(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7707,        199]*)
(*NotebookOutlinePosition[     10567,        294]*)
(*  CellTagsIndexPosition[     10216,        276]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Getting Started", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["About Wavelet Explorer",
    ButtonData:>{"Wavelets 0.1.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["Where to Find More Information about Mathematica ",
    ButtonData:>{"Wavelets 0.1.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["Installing and Loading Wavelet Explorer",
    ButtonData:>{"Wavelets 0.1.3"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["Getting Started", "Section",
  CellTags->{"S0.1.0", "0.1"}],

Cell["About Wavelet Explorer", "Subsection",
  CellTags->{"S0.1.1", "1.1"}],

Cell[TextData[{
  "Wavelet Explorer is designed to provide users with convenient ",
  StyleBox["Mathematica", "TI"],
  " tools that can be used in the study, exploration, and application of \
wavelets. In Wavelet Explorer we not only introduce the ",
  StyleBox["Mathematica", "TI"],
  " functions and their usage but also explain the key aspects of the \
theoretical framework so it can be as self\[Hyphen]contained as possible. \
Wavelet Explorer consists of a ",
  StyleBox["Mathematica", "TI"],
  " package, this manual, and data files. \n",
  StyleBox["Mathematica", "TI"],
  " packages are collections of programs written in the ",
  StyleBox["Mathematica", "TI"],
  " language, so Wavelet Explorer can only be used in conjunction with ",
  StyleBox["Mathematica", "TI"],
  ". The package provided with Wavelet Explorer is ",
  StyleBox["Wavelets.m", "MR"],
  ". It contains many of the functions and utilities necessary for both \
exploring wavelet theory and applying wavelet analysis to real data.\nThe \
purpose of this manual is twofold. Apart from introducing and illustrating \
the use of the functions contained in the package ",
  StyleBox["Wavelets.m", "MR"],
  ", it also aims to provide some theoretical background on wavelets. The \
theoretical background provided in this manual is more extensive than in the \
usual manuals of this kind partly because existing materials on wavelet \
theory tend to be rather mathematical; this manual is designed for those \
whose primary goal is to understand the ideas behind wavelet theory and to \
use wavelet analysis as a tool in their field of application. \nThis manual \
consists of three parts. Part 1, Fundamentals of Wavelets, provides the user \
with the basic ideas behind wavelet theory as well as with illustrative \
examples of using ",
  StyleBox["Mathematica", "TI"],
  " to acquire intuitive understanding. It is meant to be an introduction to \
some of the mathematical aspects of wavelet theory. The emphasis is on basic \
ideas and logical structure, and the level of mathematical rigor can only be \
described as informal. For those who want to pursue detailed derivations, \
appropriate references are given at the end of the manual. The usage of the ",
  
  StyleBox["Mathematica", "TI"],
  " functions introduced in Part 1 is further illustrated in Part 2 of the \
manual, Further Examples and Applications. Some data sets and images are \
analysed and additional utility functions are introduced. Part 3, Summary of \
Functions, summarizes all the ",
  StyleBox["Mathematica", "TI"],
  " functions provided in the first two parts of the manual and gives simple \
examples illustrating the syntax and usage of the functions. Those formulas \
that help define terms and notations are again included in this part. This \
concise summary is meant to be a quick and handy reference to the functions \
in the package. \nData sets used in the application examples are also \
provided with Wavelet Explorer so the results of the examples can be \
reproduced if desired. These data sets are contained in data files, which can \
be found in the subdirectory ",
  StyleBox["Data", "MR"],
  " of the ",
  StyleBox["Wavelets", "MR"],
  " directory. "
}], "Text",
  CellTags->{"S0.1.1", "1.2"}],

Cell[TextData[{
  "Where to Find More Information about ",
  StyleBox["Mathematica", "SBO"],
  " "
}], "Subsection",
  CellTags->{"S0.1.2", "2.1"}],

Cell[TextData[{
  "An elementary familiarity with the ",
  StyleBox["Mathematica", "TI"],
  " language is required to use Wavelet Explorer. For general information on \
using ",
  StyleBox["Mathematica", "TI"],
  ", see ",
  StyleBox["The Mathematica Book", "TI"],
  ", Third Edition, by Stephen Wolfram. Many other publications on ",
  StyleBox["Mathematica", "TI"],
  " are also available. For a complete listing see the ",
  StyleBox["Mathematica", "TI"],
  " Products Catalog, available from Wolfram Research, Inc. "
}], "Text",
  CellTags->{"S0.1.2", "2.2"}],

Cell["Installing and Loading Wavelet Explorer", "Subsection",
  CellTags->{"S0.1.3", "3.1"}],

Cell[TextData[{
  "Wavelet Explorer is easy to install. Make sure you have ",
  StyleBox["Mathematica", "TI"],
  " installed on your computer and follow the steps described on the \
installation card. First you should decide on a directory where you would \
like to put Wavelet Explorer. Suppose you choose to install it in a directory \
called ",
  StyleBox["MathApps", "MR"],
  "; the installation program will create a subdirectory ",
  StyleBox["Wavelets", "MR"],
  " for Wavelet Explorer within the ",
  StyleBox["MathApps", "MR"],
  " directory. All the data files will then be in the subdirectory ",
  StyleBox["Data", "MR"],
  " of the ",
  StyleBox["Wavelets", "MR"],
  " directory. After installing Wavelet Explorer, you must add the directory \
",
  StyleBox["MathApps", "MR"],
  " to the ",
  StyleBox["$Path", "MR"],
  " variable. The installation card tells you how to do it. Once you have \
done so, you can load the ",
  StyleBox["Wavelets.m", "MR"],
  " package as follows. "
}], "Text",
  CellTags->{"S0.1.3", "3.2"}],

Cell[TextData[{
  "This loads the package ",
  StyleBox["Wavelets.m", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S0.1.3", "3.3"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S0.1.3"]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 600},
WindowMargins->{{194, Automatic}, {-16, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 58, 1, 52, "Section",
      CellTags->"Contents"],
    Cell[1770, 52, 441, 14, 64, "Contents",
      CellTags->"Contents"]},
  "S0.1.0"->{
    Cell[2214, 68, 65, 1, 52, "Section",
      CellTags->{"S0.1.0", "0.1"}]},
  "0.1"->{
    Cell[2214, 68, 65, 1, 52, "Section",
      CellTags->{"S0.1.0", "0.1"}]},
  "S0.1.1"->{
    Cell[2282, 71, 75, 1, 36, "Subsection",
      CellTags->{"S0.1.1", "1.1"}],
    Cell[2360, 74, 3263, 58, 481, "Text",
      CellTags->{"S0.1.1", "1.2"}]},
  "1.1"->{
    Cell[2282, 71, 75, 1, 36, "Subsection",
      CellTags->{"S0.1.1", "1.1"}]},
  "1.2"->{
    Cell[2360, 74, 3263, 58, 481, "Text",
      CellTags->{"S0.1.1", "1.2"}]},
  "S0.1.2"->{
    Cell[5626, 134, 147, 5, 70, "Subsection",
      CellTags->{"S0.1.2", "2.1"}],
    Cell[5776, 141, 563, 14, 70, "Text",
      CellTags->{"S0.1.2", "2.2"}]},
  "2.1"->{
    Cell[5626, 134, 147, 5, 70, "Subsection",
      CellTags->{"S0.1.2", "2.1"}]},
  "2.2"->{
    Cell[5776, 141, 563, 14, 70, "Text",
      CellTags->{"S0.1.2", "2.2"}]},
  "S0.1.3"->{
    Cell[6342, 157, 92, 1, 70, "Subsection",
      CellTags->{"S0.1.3", "3.1"}],
    Cell[6437, 160, 1035, 26, 70, "Text",
      CellTags->{"S0.1.3", "3.2"}],
    Cell[7475, 188, 132, 5, 70, "MathCaption",
      CellTags->{"S0.1.3", "3.3"}],
    Cell[7610, 195, 93, 2, 70, "Input",
      CellTags->"S0.1.3"]},
  "3.1"->{
    Cell[6342, 157, 92, 1, 70, "Subsection",
      CellTags->{"S0.1.3", "3.1"}]},
  "3.2"->{
    Cell[6437, 160, 1035, 26, 70, "Text",
      CellTags->{"S0.1.3", "3.2"}]},
  "3.3"->{
    Cell[7475, 188, 132, 5, 70, "MathCaption",
      CellTags->{"S0.1.3", "3.3"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 8552, 221},
  {"S0.1.0", 8710, 226},
  {"0.1", 8799, 229},
  {"S0.1.1", 8891, 232},
  {"1.1", 9061, 237},
  {"1.2", 9153, 240},
  {"S0.1.2", 9246, 243},
  {"2.1", 9417, 248},
  {"2.2", 9511, 251},
  {"S0.1.3", 9603, 254},
  {"3.1", 9924, 263},
  {"3.2", 10017, 266},
  {"3.3", 10107, 269}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 58, 1, 52, "Section",
  CellTags->"Contents"],
Cell[1770, 52, 441, 14, 64, "Contents",
  CellTags->"Contents"],
Cell[2214, 68, 65, 1, 52, "Section",
  CellTags->{"S0.1.0", "0.1"}],
Cell[2282, 71, 75, 1, 36, "Subsection",
  CellTags->{"S0.1.1", "1.1"}],
Cell[2360, 74, 3263, 58, 481, "Text",
  CellTags->{"S0.1.1", "1.2"}],
Cell[5626, 134, 147, 5, 70, "Subsection",
  CellTags->{"S0.1.2", "2.1"}],
Cell[5776, 141, 563, 14, 70, "Text",
  CellTags->{"S0.1.2", "2.2"}],
Cell[6342, 157, 92, 1, 70, "Subsection",
  CellTags->{"S0.1.3", "3.1"}],
Cell[6437, 160, 1035, 26, 70, "Text",
  CellTags->{"S0.1.3", "3.2"}],
Cell[7475, 188, 132, 5, 70, "MathCaption",
  CellTags->{"S0.1.3", "3.3"}],
Cell[7610, 195, 93, 2, 70, "Input",
  CellTags->"S0.1.3"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

