(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7493,        175]*)
(*NotebookOutlinePosition[      8719,        220]*)
(*  CellTagsIndexPosition[      8577,        211]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.1 Introduction", "Section",
  CellTags->"Contents"],

Cell["1.1 Introduction", "Section",
  CellTags->{"S1.1.0", "0.1"}],

Cell[TextData[{
  "Wavelets provide convenient sets of basis functions for function spaces. \
Wavelets literally means \"small waves\". As the name suggests, they are \
waves; they oscillate and their curves yield zero net area: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Psi]", \((t)\), 
          " ", 
          StyleBox[\("dt"\),
            "TI"], "=", "0"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.1.0"],
  ". The \"smallness\" refers to the fact that they are localized in time. \
Contrast this with the behavior of the Fourier basis consisting of sines and \
cosines. Sines and cosines are perfectly localized in frequency space but do \
not decay as a function of time (\"nonlocal support\"); wavelets, on the \
other hand, decay to zero as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \(\[PlusMinus]\[Infinity]\)\)], 
    "InlineFormula",
    CellTags->"S1.1.0"],
  " and enjoy good localization properties in frequency space. This leads to \
the possibility that wavelets are better suited to represent functions that \
are localized both in time and frequency. In particular, wavelets enable us \
to represent functions with sharp spikes or edges, as for example in two\
\[Hyphen]dimensional images, with fewer terms. This efficiency in \
representing functions has obvious advantages in many applications; for \
example, in data compression and transmission and numerical analysis where \
this \"sparseness\" is a boon in terms of computational speed for certain \
classes of problems. \nHow does one construct wavelets? One starts from the \
basic wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.1.0"],
  " dubbed the \"mother wavelet\" and generates the basis by ",
  StyleBox["dilation", "TI"],
  " and ",
  StyleBox["translation", "TI"],
  " in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((a  t - b)\)\)], "InlineFormula",
    CellTags->"S1.1.0"],
  ". For discrete wavelets, the parameters by which one translates, ",
  Cell[BoxData[
      \(TraditionalForm\`b\)], "InlineFormula",
    CellTags->"S1.1.0"],
  ", and dilates, ",
  Cell[BoxData[
      \(TraditionalForm\`a\)], "InlineFormula",
    CellTags->"S1.1.0"],
  ", are restricted to a discrete set, usually ",
  Cell[BoxData[
      \(TraditionalForm\`a = 2\^j, b = k\)], "InlineFormula",
    CellTags->"S1.1.0"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.1.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.1.0"],
  " are integers. The crucial feature of dilation underlies the possibility \
of a hierarchical representation of the data set. In the so\[Hyphen]called \
multiresolution analysis framework, which we will discuss in the next \
section, we see that details or fluctuations at different levels of \
resolution are represented by the superposition of wavelets associated with \
the appropriate dilation. The ability to \"zoom\[Hyphen]in\" on details is of \
considerable value in visualizing complex data such as those in fluid \
turbulence, for example; on the other hand, details can also be suppressed \
easily and thus wavelets can be used for data smoothing. \nObviously, unlike \
the case of Fourier transforms, there exists a large selection of wavelet \
families depending on the choice of the mother wavelet. However, desirable \
properties such as orthogonality, compactness of support, rapid decay, and \
smoothness impose a variety of restrictions. The \"optimal\" choice of the \
wavelet basis will depend on the application at hand, and therein lies part \
of the difficulty for the novice. Wavelets can be a useful tool if one \
develops an intuitive understanding of their behavior, and ",
  StyleBox["Wavelet Explorer", "TI"],
  " is designed to facilitate your exploration of this exciting area. \n\
Various wavelets with different advantages and disadvantages are known. For \
example, the celebrated Daubechies wavelets are orthogonal and have compact \
support, but they do not have a closed analytic form and the \
lowest\[Hyphen]order families do not have continuous derivatives everywhere. \
However, Battle\[Hyphen]Lemari\[EAcute] wavelets, constructed from ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.1.0"],
  "\[Hyphen]spline functions, do not have compact support, but are orthogonal \
and have better smoothness properties. Other examples include the Haar \
wavelet, coiflets, Meyer wavelets, biorthogonal wavelets, etc. These families \
and the algorithms to construct them are introduced in Sections ",
  ButtonBox["1.3",
    ButtonData:>{"Wavelets 1.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ", and ",
  ButtonBox["1.6",
    ButtonData:>{"Wavelets 1.6"},
    ButtonStyle->"AddOnsLink"],
  ", where the ",
  StyleBox["Mathematica", "TI"],
  " functions that can generate these wavelets and filter coefficients are \
presented as well. Wavelet transforms and wavelet packet transforms are \
discussed in Section ",
  ButtonBox["1.5",
    ButtonData:>{"Wavelets 1.5"},
    ButtonStyle->"AddOnsLink"],
  " and the functions that implement them are presented. Local trigonometric \
bases of Coifman and Meyer and their transforms are the subject of Section ",
  ButtonBox["1.7",
    ButtonData:>{"Wavelets 1.7"},
    ButtonStyle->"AddOnsLink"],
  ". But first we discuss multiresolution analysis. "
}], "Text",
  CellTags->{"S1.1.0", "0.2"}]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{51, Automatic}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 59, 1, 58, "Section",
      CellTags->"Contents"]},
  "S1.1.0"->{
    Cell[1771, 52, 66, 1, 58, "Section",
      CellTags->{"S1.1.0", "0.1"}],
    Cell[1840, 55, 5649, 118, 672, "Text",
      CellTags->{"S1.1.0", "0.2"}]},
  "0.1"->{
    Cell[1771, 52, 66, 1, 58, "Section",
      CellTags->{"S1.1.0", "0.1"}]},
  "0.2"->{
    Cell[1840, 55, 5649, 118, 672, "Text",
      CellTags->{"S1.1.0", "0.2"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 8130, 193},
  {"S1.1.0", 8215, 196},
  {"0.1", 8383, 201},
  {"0.2", 8472, 204}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 59, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1771, 52, 66, 1, 58, "Section",
  CellTags->{"S1.1.0", "0.1"}],
Cell[1840, 55, 5649, 118, 672, "Text",
  CellTags->{"S1.1.0", "0.2"}]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

