(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    115423,       4523]*)
(*NotebookOutlinePosition[    142161,       5310]*)
(*  CellTagsIndexPosition[    138975,       5183]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.2 Multiresolution Analysis", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 1.2.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.2.1 Definition of a Multiresolution Analysis",
    ButtonData:>{"Wavelets 1.2.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.2.2 Examples of Multiresolution Analysis",
    ButtonData:>{"Wavelets 1.2.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox[
  "1.2.3 Approximation Spaces, Scaling Function, and the Dilation Equation",
    ButtonData:>{"Wavelets 1.2.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.2.4 Detail Spaces, Mother Wavelet, and the Wavelet Equation",
    ButtonData:>{"Wavelets 1.2.4"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.2.5 A View from the Frequency Domain",
    ButtonData:>{"Wavelets 1.2.5"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["1.2 Multiresolution Analysis", "Section",
  CellTags->{"S1.2.0", "0.1"}],

Cell[TextData[{
  "In this section, we introduce the subject of multiresolution analysis. We \
start with the formal definition along with a heuristic explanation; this is \
followed by the canonical examples of Haar and spline multiresolution \
analyses. The key ideas of the dilation equation, the mother wavelet, and the \
wavelet equation are presented. We then explore the frequency space view of \
these concepts which affords a different and useful perspective. Our aim is \
to provide a practical tool; therefore, we will state the definitions as \
carefully as necessary without becoming bogged down in mathematical rigor; \
the reader is referred to Mallat (1989), Daubechies (1992), Jawerth and \
Sweldens (1994), and other excellent references at the end of the manual for \
proofs and discussions. \nA function or signal can be viewed as composed of a \
smooth background and fluctuations or details on top of it. The distinction \
between the smooth part and the details is determined by the resolution, that \
is, by the scale below which the details of a signal cannot be discerned. At \
a given resolution, a signal is approximated by ignoring all fluctuations \
below that scale. We can imagine progressively increasing the resolution; at \
each stage of the increase in resolution finer details are added to the \
coarser description, providing a successively better approximation to the \
signal. Eventually when the resolution goes to infinity, we recover the exact \
signal. \nThe above intuitive description can be made more precise as \
follows. We label the resolution level by an integer ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ". The scale associated with the level ",
  Cell[BoxData[
      \(TraditionalForm\`j = 0\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " is set to, say, unity and that with the level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ". Let us consider a function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ". At resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " it is approximated by ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ". At the next level of resolution ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ", the details at that level denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " are included and we have the approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " at the new resolution level, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(f\_\(j + 1\)\) \((t)\) = \(f\_j\) \((t)\) + \(d\_j\) \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.0"],
  ". The original function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " is recovered when we let the resolution go to infinity"
}], "Text",
  CellTags->{"S1.2.0", "0.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", \(f\_j\), \((t)\), "+", 
        UnderoverscriptBox["\[Sum]", \(k = j\), "\[Infinity]",
          LimitsPositioning->True], \(d\_k\), \((t)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.0", "0.3"}],

Cell[TextData[{
  "The word multiresolution refers to the simultaneous presence of different \
resolutions. The above equation represents one way of decomposing the \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " into a smooth part plus details. Similarly, we can view the space of \
functions that are square integrable, ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ", as composed of a sequence of subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{W\_k}\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ", such that the approximation of ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " at resolution ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ", is in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " and the details ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_k\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.0"],
  " are in ",
  Cell[BoxData[
      \(TraditionalForm\`W\_k\)], "InlineFormula",
    CellTags->"S1.2.0"],
  ". This brings us to the subject of this section, multiresolution analysis. \
"
}], "Text",
  CellTags->{"S1.2.0", "0.4"}],

Cell["1.2.1 Definition of a Multiresolution Analysis", "Subsection",
  CellTags->{"S1.2.1", "1.1"}],

Cell[TextData[{
  "We discuss the requirements imposed on a multiresolution analysis \
qualitatively.\nConsider the space of square\[Hyphen]integrable functions. We \
define a sequence of resolutions labeled by the integers such that all \
details of the signal on scales smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " are suppressed at resolution ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". We denote the subspace of functions that contain signal information down \
to scale ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". The multiresolution analysis involves a decomposition of the function \
space into a sequence of subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". The first requirement is that the subspace ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " be contained in all the higher subspaces. This is clearly reasonable. If \
we denote the approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " at level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\) \[Element] V\_j\)], "InlineFormula",
    
    CellTags->"S1.2.1"],
  ". Since information at resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is necessarily included in the information at a higher resolution, ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " must be contained in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", that is, mathematically, ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j \[Subset] V\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". \nThe difference between ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_\(j + 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is the additional information about details at scale ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-\((j + 1)\)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " which we denoted earlier by ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(d\_j\) \((t)\) = \(f\_\(j + 1\)\) \((t)\) - \(f\_j\) \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.1"],
  ". So we have "
}], "Text",
  CellTags->{"S1.2.1", "1.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(f\_\(j + 1\)\) \((t)\) = \(f\_j\) \((t)\) + \(d\_j\) \((t)\).\)], 
  "DisplayFormula",
  CellTags->{"S1.2.1", "1.3"}],

Cell["We can decompose our subspaces accordingly, and write ", "Text",
  CellTags->{"S1.2.1", "1.4"}],

Cell[BoxData[
    \(TraditionalForm\`V\_\(j + 1\) = V\_j\[CirclePlus]W\_j, \)], 
  "DisplayFormula",
  CellTags->{"S1.2.1", "1.5"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is called the detail space at resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " and is orthogonal to ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". This means that the inner product between any element in ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " and any element in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " vanishes. (We call two spaces that satisfy this property orthogonal and \
use ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j \[UpTee] W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " to denote ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is orthogonal to ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ".) We can continue the decomposition of the ",
  Cell[BoxData[
      \(TraditionalForm\`V\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " space and obtain"
}], "Text",
  CellTags->{"S1.2.1", "1.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`V\_\(j + 1\) = W\_j\[CirclePlus]V\_j = 
      W\_j\[CirclePlus]W\_\(j - 1\)\[CirclePlus]V\_\(j - 1\) = 
      \[CenterEllipsis] = 
      W\_j\[CirclePlus]W\_\(j - 1\)\[CirclePlus]W
        \_\(j - 2\)\[CirclePlus]\[CenterEllipsis]\[CirclePlus]W
        \_\(j - J\)\[CirclePlus]V\_\(j - J\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.1", "1.7"}],

Cell[TextData[{
  "So the approximation space at resolution ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", can be written as a sum of subspaces. It is easy to see that these \
subspaces are mutually orthogonal. Since ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j \[UpTee] V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " should be orthogonal to any subspace of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". Because both ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j\^\[Prime]\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_\(j\^\[Prime]\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " are contained in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j\^\[Prime] < j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j \[UpTee] V\_\(j\^\[Prime]\)\)], "InlineFormula",
    
    CellTags->"S1.2.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j > j\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j \[UpTee] W\_\(j\^\[Prime]\)\)], "InlineFormula",
    
    CellTags->"S1.2.1"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`j \[NotEqual] j\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". This is to say any two detail spaces at different resolutions are \
orthogonal, and the detail space ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is orthogonal to an approximation space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j\^\[Prime]\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " only when the detail space has higher resolution. \nThe second \
requirement for multiresolution analysis is that all square integrable \
functions be included at the finest resolution and only the zero function at \
the coarsest level. As the resolution gets coarser and coarser, more and more \
details are removed, and in the limit ",
  Cell[BoxData[
      \(TraditionalForm\`j \[Rule] -\[Infinity]\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", only a constant function survives and since it has to be square \
integrable, it can only be the zero function. Therefore, we demand that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["lim", \(j \[Rule] -\[Infinity]\),
            LimitsPositioning->True], \(V\_j\), "=", \({0}\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.1"],
  ". On the other hand, when we increase the resolution, more details are \
included and as the resolution goes to infinity, we should recover, crudely \
speaking, the entire initial space ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", that is, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["lim", \(j \[Rule] \[Infinity]\),
            LimitsPositioning->True], \(V\_j\), "\[Rule]", \(L\^2\), \((R)
          \)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.1"],
  ". \nThe third condition is the key requirement of scale or dilation \
invariance. It says that all the spaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " are scaled versions of the central space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " contains no details or fluctuations at scales smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`f \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is a function obtained by squeezing ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " by a factor of 2 and contains no details at scales smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`f \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". \nThe fourth condition is the requirement of translation or shift \
invariance of the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", so do its translates by integers, ",
  Cell[BoxData[
      \(TraditionalForm\`{f \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". Given this, one can show that all the subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " are also shift\[Hyphen]invariant. \nThe third and fourth requirements of \
dilation and translation invariance yield the result that if ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f \((\(2\^j\) t - k)\) \[Element] V\_j\)], 
    "InlineFormula",
    CellTags->"S1.2.1"],
  ". \nThe final requirement is that there exists a function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " such that its translates form an orthonormal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". Using the scale invariance condition, we see that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((2  t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is an orthogonal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". Similarly, if we define ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi]\_\(j  k\)\) \((t)\) = \(2\^\(j/2\)\) \[Phi] \((
        \(2\^j\) t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " forms an orthonormal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ". The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", which generates the basis functions for all the spaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", is called the ",
  StyleBox["scaling function", "TI"],
  " of the multiresolution analysis.\nWe now summarize our previous \
discussion by formally defining a multiresolution analysis. \nA \
multiresolution analysis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is a nested sequence of subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\_\(j \[Element] Z\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`Z\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is the set of integers) such that \n(i)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CenterEllipsis] \[Subset] V\_\(-1\) \[Subset] V\_0 \[Subset] V\_1 
        \[Subset] \[CenterEllipsis] \[Subset] \(L\^2\) \((R)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.1"],
  " \n(ii)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Intersection]\_j V\_j = {0}, " " \(\( \[Union] \_j\)V\_j\)\&_ = 
        \(L\^2\) \((R)\)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " \n(iii)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`f \((t)\) \[Element] V\_j\[DoubleLongLeftRightArrow]f \((2  t)\) 
        \[Element] V\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " \n(iv)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`f \((t)\) \[Element] V\_0\[DoubleLongRightArrow]f \((t - k)\) 
        \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " \n(v)  There exists a function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ", called the scaling function, such that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.1"],
  " is an orthonormal basis of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.1"],
  ".  "
}], "Text",
  CellTags->{"S1.2.1", "1.8"}],

Cell["1.2.2 Examples of Multiresolution Analysis", "Subsection",
  CellTags->{"S1.2.2", "2.1"}],

Cell["\<\
First we look at a couple of simple, canonical examples of \
multiresolution analysis. \
\>", "Text",
  CellTags->{"S1.2.2", "2.2"}],

Cell["Haar Multiresolution Analysis", "Subsubsection",
  CellTags->{"S1.2.2", "2.3"}],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " be the space of functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] \(L\^2\) \((R)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.2"],
  " that are constant on the unit intervals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k, k + 1)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.2"],
  " for integer ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", and let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " be the space of functions that are constant on the intervals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k/2\^j, \((k + 1)\)/2\^j)
      \)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". We can easily verify that this collection of spaces forms a \
multiresolution analysis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". With increasing index ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", the spaces are larger and form better and better approximations of ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". Clearly ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is contained in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " because a function constant on unit intervals is certainly constant on \
half of those intervals. Similarly, ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j \[Subset] V\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". We can easily show that these spaces also satisfy the conditions (ii) to \
(iv). For example, if ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is a piecewise constant function with possible discontinuities at \
integers, then ",
  Cell[BoxData[
      \(TraditionalForm\`f \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is a piecewise constant function with possible discontinuities occurring \
at half integers, and translation by integers leads to ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", again a piecewise constant function with discontinuities at integers. \
Now we can complete our proof that ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " indeed form a multiresolution analysis of ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " by giving explicitly the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". In our example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " can be chosen to be the characteristic function on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 1)\)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", known as the ",
  StyleBox["box function", "TI"],
  ", "
}], "Text",
  CellTags->{"S1.2.2", "2.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["1",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" for "\), 
                    StyleBox[\(0 \[LessEqual] t < 1\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\(" otherwise".\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.2.2", "2.5"}],

Cell[TextData[{
  "This defines the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " given above."
}], "MathCaption",
  CellTags->{"S1.2.2", "2.6"}],

Cell["boxf[t_]:= Which[0 <= t < 1, 1, True, 0]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.2.2"],

Cell[TextData[{
  "The scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is simply the box function."
}], "MathCaption",
  CellTags->{"S1.2.2", "2.7"}],

Cell[CellGroupData[{

Cell["\<\
Plot[boxf[t], {t, -1, 3}, PlotRange -> {0, 2},
Ticks -> {Automatic, {1, 2}},
AxesLabel -> {\"t\", \"phi(t)\"}]\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.2494 .30902 -6 -4.5 ]
[.2494 .30902 0 4.5 ]
[.2494 .61803 -6 -4.5 ]
[.2494 .61803 0 4.5 ]
[.2619 .64303 -18 0 ]
[.2619 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] 1.025 0 -1 0 Mshowa
.2619 .30902 m
.26815 .30902 L
s
[(1)] .2494 .30902 1 0 Mshowa
.2619 .61803 m
.26815 .61803 L
s
[(2)] .2494 .61803 1 0 Mshowa
.2619 0 m
.2619 .61803 L
s
[(phi\\(t\\))] .2619 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.24141 0 L
.25127 0 L
.25666 0 L
.2593 0 L
.26045 0 L
.26171 0 L
.26301 .30902 L
.26425 .30902 L
.26698 .30902 L
.27279 .30902 L
.28302 .30902 L
.30316 .30902 L
.3438 .30902 L
.38293 .30902 L
.42451 .30902 L
.44538 .30902 L
.46458 .30902 L
.48333 .30902 L
.49277 .30902 L
.49535 .30902 L
.49678 .30902 L
.49813 .30902 L
.49938 .30902 L
.50009 0 L
.50074 0 L
.50313 0 L
.5424 0 L
.58015 0 L
.62035 0 L
.65904 0 L
.70018 0 L
.7398 0 L
.77791 0 L
.81847 0 L
.85752 0 L
.89901 0 L
.939 0 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],

Cell[TextData[{
  "Here is the translated version of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.2.2", "2.8"}],

Cell[CellGroupData[{

Cell["\<\
Plot[boxf[t-1], {t, -1, 3}, PlotRange -> {0, 2},
Ticks -> {Automatic, {1, 2}},
AxesLabel -> {\"t\", \"phi(t-1)\"}];\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.2494 .30902 -6 -4.5 ]
[.2494 .30902 0 4.5 ]
[.2494 .61803 -6 -4.5 ]
[.2494 .61803 0 4.5 ]
[.2619 .64303 -24 0 ]
[.2619 .64303 24 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] 1.025 0 -1 0 Mshowa
.2619 .30902 m
.26815 .30902 L
s
[(1)] .2494 .30902 1 0 Mshowa
.2619 .61803 m
.26815 .61803 L
s
[(2)] .2494 .61803 1 0 Mshowa
.2619 0 m
.2619 .61803 L
s
[(phi\\(t-1\\))] .2619 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.30316 0 L
.34309 0 L
.3815 0 L
.42237 0 L
.46172 0 L
.48147 0 L
.49012 0 L
.49468 0 L
.49719 0 L
.49842 0 L
.49955 0 L
.50085 .30902 L
.50154 .30902 L
.50226 .30902 L
.50471 .30902 L
.5095 .30902 L
.51896 .30902 L
.53984 .30902 L
.57781 .30902 L
.61824 .30902 L
.65714 .30902 L
.67695 .30902 L
.6985 .30902 L
.70854 .30902 L
.7192 .30902 L
.7283 .30902 L
.7308 .30902 L
.73349 .30902 L
.73472 .30902 L
.73602 .30902 L
.73713 .30902 L
.73835 0 L
.73967 0 L
.74089 0 L
.74364 0 L
.74862 0 L
.75796 0 L
.77891 0 L
.81831 0 L
.8562 0 L
.89654 0 L
.93537 0 L
.97619 0 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],

Cell[TextData[{
  "It is easy to see that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " are orthonormal since there is no overlap between ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t - k\^\[Prime])\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`k \[NotEqual] k\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " and the integral of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^2\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is 1. Any function in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " can be written as a superposition of these box functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
            LimitsPositioning->True], "f", \((k)\), "\[Phi]", \((t - k)\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.2"],
  ". Therefore, the box function is the desired scaling function for the \
multiresolution analysis. This multiresolution analysis is called the ",
  StyleBox["Haar multiresolution analysis", "TI"],
  ". "
}], "Text",
  CellTags->{"S1.2.2", "2.9"}],

Cell["Piecewise Linear Functions", "Subsubsection",
  CellTags->{"S1.2.2", "2.10"}],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " be the space containing all continuous functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " that are linear between ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k, k + 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.2"],
  ", and let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " be the space of functions linear on the intervals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k/2\^j, \((k + 1)\)/2\^j]
      \)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`f \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is a function linear on the intervals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k/2, \((k + 1)\)/2]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f \((2  t)\) \[Element] V\_1\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". Again we can verify that ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " satisfy the conditions (i)\[Dash](iv). The translates of the hat function \
",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " form a basis of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", where the hat function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is defined by "
}], "Text",
  CellTags->{"S1.2.2", "2.11"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Beta]\_1\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                
                StyleBox[
                  \(1 -  \[VerticalSeparator] t \[VerticalSeparator] \),
                  "DisplayFormula"], 
                StyleBox[\(\(-1\) \[LessEqual] t \[LessEqual] 1\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise".\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.2.2", "2.12"}],

Cell[TextData[{
  "Any function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " can be written as the superposition of these basis functions, "
}], "Text",
  CellTags->{"S1.2.2", "2.13"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], "f", \((k)\), \(\[Beta]\_1\), \((t - k)\),
         "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.2", "2.14"}],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " vanishes for all integer values of its argument except ",
  Cell[BoxData[
      \(TraditionalForm\`0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". This shows that the expansion (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.14"},
    ButtonStyle->"AddOnsLink"],
  ") agrees with the function at the integers. When ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is between two integers ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Element] \((k, k + 1)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is a combination of two linear functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t - k - 1)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", and this combination of two linear functions gives rise to a linear \
function which is specified entirely by its two values at ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k + 1\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". So (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.14"},
    ButtonStyle->"AddOnsLink"],
  ") is a correct expansion, and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". However, this basis is not orthogonal. This is evident from the \
following plot of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t - 1)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t - 2)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". "
}], "Text",
  CellTags->{"S1.2.2", "2.15"}],

Cell["This defines the hat function.", "MathCaption",
  CellTags->{"S1.2.2", "2.16"}],

Cell["beta[t_]:= Which[-1 < t < 1, 1-Abs[t], True, 0]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.2.2"],

Cell[TextData[{
  "The translates of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " overlap and the basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is not orthogonal."
}], "MathCaption",
  CellTags->{"S1.2.2", "2.17"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{beta[t], beta[t - 1], beta[t - 2]}, {t, -2, 4},
PlotRange -> {0, 2}, Ticks -> {Automatic, {1, 2}},
AxesLabel -> {\"t\", \"beta1\"}, AspectRatio -> Automatic];\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31746 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0 0.15873 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -3 -9 ]
[.81746 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.32877 .15873 -6 -4.5 ]
[.32877 .15873 0 4.5 ]
[.32877 .31746 -6 -4.5 ]
[.32877 .31746 0 4.5 ]
[.34127 .34246 -15 0 ]
[.34127 .34246 15 9 ]
[ 0 0 0 0 ]
[ 1 .31746 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-1)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(3)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] 1.025 0 -1 0 Mshowa
.34127 .15873 m
.34752 .15873 L
s
[(1)] .32877 .15873 1 0 Mshowa
.34127 .31746 m
.34752 .31746 L
s
[(2)] .32877 .31746 1 0 Mshowa
.34127 0 m
.34127 .31746 L
s
[(beta1)] .34127 .34246 0 -1 Mshowa
0 0 m
1 0 L
1 .31746 L
0 .31746 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.16408 0 L
.17277 0 L
.17735 0 L
.17986 0 L
.18109 0 L
.18221 0 L
.18341 .00087 L
.1847 .00216 L
.18744 .0049 L
.19227 .00973 L
.20178 .01924 L
.22272 .04018 L
.26243 .07989 L
.30062 .11808 L
.32194 .1394 L
.332 .14946 L
.33642 .15388 L
.33892 .15638 L
.34015 .15761 L
.34126 .15872 L
.34243 .15757 L
.34354 .15646 L
.34597 .15403 L
.35094 .14906 L
.36141 .13859 L
.38039 .11961 L
.41872 .08128 L
.45951 .04049 L
.47976 .02024 L
.48968 .01032 L
.49402 .00598 L
.49632 .00368 L
.49758 .00242 L
.49877 .00123 L
.49992 8e-05 L
.50117 0 L
.50231 0 L
.50336 0 L
.50762 0 L
.51694 0 L
.53652 0 L
.57593 0 L
.61381 0 L
.65415 0 L
.69298 0 L
.73425 0 L
Mistroke
.77401 0 L
.81226 0 L
.85296 0 L
.89214 0 L
.93377 0 L
.97389 0 L
.97619 0 L
Mfstroke
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.28158 0 L
.30316 0 L
.31323 0 L
.32392 0 L
.33304 0 L
.33554 0 L
.33823 0 L
.33953 0 L
.34076 0 L
.34187 .0006 L
.34309 .00182 L
.38373 .04246 L
.42286 .08159 L
.46444 .12317 L
.47459 .13332 L
.48531 .14404 L
.49446 .15319 L
.49697 .1557 L
.49835 .15708 L
.49966 .15839 L
.50087 .15786 L
.5022 .15653 L
.50451 .15422 L
.54306 .11567 L
.58384 .07489 L
.62311 .03562 L
.6428 .01593 L
.65143 .0073 L
.65379 .00494 L
.65631 .00242 L
.65754 .00119 L
.65869 4e-05 L
.65973 0 L
.66086 0 L
.67028 0 L
.68021 0 L
.70106 0 L
.74198 0 L
.78138 0 L
.81927 0 L
.85961 0 L
.89843 0 L
.93971 0 L
Mistroke
.97619 0 L
Mfstroke
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.30316 0 L
.34309 0 L
.3815 0 L
.42237 0 L
.46172 0 L
.48147 0 L
.49012 0 L
.49468 0 L
.49719 0 L
.49842 0 L
.49955 0 L
.50085 .00085 L
.50154 .00154 L
.50226 .00226 L
.50471 .00471 L
.5095 .0095 L
.51896 .01896 L
.53984 .03984 L
.57781 .07781 L
.61824 .11824 L
.63687 .13687 L
.6467 .1467 L
.65209 .15209 L
.65473 .15473 L
.65714 .15714 L
.65837 .15837 L
.65967 .15779 L
.66097 .15649 L
.66239 .15507 L
.66818 .14928 L
.67838 .13908 L
.6985 .11896 L
.73907 .07839 L
.77811 .03935 L
.79802 .01944 L
.80851 .00895 L
.81127 .00619 L
.81424 .00322 L
.81568 .00178 L
.81639 .00107 L
.81705 .00041 L
.81827 0 L
.81892 0 L
Mistroke
.81961 0 L
.82951 0 L
.84041 0 L
.85959 0 L
.90123 0 L
.94134 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],

Cell[TextData[{
  "From the above graph we see that the integral of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\) \(\[Beta]\_1\) \((t - 1)\)\)],
     "InlineFormula",
    CellTags->"S1.2.2"],
  " is nonzero; therefore, the basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is not orthogonal. In this case we call ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " a nonorthogonal scaling function. We will see in Section ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.1"},
    ButtonStyle->"AddOnsLink"],
  " that from this nonorthogonal scaling function we can obtain an orthogonal \
scaling function by a well\[Hyphen]defined orthogonalization procedure. \
Therefore, the ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " under consideration still form a multiresolution analysis of ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " although we have yet to find the orthogonal scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". "
}], "Text",
  CellTags->{"S1.2.2", "2.18"}],

Cell["Spline Multiresolution Analyses", "Subsubsection",
  CellTags->{"S1.2.2", "2.19"}],

Cell[TextData[{
  "In fact, the above two examples of multiresolution analysis can be thought \
of as the first two of a whole family of multiresolution analyses called the \
spline multiresolution analyses. Each multiresolution analysis is labeled by \
an index ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", and the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " consists of all functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " that are polynomials of degree at most ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " between ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k, k + 1)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.2"],
  " and have ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " continuous derivatives for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ". So ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " corresponds to the Haar multiresolution analysis, while ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is the multiresolution analysis of the piecewise linear functions. For \
general ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.2.2"],
  ", the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is the space of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " order polynomial spline functions, and a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " is the basis splines or ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.2.2"],
  "\[Hyphen]splines. Apart from the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S1.2.2"],
  " case, these basis functions are not orthogonal and orthogonalization is \
required to get the desired scaling function. We will come back to these \
multiresolution analyses and scaling functions in Section ",
  ButtonBox["1.3",
    ButtonData:>{"Wavelets 1.3"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "Text",
  CellTags->{"S1.2.2", "2.20"}],

Cell["\<\
1.2.3 Approximation Spaces, Scaling Function, and the Dilation \
Equation\
\>", "Subsection",
  CellTags->{"S1.2.3", "3.1"}],

Cell[TextData[{
  "From the definition of a multiresolution analysis we know that the \
subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " form a nested sequence that provides successively better approximations \
to ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ". The scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " generates all the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " for each space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi]\_\(j  k\)\) \((t)\) = \(2\^\(j/2\)\) \[Phi] \((
        \(2\^j\) t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ". \nSince ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0 \[Subset] V\_1\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ", any function in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " can be expanded in terms of the basis functions of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ". In particular, the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " can be expanded in terms ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(1  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ": "
}], "Text",
  CellTags->{"S1.2.3", "3.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), \(\[Phi]\_\(1  k\)\), \((t)\), 
        "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.3", "3.3"}],

Cell[TextData[{
  "This is called the ",
  StyleBox["dilation equation", "TI"],
  ". This equation relates the scaling function at two successive scales, ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2  t\)], "InlineFormula",
    CellTags->"S1.2.3"],
  ", and, hence, it is also referred to as the ",
  StyleBox["two\[Hyphen]scale equation", "TI"],
  " or ",
  StyleBox["refinement equation", "TI"],
  ". Using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(1  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " are orthonormal, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " can be obtained by computing the inner product (assuming ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " is real):"
}], "Text",
  CellTags->{"S1.2.3", "3.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(h\_k\), "=", "\[LeftAngleBracket]", \(\[Phi]\_\(1  k\)\), \(, \ \), 
        "\[Phi]", "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), 
        "\[Phi]", \((2  t - k)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.3", "3.5"}],

Cell[TextData[{
  "We can derive some properties of the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " immediately from the dilation equation. Integrating both sides of (",
  ButtonBox["2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "), we obtain (note that normalization gives ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), 
          " ", 
          StyleBox[\("dt"\),
            "TI"], "=", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.3"],
  ") "
}], "Text",
  CellTags->{"S1.2.3", "3.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "=", \(\@2\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.3", "3.7"}],

Cell[TextData[{
  "On the other hand, if we multiply both sides of (",
  ButtonBox["2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  ") by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t - l)\)\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " and integrate, we get "
}], "Text",
  CellTags->{"S1.2.3", "3.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), 
        "\[Phi]", \((t - l)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], 
        UnderscriptBox["\[Sum]", \(k\^\[Prime]\),
          LimitsPositioning->True], \(h\_k\), " ", \(h\_\(k\^\[Prime]\)\), 
        "2", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((
        2  t - k\^\[Prime])\), "\[Phi]", \((2  t - 2  l - k)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), " ", \(h\_\(k + 2  l\)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.3", "3.9"}],

Cell[TextData[{
  "Using the orthogonality of ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.3"],
  " we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), " ", \(h\_\(k + 2  l\)\), "=",
           \(\[Delta]\_\(0  l\)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.3"],
  " or"
}], "Text",
  CellTags->{"S1.2.3", "3.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\%2\), "=", \(1\ \ \ \), 
        \(" and "\), "   ", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), " ", \(h\_\(k + 2  l\)\), "=", 
        "0", \(, \ \ \ \ \ \ \), "l", "\[NotEqual]", "0."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.3", "3.11"}],

Cell["\<\
1.2.4 Detail Spaces, Mother Wavelet, and the Wavelet Equation\
\>", 
  "Subsection",
  CellTags->{"S1.2.4", "4.1"}],

Cell[TextData[{
  "Now we examine the spaces ",
  Cell[BoxData[
      \(TraditionalForm\`{W\_j}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ". These are detail spaces and they are orthogonal to each other. Iterating \
(",
  ButtonBox["2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  ") gives "
}], "Text",
  CellTags->{"S1.2.4", "4.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`V\_\(j + 1\) = \[CirclePlus]\_\(k = -\[Infinity]\)\%j W\_k, \)], 
  "DisplayFormula",
  CellTags->{"S1.2.4", "4.3"}],

Cell[TextData[{
  "and letting ",
  Cell[BoxData[
      \(TraditionalForm\`j \[Rule] \[Infinity]\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ", we get "
}], "Text",
  CellTags->{"S1.2.4", "4.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(L\^2\) \((R)\) = 
      \[CirclePlus]\_\(k = -\[Infinity]\)\%\[Infinity] W\_k.\)], 
  "DisplayFormula",
  CellTags->{"S1.2.4", "4.5"}],

Cell[TextData[{
  "This says that we can decompose ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " into orthogonal subspaces, each containing information about details at a \
given resolution. So the collection of the bases of ",
  Cell[BoxData[
      \(TraditionalForm\`{W\_j}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " serves as a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ". It turns out that for a multiresolution analysis, the detail space ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " has an orthonormal basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\_k\)], 
    "InlineFormula",
    CellTags->"S1.2.4"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Psi]\_\(j  k\)\) \((t)\) \[Congruent] \(2\^\(j/2\)\) \[Psi] \((
        \(2\^j\) t - k)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ". So ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " has an orthonormal basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\_\(j  k\)\)], 
    "InlineFormula",
    CellTags->"S1.2.4"],
  " called the wavelet basis. Each wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(j  k\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " is generated from a single function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " by translation and dilation. The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " that generates all the basis functions of the ",
  Cell[BoxData[
      \(TraditionalForm\`W\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " space is referred to as the ",
  StyleBox["mother wavelet", "TI"],
  " or the ",
  StyleBox["basic wavelet", "TI"],
  ".\nSince ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`W\_0\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_0 \[Subset] V\_1\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " can be written as a superposition of the basis functions for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi]\_\(1  k\)}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ". In particular, we have "
}], "Text",
  CellTags->{"S1.2.4", "4.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), \(\[Phi]\_\(1  k\)\), \((t)\), 
        "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.4", "4.7"}],

Cell[TextData[{
  "This is called the ",
  StyleBox["wavelet equation", "TI"],
  ".Note the similarity between this equation and the dilation equation. This \
is an equation relating the mother wavelet to the scaling function at the \
next finer scale. Again, using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(1  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " are orthonormal, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " can be obtained by computing the inner product: "
}], "Text",
  CellTags->{"S1.2.4", "4.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(g\_k\), "=", "\[LeftAngleBracket]", \(\[Phi]\_\(1  k\)\), \(, \ \), 
        "\[Psi]", "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Psi]", \((t)\), 
        "\[Phi]", \((2  t - k)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.4", "4.9"}],

Cell[TextData[{
  "From the requirement that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Psi]", \((t)\), 
          StyleBox[\("dt"\),
            "TI"], "=", "0"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.4"],
  ", we get ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(g\_k\), "=", "0"}], TraditionalForm]],
     "InlineFormula",
    CellTags->"S1.2.4"],
  ". \nHere we summarize the results so far. ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{\("    Approximation space "\), 
                StyleBox[\(V\_j\),
                  "InlineFormula"], \(" "\)}], 
              RowBox[{\("Detail space "\), 
                StyleBox[\(W\_j\),
                  "InlineFormula"], \(" "\)}]},
            {
              RowBox[{\("    "\), 
                StyleBox[\(V\_j \[Subset] V\_\(j + 1\)\),
                  "InlineFormula"], \(" "\)}], 
              StyleBox[
                RowBox[{\(W\_j\), "\[UpTee]", \(W\_k\), "  ", 
                  RowBox[{\(" for "\), 
                    StyleBox[\(j \[NotEqual] k\),
                      "InlineFormula"]}]}],
                "InlineFormula"]},
            {
              RowBox[{\("    Scaling function "\), 
                StyleBox["\[Phi]",
                  "InlineFormula"], \(" "\)}], 
              RowBox[{\("Mother wavelet "\), 
                StyleBox["\[Psi]",
                  "InlineFormula"], \(" "\)}]},
            {
              RowBox[{\("    Dilation equation: "\), 
                StyleBox[
                  RowBox[{"\[Phi]", \((t)\), "=", \(\@2\), 
                    UnderscriptBox["\[Sum]", "k",
                      LimitsPositioning->True], \(h\_k\), "\[Phi]", \((
                    2 t - k)\)}],
                  "InlineFormula"], \(" "\)}], 
              RowBox[{\("Wavelet equation: "\), 
                StyleBox[
                  RowBox[{"\[Psi]", \((t)\), "=", \(\@2\), 
                    UnderscriptBox["\[Sum]", "k",
                      LimitsPositioning->True], \(g\_k\), "\[Phi]", \((
                    2 t - k)\)}],
                  "InlineFormula"]}]},
            {
              RowBox[{\("    Orthonormal basis for "\), 
                StyleBox[\(V\_j\),
                  "InlineFormula"], \(": "\), 
                
                StyleBox[
                  \({\(\[Phi]\_\(j k\)\) \((t)\) = \(2\^\(j/2\)\) \[Phi] \((
                      \(2\^j\) t - k)\)}\),
                  "InlineFormula"], \(" "\)}], 
              RowBox[{\("Orthonormal basis for "\), 
                StyleBox[\(W\_j\),
                  "InlineFormula"], \(": "\), 
                
                StyleBox[
                  \({\(\[Psi]\_\(j k\)\) \((t)\) = \(2\^\(j/2\)\) \[Psi] \((
                      \(2\^j\) t - k)\)}\),
                  "InlineFormula"], \(" "\)}]}
            },
          ColumnAlignments->{Left}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.4"],
  "\nSo we see that wavelets constitute a special class of basis functions \
for ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.2.4"],
  ". All these basis functions are generated from a single function, called \
the mother wavelet, by dilation and translation. Clearly different choices \
for the the mother wavelet yield different wavelet bases. One could also \
start from the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " of a multiresolution analysis since the mother wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " can be obtained from it by the wavelet equation and the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " in the wavelet equation are related to the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.2.4"],
  " in the dilation equation. To see this, we first look at these equations \
in the frequency domain. "
}], "Text",
  CellTags->{"S1.2.4", "4.10"}],

Cell["1.2.5 A View from the Frequency Domain", "Subsection",
  CellTags->{"S1.2.5", "5.1"}],

Cell[TextData[{
  "All the above relations can be expressed in the frequency domain or \
Fourier space. We define the Fourier transform of the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " by "
}], "Text",
  CellTags->{"S1.2.5", "5.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Phi]\&^\), \((\[Omega])\), "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), 
        \(e\^\(-i  \[Omega]  t\)\), 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.3"}],

Cell[TextData[{
  "Multiplying both sides of the dilation equation by ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-i  \[Omega]  t\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " and integrating, we have"
}], "Text",
  CellTags->{"S1.2.5", "5.4"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(\(\[Phi]\&^\) \((\[Omega])\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                \(\[Phi] \((t)\)\), \(e\^\(-i \[Omega] t\)\), 
                StyleBox[\("dt"\),
                  "TI"], "=", 
                UnderscriptBox["\[Sum]", "k",
                  LimitsPositioning->True], \(\@2\), \(h\_k\), 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                \(\[Phi] \((2 t - k)\)\), \(e\^\(-i \[Omega] t\)\), 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    UnderscriptBox["\[Sum]", "k",
                      LimitsPositioning->True], \(h\_k\/\@2\), 
                    \(e\^\(-i k \[Omega]/2\)\)}], ")"}], 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                \(\[Phi] \((2 t - k)\)\), 
                \(e\^\(-i \((2 t - k)\) \[Omega]/2\)\), 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], 
                  RowBox[{"(", 
                    StyleBox[\("2t"\),
                      "TI"], ")"}]}], "=", 
                RowBox[{"(", 
                  RowBox[{
                    UnderscriptBox["\[Sum]", "k",
                      LimitsPositioning->True], \(h\_k\/\@2\), 
                    \(e\^\(-i k \[Omega]/2\)\)}], ")"}], \(\[Phi]\&^\), \((
                \[Omega]\/2)\), "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.5"}],

Cell["Defining ", "Text",
  CellTags->{"S1.2.5", "5.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{"H", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\/\@2\), \(e\^\(-i  k  \[Omega]\)\),
         ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.7"}],

Cell["the dilation equation in Fourier space assumes the form ", "Text",
  CellTags->{"S1.2.5", "5.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.9"}],

Cell[TextData[{
  "Similarly, let the Fourier transform of the mother wavelet be ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Psi]\&^\), \((\[Omega])\), "=", 
          \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Psi]", \((t)\), 
          \(e\^\(-i  \[Omega]  t\)\), " ", 
          StyleBox[\("dt"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.5"],
  " and "
}], "Text",
  CellTags->{"S1.2.5", "5.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{"G", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\/\@2\), \(e\^\(-i  k  \[Omega]\)\),
         ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.11"}],

Cell["the wavelet equation in Fourier space is", "Text",
  CellTags->{"S1.2.5", "5.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Psi]\&^\) \((\[Omega])\) = G \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.13"}],

Cell["Orthogonality Conditions in the Frequency Domain", "Subsubsection",
  CellTags->{"S1.2.5", "5.14"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " is orthonormal to its translates ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ", we have "
}], "Text",
  CellTags->{"S1.2.5", "5.15"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
              \(\[Delta]\_\(k, 0\)\), "=", 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((
                t)\), \(\(\[Phi] \((t - k)\)\)\&_\), 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Phi]\&^\),
                 \((\[Omega])\), \(\(\(\[Phi]\&^\) \((\[Omega])\)\)\&_\), 
                \(e\^\(i \[Omega] k\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{\(1\/\(2 \[Pi]\)\), \(\[Integral]\_0\%\(2 \[Pi]\)\), 
                
                UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                  "\[Infinity]",
                  LimitsPositioning->True], 
                \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2 \[Pi] l)
                        \)\[RightBracketingBar]\^2\), \(e\^\(i \[Omega] k\)\),
                 " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.16"}],

Cell[TextData[{
  "But the last expression is exactly the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`a\_k\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " in the Fourier series expansion of the ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "\[Hyphen]periodic function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", \((\[Omega])\), "\[Congruent]", 
          UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
            LimitsPositioning->True], 
          \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                  \)\[RightBracketingBar]\^2\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  ". In other words, "
}], "Text",
  CellTags->{"S1.2.5", "5.17"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                \)\[RightBracketingBar]\^2\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(a\_k\), \(e\^\(-i  k  \[Omega]\)\), "=",
         "1."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.18"}],

Cell[TextData[{
  "So the orthonormality of ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " can be expressed in the frequency domain as"
}], "Text",
  CellTags->{"S1.2.5", "5.19"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                \)\[RightBracketingBar]\^2\), "=", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.20"}],

Cell[TextData[{
  "If a set of basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are not orthonormal, we can orthogonalize them easily in Fourier space. \
All we need to do is to divide ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " by the square root of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
            LimitsPositioning->True], 
          \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                  \)\[RightBracketingBar]\^2\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  ", "
}], "Text",
  CellTags->{"S1.2.5", "5.21"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubscriptBox[\(\[Phi]\&^\), 
          StyleBox[\("orth"\),
            "TI"]], \((\[Omega])\), "=", 
        FractionBox[\(\(\[Phi]\&^\) \((\[Omega])\)\), 
          SqrtBox[
            RowBox[{
              
              UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                "\[Infinity]",
                LimitsPositioning->True], 
              \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                      \)\[RightBracketingBar]\^2\)}]]]}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.10) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.22"}],

Cell["and ", "Text",
  CellTags->{"S1.2.5", "5.23"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        SuperscriptBox[
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              SubscriptBox[\(\[Phi]\&^\), 
                StyleBox[\("orth"\),
                  "TI"]], \((\[Omega] + 2  \[Pi]  k)\)}], 
            "\[RightBracketingBar]"}], "2"], "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], 
        SuperscriptBox[
          RowBox[{"\[LeftBracketingBar]", 
            FractionBox[\(\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  k)\)\), 
              SqrtBox[
                RowBox[{
                  
                  UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                    "\[Infinity]",
                    LimitsPositioning->True], "\[VerticalSeparator]", 
                  \(\[Phi]\&^\), \((\[Omega] + 2  \[Pi]  l)\), 
                  \( \[VerticalSeparator] \^2\)}]]], 
            "\[RightBracketingBar]"}], "2"], "=", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.24"}],

Cell[TextData[{
  "Now, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[\(\[Phi]\&^\), 
            StyleBox[\("orth"\),
              "TI"]], \((\[Omega])\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.5"],
  " satisfies the orthonormality condition (",
  ButtonBox["2.9",
    ButtonData:>{"Wavelets 1.2.5", "5.20"},
    ButtonStyle->"AddOnsLink"],
  "), so ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SubscriptBox["\[Phi]", 
              StyleBox[\("orth"\),
                "TI"]], \((t - k)\)}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  " are orthonormal. \nUsing the dilation equation (",
  ButtonBox["2.7",
    ButtonData:>{"Wavelets 1.2.5", "5.9"},
    ButtonStyle->"AddOnsLink"],
  "), we can also rewrite the orthonormality condition (",
  ButtonBox["2.9",
    ButtonData:>{"Wavelets 1.2.5", "5.20"},
    ButtonStyle->"AddOnsLink"],
  ") as a condition on ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ":"
}], "Text",
  CellTags->{"S1.2.5", "5.25"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                
                UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                  "\[Infinity]",
                  LimitsPositioning->True], 
                \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2 \[Pi] l)
                        \)\[RightBracketingBar]\^2\)}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                
                UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                  "\[Infinity]",
                  LimitsPositioning->True], 
                \(\[LeftBracketingBar]H \((\(\[Omega] + 2 \[Pi] l\)\/2)
                        \)\[RightBracketingBar]\^2\), 
                \(\[LeftBracketingBar]\(\[Phi]\&^\) \((
                        \(\[Omega] + 2 \[Pi] l\)\/2)\)\[RightBracketingBar]\^2
                    \)}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                
                UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                  "\[Infinity]",
                  LimitsPositioning->True], 
                \(\[LeftBracketingBar]H \((\[Omega]\^\[Prime] + \[Pi] l)
                        \)\[RightBracketingBar]\^2\), 
                \(\[LeftBracketingBar]\(\[Phi]\&^\) \((
                        \[Omega]\^\[Prime] + \[Pi] l)
                        \)\[RightBracketingBar]\^2\), "=", "1."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.26"}],

Cell[TextData[{
  "Since the above equation is true for all ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^\[Prime] = \[Omega]/2\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ", we can simply replace it by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". Separating the sum into even (",
  Cell[BoxData[
      \(TraditionalForm\`l = 2  k\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ") and odd (",
  Cell[BoxData[
      \(TraditionalForm\`l = 2  k + 1\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ") terms, we have "
}], "Text",
  CellTags->{"S1.2.5", "5.27"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]H \((\[Omega] + 2  k  \[Pi])
                \)\[RightBracketingBar]\^2\), 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  k  \[Pi])
                \)\[RightBracketingBar]\^2\), "+", 
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]H \((\[Omega] + \((2  k + 1)\) \[Pi])
                \)\[RightBracketingBar]\^2\), 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((
                \[Omega] + \((2  k + 1)\) \[Pi])\)\[RightBracketingBar]\^2\), 
        "=", "1."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.28"}],

Cell[TextData[{
  "Again, using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "\[Hyphen]periodic, the above equation reduces to "
}], "Text",
  CellTags->{"S1.2.5", "5.29"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[LeftBracketingBar]H \((\[Omega])\)\[RightBracketingBar]\^2\), 
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  k  \[Pi])
                \)\[RightBracketingBar]\^2\), "+", 
        \(\[LeftBracketingBar]H \((\[Omega] + \[Pi])\)\[RightBracketingBar]\^2
            \), 
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\[Phi]\&^\) \((
                \((\[Omega] + \[Pi])\) + 2  k  \[Pi])
                \)\[RightBracketingBar]\^2\), "=", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.30"}],

Cell["This gives ", "Text",
  CellTags->{"S1.2.5", "5.31"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftBracketingBar]H \((\[Omega])\)\[RightBracketingBar]\^2 + 
      \[LeftBracketingBar]H \((\[Omega] + \[Pi])\)\[RightBracketingBar]\^2 = 
      1, \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.11) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.32"}],

Cell[TextData[{
  "the condition on ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " to be orthogonal. \nThe orthogonality conditions for the wavelets in the \
frequency domain can be derived in a completely parallel fashion. For \
example, for ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " to be orthonormal, we must have"
}], "Text",
  CellTags->{"S1.2.5", "5.33"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\[Psi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                \)\[RightBracketingBar]\^2\), "=", "1", ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.34"}],

Cell["or ", "Text",
  CellTags->{"S1.2.5", "5.35"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftBracketingBar]G \((\[Omega])\)\[RightBracketingBar]\^2 + 
      \[LeftBracketingBar]G \((\[Omega] + \[Pi])\)\[RightBracketingBar]\^2 = 
      1.\)], "DisplayFormula",
  CellTags->{"S1.2.5", "5.36"}],

Cell[TextData[{
  "We can also derive the condition in frequency space that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are orthogonal, "
}], "Text",
  CellTags->{"S1.2.5", "5.37"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
              "0", "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                "\[Phi]", \((t)\), \(\(\[Psi] \((t - k)\)\)\&_\), " ", 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Phi]\&^\),
                 \((\[Omega])\), \(\(\(\[Psi]\&^\) \((\[Omega])\)\)\&_\), 
                \(e\^\(i \[Omega] k\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{\(1\/\(2 \[Pi]\)\), \(\[Integral]\_0\%\(2 \[Pi]\)\), 
                
                UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), 
                  "\[Infinity]",
                  LimitsPositioning->True], \(\[Phi]\&^\), \((
                \[Omega] + 2 \[Pi] l)\), 
                \(\(\(\[Psi]\&^\) \((\[Omega] + 2 \[Pi] l)\)\)\&_\), 
                \(e\^\(i \[Omega] k\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.2.5", "5.38"}],

Cell[TextData[{
  "Since the Fourier coefficients of the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
            LimitsPositioning->True], \(\[Phi]\&^\), \((
          \[Omega] + 2  \[Pi]  l)\), 
          \(\(\(\[Psi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.2.5"],
  " are identically zero, we conclude, "
}], "Text",
  CellTags->{"S1.2.5", "5.39"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(\[Phi]\&^\), \((\[Omega] + 2  \[Pi]  l)
        \), \(\(\(\[Psi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\), "=", 
        "0."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.40"}],

Cell[TextData[{
  "Similarly, using the dilation equation (",
  ButtonBox["2.7",
    ButtonData:>{"Wavelets 1.2.5", "5.9"},
    ButtonStyle->"AddOnsLink"],
  ") and the wavelet equation (",
  ButtonBox["2.8",
    ButtonData:>{"Wavelets 1.2.5", "5.13"},
    ButtonStyle->"AddOnsLink"],
  ") to rewrite the above equation, we have "
}], "Text",
  CellTags->{"S1.2.5", "5.41"}],

Cell[BoxData[
    \(TraditionalForm
    \`H \((\[Omega])\) \(G \((\[Omega])\)\)\&_ + H \((\[Omega] + \[Pi])\) 
      \(G \((\[Omega] + \[Pi])\)\)\&_ = 0.\)], "DisplayFormula",
  CellTags->{"S1.2.5", "5.42"}],

Cell[TextData[{
  "This is the condition that has to be satisfied if ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are orthogonal. This equation relates the coefficients appearing in the \
wavelet equation ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " to those appearing in the dilation equation ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". To find the explicit relationship between the two sets of coefficients \
we need to solve the equation. It is obvious that the above equation is \
satisfied if ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " is chosen to be "
}], "Text",
  CellTags->{"S1.2.5", "5.43"}],

Cell[BoxData[
    \(TraditionalForm
    \`G \((\[Omega])\) = \[Lambda] \((\[Omega])\) 
      \(H \((\[Omega] + \[Pi])\)\)\&_, \)], "DisplayFormula",
  CellTags->{"S1.2.5", "5.44"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Lambda] \((\[Omega])\) = -\[Lambda] \((\[Omega] + \[Pi])\)\)], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  " is a ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "\[Hyphen]periodic function and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\[Lambda] \((\[Omega])\)\[RightBracketingBar]\^2
           = 1\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". The orthogonality conditions do not specify ",
  Cell[BoxData[
      \(TraditionalForm\`G\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " or the wavelet uniquely, we have the freedom of choosing the ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "\[Hyphen]periodic function of unit modulus ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". Here we will follow the usual convention of choosing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] \((\[Omega])\) = -e\^\(-i  \[Omega]\)\)], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  " and stick to it, but it should be borne in mind that other valid choices \
are possible. \nThus, finally we have determined the relationship between the \
coefficients in the dilation equation and those in the wavelet equation. They \
are related through "
}], "Text",
  CellTags->{"S1.2.5", "5.45"}],

Cell[BoxData[
    \(TraditionalForm
    \`G \((\[Omega])\) = -\(e\^\(-i  \[Omega]\)\) 
      \(H \((\[Omega] + \[Pi])\)\)\&_.\)], "DisplayFormula",
  CellTags->{"S1.2.5", "5.46"}],

Cell[TextData[{
  "Or, writing out ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " explicitly, "
}], "Text",
  CellTags->{"S1.2.5", "5.47"}],

Cell[BoxData[
    FormBox[
      RowBox[{"G", \((\[Omega])\), "=", "-", \(e\^\(-i  \[Omega]\)\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\/\@2\), 
        \(e\^\(i \((\[Omega] + \[Pi])\) k\)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\/\@2\), 
        \(\((\(-1\))\)\^\(1 - k\)\), \(e\^\(-i  \[Omega] \((1 - k)\)\)\), "=",
         
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], 
        \(\(\(\((\(-1\))\)\^n\) h\_\(1 - n\)\)\/\@2\), 
        \(e\^\(-i  \[Omega]  n\)\), "."}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.2.5", "5.48"}],

Cell["We immediately identify ", "Text",
  CellTags->{"S1.2.5", "5.49"}],

Cell[BoxData[
    \(TraditionalForm\`g\_n = \(\((\(-1\))\)\^n\) h\_\(1 - n\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.12) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.2.5", "5.50"}],

Cell[TextData[{
  "So we see that once the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " is known, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are obtained by calculating the inner products of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(1  k\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". In turn, the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_n}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are known from (",
  ButtonBox["2.12",
    ButtonData:>{"Wavelets 1.2.5", "5.50"},
    ButtonStyle->"AddOnsLink"],
  ") and, using the wavelet equation, we get the wavelet. On the other hand, \
if we know the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ", we can find the scaling function by solving the dilation equation. We \
will talk more about how to solve the dilation equation in Section ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Text",
  CellTags->{"S1.2.5", "5.51"}],

Cell["An Example", "Subsubsection",
  CellTags->{"S1.2.5", "5.52"}],

Cell[TextData[{
  "We have seen that the box function is the scaling function associated with \
the Haar multiresolution analysis. Here we look at the associated wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". "
}], "Text",
  CellTags->{"S1.2.5", "5.53"}],

Cell[TextData[{
  "The graph of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " is just that of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " squeezed into half the width."
}], "MathCaption",
  CellTags->{"S1.2.5", "5.54"}],

Cell[CellGroupData[{

Cell["\<\
Plot[boxf[2t], {t, -1, 2}, PlotRange -> {0, 2},
AxesLabel -> {\"t\", \"phi(2t)\"},
Ticks -> {Automatic, {1, 2}}];\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -12 -9 ]
[.18254 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.32877 .30902 -6 -4.5 ]
[.32877 .30902 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -21 0 ]
[.34127 .64303 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-0.5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(1.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] 1.025 0 -1 0 Mshowa
.34127 .30902 m
.34752 .30902 L
s
[(1)] .32877 .30902 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(2)] .32877 .61803 1 0 Mshowa
.34127 0 m
.34127 .61803 L
s
[(phi\\(2t\\))] .34127 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.28158 0 L
.30316 0 L
.31323 0 L
.32392 0 L
.33304 0 L
.33554 0 L
.33823 0 L
.33953 0 L
.34076 0 L
.34187 .30902 L
.34309 .30902 L
.38373 .30902 L
.42286 .30902 L
.44283 .30902 L
.46444 .30902 L
.47459 .30902 L
.48531 .30902 L
.49446 .30902 L
.49697 .30902 L
.49835 .30902 L
.49966 .30902 L
.50087 0 L
.5022 0 L
.50451 0 L
.54529 0 L
.58456 0 L
.62231 0 L
.66251 0 L
.7012 0 L
.74234 0 L
.78196 0 L
.82007 0 L
.86063 0 L
.89968 0 L
.94117 0 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],

Cell[TextData[{
  "The graph of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Phi] \((2  t - 1)\) = \[Phi] \((2 \((t - 1/2)\))\)\)], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  " is the graph of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " translated to the right by an amount ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "."
}], "MathCaption",
  CellTags->{"S1.2.5", "5.55"}],

Cell[CellGroupData[{

Cell["\<\
Plot[boxf[2t-1], {t, -1, 2}, PlotRange -> {0, 2},
AxesLabel -> {\"t\", \"phi(2t-1)\"},
Ticks -> {Automatic, {1, 2}}];\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0 0.309017 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.18254 -0.0125 -12 -9 ]
[.18254 -0.0125 12 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.32877 .30902 -6 -4.5 ]
[.32877 .30902 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -27 0 ]
[.34127 .64303 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-1)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(-0.5)] .18254 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(1)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(1.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] 1.025 0 -1 0 Mshowa
.34127 .30902 m
.34752 .30902 L
s
[(1)] .32877 .30902 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(2)] .32877 .61803 1 0 Mshowa
.34127 0 m
.34127 .61803 L
s
[(phi\\(2t-1\\))] .34127 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 0 L
.10458 0 L
.14415 0 L
.18221 0 L
.22272 0 L
.26171 0 L
.30316 0 L
.34309 0 L
.3815 0 L
.42237 0 L
.46172 0 L
.48147 0 L
.49012 0 L
.49468 0 L
.49719 0 L
.49842 0 L
.49955 0 L
.50085 .30902 L
.50154 .30902 L
.50226 .30902 L
.50471 .30902 L
.5095 .30902 L
.51896 .30902 L
.53984 .30902 L
.57781 .30902 L
.61824 .30902 L
.63687 .30902 L
.6467 .30902 L
.65209 .30902 L
.65473 .30902 L
.65714 .30902 L
.65837 .30902 L
.65967 0 L
.66097 0 L
.66239 0 L
.66818 0 L
.67838 0 L
.6985 0 L
.73907 0 L
.77811 0 L
.81961 0 L
.85959 0 L
.89806 0 L
.93898 0 L
.97619 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],

Cell[TextData[{
  "It is obvious that we have ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Phi] \((t)\) = \[Phi] \((2  t)\) + \[Phi] \((2  t - 1)\)\)], 
    "InlineFormula",
    CellTags->"S1.2.5"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`h\_0 = h\_1 = 1/\@2\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". But in general the coefficients cannot be determined simply by looking \
at the graphs of the scaling functions, and we need to calculate the inner \
product (",
  ButtonBox["2.4",
    ButtonData:>{"Wavelets 1.2.3", "3.5"},
    ButtonStyle->"AddOnsLink"],
  "). So let us calculate the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`h\_k\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " according to its definition. "
}], "Text",
  CellTags->{"S1.2.5", "5.56"}],

Cell[TextData[{
  "Here we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`h\_0\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " by calculating the inner product. Other coefficients can be calculated \
similarly."
}], "MathCaption",
  CellTags->{"S1.2.5", "5.57"}],

Cell[CellGroupData[{

Cell["Sqrt[2.] NIntegrate[boxf[t] boxf[2t], {t, 0, 1}]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.2.5"],

Cell[BoxData[
    \(0.707106781186547461`\)], "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S1.2.5"]
}, Open  ]],

Cell[TextData[{
  "From (",
  ButtonBox["2.12",
    ButtonData:>{"Wavelets 1.2.5", "5.50"},
    ButtonStyle->"AddOnsLink"],
  "), the only nonzero ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " coefficients are ",
  Cell[BoxData[
      \(TraditionalForm\`g\_0 = -g\_1 = 1/\@2\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ". Therefore, we have for the Haar wavelet, "
}], "Text",
  CellTags->{"S1.2.5", "5.58"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), \(\[Phi]\_\(1  k\)\), \((t)\), 
        "=", "\[Phi]", \((2  t)\), "-", "\[Phi]", \((2  t - 1)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.2.5", "5.59"}],

Cell["This defines the Haar wavelet.", "MathCaption",
  CellTags->{"S1.2.5", "5.60"}],

Cell["haarPsi[t_]:=boxf[2t]-boxf[2t-1]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.2.5"],

Cell["The Haar wavelet is plotted here.", "MathCaption",
  CellTags->{"S1.2.5", "5.61"}],

Cell[CellGroupData[{

Cell["\<\
Plot[haarPsi[t],{t, -1, 2},
AxesLabel -> {\"t\", \"psi(t)\"}]\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -12 -9 ]
[.18254 .29652 12 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -9 -9 ]
[.81746 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.32877 .01472 -12 -4.5 ]
[.32877 .01472 0 4.5 ]
[.32877 .16187 -24 -4.5 ]
[.32877 .16187 0 4.5 ]
[.32877 .45617 -18 -4.5 ]
[.32877 .45617 0 4.5 ]
[.32877 .60332 -6 -4.5 ]
[.32877 .60332 0 4.5 ]
[.34127 .64303 -18 0 ]
[.34127 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-0.5)] .18254 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(0.5)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(1.5)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(t)] 1.025 .30902 -1 0 Mshowa
.34127 .01472 m
.34752 .01472 L
s
[(-1)] .32877 .01472 1 0 Mshowa
.34127 .16187 m
.34752 .16187 L
s
[(-0.5)] .32877 .16187 1 0 Mshowa
.34127 .45617 m
.34752 .45617 L
s
[(0.5)] .32877 .45617 1 0 Mshowa
.34127 .60332 m
.34752 .60332 L
s
[(1)] .32877 .60332 1 0 Mshowa
.125 Mabswid
.34127 .04415 m
.34502 .04415 L
s
.34127 .07358 m
.34502 .07358 L
s
.34127 .10301 m
.34502 .10301 L
s
.34127 .13244 m
.34502 .13244 L
s
.34127 .1913 m
.34502 .1913 L
s
.34127 .22073 m
.34502 .22073 L
s
.34127 .25016 m
.34502 .25016 L
s
.34127 .27959 m
.34502 .27959 L
s
.34127 .33845 m
.34502 .33845 L
s
.34127 .36788 m
.34502 .36788 L
s
.34127 .39731 m
.34502 .39731 L
s
.34127 .42674 m
.34502 .42674 L
s
.34127 .4856 m
.34502 .4856 L
s
.34127 .51503 m
.34502 .51503 L
s
.34127 .54446 m
.34502 .54446 L
s
.34127 .57389 m
.34502 .57389 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi\\(t\\))] .34127 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33823 .30902 L
.33953 .30902 L
.34076 .30902 L
.34187 .60332 L
.34309 .60332 L
.38373 .60332 L
.42286 .60332 L
.44283 .60332 L
.46444 .60332 L
.47459 .60332 L
.48531 .60332 L
.49446 .60332 L
.49697 .60332 L
.49835 .60332 L
.49966 .60332 L
.50087 .01472 L
.5022 .01472 L
.50451 .01472 L
.54529 .01472 L
.58456 .01472 L
.62231 .01472 L
.64165 .01472 L
.64696 .01472 L
.65254 .01472 L
.65484 .01472 L
.6573 .01472 L
.65803 .01472 L
.65871 .01472 L
.66 .30902 L
.6612 .30902 L
.66251 .30902 L
.70343 .30902 L
.74283 .30902 L
.78072 .30902 L
.82106 .30902 L
.85988 .30902 L
.90116 .30902 L
Mistroke
.94092 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],

Cell[TextData[{
  "The fact that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((\(2\^j\) t - k)\)}\)], "InlineFormula",
    CellTags->"S1.2.5"],
  " are orthogonal can be easily seen from the graphs of the functions. Here \
we plot the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t - 1)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t/2)\)\)], "InlineFormula",
    CellTags->"S1.2.5"],
  "."
}], "MathCaption",
  CellTags->{"S1.2.5", "5.62"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{haarPsi[2t], haarPsi[t-1], haarPsi[t/2]},
{t, 0, 3}, PlotStyle ->
{Dashing[{0.02}], GrayLevel[0.5], {}},
PlotLabel -> \"psi(2t), psi(t-1), psi(t/2)\",
AxesLabel -> {\"t\", \"\"}]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.309017 0.294302 [
[.18254 .29652 -9 -9 ]
[.18254 .29652 9 0 ]
[.34127 .29652 -3 -9 ]
[.34127 .29652 3 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -9 -9 ]
[.81746 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -81 0 ]
[.5 .63053 81 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .30902 m
.18254 .31527 L
s
[(0.5)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(1)] .34127 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(1.5)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(2)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2.5)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(t)] 1.025 .30902 -1 0 Mshowa
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(psi\\(2t\\), psi\\(t-1\\), psi\\(t/2\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 ] 0 setdash
.02381 .60332 m
.04262 .60332 L
.06244 .60332 L
.08255 .60332 L
.08806 .60332 L
.09396 .60332 L
.09682 .60332 L
.09952 .60332 L
.1007 .60332 L
.10195 .60332 L
.1026 .60332 L
.10332 .01472 L
.10458 .01472 L
.12562 .01472 L
.14487 .01472 L
.15437 .01472 L
.16474 .01472 L
.16949 .01472 L
.17454 .01472 L
.177 .01472 L
.17931 .01472 L
.18032 .01472 L
.18139 .01472 L
.18256 .30902 L
.18364 .30902 L
.22161 .30902 L
.26204 .30902 L
.30094 .30902 L
.3423 .30902 L
.38215 .30902 L
.42048 .30902 L
.46126 .30902 L
.50053 .30902 L
.53828 .30902 L
.57848 .30902 L
.61717 .30902 L
.65831 .30902 L
.69793 .30902 L
.73604 .30902 L
.7766 .30902 L
.81565 .30902 L
.85715 .30902 L
.89713 .30902 L
.93559 .30902 L
.97619 .30902 L
s
.5 g
[ ] 0 setdash
.02381 .30902 m
.06244 .30902 L
.10458 .30902 L
.14415 .30902 L
.18221 .30902 L
.22272 .30902 L
.26171 .30902 L
.28158 .30902 L
.30316 .30902 L
.31323 .30902 L
.32392 .30902 L
.33304 .30902 L
.33554 .30902 L
.33823 .30902 L
.33953 .30902 L
.34076 .30902 L
.34187 .60332 L
.34309 .60332 L
.38373 .60332 L
.42286 .60332 L
.44284 .60332 L
.46444 .60332 L
.47459 .60332 L
.48531 .60332 L
.49446 .60332 L
.49697 .60332 L
.49835 .60332 L
.49966 .60332 L
.50087 .01472 L
.5022 .01472 L
.50451 .01472 L
.54529 .01472 L
.58456 .01472 L
.62231 .01472 L
.64165 .01472 L
.64696 .01472 L
.65254 .01472 L
.65484 .01472 L
.6573 .01472 L
.65803 .01472 L
.65871 .01472 L
.66 .30902 L
.6612 .30902 L
.66251 .30902 L
.70343 .30902 L
.74283 .30902 L
.78072 .30902 L
.82106 .30902 L
.85988 .30902 L
.90116 .30902 L
Mistroke
.94092 .30902 L
.97619 .30902 L
Mfstroke
0 g
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.28158 .60332 L
.30316 .60332 L
.31323 .60332 L
.32392 .60332 L
.33304 .60332 L
.33554 .60332 L
.33823 .60332 L
.33953 .60332 L
.34076 .60332 L
.34187 .01472 L
.34309 .01472 L
.38373 .01472 L
.42286 .01472 L
.46444 .01472 L
.50451 .01472 L
.54306 .01472 L
.58406 .01472 L
.60448 .01472 L
.62355 .01472 L
.64188 .01472 L
.64715 .01472 L
.65215 .01472 L
.65433 .01472 L
.65664 .01472 L
.65785 .01472 L
.65853 .01472 L
.65918 .30902 L
.66031 .30902 L
.66152 .30902 L
.70266 .30902 L
.74229 .30902 L
.78039 .30902 L
.82096 .30902 L
.86 .30902 L
.9015 .30902 L
.94148 .30902 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{83, Automatic}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 71, 1, 58, "Section",
      CellTags->"Contents"],
    Cell[1783, 52, 881, 27, 129, "Contents",
      CellTags->"Contents"]},
  "S1.2.0"->{
    Cell[2667, 81, 78, 1, 58, "Section",
      CellTags->{"S1.2.0", "0.1"}],
    Cell[2748, 84, 3330, 73, 360, "Text",
      CellTags->{"S1.2.0", "0.2"}],
    Cell[6081, 159, 284, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.0", "0.3"}],
    Cell[6368, 167, 1561, 47, 70, "Text",
      CellTags->{"S1.2.0", "0.4"}]},
  "0.1"->{
    Cell[2667, 81, 78, 1, 58, "Section",
      CellTags->{"S1.2.0", "0.1"}]},
  "0.2"->{
    Cell[2748, 84, 3330, 73, 360, "Text",
      CellTags->{"S1.2.0", "0.2"}]},
  "0.3"->{
    Cell[6081, 159, 284, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.0", "0.3"}]},
  "0.4"->{
    Cell[6368, 167, 1561, 47, 70, "Text",
      CellTags->{"S1.2.0", "0.4"}]},
  "S1.2.1"->{
    Cell[7932, 216, 99, 1, 70, "Subsection",
      CellTags->{"S1.2.1", "1.1"}],
    Cell[8034, 219, 3083, 88, 70, "Text",
      CellTags->{"S1.2.1", "1.2"}],
    Cell[11120, 309, 161, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.3"}],
    Cell[11284, 315, 101, 1, 70, "Text",
      CellTags->{"S1.2.1", "1.4"}],
    Cell[11388, 318, 131, 3, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.5"}],
    Cell[11522, 323, 1277, 40, 70, "Text",
      CellTags->{"S1.2.1", "1.6"}],
    Cell[12802, 365, 487, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.7"}],
    Cell[13292, 377, 9264, 261, 70, "Text",
      CellTags->{"S1.2.1", "1.8"}]},
  "1.1"->{
    Cell[7932, 216, 99, 1, 70, "Subsection",
      CellTags->{"S1.2.1", "1.1"}]},
  "1.2"->{
    Cell[8034, 219, 3083, 88, 70, "Text",
      CellTags->{"S1.2.1", "1.2"}]},
  "1.3"->{
    Cell[11120, 309, 161, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.3"}]},
  "1.4"->{
    Cell[11284, 315, 101, 1, 70, "Text",
      CellTags->{"S1.2.1", "1.4"}]},
  "1.5"->{
    Cell[11388, 318, 131, 3, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.5"}]},
  "1.6"->{
    Cell[11522, 323, 1277, 40, 70, "Text",
      CellTags->{"S1.2.1", "1.6"}]},
  "1.7"->{
    Cell[12802, 365, 487, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.1", "1.7"}]},
  "1.8"->{
    Cell[13292, 377, 9264, 261, 70, "Text",
      CellTags->{"S1.2.1", "1.8"}]},
  "S1.2.2"->{
    Cell[22559, 640, 95, 1, 70, "Subsection",
      CellTags->{"S1.2.2", "2.1"}],
    Cell[22657, 643, 142, 4, 70, "Text",
      CellTags->{"S1.2.2", "2.2"}],
    Cell[22802, 649, 85, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.3"}],
    Cell[22890, 652, 3467, 98, 70, "Text",
      CellTags->{"S1.2.2", "2.4"}],
    Cell[26360, 752, 677, 20, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.5"}],
    Cell[27040, 774, 225, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.6"}],
    Cell[27268, 783, 104, 2, 70, "Input",
      CellTags->"S1.2.2"],
    Cell[27375, 787, 227, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.7"}],
    Cell[27627, 798, 182, 6, 70, "Input",
      CellTags->"S1.2.2"],
    Cell[27812, 806, 2509, 184, 70, 2436, 181, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.2"],
    Cell[30336, 993, 205, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.8"}],
    Cell[30566, 1004, 187, 6, 70, "Input",
      CellTags->"S1.2.2"],
    Cell[30756, 1012, 2607, 191, 70, 2534, 188, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.2"],
    Cell[33378, 1206, 1427, 38, 70, "Text",
      CellTags->{"S1.2.2", "2.9"}],
    Cell[34808, 1246, 83, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.10"}],
    Cell[34894, 1249, 1809, 55, 70, "Text",
      CellTags->{"S1.2.2", "2.11"}],
    Cell[36706, 1306, 672, 19, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.12"}],
    Cell[37381, 1327, 345, 11, 70, "Text",
      CellTags->{"S1.2.2", "2.13"}],
    Cell[37729, 1340, 364, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.14"}],
    Cell[38096, 1350, 2329, 69, 70, "Text",
      CellTags->{"S1.2.2", "2.15"}],
    Cell[40428, 1421, 85, 1, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.16"}],
    Cell[40516, 1424, 111, 2, 70, "Input",
      CellTags->"S1.2.2"],
    Cell[40630, 1428, 369, 11, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.17"}],
    Cell[41024, 1443, 236, 6, 70, "Input",
      CellTags->"S1.2.2"],
    Cell[41263, 1451, 4658, 346, 70, 4585, 343, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.2"],
    Cell[45936, 1800, 1324, 34, 70, "Text",
      CellTags->{"S1.2.2", "2.18"}],
    Cell[47263, 1836, 88, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.19"}],
    Cell[47354, 1839, 2526, 74, 70, "Text",
      CellTags->{"S1.2.2", "2.20"}]},
  "2.1"->{
    Cell[22559, 640, 95, 1, 70, "Subsection",
      CellTags->{"S1.2.2", "2.1"}]},
  "2.2"->{
    Cell[22657, 643, 142, 4, 70, "Text",
      CellTags->{"S1.2.2", "2.2"}]},
  "2.3"->{
    Cell[22802, 649, 85, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.3"}]},
  "2.4"->{
    Cell[22890, 652, 3467, 98, 70, "Text",
      CellTags->{"S1.2.2", "2.4"}]},
  "2.5"->{
    Cell[26360, 752, 677, 20, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.5"}]},
  "2.6"->{
    Cell[27040, 774, 225, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.6"}]},
  "2.7"->{
    Cell[27375, 787, 227, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.7"}]},
  "2.8"->{
    Cell[30336, 993, 205, 7, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.8"}]},
  "2.9"->{
    Cell[33378, 1206, 1427, 38, 70, "Text",
      CellTags->{"S1.2.2", "2.9"}]},
  "2.10"->{
    Cell[34808, 1246, 83, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.10"}]},
  "2.11"->{
    Cell[34894, 1249, 1809, 55, 70, "Text",
      CellTags->{"S1.2.2", "2.11"}]},
  "2.12"->{
    Cell[36706, 1306, 672, 19, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.12"}]},
  "2.13"->{
    Cell[37381, 1327, 345, 11, 70, "Text",
      CellTags->{"S1.2.2", "2.13"}]},
  "2.14"->{
    Cell[37729, 1340, 364, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.2", "2.14"}]},
  "2.15"->{
    Cell[38096, 1350, 2329, 69, 70, "Text",
      CellTags->{"S1.2.2", "2.15"}]},
  "2.16"->{
    Cell[40428, 1421, 85, 1, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.16"}]},
  "2.17"->{
    Cell[40630, 1428, 369, 11, 70, "MathCaption",
      CellTags->{"S1.2.2", "2.17"}]},
  "2.18"->{
    Cell[45936, 1800, 1324, 34, 70, "Text",
      CellTags->{"S1.2.2", "2.18"}]},
  "2.19"->{
    Cell[47263, 1836, 88, 1, 70, "Subsubsection",
      CellTags->{"S1.2.2", "2.19"}]},
  "2.20"->{
    Cell[47354, 1839, 2526, 74, 70, "Text",
      CellTags->{"S1.2.2", "2.20"}]},
  "S1.2.3"->{
    Cell[49883, 1915, 134, 4, 70, "Subsection",
      CellTags->{"S1.2.3", "3.1"}],
    Cell[50020, 1921, 1700, 51, 70, "Text",
      CellTags->{"S1.2.3", "3.2"}],
    Cell[51723, 1974, 498, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.3"}],
    Cell[52224, 1987, 994, 29, 70, "Text",
      CellTags->{"S1.2.3", "3.4"}],
    Cell[53221, 2018, 512, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.5"}],
    Cell[53736, 2031, 694, 20, 70, "Text",
      CellTags->{"S1.2.3", "3.6"}],
    Cell[54433, 2053, 221, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.7"}],
    Cell[54657, 2061, 352, 11, 70, "Text",
      CellTags->{"S1.2.3", "3.8"}],
    Cell[55012, 2074, 790, 18, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.9"}],
    Cell[55805, 2094, 488, 15, 70, "Text",
      CellTags->{"S1.2.3", "3.10"}],
    Cell[56296, 2111, 429, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.11"}]},
  "3.1"->{
    Cell[49883, 1915, 134, 4, 70, "Subsection",
      CellTags->{"S1.2.3", "3.1"}]},
  "3.2"->{
    Cell[50020, 1921, 1700, 51, 70, "Text",
      CellTags->{"S1.2.3", "3.2"}]},
  "3.3"->{
    Cell[51723, 1974, 498, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.3"}]},
  "3.4"->{
    Cell[52224, 1987, 994, 29, 70, "Text",
      CellTags->{"S1.2.3", "3.4"}]},
  "3.5"->{
    Cell[53221, 2018, 512, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.5"}]},
  "3.6"->{
    Cell[53736, 2031, 694, 20, 70, "Text",
      CellTags->{"S1.2.3", "3.6"}]},
  "3.7"->{
    Cell[54433, 2053, 221, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.7"}]},
  "3.8"->{
    Cell[54657, 2061, 352, 11, 70, "Text",
      CellTags->{"S1.2.3", "3.8"}]},
  "3.9"->{
    Cell[55012, 2074, 790, 18, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.9"}]},
  "3.10"->{
    Cell[55805, 2094, 488, 15, 70, "Text",
      CellTags->{"S1.2.3", "3.10"}]},
  "3.11"->{
    Cell[56296, 2111, 429, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.3", "3.11"}]},
  "S1.2.4"->{
    Cell[56728, 2123, 125, 4, 70, "Subsection",
      CellTags->{"S1.2.4", "4.1"}],
    Cell[56856, 2129, 375, 12, 70, "Text",
      CellTags->{"S1.2.4", "4.2"}],
    Cell[57234, 2143, 158, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.3"}],
    Cell[57395, 2149, 199, 7, 70, "Text",
      CellTags->{"S1.2.4", "4.4"}],
    Cell[57597, 2158, 178, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.5"}],
    Cell[57778, 2165, 2825, 84, 70, "Text",
      CellTags->{"S1.2.4", "4.6"}],
    Cell[60606, 2251, 498, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.7"}],
    Cell[61107, 2264, 632, 15, 70, "Text",
      CellTags->{"S1.2.4", "4.8"}],
    Cell[61742, 2281, 512, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.9"}],
    Cell[62257, 2294, 4268, 106, 70, "Text",
      CellTags->{"S1.2.4", "4.10"}]},
  "4.1"->{
    Cell[56728, 2123, 125, 4, 70, "Subsection",
      CellTags->{"S1.2.4", "4.1"}]},
  "4.2"->{
    Cell[56856, 2129, 375, 12, 70, "Text",
      CellTags->{"S1.2.4", "4.2"}]},
  "4.3"->{
    Cell[57234, 2143, 158, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.3"}]},
  "4.4"->{
    Cell[57395, 2149, 199, 7, 70, "Text",
      CellTags->{"S1.2.4", "4.4"}]},
  "4.5"->{
    Cell[57597, 2158, 178, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.5"}]},
  "4.6"->{
    Cell[57778, 2165, 2825, 84, 70, "Text",
      CellTags->{"S1.2.4", "4.6"}]},
  "4.7"->{
    Cell[60606, 2251, 498, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.7"}]},
  "4.8"->{
    Cell[61107, 2264, 632, 15, 70, "Text",
      CellTags->{"S1.2.4", "4.8"}]},
  "4.9"->{
    Cell[61742, 2281, 512, 11, 70, "DisplayFormula",
      CellTags->{"S1.2.4", "4.9"}]},
  "4.10"->{
    Cell[62257, 2294, 4268, 106, 70, "Text",
      CellTags->{"S1.2.4", "4.10"}]},
  "S1.2.5"->{
    Cell[66528, 2402, 91, 1, 70, "Subsection",
      CellTags->{"S1.2.5", "5.1"}],
    Cell[66622, 2405, 330, 8, 70, "Text",
      CellTags->{"S1.2.5", "5.2"}],
    Cell[66955, 2415, 316, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.3"}],
    Cell[67274, 2425, 255, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.4"}],
    Cell[67532, 2434, 2007, 51, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.5"}],
    Cell[69542, 2487, 56, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.6"}],
    Cell[69601, 2490, 268, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.7"}],
    Cell[69872, 2498, 103, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.8"}],
    Cell[69978, 2501, 287, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.9"}],
    Cell[70268, 2509, 463, 13, 70, "Text",
      CellTags->{"S1.2.5", "5.10"}],
    Cell[70734, 2524, 269, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.11"}],
    Cell[71006, 2532, 88, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.12"}],
    Cell[71097, 2535, 288, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.13"}],
    Cell[71388, 2543, 105, 1, 70, "Subsubsection",
      CellTags->{"S1.2.5", "5.14"}],
    Cell[71496, 2546, 333, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.15"}],
    Cell[71832, 2559, 1698, 44, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.16"}],
    Cell[73533, 2605, 795, 21, 70, "Text",
      CellTags->{"S1.2.5", "5.17"}],
    Cell[74331, 2628, 478, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.18"}],
    Cell[74812, 2640, 247, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.19"}],
    Cell[75062, 2649, 456, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.20"}],
    Cell[75521, 2661, 817, 22, 70, "Text",
      CellTags->{"S1.2.5", "5.21"}],
    Cell[76341, 2685, 711, 18, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.22"}],
    Cell[77055, 2705, 52, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.23"}],
    Cell[77110, 2708, 1136, 27, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.24"}],
    Cell[78249, 2737, 1139, 37, 70, "Text",
      CellTags->{"S1.2.5", "5.25"}],
    Cell[79391, 2776, 1831, 46, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.26"}],
    Cell[81225, 2824, 630, 19, 70, "Text",
      CellTags->{"S1.2.5", "5.27"}],
    Cell[81858, 2845, 824, 16, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.28"}],
    Cell[82685, 2863, 356, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.29"}],
    Cell[83044, 2876, 788, 16, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.30"}],
    Cell[83835, 2894, 59, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.31"}],
    Cell[83897, 2897, 350, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.32"}],
    Cell[84250, 2906, 607, 17, 70, "Text",
      CellTags->{"S1.2.5", "5.33"}],
    Cell[84860, 2925, 362, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.34"}],
    Cell[85225, 2935, 51, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.35"}],
    Cell[85279, 2938, 246, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.36"}],
    Cell[85528, 2945, 371, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.37"}],
    Cell[85902, 2958, 1665, 43, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.38"}],
    Cell[87570, 3003, 509, 13, 70, "Text",
      CellTags->{"S1.2.5", "5.39"}],
    Cell[88082, 3018, 351, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.40"}],
    Cell[88436, 3027, 374, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.41"}],
    Cell[88813, 3040, 207, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.42"}],
    Cell[89023, 3046, 973, 26, 70, "Text",
      CellTags->{"S1.2.5", "5.43"}],
    Cell[89999, 3074, 180, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.44"}],
    Cell[90182, 3080, 1467, 39, 70, "Text",
      CellTags->{"S1.2.5", "5.45"}],
    Cell[91652, 3121, 179, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.46"}],
    Cell[91834, 3127, 203, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.47"}],
    Cell[92040, 3136, 664, 15, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.48"}],
    Cell[92707, 3153, 72, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.49"}],
    Cell[92782, 3156, 237, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.50"}],
    Cell[93022, 3163, 1287, 37, 70, "Text",
      CellTags->{"S1.2.5", "5.51"}],
    Cell[94312, 3202, 67, 1, 70, "Subsubsection",
      CellTags->{"S1.2.5", "5.52"}],
    Cell[94382, 3205, 325, 8, 70, "Text",
      CellTags->{"S1.2.5", "5.53"}],
    Cell[94710, 3215, 363, 11, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.54"}],
    Cell[95098, 3230, 185, 6, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[95286, 3238, 2945, 219, 70, 2872, 216, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.5"],
    Cell[98246, 3460, 506, 17, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.55"}],
    Cell[98777, 3481, 189, 6, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[98969, 3489, 2993, 222, 70, 2920, 219, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.5"],
    Cell[101977, 3714, 807, 23, 70, "Text",
      CellTags->{"S1.2.5", "5.56"}],
    Cell[102787, 3739, 268, 8, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.57"}],
    Cell[103080, 3751, 112, 2, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[103195, 3755, 102, 3, 70, "Output",
      CellTags->"S1.2.5"],
    Cell[103312, 3761, 462, 15, 70, "Text",
      CellTags->{"S1.2.5", "5.58"}],
    Cell[103777, 3778, 330, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.59"}],
    Cell[104110, 3787, 85, 1, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.60"}],
    Cell[104198, 3790, 96, 2, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[104297, 3794, 88, 1, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.61"}],
    Cell[104410, 3799, 134, 5, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[104547, 3806, 4219, 291, 70, 4146, 288, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.5"],
    Cell[108781, 4100, 648, 20, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.62"}],
    Cell[109454, 4124, 257, 8, 70, "Input",
      CellTags->"S1.2.5"],
    Cell[109714, 4134, 5693, 386, 70, 5620, 383, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.2.5"]},
  "5.1"->{
    Cell[66528, 2402, 91, 1, 70, "Subsection",
      CellTags->{"S1.2.5", "5.1"}]},
  "5.2"->{
    Cell[66622, 2405, 330, 8, 70, "Text",
      CellTags->{"S1.2.5", "5.2"}]},
  "5.3"->{
    Cell[66955, 2415, 316, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.3"}]},
  "5.4"->{
    Cell[67274, 2425, 255, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.4"}]},
  "5.5"->{
    Cell[67532, 2434, 2007, 51, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.5"}]},
  "5.6"->{
    Cell[69542, 2487, 56, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.6"}]},
  "5.7"->{
    Cell[69601, 2490, 268, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.7"}]},
  "5.8"->{
    Cell[69872, 2498, 103, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.8"}]},
  "5.9"->{
    Cell[69978, 2501, 287, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.9"}]},
  "5.10"->{
    Cell[70268, 2509, 463, 13, 70, "Text",
      CellTags->{"S1.2.5", "5.10"}]},
  "5.11"->{
    Cell[70734, 2524, 269, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.11"}]},
  "5.12"->{
    Cell[71006, 2532, 88, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.12"}]},
  "5.13"->{
    Cell[71097, 2535, 288, 6, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.13"}]},
  "5.14"->{
    Cell[71388, 2543, 105, 1, 70, "Subsubsection",
      CellTags->{"S1.2.5", "5.14"}]},
  "5.15"->{
    Cell[71496, 2546, 333, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.15"}]},
  "5.16"->{
    Cell[71832, 2559, 1698, 44, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.16"}]},
  "5.17"->{
    Cell[73533, 2605, 795, 21, 70, "Text",
      CellTags->{"S1.2.5", "5.17"}]},
  "5.18"->{
    Cell[74331, 2628, 478, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.18"}]},
  "5.19"->{
    Cell[74812, 2640, 247, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.19"}]},
  "5.20"->{
    Cell[75062, 2649, 456, 10, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.20"}]},
  "5.21"->{
    Cell[75521, 2661, 817, 22, 70, "Text",
      CellTags->{"S1.2.5", "5.21"}]},
  "5.22"->{
    Cell[76341, 2685, 711, 18, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.22"}]},
  "5.23"->{
    Cell[77055, 2705, 52, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.23"}]},
  "5.24"->{
    Cell[77110, 2708, 1136, 27, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.24"}]},
  "5.25"->{
    Cell[78249, 2737, 1139, 37, 70, "Text",
      CellTags->{"S1.2.5", "5.25"}]},
  "5.26"->{
    Cell[79391, 2776, 1831, 46, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.26"}]},
  "5.27"->{
    Cell[81225, 2824, 630, 19, 70, "Text",
      CellTags->{"S1.2.5", "5.27"}]},
  "5.28"->{
    Cell[81858, 2845, 824, 16, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.28"}]},
  "5.29"->{
    Cell[82685, 2863, 356, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.29"}]},
  "5.30"->{
    Cell[83044, 2876, 788, 16, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.30"}]},
  "5.31"->{
    Cell[83835, 2894, 59, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.31"}]},
  "5.32"->{
    Cell[83897, 2897, 350, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.32"}]},
  "5.33"->{
    Cell[84250, 2906, 607, 17, 70, "Text",
      CellTags->{"S1.2.5", "5.33"}]},
  "5.34"->{
    Cell[84860, 2925, 362, 8, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.34"}]},
  "5.35"->{
    Cell[85225, 2935, 51, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.35"}]},
  "5.36"->{
    Cell[85279, 2938, 246, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.36"}]},
  "5.37"->{
    Cell[85528, 2945, 371, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.37"}]},
  "5.38"->{
    Cell[85902, 2958, 1665, 43, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.38"}]},
  "5.39"->{
    Cell[87570, 3003, 509, 13, 70, "Text",
      CellTags->{"S1.2.5", "5.39"}]},
  "5.40"->{
    Cell[88082, 3018, 351, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.40"}]},
  "5.41"->{
    Cell[88436, 3027, 374, 11, 70, "Text",
      CellTags->{"S1.2.5", "5.41"}]},
  "5.42"->{
    Cell[88813, 3040, 207, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.42"}]},
  "5.43"->{
    Cell[89023, 3046, 973, 26, 70, "Text",
      CellTags->{"S1.2.5", "5.43"}]},
  "5.44"->{
    Cell[89999, 3074, 180, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.44"}]},
  "5.45"->{
    Cell[90182, 3080, 1467, 39, 70, "Text",
      CellTags->{"S1.2.5", "5.45"}]},
  "5.46"->{
    Cell[91652, 3121, 179, 4, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.46"}]},
  "5.47"->{
    Cell[91834, 3127, 203, 7, 70, "Text",
      CellTags->{"S1.2.5", "5.47"}]},
  "5.48"->{
    Cell[92040, 3136, 664, 15, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.48"}]},
  "5.49"->{
    Cell[92707, 3153, 72, 1, 70, "Text",
      CellTags->{"S1.2.5", "5.49"}]},
  "5.50"->{
    Cell[92782, 3156, 237, 5, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.50"}]},
  "5.51"->{
    Cell[93022, 3163, 1287, 37, 70, "Text",
      CellTags->{"S1.2.5", "5.51"}]},
  "5.52"->{
    Cell[94312, 3202, 67, 1, 70, "Subsubsection",
      CellTags->{"S1.2.5", "5.52"}]},
  "5.53"->{
    Cell[94382, 3205, 325, 8, 70, "Text",
      CellTags->{"S1.2.5", "5.53"}]},
  "5.54"->{
    Cell[94710, 3215, 363, 11, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.54"}]},
  "5.55"->{
    Cell[98246, 3460, 506, 17, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.55"}]},
  "5.56"->{
    Cell[101977, 3714, 807, 23, 70, "Text",
      CellTags->{"S1.2.5", "5.56"}]},
  "5.57"->{
    Cell[102787, 3739, 268, 8, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.57"}]},
  "5.58"->{
    Cell[103312, 3761, 462, 15, 70, "Text",
      CellTags->{"S1.2.5", "5.58"}]},
  "5.59"->{
    Cell[103777, 3778, 330, 7, 70, "DisplayFormula",
      CellTags->{"S1.2.5", "5.59"}]},
  "5.60"->{
    Cell[104110, 3787, 85, 1, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.60"}]},
  "5.61"->{
    Cell[104297, 3794, 88, 1, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.61"}]},
  "5.62"->{
    Cell[108781, 4100, 648, 20, 70, "MathCaption",
      CellTags->{"S1.2.5", "5.62"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 116060, 4541},
  {"S1.2.0", 116219, 4546},
  {"0.1", 116550, 4555},
  {"0.2", 116639, 4558},
  {"0.3", 116729, 4561},
  {"0.4", 116827, 4564},
  {"S1.2.1", 116920, 4567},
  {"1.1", 117589, 4584},
  {"1.2", 117682, 4587},
  {"1.3", 117772, 4590},
  {"1.4", 117871, 4593},
  {"1.5", 117960, 4596},
  {"1.6", 118059, 4599},
  {"1.7", 118150, 4602},
  {"1.8", 118250, 4605},
  {"S1.2.2", 118345, 4608},
  {"2.1", 120832, 4671},
  {"2.2", 120926, 4674},
  {"2.3", 121015, 4677},
  {"2.4", 121112, 4680},
  {"2.5", 121203, 4683},
  {"2.6", 121303, 4686},
  {"2.7", 121399, 4689},
  {"2.8", 121495, 4692},
  {"2.9", 121591, 4695},
  {"2.10", 121684, 4698},
  {"2.11", 121784, 4701},
  {"2.12", 121878, 4704},
  {"2.13", 121981, 4707},
  {"2.14", 122074, 4710},
  {"2.15", 122176, 4713},
  {"2.16", 122270, 4716},
  {"2.17", 122368, 4719},
  {"2.18", 122468, 4722},
  {"2.19", 122562, 4725},
  {"2.20", 122662, 4728},
  {"S1.2.3", 122758, 4731},
  {"3.1", 123696, 4754},
  {"3.2", 123792, 4757},
  {"3.3", 123884, 4760},
  {"3.4", 123985, 4763},
  {"3.5", 124076, 4766},
  {"3.6", 124177, 4769},
  {"3.7", 124268, 4772},
  {"3.8", 124368, 4775},
  {"3.9", 124459, 4778},
  {"3.10", 124561, 4781},
  {"3.11", 124654, 4784},
  {"S1.2.4", 124759, 4787},
  {"4.1", 125607, 4808},
  {"4.2", 125703, 4811},
  {"4.3", 125794, 4814},
  {"4.4", 125894, 4817},
  {"4.5", 125984, 4820},
  {"4.6", 126084, 4823},
  {"4.7", 126176, 4826},
  {"4.8", 126277, 4829},
  {"4.9", 126368, 4832},
  {"4.10", 126470, 4835},
  {"S1.2.5", 126567, 4838},
  {"5.1", 132924, 4993},
  {"5.2", 133019, 4996},
  {"5.3", 133109, 4999},
  {"5.4", 133209, 5002},
  {"5.5", 133299, 5005},
  {"5.6", 133401, 5008},
  {"5.7", 133490, 5011},
  {"5.8", 133590, 5014},
  {"5.9", 133680, 5017},
  {"5.10", 133781, 5020},
  {"5.11", 133874, 5023},
  {"5.12", 133976, 5026},
  {"5.13", 134067, 5029},
  {"5.14", 134169, 5032},
  {"5.15", 134270, 5035},
  {"5.16", 134363, 5038},
  {"5.17", 134467, 5041},
  {"5.18", 134560, 5044},
  {"5.19", 134663, 5047},
  {"5.20", 134755, 5050},
  {"5.21", 134858, 5053},
  {"5.22", 134951, 5056},
  {"5.23", 135054, 5059},
  {"5.24", 135145, 5062},
  {"5.25", 135249, 5065},
  {"5.26", 135343, 5068},
  {"5.27", 135447, 5071},
  {"5.28", 135540, 5074},
  {"5.29", 135643, 5077},
  {"5.30", 135736, 5080},
  {"5.31", 135839, 5083},
  {"5.32", 135930, 5086},
  {"5.33", 136032, 5089},
  {"5.34", 136125, 5092},
  {"5.35", 136227, 5095},
  {"5.36", 136318, 5098},
  {"5.37", 136420, 5101},
  {"5.38", 136513, 5104},
  {"5.39", 136617, 5107},
  {"5.40", 136710, 5110},
  {"5.41", 136812, 5113},
  {"5.42", 136905, 5116},
  {"5.43", 137007, 5119},
  {"5.44", 137100, 5122},
  {"5.45", 137202, 5125},
  {"5.46", 137296, 5128},
  {"5.47", 137398, 5131},
  {"5.48", 137490, 5134},
  {"5.49", 137593, 5137},
  {"5.50", 137684, 5140},
  {"5.51", 137786, 5143},
  {"5.52", 137880, 5146},
  {"5.53", 137980, 5149},
  {"5.54", 138072, 5152},
  {"5.55", 138172, 5155},
  {"5.56", 138272, 5158},
  {"5.57", 138366, 5161},
  {"5.58", 138466, 5164},
  {"5.59", 138560, 5167},
  {"5.60", 138663, 5170},
  {"5.61", 138762, 5173},
  {"5.62", 138861, 5176}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 71, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1783, 52, 881, 27, 129, "Contents",
  CellTags->"Contents"],
Cell[2667, 81, 78, 1, 58, "Section",
  CellTags->{"S1.2.0", "0.1"}],
Cell[2748, 84, 3330, 73, 360, "Text",
  CellTags->{"S1.2.0", "0.2"}],
Cell[6081, 159, 284, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.0", "0.3"}],
Cell[6368, 167, 1561, 47, 70, "Text",
  CellTags->{"S1.2.0", "0.4"}],
Cell[7932, 216, 99, 1, 70, "Subsection",
  CellTags->{"S1.2.1", "1.1"}],
Cell[8034, 219, 3083, 88, 70, "Text",
  CellTags->{"S1.2.1", "1.2"}],
Cell[11120, 309, 161, 4, 70, "DisplayFormula",
  CellTags->{"S1.2.1", "1.3"}],
Cell[11284, 315, 101, 1, 70, "Text",
  CellTags->{"S1.2.1", "1.4"}],
Cell[11388, 318, 131, 3, 70, "DisplayFormula",
  CellTags->{"S1.2.1", "1.5"}],
Cell[11522, 323, 1277, 40, 70, "Text",
  CellTags->{"S1.2.1", "1.6"}],
Cell[12802, 365, 487, 10, 70, "DisplayFormula",
  CellTags->{"S1.2.1", "1.7"}],
Cell[13292, 377, 9264, 261, 70, "Text",
  CellTags->{"S1.2.1", "1.8"}],
Cell[22559, 640, 95, 1, 70, "Subsection",
  CellTags->{"S1.2.2", "2.1"}],
Cell[22657, 643, 142, 4, 70, "Text",
  CellTags->{"S1.2.2", "2.2"}],
Cell[22802, 649, 85, 1, 70, "Subsubsection",
  CellTags->{"S1.2.2", "2.3"}],
Cell[22890, 652, 3467, 98, 70, "Text",
  CellTags->{"S1.2.2", "2.4"}],
Cell[26360, 752, 677, 20, 70, "DisplayFormula",
  CellTags->{"S1.2.2", "2.5"}],
Cell[27040, 774, 225, 7, 70, "MathCaption",
  CellTags->{"S1.2.2", "2.6"}],
Cell[27268, 783, 104, 2, 70, "Input",
  CellTags->"S1.2.2"],
Cell[27375, 787, 227, 7, 70, "MathCaption",
  CellTags->{"S1.2.2", "2.7"}],

Cell[CellGroupData[{
Cell[27627, 798, 182, 6, 70, "Input",
  CellTags->"S1.2.2"],
Cell[27812, 806, 2509, 184, 70, 2436, 181, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],
Cell[30336, 993, 205, 7, 70, "MathCaption",
  CellTags->{"S1.2.2", "2.8"}],

Cell[CellGroupData[{
Cell[30566, 1004, 187, 6, 70, "Input",
  CellTags->"S1.2.2"],
Cell[30756, 1012, 2607, 191, 70, 2534, 188, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],
Cell[33378, 1206, 1427, 38, 70, "Text",
  CellTags->{"S1.2.2", "2.9"}],
Cell[34808, 1246, 83, 1, 70, "Subsubsection",
  CellTags->{"S1.2.2", "2.10"}],
Cell[34894, 1249, 1809, 55, 70, "Text",
  CellTags->{"S1.2.2", "2.11"}],
Cell[36706, 1306, 672, 19, 70, "DisplayFormula",
  CellTags->{"S1.2.2", "2.12"}],
Cell[37381, 1327, 345, 11, 70, "Text",
  CellTags->{"S1.2.2", "2.13"}],
Cell[37729, 1340, 364, 8, 70, "DisplayFormula",
  CellTags->{"S1.2.2", "2.14"}],
Cell[38096, 1350, 2329, 69, 70, "Text",
  CellTags->{"S1.2.2", "2.15"}],
Cell[40428, 1421, 85, 1, 70, "MathCaption",
  CellTags->{"S1.2.2", "2.16"}],
Cell[40516, 1424, 111, 2, 70, "Input",
  CellTags->"S1.2.2"],
Cell[40630, 1428, 369, 11, 70, "MathCaption",
  CellTags->{"S1.2.2", "2.17"}],

Cell[CellGroupData[{
Cell[41024, 1443, 236, 6, 70, "Input",
  CellTags->"S1.2.2"],
Cell[41263, 1451, 4658, 346, 70, 4585, 343, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.2"]
}, Open  ]],
Cell[45936, 1800, 1324, 34, 70, "Text",
  CellTags->{"S1.2.2", "2.18"}],
Cell[47263, 1836, 88, 1, 70, "Subsubsection",
  CellTags->{"S1.2.2", "2.19"}],
Cell[47354, 1839, 2526, 74, 70, "Text",
  CellTags->{"S1.2.2", "2.20"}],
Cell[49883, 1915, 134, 4, 70, "Subsection",
  CellTags->{"S1.2.3", "3.1"}],
Cell[50020, 1921, 1700, 51, 70, "Text",
  CellTags->{"S1.2.3", "3.2"}],
Cell[51723, 1974, 498, 11, 70, "DisplayFormula",
  CellTags->{"S1.2.3", "3.3"}],
Cell[52224, 1987, 994, 29, 70, "Text",
  CellTags->{"S1.2.3", "3.4"}],
Cell[53221, 2018, 512, 11, 70, "DisplayFormula",
  CellTags->{"S1.2.3", "3.5"}],
Cell[53736, 2031, 694, 20, 70, "Text",
  CellTags->{"S1.2.3", "3.6"}],
Cell[54433, 2053, 221, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.3", "3.7"}],
Cell[54657, 2061, 352, 11, 70, "Text",
  CellTags->{"S1.2.3", "3.8"}],
Cell[55012, 2074, 790, 18, 70, "DisplayFormula",
  CellTags->{"S1.2.3", "3.9"}],
Cell[55805, 2094, 488, 15, 70, "Text",
  CellTags->{"S1.2.3", "3.10"}],
Cell[56296, 2111, 429, 10, 70, "DisplayFormula",
  CellTags->{"S1.2.3", "3.11"}],
Cell[56728, 2123, 125, 4, 70, "Subsection",
  CellTags->{"S1.2.4", "4.1"}],
Cell[56856, 2129, 375, 12, 70, "Text",
  CellTags->{"S1.2.4", "4.2"}],
Cell[57234, 2143, 158, 4, 70, "DisplayFormula",
  CellTags->{"S1.2.4", "4.3"}],
Cell[57395, 2149, 199, 7, 70, "Text",
  CellTags->{"S1.2.4", "4.4"}],
Cell[57597, 2158, 178, 5, 70, "DisplayFormula",
  CellTags->{"S1.2.4", "4.5"}],
Cell[57778, 2165, 2825, 84, 70, "Text",
  CellTags->{"S1.2.4", "4.6"}],
Cell[60606, 2251, 498, 11, 70, "DisplayFormula",
  CellTags->{"S1.2.4", "4.7"}],
Cell[61107, 2264, 632, 15, 70, "Text",
  CellTags->{"S1.2.4", "4.8"}],
Cell[61742, 2281, 512, 11, 70, "DisplayFormula",
  CellTags->{"S1.2.4", "4.9"}],
Cell[62257, 2294, 4268, 106, 70, "Text",
  CellTags->{"S1.2.4", "4.10"}],
Cell[66528, 2402, 91, 1, 70, "Subsection",
  CellTags->{"S1.2.5", "5.1"}],
Cell[66622, 2405, 330, 8, 70, "Text",
  CellTags->{"S1.2.5", "5.2"}],
Cell[66955, 2415, 316, 8, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.3"}],
Cell[67274, 2425, 255, 7, 70, "Text",
  CellTags->{"S1.2.5", "5.4"}],
Cell[67532, 2434, 2007, 51, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.5"}],
Cell[69542, 2487, 56, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.6"}],
Cell[69601, 2490, 268, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.7"}],
Cell[69872, 2498, 103, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.8"}],
Cell[69978, 2501, 287, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.9"}],
Cell[70268, 2509, 463, 13, 70, "Text",
  CellTags->{"S1.2.5", "5.10"}],
Cell[70734, 2524, 269, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.11"}],
Cell[71006, 2532, 88, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.12"}],
Cell[71097, 2535, 288, 6, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.13"}],
Cell[71388, 2543, 105, 1, 70, "Subsubsection",
  CellTags->{"S1.2.5", "5.14"}],
Cell[71496, 2546, 333, 11, 70, "Text",
  CellTags->{"S1.2.5", "5.15"}],
Cell[71832, 2559, 1698, 44, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.16"}],
Cell[73533, 2605, 795, 21, 70, "Text",
  CellTags->{"S1.2.5", "5.17"}],
Cell[74331, 2628, 478, 10, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.18"}],
Cell[74812, 2640, 247, 7, 70, "Text",
  CellTags->{"S1.2.5", "5.19"}],
Cell[75062, 2649, 456, 10, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.20"}],
Cell[75521, 2661, 817, 22, 70, "Text",
  CellTags->{"S1.2.5", "5.21"}],
Cell[76341, 2685, 711, 18, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.22"}],
Cell[77055, 2705, 52, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.23"}],
Cell[77110, 2708, 1136, 27, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.24"}],
Cell[78249, 2737, 1139, 37, 70, "Text",
  CellTags->{"S1.2.5", "5.25"}],
Cell[79391, 2776, 1831, 46, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.26"}],
Cell[81225, 2824, 630, 19, 70, "Text",
  CellTags->{"S1.2.5", "5.27"}],
Cell[81858, 2845, 824, 16, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.28"}],
Cell[82685, 2863, 356, 11, 70, "Text",
  CellTags->{"S1.2.5", "5.29"}],
Cell[83044, 2876, 788, 16, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.30"}],
Cell[83835, 2894, 59, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.31"}],
Cell[83897, 2897, 350, 7, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.32"}],
Cell[84250, 2906, 607, 17, 70, "Text",
  CellTags->{"S1.2.5", "5.33"}],
Cell[84860, 2925, 362, 8, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.34"}],
Cell[85225, 2935, 51, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.35"}],
Cell[85279, 2938, 246, 5, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.36"}],
Cell[85528, 2945, 371, 11, 70, "Text",
  CellTags->{"S1.2.5", "5.37"}],
Cell[85902, 2958, 1665, 43, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.38"}],
Cell[87570, 3003, 509, 13, 70, "Text",
  CellTags->{"S1.2.5", "5.39"}],
Cell[88082, 3018, 351, 7, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.40"}],
Cell[88436, 3027, 374, 11, 70, "Text",
  CellTags->{"S1.2.5", "5.41"}],
Cell[88813, 3040, 207, 4, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.42"}],
Cell[89023, 3046, 973, 26, 70, "Text",
  CellTags->{"S1.2.5", "5.43"}],
Cell[89999, 3074, 180, 4, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.44"}],
Cell[90182, 3080, 1467, 39, 70, "Text",
  CellTags->{"S1.2.5", "5.45"}],
Cell[91652, 3121, 179, 4, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.46"}],
Cell[91834, 3127, 203, 7, 70, "Text",
  CellTags->{"S1.2.5", "5.47"}],
Cell[92040, 3136, 664, 15, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.48"}],
Cell[92707, 3153, 72, 1, 70, "Text",
  CellTags->{"S1.2.5", "5.49"}],
Cell[92782, 3156, 237, 5, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.50"}],
Cell[93022, 3163, 1287, 37, 70, "Text",
  CellTags->{"S1.2.5", "5.51"}],
Cell[94312, 3202, 67, 1, 70, "Subsubsection",
  CellTags->{"S1.2.5", "5.52"}],
Cell[94382, 3205, 325, 8, 70, "Text",
  CellTags->{"S1.2.5", "5.53"}],
Cell[94710, 3215, 363, 11, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.54"}],

Cell[CellGroupData[{
Cell[95098, 3230, 185, 6, 70, "Input",
  CellTags->"S1.2.5"],
Cell[95286, 3238, 2945, 219, 70, 2872, 216, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],
Cell[98246, 3460, 506, 17, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.55"}],

Cell[CellGroupData[{
Cell[98777, 3481, 189, 6, 70, "Input",
  CellTags->"S1.2.5"],
Cell[98969, 3489, 2993, 222, 70, 2920, 219, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],
Cell[101977, 3714, 807, 23, 70, "Text",
  CellTags->{"S1.2.5", "5.56"}],
Cell[102787, 3739, 268, 8, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.57"}],

Cell[CellGroupData[{
Cell[103080, 3751, 112, 2, 70, "Input",
  CellTags->"S1.2.5"],
Cell[103195, 3755, 102, 3, 70, "Output",
  CellTags->"S1.2.5"]
}, Open  ]],
Cell[103312, 3761, 462, 15, 70, "Text",
  CellTags->{"S1.2.5", "5.58"}],
Cell[103777, 3778, 330, 7, 70, "DisplayFormula",
  CellTags->{"S1.2.5", "5.59"}],
Cell[104110, 3787, 85, 1, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.60"}],
Cell[104198, 3790, 96, 2, 70, "Input",
  CellTags->"S1.2.5"],
Cell[104297, 3794, 88, 1, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.61"}],

Cell[CellGroupData[{
Cell[104410, 3799, 134, 5, 70, "Input",
  CellTags->"S1.2.5"],
Cell[104547, 3806, 4219, 291, 70, 4146, 288, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]],
Cell[108781, 4100, 648, 20, 70, "MathCaption",
  CellTags->{"S1.2.5", "5.62"}],

Cell[CellGroupData[{
Cell[109454, 4124, 257, 8, 70, "Input",
  CellTags->"S1.2.5"],
Cell[109714, 4134, 5693, 386, 70, 5620, 383, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.2.5"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

