(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    458395,      25071]*)
(*NotebookOutlinePosition[    519427,      26798]*)
(*  CellTagsIndexPosition[    512823,      26551]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.3 Orthogonal Wavelets", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 1.3.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.3.1 Battle\[Hyphen]Lemari\[EAcute] Wavelets",
    ButtonData:>{"Wavelets 1.3.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.3.2 Other Examples",
    ButtonData:>{"Wavelets 1.3.2"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["1.3 Orthogonal Wavelets", "Section",
  CellTags->{"S1.3.0", "0.1"}],

Cell[TextData[{
  "We have seen in the earlier sections that wavelets provide special kinds \
of bases in function space. Their novelty lies partly in the fact that all \
the functions of the basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.3.0"],
  " are derived from a single function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  ", called the basic wavelet or mother wavelet, by translations and \
dilations: "
}], "Text",
  CellTags->{"S1.3.0", "0.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Psi]\_\(j  k\)\) \((t)\) = \(2\^\(j/2\)\) \[Psi] \((\(2\^j\) t - k)
      \).\)], "DisplayFormula",
  CellTags->{"S1.3.0", "0.3"}],

Cell[TextData[{
  "Of course, like any other basis, a wavelet basis does not have to be \
orthogonal. But orthogonality provides conveniences in computations in our \
applications. This is the first of two sections devoted to the discussion of \
orthogonal wavelets. We will outline the ideas behind the derivation of some \
of the best known orthogonal wavelets and show how we can use ",
  StyleBox["Mathematica", "TI"],
  " to construct and plot them and to get the corresponding filter \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.0"],
  ", which are used in wavelet decomposition and reconstruction. \nHow does \
one construct an orthogonal wavelet basis? We know from the discussion in \
Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  " that if we can find a scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  " associated with a multiresolution analysis, we can find the associated \
orthogonal wavelets through the wavelet equation (",
  ButtonBox["2.5",
    ButtonData:>{"Wavelets 1.2.4", "4.7"},
    ButtonStyle->"AddOnsLink"],
  "). So the first task is to find a scaling function. There are essentially \
two approaches to finding the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  ". The first starts from a multiresolution analysis. Usually, there exists \
a known, nonorthogonal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.0"],
  ", and all we need to do is to use the orthogonalization procedure outlined \
in Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  " to obtain the scaling function that generates the orthogonal basis. The \
second approach is to find the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.3.0"],
  " in the dilation equation (",
  ButtonBox["2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  ") that obey appropriate conditions, and the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  " can then be constructed from the dilation equation. \nThe second \
approach, which leads to the celebrated Daubechies wavelets, will be the \
subject of Section ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ". In this section we illustrate the first approach to finding a scaling \
function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  " and, in turn, the associated wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.0"],
  ". In particular, we will look at the example of Battle\[Hyphen]Lemari\
\[EAcute] wavelets, which are associated with the multiresolution analyses of \
polynomial splines. The scaling functions are simply the orthogonalized ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.0"],
  "\[Hyphen]spline functions. Yet another related approach to finding a \
scaling function is to specify the appropriate scaling function in frequency \
space. We will present the Shannon and Meyer wavelets to illustrate this \
method of constructing wavelets. "
}], "Text",
  CellTags->{"S1.3.0", "0.4"}],

Cell["1.3.1 Battle\[Hyphen]Lemari\[EAcute] Wavelets", "Subsection",
  CellTags->{"S1.3.1", "1.1"}],

Cell[TextData[{
  "We have seen that the Haar system constitutes a multiresolution analysis \
where the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is the characteristic function on the interval [0, 1). However, due to \
its lack of continuity, representing smooth functions in terms of the Haar \
wavelet basis is not very efficient in that a reasonable approximation of a \
smooth function requires a large number of terms in the expansion. So we \
would like to find other multiresolution analyses where the scaling \
functions, and in turn the wavelets, are smoother. In fact, it turns out that \
there exists a whole family of multiresolution analyses generated by \
polynomial splines. Before embarking on the task of finding the orthogonal \
scaling functions and wavelets associated with these multiresolution \
analyses, let us first review some of the properties of splines. "
}], "Text",
  CellTags->{"S1.3.1", "1.2"}],

Cell["Spline Functions", "Subsubsection",
  CellTags->{"S1.3.1", "1.3"}],

Cell[TextData[{
  "We consider the space ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " of polynomial spline functions of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " with knots at integers defined as follows: ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a collection of functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " that satisfy the following two properties: (i) in each interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k, k + 1)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " integer), ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a polynomial of degree not exceeding ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and (ii) for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is smooth in that the first ",
  Cell[BoxData[
      \(TraditionalForm\`\((n - 1)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " derivatives are continuous. The functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " so defined are often called ",
  StyleBox["cardinal spline functions", "TI"],
  ". However, for simplicity we will refer to them simply as spline functions \
or polynomial splines. For example, when ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " consists of piecewise constant functions with possible discontinuities at \
the integers. The box function defined in Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  " and its translates form a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", since any piecewise constant function in ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " can obviously be written as a superposition of these basis functions. We \
call the box function a ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline of order zero, where the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " stands for basis, and denote it by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". That is, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t)\) = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t < 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t)\) = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " otherwise, and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_0\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". \nFor ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the space of polynomial splines of order 1, consists of piecewise linear \
functions with possible discontinuities in the first derivative at the \
integers. This means that the derivative of any spline function of order 1 is \
a spline function of order zero and suggests that the basis functions for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " can be obtained by integrating those of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". In fact, one choice for the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline of order 1 can be written in the form "
}], "Text",
  CellTags->{"S1.3.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Integral]\_0\%1\), \(\[Beta]\_0\), \((t - x)\), " ", 
        StyleBox[\("dx"\),
          "TI"], "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\[Beta]\_0\), \((x)\), \(\[Beta]\_0\), \((t - x)\), " ", 
        StyleBox[\("dx"\),
          "TI"], ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.5"}],

Cell[TextData[{
  "that is, a convolution of a ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline of order zero with itself. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t - x)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is nonzero only when ",
  Cell[BoxData[
      \(TraditionalForm\`t - x\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is within ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 1)\)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the integral vanishes except when ",
  Cell[BoxData[
      \(TraditionalForm\`t - 1 < x \[LessEqual] t\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". That is, "
}], "Text",
  CellTags->{"S1.3.1", "1.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Beta]\_0\), \((x)\),
         \(\[Beta]\_0\), \((t - x)\), " ", 
        StyleBox[\("dx"\),
          "TI"], "=", \(\[Integral]\_0\%1\), \(\[Beta]\_0\), \((t - x)\), " ",
         
        StyleBox[\("dx"\),
          "TI"], "=", 
        SubsuperscriptBox["\[Integral]", 
          RowBox[{
            StyleBox[\("max"\),
              "TI"], \((0, t - 1)\)}], 
          RowBox[{
            StyleBox[\("min"\),
              "TI"], \((1, t)\)}]], " ", 
        StyleBox[\("dt"\),
          "TI"], "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["t",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    StyleBox[\(0 \[LessEqual] t \[LessEqual] 1\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox[\(2 - t\),
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    StyleBox[\(1 \[LessEqual] t \[LessEqual] 2\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\(" otherwise."\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.1", "1.7"}],

Cell[TextData[{
  "This is the hat function defined on the interval [0, 2]. We will choose \
the hat function defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-1\), 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " as our ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function of order one ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is obtained by translating the above function by unity: "
}], "Text",
  CellTags->{"S1.3.1", "1.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Beta]\_1\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                
                StyleBox[
                  \(1 -  \[VerticalSeparator] t \[VerticalSeparator] , \),
                  "DisplayFormula"], 
                StyleBox[\(\(-1\) \[LessEqual] t \[LessEqual] 1\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise"\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.9"}],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " form a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". \nThe higher\[Hyphen]order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline functions can be obtained similarly using convolutions. In \
general, the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is obtained from an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]fold convolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". It is a polynomial of degree ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " with support of length ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". Here in our discussion we choose its support to be ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      \(-\((n + 1)\)/2, \((n + 1)\)/2\)]\)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for odd ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and [",
  Cell[BoxData[
      \(TraditionalForm\`\(-n/2\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n/2 + 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "] for even ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is symmetric about ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " odd and about ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " even. If we define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[InvisibleSpace]\([t]\)\)\_+\) = \)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " max(",
  Cell[BoxData[
      \(TraditionalForm\`0, t\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[InvisibleSpace]\([t]\)\)\_+\%n = 
        \((\(\(\[InvisibleSpace]\([t]\)\)\_+\))\)\^n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", an explicit formula for ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\( > 0\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ") is "
}], "Text",
  CellTags->{"S1.3.1", "1.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Beta]\_n\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox[
                  RowBox[{\(1\/\(n!\)\), 
                    UnderoverscriptBox["\[Sum]", \(j = 0\), \(n + 1\),
                      LimitsPositioning->True], \(\((\(-1\))\)\^j\), 
                    RowBox[{"(", GridBox[{
                          {
                            StyleBox[\(n + 1\),
                              "DisplayFormula"]},
                          {
                            StyleBox["j",
                              "DisplayFormula"]}
                          },
                        ColumnAlignments->{Center}], ")"}], 
                    \(\(\[InvisibleSpace]\([t + n/2 - j]\)\)\_+\%n\)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    StyleBox["n",
                      "DisplayFormula"], \(" is even"\)}],
                  "DisplayFormula"]},
              {
                StyleBox[
                  RowBox[{\(1\/\(n!\)\), 
                    UnderoverscriptBox["\[Sum]", \(j = 0\), \(n + 1\),
                      LimitsPositioning->True], \(\((\(-1\))\)\^j\), 
                    RowBox[{"(", GridBox[{
                          {
                            StyleBox[\(n + 1\),
                              "DisplayFormula"]},
                          {
                            StyleBox["j",
                              "DisplayFormula"]}
                          },
                        ColumnAlignments->{Center}], ")"}], 
                    \(\(\[InvisibleSpace]\([t + \((n + 1)\)/2 - j]\)\)\_+\%n
                        \)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    StyleBox["n",
                      "DisplayFormula"], \(" is odd"\)}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.11"}],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_n\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the space of polynomial splines of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". We have defined a ",
  StyleBox["Mathematica", "TI"],
  " function "
}], "Text",
  CellTags->{"S1.3.1", "1.12"}],

Cell[TextData[{
  StyleBox["BSpline[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.1", "1.13"}],

Cell[TextData[{
  "that gives ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.14"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S1.3.1", "1.15"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and its translates were displayed in Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  ". Here we display ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline of order 4."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.16"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[BSpline[4, t]], {t, -3, 4},
PlotRange -> All, AxesLabel -> {\"t\", \"beta[4, t]\"}]\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.431973 0.136054 0.0147151 0.982714 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.15986 .00222 -6 -9 ]
[.15986 .00222 6 0 ]
[.29592 .00222 -6 -9 ]
[.29592 .00222 6 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.41947 .11299 -18 -4.5 ]
[.41947 .11299 0 4.5 ]
[.41947 .21126 -18 -4.5 ]
[.41947 .21126 0 4.5 ]
[.41947 .30953 -18 -4.5 ]
[.41947 .30953 0 4.5 ]
[.41947 .4078 -18 -4.5 ]
[.41947 .4078 0 4.5 ]
[.41947 .50607 -18 -4.5 ]
[.41947 .50607 0 4.5 ]
[.41947 .60434 -18 -4.5 ]
[.41947 .60434 0 4.5 ]
[.43197 .64303 -30 0 ]
[.43197 .64303 30 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-3)] .02381 .00222 0 1 Mshowa
.15986 .01472 m
.15986 .02097 L
s
[(-2)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(-1)] .29592 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(1)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(2)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(3)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(t)] 1.025 .01472 -1 0 Mshowa
.43197 .11299 m
.43822 .11299 L
s
[(0.1)] .41947 .11299 1 0 Mshowa
.43197 .21126 m
.43822 .21126 L
s
[(0.2)] .41947 .21126 1 0 Mshowa
.43197 .30953 m
.43822 .30953 L
s
[(0.3)] .41947 .30953 1 0 Mshowa
.43197 .4078 m
.43822 .4078 L
s
[(0.4)] .41947 .4078 1 0 Mshowa
.43197 .50607 m
.43822 .50607 L
s
[(0.5)] .41947 .50607 1 0 Mshowa
.43197 .60434 m
.43822 .60434 L
s
[(0.6)] .41947 .60434 1 0 Mshowa
.125 Mabswid
.43197 .03437 m
.43572 .03437 L
s
.43197 .05402 m
.43572 .05402 L
s
.43197 .07368 m
.43572 .07368 L
s
.43197 .09333 m
.43572 .09333 L
s
.43197 .13264 m
.43572 .13264 L
s
.43197 .1523 m
.43572 .1523 L
s
.43197 .17195 m
.43572 .17195 L
s
.43197 .1916 m
.43572 .1916 L
s
.43197 .23091 m
.43572 .23091 L
s
.43197 .25057 m
.43572 .25057 L
s
.43197 .27022 m
.43572 .27022 L
s
.43197 .28987 m
.43572 .28987 L
s
.43197 .32918 m
.43572 .32918 L
s
.43197 .34884 m
.43572 .34884 L
s
.43197 .36849 m
.43572 .36849 L
s
.43197 .38815 m
.43572 .38815 L
s
.43197 .42745 m
.43572 .42745 L
s
.43197 .44711 m
.43572 .44711 L
s
.43197 .46676 m
.43572 .46676 L
s
.43197 .48642 m
.43572 .48642 L
s
.43197 .52573 m
.43572 .52573 L
s
.43197 .54538 m
.43572 .54538 L
s
.43197 .56503 m
.43572 .56503 L
s
.43197 .58469 m
.43572 .58469 L
s
.25 Mabswid
.43197 0 m
.43197 .61803 L
s
[(beta[4, t])] .43197 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.12507 .01472 L
.13506 .01472 L
.14415 .01472 L
.14868 .01472 L
.1536 .01472 L
.15586 .01472 L
.15709 .01472 L
.15825 .01472 L
.15923 .01472 L
.16029 .01472 L
.16146 .01472 L
.16254 .01472 L
.16375 .01472 L
.16504 .01472 L
.16626 .01472 L
.16736 .01472 L
.16866 .01472 L
.1694 .01472 L
.17007 .01472 L
.17131 .01472 L
.17262 .01472 L
.17376 .01472 L
.17499 .01472 L
.17719 .01473 L
.17854 .01473 L
.17982 .01473 L
.18221 .01474 L
.18457 .01476 L
.1868 .01478 L
.18923 .0148 L
.19186 .01484 L
.19447 .01489 L
.19721 .01495 L
.20212 .0151 L
.20667 .01529 L
.21091 .01553 L
.21557 .01587 L
.22054 .01633 L
.22587 .01698 L
.23078 .01774 L
.23607 .01874 L
.24188 .02012 L
.25167 .0232 L
.26204 .02774 L
.2722 .03374 L
.28148 .04086 L
.2922 .05137 L
Mistroke
.30238 .064 L
.32222 .09746 L
.34062 .1399 L
.3798 .26475 L
.42144 .42582 L
.44234 .50095 L
.45151 .52926 L
.46156 .55585 L
.47128 .57643 L
.48034 .5906 L
.48535 .59623 L
.48991 .59995 L
.49243 .60142 L
.49386 .60207 L
.49518 .60255 L
.49633 .60287 L
.49759 .60313 L
.49823 .60322 L
.49892 .60328 L
.50016 .60332 L
.50142 .60325 L
.50256 .6031 L
.50389 .60282 L
.50513 .60245 L
.50735 .60153 L
.50975 .60017 L
.51241 .59823 L
.51521 .59568 L
.52024 .58985 L
.5303 .57346 L
.54135 .54868 L
.56084 .49034 L
.58174 .41358 L
.62307 .25427 L
.64374 .18457 L
.66288 .13095 L
.68145 .09034 L
.69094 .07391 L
.70118 .05927 L
.71132 .04762 L
.72063 .03909 L
.72946 .03265 L
.7389 .02727 L
.74869 .02307 L
.7578 .02021 L
.76337 .01886 L
.76864 .01784 L
.77333 .0171 L
.77849 .01644 L
.7835 .01594 L
Mistroke
.7882 .01558 L
.79315 .0153 L
.7957 .01518 L
.79848 .01507 L
.80104 .01499 L
.80342 .01493 L
.80588 .01488 L
.80812 .01484 L
.81016 .01481 L
.81238 .01479 L
.81472 .01476 L
.81693 .01475 L
.8193 .01474 L
.82063 .01473 L
.82185 .01473 L
.82298 .01473 L
.82421 .01472 L
.82536 .01472 L
.82644 .01472 L
.82769 .01472 L
.82841 .01472 L
.82907 .01472 L
.83042 .01472 L
.83112 .01472 L
.83186 .01472 L
.83311 .01472 L
.83426 .01472 L
.83553 .01472 L
.83624 .01472 L
.83688 .01472 L
.83819 .01472 L
.83886 .01472 L
.83959 .01472 L
.84088 .01472 L
.84208 .01472 L
.84281 .01472 L
.8435 .01472 L
.8448 .01472 L
.84553 .01472 L
.8462 .01472 L
.84694 .01472 L
.84772 .01472 L
.84841 .01472 L
.84905 .01472 L
.84975 .01472 L
.85049 .01472 L
.85173 .01472 L
.85243 .01472 L
.85309 .01472 L
.85432 .01472 L
Mistroke
.85544 .01472 L
.85673 .01472 L
.85795 .01472 L
.8591 .01472 L
.86033 .01472 L
.86149 .01472 L
.86256 .01472 L
.8638 .01472 L
.86451 .01472 L
.86516 .01472 L
.86636 .01472 L
.86764 .01472 L
.86833 .01472 L
.86897 .01472 L
.86967 .01472 L
.87041 .01472 L
.87166 .01472 L
.87237 .01472 L
.87303 .01472 L
.87426 .01472 L
.87538 .01472 L
.87668 .01472 L
.87791 .01472 L
.87897 .01472 L
.88014 .01472 L
.88135 .01472 L
.8825 .01472 L
.88356 .01472 L
.88454 .01472 L
.88561 .01472 L
.88674 .01472 L
.88789 .01472 L
.88912 .01472 L
.89028 .01472 L
.89133 .01472 L
.89257 .01472 L
.89327 .01472 L
.89391 .01472 L
.8951 .01472 L
.89635 .01472 L
.89756 .01472 L
.89888 .01472 L
.90012 .01472 L
.90128 .01472 L
.90239 .01472 L
.9036 .01472 L
.90474 .01472 L
.90578 .01472 L
.90703 .01472 L
.90836 .01472 L
Mistroke
.90947 .01472 L
.91069 .01472 L
.91199 .01472 L
.91273 .01472 L
.91339 .01472 L
.91469 .01472 L
.91592 .01472 L
.91697 .01472 L
.91813 .01472 L
.91934 .01472 L
.92048 .01472 L
.92153 .01472 L
.9225 .01472 L
.92357 .01472 L
.92469 .01472 L
.92583 .01472 L
.92705 .01472 L
.9282 .01472 L
.92925 .01472 L
.93048 .01472 L
.93112 .01472 L
.93181 .01472 L
.93307 .01472 L
.93423 .01472 L
.93544 .01472 L
.93676 .01472 L
.93801 .01472 L
.93917 .01472 L
.94021 .01472 L
.94136 .01472 L
.94255 .01472 L
.94368 .01472 L
.94492 .01472 L
.94623 .01472 L
.94734 .01472 L
.94856 .01472 L
.94988 .01472 L
.95062 .01472 L
.95129 .01472 L
.9526 .01472 L
.95383 .01472 L
.95489 .01472 L
.95605 .01472 L
.95726 .01472 L
.9584 .01472 L
.95946 .01472 L
.96043 .01472 L
.96155 .01472 L
.96262 .01472 L
.96376 .01472 L
Mistroke
.96498 .01472 L
.96613 .01472 L
.96718 .01472 L
.96841 .01472 L
.9691 .01472 L
.96974 .01472 L
.97091 .01472 L
.97215 .01472 L
.97316 .01472 L
.97424 .01472 L
.97526 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "The basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_n\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are not orthogonal except in the case of ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". This can be understood from the fact the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is nonnegative and has support of length ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and the graphs of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t - 1)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " necessarily overlap when ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". The following plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_4\) \((t + 1)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_4\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_4\) \((t - 1)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " clearly shows the nonorthogonal nature of the basis. "
}], "Text",
  CellTags->{"S1.3.1", "1.17"}],

Cell[TextData[{
  "This shows ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_4\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and its translates."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.18"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{BSpline[4, t+1], BSpline[4, t],
BSpline[4, t-1]}], {t, -3, 4}, PlotRange -> All,
AxesLabel -> {\"t\", \"B-Spline functions of order 4\"}]\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.431973 0.136054 0.0147151 0.982713 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.15986 .00222 -6 -9 ]
[.15986 .00222 6 0 ]
[.29592 .00222 -6 -9 ]
[.29592 .00222 6 0 ]
[.56803 .00222 -3 -9 ]
[.56803 .00222 3 0 ]
[.70408 .00222 -3 -9 ]
[.70408 .00222 3 0 ]
[.84014 .00222 -3 -9 ]
[.84014 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.41947 .11299 -18 -4.5 ]
[.41947 .11299 0 4.5 ]
[.41947 .21126 -18 -4.5 ]
[.41947 .21126 0 4.5 ]
[.41947 .30953 -18 -4.5 ]
[.41947 .30953 0 4.5 ]
[.41947 .4078 -18 -4.5 ]
[.41947 .4078 0 4.5 ]
[.41947 .50607 -18 -4.5 ]
[.41947 .50607 0 4.5 ]
[.41947 .60434 -18 -4.5 ]
[.41947 .60434 0 4.5 ]
[.43197 .64303 -87 0 ]
[.43197 .64303 87 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-3)] .02381 .00222 0 1 Mshowa
.15986 .01472 m
.15986 .02097 L
s
[(-2)] .15986 .00222 0 1 Mshowa
.29592 .01472 m
.29592 .02097 L
s
[(-1)] .29592 .00222 0 1 Mshowa
.56803 .01472 m
.56803 .02097 L
s
[(1)] .56803 .00222 0 1 Mshowa
.70408 .01472 m
.70408 .02097 L
s
[(2)] .70408 .00222 0 1 Mshowa
.84014 .01472 m
.84014 .02097 L
s
[(3)] .84014 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05102 .01472 m
.05102 .01847 L
s
.07823 .01472 m
.07823 .01847 L
s
.10544 .01472 m
.10544 .01847 L
s
.13265 .01472 m
.13265 .01847 L
s
.18707 .01472 m
.18707 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.2415 .01472 m
.2415 .01847 L
s
.26871 .01472 m
.26871 .01847 L
s
.32313 .01472 m
.32313 .01847 L
s
.35034 .01472 m
.35034 .01847 L
s
.37755 .01472 m
.37755 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45918 .01472 m
.45918 .01847 L
s
.48639 .01472 m
.48639 .01847 L
s
.51361 .01472 m
.51361 .01847 L
s
.54082 .01472 m
.54082 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62245 .01472 m
.62245 .01847 L
s
.64966 .01472 m
.64966 .01847 L
s
.67687 .01472 m
.67687 .01847 L
s
.73129 .01472 m
.73129 .01847 L
s
.7585 .01472 m
.7585 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.81293 .01472 m
.81293 .01847 L
s
.86735 .01472 m
.86735 .01847 L
s
.89456 .01472 m
.89456 .01847 L
s
.92177 .01472 m
.92177 .01847 L
s
.94898 .01472 m
.94898 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(t)] 1.025 .01472 -1 0 Mshowa
.43197 .11299 m
.43822 .11299 L
s
[(0.1)] .41947 .11299 1 0 Mshowa
.43197 .21126 m
.43822 .21126 L
s
[(0.2)] .41947 .21126 1 0 Mshowa
.43197 .30953 m
.43822 .30953 L
s
[(0.3)] .41947 .30953 1 0 Mshowa
.43197 .4078 m
.43822 .4078 L
s
[(0.4)] .41947 .4078 1 0 Mshowa
.43197 .50607 m
.43822 .50607 L
s
[(0.5)] .41947 .50607 1 0 Mshowa
.43197 .60434 m
.43822 .60434 L
s
[(0.6)] .41947 .60434 1 0 Mshowa
.125 Mabswid
.43197 .03437 m
.43572 .03437 L
s
.43197 .05402 m
.43572 .05402 L
s
.43197 .07368 m
.43572 .07368 L
s
.43197 .09333 m
.43572 .09333 L
s
.43197 .13264 m
.43572 .13264 L
s
.43197 .15229 m
.43572 .15229 L
s
.43197 .17195 m
.43572 .17195 L
s
.43197 .1916 m
.43572 .1916 L
s
.43197 .23091 m
.43572 .23091 L
s
.43197 .25057 m
.43572 .25057 L
s
.43197 .27022 m
.43572 .27022 L
s
.43197 .28987 m
.43572 .28987 L
s
.43197 .32918 m
.43572 .32918 L
s
.43197 .34884 m
.43572 .34884 L
s
.43197 .36849 m
.43572 .36849 L
s
.43197 .38815 m
.43572 .38815 L
s
.43197 .42745 m
.43572 .42745 L
s
.43197 .44711 m
.43572 .44711 L
s
.43197 .46676 m
.43572 .46676 L
s
.43197 .48642 m
.43572 .48642 L
s
.43197 .52573 m
.43572 .52573 L
s
.43197 .54538 m
.43572 .54538 L
s
.43197 .56503 m
.43572 .56503 L
s
.43197 .58469 m
.43572 .58469 L
s
.25 Mabswid
.43197 0 m
.43197 .61803 L
s
[(B-Spline functions of order 4)] .43197 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.04011 .01472 L
.04141 .01473 L
.04262 .01473 L
.04386 .01473 L
.04521 .01474 L
.04765 .01475 L
.05003 .01477 L
.05221 .01479 L
.05459 .01482 L
.05719 .01486 L
.06244 .01498 L
.06527 .01507 L
.06795 .01517 L
.07296 .01541 L
.07836 .01577 L
.08424 .01631 L
.08936 .01692 L
.0948 .01775 L
.0999 .01872 L
.10458 .0198 L
.11395 .0226 L
.12405 .02678 L
.13296 .03167 L
.14233 .0383 L
.15188 .04686 L
.16207 .05838 L
.18044 .08653 L
.20178 .13277 L
.22194 .18998 L
.2604 .3281 L
.27989 .40459 L
.30132 .48422 L
.31114 .51636 L
.32168 .54633 L
.33156 .56931 L
.34072 .58564 L
Mistroke
.34563 .59227 L
.35086 .59765 L
.35384 .59994 L
.35531 .60085 L
.35665 .60156 L
.35785 .60209 L
.35917 .60256 L
.3605 .60293 L
.36122 .60307 L
.3619 .60318 L
.36315 .6033 L
.36386 .60332 L
.36451 .60331 L
.36571 .60322 L
.36698 .60301 L
.36812 .60274 L
.36918 .60241 L
.37161 .60137 L
.37422 .59982 L
.37661 .59801 L
.382 .59258 L
.38676 .58625 L
.39183 .57795 L
.40096 .5592 L
.42168 .50069 L
.46323 .34479 L
.50326 .19856 L
.52162 .1444 L
.54178 .09735 L
.56169 .06383 L
.57258 .05045 L
.58275 .04061 L
.59319 .03279 L
.60308 .02715 L
.61196 .02332 L
.62163 .02024 L
.63101 .01812 L
.63636 .01723 L
.64138 .01656 L
.64665 .01602 L
.65148 .01563 L
.65679 .01531 L
.65966 .01518 L
.66238 .01508 L
.66477 .015 L
.66737 .01493 L
.67191 .01484 L
.67448 .01481 L
.6772 .01478 L
.67953 .01476 L
Mistroke
.68209 .01474 L
.68448 .01473 L
.68666 .01473 L
.68787 .01472 L
.68918 .01472 L
.69042 .01472 L
.69158 .01472 L
.69274 .01472 L
.69383 .01472 L
.69481 .01472 L
.69587 .01472 L
.69703 .01472 L
.69826 .01472 L
.69931 .01472 L
.70045 .01472 L
.70176 .01472 L
.70297 .01472 L
.7036 .01472 L
.70429 .01472 L
.70502 .01472 L
.7057 .01472 L
.70695 .01472 L
.70809 .01472 L
.70935 .01472 L
.71067 .01472 L
.71178 .01472 L
.71297 .01472 L
.7141 .01472 L
.71512 .01472 L
.71632 .01472 L
.71762 .01472 L
.71885 .01472 L
.71998 .01472 L
.72118 .01472 L
.72248 .01472 L
.7237 .01472 L
.72482 .01472 L
.72613 .01472 L
.72687 .01472 L
.72755 .01472 L
.72881 .01472 L
.72951 .01472 L
.73014 .01472 L
.73082 .01472 L
.73153 .01472 L
.73281 .01472 L
.73352 .01472 L
.73418 .01472 L
.73491 .01472 L
.73569 .01472 L
Mistroke
.73636 .01472 L
.73709 .01472 L
.73778 .01472 L
.73841 .01472 L
.73962 .01472 L
.7409 .01472 L
.7421 .01472 L
.74341 .01472 L
.74466 .01472 L
.74581 .01472 L
.74693 .01472 L
.74798 .01472 L
.7492 .01472 L
.7503 .01472 L
.75153 .01472 L
.75283 .01472 L
.75394 .01472 L
.75516 .01472 L
.75648 .01472 L
.75721 .01472 L
.75788 .01472 L
.75919 .01472 L
.76042 .01472 L
.76147 .01472 L
.76263 .01472 L
.76384 .01472 L
.76497 .01472 L
.76603 .01472 L
.767 .01472 L
.76806 .01472 L
.76919 .01472 L
.77033 .01472 L
.77154 .01472 L
.77269 .01472 L
.77374 .01472 L
.77497 .01472 L
.77566 .01472 L
.7763 .01472 L
.77748 .01472 L
.77872 .01472 L
.77993 .01472 L
.78125 .01472 L
.78249 .01472 L
.78365 .01472 L
.78479 .01472 L
.78583 .01472 L
.78702 .01472 L
.78815 .01472 L
.78939 .01472 L
.79069 .01472 L
Mistroke
.7918 .01472 L
.79302 .01472 L
.79434 .01472 L
.79507 .01472 L
.79575 .01472 L
.79705 .01472 L
.79829 .01472 L
.79934 .01472 L
.8005 .01472 L
.80171 .01472 L
.80285 .01472 L
.8039 .01472 L
.80487 .01472 L
.80594 .01472 L
.80706 .01472 L
.8082 .01472 L
.80942 .01472 L
.81057 .01472 L
.81162 .01472 L
.81285 .01472 L
.81354 .01472 L
.81418 .01472 L
.81535 .01472 L
.8166 .01472 L
.81781 .01472 L
.81913 .01472 L
.82038 .01472 L
.82154 .01472 L
.82258 .01472 L
.82373 .01472 L
.82492 .01472 L
.82605 .01472 L
.82729 .01472 L
.8286 .01472 L
.82971 .01472 L
.83093 .01472 L
.83225 .01472 L
.83299 .01472 L
.83366 .01472 L
.83497 .01472 L
.8362 .01472 L
.83735 .01472 L
.83842 .01472 L
.83954 .01472 L
.84077 .01472 L
.84183 .01472 L
.8428 .01472 L
.84392 .01472 L
.84499 .01472 L
.84613 .01472 L
Mistroke
.84735 .01472 L
.84955 .01472 L
.85452 .01472 L
.85517 .01472 L
.85587 .01472 L
.85713 .01472 L
.85844 .01472 L
.8592 .01472 L
.85988 .01472 L
.86109 .01472 L
.86241 .01472 L
.86366 .01472 L
.86481 .01472 L
.86545 .01472 L
.86614 .01472 L
.86738 .01472 L
.8681 .01472 L
.86885 .01472 L
.8695 .01472 L
.87021 .01472 L
.87096 .01472 L
.87164 .01472 L
.87243 .01472 L
.87318 .01472 L
.87387 .01472 L
.8745 .01472 L
.8752 .01472 L
.87594 .01472 L
.87719 .01472 L
.87833 .01472 L
.87965 .01472 L
.8809 .01472 L
.88206 .01472 L
.88315 .01472 L
.88441 .01472 L
.88555 .01472 L
.88681 .01472 L
.88752 .01472 L
.88817 .01472 L
.88935 .01472 L
.8906 .01472 L
.89126 .01472 L
.89196 .01472 L
.89323 .01472 L
.89401 .01472 L
.89474 .01472 L
.8954 .01472 L
.89611 .01472 L
.89734 .01472 L
.89846 .01472 L
Mistroke
.89975 .01472 L
.90098 .01472 L
.90211 .01472 L
.90316 .01472 L
.90431 .01472 L
.90554 .01472 L
.90619 .01472 L
.90689 .01472 L
.90765 .01472 L
.90834 .01472 L
.9096 .01472 L
.91032 .01472 L
.91099 .01472 L
.91224 .01472 L
.91337 .01472 L
.91469 .01472 L
.91593 .01472 L
.91724 .01472 L
.91846 .01472 L
.91974 .01472 L
.92042 .01472 L
.92116 .01472 L
.92239 .01472 L
.92368 .01472 L
.92479 .01472 L
.926 .01472 L
.92674 .01472 L
.92743 .01472 L
.92874 .01472 L
.92947 .01472 L
.93015 .01472 L
.93089 .01472 L
.93167 .01472 L
.93297 .01472 L
.93419 .01472 L
.93488 .01472 L
.93552 .01472 L
.93626 .01472 L
.93695 .01472 L
.9382 .01472 L
.9389 .01472 L
.93955 .01472 L
.94074 .01472 L
.94199 .01472 L
.94312 .01472 L
.94417 .01472 L
.94532 .01472 L
.94655 .01472 L
.94787 .01472 L
.94862 .01472 L
Mistroke
.9493 .01472 L
.95057 .01472 L
.95121 .01472 L
.95191 .01472 L
.9531 .01472 L
.95422 .01472 L
.95487 .01472 L
.95556 .01472 L
.95678 .01472 L
.95794 .01472 L
.95898 .01472 L
.96019 .01472 L
.96133 .01472 L
.96239 .01472 L
.96337 .01472 L
.96444 .01472 L
.96557 .01472 L
.96671 .01472 L
.96793 .01472 L
.96909 .01472 L
.97014 .01472 L
.97138 .01472 L
.97208 .01472 L
.97273 .01472 L
.97391 .01472 L
.97517 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.12507 .01472 L
.13506 .01472 L
.14415 .01472 L
.14868 .01472 L
.1536 .01472 L
.15586 .01472 L
.15709 .01472 L
.15825 .01472 L
.15923 .01472 L
.16029 .01472 L
.16146 .01472 L
.16254 .01472 L
.16375 .01472 L
.16504 .01472 L
.16626 .01472 L
.16736 .01472 L
.16866 .01472 L
.1694 .01472 L
.17007 .01472 L
.17131 .01472 L
.17262 .01472 L
.17376 .01472 L
.17499 .01472 L
.17719 .01473 L
.17854 .01473 L
.17982 .01473 L
.18221 .01474 L
.18457 .01476 L
.1868 .01478 L
.18923 .0148 L
.19186 .01484 L
.19447 .01489 L
.19721 .01495 L
.20212 .0151 L
.20667 .01529 L
.21091 .01553 L
.21557 .01587 L
.22054 .01633 L
.22587 .01698 L
.23078 .01774 L
.23607 .01874 L
.24188 .02012 L
.25167 .0232 L
.26204 .02774 L
.2722 .03374 L
.28148 .04086 L
.2922 .05137 L
Mistroke
.30238 .064 L
.32222 .09746 L
.34062 .1399 L
.3798 .26475 L
.42144 .42582 L
.44234 .50094 L
.45151 .52926 L
.46156 .55584 L
.47128 .57643 L
.48034 .5906 L
.48535 .59623 L
.48991 .59995 L
.49243 .60142 L
.49386 .60207 L
.49518 .60255 L
.49633 .60287 L
.49759 .60313 L
.49823 .60322 L
.49892 .60328 L
.50016 .60332 L
.50142 .60325 L
.50256 .6031 L
.50389 .60282 L
.50513 .60245 L
.50735 .60153 L
.50975 .60017 L
.51241 .59823 L
.51521 .59568 L
.52024 .58985 L
.5303 .57346 L
.54135 .54868 L
.56084 .49034 L
.58174 .41358 L
.62307 .25427 L
.64374 .18457 L
.66288 .13095 L
.68145 .09034 L
.69094 .07391 L
.70118 .05927 L
.71132 .04762 L
.72063 .03909 L
.72946 .03265 L
.7389 .02727 L
.74869 .02307 L
.7578 .02021 L
.76337 .01886 L
.76864 .01784 L
.77333 .0171 L
.77849 .01644 L
.7835 .01594 L
Mistroke
.7882 .01558 L
.79315 .0153 L
.7957 .01518 L
.79848 .01507 L
.80104 .01499 L
.80342 .01493 L
.80588 .01488 L
.80812 .01484 L
.81016 .01481 L
.81238 .01479 L
.81472 .01476 L
.81693 .01475 L
.8193 .01474 L
.82063 .01473 L
.82185 .01473 L
.82298 .01473 L
.82421 .01472 L
.82536 .01472 L
.82644 .01472 L
.82769 .01472 L
.82841 .01472 L
.82907 .01472 L
.83042 .01472 L
.83112 .01472 L
.83186 .01472 L
.83311 .01472 L
.83426 .01472 L
.83553 .01472 L
.83624 .01472 L
.83688 .01472 L
.83819 .01472 L
.83886 .01472 L
.83959 .01472 L
.84088 .01472 L
.84208 .01472 L
.84281 .01472 L
.8435 .01472 L
.8448 .01472 L
.84553 .01472 L
.8462 .01472 L
.84694 .01472 L
.84772 .01472 L
.84841 .01472 L
.84905 .01472 L
.84975 .01472 L
.85049 .01472 L
.85173 .01472 L
.85243 .01472 L
.85309 .01472 L
.85432 .01472 L
Mistroke
.85544 .01472 L
.85673 .01472 L
.85795 .01472 L
.8591 .01472 L
.86033 .01472 L
.86149 .01472 L
.86256 .01472 L
.8638 .01472 L
.86451 .01472 L
.86516 .01472 L
.86636 .01472 L
.86764 .01472 L
.86833 .01472 L
.86897 .01472 L
.86967 .01472 L
.87041 .01472 L
.87166 .01472 L
.87237 .01472 L
.87303 .01472 L
.87426 .01472 L
.87538 .01472 L
.87668 .01472 L
.87791 .01472 L
.87897 .01472 L
.88014 .01472 L
.88135 .01472 L
.8825 .01472 L
.88356 .01472 L
.88454 .01472 L
.88561 .01472 L
.88674 .01472 L
.88789 .01472 L
.88912 .01472 L
.89028 .01472 L
.89133 .01472 L
.89257 .01472 L
.89327 .01472 L
.89391 .01472 L
.8951 .01472 L
.89635 .01472 L
.89756 .01472 L
.89888 .01472 L
.90012 .01472 L
.90128 .01472 L
.90239 .01472 L
.9036 .01472 L
.90474 .01472 L
.90578 .01472 L
.90703 .01472 L
.90836 .01472 L
Mistroke
.90947 .01472 L
.91069 .01472 L
.91199 .01472 L
.91273 .01472 L
.91339 .01472 L
.91469 .01472 L
.91592 .01472 L
.91697 .01472 L
.91813 .01472 L
.91934 .01472 L
.92048 .01472 L
.92153 .01472 L
.9225 .01472 L
.92357 .01472 L
.92469 .01472 L
.92583 .01472 L
.92705 .01472 L
.9282 .01472 L
.92925 .01472 L
.93048 .01472 L
.93112 .01472 L
.93181 .01472 L
.93307 .01472 L
.93423 .01472 L
.93544 .01472 L
.93676 .01472 L
.93801 .01472 L
.93917 .01472 L
.94021 .01472 L
.94136 .01472 L
.94255 .01472 L
.94368 .01472 L
.94492 .01472 L
.94623 .01472 L
.94734 .01472 L
.94856 .01472 L
.94988 .01472 L
.95062 .01472 L
.95129 .01472 L
.9526 .01472 L
.95383 .01472 L
.95489 .01472 L
.95605 .01472 L
.95726 .01472 L
.9584 .01472 L
.95946 .01472 L
.96043 .01472 L
.96155 .01472 L
.96262 .01472 L
.96376 .01472 L
Mistroke
.96498 .01472 L
.96613 .01472 L
.96718 .01472 L
.96841 .01472 L
.9691 .01472 L
.96974 .01472 L
.97091 .01472 L
.97215 .01472 L
.97316 .01472 L
.97424 .01472 L
.97526 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.27193 .01472 L
.28302 .01472 L
.2881 .01472 L
.29088 .01472 L
.29349 .01472 L
.29462 .01472 L
.2957 .01472 L
.29695 .01472 L
.29809 .01472 L
.29934 .01472 L
.30051 .01472 L
.30179 .01472 L
.30251 .01472 L
.30316 .01472 L
.30436 .01472 L
.30548 .01472 L
.30671 .01472 L
.30803 .01472 L
.30941 .01472 L
.31072 .01472 L
.3119 .01472 L
.31318 .01473 L
.3155 .01473 L
.31668 .01474 L
.31797 .01474 L
.32026 .01476 L
.3224 .01477 L
.32495 .0148 L
.32763 .01484 L
.33242 .01493 L
.33509 .015 L
.33758 .01508 L
.34322 .01531 L
.34827 .01561 L
.35374 .01605 L
.35891 .0166 L
.36368 .01723 L
.37271 .01887 L
.37726 .01995 L
.38227 .02136 L
.39243 .02508 L
.40171 .02969 L
.41243 .03674 L
Mistroke
.42261 .0455 L
.43222 .05596 L
.44245 .0698 L
.46085 .10273 L
.4823 .1551 L
.50249 .21752 L
.54109 .36177 L
.56067 .43793 L
.58214 .51294 L
.59203 .5417 L
.60261 .5671 L
.60774 .57717 L
.61259 .58527 L
.61728 .59172 L
.62168 .5965 L
.62629 .60016 L
.62873 .60154 L
.62999 .6021 L
.63136 .60259 L
.63202 .60278 L
.63272 .60295 L
.63398 .60318 L
.63472 .60326 L
.63542 .60331 L
.63672 .6033 L
.63795 .6032 L
.63908 .60302 L
.64032 .60272 L
.64163 .60229 L
.64382 .60132 L
.64617 .59993 L
.65042 .59651 L
.65546 .59092 L
.66007 .58443 L
.66996 .56612 L
.67913 .54423 L
.69988 .48005 L
.73911 .32999 L
.77683 .19388 L
.79778 .13387 L
.817 .09128 L
.83582 .0611 L
.84529 .0498 L
.85566 .03994 L
.86592 .03239 L
.87524 .02712 L
.88601 .02262 L
.89086 .02105 L
.89619 .01961 L
.90589 .01763 L
Mistroke
.9112 .01685 L
.91618 .01627 L
.92073 .01585 L
.92506 .01553 L
.93006 .01526 L
.93462 .01507 L
.93721 .01499 L
.93965 .01493 L
.94422 .01484 L
.94678 .0148 L
.94913 .01478 L
.95171 .01476 L
.95444 .01474 L
.95663 .01473 L
.95784 .01473 L
.95898 .01473 L
.96004 .01472 L
.96119 .01472 L
.96223 .01472 L
.96321 .01472 L
.96436 .01472 L
.96564 .01472 L
.96688 .01472 L
.96757 .01472 L
.96821 .01472 L
.96929 .01472 L
.97046 .01472 L
.97169 .01472 L
.97283 .01472 L
.97374 .01472 L
.97459 .01472 L
.97536 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "We can evaluate the overlap integral numerically using ",
  StyleBox["Mathematica", "TI"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.19"}],

Cell[CellGroupData[{

Cell["\<\
NIntegrate[Evaluate[BSpline[4, t] BSpline[4, t-1]],
{t, -2, 4}]\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(0.243149258327107586`\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell["Spline Multiresolution Analyses", "Subsubsection",
  CellTags->{"S1.3.1", "1.20"}],

Cell[TextData[{
  "Starting from the space of spline functions of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", we can build a multiresolution analysis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". Let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " be the space containing functions of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " that are square\[Hyphen]integrable. That is, if ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] L\^2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a polynomial of degree not exceeding ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in each interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([k, k + 1)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " integer), and its first ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " derivatives are continuous with possible discontinuities in higher \
derivatives occurring only at the integers. The space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is then the space containing square\[Hyphen]integrable polynomial \
functions of degree at most ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " on each half intervals with the first ",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " derivatives continuous. Therefore, we obviously have ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0 \[Subset] V\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". We can show that there is a nested sequence of subspaces of ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and conditions (i) to (iv) for ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " to be a multiresolution analysis are satisfied (see Section ",
  ButtonBox["1.2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  "). Now it remains to be shown that there exists a scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " forms an orthonormal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". In fact, we already have a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_n\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". All we need to do is to use the orthogonalization trick to make it \
orthogonal. In addition, since ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0 \[Subset] V\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", we can express ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in terms of the basis of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_n\) \((2  t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". In fact, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " satisfies the following two\[Hyphen]scale equation:"
}], "Text",
  CellTags->{"S1.3.1", "1.21"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Beta]\_n\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox[
                  RowBox[{\(1\/2\^n\), 
                    UnderoverscriptBox["\[Sum]", \(j = 0\), \(n + 1\),
                      LimitsPositioning->True], 
                    RowBox[{"(", GridBox[{
                          {
                            StyleBox[\(n + 1\),
                              "DisplayFormula"]},
                          {
                            StyleBox["j",
                              "DisplayFormula"]}
                          },
                        ColumnAlignments->{Center}], ")"}], \(\[Beta]\_n\), 
                    \((2 t + n/2 - j)\)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" for "\), 
                    StyleBox["n",
                      "DisplayFormula"], \(" even"\)}],
                  "DisplayFormula"]},
              {
                StyleBox[
                  RowBox[{\(1\/2\^n\), 
                    UnderoverscriptBox["\[Sum]", \(j = 0\), \(n + 1\),
                      LimitsPositioning->True], 
                    RowBox[{"(", GridBox[{
                          {
                            StyleBox[\(n + 1\),
                              "DisplayFormula"]},
                          {
                            StyleBox["j",
                              "DisplayFormula"]}
                          },
                        ColumnAlignments->{Center}], ")"}], \(\[Beta]\_n\), 
                    \((2 t + \((n + 1)\)/2 - j)\)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{
                    RowBox[{\(" for "\), 
                      StyleBox["n",
                        "DisplayFormula"], \(" odd"\)}], "."}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.22"}],

Cell[TextData[{
  "For example, for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " we have "
}], "Text",
  CellTags->{"S1.3.1", "1.23"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Beta]\_1\) \((t)\) = \(1\/2\) \(\[InvisibleSpace]\([
      \(\[Beta]\_1\) \((2  t + 1)\) + 2 \( \[Beta]\_1\) \((2  t)\) + 
        \(\[Beta]\_1\) \((2  t - 1)\)]\)\)\)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.24"}],

Cell[TextData[{
  "and for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", "
}], "Text",
  CellTags->{"S1.3.1", "1.25"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Beta]\_2\) \((t)\) = \(1\/4\) \(\[InvisibleSpace]\([
      \(\[Beta]\_2\) \((2  t + 1)\) + 3 \( \[Beta]\_2\) \((2  t)\) + 3 
        \( \[Beta]\_2\) \((2  t - 1)\) + \(\[Beta]\_2\) \((2  t - 2)\)]\)\).
      \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.26"}],

Cell[TextData[{
  "The two\[Hyphen]scale relation (",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 1.3.1", "1.22"},
    ButtonStyle->"AddOnsLink"],
  ") can be seen clearly by plotting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\_n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " at scale ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2  t\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " together. For example, we can write a function ",
  StyleBox["plotTwoScaleBeta[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " that plots the two\[Hyphen]scale relation for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function. "
}], "Text",
  CellTags->{"S1.3.1", "1.27"}],

Cell[TextData[{
  "This defines a function that plots the two\[Hyphen]scale relation of ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline functions."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.28"}],

Cell["\<\
plotTwoScaleBeta[n_]:= Plot[Evaluate[{BSpline[n, t],
Table[Binomial[n+1, j]BSpline[n, 2t+Floor[(n+1)/2]-j],
{j, 0, n+1}]/2^n}], {t, -Floor[(n+1)/2], Floor[n/2]+1},
PlotStyle -> ({{}, ##}& @@ Table[Dashing[{0.02}],
{n+2}]), PlotRange -> All, PlotLabel ->
\"Two-scale relation for B-spline order \"<>ToString[n]]\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "The following two graphs show the two\[Hyphen]scale relation for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 3\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". The solid line is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and it is the sum of the dashed curves that are translated versions of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " multiplied by the appropriate coefficients. "
}], "Text",
  CellTags->{"S1.3.1", "1.29"}],

Cell[TextData[{
  "This shows the two\[Hyphen]scale relation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_2\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.30"}],

Cell[CellGroupData[{

Cell["plotTwoScaleBeta[2]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.0147151 0.784805 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.18254 .00222 -12 -9 ]
[.18254 .00222 12 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.32877 .0932 -18 -4.5 ]
[.32877 .0932 0 4.5 ]
[.32877 .17168 -18 -4.5 ]
[.32877 .17168 0 4.5 ]
[.32877 .25016 -18 -4.5 ]
[.32877 .25016 0 4.5 ]
[.32877 .32864 -18 -4.5 ]
[.32877 .32864 0 4.5 ]
[.32877 .40712 -18 -4.5 ]
[.32877 .40712 0 4.5 ]
[.32877 .4856 -18 -4.5 ]
[.32877 .4856 0 4.5 ]
[.32877 .56408 -18 -4.5 ]
[.32877 .56408 0 4.5 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-0.5)] .18254 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(1)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(1.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.34127 .0932 m
.34752 .0932 L
s
[(0.1)] .32877 .0932 1 0 Mshowa
.34127 .17168 m
.34752 .17168 L
s
[(0.2)] .32877 .17168 1 0 Mshowa
.34127 .25016 m
.34752 .25016 L
s
[(0.3)] .32877 .25016 1 0 Mshowa
.34127 .32864 m
.34752 .32864 L
s
[(0.4)] .32877 .32864 1 0 Mshowa
.34127 .40712 m
.34752 .40712 L
s
[(0.5)] .32877 .40712 1 0 Mshowa
.34127 .4856 m
.34752 .4856 L
s
[(0.6)] .32877 .4856 1 0 Mshowa
.34127 .56408 m
.34752 .56408 L
s
[(0.7)] .32877 .56408 1 0 Mshowa
.125 Mabswid
.34127 .03041 m
.34502 .03041 L
s
.34127 .04611 m
.34502 .04611 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0775 m
.34502 .0775 L
s
.34127 .10889 m
.34502 .10889 L
s
.34127 .12459 m
.34502 .12459 L
s
.34127 .14028 m
.34502 .14028 L
s
.34127 .15598 m
.34502 .15598 L
s
.34127 .18737 m
.34502 .18737 L
s
.34127 .20307 m
.34502 .20307 L
s
.34127 .21876 m
.34502 .21876 L
s
.34127 .23446 m
.34502 .23446 L
s
.34127 .26585 m
.34502 .26585 L
s
.34127 .28155 m
.34502 .28155 L
s
.34127 .29724 m
.34502 .29724 L
s
.34127 .31294 m
.34502 .31294 L
s
.34127 .34433 m
.34502 .34433 L
s
.34127 .36003 m
.34502 .36003 L
s
.34127 .37573 m
.34502 .37573 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .42281 m
.34502 .42281 L
s
.34127 .43851 m
.34502 .43851 L
s
.34127 .45421 m
.34502 .45421 L
s
.34127 .4699 m
.34502 .4699 L
s
.34127 .50129 m
.34502 .50129 L
s
.34127 .51699 m
.34502 .51699 L
s
.34127 .53269 m
.34502 .53269 L
s
.34127 .54838 m
.34502 .54838 L
s
.34127 .57977 m
.34502 .57977 L
s
.34127 .59547 m
.34502 .59547 L
s
.34127 .61117 m
.34502 .61117 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(Two-scale relation for B-spline order 2)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01473 L
.02729 .01476 L
.02846 .0148 L
.03053 .01489 L
.03279 .01503 L
.03527 .01523 L
.0379 .01549 L
.04262 .01609 L
.04749 .0169 L
.05205 .01782 L
.06244 .02053 L
.07305 .02415 L
.08274 .02824 L
.10458 .04012 L
.12357 .05346 L
.14429 .07123 L
.18493 .1158 L
.22406 .17086 L
.26565 .24243 L
.30571 .32414 L
.34426 .41445 L
.36381 .45888 L
.38527 .50081 L
.40592 .5344 L
.42475 .55923 L
.44426 .57913 L
.455 .58755 L
.46518 .59388 L
.47483 .59839 L
.47971 .60011 L
.48509 .60159 L
.48966 .60249 L
.49223 .60285 L
.49345 .60299 L
.49459 .60309 L
.49568 .60317 L
.49666 .60323 L
.49776 .60328 L
.49893 .60331 L
.50006 .60332 L
.50129 .60331 L
.50244 .60327 L
.50351 .60322 L
.50476 .60314 L
.50595 .60304 L
.50818 .6028 L
.51058 .60245 L
.5132 .60196 L
Mistroke
.51791 .60082 L
.52227 .59946 L
.53227 .59521 L
.54291 .58898 L
.55322 .58126 L
.56436 .57106 L
.58454 .54766 L
.6256 .48047 L
.66514 .39143 L
.70316 .30496 L
.74364 .22528 L
.7826 .16064 L
.82401 .10488 L
.84475 .08198 L
.86391 .0638 L
.88372 .04801 L
.90229 .03598 L
.921 .02658 L
.93092 .02269 L
.94161 .01937 L
.94967 .01745 L
.95428 .01658 L
.95847 .01594 L
.96291 .0154 L
.96535 .01517 L
.96765 .015 L
.96979 .01487 L
.97175 .01479 L
.97278 .01476 L
.97391 .01474 L
.97509 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01473 L
.02729 .01476 L
.02846 .0148 L
.03053 .01489 L
.03279 .01503 L
.03527 .01523 L
.0379 .01549 L
.04262 .01609 L
.04749 .0169 L
.05205 .01782 L
.06244 .02053 L
.07305 .02415 L
.08274 .02824 L
.10458 .04012 L
.12357 .05346 L
.14429 .07123 L
.18493 .11573 L
.20373 .13551 L
.21362 .14371 L
.22406 .15072 L
.22938 .15363 L
.23522 .15632 L
.24058 .15833 L
.24547 .15976 L
.25051 .16085 L
.25328 .16129 L
.25455 .16145 L
.25591 .16159 L
.25706 .16168 L
.25833 .16177 L
.25949 .16182 L
.26057 .16185 L
.26185 .16187 L
.26301 .16186 L
.2643 .16182 L
.26494 .16179 L
.26565 .16176 L
.26697 .16167 L
.26818 .16156 L
.27093 .16123 L
.27335 .16085 L
.27592 .16034 L
.28037 .15921 L
.28526 .15762 L
.29608 .15277 L
.30621 .14658 L
.32649 .12938 L
.34503 .10822 L
Mistroke
.38479 .06639 L
.40486 .04996 L
.42304 .03778 L
.44275 .02748 L
.45356 .02311 L
.46373 .01984 L
.47352 .01744 L
.47845 .01652 L
.48385 .01573 L
.48847 .01523 L
.49106 .01503 L
.49342 .01488 L
.49448 .01483 L
.49561 .01479 L
.49686 .01475 L
.498 .01473 L
.49907 .01472 L
.50006 .01472 L
.50116 .01472 L
.50234 .01472 L
.5036 .01472 L
.50474 .01472 L
.50607 .01472 L
.50731 .01472 L
.50847 .01472 L
.50953 .01472 L
.5107 .01472 L
.51193 .01472 L
.51318 .01472 L
.51388 .01472 L
.51452 .01472 L
.51575 .01472 L
.51693 .01472 L
.51759 .01472 L
.51829 .01472 L
.51956 .01472 L
.52026 .01472 L
.52092 .01472 L
.52164 .01472 L
.52242 .01472 L
.52306 .01472 L
.52374 .01472 L
.52498 .01472 L
.52573 .01472 L
.52644 .01472 L
.52708 .01472 L
.52778 .01472 L
.52846 .01472 L
.5292 .01472 L
.52998 .01472 L
Mistroke
.53072 .01472 L
.53202 .01472 L
.53276 .01472 L
.53343 .01472 L
.53471 .01472 L
.5359 .01472 L
.53721 .01472 L
.53794 .01472 L
.53861 .01472 L
.54353 .01472 L
.54605 .01472 L
.54729 .01472 L
.54841 .01472 L
.5496 .01472 L
.55087 .01472 L
.55155 .01472 L
.55227 .01472 L
.55356 .01472 L
.55464 .01472 L
.55583 .01472 L
.55711 .01472 L
.5583 .01472 L
.55934 .01472 L
.56045 .01472 L
.56166 .01472 L
.56279 .01472 L
.56348 .01472 L
.56413 .01472 L
.56534 .01472 L
.56663 .01472 L
.56735 .01472 L
.56802 .01472 L
.56913 .01472 L
.57035 .01472 L
.57162 .01472 L
.57282 .01472 L
.57348 .01472 L
.57421 .01472 L
.5749 .01472 L
.57554 .01472 L
.57674 .01472 L
.57802 .01472 L
.57875 .01472 L
.57954 .01472 L
.58028 .01472 L
.58096 .01472 L
.58225 .01472 L
.5829 .01472 L
.58362 .01472 L
.58493 .01472 L
Mistroke
.58614 .01472 L
.58677 .01472 L
.58747 .01472 L
.5882 .01472 L
.58888 .01472 L
.59013 .01472 L
.59128 .01472 L
.5926 .01472 L
.59386 .01472 L
.59498 .01472 L
.59617 .01472 L
.59729 .01472 L
.59831 .01472 L
.59952 .01472 L
.60082 .01472 L
.60205 .01472 L
.60318 .01472 L
.60439 .01472 L
.60569 .01472 L
.60691 .01472 L
.60803 .01472 L
.60934 .01472 L
.61003 .01472 L
.61076 .01472 L
.6114 .01472 L
.61211 .01472 L
.61336 .01472 L
.61403 .01472 L
.61475 .01472 L
.61603 .01472 L
.61674 .01472 L
.6174 .01472 L
.61813 .01472 L
.6189 .01472 L
.61958 .01472 L
.62031 .01472 L
.621 .01472 L
.62163 .01472 L
.62284 .01472 L
.62411 .01472 L
.62532 .01472 L
.62664 .01472 L
.62788 .01472 L
.62904 .01472 L
.63018 .01472 L
.63122 .01472 L
.63235 .01472 L
.63354 .01472 L
.63485 .01472 L
.63605 .01472 L
Mistroke
.63735 .01472 L
.63808 .01472 L
.63876 .01472 L
.64001 .01472 L
.64114 .01472 L
.64244 .01472 L
.64368 .01472 L
.64482 .01472 L
.64589 .01472 L
.64701 .01472 L
.64824 .01472 L
.6493 .01472 L
.65027 .01472 L
.65133 .01472 L
.65245 .01472 L
.65359 .01472 L
.65481 .01472 L
.65596 .01472 L
.65701 .01472 L
.65824 .01472 L
.65893 .01472 L
.65957 .01472 L
.66075 .01472 L
.66199 .01472 L
.6632 .01472 L
.66452 .01472 L
.66577 .01472 L
.66693 .01472 L
.66797 .01472 L
.66912 .01472 L
.67032 .01472 L
.67144 .01472 L
.67268 .01472 L
.67399 .01472 L
.6751 .01472 L
.67632 .01472 L
.67764 .01472 L
.67838 .01472 L
.67905 .01472 L
.68036 .01472 L
.68159 .01472 L
.68265 .01472 L
.68381 .01472 L
.68502 .01472 L
.68616 .01472 L
.68722 .01472 L
.68819 .01472 L
.68931 .01472 L
.69038 .01472 L
.69152 .01472 L
Mistroke
.69274 .01472 L
.69389 .01472 L
.69494 .01472 L
.69617 .01472 L
.69686 .01472 L
.6975 .01472 L
.69867 .01472 L
.69991 .01472 L
.70113 .01472 L
.70182 .01472 L
.70246 .01472 L
.70363 .01472 L
.70487 .01472 L
.70598 .01472 L
.70702 .01472 L
.70817 .01472 L
.7094 .01472 L
.71063 .01472 L
.71133 .01472 L
.71198 .01472 L
.71329 .01472 L
.71403 .01472 L
.7147 .01472 L
.71956 .01472 L
.72069 .01472 L
.72176 .01472 L
.72287 .01472 L
.72408 .01472 L
.72532 .01472 L
.72664 .01472 L
.72787 .01472 L
.72899 .01472 L
.73005 .01472 L
.73118 .01472 L
.73241 .01472 L
.73356 .01472 L
.73473 .01472 L
.73583 .01472 L
.73682 .01472 L
.73789 .01472 L
.73914 .01472 L
.74028 .01472 L
.74159 .01472 L
.74283 .01472 L
.74397 .01472 L
.74503 .01472 L
.7462 .01472 L
.74743 .01472 L
.74866 .01472 L
.74936 .01472 L
Mistroke
.74999 .01472 L
.75123 .01472 L
.7524 .01472 L
.75306 .01472 L
.75376 .01472 L
.75502 .01472 L
.75579 .01472 L
.75652 .01472 L
.75717 .01472 L
.75788 .01472 L
.75919 .01472 L
.76042 .01472 L
.76112 .01472 L
.76177 .01472 L
.76251 .01472 L
.76321 .01472 L
.76389 .01472 L
.76461 .01472 L
.76591 .01472 L
.76658 .01472 L
.76731 .01472 L
.76811 .01472 L
.76885 .01472 L
.77008 .01472 L
.77077 .01472 L
.77142 .01472 L
.77273 .01472 L
.77346 .01472 L
.77412 .01472 L
.77531 .01472 L
.77661 .01472 L
.77896 .01472 L
.78131 .01472 L
.78261 .01472 L
.78384 .01472 L
.78498 .01472 L
.78623 .01472 L
.78736 .01472 L
.78841 .01472 L
.78906 .01472 L
.78977 .01472 L
.79105 .01472 L
.7923 .01472 L
.79345 .01472 L
.79469 .01472 L
.7954 .01472 L
.79606 .01472 L
.79675 .01472 L
.79739 .01472 L
.79812 .01472 L
Mistroke
.79881 .01472 L
.80002 .01472 L
.80071 .01472 L
.80135 .01472 L
.80265 .01472 L
.80338 .01472 L
.80405 .01472 L
.80518 .01472 L
.80641 .01472 L
.8077 .01472 L
.80889 .01472 L
.80958 .01472 L
.81032 .01472 L
.81102 .01472 L
.81167 .01472 L
.8129 .01472 L
.81419 .01472 L
.81487 .01472 L
.81559 .01472 L
.81689 .01472 L
.81768 .01472 L
.81844 .01472 L
.81911 .01472 L
.81985 .01472 L
.8205 .01472 L
.82119 .01472 L
.82242 .01472 L
.82374 .01472 L
.82449 .01472 L
.82519 .01472 L
.82646 .01472 L
.82762 .01472 L
.83021 .01472 L
.83133 .01472 L
.83252 .01472 L
.83382 .01472 L
.83503 .01472 L
.83615 .01472 L
.8372 .01472 L
.83835 .01472 L
.83958 .01472 L
.84026 .01472 L
.84098 .01472 L
.84227 .01472 L
.843 .01472 L
.84378 .01472 L
.84446 .01472 L
.8452 .01472 L
.84591 .01472 L
.84666 .01472 L
Mistroke
.84736 .01472 L
.848 .01472 L
.84923 .01472 L
.85055 .01472 L
.85184 .01472 L
.85256 .01472 L
.85324 .01472 L
.85448 .01472 L
.85579 .01472 L
.85696 .01472 L
.85807 .01472 L
.85927 .01472 L
.86058 .01472 L
.86183 .01472 L
.86297 .01472 L
.86429 .01472 L
.86553 .01472 L
.86668 .01472 L
.86775 .01472 L
.86891 .01472 L
.87014 .01472 L
.87139 .01472 L
.87208 .01472 L
.87272 .01472 L
.87396 .01472 L
.87513 .01472 L
.87579 .01472 L
.87649 .01472 L
.87775 .01472 L
.87853 .01472 L
.87925 .01472 L
.87991 .01472 L
.88061 .01472 L
.88193 .01472 L
.88317 .01472 L
.88387 .01472 L
.88452 .01472 L
.88526 .01472 L
.88596 .01472 L
.88665 .01472 L
.88737 .01472 L
.88867 .01472 L
.88939 .01472 L
.89007 .01472 L
.89081 .01472 L
.89161 .01472 L
.89284 .01472 L
.89353 .01472 L
.89418 .01472 L
.89549 .01472 L
Mistroke
.89622 .01472 L
.89688 .01472 L
.89808 .01472 L
.89937 .01472 L
.90059 .01472 L
.90171 .01472 L
.90297 .01472 L
.90416 .01472 L
.90523 .01472 L
.9064 .01472 L
.90766 .01472 L
.9083 .01472 L
.90901 .01472 L
.91027 .01472 L
.91143 .01472 L
.91253 .01472 L
.91368 .01472 L
.91494 .01472 L
.91611 .01472 L
.91712 .01472 L
.91821 .01472 L
.91941 .01472 L
.92051 .01472 L
.92179 .01472 L
.9225 .01472 L
.92316 .01472 L
.92432 .01472 L
.9256 .01472 L
.92631 .01472 L
.92699 .01472 L
.92826 .01472 L
.92897 .01472 L
.92963 .01472 L
.93036 .01472 L
.93113 .01472 L
.93243 .01472 L
.93316 .01472 L
.93384 .01472 L
.93508 .01472 L
.93639 .01472 L
.93757 .01472 L
.93867 .01472 L
.93987 .01472 L
.94116 .01472 L
.94219 .01472 L
.94333 .01472 L
.94452 .01472 L
.94564 .01472 L
.94668 .01472 L
.94763 .01472 L
Mistroke
.94868 .01472 L
.94978 .01472 L
.9509 .01472 L
.9521 .01472 L
.95323 .01472 L
.95426 .01472 L
.95547 .01472 L
.95678 .01472 L
.95801 .01472 L
.95915 .01472 L
.96014 .01472 L
.96119 .01472 L
.96219 .01472 L
.9631 .01472 L
.96416 .01472 L
.96532 .01472 L
.96642 .01472 L
.96743 .01472 L
.96858 .01472 L
.96966 .01472 L
.97063 .01472 L
.97167 .01472 L
.97282 .01472 L
.97403 .01472 L
.97506 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.16408 .01472 L
.17277 .01472 L
.17735 .01472 L
.17986 .01472 L
.18109 .01472 L
.18221 .01472 L
.18341 .01472 L
.1847 .01477 L
.18537 .01481 L
.1861 .01486 L
.18744 .015 L
.18865 .01515 L
.18994 .01536 L
.19227 .01582 L
.19484 .01648 L
.19726 .01725 L
.20178 .01904 L
.20702 .02171 L
.21184 .02474 L
.22272 .03357 L
.23245 .04382 L
.24154 .05538 L
.2622 .08885 L
.28256 .13156 L
.30111 .17894 L
.34096 .30786 L
.35918 .36793 L
.36955 .3952 L
.37929 .41623 L
.3888 .4325 L
.39906 .4453 L
.4044 .45001 L
.40731 .45202 L
.41002 .45354 L
.41234 .45456 L
.41482 .45538 L
.41624 .45572 L
.41693 .45585 L
.41757 .45595 L
.41877 .45609 L
.42007 .45616 L
.42132 .45616 L
.42251 .45609 L
.42358 .45597 L
.42474 .45577 L
.426 .45549 L
Mistroke
.42735 .45512 L
.42976 .45422 L
.43222 .45303 L
.43452 .45166 L
.43883 .44843 L
.444 .44341 L
.44875 .4377 L
.45947 .42093 L
.46923 .40099 L
.47834 .37839 L
.49901 .31266 L
.53797 .18505 L
.55782 .13365 L
.57939 .08825 L
.60012 .05484 L
.61001 .04244 L
.61928 .03289 L
.62829 .02554 L
.63799 .01974 L
.64323 .01752 L
.64587 .01665 L
.64875 .01588 L
.65122 .01537 L
.65258 .01516 L
.65386 .01499 L
.65505 .01487 L
.65634 .01478 L
.65752 .01473 L
.6586 .01472 L
.65986 .01472 L
.66105 .01472 L
.66213 .01472 L
.66329 .01472 L
.66456 .01472 L
.6652 .01472 L
.6659 .01472 L
.66715 .01472 L
.66832 .01472 L
.6774 .01472 L
.69806 .01472 L
.70787 .01472 L
.7092 .01472 L
.71046 .01472 L
.71116 .01472 L
.71191 .01472 L
.71323 .01472 L
.71449 .01472 L
.71512 .01472 L
.71582 .01472 L
.71706 .01472 L
Mistroke
.71822 .01472 L
.71936 .01472 L
.72044 .01472 L
.72141 .01472 L
.72247 .01472 L
.72362 .01472 L
.72484 .01472 L
.726 .01472 L
.72705 .01472 L
.72829 .01472 L
.72944 .01472 L
.7307 .01472 L
.73133 .01472 L
.73202 .01472 L
.7332 .01472 L
.73445 .01472 L
.73563 .01472 L
.73671 .01472 L
.73789 .01472 L
.739 .01472 L
.74022 .01472 L
.74153 .01472 L
.74283 .01472 L
.74348 .01472 L
.74419 .01472 L
.74546 .01472 L
.74664 .01472 L
.74783 .01472 L
.74896 .01472 L
.74998 .01472 L
.75107 .01472 L
.75227 .01472 L
.75354 .01472 L
.75462 .01472 L
.75581 .01472 L
.75648 .01472 L
.7572 .01472 L
.75852 .01472 L
.7598 .01472 L
.76099 .01472 L
.76172 .01472 L
.7624 .01472 L
.76368 .01472 L
.7644 .01472 L
.76506 .01472 L
.76578 .01472 L
.76654 .01472 L
.76774 .01472 L
.76902 .01472 L
.77023 .01472 L
Mistroke
.77133 .01472 L
.77383 .01472 L
.77515 .01472 L
.77588 .01472 L
.77658 .01472 L
.77788 .01472 L
.77907 .01472 L
.78019 .01472 L
.78141 .01472 L
.78269 .01472 L
.78341 .01472 L
.78406 .01472 L
.78533 .01472 L
.78653 .01472 L
.78764 .01472 L
.78883 .01472 L
.78983 .01472 L
.79094 .01472 L
.79213 .01472 L
.79341 .01472 L
.79462 .01472 L
.79572 .01472 L
.797 .01472 L
.79765 .01472 L
.79837 .01472 L
.79964 .01472 L
.80083 .01472 L
.80156 .01472 L
.80224 .01472 L
.80295 .01472 L
.80373 .01472 L
.80501 .01472 L
.80573 .01472 L
.80639 .01472 L
.80759 .01472 L
.80889 .01472 L
.81012 .01472 L
.81125 .01472 L
.81246 .01472 L
.81315 .01472 L
.8138 .01472 L
.8151 .01472 L
.81583 .01472 L
.8165 .01472 L
.81779 .01472 L
.819 .01472 L
.82009 .01472 L
.82127 .01472 L
.82256 .01472 L
.82327 .01472 L
Mistroke
.82392 .01472 L
.82509 .01472 L
.82636 .01472 L
.82745 .01472 L
.82863 .01472 L
.82975 .01472 L
.83078 .01472 L
.83198 .01472 L
.83325 .01472 L
.83433 .01472 L
.83551 .01472 L
.83682 .01472 L
.83748 .01472 L
.8382 .01472 L
.83948 .01472 L
.84066 .01472 L
.84139 .01472 L
.84207 .01472 L
.84335 .01472 L
.84406 .01472 L
.84472 .01472 L
.84544 .01472 L
.84621 .01472 L
.8474 .01472 L
.84868 .01472 L
.84989 .01472 L
.85099 .01472 L
.85228 .01472 L
.85301 .01472 L
.85369 .01472 L
.85493 .01472 L
.85624 .01472 L
.85862 .01472 L
.85981 .01472 L
.86112 .01472 L
.86224 .01472 L
.86344 .01472 L
.86456 .01472 L
.86559 .01472 L
.8669 .01472 L
.86758 .01472 L
.86831 .01472 L
.86953 .01472 L
.87088 .01472 L
.87207 .01472 L
.87336 .01472 L
.87457 .01472 L
.87568 .01472 L
.87675 .01472 L
.87787 .01472 L
Mistroke
.8791 .01472 L
.88024 .01472 L
.88129 .01472 L
.88228 .01472 L
.88336 .01472 L
.88452 .01472 L
.88516 .01472 L
.88585 .01472 L
.88711 .01472 L
.88834 .01472 L
.88947 .01472 L
.8905 .01472 L
.89164 .01472 L
.89283 .01472 L
.89395 .01472 L
.89516 .01472 L
.89642 .01472 L
.89751 .01472 L
.89869 .01472 L
.89997 .01472 L
.90069 .01472 L
.90134 .01472 L
.9026 .01472 L
.9038 .01472 L
.90491 .01472 L
.90608 .01472 L
.90708 .01472 L
.90819 .01472 L
.90937 .01472 L
.91064 .01472 L
.91184 .01472 L
.91294 .01472 L
.91422 .01472 L
.91493 .01472 L
.91558 .01472 L
.91684 .01472 L
.91803 .01472 L
.91871 .01472 L
.91942 .01472 L
.92069 .01472 L
.92141 .01472 L
.92207 .01472 L
.9228 .01472 L
.92357 .01472 L
.92488 .01472 L
.92561 .01472 L
.92629 .01472 L
.92754 .01472 L
.92886 .01472 L
.93004 .01472 L
Mistroke
.93114 .01472 L
.93236 .01472 L
.93367 .01472 L
.93435 .01472 L
.93499 .01472 L
.9362 .01472 L
.93749 .01472 L
.93823 .01472 L
.9389 .01472 L
.94002 .01472 L
.94126 .01472 L
.94255 .01472 L
.94376 .01472 L
.94444 .01472 L
.94519 .01472 L
.94589 .01472 L
.94654 .01472 L
.94777 .01472 L
.94908 .01472 L
.94975 .01472 L
.95047 .01472 L
.95179 .01472 L
.95255 .01472 L
.95335 .01472 L
.95403 .01472 L
.95478 .01472 L
.95594 .01472 L
.95718 .01472 L
.95782 .01472 L
.95853 .01472 L
.95977 .01472 L
.96095 .01472 L
.96221 .01472 L
.9634 .01472 L
.96449 .01472 L
.96518 .01472 L
.96582 .01472 L
.96653 .01472 L
.96728 .01472 L
.96799 .01472 L
.96867 .01472 L
.96992 .01472 L
.97108 .01472 L
.9723 .01472 L
.97294 .01472 L
.97364 .01472 L
.97487 .01472 L
.97555 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.28158 .01472 L
.30316 .01472 L
.31323 .01472 L
.32392 .01472 L
.33304 .01472 L
.33554 .01472 L
.33823 .01472 L
.33953 .01472 L
.34076 .01472 L
.34187 .01472 L
.34309 .01475 L
.34373 .01479 L
.34441 .01483 L
.34564 .01494 L
.34695 .01509 L
.3484 .01531 L
.35099 .01582 L
.3534 .01643 L
.35792 .01795 L
.36276 .02011 L
.37373 .02702 L
.38373 .03577 L
.40282 .05896 L
.42358 .09384 L
.44335 .13643 L
.46436 .19169 L
.50211 .31673 L
.51233 .35117 L
.52308 .38216 L
.53304 .40604 L
.54231 .42409 L
.55124 .43769 L
.55582 .44322 L
.56079 .44811 L
.56362 .45038 L
.56624 .45214 L
.56868 .4535 L
.57138 .45468 L
.57254 .45508 L
.57379 .45544 L
.57487 .4557 L
.57605 .45591 L
.57674 .45601 L
Mistroke
.57738 .45608 L
.57864 .45616 L
.57978 .45616 L
.581 .45611 L
.58225 .45597 L
.58295 .45587 L
.58361 .45575 L
.58495 .45544 L
.58637 .45502 L
.58896 .45402 L
.59131 .45283 L
.59704 .44887 L
.60245 .44372 L
.61212 .4311 L
.62263 .41243 L
.64245 .36321 L
.66347 .29171 L
.70127 .17241 L
.72228 .12053 L
.74153 .08207 L
.76041 .05273 L
.77002 .04101 L
.78027 .03088 L
.7856 .02657 L
.79064 .02312 L
.79554 .02033 L
.80005 .01826 L
.80434 .01673 L
.80652 .01611 L
.80887 .01558 L
.8101 .01535 L
.81123 .01517 L
.81237 .01502 L
.81342 .01491 L
.81465 .01481 L
.8153 .01477 L
.81599 .01474 L
.81715 .01472 L
.81843 .01472 L
.81964 .01472 L
.82077 .01472 L
.82201 .01472 L
.8227 .01472 L
.82333 .01472 L
.82461 .01472 L
.82533 .01472 L
.82599 .01472 L
.8285 .01472 L
.83064 .01472 L
.83185 .01472 L
Mistroke
.83299 .01472 L
.83419 .01472 L
.83528 .01472 L
.83655 .01472 L
.83775 .01472 L
.83906 .01472 L
.84025 .01472 L
.84091 .01472 L
.84163 .01472 L
.84292 .01472 L
.84414 .01472 L
.84542 .01472 L
.84652 .01472 L
.84772 .01472 L
.84845 .01472 L
.84914 .01472 L
.85044 .01472 L
.85116 .01472 L
.85183 .01472 L
.85257 .01472 L
.85335 .01472 L
.85455 .01472 L
.85584 .01472 L
.85658 .01472 L
.85726 .01472 L
.85791 .01472 L
.8586 .01472 L
.85983 .01472 L
.86053 .01472 L
.86117 .01472 L
.86235 .01472 L
.8636 .01472 L
.86472 .01472 L
.86577 .01472 L
.86692 .01472 L
.86815 .01472 L
.86946 .01472 L
.8702 .01472 L
.87089 .01472 L
.87215 .01472 L
.87285 .01472 L
.87348 .01472 L
.87469 .01472 L
.87599 .01472 L
.87835 .01472 L
.89673 .01472 L
.91633 .01472 L
.9378 .01472 L
.9474 .01472 L
.94863 .01472 L
Mistroke
.94993 .01472 L
.95061 .01472 L
.95136 .01472 L
.95268 .01472 L
.95392 .01472 L
.95462 .01472 L
.95526 .01472 L
.95767 .01472 L
.96005 .01472 L
.96264 .01472 L
.96383 .01472 L
.96509 .01472 L
.96628 .01472 L
.96737 .01472 L
.9685 .01472 L
.96955 .01472 L
.9707 .01472 L
.97191 .01472 L
.97395 .01472 L
.97511 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49719 .01472 L
.49842 .01472 L
.49955 .01472 L
.50085 .01472 L
.50154 .01472 L
.50226 .01473 L
.50343 .01476 L
.50471 .0148 L
.50591 .01485 L
.50719 .01492 L
.5095 .01507 L
.51204 .01528 L
.51445 .01553 L
.51896 .01611 L
.52416 .01699 L
.52896 .01798 L
.53984 .02089 L
.54947 .02424 L
.5585 .02804 L
.57911 .03908 L
.59929 .0531 L
.61779 .06874 L
.65742 .1112 L
.67738 .13316 L
.69553 .14775 L
.70561 .15365 L
.71514 .15776 L
.72037 .15942 L
.72519 .16057 L
.72771 .16103 L
.73048 .16141 L
.73188 .16157 L
.73338 .16169 L
.7341 .16174 L
.73479 .16178 L
Mistroke
.73609 .16183 L
.73734 .16186 L
.73804 .16187 L
.73869 .16186 L
.73988 .16184 L
.74113 .16179 L
.74226 .16173 L
.74331 .16165 L
.7457 .16142 L
.74829 .16106 L
.75064 .16064 L
.75593 .15939 L
.76046 .15797 L
.76539 .15607 L
.77433 .15164 L
.78376 .14563 L
.79414 .1374 L
.81517 .11561 L
.85542 .0715 L
.89416 .04091 L
.91424 .02966 L
.92445 .02514 L
.93535 .02121 L
.94572 .01833 L
.95513 .01644 L
.95968 .01578 L
.96207 .01549 L
.96459 .01524 L
.96681 .01506 L
.96924 .0149 L
.9703 .01485 L
.97145 .0148 L
.97253 .01477 L
.97351 .01474 L
.9748 .01472 L
.97552 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "This shows the two\[Hyphen]scale relation for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_3\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.31"}],

Cell[CellGroupData[{

Cell["plotTwoScaleBeta[3]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0147151 0.882907 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .1913 -18 -4.5 ]
[.4875 .1913 0 4.5 ]
[.4875 .27959 -18 -4.5 ]
[.4875 .27959 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .54446 -18 -4.5 ]
[.4875 .54446 0 4.5 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-1)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .10301 m
.50625 .10301 L
s
[(0.1)] .4875 .10301 1 0 Mshowa
.5 .1913 m
.50625 .1913 L
s
[(0.2)] .4875 .1913 1 0 Mshowa
.5 .27959 m
.50625 .27959 L
s
[(0.3)] .4875 .27959 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.4)] .4875 .36788 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .54446 m
.50625 .54446 L
s
[(0.6)] .4875 .54446 1 0 Mshowa
.125 Mabswid
.5 .03237 m
.50375 .03237 L
s
.5 .05003 m
.50375 .05003 L
s
.5 .06769 m
.50375 .06769 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .12066 m
.50375 .12066 L
s
.5 .13832 m
.50375 .13832 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17364 m
.50375 .17364 L
s
.5 .20895 m
.50375 .20895 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24427 m
.50375 .24427 L
s
.5 .26193 m
.50375 .26193 L
s
.5 .29725 m
.50375 .29725 L
s
.5 .3149 m
.50375 .3149 L
s
.5 .33256 m
.50375 .33256 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .38554 m
.50375 .38554 L
s
.5 .40319 m
.50375 .40319 L
s
.5 .42085 m
.50375 .42085 L
s
.5 .43851 m
.50375 .43851 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49148 m
.50375 .49148 L
s
.5 .50914 m
.50375 .50914 L
s
.5 .5268 m
.50375 .5268 L
s
.5 .56212 m
.50375 .56212 L
s
.5 .57978 m
.50375 .57978 L
s
.5 .59743 m
.50375 .59743 L
s
.5 .61509 m
.50375 .61509 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Two-scale relation for B-spline order 3)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01473 L
.0352 .01473 L
.03746 .01474 L
.03884 .01475 L
.04016 .01476 L
.04262 .01479 L
.045 .01482 L
.04753 .01486 L
.0521 .01496 L
.05489 .01504 L
.05752 .01513 L
.06244 .01534 L
.06757 .01563 L
.07299 .01601 L
.08269 .01694 L
.09312 .01835 L
.10458 .02046 L
.11478 .02292 L
.12409 .02571 L
.145 .03412 L
.16409 .04481 L
.18485 .06025 L
.20462 .07916 L
.22563 .10434 L
.26338 .16462 L
.30359 .25031 L
.34227 .3442 L
.38341 .44345 L
.40394 .48859 L
.42304 .52598 L
.44264 .55825 L
.46115 .58173 L
.47096 .59099 L
.47613 .59489 L
.4816 .59825 L
.48621 .60044 L
.48865 .60136 L
.49127 .60216 L
.49251 .60246 L
.49368 .60271 L
.49482 .60291 L
Mistroke
.49588 .60306 L
.49688 .60317 L
.49794 .60325 L
.49912 .60331 L
.50019 .60332 L
.5014 .60329 L
.50252 .60322 L
.50376 .6031 L
.50508 .60292 L
.50647 .60268 L
.50778 .60239 L
.51024 .60172 L
.51467 .60007 L
.51948 .59765 L
.5303 .58993 L
.54031 .58016 L
.55901 .55581 L
.57963 .52108 L
.61988 .43584 L
.65862 .34198 L
.69981 .24242 L
.73949 .15929 L
.77765 .10003 L
.7973 .07713 L
.81826 .05766 L
.83965 .04247 L
.85981 .0319 L
.86956 .02793 L
.87987 .02446 L
.88952 .02181 L
.89833 .01986 L
.9078 .0182 L
.91795 .01687 L
.92245 .01641 L
.92735 .01598 L
.93627 .01541 L
.94101 .01519 L
.94547 .01503 L
.95035 .0149 L
.9531 .01485 L
.95562 .01481 L
.9581 .01478 L
.9604 .01476 L
.96293 .01474 L
.96435 .01473 L
.96564 .01473 L
.96699 .01472 L
.96824 .01472 L
.96961 .01472 L
.9703 .01472 L
Mistroke
.97106 .01472 L
.97234 .01472 L
.97306 .01472 L
.97371 .01472 L
.97498 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01473 L
.0352 .01473 L
.03746 .01474 L
.03884 .01475 L
.04016 .01476 L
.04262 .01479 L
.045 .01482 L
.04753 .01486 L
.0521 .01496 L
.05489 .01504 L
.05752 .01513 L
.06244 .01534 L
.06757 .01563 L
.07299 .01601 L
.08269 .01694 L
.09312 .01835 L
.10458 .02046 L
.11478 .02292 L
.12409 .02571 L
.145 .03412 L
.16409 .04439 L
.18485 .05702 L
.20423 .06866 L
.21453 .07429 L
.22563 .07961 L
.2362 .0837 L
.24082 .08514 L
.24588 .08643 L
.2482 .08691 L
.25068 .08736 L
.25282 .08767 L
.25515 .08795 L
.25651 .08807 L
.25777 .08816 L
.25898 .08822 L
.26026 .08827 L
.2614 .08829 L
.26247 .08829 L
.26364 .08827 L
.2649 .08822 L
.26559 .08819 L
Mistroke
.26623 .08815 L
.26744 .08806 L
.27015 .08778 L
.2725 .08746 L
.27503 .08702 L
.28078 .08574 L
.28607 .0842 L
.29585 .0806 L
.30617 .07587 L
.3442 .05378 L
.36538 .04115 L
.38467 .03144 L
.39427 .0276 L
.4047 .02415 L
.41447 .02154 L
.42364 .01957 L
.43306 .01799 L
.43848 .01725 L
.44345 .01669 L
.45357 .01581 L
.45888 .01547 L
.46447 .0152 L
.46949 .01502 L
.47404 .01491 L
.47656 .01486 L
.4793 .01481 L
.48188 .01478 L
.48425 .01476 L
.48645 .01474 L
.48851 .01473 L
.48969 .01473 L
.49076 .01472 L
.49201 .01472 L
.49318 .01472 L
.49432 .01472 L
.49553 .01472 L
.49657 .01472 L
.49771 .01472 L
.49893 .01472 L
.50025 .01472 L
.50149 .01472 L
.50263 .01472 L
.5039 .01472 L
.50511 .01472 L
.50619 .01472 L
.50736 .01472 L
.50864 .01472 L
.50928 .01472 L
.50999 .01472 L
.51242 .01472 L
Mistroke
.51358 .01472 L
.51469 .01472 L
.51596 .01472 L
.51712 .01472 L
.51822 .01472 L
.51923 .01472 L
.52034 .01472 L
.52153 .01472 L
.52221 .01472 L
.52293 .01472 L
.52422 .01472 L
.52493 .01472 L
.5256 .01472 L
.52634 .01472 L
.52712 .01472 L
.5278 .01472 L
.52854 .01472 L
.52923 .01472 L
.52988 .01472 L
.53109 .01472 L
.53239 .01472 L
.53355 .01472 L
.5348 .01472 L
.53598 .01472 L
.53706 .01472 L
.53826 .01472 L
.53958 .01472 L
.54024 .01472 L
.54095 .01472 L
.54222 .01472 L
.54346 .01472 L
.54416 .01472 L
.54481 .01472 L
.54551 .01472 L
.54614 .01472 L
.54687 .01472 L
.54756 .01472 L
.54878 .01472 L
.54991 .01472 L
.55115 .01472 L
.55248 .01472 L
.55323 .01472 L
.55392 .01472 L
.55468 .01472 L
.55548 .01472 L
.55613 .01472 L
.55683 .01472 L
.55759 .01472 L
.55831 .01472 L
.55899 .01472 L
Mistroke
.55973 .01472 L
.56042 .01472 L
.56107 .01472 L
.56229 .01472 L
.56358 .01472 L
.56483 .01472 L
.56597 .01472 L
.56728 .01472 L
.56853 .01472 L
.57078 .01472 L
.57201 .01472 L
.57317 .01472 L
.57383 .01472 L
.57455 .01472 L
.57579 .01472 L
.57706 .01472 L
.57822 .01472 L
.5795 .01472 L
.58024 .01472 L
.58091 .01472 L
.58161 .01472 L
.58237 .01472 L
.58307 .01472 L
.58374 .01472 L
.58488 .01472 L
.5861 .01472 L
.58726 .01472 L
.58833 .01472 L
.5895 .01472 L
.59079 .01472 L
.59144 .01472 L
.59214 .01472 L
.59339 .01472 L
.59403 .01472 L
.59471 .01472 L
.59546 .01472 L
.59615 .01472 L
.59739 .01472 L
.5981 .01472 L
.59876 .01472 L
.59999 .01472 L
.60111 .01472 L
.60241 .01472 L
.60364 .01472 L
.6048 .01472 L
.60585 .01472 L
.60707 .01472 L
.60821 .01472 L
.60928 .01472 L
.61027 .01472 L
Mistroke
.61131 .01472 L
.61245 .01472 L
.61361 .01472 L
.61486 .01472 L
.61601 .01472 L
.61707 .01472 L
.6183 .01472 L
.61899 .01472 L
.61963 .01472 L
.62081 .01472 L
.62206 .01472 L
.6232 .01472 L
.62445 .01472 L
.62566 .01472 L
.62696 .01472 L
.62818 .01472 L
.62928 .01472 L
.63034 .01472 L
.63145 .01472 L
.63275 .01472 L
.63395 .01472 L
.63523 .01472 L
.63597 .01472 L
.63665 .01472 L
.63789 .01472 L
.63902 .01472 L
.64032 .01472 L
.64156 .01472 L
.6426 .01472 L
.64376 .01472 L
.64497 .01472 L
.6461 .01472 L
.64716 .01472 L
.64815 .01472 L
.64918 .01472 L
.65031 .01472 L
.65147 .01472 L
.6527 .01472 L
.65385 .01472 L
.6549 .01472 L
.65612 .01472 L
.65681 .01472 L
.65744 .01472 L
.65861 .01472 L
.65985 .01472 L
.66106 .01472 L
.66219 .01472 L
.6635 .01472 L
.66469 .01472 L
.66601 .01472 L
Mistroke
.66675 .01472 L
.66744 .01472 L
.66867 .01472 L
.66998 .01472 L
.67122 .01472 L
.67239 .01472 L
.67303 .01472 L
.67373 .01472 L
.67496 .01472 L
.67613 .01472 L
.67738 .01472 L
.67844 .01472 L
.67961 .01472 L
.68073 .01472 L
.68175 .01472 L
.68285 .01472 L
.68406 .01472 L
.68511 .01472 L
.68609 .01472 L
.68713 .01472 L
.68823 .01472 L
.68945 .01472 L
.69014 .01472 L
.69078 .01472 L
.69195 .01472 L
.69319 .01472 L
.6943 .01472 L
.69533 .01472 L
.69647 .01472 L
.69769 .01472 L
.69898 .01472 L
.70018 .01472 L
.7015 .01472 L
.70223 .01472 L
.7029 .01472 L
.70412 .01472 L
.70544 .01472 L
.70669 .01472 L
.70784 .01472 L
.70895 .01472 L
.70999 .01472 L
.71113 .01472 L
.71235 .01472 L
.71363 .01472 L
.71484 .01472 L
.71592 .01472 L
.71711 .01472 L
.7184 .01472 L
.71961 .01472 L
.72031 .01472 L
Mistroke
.72094 .01472 L
.72167 .01472 L
.72237 .01472 L
.72304 .01472 L
.72376 .01472 L
.72504 .01472 L
.72583 .01472 L
.72657 .01472 L
.72724 .01472 L
.72796 .01472 L
.72917 .01472 L
.72986 .01472 L
.7305 .01472 L
.73179 .01472 L
.73252 .01472 L
.73318 .01472 L
.73436 .01472 L
.73565 .01472 L
.73686 .01472 L
.73799 .01472 L
.73908 .01472 L
.74025 .01472 L
.74135 .01472 L
.74235 .01472 L
.74348 .01472 L
.74455 .01472 L
.7457 .01472 L
.74696 .01472 L
.74823 .01472 L
.74887 .01472 L
.74958 .01472 L
.75083 .01472 L
.752 .01472 L
.75317 .01472 L
.75423 .01472 L
.75546 .01472 L
.75663 .01472 L
.75791 .01472 L
.75862 .01472 L
.75927 .01472 L
.76053 .01472 L
.76171 .01472 L
.76239 .01472 L
.7631 .01472 L
.76437 .01472 L
.76508 .01472 L
.76575 .01472 L
.76647 .01472 L
.76725 .01472 L
.76854 .01472 L
Mistroke
.76926 .01472 L
.76993 .01472 L
.77114 .01472 L
.77178 .01472 L
.77247 .01472 L
.77366 .01472 L
.77478 .01472 L
.77723 .01472 L
.77846 .01472 L
.77963 .01472 L
.78027 .01472 L
.78097 .01472 L
.78219 .01472 L
.78336 .01472 L
.7846 .01472 L
.78565 .01472 L
.78681 .01472 L
.78751 .01472 L
.78818 .01472 L
.78942 .01472 L
.79012 .01472 L
.79076 .01472 L
.79147 .01472 L
.79223 .01472 L
.79289 .01472 L
.7936 .01472 L
.79488 .01472 L
.79614 .01472 L
.79729 .01472 L
.79851 .01472 L
.79983 .01472 L
.80107 .01472 L
.80219 .01472 L
.80498 .01472 L
.80621 .01472 L
.80691 .01472 L
.80756 .01472 L
.80886 .01472 L
.80952 .01472 L
.81023 .01472 L
.81101 .01472 L
.81175 .01472 L
.81241 .01472 L
.81313 .01472 L
.81445 .01472 L
.81519 .01472 L
.81586 .01472 L
.81717 .01472 L
.8184 .01472 L
.81956 .01472 L
Mistroke
.8208 .01472 L
.82198 .01472 L
.82305 .01472 L
.8243 .01472 L
.82501 .01472 L
.82567 .01472 L
.82688 .01472 L
.82816 .01472 L
.82937 .01472 L
.83068 .01472 L
.83192 .01472 L
.83306 .01472 L
.83432 .01472 L
.83503 .01472 L
.83569 .01472 L
.8364 .01472 L
.83704 .01472 L
.83777 .01472 L
.83847 .01472 L
.83954 .01472 L
.84071 .01472 L
.84193 .01472 L
.84308 .01472 L
.84415 .01472 L
.84513 .01472 L
.84626 .01472 L
.84733 .01472 L
.84849 .01472 L
.84972 .01472 L
.85088 .01472 L
.85193 .01472 L
.85317 .01472 L
.85387 .01472 L
.85451 .01472 L
.85569 .01472 L
.85694 .01472 L
.85817 .01472 L
.85886 .01472 L
.8595 .01472 L
.86067 .01472 L
.86191 .01472 L
.86303 .01472 L
.86407 .01472 L
.86521 .01472 L
.86644 .01472 L
.86768 .01472 L
.86838 .01472 L
.86903 .01472 L
.87035 .01472 L
.87108 .01472 L
Mistroke
.87175 .01472 L
.87295 .01472 L
.87425 .01472 L
.87548 .01472 L
.87661 .01472 L
.87767 .01472 L
.87881 .01472 L
.88086 .01472 L
.88212 .01472 L
.8833 .01472 L
.88437 .01472 L
.88553 .01472 L
.88666 .01472 L
.8879 .01472 L
.8892 .01472 L
.89043 .01472 L
.89156 .01472 L
.89261 .01472 L
.89374 .01472 L
.89496 .01472 L
.89623 .01472 L
.89744 .01472 L
.89861 .01472 L
.89969 .01472 L
.90086 .01472 L
.90214 .01472 L
.90279 .01472 L
.90349 .01472 L
.90475 .01472 L
.90591 .01472 L
.90719 .01472 L
.90839 .01472 L
.9095 .01472 L
.91061 .01472 L
.91161 .01472 L
.91277 .01472 L
.91386 .01472 L
.91506 .01472 L
.91638 .01472 L
.91704 .01472 L
.91775 .01472 L
.91904 .01472 L
.92032 .01472 L
.92153 .01472 L
.92262 .01472 L
.9238 .01472 L
.92509 .01472 L
.92582 .01472 L
.92651 .01472 L
.92723 .01472 L
Mistroke
.92789 .01472 L
.92862 .01472 L
.92938 .01472 L
.93066 .01472 L
.93185 .01472 L
.93315 .01472 L
.93388 .01472 L
.93455 .01472 L
.93574 .01472 L
.93686 .01472 L
.93808 .01472 L
.9394 .01472 L
.94006 .01472 L
.94078 .01472 L
.94209 .01472 L
.94336 .01472 L
.94454 .01472 L
.94565 .01472 L
.94682 .01472 L
.9481 .01472 L
.94928 .01472 L
.95038 .01472 L
.95141 .01472 L
.95254 .01472 L
.95374 .01472 L
.95443 .01472 L
.95517 .01472 L
.95587 .01472 L
.95651 .01472 L
.95774 .01472 L
.95903 .01472 L
.96021 .01472 L
.96131 .01472 L
.96252 .01472 L
.96382 .01472 L
.96453 .01472 L
.96519 .01472 L
.96592 .01472 L
.96669 .01472 L
.96743 .01472 L
.96812 .01472 L
.96942 .01472 L
.9707 .01472 L
.97188 .01472 L
.97318 .01472 L
.97383 .01472 L
.97454 .01472 L
.97534 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.10458 .01472 L
.11448 .01472 L
.12507 .01472 L
.1302 .01472 L
.13506 .01472 L
.13942 .01472 L
.14061 .01472 L
.14188 .01472 L
.14296 .01472 L
.14415 .01472 L
.14544 .01472 L
.14664 .01472 L
.14795 .01472 L
.14868 .01472 L
.14935 .01473 L
.15057 .01474 L
.15189 .01475 L
.15314 .01476 L
.15429 .01478 L
.15644 .01482 L
.1588 .01489 L
.16126 .01499 L
.16356 .0151 L
.16627 .01527 L
.16883 .01548 L
.17364 .01599 L
.17881 .01674 L
.18444 .01785 L
.18929 .01908 L
.19384 .02049 L
.20421 .02479 L
.21432 .03063 L
.22522 .03908 L
.23479 .0486 L
.24526 .06155 L
.26636 .09685 L
.30692 .19139 L
.32566 .2359 L
.34597 .27649 L
.35136 .28513 L
.35707 .29304 L
.36236 .29909 L
.36731 .30355 L
.36969 .30525 L
.37194 .30658 L
.37318 .3072 L
.37454 .30777 L
Mistroke
.37576 .3082 L
.37691 .30852 L
.37758 .30867 L
.3783 .3088 L
.37956 .30896 L
.38028 .309 L
.38103 .30902 L
.38168 .309 L
.38239 .30895 L
.38366 .30879 L
.38437 .30866 L
.38501 .30851 L
.38628 .30815 L
.38747 .30773 L
.38976 .30669 L
.39229 .30521 L
.3974 .30117 L
.40183 .29663 L
.40659 .29075 L
.42736 .255 L
.46855 .15793 L
.48912 .11013 L
.50823 .07406 L
.52669 .04907 L
.53702 .03878 L
.54639 .03144 L
.5564 .02544 L
.56562 .02137 L
.57044 .01972 L
.57573 .01826 L
.58126 .01707 L
.58643 .01623 L
.59142 .01563 L
.59425 .01538 L
.59686 .01519 L
.59933 .01505 L
.60166 .01494 L
.60408 .01486 L
.60535 .01483 L
.60675 .0148 L
.60902 .01476 L
.61026 .01474 L
.61141 .01473 L
.61249 .01473 L
.61347 .01472 L
.6146 .01472 L
.61568 .01472 L
.61684 .01472 L
.61808 .01472 L
.61913 .01472 L
Mistroke
.62029 .01472 L
.62154 .01472 L
.62224 .01472 L
.62288 .01472 L
.62412 .01472 L
.6253 .01472 L
.62655 .01472 L
.62725 .01472 L
.6279 .01472 L
.62908 .01472 L
.63034 .01472 L
.6349 .01472 L
.63612 .01472 L
.63742 .01472 L
.63865 .01472 L
.63977 .01472 L
.64109 .01472 L
.64183 .01472 L
.64252 .01472 L
.64378 .01472 L
.64442 .01472 L
.64512 .01472 L
.64628 .01472 L
.64751 .01472 L
.64855 .01472 L
.64969 .01472 L
.65092 .01472 L
.65224 .01472 L
.65348 .01472 L
.65461 .01472 L
.65576 .01472 L
.65681 .01472 L
.65797 .01472 L
.65919 .01472 L
.66026 .01472 L
.66125 .01472 L
.66234 .01472 L
.66352 .01472 L
.66421 .01472 L
.66485 .01472 L
.66607 .01472 L
.66737 .01472 L
.6681 .01472 L
.66878 .01472 L
.66991 .01472 L
.67115 .01472 L
.67245 .01472 L
.67366 .01472 L
.67434 .01472 L
.67509 .01472 L
Mistroke
.6758 .01472 L
.67645 .01472 L
.67768 .01472 L
.67899 .01472 L
.67967 .01472 L
.6804 .01472 L
.68171 .01472 L
.68251 .01472 L
.68327 .01472 L
.68396 .01472 L
.68471 .01472 L
.68536 .01472 L
.68607 .01472 L
.68735 .01472 L
.6886 .01472 L
.68975 .01472 L
.69099 .01472 L
.69168 .01472 L
.69231 .01472 L
.69306 .01472 L
.69377 .01472 L
.69442 .01472 L
.69513 .01472 L
.69632 .01472 L
.69757 .01472 L
.69865 .01472 L
.69984 .01472 L
.70107 .01472 L
.70177 .01472 L
.7024 .01472 L
.70358 .01472 L
.70481 .01472 L
.70604 .01472 L
.70674 .01472 L
.70738 .01472 L
.70856 .01472 L
.70981 .01472 L
.71093 .01472 L
.71197 .01472 L
.71312 .01472 L
.71435 .01472 L
.71566 .01472 L
.7164 .01472 L
.71708 .01472 L
.71834 .01472 L
.71904 .01472 L
.71968 .01472 L
.72088 .01472 L
.72218 .01472 L
.72341 .01472 L
Mistroke
.72454 .01472 L
.7256 .01472 L
.7266 .01472 L
.72775 .01472 L
.72881 .01472 L
.72996 .01472 L
.73122 .01472 L
.7324 .01472 L
.73348 .01472 L
.7346 .01472 L
.73565 .01472 L
.73681 .01472 L
.73805 .01472 L
.73929 .01472 L
.74059 .01472 L
.7417 .01472 L
.74291 .01472 L
.74355 .01472 L
.74423 .01472 L
.74545 .01472 L
.74676 .01472 L
.74752 .01472 L
.74821 .01472 L
.74945 .01472 L
.75014 .01472 L
.75079 .01472 L
.75194 .01472 L
.7532 .01472 L
.75432 .01472 L
.75555 .01472 L
.75684 .01472 L
.75805 .01472 L
.75918 .01472 L
.76022 .01472 L
.76135 .01472 L
.76255 .01472 L
.76386 .01472 L
.76505 .01472 L
.76571 .01472 L
.76643 .01472 L
.76773 .01472 L
.76895 .01472 L
.77024 .01472 L
.77134 .01472 L
.77255 .01472 L
.77328 .01472 L
.77398 .01472 L
.77528 .01472 L
.77601 .01472 L
.77668 .01472 L
Mistroke
.77742 .01472 L
.77821 .01472 L
.7789 .01472 L
.77964 .01472 L
.78034 .01472 L
.78099 .01472 L
.78228 .01472 L
.78351 .01472 L
.78469 .01472 L
.78597 .01472 L
.78713 .01472 L
.78821 .01472 L
.78947 .01472 L
.79065 .01472 L
.79189 .01472 L
.79254 .01472 L
.79325 .01472 L
.79445 .01472 L
.79556 .01472 L
.79672 .01472 L
.79799 .01472 L
.79909 .01472 L
.80009 .01472 L
.80234 .01472 L
.80363 .01472 L
.80428 .01472 L
.80499 .01472 L
.80626 .01472 L
.80744 .01472 L
.80816 .01472 L
.80883 .01472 L
.81011 .01472 L
.81082 .01472 L
.81148 .01472 L
.8122 .01472 L
.81297 .01472 L
.81427 .01472 L
.81501 .01472 L
.81568 .01472 L
.81693 .01472 L
.81824 .01472 L
.81941 .01472 L
.82051 .01472 L
.82171 .01472 L
.823 .01472 L
.82423 .01472 L
.82492 .01472 L
.82558 .01472 L
.82689 .01472 L
.82763 .01472 L
Mistroke
.82831 .01472 L
.82951 .01472 L
.83082 .01472 L
.83206 .01472 L
.83321 .01472 L
.8339 .01472 L
.83465 .01472 L
.83537 .01472 L
.83602 .01472 L
.83726 .01472 L
.83857 .01472 L
.83925 .01472 L
.83998 .01472 L
.8413 .01472 L
.8421 .01472 L
.84286 .01472 L
.84355 .01472 L
.84429 .01472 L
.84553 .01472 L
.8467 .01472 L
.84798 .01472 L
.8487 .01472 L
.84936 .01472 L
.85061 .01472 L
.85132 .01472 L
.85198 .01472 L
.85268 .01472 L
.85332 .01472 L
.85405 .01472 L
.85475 .01472 L
.85592 .01472 L
.85716 .01472 L
.85822 .01472 L
.85939 .01472 L
.86064 .01472 L
.86135 .01472 L
.86199 .01472 L
.86324 .01472 L
.86442 .01472 L
.86567 .01472 L
.86637 .01472 L
.86702 .01472 L
.86821 .01472 L
.86946 .01472 L
.87059 .01472 L
.87164 .01472 L
.87279 .01472 L
.87402 .01472 L
.87534 .01472 L
.87609 .01472 L
Mistroke
.87677 .01472 L
.87804 .01472 L
.87867 .01472 L
.87938 .01472 L
.88059 .01472 L
.88189 .01472 L
.88312 .01472 L
.88425 .01472 L
.88532 .01472 L
.88647 .01472 L
.88755 .01472 L
.88853 .01472 L
.88969 .01472 L
.89094 .01472 L
.89213 .01472 L
.89321 .01472 L
.89427 .01472 L
.8954 .01472 L
.89664 .01472 L
.8978 .01472 L
.8991 .01472 L
.90033 .01472 L
.90144 .01472 L
.90265 .01472 L
.9033 .01472 L
.90398 .01472 L
.90521 .01472 L
.90654 .01472 L
.90729 .01472 L
.90798 .01472 L
.90925 .01472 L
.91041 .01472 L
.91105 .01472 L
.91174 .01472 L
.913 .01472 L
.91413 .01472 L
.91537 .01472 L
.91666 .01472 L
.91788 .01472 L
.91901 .01472 L
.92005 .01472 L
.92124 .01472 L
.92238 .01472 L
.9237 .01472 L
.9249 .01472 L
.92556 .01472 L
.92628 .01472 L
.92758 .01472 L
.92881 .01472 L
.9301 .01472 L
Mistroke
.9312 .01472 L
.93241 .01472 L
.93315 .01472 L
.93384 .01472 L
.93515 .01472 L
.93588 .01472 L
.93655 .01472 L
.93734 .01472 L
.93808 .01472 L
.9393 .01472 L
.93995 .01472 L
.94064 .01472 L
.94134 .01472 L
.94207 .01472 L
.94337 .01472 L
.94443 .01472 L
.94559 .01472 L
.94667 .01472 L
.94768 .01472 L
.94858 .01472 L
.94958 .01472 L
.95062 .01472 L
.95159 .01472 L
.95272 .01472 L
.9538 .01472 L
.95477 .01472 L
.95582 .01472 L
.95697 .01472 L
.95818 .01472 L
.95933 .01472 L
.96037 .01472 L
.96136 .01472 L
.96241 .01472 L
.96331 .01472 L
.96429 .01472 L
.96535 .01472 L
.96648 .01472 L
.96755 .01472 L
.96852 .01472 L
.9695 .01472 L
.97041 .01472 L
.97141 .01472 L
.97246 .01472 L
.97338 .01472 L
.97424 .01472 L
.97518 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .01472 L
.26425 .01472 L
.26494 .01472 L
.26567 .01472 L
.26698 .01472 L
.26773 .01473 L
.26855 .01473 L
.26927 .01474 L
.27003 .01475 L
.27146 .01477 L
.27279 .0148 L
.274 .01483 L
.27531 .01487 L
.27766 .01497 L
.28046 .01513 L
.28302 .01533 L
.28797 .01587 L
.29077 .01629 L
.29336 .01675 L
.29811 .01782 L
.30316 .01931 L
.31253 .0232 L
.31779 .02614 L
.32263 .02936 L
.33153 .03679 L
.34091 .04697 L
.35045 .06013 L
.36065 .07769 L
.37901 .11978 L
.40036 .18642 L
.42051 .25951 L
.43883 .32625 L
.45898 .39109 L
.46856 .41608 L
.47885 .43713 L
.48454 .44572 L
.48973 .45145 L
.49222 .45343 L
Mistroke
.49354 .45427 L
.49494 .455 L
.49629 .45554 L
.49751 .45588 L
.49874 .45609 L
.4999 .45617 L
.50106 .45612 L
.50231 .45592 L
.50349 .45561 L
.50457 .45521 L
.50583 .45462 L
.5072 .45382 L
.50969 .45196 L
.51229 .44947 L
.51505 .44625 L
.52001 .43902 L
.52881 .42209 L
.5385 .39811 L
.57876 .26223 L
.59727 .1947 L
.61749 .12945 L
.63757 .08116 L
.64852 .06173 L
.65869 .04747 L
.66924 .03607 L
.67918 .02809 L
.68812 .02288 L
.69315 .02065 L
.69778 .019 L
.70247 .01767 L
.7075 .01659 L
.71225 .01584 L
.71659 .01537 L
.71922 .01515 L
.72166 .01501 L
.72434 .01489 L
.72569 .01484 L
.72719 .0148 L
.72849 .01477 L
.72968 .01475 L
.73099 .01474 L
.73165 .01473 L
.73237 .01473 L
.73359 .01472 L
.73489 .01472 L
.73612 .01472 L
.73724 .01472 L
.73843 .01472 L
.73954 .01472 L
.74076 .01472 L
Mistroke
.74208 .01472 L
.74274 .01472 L
.74345 .01472 L
.74476 .01472 L
.74603 .01472 L
.74721 .01472 L
.74841 .01472 L
.74954 .01472 L
.75166 .01472 L
.75394 .01472 L
.75522 .01472 L
.7564 .01472 L
.75761 .01472 L
.7589 .01472 L
.76011 .01472 L
.76122 .01472 L
.76252 .01472 L
.76326 .01472 L
.76394 .01472 L
.76519 .01472 L
.76582 .01472 L
.76651 .01472 L
.76719 .01472 L
.7679 .01472 L
.76916 .01472 L
.76982 .01472 L
.77053 .01472 L
.7713 .01472 L
.77202 .01472 L
.77269 .01472 L
.77341 .01472 L
.77473 .01472 L
.77601 .01472 L
.77719 .01472 L
.77844 .01472 L
.77964 .01472 L
.7807 .01472 L
.78187 .01472 L
.78313 .01472 L
.78384 .01472 L
.78448 .01472 L
.78572 .01472 L
.78689 .01472 L
.788 .01472 L
.78917 .01472 L
.79016 .01472 L
.79126 .01472 L
.79597 .01472 L
.79862 .01472 L
.79993 .01472 L
Mistroke
.80113 .01472 L
.8018 .01472 L
.80252 .01472 L
.80323 .01472 L
.80402 .01472 L
.80473 .01472 L
.8054 .01472 L
.80665 .01472 L
.80784 .01472 L
.80913 .01472 L
.8098 .01472 L
.81051 .01472 L
.81179 .01472 L
.8131 .01472 L
.81432 .01472 L
.81552 .01472 L
.81661 .01472 L
.81777 .01472 L
.81902 .01472 L
.82017 .01472 L
.82126 .01472 L
.82253 .01472 L
.82371 .01472 L
.825 .01472 L
.82565 .01472 L
.82637 .01472 L
.82702 .01472 L
.8277 .01472 L
.82893 .01472 L
.83025 .01472 L
.83099 .01472 L
.83169 .01472 L
.83295 .01472 L
.8341 .01472 L
.83474 .01472 L
.83543 .01472 L
.83668 .01472 L
.83783 .01472 L
.8389 .01472 L
.84008 .01472 L
.84135 .01472 L
.84198 .01472 L
.84267 .01472 L
.84393 .01472 L
.84515 .01472 L
.84629 .01472 L
.84745 .01472 L
.84854 .01472 L
.84952 .01472 L
.85058 .01472 L
Mistroke
.85174 .01472 L
.85296 .01472 L
.85401 .01472 L
.85515 .01472 L
.85646 .01472 L
.85767 .01472 L
.8583 .01472 L
.859 .01472 L
.85972 .01472 L
.8604 .01472 L
.86165 .01472 L
.8628 .01472 L
.86405 .01472 L
.86538 .01472 L
.86649 .01472 L
.86768 .01472 L
.86881 .01472 L
.86983 .01472 L
.87103 .01472 L
.87233 .01472 L
.87356 .01472 L
.87469 .01472 L
.87995 .01472 L
.88126 .01472 L
.88251 .01472 L
.88364 .01472 L
.88486 .01472 L
.88614 .01472 L
.88733 .01472 L
.88862 .01472 L
.88927 .01472 L
.88998 .01472 L
.89071 .01472 L
.89138 .01472 L
.89211 .01472 L
.89289 .01472 L
.8942 .01472 L
.89493 .01472 L
.89562 .01472 L
.89686 .01472 L
.89818 .01472 L
.89933 .01472 L
.9006 .01472 L
.90173 .01472 L
.90294 .01472 L
.90409 .01472 L
.90514 .01472 L
.90643 .01472 L
.90763 .01472 L
.90895 .01472 L
Mistroke
.90963 .01472 L
.91036 .01472 L
.91106 .01472 L
.9117 .01472 L
.91296 .01472 L
.91411 .01472 L
.91532 .01472 L
.91647 .01472 L
.91751 .01472 L
.91871 .01472 L
.91985 .01472 L
.9209 .01472 L
.92187 .01472 L
.92294 .01472 L
.92407 .01472 L
.92521 .01472 L
.92643 .01472 L
.92758 .01472 L
.92864 .01472 L
.92981 .01472 L
.93109 .01472 L
.93174 .01472 L
.93243 .01472 L
.93368 .01472 L
.93491 .01472 L
.93562 .01472 L
.93627 .01472 L
.93695 .01472 L
.93769 .01472 L
.93837 .01472 L
.93901 .01472 L
.94023 .01472 L
.94136 .01472 L
.94393 .01472 L
.94462 .01472 L
.94538 .01472 L
.94609 .01472 L
.94675 .01472 L
.94799 .01472 L
.9493 .01472 L
.94999 .01472 L
.95072 .01472 L
.95204 .01472 L
.95284 .01472 L
.9536 .01472 L
.95429 .01472 L
.95503 .01472 L
.95628 .01472 L
.95745 .01472 L
.95873 .01472 L
Mistroke
.95945 .01472 L
.96011 .01472 L
.96144 .01472 L
.96218 .01472 L
.96288 .01472 L
.96415 .01472 L
.96486 .01472 L
.96551 .01472 L
.96675 .01472 L
.9679 .01472 L
.96916 .01472 L
.96979 .01472 L
.97049 .01472 L
.97166 .01472 L
.97292 .01472 L
.9741 .01472 L
.97518 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.32392 .01472 L
.34309 .01472 L
.36173 .01472 L
.37114 .01472 L
.37372 .01472 L
.37649 .01472 L
.37783 .01472 L
.3791 .01472 L
.38025 .01472 L
.3815 .01472 L
.38215 .01472 L
.38283 .01472 L
.38405 .01472 L
.38537 .01472 L
.38611 .01472 L
.38681 .01472 L
.38808 .01473 L
.38923 .01474 L
.39056 .01475 L
.39182 .01477 L
.39414 .01482 L
.3963 .01487 L
.39866 .01496 L
.40117 .01508 L
.40365 .01522 L
.40631 .01543 L
.41114 .01591 L
.41688 .01674 L
.42214 .01776 L
.42688 .01894 L
.43195 .0205 L
.44107 .02419 L
.45191 .0303 L
.46177 .03773 L
.47175 .04736 L
.48095 .05833 L
.50175 .09158 L
.52051 .13175 L
.54115 .18185 L
.56223 .23246 L
.58149 .27202 L
.59102 .28743 L
Mistroke
.59605 .29414 L
.60141 .30005 L
.60406 .30246 L
.60656 .30441 L
.60899 .306 L
.61122 .30717 L
.61335 .30803 L
.61442 .30836 L
.61559 .30865 L
.61677 .30886 L
.61804 .30899 L
.61923 .30902 L
.62032 .30897 L
.6215 .30883 L
.62261 .30863 L
.62383 .30832 L
.62514 .30789 L
.62781 .30671 L
.63026 .30529 L
.63473 .30186 L
.63944 .29717 L
.64937 .28403 L
.66022 .26535 L
.70083 .17225 L
.7196 .12708 L
.73993 .08495 L
.75106 .06678 L
.76131 .05309 L
.77174 .04188 L
.78148 .03361 L
.79055 .0276 L
.80028 .02273 L
.80582 .02061 L
.81108 .01898 L
.81576 .01781 L
.82093 .01679 L
.8259 .01605 L
.83057 .01553 L
.83314 .01532 L
.8355 .01516 L
.83809 .01502 L
.84082 .0149 L
.84302 .01484 L
.84422 .01481 L
.84537 .01479 L
.84643 .01477 L
.84759 .01475 L
.84863 .01474 L
.84961 .01473 L
.85076 .01473 L
Mistroke
.85204 .01472 L
.85328 .01472 L
.85397 .01472 L
.85461 .01472 L
.85574 .01472 L
.85698 .01472 L
.85815 .01472 L
.85923 .01472 L
.86051 .01472 L
.8617 .01472 L
.86295 .01472 L
.8636 .01472 L
.86431 .01472 L
.86508 .01472 L
.86581 .01472 L
.86646 .01472 L
.86717 .01472 L
.86784 .01472 L
.86854 .01472 L
.86981 .01472 L
.87098 .01472 L
.87225 .01472 L
.87345 .01472 L
.87454 .01472 L
.87586 .01472 L
.87709 .01472 L
.87837 .01472 L
.87904 .01472 L
.87977 .01472 L
.88102 .01472 L
.88217 .01472 L
.88344 .01472 L
.88408 .01472 L
.88478 .01472 L
.88596 .01472 L
.88723 .01472 L
.88843 .01472 L
.88952 .01472 L
.89065 .01472 L
.89169 .01472 L
.89284 .01472 L
.89406 .01472 L
.89523 .01472 L
.89633 .01472 L
.89731 .01472 L
.89838 .01472 L
.89963 .01472 L
.90076 .01472 L
.90208 .01472 L
.90332 .01472 L
Mistroke
.90446 .01472 L
.90552 .01472 L
.90668 .01472 L
.90792 .01472 L
.90915 .01472 L
.90985 .01472 L
.91049 .01472 L
.91172 .01472 L
.91289 .01472 L
.91355 .01472 L
.91425 .01472 L
.91551 .01472 L
.91628 .01472 L
.91701 .01472 L
.91766 .01472 L
.91837 .01472 L
.91969 .01472 L
.92091 .01472 L
.92162 .01472 L
.92226 .01472 L
.923 .01472 L
.92371 .01472 L
.92439 .01472 L
.92511 .01472 L
.92641 .01472 L
.92713 .01472 L
.92781 .01472 L
.92855 .01472 L
.92935 .01472 L
.93057 .01472 L
.93127 .01472 L
.93192 .01472 L
.93322 .01472 L
.93395 .01472 L
.93462 .01472 L
.93581 .01472 L
.93711 .01472 L
.93833 .01472 L
.93945 .01472 L
.94062 .01472 L
.94173 .01472 L
.94274 .01472 L
.94381 .01472 L
.94497 .01472 L
.94605 .01472 L
.94733 .01472 L
.94849 .01472 L
.94958 .01472 L
.95058 .01472 L
.95168 .01472 L
Mistroke
.95284 .01472 L
.95386 .01472 L
.9548 .01472 L
.95584 .01472 L
.95694 .01472 L
.95823 .01472 L
.95942 .01472 L
.96073 .01472 L
.96139 .01472 L
.96212 .01472 L
.96334 .01472 L
.96465 .01472 L
.96588 .01472 L
.96702 .01472 L
.96812 .01472 L
.96915 .01472 L
.97028 .01472 L
.97149 .01472 L
.97276 .01472 L
.97395 .01472 L
.97503 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.48147 .01472 L
.49012 .01472 L
.49468 .01472 L
.49719 .01472 L
.49842 .01472 L
.49955 .01472 L
.50085 .01472 L
.50154 .01472 L
.50226 .01472 L
.50343 .01472 L
.50471 .01472 L
.50591 .01472 L
.50719 .01472 L
.5084 .01472 L
.5095 .01472 L
.51071 .01473 L
.51183 .01473 L
.51436 .01475 L
.51659 .01476 L
.51896 .01479 L
.52142 .01482 L
.52408 .01487 L
.52888 .01498 L
.53167 .01506 L
.5346 .01517 L
.53984 .0154 L
.54484 .0157 L
.54938 .01603 L
.55958 .01702 L
.56903 .0183 L
.57795 .01988 L
.58767 .02206 L
.59796 .02496 L
.61641 .03191 L
.63599 .04192 L
.6543 .05286 L
.69313 .07552 L
.70326 .08022 L
Mistroke
.70861 .08236 L
.7143 .08432 L
.71977 .08588 L
.72473 .08698 L
.72713 .0874 L
.72971 .08776 L
.7309 .0879 L
.73216 .08802 L
.73332 .08812 L
.7344 .08819 L
.73563 .08824 L
.73627 .08826 L
.73696 .08828 L
.73811 .08829 L
.73938 .08828 L
.7405 .08825 L
.74171 .08819 L
.74286 .08812 L
.74391 .08803 L
.74628 .08779 L
.74886 .08743 L
.75408 .08643 L
.75868 .08528 L
.76359 .08377 L
.77243 .08044 L
.79381 .06977 L
.81398 .05774 L
.85249 .03534 L
.87241 .0269 L
.88244 .0237 L
.89347 .02089 L
.90365 .01888 L
.91295 .01747 L
.91809 .01685 L
.92368 .01629 L
.92893 .01587 L
.93386 .01554 L
.93875 .01529 L
.94324 .01511 L
.94823 .01495 L
.95085 .01489 L
.95361 .01484 L
.95612 .0148 L
.9588 .01477 L
.96133 .01475 L
.96363 .01474 L
.96504 .01473 L
.96634 .01473 L
.96776 .01472 L
.96849 .01472 L
Mistroke
.96928 .01472 L
.97059 .01472 L
.97181 .01472 L
.97256 .01472 L
.97327 .01472 L
.97391 .01472 L
.97461 .01472 L
.97537 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Orthogonalization of the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]Spline Functions"
}], "Subsubsection",
  CellTags->{"S1.3.1", "1.32"}],

Cell[TextData[{
  "We now show how we can orthogonalize ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " to get an orthogonal scaling function using the formula given in (",
  ButtonBox["2.10",
    ButtonData:>{"Wavelets 1.2.5", "5.22"},
    ButtonStyle->"AddOnsLink"],
  "). Here we will refer to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " as the nonorthogonal scaling function and use ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " to denote the (orthogonal) scaling function. Note that for simplicity we \
have omitted the subscript ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", but the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " dependence of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " should be clear. \nThe Fourier transform of the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is "
}], "Text",
  CellTags->{"S1.3.1", "1.33"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\(\[Beta]\_0\)\&^\), \((\[Omega])\), "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Beta]\_0\), \((t)
        \), \(e\^\(-i  \[Omega]  t\)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(\[Integral]\_0\%1\), \(e\^\(-i  \[Omega]  t\)\), " ", 
        
        StyleBox[\("dt"\),
          "TI"], "=", \((1 - e\^\(-i  \[Omega]\))\), "/", \((i  \[Omega])\), 
        "=", \(e\^\(-i  \[Omega]/2\)\), 
        \(\(sin  \[Omega]/2\)\/\(\[Omega]/2\)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.34"}],

Cell[TextData[{
  "Since the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", is the convolution of ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " zeroth order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]splines, its Fourier transform is that of the zeroth order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline raised to the ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " power: "
}], "Text",
  CellTags->{"S1.3.1", "1.35"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Beta]\&^\)\_n\) \((\[Omega])\) = 
      \(e\^\(-i  \[Kappa]\[Omega]/2\)\) 
      \((\(sin  \[Omega]/2\)\/\(\[Omega]/2\))\)\^\(n + 1\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.36"}],

Cell[TextData[{
  "Depending on where the center of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is located, the phase factor ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-i  \[Kappa]\[Omega]/2\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " assumes different values. Our convention is such that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is symmetric about ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " odd and about ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " even. This corresponds to the choice ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is odd and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is even in the above expression. \nTo orthogonalize ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " it is useful to first calculate the quantity ",
  Cell[BoxData[
      \(TraditionalForm\`b \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " which is defined by (see Mallat (1989) and Chui (1992)) "
}], "Text",
  CellTags->{"S1.3.1", "1.37"}],

Cell[BoxData[
    FormBox[
      RowBox[{"b", \((\[Omega])\), "\[Congruent]", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        \(\[LeftBracketingBar]\(\(\[Beta]\&^\)\_n\) \((\[Omega] + 2  \[Pi]  l)
                \)\[RightBracketingBar]\^2\), "=", 
        \(\((2  sin  \[Omega]/2)\)\^\(2 \((n + 1)\)\)\), 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        \(1\/\((\[Omega] + 2  \[Pi]  l)\)\^\(2 \((n + 1)\)\)\), "=", 
        \(\((2  sin  \[Omega]/2)\)\^\(2 \((n + 1)\)\)\), 
        \(\[CapitalSigma]\_\(2 \((n + 1)\)\)\), \((\[Omega])\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.38"}],

Cell["In the last equality we have introduced the notation ", "Text",
  CellTags->{"S1.3.1", "1.39"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalSigma]\_n\), \((\[Omega])\), "\[Congruent]", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(1\/\((\[Omega] + 2  \[Pi]  l)\)\^n\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.40"}],

Cell["It is straightforward to see that ", "Text",
  CellTags->{"S1.3.1", "1.41"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[CapitalSigma]\_n\) \((\[Omega])\) = 
      \(\((\(-1\))\)\^\(n - 2\)\/\(\((n - 1)\)!\)\) 
      \(d\^\(n - 2\)\/\(d  \[Omega]\^\(n - 2\)\)\) \(\[CapitalSigma]\_2\) \((
      \[Omega])\).\)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.42"}],

Cell[TextData[{
  "Let us evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\_2\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " using ",
  StyleBox["Mathematica", "TI"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.43"}],

Cell[TextData[{
  "This gives the result of the infinite sum for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.44"}],

Cell[CellGroupData[{

Cell["Sum[1/(w+2Pi k)^2, {k, -Infinity, Infinity}]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(1\/4\ Csc[w\/2]\^2\)], "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell["Therefore, ", "Text",
  CellTags->{"S1.3.1", "1.45"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[CapitalSigma]\_2\) \((\[Omega])\) = 1\/\(4 \( sin\^2\) \[Omega]/2\).
      \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.46"}],

Cell[TextData[{
  "So, the desired scaling function, that is, the orthogonalized ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", is, in Fourier space, "
}], "Text",
  CellTags->{"S1.3.1", "1.47"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = 
      \(\(\(\[Beta]\&^\)\_n\) \((\[Omega])
          \)\)\/\@\(\(\((2  sin  \[Omega]/2)\)\^\(2 \((n + 1)\)\)\) 
            \(\[CapitalSigma]\_\(2 \((n + 1)\)\)\) \((\[Omega])\)\) 
      \[Congruent] M \((\[Omega])\) \(\(\[Beta]\&^\)\_n\) \((\[Omega])\)\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.48"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`M \((\[Omega])\) = 1/\@\(b \((\[Omega])\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " is an even, ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]periodic function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". To find the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the straightforward procedure is to apply the inverse Fourier transform \
to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". A simpler way of finding ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is to find ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", where "
}], "Text",
  CellTags->{"S1.3.1", "1.49"}],

Cell[BoxData[
    FormBox[
      RowBox[{"M", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(c\_k\), \(e\^\(-i  k  \[Omega]\)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.50"}],

Cell[TextData[{
  "is the discrete Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and the scaling function is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", \((t)\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((t - k)\)}],
         TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " (see Daubechies (1992)). \nWe see that since ",
  Cell[BoxData[
      \(TraditionalForm\`M \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a trigonometric polynomial raised to the negative ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " power, its expansion in terms of Fourier series will have infinite number \
of terms. This in turn shows that, unlike the nonorthogonal scaling function \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the orthogonalized scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " will not have finite support. This means that in principle we need to \
calculate infinitely many ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in order to get ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". However, in practice, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " decay exponentially fast with ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and we can truncate the series at some ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["k", 
          StyleBox[\("max"\),
            "TI"]], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " depending on the required accuracy. \nAs an example, we show explicitly \
how to obtain the orthogonal scaling function for a linear spline (",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ") using ",
  StyleBox["Mathematica", "TI"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.51"}],

Cell[TextData[{
  "First, we define a function ",
  StyleBox["sigma[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["w", "TI"],
  StyleBox["]", "MR"],
  " that gives ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalSigma]\_n\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.52"}],

Cell["\<\
(sigma[2, w_]:=1/(4 Sin[w/2]^2);
 sigma[n_, w_]:= Module[{sig},
 sig[x_]= (-1)^n D[1/Sin[x/2]^2, {x, n-2}]/(4(n-1)!);
 sig[w]])\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "Then for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", we calculate ",
  Cell[BoxData[
      \(TraditionalForm\`b \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.53"}],

Cell[CellGroupData[{

Cell["\<\
(n=1;
 b=Expand[sigma[2(n+1), w] (2 Sin[w/2])^(2n+2)])\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(1\/3 + 2\/3\ Cos[w\/2]\^2\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`M(\[Omega])\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is even, ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are related to what is called the Fourier cosine series coefficients. To \
calculate the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " coefficient of the Fourier cosine series of a periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Omega])\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " with period ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " we use ",
  StyleBox["FourierCosSeriesCoefficient[", "MR"],
  StyleBox["f", "TI"],
  StyleBox["[", "MR"],
  StyleBox["w", "TI"],
  StyleBox["],", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.3.1"],
  StyleBox["w", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["0,", "MR"],
  " ",
  StyleBox["2Pi", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["k", "TI"],
  StyleBox["]", "MR"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 3. The syntax was modified in Version 4 to be more consistent \
with new kernel implementations of the Fourier transform functions."
}], "Text",
  CellTags->{"S1.3.1", "1.54"}],

Cell["This loads the Fourier transform package.", "MathCaption",
  CellTags->{"S1.3.1", "1.55"}],

Cell["Needs[\"Calculus`FourierTransform`\"]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "Here we calculate the Fourier cosine coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`M \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
          \(c\_0\%\[Prime]\), ",", \(c\_1\%\[Prime]\), ",", "...", ",", 
            SubsuperscriptBox["c", 
              StyleBox[\("kmax"\),
                "TI"], "\[Prime]"]}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.56"}],

Cell[CellGroupData[{

Cell["\<\
(kmax=7;
 clist=Table[
 If[$VersionNumber > 3.0,
     NFourierCosCoefficient[1/Sqrt[b], w, i,
     \tFourierParameters -> {1, 1/(2 Pi)}]/(2 Pi),
     NFourierCosSeriesCoefficient[1/Sqrt[b],
     \t{w, 0, N[2Pi]}, i]
\t], {i, 0, kmax}])\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \({1.291675482135203`, \(-0.349326455110599942`\), 
      0.0704202255375570462`, \(-0.0157488486539703735`\), 
      0.00369589142964167471`, \(-0.000891842796748872324`\), 
      0.000219153545743412125`, \(-0.0000545461101113311297`\)}\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "We see that in this case the magnitude of the coefficients indeed decay \
rapidly and we have stopped at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "=", 
          StyleBox[\("kmax"\),
            "TI"], "=", "7"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is approximated by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "-", 
              StyleBox[\("kmax"\),
                "TI"]}], 
            StyleBox[\("kmax"\),
              "TI"],
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_1\), \((t - k)\)}],
         TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(-k\) = c\_k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c\_0 = c\_0\%\[Prime]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_k = c\_k\%\[Prime]/2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k \[NotEqual] 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.57"}],

Cell[TextData[{
  "This is the plot of the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.58"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Table[BSpline[1, x-j], {j, -7, 7}].Join[
Reverse[Rest[clist]], {2clist[[1]]}, Rest[clist]]/2],
{x, -8, 8}, PlotRange -> All, Axes -> False,
Frame -> True, PlotLabel -> \"phi(t)\"]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0845792 0.405872 [
[.05357 -0.0125 -12 -9 ]
[.05357 -0.0125 12 0 ]
[.20238 -0.0125 -6 -9 ]
[.20238 -0.0125 6 0 ]
[.35119 -0.0125 -12 -9 ]
[.35119 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64881 -0.0125 -9 -9 ]
[.64881 -0.0125 9 0 ]
[.79762 -0.0125 -3 -9 ]
[.79762 -0.0125 3 0 ]
[.94643 -0.0125 -9 -9 ]
[.94643 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0034 -24 -4.5 ]
[-0.0125 .0034 0 4.5 ]
[-0.0125 .08458 -6 -4.5 ]
[-0.0125 .08458 0 4.5 ]
[-0.0125 .16575 -18 -4.5 ]
[-0.0125 .16575 0 4.5 ]
[-0.0125 .24693 -18 -4.5 ]
[-0.0125 .24693 0 4.5 ]
[-0.0125 .3281 -18 -4.5 ]
[-0.0125 .3281 0 4.5 ]
[-0.0125 .40928 -18 -4.5 ]
[-0.0125 .40928 0 4.5 ]
[-0.0125 .49045 -6 -4.5 ]
[-0.0125 .49045 0 4.5 ]
[-0.0125 .57163 -18 -4.5 ]
[-0.0125 .57163 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 0 m
.05357 .00625 L
s
[(-7.5)] .05357 -0.0125 0 1 Mshowa
.20238 0 m
.20238 .00625 L
s
[(-5)] .20238 -0.0125 0 1 Mshowa
.35119 0 m
.35119 .00625 L
s
[(-2.5)] .35119 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64881 0 m
.64881 .00625 L
s
[(2.5)] .64881 -0.0125 0 1 Mshowa
.79762 0 m
.79762 .00625 L
s
[(5)] .79762 -0.0125 0 1 Mshowa
.94643 0 m
.94643 .00625 L
s
[(7.5)] .94643 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0034 m
.00625 .0034 L
s
[(-0.2)] -0.0125 .0034 1 0 Mshowa
0 .08458 m
.00625 .08458 L
s
[(0)] -0.0125 .08458 1 0 Mshowa
0 .16575 m
.00625 .16575 L
s
[(0.2)] -0.0125 .16575 1 0 Mshowa
0 .24693 m
.00625 .24693 L
s
[(0.4)] -0.0125 .24693 1 0 Mshowa
0 .3281 m
.00625 .3281 L
s
[(0.6)] -0.0125 .3281 1 0 Mshowa
0 .40928 m
.00625 .40928 L
s
[(0.8)] -0.0125 .40928 1 0 Mshowa
0 .49045 m
.00625 .49045 L
s
[(1)] -0.0125 .49045 1 0 Mshowa
0 .57163 m
.00625 .57163 L
s
[(1.2)] -0.0125 .57163 1 0 Mshowa
.125 Mabswid
0 .0237 m
.00375 .0237 L
s
0 .04399 m
.00375 .04399 L
s
0 .06429 m
.00375 .06429 L
s
0 .10487 m
.00375 .10487 L
s
0 .12517 m
.00375 .12517 L
s
0 .14546 m
.00375 .14546 L
s
0 .18605 m
.00375 .18605 L
s
0 .20634 m
.00375 .20634 L
s
0 .22663 m
.00375 .22663 L
s
0 .26722 m
.00375 .26722 L
s
0 .28752 m
.00375 .28752 L
s
0 .30781 m
.00375 .30781 L
s
0 .3484 m
.00375 .3484 L
s
0 .36869 m
.00375 .36869 L
s
0 .38898 m
.00375 .38898 L
s
0 .42957 m
.00375 .42957 L
s
0 .44986 m
.00375 .44986 L
s
0 .47016 m
.00375 .47016 L
s
0 .51074 m
.00375 .51074 L
s
0 .53104 m
.00375 .53104 L
s
0 .55133 m
.00375 .55133 L
s
0 .59192 m
.00375 .59192 L
s
0 .61221 m
.00375 .61221 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.05357 .61178 m
.05357 .61803 L
s
.20238 .61178 m
.20238 .61803 L
s
.35119 .61178 m
.35119 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64881 .61178 m
.64881 .61803 L
s
.79762 .61178 m
.79762 .61803 L
s
.94643 .61178 m
.94643 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76786 .61428 m
.76786 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0034 m
1 .0034 L
s
.99375 .08458 m
1 .08458 L
s
.99375 .16575 m
1 .16575 L
s
.99375 .24693 m
1 .24693 L
s
.99375 .3281 m
1 .3281 L
s
.99375 .40928 m
1 .40928 L
s
.99375 .49045 m
1 .49045 L
s
.99375 .57163 m
1 .57163 L
s
.125 Mabswid
.99625 .0237 m
1 .0237 L
s
.99625 .04399 m
1 .04399 L
s
.99625 .06429 m
1 .06429 L
s
.99625 .10487 m
1 .10487 L
s
.99625 .12517 m
1 .12517 L
s
.99625 .14546 m
1 .14546 L
s
.99625 .18605 m
1 .18605 L
s
.99625 .20634 m
1 .20634 L
s
.99625 .22663 m
1 .22663 L
s
.99625 .26722 m
1 .26722 L
s
.99625 .28752 m
1 .28752 L
s
.99625 .30781 m
1 .30781 L
s
.99625 .3484 m
1 .3484 L
s
.99625 .36869 m
1 .36869 L
s
.99625 .38898 m
1 .38898 L
s
.99625 .42957 m
1 .42957 L
s
.99625 .44986 m
1 .44986 L
s
.99625 .47016 m
1 .47016 L
s
.99625 .51074 m
1 .51074 L
s
.99625 .53104 m
1 .53104 L
s
.99625 .55133 m
1 .55133 L
s
.99625 .59192 m
1 .59192 L
s
.99625 .61221 m
1 .61221 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(phi\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .08458 m
.04262 .08458 L
.06244 .08457 L
.07216 .08457 L
.0775 .08457 L
.08013 .08457 L
.08128 .08457 L
.08255 .08457 L
.08327 .08457 L
.08394 .08457 L
.08542 .08457 L
.08852 .08457 L
.09396 .08458 L
.10458 .08459 L
.12312 .08461 L
.13291 .08461 L
.13549 .08462 L
.13829 .08462 L
.13957 .08462 L
.14092 .08462 L
.14208 .08462 L
.14335 .08462 L
.1441 .08462 L
.14479 .08462 L
.14632 .08461 L
.1491 .0846 L
.15431 .08458 L
.16449 .08454 L
.17492 .0845 L
.18458 .08447 L
.19383 .08443 L
.1985 .08441 L
.19978 .08441 L
.20046 .08441 L
.20116 .0844 L
.20247 .0844 L
.20366 .08442 L
.22442 .08474 L
.24439 .08506 L
.25309 .08519 L
.25548 .08523 L
.258 .08527 L
.26016 .0853 L
.26138 .08532 L
.26253 .08529 L
.26383 .0852 L
.26507 .08512 L
.26739 .08497 L
.27262 .08462 L
.28214 .08399 L
Mistroke
.29229 .08332 L
.30309 .0826 L
.30846 .08224 L
.31351 .08191 L
.31804 .08161 L
.31928 .08153 L
.32059 .08144 L
.32171 .08147 L
.32294 .08183 L
.34134 .08723 L
.36252 .09346 L
.36739 .09488 L
.37255 .0964 L
.37695 .0977 L
.37816 .09805 L
.37946 .09843 L
.38069 .09879 L
.38181 .09764 L
.39141 .08391 L
.40183 .06899 L
.42077 .04188 L
.42995 .02876 L
.43499 .02155 L
.43746 .01801 L
.43854 .01645 L
.43973 .01475 L
.44105 .01941 L
.44177 .02659 L
.44244 .0333 L
.44536 .06256 L
.45047 .11364 L
.46045 .21339 L
.47906 .39949 L
.48888 .49769 L
.49427 .55152 L
.49691 .57789 L
.49806 .58944 L
.49933 .60209 L
.50055 .60332 L
.50184 .5904 L
.50456 .56325 L
.51034 .50544 L
.52054 .40346 L
.54065 .20235 L
.55073 .10166 L
.55567 .05217 L
.55785 .03044 L
.55908 .01808 L
.56024 .01472 L
.56147 .01648 L
Mistroke
.5628 .01837 L
.5655 .02224 L
.57121 .03041 L
.58118 .04468 L
.60091 .07291 L
.61133 .08782 L
.61433 .09211 L
.6158 .09422 L
.61715 .09615 L
.61838 .09792 L
.61969 .09868 L
.62099 .0983 L
.62243 .09788 L
.64303 .09182 L
.66216 .08621 L
.66696 .08479 L
.67218 .08326 L
.67458 .08256 L
.67589 .08217 L
.67712 .08181 L
.67816 .0815 L
.67929 .08143 L
.68054 .08151 L
.68168 .08159 L
.69263 .08231 L
.7026 .08298 L
.72314 .08434 L
.72829 .08468 L
.73315 .085 L
.73527 .08514 L
.73643 .08522 L
.73752 .08529 L
.73869 .08532 L
.73998 .0853 L
.74224 .08526 L
.76068 .08498 L
.78037 .08467 L
.78536 .08459 L
.79079 .08451 L
.79328 .08447 L
.79464 .08444 L
.79592 .08442 L
.79712 .08441 L
.79842 .0844 L
.79959 .08441 L
.80068 .08441 L
.81922 .08448 L
.83969 .08456 L
.84968 .0846 L
.85198 .0846 L
Mistroke
.85441 .08461 L
.85541 .08462 L
.85649 .08462 L
.85767 .08462 L
.85878 .08462 L
.86331 .08462 L
.86822 .08461 L
.87715 .08461 L
.89682 .08459 L
.90692 .08458 L
.91225 .08457 L
.91366 .08457 L
.91518 .08457 L
.91588 .08457 L
.91662 .08457 L
.91725 .08457 L
.91795 .08457 L
.92341 .08457 L
.92836 .08457 L
.93803 .08457 L
.97619 .08458 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "For comparison, we display the orthogonalized scaling function (solid \
line) along with the linear ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function before orthogonalization (dashed line)."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.59"}],

Cell[CellGroupData[{

Cell["\<\
Show[%, Plot[BSpline[1, x], {x, -8, 8},
PlotStyle -> Dashing[{0.02}],
DisplayFunction -> Identity]]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0845792 0.405872 [
[.05357 -0.0125 -12 -9 ]
[.05357 -0.0125 12 0 ]
[.20238 -0.0125 -6 -9 ]
[.20238 -0.0125 6 0 ]
[.35119 -0.0125 -12 -9 ]
[.35119 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64881 -0.0125 -9 -9 ]
[.64881 -0.0125 9 0 ]
[.79762 -0.0125 -3 -9 ]
[.79762 -0.0125 3 0 ]
[.94643 -0.0125 -9 -9 ]
[.94643 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0034 -24 -4.5 ]
[-0.0125 .0034 0 4.5 ]
[-0.0125 .08458 -6 -4.5 ]
[-0.0125 .08458 0 4.5 ]
[-0.0125 .16575 -18 -4.5 ]
[-0.0125 .16575 0 4.5 ]
[-0.0125 .24693 -18 -4.5 ]
[-0.0125 .24693 0 4.5 ]
[-0.0125 .3281 -18 -4.5 ]
[-0.0125 .3281 0 4.5 ]
[-0.0125 .40928 -18 -4.5 ]
[-0.0125 .40928 0 4.5 ]
[-0.0125 .49045 -6 -4.5 ]
[-0.0125 .49045 0 4.5 ]
[-0.0125 .57163 -18 -4.5 ]
[-0.0125 .57163 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 0 m
.05357 .00625 L
s
[(-7.5)] .05357 -0.0125 0 1 Mshowa
.20238 0 m
.20238 .00625 L
s
[(-5)] .20238 -0.0125 0 1 Mshowa
.35119 0 m
.35119 .00625 L
s
[(-2.5)] .35119 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64881 0 m
.64881 .00625 L
s
[(2.5)] .64881 -0.0125 0 1 Mshowa
.79762 0 m
.79762 .00625 L
s
[(5)] .79762 -0.0125 0 1 Mshowa
.94643 0 m
.94643 .00625 L
s
[(7.5)] .94643 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0034 m
.00625 .0034 L
s
[(-0.2)] -0.0125 .0034 1 0 Mshowa
0 .08458 m
.00625 .08458 L
s
[(0)] -0.0125 .08458 1 0 Mshowa
0 .16575 m
.00625 .16575 L
s
[(0.2)] -0.0125 .16575 1 0 Mshowa
0 .24693 m
.00625 .24693 L
s
[(0.4)] -0.0125 .24693 1 0 Mshowa
0 .3281 m
.00625 .3281 L
s
[(0.6)] -0.0125 .3281 1 0 Mshowa
0 .40928 m
.00625 .40928 L
s
[(0.8)] -0.0125 .40928 1 0 Mshowa
0 .49045 m
.00625 .49045 L
s
[(1)] -0.0125 .49045 1 0 Mshowa
0 .57163 m
.00625 .57163 L
s
[(1.2)] -0.0125 .57163 1 0 Mshowa
.125 Mabswid
0 .0237 m
.00375 .0237 L
s
0 .04399 m
.00375 .04399 L
s
0 .06429 m
.00375 .06429 L
s
0 .10487 m
.00375 .10487 L
s
0 .12517 m
.00375 .12517 L
s
0 .14546 m
.00375 .14546 L
s
0 .18605 m
.00375 .18605 L
s
0 .20634 m
.00375 .20634 L
s
0 .22663 m
.00375 .22663 L
s
0 .26722 m
.00375 .26722 L
s
0 .28752 m
.00375 .28752 L
s
0 .30781 m
.00375 .30781 L
s
0 .3484 m
.00375 .3484 L
s
0 .36869 m
.00375 .36869 L
s
0 .38898 m
.00375 .38898 L
s
0 .42957 m
.00375 .42957 L
s
0 .44986 m
.00375 .44986 L
s
0 .47016 m
.00375 .47016 L
s
0 .51074 m
.00375 .51074 L
s
0 .53104 m
.00375 .53104 L
s
0 .55133 m
.00375 .55133 L
s
0 .59192 m
.00375 .59192 L
s
0 .61221 m
.00375 .61221 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.05357 .61178 m
.05357 .61803 L
s
.20238 .61178 m
.20238 .61803 L
s
.35119 .61178 m
.35119 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64881 .61178 m
.64881 .61803 L
s
.79762 .61178 m
.79762 .61803 L
s
.94643 .61178 m
.94643 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76786 .61428 m
.76786 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0034 m
1 .0034 L
s
.99375 .08458 m
1 .08458 L
s
.99375 .16575 m
1 .16575 L
s
.99375 .24693 m
1 .24693 L
s
.99375 .3281 m
1 .3281 L
s
.99375 .40928 m
1 .40928 L
s
.99375 .49045 m
1 .49045 L
s
.99375 .57163 m
1 .57163 L
s
.125 Mabswid
.99625 .0237 m
1 .0237 L
s
.99625 .04399 m
1 .04399 L
s
.99625 .06429 m
1 .06429 L
s
.99625 .10487 m
1 .10487 L
s
.99625 .12517 m
1 .12517 L
s
.99625 .14546 m
1 .14546 L
s
.99625 .18605 m
1 .18605 L
s
.99625 .20634 m
1 .20634 L
s
.99625 .22663 m
1 .22663 L
s
.99625 .26722 m
1 .26722 L
s
.99625 .28752 m
1 .28752 L
s
.99625 .30781 m
1 .30781 L
s
.99625 .3484 m
1 .3484 L
s
.99625 .36869 m
1 .36869 L
s
.99625 .38898 m
1 .38898 L
s
.99625 .42957 m
1 .42957 L
s
.99625 .44986 m
1 .44986 L
s
.99625 .47016 m
1 .47016 L
s
.99625 .51074 m
1 .51074 L
s
.99625 .53104 m
1 .53104 L
s
.99625 .55133 m
1 .55133 L
s
.99625 .59192 m
1 .59192 L
s
.99625 .61221 m
1 .61221 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(phi\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .08458 m
.04262 .08458 L
.06244 .08457 L
.07216 .08457 L
.0775 .08457 L
.08013 .08457 L
.08128 .08457 L
.08255 .08457 L
.08327 .08457 L
.08394 .08457 L
.08542 .08457 L
.08852 .08457 L
.09396 .08458 L
.10458 .08459 L
.12312 .08461 L
.13291 .08461 L
.13549 .08462 L
.13829 .08462 L
.13957 .08462 L
.14092 .08462 L
.14208 .08462 L
.14335 .08462 L
.1441 .08462 L
.14479 .08462 L
.14632 .08461 L
.1491 .0846 L
.15431 .08458 L
.16449 .08454 L
.17492 .0845 L
.18458 .08447 L
.19383 .08443 L
.1985 .08441 L
.19978 .08441 L
.20046 .08441 L
.20116 .0844 L
.20247 .0844 L
.20366 .08442 L
.22442 .08474 L
.24439 .08506 L
.25309 .08519 L
.25548 .08523 L
.258 .08527 L
.26016 .0853 L
.26138 .08532 L
.26253 .08529 L
.26383 .0852 L
.26507 .08512 L
.26739 .08497 L
.27262 .08462 L
.28214 .08399 L
Mistroke
.29229 .08332 L
.30309 .0826 L
.30846 .08224 L
.31351 .08191 L
.31804 .08161 L
.31928 .08153 L
.32059 .08144 L
.32171 .08147 L
.32294 .08183 L
.34134 .08723 L
.36252 .09346 L
.36739 .09488 L
.37255 .0964 L
.37695 .0977 L
.37816 .09805 L
.37946 .09843 L
.38069 .09879 L
.38181 .09764 L
.39141 .08391 L
.40183 .06899 L
.42077 .04188 L
.42995 .02876 L
.43499 .02155 L
.43746 .01801 L
.43854 .01645 L
.43973 .01475 L
.44105 .01941 L
.44177 .02659 L
.44244 .0333 L
.44536 .06256 L
.45047 .11364 L
.46045 .21339 L
.47906 .39949 L
.48888 .49769 L
.49427 .55152 L
.49691 .57789 L
.49806 .58944 L
.49933 .60209 L
.50055 .60332 L
.50184 .5904 L
.50456 .56325 L
.51034 .50544 L
.52054 .40346 L
.54065 .20235 L
.55073 .10166 L
.55567 .05217 L
.55785 .03044 L
.55908 .01808 L
.56024 .01472 L
.56147 .01648 L
Mistroke
.5628 .01837 L
.5655 .02224 L
.57121 .03041 L
.58118 .04468 L
.60091 .07291 L
.61133 .08782 L
.61433 .09211 L
.6158 .09422 L
.61715 .09615 L
.61838 .09792 L
.61969 .09868 L
.62099 .0983 L
.62243 .09788 L
.64303 .09182 L
.66216 .08621 L
.66696 .08479 L
.67218 .08326 L
.67458 .08256 L
.67589 .08217 L
.67712 .08181 L
.67816 .0815 L
.67929 .08143 L
.68054 .08151 L
.68168 .08159 L
.69263 .08231 L
.7026 .08298 L
.72314 .08434 L
.72829 .08468 L
.73315 .085 L
.73527 .08514 L
.73643 .08522 L
.73752 .08529 L
.73869 .08532 L
.73998 .0853 L
.74224 .08526 L
.76068 .08498 L
.78037 .08467 L
.78536 .08459 L
.79079 .08451 L
.79328 .08447 L
.79464 .08444 L
.79592 .08442 L
.79712 .08441 L
.79842 .0844 L
.79959 .08441 L
.80068 .08441 L
.81922 .08448 L
.83969 .08456 L
.84968 .0846 L
.85198 .0846 L
Mistroke
.85441 .08461 L
.85541 .08462 L
.85649 .08462 L
.85767 .08462 L
.85878 .08462 L
.86331 .08462 L
.86822 .08461 L
.87715 .08461 L
.89682 .08459 L
.90692 .08458 L
.91225 .08457 L
.91366 .08457 L
.91518 .08457 L
.91588 .08457 L
.91662 .08457 L
.91725 .08457 L
.91795 .08457 L
.92341 .08457 L
.92836 .08457 L
.93803 .08457 L
.97619 .08458 L
Mfstroke
[ .02 ] 0 setdash
.02381 .08458 m
.06244 .08458 L
.10458 .08458 L
.14415 .08458 L
.18221 .08458 L
.22272 .08458 L
.26171 .08458 L
.30316 .08458 L
.34309 .08458 L
.3815 .08458 L
.40095 .08458 L
.41127 .08458 L
.42237 .08458 L
.42781 .08458 L
.43298 .08458 L
.43762 .08458 L
.43889 .08458 L
.43959 .08458 L
.44024 .08458 L
.44152 .09172 L
.44268 .09963 L
.46172 .22941 L
.48009 .35472 L
.49053 .42586 L
.49562 .4606 L
.49803 .47705 L
.4991 .48429 L
.50027 .48863 L
.50141 .4808 L
.50263 .47249 L
.50521 .45493 L
.50989 .42301 L
.52021 .35267 L
.54127 .20904 L
.5507 .14478 L
.55584 .10973 L
.55712 .10094 L
.55834 .09265 L
.55943 .0852 L
.56062 .08458 L
.56192 .08458 L
.56313 .08458 L
.56581 .08458 L
.5715 .08458 L
.58147 .08458 L
.62088 .08458 L
.65876 .08458 L
.6991 .08458 L
.73793 .08458 L
.7792 .08458 L
Mistroke
.81897 .08458 L
.85721 .08458 L
.89791 .08458 L
.93709 .08458 L
.97619 .08458 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "We see that the orthogonalized scaling function has a general shape \
similar to that of the linear ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline function around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". This is because ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_1\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " having the largest coefficient. But the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " can be both positive and negative is crucial for the orthogonality. \nWe \
have collected the above ",
  StyleBox["Mathematica", "TI"],
  " commands together and formed a function "
}], "Text",
  CellTags->{"S1.3.1", "1.60"}],

Cell[TextData[{
  StyleBox["SplinePhi[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["kmax", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.1", "1.61"}],

Cell[TextData[{
  "that gives the approximate orthogonal ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order spline scaling function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "-", 
              StyleBox[\("kmax"\),
                "TI"]}], 
            StyleBox[\("kmax"\),
              "TI"],
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((t - k)\)}],
         TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.62"}],

Cell["\<\
For example, this gives the orthogonal spline scaling function of \
order 5.\
\>", "MathCaption",
  CellTags->{"S1.3.1", "1.63"}],

Cell["SplinePhi[5, t, 7];", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S1.3.1"],

Cell["And this is its plot.", "MathCaption",
  CellTags->{"S1.3.1", "1.64"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[%], {t, -10, 10}, PlotRange -> All,
Axes -> False, Frame -> True,
PlotLabel -> \"spline phi(t) of order 5\"]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.111509 0.465292 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01845 -24 -4.5 ]
[-0.0125 .01845 0 4.5 ]
[-0.0125 .11151 -6 -4.5 ]
[-0.0125 .11151 0 4.5 ]
[-0.0125 .20457 -18 -4.5 ]
[-0.0125 .20457 0 4.5 ]
[-0.0125 .29763 -18 -4.5 ]
[-0.0125 .29763 0 4.5 ]
[-0.0125 .39068 -18 -4.5 ]
[-0.0125 .39068 0 4.5 ]
[-0.0125 .48374 -18 -4.5 ]
[-0.0125 .48374 0 4.5 ]
[-0.0125 .5768 -6 -4.5 ]
[-0.0125 .5768 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -72 0 ]
[.5 .63053 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01845 m
.00625 .01845 L
s
[(-0.2)] -0.0125 .01845 1 0 Mshowa
0 .11151 m
.00625 .11151 L
s
[(0)] -0.0125 .11151 1 0 Mshowa
0 .20457 m
.00625 .20457 L
s
[(0.2)] -0.0125 .20457 1 0 Mshowa
0 .29763 m
.00625 .29763 L
s
[(0.4)] -0.0125 .29763 1 0 Mshowa
0 .39068 m
.00625 .39068 L
s
[(0.6)] -0.0125 .39068 1 0 Mshowa
0 .48374 m
.00625 .48374 L
s
[(0.8)] -0.0125 .48374 1 0 Mshowa
0 .5768 m
.00625 .5768 L
s
[(1)] -0.0125 .5768 1 0 Mshowa
.125 Mabswid
0 .04172 m
.00375 .04172 L
s
0 .06498 m
.00375 .06498 L
s
0 .08824 m
.00375 .08824 L
s
0 .13477 m
.00375 .13477 L
s
0 .15804 m
.00375 .15804 L
s
0 .1813 m
.00375 .1813 L
s
0 .22783 m
.00375 .22783 L
s
0 .2511 m
.00375 .2511 L
s
0 .27436 m
.00375 .27436 L
s
0 .32089 m
.00375 .32089 L
s
0 .34415 m
.00375 .34415 L
s
0 .36742 m
.00375 .36742 L
s
0 .41395 m
.00375 .41395 L
s
0 .43721 m
.00375 .43721 L
s
0 .46048 m
.00375 .46048 L
s
0 .50701 m
.00375 .50701 L
s
0 .53027 m
.00375 .53027 L
s
0 .55354 m
.00375 .55354 L
s
0 .60007 m
.00375 .60007 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01845 m
1 .01845 L
s
.99375 .11151 m
1 .11151 L
s
.99375 .20457 m
1 .20457 L
s
.99375 .29763 m
1 .29763 L
s
.99375 .39068 m
1 .39068 L
s
.99375 .48374 m
1 .48374 L
s
.99375 .5768 m
1 .5768 L
s
.125 Mabswid
.99625 .04172 m
1 .04172 L
s
.99625 .06498 m
1 .06498 L
s
.99625 .08824 m
1 .08824 L
s
.99625 .13477 m
1 .13477 L
s
.99625 .15804 m
1 .15804 L
s
.99625 .1813 m
1 .1813 L
s
.99625 .22783 m
1 .22783 L
s
.99625 .2511 m
1 .2511 L
s
.99625 .27436 m
1 .27436 L
s
.99625 .32089 m
1 .32089 L
s
.99625 .34415 m
1 .34415 L
s
.99625 .36742 m
1 .36742 L
s
.99625 .41395 m
1 .41395 L
s
.99625 .43721 m
1 .43721 L
s
.99625 .46048 m
1 .46048 L
s
.99625 .50701 m
1 .50701 L
s
.99625 .53027 m
1 .53027 L
s
.99625 .55354 m
1 .55354 L
s
.99625 .60007 m
1 .60007 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(spline phi\\(t\\) of order 5)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .11151 m
.02499 .11151 L
.02605 .11151 L
.02729 .11151 L
.02846 .11151 L
.02954 .11151 L
.03053 .11151 L
.03163 .11151 L
.03279 .11151 L
.03395 .11151 L
.0352 .11151 L
.03638 .11151 L
.03746 .11151 L
.03873 .11151 L
.03944 .11151 L
.04011 .11151 L
.04132 .11151 L
.04262 .11151 L
.04396 .11151 L
.04519 .1115 L
.04654 .1115 L
.04797 .1115 L
.05038 .1115 L
.05174 .11149 L
.05302 .11149 L
.0554 .11148 L
.05757 .11147 L
.06007 .11145 L
.06244 .11143 L
.06486 .1114 L
.06753 .11136 L
.07031 .11131 L
.07293 .11124 L
.07759 .11109 L
.08022 .11097 L
.08263 .11085 L
.08773 .11052 L
.09332 .11002 L
.09915 .10935 L
.10458 .10857 L
.12332 .10505 L
.13318 .10325 L
.13558 .1029 L
.13815 .10258 L
.13963 .10243 L
.14098 .10232 L
.14234 .10223 L
.14362 .10216 L
.14433 .10214 L
.14496 .10212 L
Mistroke
.14569 .10211 L
.14638 .10211 L
.14761 .10212 L
.1483 .10213 L
.14894 .10216 L
.14963 .10219 L
.15028 .10222 L
.15176 .10233 L
.15319 .10247 L
.15473 .10266 L
.15749 .10311 L
.16009 .10365 L
.16497 .10495 L
.17463 .10845 L
.18512 .11271 L
.18966 .11433 L
.19455 .11571 L
.19591 .116 L
.19735 .11627 L
.19867 .11647 L
.19991 .11662 L
.20107 .11672 L
.20231 .11679 L
.20302 .11681 L
.20369 .11681 L
.20494 .11679 L
.20615 .11672 L
.20684 .11666 L
.20749 .11659 L
.20879 .11642 L
.21019 .11619 L
.21272 .11561 L
.21503 .11494 L
.22064 .11279 L
.22596 .11028 L
.23559 .1056 L
.24046 .10371 L
.2418 .1033 L
.24324 .10292 L
.24459 .10262 L
.24584 .10241 L
.24692 .10227 L
.24807 .10217 L
.24935 .10213 L
.25052 .10215 L
.25173 .10224 L
.25305 .1024 L
.2543 .10263 L
.25544 .1029 L
.25748 .10354 L
Mistroke
.25972 .10445 L
.26425 .10692 L
.27505 .11524 L
.28037 .11964 L
.28531 .12323 L
.2876 .12459 L
.28977 .12565 L
.29096 .12612 L
.29226 .12654 L
.29343 .12683 L
.29452 .12702 L
.29572 .12714 L
.29685 .12715 L
.29808 .12706 L
.2994 .12684 L
.30007 .12668 L
.30079 .12647 L
.3021 .12598 L
.30456 .1247 L
.30696 .12302 L
.30921 .12106 L
.31434 .11538 L
.32472 .10097 L
.32909 .09503 L
.33369 .08977 L
.3361 .08764 L
.33737 .08672 L
.33873 .08592 L
.33999 .08536 L
.34113 .08501 L
.34227 .0848 L
.34335 .08476 L
.34451 .08487 L
.34575 .08519 L
.34692 .08567 L
.34799 .08627 L
.34924 .08717 L
.3506 .08839 L
.35308 .09125 L
.35567 .09509 L
.35843 .10006 L
.36338 .11088 L
.373 .135 L
.37722 .14473 L
.37945 .14919 L
.38184 .15323 L
.3832 .15514 L
.38444 .15659 L
.38569 .15777 L
.38686 .15859 L
Mistroke
.38818 .15917 L
.3894 .15937 L
.39004 .15934 L
.39074 .15919 L
.39148 .15892 L
.39216 .15854 L
.39285 .15806 L
.3936 .15739 L
.39497 .15581 L
.3963 .15383 L
.39753 .15159 L
.40033 .1451 L
.40331 .13611 L
.41389 .09078 L
.42349 .04506 L
.42836 .0271 L
.43082 .02066 L
.43221 .01796 L
.43351 .01614 L
.43471 .01511 L
.43584 .01472 L
.43686 .01488 L
.43796 .01563 L
.43916 .01715 L
.44044 .01959 L
.44153 .02237 L
.44273 .02621 L
.44543 .03777 L
.4479 .05206 L
.45347 .09714 L
.45838 .15055 L
.46355 .21787 L
.47381 .36806 L
.47885 .43992 L
.48351 .49909 L
.48765 .54294 L
.48985 .56196 L
.49221 .57869 L
.49344 .58582 L
.49458 .59131 L
.49572 .59587 L
.49679 .59914 L
.49798 .60171 L
.49928 .60318 L
.50043 .60332 L
.50164 .60227 L
.50229 .60123 L
.50297 .59975 L
.50419 .59616 L
.5055 .59096 L
Mistroke
.50694 .58371 L
.50952 .56682 L
.51193 .54683 L
.52125 .43854 L
.53201 .28168 L
.5373 .20619 L
.54219 .14376 L
.54684 .09422 L
.55196 .05299 L
.55462 .03754 L
.55711 .02677 L
.55848 .02233 L
.55974 .01919 L
.56046 .01778 L
.56112 .01672 L
.56182 .01585 L
.56258 .01519 L
.56374 .01472 L
.565 .01495 L
.56619 .01582 L
.56728 .01717 L
.56827 .01881 L
.56936 .02106 L
.57156 .02686 L
.57651 .04508 L
.58114 .06635 L
.58613 .09091 L
.59157 .11626 L
.59636 .13499 L
.59899 .14323 L
.60146 .14947 L
.60366 .15375 L
.60479 .15548 L
.60603 .15701 L
.60732 .15818 L
.60802 .15865 L
.60867 .15898 L
.60984 .15932 L
.61109 .15933 L
.61224 .15903 L
.61349 .15838 L
.61467 .15746 L
.61576 .15638 L
.61782 .15374 L
.62001 .15018 L
.63014 .1271 L
.63513 .11447 L
.63977 .10375 L
.6443 .09513 L
.64628 .09212 L
Mistroke
.64841 .08943 L
.64964 .08816 L
.65077 .08717 L
.65191 .08634 L
.65298 .08572 L
.65411 .08524 L
.65535 .0849 L
.65655 .08476 L
.65785 .08482 L
.65915 .08508 L
.66035 .08549 L
.66166 .08614 L
.66306 .08702 L
.66541 .08892 L
.668 .09155 L
.67726 .1038 L
.68257 .11133 L
.68816 .11833 L
.69293 .12293 L
.69563 .12482 L
.69814 .12608 L
.69935 .12651 L
.70067 .12686 L
.7019 .12706 L
.70305 .12715 L
.70408 .12715 L
.70521 .12706 L
.70639 .12687 L
.7075 .12661 L
.70879 .12621 L
.71002 .12574 L
.71232 .12463 L
.7175 .12128 L
.7276 .11302 L
.73314 .10869 L
.73586 .10685 L
.73835 .1054 L
.74074 .10424 L
.74336 .10325 L
.74473 .10286 L
.746 .10257 L
.74734 .10235 L
.74809 .10225 L
.74877 .10219 L
.74998 .10213 L
.7511 .10214 L
.75232 .1022 L
.75362 .10233 L
.75475 .1025 L
.7558 .1027 L
Mistroke
.75821 .1033 L
.76283 .10493 L
.76707 .10682 L
.77661 .11153 L
.78136 .11363 L
.78398 .11461 L
.78644 .11539 L
.78874 .11597 L
.78995 .11621 L
.79123 .11643 L
.79231 .11657 L
.79349 .11669 L
.79457 .11676 L
.79557 .1168 L
.79686 .11681 L
.79759 .11679 L
.79826 .11676 L
.79949 .11668 L
.8008 .11654 L
.80197 .11638 L
.80307 .1162 L
.80557 .11568 L
.81073 .1142 L
.81629 .11216 L
.82666 .10794 L
.83631 .10457 L
.84118 .10337 L
.84391 .10287 L
.84638 .10252 L
.8478 .10237 L
.8491 .10227 L
.85053 .10218 L
.85126 .10215 L
.85205 .10212 L
.85275 .10211 L
.85338 .10211 L
.85412 .10211 L
.85482 .10212 L
.85606 .10215 L
.85676 .10218 L
.85741 .10221 L
.85869 .1023 L
.86006 .10241 L
.86249 .10266 L
.86799 .10343 L
.87795 .10531 L
.88769 .10724 L
.89656 .10875 L
.90605 .10996 L
.91128 .11044 L
Mistroke
.91622 .11078 L
.92079 .11102 L
.92501 .11118 L
.92964 .1113 L
.93198 .11135 L
.93456 .11139 L
.93692 .11142 L
.93949 .11145 L
.94217 .11147 L
.94467 .11148 L
.94702 .11149 L
.94915 .1115 L
.95033 .1115 L
.95161 .1115 L
.95393 .1115 L
.95523 .11151 L
.95644 .11151 L
.95778 .11151 L
.95921 .11151 L
.95992 .11151 L
.9607 .11151 L
.96139 .11151 L
.96212 .11151 L
.96285 .11151 L
.96351 .11151 L
.96479 .11151 L
.96608 .11151 L
.96727 .11151 L
.96857 .11151 L
.96923 .11151 L
.96995 .11151 L
.97116 .11151 L
.97246 .11151 L
.97368 .11151 L
.97479 .11151 L
.97546 .11151 L
.97619 .11151 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell["\<\
In calculating the above spline scaling function, sometimes it is \
useful to have some control over the magnitude of the terms we neglect. For \
example, instead of specifying the number of coefficients, we can specify a \
small positive number which we call tolerance; the function \
\>", "Text",
  CellTags->{"S1.3.1", "1.65"}],

Cell[TextData[{
  StyleBox["SplinePhi[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["tol", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.1", "1.66"}],

Cell[TextData[{
  "gives the approximate orthogonal ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order spline scaling function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "-", 
              StyleBox[\("kmax"\),
                "TI"]}], 
            StyleBox[\("kmax"\),
              "TI"],
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((t - k)\)}],
         TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            SubscriptBox["c", 
              RowBox[{
                StyleBox[\("kmax"\),
                  "TI"], "+", "1"}]], "\[RightBracketingBar]"}], "<", 
          StyleBox[\("tol"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.67"}],

Cell[TextData[{
  "In this example, we neglect coefficients ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c\_k \[VerticalSeparator]  < 0.005\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.68"}],

Cell["phi2[t_] = SplinePhi[2, t, 0.005];", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "In this case, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "5"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.69"}],

Cell[CellGroupData[{

Cell["Length[phi2[t]]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(11\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "In the above, we have explicitly defined the second order spline scaling \
function to be ",
  StyleBox["phi2[", "MR"],
  StyleBox["t", "TI"],
  StyleBox["]", "MR"],
  ", so we can plot the translated and dilated versions of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". For example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t + 1)\), \[Phi] \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((2  t - 4)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are plotted together here."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.70"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{phi2[t+1], phi2[t], phi2[2t-4]}],
{t, -6, 6}, PlotRange -> All,
Ticks -> {Range[-6, 6, 2], {1}},
PlotLabel -> \"phi2(t+1), phi2(t), phi2(2t-4)\"]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.0987638 0.461491 [
[.02381 .08626 -6 -9 ]
[.02381 .08626 6 0 ]
[.18254 .08626 -6 -9 ]
[.18254 .08626 6 0 ]
[.34127 .08626 -6 -9 ]
[.34127 .08626 6 0 ]
[.65873 .08626 -3 -9 ]
[.65873 .08626 3 0 ]
[.81746 .08626 -3 -9 ]
[.81746 .08626 3 0 ]
[.97619 .08626 -3 -9 ]
[.97619 .08626 3 0 ]
[.4875 .56025 -6 -4.5 ]
[.4875 .56025 0 4.5 ]
[.5 .63053 -90 0 ]
[.5 .63053 90 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .09876 m
.02381 .10501 L
s
[(-6)] .02381 .08626 0 1 Mshowa
.18254 .09876 m
.18254 .10501 L
s
[(-4)] .18254 .08626 0 1 Mshowa
.34127 .09876 m
.34127 .10501 L
s
[(-2)] .34127 .08626 0 1 Mshowa
.65873 .09876 m
.65873 .10501 L
s
[(2)] .65873 .08626 0 1 Mshowa
.81746 .09876 m
.81746 .10501 L
s
[(4)] .81746 .08626 0 1 Mshowa
.97619 .09876 m
.97619 .10501 L
s
[(6)] .97619 .08626 0 1 Mshowa
0 .09876 m
1 .09876 L
s
.5 .56025 m
.50625 .56025 L
s
[(1)] .4875 .56025 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(phi2\\(t+1\\), phi2\\(t\\), phi2\\(2t-4\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .09729 m
.02605 .09721 L
.02846 .09714 L
.03053 .09709 L
.03279 .09704 L
.03416 .09702 L
.03543 .097 L
.03665 .09699 L
.03793 .09698 L
.03908 .09697 L
.04016 .09697 L
.04135 .09697 L
.04262 .09697 L
.04393 .09698 L
.04516 .09699 L
.0465 .097 L
.04793 .09702 L
.05057 .09706 L
.05297 .09712 L
.05785 .09727 L
.06244 .09746 L
.07299 .09806 L
.08269 .09882 L
.09333 .09989 L
.10458 .10127 L
.10945 .10181 L
.11406 .10218 L
.1166 .10233 L
.11795 .10239 L
.11937 .10245 L
.12057 .10248 L
.12189 .10251 L
.12309 .10253 L
.12422 .10254 L
.12529 .10254 L
.12646 .10254 L
.12768 .10252 L
.12882 .1025 L
.12989 .10247 L
.13086 .10244 L
.13304 .10235 L
.13539 .10221 L
.13793 .10203 L
.14255 .10161 L
.14744 .10101 L
.15202 .10032 L
.16243 .09828 L
.17257 .09566 L
.18347 .09215 L
.18838 .09071 L
Mistroke
.19107 .09008 L
.1936 .08961 L
.19505 .08939 L
.19661 .08918 L
.19791 .08905 L
.19933 .08893 L
.20068 .08884 L
.20141 .08881 L
.2021 .08879 L
.20333 .08877 L
.20464 .08878 L
.2053 .08879 L
.20599 .08882 L
.20724 .08888 L
.20793 .08892 L
.20858 .08897 L
.21005 .08911 L
.21251 .08942 L
.21517 .08987 L
.22017 .09103 L
.22475 .09246 L
.23458 .0967 L
.24371 .10208 L
.25437 .1101 L
.2596 .11473 L
.26442 .11919 L
.26921 .12266 L
.27162 .12398 L
.27427 .1251 L
.27565 .12555 L
.27692 .12587 L
.27762 .12602 L
.27839 .12615 L
.27911 .12625 L
.27977 .12632 L
.28096 .12639 L
.28227 .12638 L
.28293 .12635 L
.28364 .12629 L
.28492 .12611 L
.28609 .12588 L
.28718 .12561 L
.28964 .12478 L
.29205 .12367 L
.29462 .12218 L
.29928 .11864 L
.30352 .1145 L
.31349 .10126 L
.32268 .08472 L
.33342 .06014 L
Mistroke
.33867 .04605 L
.34347 .03253 L
.34569 .02735 L
.3481 .0227 L
.35038 .01929 L
.3525 .01697 L
.35377 .01597 L
.35497 .01529 L
.35604 .01491 L
.3572 .01472 L
.35847 .0148 L
.35911 .01495 L
.35981 .0152 L
.36105 .01587 L
.36221 .01674 L
.36349 .01798 L
.36489 .01968 L
.36742 .02366 L
.37217 .03425 L
.37771 .05179 L
.38284 .07298 L
.39248 .12569 L
.40152 .19046 L
.42213 .39294 L
.43197 .4874 L
.43692 .52433 L
.44233 .55662 L
.44696 .5776 L
.44956 .58662 L
.45192 .59314 L
.45412 .59778 L
.45536 .59977 L
.4565 .60122 L
.45751 .60218 L
.45861 .6029 L
.45976 .60327 L
.46083 .60328 L
.46209 .60287 L
.46279 .60244 L
.46342 .60193 L
.46466 .6006 L
.46582 .59895 L
.46843 .59382 L
.47125 .58607 L
.47641 .56599 L
.48114 .54079 L
.49016 .47484 L
.49968 .37983 L
.50992 .27156 L
.5196 .18664 L
Mistroke
.52902 .12028 L
.53772 .0733 L
.54227 .0542 L
.5471 .03805 L
.55195 .02608 L
.5547 .02118 L
.55729 .01783 L
.55858 .01661 L
.55926 .01609 L
.55998 .01562 L
.56068 .01526 L
.56131 .01502 L
.56255 .01475 L
.56374 .01475 L
.56503 .01504 L
.56625 .01559 L
.56737 .01633 L
.56867 .01748 L
.56988 .01883 L
.57264 .02289 L
.57533 .02818 L
.57822 .03531 L
.58782 .06166 L
.59802 .08486 L
.60334 .09492 L
.60921 .1044 L
.61461 .11163 L
.61957 .117 L
.62438 .12106 L
.62683 .12269 L
.62945 .1241 L
.63083 .12471 L
.63209 .12518 L
.63336 .12559 L
.63454 .12588 L
.63592 .12615 L
.63664 .12625 L
.63741 .12632 L
.63869 .12639 L
.63942 .12639 L
.64011 .12637 L
.6413 .12628 L
.6426 .12609 L
.64383 .12585 L
.64497 .12555 L
.64712 .12481 L
.64941 .12378 L
.65465 .12044 L
.6594 .11627 L
.66957 .10742 L
Mistroke
.6803 .09993 L
.68946 .09505 L
.69466 .0929 L
.69951 .0913 L
.70191 .09066 L
.70452 .09006 L
.70682 .08963 L
.70926 .08927 L
.71145 .08902 L
.7127 .08892 L
.71388 .08885 L
.71495 .08881 L
.71593 .08878 L
.71701 .08877 L
.71814 .08878 L
.71939 .08882 L
.72053 .08888 L
.72185 .08897 L
.72308 .08908 L
.72529 .08934 L
.72768 .08972 L
.7331 .09093 L
.7381 .09247 L
.74793 .09562 L
.75849 .09834 L
.7636 .09942 L
.76845 .10029 L
.77277 .10095 L
.77754 .10155 L
.78211 .10199 L
.78461 .10217 L
.78697 .10231 L
.78916 .10242 L
.79116 .10248 L
.79222 .10251 L
.79337 .10253 L
.79457 .10254 L
.7957 .10254 L
.79693 .10254 L
.79763 .10253 L
.79827 .10252 L
.79945 .1025 L
.8007 .10246 L
.80286 .10238 L
.80525 .10226 L
.80779 .10209 L
.81053 .10187 L
.81547 .10134 L
.83518 .09907 L
.84634 .09815 L
Mistroke
.85168 .0978 L
.8567 .09753 L
.86154 .09731 L
.86409 .09722 L
.86678 .09714 L
.86905 .09709 L
.87155 .09704 L
.87264 .09702 L
.87381 .097 L
.87484 .09699 L
.87593 .09698 L
.87658 .09698 L
.8773 .09697 L
.87856 .09697 L
.87927 .09697 L
.88004 .09697 L
.88077 .09697 L
.88143 .09697 L
.88264 .09698 L
.88333 .09698 L
.88397 .09699 L
.88535 .09701 L
.88664 .09702 L
.88912 .09707 L
.89137 .09712 L
.89642 .09728 L
.91474 .09788 L
.92515 .09815 L
.93489 .09836 L
.94448 .09853 L
.9494 .0986 L
.95477 .09866 L
.96041 .09871 L
.96301 .09872 L
.96577 .09874 L
.96851 .09875 L
.97098 .09876 L
.97218 .09876 L
.97347 .09876 L
.97469 .09876 L
.97582 .09876 L
.97619 .09876 L
Mfstroke
.02381 .09876 m
.02499 .09876 L
.02605 .09876 L
.02729 .09876 L
.02846 .09876 L
.03053 .09875 L
.03279 .09874 L
.03527 .09873 L
.0379 .09872 L
.04262 .09868 L
.04749 .09863 L
.05205 .09858 L
.06244 .09841 L
.07305 .0982 L
.08274 .09795 L
.09407 .09761 L
.09958 .09742 L
.10458 .09724 L
.10685 .09717 L
.10931 .0971 L
.11144 .09706 L
.11377 .09702 L
.11505 .097 L
.11625 .09699 L
.11751 .09698 L
.11822 .09697 L
.11887 .09697 L
.12003 .09697 L
.12128 .09697 L
.12247 .09697 L
.12357 .09698 L
.12475 .09699 L
.12603 .097 L
.12834 .09704 L
.13109 .09709 L
.13361 .09715 L
.13881 .09733 L
.14429 .09758 L
.15383 .09816 L
.16403 .099 L
.1824 .10107 L
.18737 .10166 L
.19264 .10212 L
.19539 .1023 L
.19685 .10237 L
.19842 .10243 L
.19985 .10248 L
.20117 .10251 L
.20249 .10253 L
.20374 .10254 L
Mistroke
.20501 .10254 L
.20617 .10253 L
.2068 .10252 L
.2075 .10251 L
.20875 .10248 L
.20992 .10245 L
.21116 .1024 L
.21338 .1023 L
.21598 .10213 L
.2184 .10194 L
.22389 .10138 L
.22892 .10071 L
.23437 .0998 L
.24429 .09769 L
.26286 .09214 L
.26739 .0908 L
.27228 .08973 L
.27508 .08929 L
.2763 .08915 L
.27764 .08901 L
.27891 .08891 L
.28009 .08884 L
.28134 .08879 L
.28204 .08878 L
.28267 .08877 L
.28398 .08878 L
.28465 .08879 L
.28537 .08882 L
.28666 .08888 L
.28786 .08897 L
.28928 .0891 L
.29058 .08925 L
.29349 .08968 L
.296 .09017 L
.29872 .09082 L
.30369 .09232 L
.31307 .09626 L
.32344 .10232 L
.33439 .11066 L
.33919 .11494 L
.34444 .11973 L
.34679 .1215 L
.34931 .12309 L
.35149 .12422 L
.35385 .12517 L
.35524 .12561 L
.35652 .12592 L
.35774 .12615 L
.35904 .12631 L
.3602 .12638 L
Mistroke
.36129 .12639 L
.36248 .12633 L
.36376 .12619 L
.36443 .12609 L
.36515 .12595 L
.36643 .12564 L
.36796 .12517 L
.36935 .12464 L
.37208 .12332 L
.37465 .12174 L
.37944 .11794 L
.38461 .11256 L
.39413 .09922 L
.40456 .07946 L
.41559 .05278 L
.4204 .03925 L
.42294 .03227 L
.42563 .02613 L
.42811 .02165 L
.42943 .01972 L
.43084 .01799 L
.43214 .01673 L
.43333 .01584 L
.43447 .01523 L
.43566 .01484 L
.4368 .01472 L
.43801 .01484 L
.43916 .0152 L
.4402 .01573 L
.44142 .01661 L
.44275 .01787 L
.44516 .02096 L
.44768 .02533 L
.45045 .03146 L
.45604 .0481 L
.46123 .06857 L
.46608 .09213 L
.4765 .15716 L
.48638 .23706 L
.50492 .42902 L
.51454 .51216 L
.51992 .54697 L
.52478 .57129 L
.52934 .5879 L
.53191 .5946 L
.53313 .59713 L
.53427 .59909 L
.53535 .60061 L
.53634 .60171 L
.53744 .60259 L
Mistroke
.53861 .60315 L
.53974 .60332 L
.54096 .60308 L
.54212 .60246 L
.54319 .60155 L
.54443 .60006 L
.54562 .59824 L
.54784 .59372 L
.55023 .58726 L
.55285 .57831 L
.55754 .5573 L
.5619 .53209 L
.57188 .45375 L
.58253 .3409 L
.5928 .23868 L
.60393 .14966 L
.60903 .11631 L
.61443 .0862 L
.61948 .06278 L
.6241 .04546 L
.62642 .03817 L
.62896 .03136 L
.63115 .02642 L
.63357 .02197 L
.63612 .01841 L
.63753 .01697 L
.63884 .01593 L
.64007 .01526 L
.64119 .01487 L
.64242 .01472 L
.64372 .01485 L
.64487 .01522 L
.64592 .01577 L
.64712 .01664 L
.64826 .01771 L
.65028 .02019 L
.65248 .02372 L
.65746 .03497 L
.66205 .04807 L
.67109 .07116 L
.68081 .09149 L
.68638 .10105 L
.69147 .10845 L
.6963 .1143 L
.70145 .11926 L
.70411 .12132 L
.70662 .12294 L
.70906 .12422 L
.71131 .12513 L
.71345 .12578 L
Mistroke
.71453 .12601 L
.71571 .12621 L
.7169 .12633 L
.71817 .12639 L
.71937 .12638 L
.72046 .1263 L
.72175 .12613 L
.7224 .12602 L
.72311 .12586 L
.72556 .12516 L
.72694 .12463 L
.72843 .12395 L
.73111 .12246 L
.73637 .1185 L
.74119 .114 L
.75036 .10631 L
.76015 .09964 L
.76577 .09652 L
.77088 .09415 L
.77563 .09233 L
.78086 .09076 L
.78572 .08971 L
.78838 .0893 L
.78965 .08914 L
.79086 .08902 L
.79197 .08893 L
.79318 .08885 L
.79428 .08881 L
.7953 .08878 L
.7964 .08877 L
.79761 .08878 L
.79888 .08882 L
.80007 .08889 L
.80128 .08897 L
.80261 .0891 L
.80529 .08943 L
.80777 .08985 L
.81008 .09034 L
.8153 .09175 L
.82088 .09363 L
.8311 .09668 L
.84219 .09927 L
.84728 .1002 L
.85267 .10103 L
.85727 .10159 L
.86233 .10205 L
.86482 .10223 L
.86613 .1023 L
.86753 .10237 L
.86888 .10243 L
Mistroke
.87009 .10247 L
.87132 .1025 L
.87247 .10252 L
.8736 .10254 L
.87479 .10254 L
.87581 .10254 L
.87693 .10253 L
.87813 .10251 L
.87942 .10248 L
.88064 .10245 L
.88175 .1024 L
.88442 .10227 L
.88688 .10211 L
.89247 .10161 L
.90263 .10036 L
.91161 .09936 L
.9213 .09848 L
.92684 .09807 L
.93193 .09775 L
.93675 .09749 L
.9419 .09728 L
.94635 .09714 L
.95039 .09705 L
.95234 .09701 L
.95336 .097 L
.95445 .09699 L
.9554 .09698 L
.95644 .09698 L
.95739 .09697 L
.95828 .09697 L
.95939 .09697 L
.96059 .09697 L
.96174 .09698 L
.96279 .09699 L
.96384 .097 L
.96479 .09701 L
.96691 .09704 L
.96921 .09708 L
.97169 .09715 L
.97619 .09729 L
Mfstroke
.02381 .09876 m
.06244 .09876 L
.10458 .09876 L
.14415 .09876 L
.18221 .09876 L
.22272 .09876 L
.26171 .09876 L
.30316 .09876 L
.34309 .09876 L
.3815 .09876 L
.40134 .09876 L
.41134 .09876 L
.41408 .09876 L
.41703 .09876 L
.41846 .09876 L
.41917 .09876 L
.41982 .09876 L
.42104 .09876 L
.42168 .09876 L
.42237 .09876 L
.42361 .09876 L
.42431 .09875 L
.42497 .09875 L
.4263 .09873 L
.42772 .09872 L
.4303 .09868 L
.43265 .09863 L
.43836 .09847 L
.44378 .09826 L
.45344 .09776 L
.45886 .0974 L
.46151 .09721 L
.46268 .09714 L
.46395 .09708 L
.46509 .09703 L
.46615 .097 L
.46727 .09698 L
.46847 .09697 L
.46979 .09697 L
.47103 .09699 L
.47214 .09701 L
.47335 .09705 L
.4746 .0971 L
.47597 .09718 L
.47875 .09738 L
.48132 .09762 L
.48372 .0979 L
.48901 .09869 L
.49385 .09962 L
.49912 .10086 L
Mistroke
.50201 .10158 L
.50343 .10186 L
.50473 .10208 L
.50592 .10224 L
.50722 .10238 L
.50853 .10247 L
.50924 .10251 L
.50991 .10253 L
.5111 .10254 L
.51218 .10252 L
.51342 .10247 L
.5146 .10238 L
.51571 .10226 L
.51688 .10211 L
.51899 .10175 L
.52125 .10124 L
.52375 .10054 L
.52891 .0986 L
.53446 .0958 L
.53966 .09249 L
.54219 .09092 L
.54449 .08987 L
.54564 .08947 L
.54688 .08915 L
.54805 .08893 L
.54913 .08881 L
.55028 .08877 L
.55154 .08883 L
.55286 .089 L
.55409 .08926 L
.55544 .08967 L
.55673 .09017 L
.55914 .0914 L
.56174 .09316 L
.56457 .09558 L
.56988 .10157 L
.57553 .10999 L
.57811 .11454 L
.58083 .11953 L
.58314 .12281 L
.58446 .1242 L
.58568 .12519 L
.5869 .12588 L
.58805 .12627 L
.58908 .12639 L
.5902 .12629 L
.59142 .1259 L
.59272 .12516 L
.59382 .12427 L
.59504 .12302 L
Mistroke
.59755 .1195 L
.60025 .11433 L
.60513 .10135 L
.61002 .08362 L
.61467 .0624 L
.61917 .03786 L
.62024 .03206 L
.62137 .02684 L
.62242 .02284 L
.6234 .01983 L
.62455 .01717 L
.62582 .01536 L
.62708 .01472 L
.62779 .01486 L
.62844 .01531 L
.62956 .0168 L
.63078 .01947 L
.63193 .02298 L
.633 .02708 L
.63536 .03908 L
.63796 .057 L
.64322 .10829 L
.64779 .16907 L
.65271 .25148 L
.66161 .4374 L
.66401 .48106 L
.66658 .52033 L
.66879 .54816 L
.67119 .57192 L
.67266 .58319 L
.67402 .59136 L
.67531 .5972 L
.67597 .5994 L
.67668 .60126 L
.67793 .60308 L
.67862 .60332 L
.67926 .60305 L
.6805 .60118 L
.68167 .59778 L
.68236 .59505 L
.683 .59199 L
.68421 .58498 L
.68691 .56318 L
.68925 .53755 L
.69177 .50281 L
.69751 .39646 L
.70277 .28321 L
.70749 .19814 L
.71255 .125 L
.715 .09619 L
Mistroke
.71731 .07295 L
.71938 .05552 L
.72165 .0399 L
.72415 .02705 L
.72552 .02194 L
.72681 .01838 L
.728 .01614 L
.7291 .015 L
.73036 .01477 L
.73157 .01562 L
.73286 .01771 L
.73358 .0194 L
.73424 .02126 L
.73671 .03113 L
.74233 .06172 L
.7472 .08397 L
.75235 .1024 L
.75675 .11401 L
.75924 .1189 L
.76157 .12237 L
.76286 .12383 L
.76354 .12447 L
.76427 .12505 L
.7649 .12547 L
.7656 .12584 L
.76682 .12627 L
.76801 .1264 L
.7693 .12622 L
.77051 .12576 L
.77162 .12508 L
.77291 .12398 L
.77412 .12266 L
.77686 .1186 L
.78239 .10871 L
.78743 .10135 L
.79009 .09815 L
.7929 .09527 L
.79536 .09319 L
.79807 .09136 L
.79926 .09071 L
.80053 .09012 L
.80165 .08969 L
.80284 .08932 L
.80407 .08904 L
.80522 .08887 L
.80592 .0888 L
.80658 .08877 L
.80782 .0888 L
.809 .08892 L
.81009 .08911 L
Mistroke
.81128 .08941 L
.81255 .08983 L
.81474 .09081 L
.81678 .09201 L
.82142 .09505 L
.82644 .09778 L
.82908 .09897 L
.83189 .10004 L
.83434 .10082 L
.83704 .10152 L
.83823 .10176 L
.8395 .10199 L
.84069 .10217 L
.8418 .1023 L
.8429 .10241 L
.84406 .10249 L
.84535 .10253 L
.84653 .10254 L
.84775 .10251 L
.84845 .10248 L
.84908 .10244 L
.85025 .10235 L
.85149 .1022 L
.85368 .10187 L
.85572 .10144 L
.86037 .10028 L
.86536 .0992 L
.8708 .09826 L
.87329 .09792 L
.87593 .09761 L
.87822 .09739 L
.88069 .09721 L
.88184 .09714 L
.88305 .09708 L
.88409 .09704 L
.88523 .09701 L
.8863 .09698 L
.88744 .09697 L
.88852 .09697 L
.8895 .09698 L
.89075 .097 L
.8919 .09703 L
.89316 .09708 L
.8945 .09714 L
.89923 .09746 L
.90865 .09804 L
.91394 .09829 L
.91877 .09847 L
.92326 .0986 L
.9258 .09866 L
Mistroke
.92816 .0987 L
.92932 .09872 L
.93042 .09873 L
.93142 .09874 L
.93247 .09875 L
.93363 .09876 L
.93468 .09876 L
.93582 .09876 L
.93708 .09876 L
.93834 .09876 L
.93951 .09876 L
.94079 .09876 L
.94143 .09876 L
.94215 .09876 L
.94334 .09876 L
.94463 .09876 L
.94584 .09876 L
.94695 .09876 L
.94804 .09876 L
.94905 .09876 L
.95015 .09876 L
.95134 .09876 L
.95258 .09876 L
.95376 .09876 L
.95481 .09876 L
.95596 .09876 L
.95721 .09876 L
.95839 .09876 L
.95968 .09876 L
.96041 .09876 L
.96107 .09876 L
.96176 .09876 L
.9624 .09876 L
.9631 .09876 L
.96385 .09876 L
.96456 .09876 L
.96523 .09876 L
.96648 .09876 L
.97619 .09876 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "We can check the orthogonality by explicitly doing the numerical \
integration using ",
  StyleBox["Mathematica", "TI"],
  ". Note that since the scaling function we calculated is an approximation \
due to truncation of the sum, the integral is not exactly zero."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.71"}],

Cell[CellGroupData[{

Cell["NIntegrate[Evaluate[phi2[t] phi2[t-1]], {t, -8, 8}]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(\(-1.07118094233929483`*^-6\)\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell["\<\
As we include more terms in the sum, the integral is closer to 0.\
\
\>", "MathCaption",
  CellTags->{"S1.3.1", "1.72"}],

Cell[CellGroupData[{

Cell["\<\
(phi2[t_] = SplinePhi[2, t, 0.0001];
 NIntegrate[Evaluate[phi2[t] phi2[t-1]], {t, -8, 8}])\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \(7.75438977541497287`*^-8\)], "Output",
  CellLabel->"Out[21]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell["Spline Filters and Wavelets", "Subsubsection",
  CellTags->{"S1.3.1", "1.73"}],

Cell[TextData[{
  "We saw in the last section that from the space of polynomial splines of \
order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " we can form a multiresolution analysis with the scaling function which is \
a superposition of the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "\[Hyphen]spline functions of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". We also know from Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  " that associated with each multiresolution analysis is an orthonormal \
wavelet basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(2\^\(j/2\)\) \[Psi] \((\(2\^j\) t - k)\)}\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  ". The mother wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is obtained from the wavelet equation"
}], "Text",
  CellTags->{"S1.3.1", "1.74"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(\@2\), \(g\_k\), "\[Phi]", \((2  t - k)
        \)}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.75"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is the scaling function of the multiresolution analysis and the \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are related to ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " through "
}], "Text",
  CellTags->{"S1.3.1", "1.76"}],

Cell[BoxData[
    \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) h\_\(1 - k\).\)], 
  "DisplayFormula",
  CellTags->{"S1.3.1", "1.77"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are the coefficients appearing in the dilation equation: "
}], "Text",
  CellTags->{"S1.3.1", "1.78"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(\@2\), \(h\_k\), "\[Phi]", \((2  t - k)
        \), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.79"}],

Cell[TextData[{
  "Therefore, once we know the scaling function, the mother wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " can be obtained if the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", called filter coefficients, are known.If the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is infinite, the sums in both the dilation equation and the wavelet \
equation are infinite. In practice, we only calculate the finite number of \
the coefficients and truncate the sums at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "=", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " depending on the accuracy required for a particular application. \nWe \
first describe the calculation of the spline filter coefficients. Recall that \
the dilation equation in Fourier space assumes the form "
}], "Text",
  CellTags->{"S1.3.1", "1.80"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\), \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.81"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"H", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), \(e\^\(-i  k  \[Omega]\)\), 
          "/", \(\@2\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  ". Therefore, given ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h\_k/\@2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " can be computed as the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " Fourier coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". To find the expression for ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " we employ the two\[Hyphen]scale equation satisfied by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " (see (",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 1.3.1", "1.22"},
    ButtonStyle->"AddOnsLink"],
  ")). In Fourier space it is "
}], "Text",
  CellTags->{"S1.3.1", "1.82"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Beta]\&^\)\_n\) \((\[Omega])\) = \(H\_b\) \((\[Omega]\/2)\) 
      \(\(\[Beta]\&^\)\_n\) \((\[Omega]\/2)\).\)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.83"}],

Cell[TextData[{
  "Substituting the expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Beta]\&^\)\_n\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " given in (",
  ButtonBox["3.5",
    ButtonData:>{"Wavelets 1.3.1", "1.36"},
    ButtonStyle->"AddOnsLink"],
  "), we have "
}], "Text",
  CellTags->{"S1.3.1", "1.84"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(H\_b\) \((\[Omega])\) = 
      \(\(\(\[Beta]\&^\)\_n\) \((2  \[Omega])\)\)\/\(\(\(\[Beta]\&^\)\_n\) \((
          \[Omega])\)\) = 
      \(\((\(\(sin  \[Omega]\)\/\[Omega]\) 
              \(\[Omega]/2\)\/\(sin  \[Omega]/2\))\)\^\(n + 1\)\) 
      e\^\(-i  \[Omega]\[Kappa]\)\/e\^\(-i  \[Omega]\[Kappa]/2\) = 
      \(\((cos  \[Omega]\/2)\)\^\(n + 1\)\) e\^\(-i  \[Omega]\[Kappa]/2\).\)],
   "DisplayFormula",
  CellTags->{"S1.3.1", "1.85"}],

Cell[TextData[{
  "On the other hand, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are related through the orthogonalization procedure, "
}], "Text",
  CellTags->{"S1.3.1", "1.86"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = M \((\[Omega])\) \(\(\[Beta]\&^\)\_n\) 
      \((\[Omega])\), \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.87"}],

Cell[TextData[{
  "and using the two\[Hyphen]scale equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", we can rewrite the above equation as "
}], "Text",
  CellTags->{"S1.3.1", "1.88"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = M \((\[Omega])\) \(H\_b\) \((\[Omega]\/2)
      \) \(\(\[Beta]\&^\)\_n\) \((\[Omega]\/2)\) = M \((\[Omega])\) \(H\_b\) 
      \((\[Omega]\/2)\) \(\[Phi]\&^\) \((\[Omega]\/2)\)/M \((\[Omega]\/2)\).
      \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.89"}],

Cell[TextData[{
  "From this we immediately obtain an explicit expression for ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " "
}], "Text",
  CellTags->{"S1.3.1", "1.90"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(H \((\[Omega])\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            
            StyleBox[
              \(\(H\_b\) \((\[Omega])\) 
                \(M \((2 \[Omega])\)\)\/\(M \((\[Omega])\)\) = 
                \(e\^\(-i \[Omega]\[Kappa]/2\)\) 
                \(\((cos \[Omega]\/2)\)\^\(n + 1\)\) 
                \@\(\(\(\((2 sin \[Omega]/2)\)\^\(2 \((n + 1)\)\)\) 
                        \(\[CapitalSigma]\_\(2 \((n + 1)\)\)\) \((\[Omega])
                        \)\)\/\(\(\((2 sin \[Omega])\)\^\(2 \((n + 1)\)\)\) 
                        \(\[CapitalSigma]\_\(2 \((n + 1)\)\)\) \((2 \[Omega])
                        \)\)\)\),
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(e\^\(-i \[Omega]\[Kappa]/2\)\/2\^\(n + 1\)\), 
                \(\@\(\(\(\[CapitalSigma]\_\(2 \((n + 1)\)\)\) \((\[Omega])
                          \)\)\/\(\(\[CapitalSigma]\_\(2 \((n + 1)\)\)\) \((
                          2 \[Omega])\)\)\)\), 
                StyleBox[\("sign"\),
                  "TI"], \((\(cos\^\[Kappa]\) \[Omega]\/2)\), "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\n(3.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.91"}],

Cell[TextData[{
  "The desired filter coefficients are given by ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " times the Fourier coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ":"
}], "Text",
  CellTags->{"S1.3.1", "1.92"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(h\_k\), "=", \(\@2\), \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_0\%\(2  \[Pi]\)\), "H", \((\[Omega])\), 
        \(e\^\(i  k  \[Omega]\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.1", "1.93"}],

Cell[TextData[{
  "This calculation of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order spline filter coefficients can be accomplished by the function "
}], "Text",
  CellTags->{"S1.3.1", "1.94"}],

Cell[TextData[{
  StyleBox["SplineFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["kmax", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.1", "1.95"}],

Cell[TextData[{
  "The output consists of a list of two parts; the first part is ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " goes from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " to ",
  StyleBox["kmax", "TI"],
  " for odd ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " for even ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and the second part is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " which indicates the index of the first coefficient. "
}], "Text",
  CellTags->{"S1.3.1", "1.96"}],

Cell[TextData[{
  "This gives the spline filter of order 3 with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "4"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  ". We will see in Section ",
  ButtonBox["1.5",
    ButtonData:>{"Wavelets 1.5"},
    ButtonStyle->"AddOnsLink"],
  " that they, rather than the actual wavelets themselves, are used to do \
wavelet transforms."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.97"}],

Cell[CellGroupData[{

Cell["SplineFilter[3, 4]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S1.3.1"],

Cell[BoxData[
    \({{0.0320808974701902815`, \(-0.110037018388013274`\), 
        \(-0.0502017246714501119`\), 0.433922633589276873`, 
        0.766130053759815687`, 0.433922633589276873`, 
        \(-0.0502017246714501119`\), \(-0.110037018388013274`\), 
        0.0320808974701902815`}, \(-4\)}\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Now we discuss the calculation of the corresponding mother wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". In principle, once the coefficients in the dilation equation ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are known, we can get the coefficients in the wavelet equation through ",
  Cell[BoxData[
      \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) h\_\(1 - k\)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  ", and the mother wavelet can be obtained from the superposition of the \
dilated scaling function. However, since the nonorthogonal scaling function ",
  
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is known directly, we can in this particular case also write the wavelet \
as a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Beta]\_n\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " rather than that of ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". \nFrom the wavelet equation, we have "
}], "Text",
  CellTags->{"S1.3.1", "1.98"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Psi]\&^\) \((\[Omega])\) = G \((\[Omega]/2)\) \(\[Phi]\&^\) \((
      \[Omega]/2)\) = -\(e\^\(-i  \[Omega]/2\)\) 
      \(\(H \((\[Omega]/2 + \[Pi])\)\)\&_\) \(\[Phi]\&^\) \((\[Omega]/2)\)\)],
   "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.1", "1.99"}],

Cell["If we define ", "Text",
  CellTags->{"S1.3.1", "1.100"}],

Cell[BoxData[
    \(TraditionalForm
    \`N \((\[Omega]/2)\) \[Congruent] 
      \(M \((\[Omega])\) M \((\[Omega]/2)\)\)\/\(M \((\[Omega]/2 + \[Pi])
          \)\), \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.101"}],

Cell["", "Text",
  CellTags->{"S1.3.1", "1.102"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(G\_b\) \((\[Omega]/2)\) \[Congruent] -\(e\^\(-i  \[Omega]/2\)\) 
      \(\(H\_b\) \((\[Omega]/2 + \[Pi])\)\)\&_, \)], "DisplayFormula",
  CellTags->{"S1.3.1", "1.103"}],

Cell["and ", "Text",
  CellTags->{"S1.3.1", "1.104"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Beta]\&^\)\_n\%#\) \((\[Omega])\) \[Congruent] \(G\_b\) \((
      \[Omega])\) \(\(\[Beta]\&^\)\_n\) \((\[Omega])\), \)], "DisplayFormula",\

  CellTags->{"S1.3.1", "1.105"}],

Cell[TextData[{
  "the above expression (",
  ButtonBox["3.9",
    ButtonData:>{"Wavelets 1.3.1", "1.99"},
    ButtonStyle->"AddOnsLink"],
  ") can be written as (see Daubechies (1992)) "
}], "Text",
  CellTags->{"S1.3.1", "1.106"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Psi]\&^\) \((\[Omega])\) = N \((\[Omega]\/2)\) \(G\_b\) \((
      \[Omega]\/2)\) \(\(\[Beta]\&^\)\_n\) \((\[Omega]\/2)\) = N \((
      \[Omega]\/2)\) \(\(\[Beta]\&^\)\_n\%#\) \((\[Omega]\/2)\), \)], 
  "DisplayFormula",
  CellTags->{"S1.3.1", "1.107"}],

Cell["and the wavelet can then be obtained from ", "Text",
  CellTags->{"S1.3.1", "1.108"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(n\_k\), \(\[Beta]\_n\%#\), \((2  t - k)
        \), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(n\_k\), 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_l\), \(\[Beta]\_n\), \((2  t - k - l)
        \), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(n\_\(k - l\)\), \(g\_l\), 
        \(\[Beta]\_n\), \((2  t - k)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.1", "1.109"}],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{n\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are obtained by Fourier transforming ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(n\_k\), "/", "2", 
          \(e\^\(-i  k  \[Omega]\)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " and the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are given by ",
  Cell[BoxData[
      \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) b\_\(1 - k\)/2\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`{b\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " are the coefficients connecting ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in (",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 1.3.1", "1.22"},
    ButtonStyle->"AddOnsLink"],
  "). \nThe function "
}], "Text",
  CellTags->{"S1.3.1", "1.110"}],

Cell[TextData[{
  StyleBox["SplinePsi[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["kmax", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.1", "1.111"}],

Cell[TextData[{
  "gives the spline wavelet or Battle\[Hyphen]Lemari\[EAcute] wavelet ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", \((t)\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((2  t - k)
          \)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". The summation index ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " goes from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " for odd ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " for even ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.112"}],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", the Battle\[Hyphen]Lemari\[EAcute] wavelet has the graph shown here."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.113"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SplinePsi[1, t, 5]], {t, -5, 5},
AxesLabel -> {\"t\", \"spline psi(t) of order 1\"},
PlotRange -> All]\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.39217 0.228137 [
[.11905 .37967 -6 -9 ]
[.11905 .37967 6 0 ]
[.30952 .37967 -6 -9 ]
[.30952 .37967 6 0 ]
[.69048 .37967 -3 -9 ]
[.69048 .37967 3 0 ]
[.88095 .37967 -3 -9 ]
[.88095 .37967 3 0 ]
[1.025 .39217 0 -4.5 ]
[1.025 .39217 6 4.5 ]
[.4875 .04996 -24 -4.5 ]
[.4875 .04996 0 4.5 ]
[.4875 .16403 -12 -4.5 ]
[.4875 .16403 0 4.5 ]
[.4875 .2781 -24 -4.5 ]
[.4875 .2781 0 4.5 ]
[.4875 .50624 -18 -4.5 ]
[.4875 .50624 0 4.5 ]
[.5 .64303 -72 0 ]
[.5 .64303 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .39217 m
.11905 .39842 L
s
[(-4)] .11905 .37967 0 1 Mshowa
.30952 .39217 m
.30952 .39842 L
s
[(-2)] .30952 .37967 0 1 Mshowa
.69048 .39217 m
.69048 .39842 L
s
[(2)] .69048 .37967 0 1 Mshowa
.88095 .39217 m
.88095 .39842 L
s
[(4)] .88095 .37967 0 1 Mshowa
.125 Mabswid
.16667 .39217 m
.16667 .39592 L
s
.21429 .39217 m
.21429 .39592 L
s
.2619 .39217 m
.2619 .39592 L
s
.35714 .39217 m
.35714 .39592 L
s
.40476 .39217 m
.40476 .39592 L
s
.45238 .39217 m
.45238 .39592 L
s
.54762 .39217 m
.54762 .39592 L
s
.59524 .39217 m
.59524 .39592 L
s
.64286 .39217 m
.64286 .39592 L
s
.7381 .39217 m
.7381 .39592 L
s
.78571 .39217 m
.78571 .39592 L
s
.83333 .39217 m
.83333 .39592 L
s
.07143 .39217 m
.07143 .39592 L
s
.02381 .39217 m
.02381 .39592 L
s
.92857 .39217 m
.92857 .39592 L
s
.97619 .39217 m
.97619 .39592 L
s
.25 Mabswid
0 .39217 m
1 .39217 L
s
[(t)] 1.025 .39217 -1 0 Mshowa
.5 .04996 m
.50625 .04996 L
s
[(-1.5)] .4875 .04996 1 0 Mshowa
.5 .16403 m
.50625 .16403 L
s
[(-1)] .4875 .16403 1 0 Mshowa
.5 .2781 m
.50625 .2781 L
s
[(-0.5)] .4875 .2781 1 0 Mshowa
.5 .50624 m
.50625 .50624 L
s
[(0.5)] .4875 .50624 1 0 Mshowa
.125 Mabswid
.5 .07278 m
.50375 .07278 L
s
.5 .09559 m
.50375 .09559 L
s
.5 .11841 m
.50375 .11841 L
s
.5 .14122 m
.50375 .14122 L
s
.5 .18685 m
.50375 .18685 L
s
.5 .20966 m
.50375 .20966 L
s
.5 .23247 m
.50375 .23247 L
s
.5 .25529 m
.50375 .25529 L
s
.5 .30092 m
.50375 .30092 L
s
.5 .32373 m
.50375 .32373 L
s
.5 .34654 m
.50375 .34654 L
s
.5 .36936 m
.50375 .36936 L
s
.5 .41498 m
.50375 .41498 L
s
.5 .4378 m
.50375 .4378 L
s
.5 .46061 m
.50375 .46061 L
s
.5 .48342 m
.50375 .48342 L
s
.5 .52905 m
.50375 .52905 L
s
.5 .55187 m
.50375 .55187 L
s
.5 .57468 m
.50375 .57468 L
s
.5 .59749 m
.50375 .59749 L
s
.5 .02715 m
.50375 .02715 L
s
.5 .00434 m
.50375 .00434 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(spline psi\\(t\\) of order 1)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .39217 m
.06244 .39217 L
.10458 .39217 L
.14415 .39217 L
.18221 .39217 L
.22272 .39217 L
.24141 .39217 L
.25127 .39217 L
.25666 .39217 L
.2593 .39217 L
.26045 .39217 L
.26171 .39217 L
.26301 .39227 L
.26425 .39239 L
.26698 .39265 L
.27279 .39319 L
.28302 .39416 L
.29358 .39515 L
.30316 .39605 L
.30552 .39627 L
.30802 .39651 L
.30933 .39663 L
.31007 .39654 L
.31076 .39639 L
.31329 .39587 L
.32283 .39388 L
.3438 .38952 L
.38271 .38017 L
.39288 .37756 L
.39825 .37618 L
.40119 .37542 L
.40263 .37505 L
.40395 .37471 L
.40511 .37463 L
.40634 .37505 L
.40892 .37595 L
.4144 .37785 L
.42407 .38121 L
.43361 .38452 L
.43886 .38634 L
.44381 .38806 L
.44843 .38967 L
.44969 .39011 L
.45103 .39057 L
.45218 .39097 L
.45343 .39575 L
.46218 .43479 L
.47299 .48308 L
.48326 .52893 L
.49247 .57008 L
Mistroke
.495 .58135 L
.49638 .58754 L
.49769 .59335 L
.4989 .5988 L
.50022 .60092 L
.50142 .58595 L
.50252 .57221 L
.52261 .32107 L
.53241 .19851 L
.54134 .08691 L
.54359 .05887 L
.54477 .04409 L
.54602 .0284 L
.54712 .01472 L
.54833 .01729 L
.54942 .03101 L
.55045 .04387 L
.56021 .16578 L
.57028 .29177 L
.58088 .42424 L
.59055 .54505 L
.59319 .57815 L
.59396 .58768 L
.59468 .59666 L
.59532 .60332 L
.59602 .6002 L
.6011 .57749 L
.61962 .4948 L
.62992 .44883 L
.63954 .40587 L
.64073 .40056 L
.64202 .39477 L
.64324 .39091 L
.64438 .39051 L
.64709 .38957 L
.64957 .38871 L
.66059 .38488 L
.67923 .37841 L
.68434 .37663 L
.68702 .3757 L
.68849 .37519 L
.6892 .37495 L
.68985 .37472 L
.69105 .37465 L
.69233 .37498 L
.69505 .37568 L
.69983 .37691 L
.73978 .38709 L
.75807 .3909 L
.76847 .39306 L
Mistroke
.77356 .39412 L
.77821 .39509 L
.78056 .39558 L
.78312 .39611 L
.78429 .39635 L
.78553 .39661 L
.78671 .39656 L
.78778 .39646 L
.79806 .39549 L
.8191 .39351 L
.82847 .39263 L
.83074 .39241 L
.832 .3923 L
.83318 .39218 L
.83385 .39217 L
.83458 .39217 L
.83586 .39217 L
.83836 .39217 L
.84921 .39217 L
.85918 .39217 L
.89999 .39217 L
.93927 .39217 L
.97619 .39217 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "This is also called the ",
  StyleBox["Franklin wavelet", "TI"],
  " and the corresponding multiresolution analysis is called the Franklin \
multiresolution analysis. Note that the usual convention is to plot the \
wavelet such that the peak is positive. Here, according to our definition, it \
has the opposite sign. Of course, we can always choose to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Psi] \((t)\)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " as is done in the example below. "
}], "Text",
  CellTags->{"S1.3.1", "1.114"}],

Cell[TextData[{
  "Here we plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Psi] \((t)\)\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " of order 5."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.115"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[-SplinePsi[5, t, 8]], {t, -6, 6},
PlotRange -> All, AxesLabel -> {\"t\", \"-psi(t)\"}]\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.266562 0.287642 [
[.02381 .25406 -6 -9 ]
[.02381 .25406 6 0 ]
[.18254 .25406 -6 -9 ]
[.18254 .25406 6 0 ]
[.34127 .25406 -6 -9 ]
[.34127 .25406 6 0 ]
[.65873 .25406 -3 -9 ]
[.65873 .25406 3 0 ]
[.81746 .25406 -3 -9 ]
[.81746 .25406 3 0 ]
[.97619 .25406 -3 -9 ]
[.97619 .25406 3 0 ]
[1.025 .26656 0 -4.5 ]
[1.025 .26656 6 4.5 ]
[.4875 .12274 -24 -4.5 ]
[.4875 .12274 0 4.5 ]
[.4875 .41038 -18 -4.5 ]
[.4875 .41038 0 4.5 ]
[.4875 .5542 -6 -4.5 ]
[.4875 .5542 0 4.5 ]
[.5 .64303 -21 0 ]
[.5 .64303 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .26656 m
.02381 .27281 L
s
[(-6)] .02381 .25406 0 1 Mshowa
.18254 .26656 m
.18254 .27281 L
s
[(-4)] .18254 .25406 0 1 Mshowa
.34127 .26656 m
.34127 .27281 L
s
[(-2)] .34127 .25406 0 1 Mshowa
.65873 .26656 m
.65873 .27281 L
s
[(2)] .65873 .25406 0 1 Mshowa
.81746 .26656 m
.81746 .27281 L
s
[(4)] .81746 .25406 0 1 Mshowa
.97619 .26656 m
.97619 .27281 L
s
[(6)] .97619 .25406 0 1 Mshowa
.125 Mabswid
.06349 .26656 m
.06349 .27031 L
s
.10317 .26656 m
.10317 .27031 L
s
.14286 .26656 m
.14286 .27031 L
s
.22222 .26656 m
.22222 .27031 L
s
.2619 .26656 m
.2619 .27031 L
s
.30159 .26656 m
.30159 .27031 L
s
.38095 .26656 m
.38095 .27031 L
s
.42063 .26656 m
.42063 .27031 L
s
.46032 .26656 m
.46032 .27031 L
s
.53968 .26656 m
.53968 .27031 L
s
.57937 .26656 m
.57937 .27031 L
s
.61905 .26656 m
.61905 .27031 L
s
.69841 .26656 m
.69841 .27031 L
s
.7381 .26656 m
.7381 .27031 L
s
.77778 .26656 m
.77778 .27031 L
s
.85714 .26656 m
.85714 .27031 L
s
.89683 .26656 m
.89683 .27031 L
s
.93651 .26656 m
.93651 .27031 L
s
.25 Mabswid
0 .26656 m
1 .26656 L
s
[(t)] 1.025 .26656 -1 0 Mshowa
.5 .12274 m
.50625 .12274 L
s
[(-0.5)] .4875 .12274 1 0 Mshowa
.5 .41038 m
.50625 .41038 L
s
[(0.5)] .4875 .41038 1 0 Mshowa
.5 .5542 m
.50625 .5542 L
s
[(1)] .4875 .5542 1 0 Mshowa
.125 Mabswid
.5 .15151 m
.50375 .15151 L
s
.5 .18027 m
.50375 .18027 L
s
.5 .20903 m
.50375 .20903 L
s
.5 .2378 m
.50375 .2378 L
s
.5 .29533 m
.50375 .29533 L
s
.5 .32409 m
.50375 .32409 L
s
.5 .35285 m
.50375 .35285 L
s
.5 .38162 m
.50375 .38162 L
s
.5 .43915 m
.50375 .43915 L
s
.5 .46791 m
.50375 .46791 L
s
.5 .49668 m
.50375 .49668 L
s
.5 .52544 m
.50375 .52544 L
s
.5 .09398 m
.50375 .09398 L
s
.5 .06521 m
.50375 .06521 L
s
.5 .03645 m
.50375 .03645 L
s
.5 .00768 m
.50375 .00768 L
s
.5 .58297 m
.50375 .58297 L
s
.5 .61173 m
.50375 .61173 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(-psi\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .26656 m
.04262 .26656 L
.06244 .26656 L
.08255 .26656 L
.08806 .26656 L
.09396 .26656 L
.09682 .26656 L
.09952 .26656 L
.1007 .26656 L
.10195 .26656 L
.1026 .26656 L
.10332 .26656 L
.10458 .26656 L
.10587 .26656 L
.10706 .26656 L
.10838 .26656 L
.10911 .26656 L
.10978 .26656 L
.111 .26656 L
.11232 .26656 L
.11357 .26656 L
.11472 .26656 L
.11583 .26656 L
.11687 .26656 L
.118 .26656 L
.11922 .26656 L
.1205 .26657 L
.12172 .26657 L
.12281 .26657 L
.12399 .26657 L
.12528 .26657 L
.12649 .26658 L
.12793 .26658 L
.12925 .26659 L
.13194 .26661 L
.13335 .26662 L
.13483 .26664 L
.13732 .26667 L
.13963 .26671 L
.14216 .26677 L
.14487 .26685 L
.14746 .26696 L
.1502 .26709 L
.15511 .26743 L
.15784 .26768 L
.1604 .26796 L
.16621 .26877 L
.17129 .26969 L
.17593 .2707 L
.18637 .27351 L
Mistroke
.19558 .27622 L
.20063 .27759 L
.20539 .27869 L
.2081 .2792 L
.21104 .27964 L
.21233 .2798 L
.2137 .27994 L
.21498 .28004 L
.21615 .28011 L
.21734 .28016 L
.21861 .28019 L
.21979 .2802 L
.22091 .28019 L
.22221 .28015 L
.22341 .28009 L
.22473 .28001 L
.22613 .27989 L
.23575 .27866 L
.24099 .27788 L
.24354 .27753 L
.24586 .27727 L
.24787 .27708 L
.25004 .27692 L
.25123 .27685 L
.25233 .27681 L
.25338 .27679 L
.25449 .27677 L
.25562 .27678 L
.25682 .2768 L
.25795 .27683 L
.25899 .27687 L
.26153 .27702 L
.26393 .27721 L
.26843 .27759 L
.2707 .27774 L
.27199 .2778 L
.27321 .27784 L
.27453 .27785 L
.27573 .27783 L
.27637 .2778 L
.27706 .27776 L
.27778 .2777 L
.27846 .27763 L
.27969 .27746 L
.2808 .27727 L
.28331 .27665 L
.28461 .27622 L
.28599 .27569 L
.28846 .27449 L
.29112 .27285 L
Mistroke
.29405 .2706 L
.29928 .26544 L
.30418 .25943 L
.31457 .24492 L
.3197 .23833 L
.32219 .23561 L
.32445 .23352 L
.32666 .23189 L
.32767 .23129 L
.32874 .23077 L
.32988 .23034 L
.33093 .23007 L
.33207 .22992 L
.33331 .22992 L
.33457 .2301 L
.33572 .23043 L
.33636 .23068 L
.33705 .23101 L
.33831 .23175 L
.34073 .2337 L
.34298 .2361 L
.35273 .2518 L
.36324 .2723 L
.36808 .28027 L
.37072 .28377 L
.37317 .28637 L
.37527 .28805 L
.37644 .28876 L
.37751 .28926 L
.37869 .28966 L
.37996 .2899 L
.38116 .28996 L
.38226 .28987 L
.3834 .28965 L
.38444 .28934 L
.38564 .28887 L
.38678 .28831 L
.391 .28561 L
.39599 .28202 L
.39842 .28055 L
.39956 .27999 L
.40061 .27958 L
.40173 .27925 L
.40293 .27905 L
.404 .27902 L
.40512 .27916 L
.4063 .27949 L
.4074 .27999 L
.40861 .28076 L
.40991 .28186 L
Mistroke
.41263 .28512 L
.41521 .2894 L
.42003 .30039 L
.42972 .32958 L
.43228 .33709 L
.43503 .34416 L
.43636 .34703 L
.43762 .34935 L
.43877 .35106 L
.44 .35243 L
.44114 .35324 L
.44217 .35355 L
.44321 .35343 L
.44419 .3529 L
.44534 .35175 L
.44639 .35015 L
.44755 .34778 L
.44877 .34456 L
.45115 .33606 L
.45338 .32542 L
.45843 .29151 L
.46747 .2031 L
.47706 .09682 L
.48206 .05165 L
.48344 .04181 L
.48491 .03269 L
.48619 .02619 L
.48687 .0233 L
.48759 .02065 L
.48887 .0171 L
.49006 .01519 L
.49077 .01472 L
.49143 .01472 L
.49267 .01592 L
.49383 .01851 L
.49491 .02216 L
.49608 .02758 L
.49733 .03494 L
.49985 .05484 L
.50255 .08346 L
.50744 .15204 L
.51856 .35591 L
.52395 .45422 L
.52661 .49693 L
.52907 .53147 L
.53148 .55957 L
.53367 .57947 L
.53492 .58828 L
.53609 .59477 L
.53734 .59968 L
Mistroke
.53804 .60155 L
.53868 .60269 L
.53995 .60332 L
.54114 .60193 L
.54222 .59905 L
.54339 .59419 L
.54466 .5869 L
.54601 .57695 L
.54843 .55367 L
.55276 .49685 L
.55753 .41697 L
.56832 .21351 L
.57305 .13462 L
.57554 .09933 L
.57821 .0678 L
.58077 .04408 L
.5831 .02854 L
.58423 .02312 L
.58544 .01876 L
.58659 .01609 L
.58765 .01485 L
.58884 .01482 L
.58995 .01606 L
.59117 .01878 L
.59248 .02322 L
.59385 .02945 L
.59515 .03678 L
.59758 .05384 L
.60277 .1016 L
.60757 .15419 L
.6128 .21306 L
.61845 .27027 L
.62089 .29117 L
.62346 .31011 L
.62584 .3246 L
.62805 .33539 L
.63014 .34315 L
.6313 .34651 L
.63236 .34898 L
.63353 .35105 L
.63479 .35258 L
.63598 .35337 L
.63708 .35355 L
.63827 .35322 L
.63954 .35227 L
.64074 .35087 L
.64184 .34919 L
.64452 .34372 L
.64708 .33712 L
.65767 .30495 L
Mistroke
.66004 .29855 L
.66261 .29252 L
.66487 .28809 L
.66726 .28438 L
.66859 .28275 L
.67005 .28132 L
.67138 .28033 L
.67262 .27967 L
.67385 .27925 L
.67497 .27905 L
.67626 .27904 L
.67748 .27922 L
.67854 .2795 L
.6797 .27995 L
.68206 .28119 L
.68629 .2841 L
.69087 .28731 L
.69212 .28806 L
.69346 .28875 L
.69462 .28923 L
.69587 .28963 L
.69656 .28979 L
.6972 .28989 L
.69845 .28996 L
.69959 .28988 L
.70079 .28963 L
.70207 .28917 L
.70326 .28857 L
.70456 .28772 L
.70597 .28658 L
.70845 .28401 L
.71081 .28096 L
.71522 .2739 L
.72533 .25434 L
.73087 .24412 L
.73359 .23983 L
.73608 .23647 L
.73852 .23381 L
.74109 .23173 L
.74243 .23095 L
.74367 .23042 L
.74439 .2302 L
.74504 .23005 L
.74579 .22994 L
.7465 .2299 L
.74764 .22995 L
.74885 .23017 L
.74988 .23048 L
.75102 .23095 L
.75224 .2316 L
Mistroke
.75356 .23246 L
.75593 .23441 L
.76086 .23976 L
.76554 .24595 L
.77434 .25831 L
.77926 .26451 L
.78391 .26936 L
.78648 .27155 L
.78926 .27352 L
.79158 .27485 L
.79412 .27599 L
.79528 .27641 L
.79653 .27679 L
.79877 .27731 L
.8001 .27752 L
.80135 .27767 L
.80247 .27777 L
.80369 .27783 L
.80475 .27785 L
.80591 .27785 L
.80713 .27781 L
.80827 .27776 L
.80933 .2777 L
.81031 .27763 L
.8125 .27746 L
.81724 .27707 L
.8186 .27697 L
.81989 .2769 L
.82104 .27684 L
.82229 .2768 L
.82339 .27678 L
.8246 .27677 L
.82586 .27678 L
.82704 .27681 L
.82814 .27685 L
.82914 .27691 L
.83141 .27707 L
.83404 .27732 L
.83649 .27762 L
.84202 .27841 L
.84727 .27919 L
.8521 .27979 L
.85458 .28 L
.85582 .28008 L
.85652 .28012 L
.85719 .28015 L
.85791 .28017 L
.85856 .28019 L
.85927 .2802 L
.86003 .2802 L
Mistroke
.8607 .2802 L
.86141 .28018 L
.86269 .28014 L
.86386 .28008 L
.86513 .27998 L
.86742 .27976 L
.87015 .27938 L
.87265 .27895 L
.88172 .2768 L
.89126 .27402 L
.90082 .27135 L
.90607 .27011 L
.91102 .26913 L
.91565 .26839 L
.92065 .26777 L
.9252 .26736 L
.9294 .26708 L
.93184 .26696 L
.93408 .26687 L
.93648 .26679 L
.9391 .26672 L
.94152 .26668 L
.94376 .26665 L
.9459 .26662 L
.94818 .2666 L
.94958 .26659 L
.95087 .26659 L
.95225 .26658 L
.95377 .26658 L
.95509 .26657 L
.95632 .26657 L
.95763 .26657 L
.95902 .26657 L
.96028 .26656 L
.96095 .26656 L
.96166 .26656 L
.96296 .26656 L
.96415 .26656 L
.9653 .26656 L
.96638 .26656 L
.96756 .26656 L
.96883 .26656 L
.96976 .26656 L
.97063 .26656 L
.97159 .26656 L
.9726 .26656 L
.97357 .26656 L
.97448 .26656 L
.9753 .26656 L
.97619 .26656 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Here is the plot of Battle\[Hyphen]Lemari\[EAcute] or spline wavelet of \
order 2 computed with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "8"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.116"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SplinePsi[2, t, 8]], {t, -5, 5},
AxesLabel -> {\"t\", \"spline psi(t) of order 2\"},
PlotRange -> All]\
\>", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.309038 0.252852 [
[.11905 .29654 -6 -9 ]
[.11905 .29654 6 0 ]
[.30952 .29654 -6 -9 ]
[.30952 .29654 6 0 ]
[.69048 .29654 -3 -9 ]
[.69048 .29654 3 0 ]
[.88095 .29654 -3 -9 ]
[.88095 .29654 3 0 ]
[1.025 .30904 0 -4.5 ]
[1.025 .30904 6 4.5 ]
[.4875 .05619 -12 -4.5 ]
[.4875 .05619 0 4.5 ]
[.4875 .18261 -24 -4.5 ]
[.4875 .18261 0 4.5 ]
[.4875 .43546 -18 -4.5 ]
[.4875 .43546 0 4.5 ]
[.4875 .56189 -6 -4.5 ]
[.4875 .56189 0 4.5 ]
[.5 .64303 -72 0 ]
[.5 .64303 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30904 m
.11905 .31529 L
s
[(-4)] .11905 .29654 0 1 Mshowa
.30952 .30904 m
.30952 .31529 L
s
[(-2)] .30952 .29654 0 1 Mshowa
.69048 .30904 m
.69048 .31529 L
s
[(2)] .69048 .29654 0 1 Mshowa
.88095 .30904 m
.88095 .31529 L
s
[(4)] .88095 .29654 0 1 Mshowa
.125 Mabswid
.16667 .30904 m
.16667 .31279 L
s
.21429 .30904 m
.21429 .31279 L
s
.2619 .30904 m
.2619 .31279 L
s
.35714 .30904 m
.35714 .31279 L
s
.40476 .30904 m
.40476 .31279 L
s
.45238 .30904 m
.45238 .31279 L
s
.54762 .30904 m
.54762 .31279 L
s
.59524 .30904 m
.59524 .31279 L
s
.64286 .30904 m
.64286 .31279 L
s
.7381 .30904 m
.7381 .31279 L
s
.78571 .30904 m
.78571 .31279 L
s
.83333 .30904 m
.83333 .31279 L
s
.07143 .30904 m
.07143 .31279 L
s
.02381 .30904 m
.02381 .31279 L
s
.92857 .30904 m
.92857 .31279 L
s
.97619 .30904 m
.97619 .31279 L
s
.25 Mabswid
0 .30904 m
1 .30904 L
s
[(t)] 1.025 .30904 -1 0 Mshowa
.5 .05619 m
.50625 .05619 L
s
[(-1)] .4875 .05619 1 0 Mshowa
.5 .18261 m
.50625 .18261 L
s
[(-0.5)] .4875 .18261 1 0 Mshowa
.5 .43546 m
.50625 .43546 L
s
[(0.5)] .4875 .43546 1 0 Mshowa
.5 .56189 m
.50625 .56189 L
s
[(1)] .4875 .56189 1 0 Mshowa
.125 Mabswid
.5 .08147 m
.50375 .08147 L
s
.5 .10676 m
.50375 .10676 L
s
.5 .13204 m
.50375 .13204 L
s
.5 .15733 m
.50375 .15733 L
s
.5 .2079 m
.50375 .2079 L
s
.5 .23318 m
.50375 .23318 L
s
.5 .25847 m
.50375 .25847 L
s
.5 .28375 m
.50375 .28375 L
s
.5 .33432 m
.50375 .33432 L
s
.5 .35961 m
.50375 .35961 L
s
.5 .38489 m
.50375 .38489 L
s
.5 .41018 m
.50375 .41018 L
s
.5 .46075 m
.50375 .46075 L
s
.5 .48603 m
.50375 .48603 L
s
.5 .51132 m
.50375 .51132 L
s
.5 .53661 m
.50375 .53661 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .00562 m
.50375 .00562 L
s
.5 .58718 m
.50375 .58718 L
s
.5 .61246 m
.50375 .61246 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(spline psi\\(t\\) of order 2)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .30904 m
.04262 .30904 L
.0522 .30904 L
.06244 .30904 L
.06525 .30904 L
.0679 .30904 L
.06905 .30904 L
.07027 .30904 L
.07091 .30904 L
.07162 .30904 L
.07286 .30904 L
.07412 .30904 L
.07527 .30905 L
.0766 .30905 L
.07786 .30906 L
.08011 .30908 L
.08255 .30911 L
.08808 .3092 L
.09398 .30934 L
.10458 .3097 L
.12455 .31068 L
.13003 .31091 L
.13302 .311 L
.13581 .31108 L
.13839 .31114 L
.14074 .31118 L
.142 .31119 L
.14336 .31121 L
.14411 .31122 L
.1448 .31122 L
.14546 .31123 L
.14616 .31123 L
.14736 .31123 L
.14845 .31124 L
.14963 .31123 L
.15092 .31123 L
.15204 .31122 L
.15324 .31121 L
.1554 .31119 L
.15814 .31114 L
.16074 .31109 L
.16559 .31095 L
.17074 .31075 L
.17549 .31051 L
.18623 .30978 L
.19592 .30888 L
.20499 .30785 L
.21558 .3064 L
.22563 .30512 L
.23534 .30415 L
Mistroke
.24083 .30373 L
.24592 .30342 L
.25063 .3032 L
.2549 .30306 L
.25726 .303 L
.2586 .30297 L
.25982 .30296 L
.2609 .30294 L
.26208 .30293 L
.26331 .30294 L
.26446 .30296 L
.26572 .303 L
.26636 .30303 L
.26707 .30307 L
.26948 .30326 L
.27083 .3034 L
.27229 .30357 L
.27493 .30396 L
.28011 .30499 L
.28485 .30624 L
.2939 .30944 L
.30342 .31398 L
.31299 .31953 L
.31824 .32207 L
.3232 .32391 L
.32545 .32456 L
.32782 .32513 L
.32907 .32537 L
.33043 .3256 L
.33169 .32578 L
.33283 .32591 L
.33395 .32601 L
.33501 .32608 L
.33613 .32612 L
.33735 .32614 L
.33842 .32613 L
.33955 .32609 L
.34051 .32603 L
.34158 .32594 L
.34279 .32581 L
.34392 .32566 L
.34648 .32521 L
.34898 .32464 L
.35165 .32387 L
.3609 .32015 L
.38175 .31186 L
.39197 .30826 L
.39736 .30649 L
.40307 .30471 L
.40547 .30397 L
Mistroke
.40682 .30344 L
.40806 .30284 L
.41089 .30105 L
.41355 .29887 L
.4185 .29347 L
.42321 .28675 L
.43281 .26823 L
.44303 .24138 L
.44769 .22671 L
.45262 .20957 L
.45464 .20315 L
.45682 .19798 L
.45806 .19582 L
.4592 .19436 L
.46034 .19338 L
.46143 .19291 L
.46267 .19292 L
.46399 .19356 L
.46512 .19463 L
.46636 .19637 L
.46769 .19887 L
.46913 .20232 L
.47172 .21054 L
.47455 .22238 L
.47753 .23811 L
.48285 .27456 L
.49249 .36773 L
.49791 .43554 L
.50303 .50457 L
.50796 .5552 L
.51075 .57582 L
.51207 .58362 L
.51331 .58975 L
.51444 .59434 L
.51547 .59772 L
.51662 .60054 L
.51785 .6025 L
.51903 .60332 L
.52032 .60305 L
.52153 .60167 L
.52265 .59942 L
.52397 .59559 L
.5254 .59001 L
.52798 .57608 L
.5305 .55778 L
.53281 .53687 L
.53806 .47454 L
.54361 .38671 L
.55312 .20548 L
.55845 .12651 L
Mistroke
.56097 .09646 L
.5633 .07287 L
.56545 .05464 L
.56782 .03851 L
.57021 .02648 L
.57151 .02167 L
.57273 .0183 L
.57388 .01614 L
.57498 .01499 L
.57596 .01472 L
.57703 .01522 L
.57819 .01673 L
.57943 .01943 L
.58059 .02301 L
.58165 .02714 L
.58397 .03907 L
.58652 .05676 L
.59167 .10711 L
.60089 .22838 L
.60608 .28658 L
.61165 .33769 L
.61691 .37519 L
.62171 .40032 L
.62399 .40923 L
.62651 .41679 L
.62778 .41968 L
.62914 .42212 L
.63043 .42378 L
.63161 .42476 L
.63272 .42519 L
.63375 .42518 L
.63487 .42471 L
.63608 .42367 L
.63735 .42199 L
.63854 .41985 L
.64078 .4144 L
.65086 .38076 L
.66154 .35189 L
.67106 .33289 L
.67648 .32493 L
.67908 .32184 L
.68154 .31934 L
.68377 .31746 L
.68619 .3158 L
.68839 .31465 L
.69044 .31389 L
.69999 .3109 L
.71882 .30422 L
.73916 .29583 L
.7446 .2939 L
Mistroke
.74734 .29317 L
.74891 .29283 L
.75034 .29257 L
.75157 .29238 L
.7529 .29221 L
.75364 .29214 L
.75431 .29208 L
.755 .29203 L
.75565 .29199 L
.75679 .29195 L
.75805 .29194 L
.75928 .29196 L
.75997 .29199 L
.76061 .29202 L
.76178 .29211 L
.76304 .29223 L
.76531 .29255 L
.768 .29308 L
.77044 .29369 L
.77576 .2955 L
.78079 .29778 L
.78963 .30289 L
.79913 .30769 L
.80458 .30991 L
.80955 .31159 L
.81461 .31297 L
.81929 .31394 L
.82166 .31433 L
.82418 .31466 L
.82671 .3149 L
.82815 .315 L
.8288 .31504 L
.82951 .31507 L
.83069 .31511 L
.83194 .31514 L
.83309 .31514 L
.83417 .31513 L
.83544 .31512 L
.8366 .3151 L
.8392 .31505 L
.8419 .31497 L
.84439 .31488 L
.85002 .31462 L
.85499 .3143 L
.86025 .31389 L
.86967 .31295 L
.87979 .31166 L
.89809 .30932 L
.9082 .30836 L
.91354 .30796 L
Mistroke
.91923 .30759 L
.9247 .30732 L
.92965 .30712 L
.93205 .30705 L
.93463 .30698 L
.9369 .30694 L
.93933 .30689 L
.94051 .30688 L
.94164 .30687 L
.94273 .30686 L
.94375 .30685 L
.9447 .30684 L
.94572 .30684 L
.94675 .30684 L
.94787 .30684 L
.94909 .30685 L
.9502 .30685 L
.95142 .30686 L
.95271 .30688 L
.95488 .3069 L
.95725 .30695 L
.962 .30707 L
.96706 .30724 L
.97619 .30768 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "In Section ",
  ButtonBox["1.5",
    ButtonData:>{"Wavelets 1.5"},
    ButtonStyle->"AddOnsLink"],
  " we will see that we can also get the approximate spline scaling functions \
and wavelets using inverse wavelet transforms. "
}], "Text",
  CellTags->{"S1.3.1", "1.117"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in Fourier Space"
}], "Subsubsection",
  CellTags->{"S1.3.1", "1.118"}],

Cell[TextData[{
  "In this section we briefly look at the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and the wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&^\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " in frequency space using ",
  StyleBox["Mathematica", "TI"],
  ". In fact, we have already derived their expressions in (",
  ButtonBox["3.6",
    ButtonData:>{"Wavelets 1.3.1", "1.48"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["3.9",
    ButtonData:>{"Wavelets 1.3.1", "1.99"},
    ButtonStyle->"AddOnsLink"],
  "), so it is a simple matter to write ",
  StyleBox["Mathematica", "TI"],
  " programs that implement the two expressions. "
}], "Text",
  CellTags->{"S1.3.1", "1.119"}],

Cell[TextData[{
  "Using (",
  ButtonBox["3.5",
    ButtonData:>{"Wavelets 1.3.1", "1.36"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["3.6",
    ButtonData:>{"Wavelets 1.3.1", "1.48"},
    ButtonStyle->"AddOnsLink"],
  "), we define the function ",
  StyleBox["splinePhiHat[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["w", "TI"],
  StyleBox["]", "MR"],
  " that gives the magnitude of the Fourier transform of the ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " order spline scaling function ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.120"}],

Cell["\<\
(splinePhiHat[n_, 0]=1;
 splinePhiHat[n_, w_]:=1/Sqrt[sigma[2n+2, w] w^(2n+2)])\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "Here is the plot of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.121"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splinePhiHat[2, w]], {w, -4Pi, 4Pi},
PlotRange -> All, AxesLabel -> {\"w\", \"|phihat(w)|\"}]\
\>", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.588604 [
[.12106 .00222 -9 -9 ]
[.12106 .00222 9 0 ]
[.31053 .00222 -6 -9 ]
[.31053 .00222 6 0 ]
[.68947 .00222 -3 -9 ]
[.68947 .00222 3 0 ]
[.87894 .00222 -6 -9 ]
[.87894 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 .01472 m
.12106 .02097 L
s
[(-10)] .12106 .00222 0 1 Mshowa
.31053 .01472 m
.31053 .02097 L
s
[(-5)] .31053 .00222 0 1 Mshowa
.68947 .01472 m
.68947 .02097 L
s
[(5)] .68947 .00222 0 1 Mshowa
.87894 .01472 m
.87894 .02097 L
s
[(10)] .87894 .00222 0 1 Mshowa
.125 Mabswid
.15895 .01472 m
.15895 .01847 L
s
.19685 .01472 m
.19685 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.34842 .01472 m
.34842 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.65158 .01472 m
.65158 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.80315 .01472 m
.80315 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.08317 .01472 m
.08317 .01847 L
s
.04527 .01472 m
.04527 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.95473 .01472 m
.95473 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|phihat\\(w\\)|)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03746 .01473 L
.03884 .01474 L
.04016 .01474 L
.04262 .01476 L
.045 .01477 L
.04753 .0148 L
.0521 .01486 L
.05489 .01492 L
.05752 .01498 L
.06244 .01512 L
.06757 .01533 L
.07299 .01561 L
.07761 .01593 L
.08269 .01637 L
.08815 .01696 L
.09401 .01775 L
.10458 .01969 L
.12439 .02524 L
.13484 .02847 L
.13738 .02911 L
.14012 .02969 L
.14168 .02995 L
.14312 .03015 L
.14449 .0303 L
.14524 .03037 L
.14594 .03041 L
.14724 .03048 L
.14842 .0305 L
.14969 .03049 L
.1504 .03047 L
.15106 .03044 L
.15216 .03038 L
.15338 .03028 L
.15583 .03 L
.15852 .02959 L
.16141 .02905 L
.16664 .02788 L
.18579 .02304 L
.19592 .02072 L
Mistroke
.20696 .01859 L
.21739 .01701 L
.22706 .01594 L
.23216 .01552 L
.23483 .01534 L
.23766 .01518 L
.24014 .01506 L
.24285 .01495 L
.24535 .01488 L
.24763 .01482 L
.24877 .0148 L
.25002 .01478 L
.25228 .01475 L
.25354 .01474 L
.25487 .01473 L
.25601 .01472 L
.25726 .01472 L
.25843 .01472 L
.25949 .01472 L
.26067 .01472 L
.2619 .01472 L
.26297 .01472 L
.26398 .01472 L
.26507 .01472 L
.26624 .01472 L
.26748 .01472 L
.26819 .01473 L
.26884 .01473 L
.27017 .01474 L
.27091 .01475 L
.27159 .01476 L
.2728 .01478 L
.27412 .01481 L
.27651 .01488 L
.27784 .01493 L
.27931 .015 L
.28229 .0152 L
.28504 .01545 L
.28763 .01576 L
.29009 .01614 L
.29269 .01664 L
.29733 .01786 L
.29992 .01875 L
.30233 .01975 L
.30779 .02273 L
.31283 .02657 L
.3183 .03231 L
.32346 .03965 L
.32823 .04854 L
.33252 .05871 L
Mistroke
.33725 .07282 L
.34219 .09152 L
.34681 .11347 L
.35178 .14274 L
.3572 .18231 L
.36707 .27575 L
.37661 .38313 L
.3856 .47601 L
.39056 .51566 L
.39317 .53254 L
.39593 .54748 L
.39825 .55798 L
.4008 .56752 L
.40529 .58008 L
.40803 .58565 L
.41053 .58962 L
.41341 .59318 L
.41614 .59574 L
.41866 .59755 L
.42099 .59886 L
.42355 .59997 L
.42626 .60087 L
.42865 .60147 L
.43116 .60195 L
.4333 .60226 L
.43564 .60253 L
.43818 .60275 L
.44088 .60292 L
.44343 .60303 L
.44575 .60311 L
.4481 .60317 L
.45027 .60321 L
.45264 .60324 L
.45516 .60327 L
.45734 .60328 L
.45939 .60329 L
.46163 .6033 L
.46289 .60331 L
.46404 .60331 L
.46533 .60331 L
.46655 .60331 L
.46882 .60331 L
.4701 .60332 L
.47127 .60332 L
.47256 .60332 L
.47392 .60332 L
.47501 .60332 L
.47618 .60332 L
.47728 .60332 L
.47829 .60332 L
Mistroke
.47947 .60332 L
.48075 .60332 L
.48196 .60332 L
.48307 .60332 L
.48426 .60332 L
.48555 .60332 L
.48676 .60332 L
.48786 .60332 L
.48916 .60332 L
.48989 .60332 L
.49057 .60332 L
.49181 .60332 L
.49251 .60332 L
.49314 .60332 L
.49381 .60332 L
.49452 .60332 L
.49578 .60332 L
.49648 .60332 L
.49714 .60332 L
.49786 .60332 L
.49864 .60332 L
.4993 .60332 L
.50003 .60332 L
.50135 .60332 L
.50263 .60332 L
.50382 .60332 L
.50499 .60332 L
.50623 .60332 L
.50729 .60332 L
.50845 .60332 L
.50969 .60332 L
.51039 .60332 L
.51103 .60332 L
.51227 .60332 L
.51344 .60332 L
.51453 .60332 L
.51569 .60332 L
.51668 .60332 L
.51777 .60332 L
.51894 .60332 L
.5202 .60332 L
.52139 .60332 L
.52247 .60332 L
.52374 .60332 L
.52509 .60332 L
.52637 .60332 L
.52753 .60332 L
.52889 .60332 L
.53036 .60332 L
.53176 .60331 L
Mistroke
.53304 .60331 L
.53537 .60331 L
.53669 .60331 L
.53792 .6033 L
.54041 .60329 L
.5418 .60329 L
.54307 .60328 L
.54536 .60326 L
.54789 .60324 L
.54916 .60322 L
.55053 .6032 L
.553 .60314 L
.55534 .60308 L
.5578 .60298 L
.55989 .60287 L
.56218 .60272 L
.56491 .60247 L
.56739 .60217 L
.57025 .60169 L
.57295 .60108 L
.57545 .60034 L
.57775 .59945 L
.58028 .59819 L
.58296 .59644 L
.58549 .59429 L
.5879 .59169 L
.59241 .58485 L
.59493 .57957 L
.59727 .57352 L
.6 .56474 L
.60256 .55452 L
.60678 .53284 L
.61144 .50087 L
.62088 .41098 L
.62979 .3102 L
.63933 .21216 L
.6448 .16673 L
.64978 .13286 L
.65485 .10506 L
.65953 .08453 L
.66446 .06734 L
.66981 .0529 L
.67453 .04312 L
.67953 .03513 L
.68471 .02892 L
.68957 .02459 L
.69489 .02113 L
.69788 .01965 L
.70062 .01855 L
.70539 .01709 L
Mistroke
.70805 .01649 L
.71047 .01605 L
.71273 .01571 L
.71518 .01543 L
.71749 .01522 L
.71961 .01507 L
.7221 .01494 L
.72442 .01485 L
.72575 .01481 L
.72696 .01478 L
.72836 .01476 L
.72969 .01474 L
.73098 .01473 L
.73162 .01473 L
.73234 .01472 L
.7336 .01472 L
.73479 .01472 L
.73547 .01472 L
.73618 .01472 L
.73746 .01472 L
.73817 .01472 L
.73883 .01472 L
.73956 .01472 L
.74034 .01472 L
.74157 .01472 L
.74227 .01472 L
.74293 .01472 L
.74425 .01472 L
.74499 .01473 L
.74567 .01473 L
.74687 .01474 L
.74819 .01475 L
.75058 .01479 L
.75205 .01481 L
.75337 .01484 L
.75635 .01493 L
.7591 .01503 L
.76169 .01515 L
.76674 .01544 L
.77138 .0158 L
.78184 .01692 L
.79161 .01835 L
.80071 .02002 L
.82139 .02484 L
.83187 .02752 L
.83703 .02872 L
.83929 .02919 L
.84179 .02964 L
.84387 .02996 L
.84611 .03023 L
Mistroke
.84734 .03034 L
.84847 .03042 L
.84961 .03047 L
.85069 .0305 L
.85185 .0305 L
.85308 .03046 L
.85425 .0304 L
.85531 .03032 L
.85656 .03019 L
.85791 .03001 L
.86036 .0296 L
.86527 .02844 L
.86985 .02709 L
.88028 .02374 L
.89109 .02069 L
.90134 .01852 L
.91107 .01705 L
.91658 .01644 L
.92167 .01599 L
.92631 .01566 L
.93066 .01541 L
.9352 .01521 L
.94022 .01504 L
.94458 .01493 L
.94936 .01484 L
.95176 .01481 L
.95434 .01478 L
.95677 .01476 L
.95898 .01475 L
.96119 .01474 L
.96323 .01473 L
.96546 .01472 L
.96659 .01472 L
.96783 .01472 L
.96892 .01472 L
.96991 .01472 L
.97106 .01472 L
.97215 .01472 L
.97315 .01472 L
.97408 .01472 L
.9751 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Here is the plot of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.122"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splinePhiHat[5, w]], {w, -4Pi, 4Pi},
PlotRange -> All, AxesLabel -> {\"w\", \"|phihat(w)|\"}]\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.588604 [
[.12106 .00222 -9 -9 ]
[.12106 .00222 9 0 ]
[.31053 .00222 -6 -9 ]
[.31053 .00222 6 0 ]
[.68947 .00222 -3 -9 ]
[.68947 .00222 3 0 ]
[.87894 .00222 -6 -9 ]
[.87894 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 .01472 m
.12106 .02097 L
s
[(-10)] .12106 .00222 0 1 Mshowa
.31053 .01472 m
.31053 .02097 L
s
[(-5)] .31053 .00222 0 1 Mshowa
.68947 .01472 m
.68947 .02097 L
s
[(5)] .68947 .00222 0 1 Mshowa
.87894 .01472 m
.87894 .02097 L
s
[(10)] .87894 .00222 0 1 Mshowa
.125 Mabswid
.15895 .01472 m
.15895 .01847 L
s
.19685 .01472 m
.19685 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.34842 .01472 m
.34842 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.65158 .01472 m
.65158 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.80315 .01472 m
.80315 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.08317 .01472 m
.08317 .01847 L
s
.04527 .01472 m
.04527 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.95473 .01472 m
.95473 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|phihat\\(w\\)|)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04652 .01472 L
.04797 .01472 L
.04923 .01472 L
.05058 .01472 L
.05185 .01472 L
.05302 .01472 L
.05534 .01472 L
.05665 .01472 L
.05786 .01472 L
.06008 .01472 L
.06121 .01472 L
.06244 .01472 L
.0651 .01472 L
.06644 .01472 L
.0679 .01472 L
.07049 .01472 L
.0729 .01472 L
.07576 .01472 L
.07835 .01472 L
.08135 .01472 L
.08418 .01472 L
.08665 .01472 L
.08927 .01472 L
.09397 .01473 L
.09658 .01474 L
.09902 .01474 L
.10191 .01475 L
.10458 .01476 L
.10956 .01478 L
Mistroke
.11219 .0148 L
.11499 .01482 L
.12017 .01487 L
.12487 .01494 L
.13389 .01512 L
.13627 .01517 L
.13881 .01523 L
.14005 .01525 L
.14122 .01527 L
.14228 .01528 L
.1434 .01529 L
.1446 .0153 L
.1457 .0153 L
.14689 .0153 L
.1482 .01529 L
.1495 .01529 L
.15091 .01527 L
.15345 .01524 L
.16269 .01509 L
.17265 .01496 L
.17791 .0149 L
.18352 .01485 L
.18898 .01481 L
.19393 .01479 L
.19891 .01476 L
.2036 .01475 L
.20617 .01474 L
.20888 .01474 L
.21374 .01473 L
.21644 .01473 L
.21897 .01472 L
.22174 .01472 L
.22471 .01472 L
.22727 .01472 L
.22999 .01472 L
.23231 .01472 L
.23487 .01472 L
.2363 .01472 L
.23761 .01472 L
.23905 .01472 L
.24057 .01472 L
.2419 .01472 L
.24313 .01472 L
.24448 .01472 L
.24524 .01472 L
.24593 .01472 L
.24718 .01472 L
.24781 .01472 L
.24851 .01472 L
.24974 .01472 L
Mistroke
.25089 .01472 L
.25158 .01472 L
.25224 .01472 L
.25348 .01472 L
.25418 .01472 L
.25482 .01472 L
.25552 .01472 L
.25627 .01472 L
.25754 .01472 L
.25825 .01472 L
.25891 .01472 L
.26012 .01472 L
.2614 .01472 L
.26254 .01472 L
.26361 .01472 L
.26479 .01472 L
.26604 .01472 L
.26726 .01472 L
.26796 .01472 L
.26861 .01472 L
.26992 .01472 L
.27066 .01472 L
.27133 .01472 L
.27247 .01472 L
.27372 .01472 L
.27502 .01472 L
.27623 .01472 L
.27692 .01472 L
.27767 .01472 L
.27838 .01472 L
.27903 .01472 L
.28027 .01472 L
.28158 .01472 L
.28226 .01472 L
.28299 .01472 L
.2843 .01472 L
.28511 .01472 L
.28587 .01472 L
.2873 .01472 L
.28857 .01472 L
.28972 .01472 L
.29105 .01472 L
.2923 .01472 L
.29453 .01472 L
.29578 .01473 L
.29693 .01473 L
.29937 .01474 L
.30075 .01475 L
.30204 .01476 L
.30464 .01478 L
Mistroke
.3061 .0148 L
.30742 .01482 L
.30972 .01486 L
.31225 .01493 L
.31353 .01498 L
.3149 .01504 L
.31737 .01518 L
.31983 .01537 L
.32217 .01561 L
.32427 .01589 L
.32656 .0163 L
.3293 .01694 L
.33178 .01774 L
.33464 .01898 L
.33734 .02057 L
.33984 .02253 L
.34214 .02486 L
.34467 .02818 L
.34734 .03279 L
.34989 .03855 L
.3523 .04559 L
.35446 .05356 L
.35681 .06445 L
.35937 .07956 L
.36209 .10029 L
.36441 .12272 L
.36697 .15354 L
.37152 .2265 L
.37642 .32966 L
.38072 .42592 L
.38307 .47267 L
.3853 .50936 L
.3879 .54198 L
.38912 .55382 L
.39026 .56295 L
.39247 .57659 L
.39363 .58193 L
.39487 .58649 L
.39611 .59014 L
.39744 .59321 L
.3987 .59547 L
.39985 .59711 L
.40119 .5986 L
.40266 .59983 L
.40405 .6007 L
.40533 .60132 L
.40666 .6018 L
.40809 .6022 L
.40945 .60248 L
.41069 .60268 L
Mistroke
.41182 .60281 L
.41306 .60293 L
.41435 .60303 L
.41555 .6031 L
.41696 .60316 L
.4183 .6032 L
.4195 .60323 L
.4208 .60325 L
.42222 .60327 L
.42373 .60328 L
.42501 .60329 L
.42643 .6033 L
.42765 .6033 L
.42878 .60331 L
.43003 .60331 L
.43136 .60331 L
.43276 .60331 L
.43408 .60332 L
.43526 .60332 L
.43654 .60332 L
.43766 .60332 L
.43889 .60332 L
.44017 .60332 L
.44136 .60332 L
.44248 .60332 L
.44351 .60332 L
.44469 .60332 L
.44581 .60332 L
.447 .60332 L
.44832 .60332 L
.44898 .60332 L
.4497 .60332 L
.45099 .60332 L
.45221 .60332 L
.4535 .60332 L
.45459 .60332 L
.45579 .60332 L
.45653 .60332 L
.45722 .60332 L
.45852 .60332 L
.45924 .60332 L
.45991 .60332 L
.46065 .60332 L
.46143 .60332 L
.46272 .60332 L
.46392 .60332 L
.46461 .60332 L
.46525 .60332 L
.46598 .60332 L
.46667 .60332 L
Mistroke
.46792 .60332 L
.46862 .60332 L
.46926 .60332 L
.47045 .60332 L
.4717 .60332 L
.47283 .60332 L
.47388 .60332 L
.47503 .60332 L
.47626 .60332 L
.47758 .60332 L
.47832 .60332 L
.47901 .60332 L
.48027 .60332 L
.48091 .60332 L
.48161 .60332 L
.48282 .60332 L
.48412 .60332 L
.48535 .60332 L
.48648 .60332 L
.48756 .60332 L
.4887 .60332 L
.48978 .60332 L
.49076 .60332 L
.49192 .60332 L
.49317 .60332 L
.49435 .60332 L
.49544 .60332 L
.49657 .60332 L
.49762 .60332 L
.49878 .60332 L
.50002 .60332 L
.50132 .60332 L
.50256 .60332 L
.50367 .60332 L
.50487 .60332 L
.50552 .60332 L
.50621 .60332 L
.50744 .60332 L
.50876 .60332 L
.50951 .60332 L
.51021 .60332 L
.51263 .60332 L
.51333 .60332 L
.51399 .60332 L
.51522 .60332 L
.51635 .60332 L
.51756 .60332 L
.51858 .60332 L
.51971 .60332 L
.52092 .60332 L
Mistroke
.52223 .60332 L
.52346 .60332 L
.52459 .60332 L
.52588 .60332 L
.5266 .60332 L
.52726 .60332 L
.52853 .60332 L
.52973 .60332 L
.53041 .60332 L
.53114 .60332 L
.53243 .60332 L
.53315 .60332 L
.53382 .60332 L
.53456 .60332 L
.53535 .60332 L
.53666 .60332 L
.5374 .60332 L
.53809 .60332 L
.53935 .60332 L
.53999 .60332 L
.5407 .60332 L
.54191 .60332 L
.54321 .60332 L
.54445 .60332 L
.54558 .60332 L
.54685 .60332 L
.54806 .60332 L
.54914 .60332 L
.55031 .60332 L
.55159 .60332 L
.55223 .60332 L
.55294 .60332 L
.55419 .60332 L
.55537 .60332 L
.55655 .60332 L
.55766 .60332 L
.55867 .60332 L
.55976 .60332 L
.56095 .60332 L
.56221 .60332 L
.5634 .60332 L
.56448 .60332 L
.56578 .60332 L
.56715 .60331 L
.56832 .60331 L
.56961 .60331 L
.57099 .60331 L
.57247 .6033 L
.57387 .6033 L
.57514 .60329 L
Mistroke
.57643 .60328 L
.57761 .60327 L
.57891 .60325 L
.5803 .60323 L
.58149 .6032 L
.58262 .60317 L
.58385 .60312 L
.58518 .60306 L
.58644 .60297 L
.58758 .60288 L
.5889 .60273 L
.59014 .60255 L
.5913 .60234 L
.59236 .60209 L
.59353 .60174 L
.59476 .60128 L
.59601 .60067 L
.59734 .59983 L
.5986 .59879 L
.59975 .59759 L
.6011 .59579 L
.60257 .5932 L
.60395 .58998 L
.60524 .58614 L
.60657 .58108 L
.60801 .57408 L
.60927 .5663 L
.61061 .55614 L
.61314 .53024 L
.61546 .49764 L
.62066 .39599 L
.62634 .2689 L
.62887 .21931 L
.63161 .17369 L
.63403 .14071 L
.63659 .11247 L
.6389 .09214 L
.64144 .07436 L
.64373 .0617 L
.64591 .05206 L
.64863 .04267 L
.65112 .03609 L
.6538 .03067 L
.65672 .02625 L
.65926 .02337 L
.66197 .02106 L
.66453 .01942 L
.66685 .01828 L
.66917 .01741 L
.67172 .01668 L
Mistroke
.67438 .01611 L
.67687 .01573 L
.6792 .01546 L
.68132 .01527 L
.68377 .01511 L
.68609 .015 L
.6886 .01491 L
.68987 .01487 L
.69127 .01484 L
.69246 .01482 L
.69374 .0148 L
.69606 .01477 L
.69738 .01476 L
.69882 .01475 L
.70022 .01474 L
.70172 .01474 L
.70313 .01473 L
.70441 .01473 L
.7057 .01472 L
.70691 .01472 L
.70812 .01472 L
.70922 .01472 L
.71044 .01472 L
.71176 .01472 L
.71302 .01472 L
.71439 .01472 L
.71569 .01472 L
.71689 .01472 L
.71809 .01472 L
.71923 .01472 L
.72025 .01472 L
.72135 .01472 L
.72255 .01472 L
.72382 .01472 L
.7249 .01472 L
.72609 .01472 L
.72676 .01472 L
.72749 .01472 L
.72881 .01472 L
.7301 .01472 L
.73129 .01472 L
.73257 .01472 L
.7333 .01472 L
.73399 .01472 L
.73471 .01472 L
.73537 .01472 L
.73609 .01472 L
.73685 .01472 L
.73806 .01472 L
.73934 .01472 L
Mistroke
.74055 .01472 L
.74165 .01472 L
.74294 .01472 L
.74367 .01472 L
.74435 .01472 L
.74558 .01472 L
.74689 .01472 L
.7481 .01472 L
.74879 .01472 L
.74943 .01472 L
.75059 .01472 L
.75183 .01472 L
.75294 .01472 L
.75398 .01472 L
.75512 .01472 L
.75635 .01472 L
.75758 .01472 L
.75892 .01472 L
.76033 .01472 L
.76164 .01472 L
.76399 .01472 L
.7653 .01472 L
.7665 .01472 L
.76885 .01472 L
.77102 .01472 L
.7734 .01472 L
.77592 .01472 L
.77811 .01472 L
.78016 .01472 L
.78482 .01473 L
.7874 .01473 L
.78979 .01473 L
.79521 .01475 L
.79999 .01476 L
.80508 .01478 L
.81009 .01481 L
.8148 .01484 L
.82361 .01492 L
.842 .01517 L
.84704 .01525 L
.84849 .01526 L
.84986 .01528 L
.85109 .01529 L
.85179 .01529 L
.85244 .0153 L
.85359 .0153 L
.85468 .0153 L
.85587 .0153 L
.85716 .01529 L
.85843 .01527 L
Mistroke
.85978 .01525 L
.86218 .01521 L
.86717 .01509 L
.87251 .01498 L
.87755 .0149 L
.88213 .01485 L
.88461 .01482 L
.8873 .0148 L
.89219 .01477 L
.89497 .01476 L
.89792 .01475 L
.90062 .01474 L
.90319 .01474 L
.90556 .01473 L
.90813 .01473 L
.91264 .01472 L
.91519 .01472 L
.9179 .01472 L
.92046 .01472 L
.92278 .01472 L
.92515 .01472 L
.92732 .01472 L
.9297 .01472 L
.93222 .01472 L
.93441 .01472 L
.93646 .01472 L
.9387 .01472 L
.93984 .01472 L
.9411 .01472 L
.94328 .01472 L
.94447 .01472 L
.94559 .01472 L
.94759 .01472 L
.94871 .01472 L
.94974 .01472 L
.95086 .01472 L
.95204 .01472 L
.95335 .01472 L
.95456 .01472 L
.95579 .01472 L
.95696 .01472 L
.958 .01472 L
.95913 .01472 L
.9602 .01472 L
.96119 .01472 L
.96228 .01472 L
.96345 .01472 L
.96468 .01472 L
.96584 .01472 L
.96688 .01472 L
Mistroke
.96802 .01472 L
.96899 .01472 L
.97007 .01472 L
.9712 .01472 L
.97226 .01472 L
.97325 .01472 L
.97415 .01472 L
.97514 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "Similarly, using (",
  ButtonBox["3.9",
    ButtonData:>{"Wavelets 1.3.1", "1.99"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["3.8",
    ButtonData:>{"Wavelets 1.3.1", "1.91"},
    ButtonStyle->"AddOnsLink"],
  ") we define the function ",
  StyleBox["splinePsiHat[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["w", "TI"],
  StyleBox["]", "MR"],
  " that gives the magnitude of the Fourier transform of the spline wavelet \
oforder ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.123"}],

Cell["\<\
splinePsiHat[n_, w_]:= Module[{sig},
sig[x_]=sigma[2n+2,x];
Chop[Sqrt[Simplify[sig[w/2+Pi]/sig[w]]/sig[w/2]/w^(2n+2)]]]\
\>", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Psi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " of order 2 is plotted here."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.124"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splinePsiHat[2, w]], {w, -4Pi, 4Pi},
PlotRange -> All, AxesLabel -> {\"w\", \"|psihat(w)|\"}]\
\>", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.597424 [
[.12106 .00222 -9 -9 ]
[.12106 .00222 9 0 ]
[.31053 .00222 -6 -9 ]
[.31053 .00222 6 0 ]
[.68947 .00222 -3 -9 ]
[.68947 .00222 3 0 ]
[.87894 .00222 -6 -9 ]
[.87894 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .1342 -18 -4.5 ]
[.4875 .1342 0 4.5 ]
[.4875 .25368 -18 -4.5 ]
[.4875 .25368 0 4.5 ]
[.4875 .37317 -18 -4.5 ]
[.4875 .37317 0 4.5 ]
[.4875 .49265 -18 -4.5 ]
[.4875 .49265 0 4.5 ]
[.4875 .61214 -6 -4.5 ]
[.4875 .61214 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 .01472 m
.12106 .02097 L
s
[(-10)] .12106 .00222 0 1 Mshowa
.31053 .01472 m
.31053 .02097 L
s
[(-5)] .31053 .00222 0 1 Mshowa
.68947 .01472 m
.68947 .02097 L
s
[(5)] .68947 .00222 0 1 Mshowa
.87894 .01472 m
.87894 .02097 L
s
[(10)] .87894 .00222 0 1 Mshowa
.125 Mabswid
.15895 .01472 m
.15895 .01847 L
s
.19685 .01472 m
.19685 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.34842 .01472 m
.34842 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.65158 .01472 m
.65158 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.80315 .01472 m
.80315 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.08317 .01472 m
.08317 .01847 L
s
.04527 .01472 m
.04527 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.95473 .01472 m
.95473 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .1342 m
.50625 .1342 L
s
[(0.2)] .4875 .1342 1 0 Mshowa
.5 .25368 m
.50625 .25368 L
s
[(0.4)] .4875 .25368 1 0 Mshowa
.5 .37317 m
.50625 .37317 L
s
[(0.6)] .4875 .37317 1 0 Mshowa
.5 .49265 m
.50625 .49265 L
s
[(0.8)] .4875 .49265 1 0 Mshowa
.5 .61214 m
.50625 .61214 L
s
[(1)] .4875 .61214 1 0 Mshowa
.125 Mabswid
.5 .04459 m
.50375 .04459 L
s
.5 .07446 m
.50375 .07446 L
s
.5 .10433 m
.50375 .10433 L
s
.5 .16407 m
.50375 .16407 L
s
.5 .19394 m
.50375 .19394 L
s
.5 .22381 m
.50375 .22381 L
s
.5 .28356 m
.50375 .28356 L
s
.5 .31343 m
.50375 .31343 L
s
.5 .3433 m
.50375 .3433 L
s
.5 .40304 m
.50375 .40304 L
s
.5 .43291 m
.50375 .43291 L
s
.5 .46278 m
.50375 .46278 L
s
.5 .52253 m
.50375 .52253 L
s
.5 .5524 m
.50375 .5524 L
s
.5 .58227 m
.50375 .58227 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|psihat\\(w\\)|)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04652 .01472 L
.04797 .01472 L
.04923 .01472 L
.05058 .01472 L
.05185 .01472 L
.05302 .01472 L
.05534 .01472 L
.05665 .01472 L
.05786 .01472 L
.06008 .01472 L
.06121 .01472 L
.06244 .01472 L
.0651 .01472 L
.06644 .01472 L
.0679 .01472 L
.07049 .01473 L
.0729 .01473 L
.07576 .01474 L
.07835 .01475 L
.08135 .01477 L
.08418 .01479 L
.08665 .01481 L
.08927 .01485 L
.09151 .01489 L
.09397 .01494 L
.09661 .01502 L
.09945 .01512 L
.10213 .01525 L
.10458 .0154 L
Mistroke
.10936 .01581 L
.11203 .01613 L
.11445 .01648 L
.11672 .01688 L
.11917 .0174 L
.1236 .01864 L
.12886 .0207 L
.13441 .02376 L
.13915 .02716 L
.14434 .03175 L
.16389 .05551 L
.17484 .07321 L
.18482 .09316 L
.20394 .14587 L
.21474 .18621 L
.22471 .23105 L
.24501 .34106 L
.26403 .44802 L
.27291 .49056 L
.28224 .52706 L
.28713 .54263 L
.29247 .55698 L
.30184 .57617 L
.30714 .58419 L
.31214 .5902 L
.31668 .59454 L
.32149 .59813 L
.32398 .59961 L
.32673 .60097 L
.32922 .60194 L
.33155 .60263 L
.33296 .60294 L
.33366 .60306 L
.3343 .60315 L
.3355 .60327 L
.33681 .60332 L
.33811 .60328 L
.33885 .60322 L
.33954 .60313 L
.34027 .60301 L
.34094 .60286 L
.34245 .60243 L
.34372 .60194 L
.34493 .60135 L
.34718 .5999 L
.3496 .59774 L
.35224 .59455 L
.35454 .59089 L
.35698 .58595 L
.36135 .57366 L
Mistroke
.3638 .56444 L
.36644 .5523 L
.3712 .52369 L
.37686 .47762 L
.38204 .42516 L
.39202 .31134 L
.40265 .20284 L
.40781 .1613 L
.41268 .12918 L
.42177 .08482 L
.42642 .06852 L
.43133 .05496 L
.43558 .04571 L
.44013 .03786 L
.44503 .03135 L
.4496 .02672 L
.45503 .02263 L
.45998 .01996 L
.4648 .01809 L
.46723 .01737 L
.46991 .01671 L
.47218 .01626 L
.47464 .01586 L
.47694 .01556 L
.47908 .01534 L
.4816 .01513 L
.48305 .01504 L
.48436 .01497 L
.48705 .01486 L
.48852 .01481 L
.48992 .01478 L
.49112 .01476 L
.4924 .01474 L
.49349 .01473 L
.49468 .01472 L
.49597 .01472 L
.49669 .01472 L
.49735 .01472 L
.49863 .01472 L
.49985 .01472 L
.5011 .01472 L
.5018 .01472 L
.50245 .01472 L
.50364 .01472 L
.5049 .01472 L
.50603 .01473 L
.50708 .01474 L
.50823 .01475 L
.50947 .01477 L
.51079 .0148 L
Mistroke
.51222 .01483 L
.51349 .01487 L
.51483 .01493 L
.51737 .01506 L
.51971 .01523 L
.52189 .01543 L
.52423 .0157 L
.52846 .01638 L
.53105 .01693 L
.5335 .01757 L
.53811 .01914 L
.54314 .02154 L
.54769 .02451 L
.55295 .02915 L
.55791 .03504 L
.56251 .04217 L
.56674 .05051 L
.57138 .06205 L
.57629 .07758 L
.58125 .09753 L
.58577 .12023 L
.59592 .19055 L
.60533 .28189 L
.61425 .38359 L
.6239 .48457 L
.62877 .52349 L
.63158 .54147 L
.63415 .55523 L
.63872 .57391 L
.64112 .5812 L
.64365 .58733 L
.64571 .59133 L
.64791 .59475 L
.65032 .59766 L
.65257 .5997 L
.65516 .60139 L
.65646 .60201 L
.6579 .60254 L
.65912 .60288 L
.66043 .60313 L
.66167 .60327 L
.66281 .60332 L
.66349 .60331 L
.66422 .60329 L
.66553 .60317 L
.66633 .60306 L
.66709 .60293 L
.6685 .60262 L
.6711 .60183 L
.67391 .60068 L
Mistroke
.67901 .5978 L
.68441 .59359 L
.68901 .58894 L
.69406 .58254 L
.69931 .57419 L
.70428 .56444 L
.71359 .54048 L
.72362 .50517 L
.73452 .45541 L
.75393 .3472 L
.77534 .23078 L
.78511 .18685 L
.79562 .14733 L
.81465 .09436 L
.82424 .07487 L
.83472 .05756 L
.84578 .04259 L
.85583 .03158 L
.86068 .0273 L
.86594 .02354 L
.8709 .02082 L
.87547 .01895 L
.88032 .01752 L
.88308 .01692 L
.88565 .01646 L
.88832 .01608 L
.89085 .01579 L
.89377 .01552 L
.89643 .01534 L
.901 .0151 L
.90361 .01501 L
.90606 .01494 L
.90863 .01489 L
.91099 .01485 L
.91358 .01481 L
.9163 .01478 L
.9185 .01477 L
.92085 .01475 L
.92307 .01474 L
.92509 .01474 L
.92746 .01473 L
.93004 .01473 L
.93247 .01472 L
.93471 .01472 L
.93596 .01472 L
.93715 .01472 L
.93937 .01472 L
.94062 .01472 L
.94177 .01472 L
.94312 .01472 L
Mistroke
.94439 .01472 L
.94549 .01472 L
.94669 .01472 L
.94877 .01472 L
.94995 .01472 L
.95121 .01472 L
.95227 .01472 L
.95344 .01472 L
.95483 .01472 L
.95614 .01472 L
.95731 .01472 L
.95859 .01472 L
.95926 .01472 L
.95998 .01472 L
.96075 .01472 L
.96146 .01472 L
.96274 .01472 L
.96346 .01472 L
.96411 .01472 L
.96531 .01472 L
.96643 .01472 L
.96766 .01472 L
.96897 .01472 L
.96963 .01472 L
.97034 .01472 L
.97164 .01472 L
.97291 .01472 L
.97407 .01472 L
.97508 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "This is the plot of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Psi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " of order 5."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.125"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splinePsiHat[5, w]], {w, -4Pi, 4Pi},
PlotRange -> All, AxesLabel -> {\"w\", \"|psihat(w)|\"}]\
\>", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.588739 [
[.12106 .00222 -9 -9 ]
[.12106 .00222 9 0 ]
[.31053 .00222 -6 -9 ]
[.31053 .00222 6 0 ]
[.68947 .00222 -3 -9 ]
[.68947 .00222 3 0 ]
[.87894 .00222 -6 -9 ]
[.87894 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13246 -18 -4.5 ]
[.4875 .13246 0 4.5 ]
[.4875 .25021 -18 -4.5 ]
[.4875 .25021 0 4.5 ]
[.4875 .36796 -18 -4.5 ]
[.4875 .36796 0 4.5 ]
[.4875 .48571 -18 -4.5 ]
[.4875 .48571 0 4.5 ]
[.4875 .60345 -6 -4.5 ]
[.4875 .60345 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12106 .01472 m
.12106 .02097 L
s
[(-10)] .12106 .00222 0 1 Mshowa
.31053 .01472 m
.31053 .02097 L
s
[(-5)] .31053 .00222 0 1 Mshowa
.68947 .01472 m
.68947 .02097 L
s
[(5)] .68947 .00222 0 1 Mshowa
.87894 .01472 m
.87894 .02097 L
s
[(10)] .87894 .00222 0 1 Mshowa
.125 Mabswid
.15895 .01472 m
.15895 .01847 L
s
.19685 .01472 m
.19685 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.34842 .01472 m
.34842 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.65158 .01472 m
.65158 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.80315 .01472 m
.80315 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.08317 .01472 m
.08317 .01847 L
s
.04527 .01472 m
.04527 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.95473 .01472 m
.95473 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13246 m
.50625 .13246 L
s
[(0.2)] .4875 .13246 1 0 Mshowa
.5 .25021 m
.50625 .25021 L
s
[(0.4)] .4875 .25021 1 0 Mshowa
.5 .36796 m
.50625 .36796 L
s
[(0.6)] .4875 .36796 1 0 Mshowa
.5 .48571 m
.50625 .48571 L
s
[(0.8)] .4875 .48571 1 0 Mshowa
.5 .60345 m
.50625 .60345 L
s
[(1)] .4875 .60345 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07359 m
.50375 .07359 L
s
.5 .10303 m
.50375 .10303 L
s
.5 .1619 m
.50375 .1619 L
s
.5 .19134 m
.50375 .19134 L
s
.5 .22077 m
.50375 .22077 L
s
.5 .27965 m
.50375 .27965 L
s
.5 .30908 m
.50375 .30908 L
s
.5 .33852 m
.50375 .33852 L
s
.5 .3974 m
.50375 .3974 L
s
.5 .42683 m
.50375 .42683 L
s
.5 .45627 m
.50375 .45627 L
s
.5 .51514 m
.50375 .51514 L
s
.5 .54458 m
.50375 .54458 L
s
.5 .57402 m
.50375 .57402 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|psihat\\(w\\)|)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06451 .01472 L
.06529 .01472 L
.06659 .01472 L
.06731 .01472 L
.06797 .01472 L
.06924 .01472 L
.0704 .01472 L
.07103 .01472 L
.07173 .01472 L
.073 .01472 L
Mistroke
.07376 .01472 L
.07448 .01472 L
.07583 .01472 L
.07659 .01472 L
.07728 .01472 L
.07809 .01472 L
.07885 .01472 L
.08011 .01472 L
.08149 .01472 L
.08283 .01472 L
.08427 .01472 L
.08563 .01472 L
.08689 .01472 L
.08827 .01472 L
.08973 .01472 L
.091 .01472 L
.09219 .01472 L
.0935 .01472 L
.0949 .01472 L
.09608 .01472 L
.09736 .01472 L
.09871 .01472 L
.09995 .01472 L
.10113 .01472 L
.10219 .01472 L
.10343 .01472 L
.10458 .01472 L
.1069 .01472 L
.10813 .01472 L
.10944 .01472 L
.11082 .01472 L
.11213 .01472 L
.11331 .01472 L
.11459 .01472 L
.11691 .01472 L
.11808 .01473 L
.11937 .01473 L
.12047 .01473 L
.12166 .01474 L
.1238 .01474 L
.12511 .01475 L
.12633 .01476 L
.12777 .01477 L
.12909 .01479 L
.13178 .01483 L
.13326 .01486 L
.13466 .0149 L
.13714 .01498 L
.13943 .01508 L
.14461 .01541 L
Mistroke
.14928 .01581 L
.15429 .01634 L
.15863 .0169 L
.16335 .01768 L
.16888 .01887 L
.17413 .02038 L
.17924 .02234 L
.18398 .0247 L
.18907 .02798 L
.19456 .03268 L
.19975 .03853 L
.20452 .04548 L
.20884 .05341 L
.21358 .06433 L
.21852 .07883 L
.22313 .09591 L
.22815 .1192 L
.2336 .15128 L
.2435 .23091 L
.26206 .43267 L
.26659 .47678 L
.27147 .5157 L
.27427 .53361 L
.27683 .54735 L
.27943 .55892 L
.28185 .56776 L
.28674 .58096 L
.28933 .58595 L
.29209 .59011 L
.295 .59346 L
.29774 .59587 L
.3002 .59755 L
.30286 .59896 L
.30523 .59993 L
.30776 .60074 L
.31015 .60134 L
.31234 .60177 L
.3149 .60217 L
.31768 .6025 L
.32032 .60273 L
.32276 .6029 L
.32551 .60304 L
.32811 .60314 L
.33044 .60321 L
.33295 .60326 L
.33427 .60328 L
.33571 .6033 L
.33643 .60331 L
.33721 .60331 L
.33794 .60332 L
Mistroke
.33861 .60332 L
.33989 .60332 L
.34061 .60332 L
.34128 .60331 L
.3425 .6033 L
.3438 .60327 L
.34501 .60324 L
.34632 .60319 L
.34756 .60313 L
.34871 .60305 L
.34985 .60295 L
.35089 .60283 L
.35208 .60266 L
.35321 .60245 L
.35444 .60216 L
.35574 .60176 L
.35685 .60132 L
.35807 .60071 L
.35938 .59985 L
.36079 .59865 L
.36212 .59716 L
.36333 .5954 L
.36446 .59335 L
.36567 .59061 L
.36783 .58382 L
.36903 .57872 L
.37015 .57283 L
.37141 .56483 L
.37272 .55444 L
.37496 .5314 L
.37701 .50342 L
.38163 .41665 L
.38653 .3061 L
.39117 .21232 L
.39373 .17058 L
.3965 .13386 L
.39882 .1094 L
.40136 .08788 L
.40359 .07284 L
.406 .05996 L
.40854 .04933 L
.41091 .04158 L
.41327 .03553 L
.41551 .03101 L
.41754 .02774 L
.41972 .02491 L
.42232 .02231 L
.42476 .02044 L
.42714 .01904 L
.42933 .01805 L
Mistroke
.4317 .01721 L
.43431 .01652 L
.43702 .01599 L
.43956 .01563 L
.44195 .01538 L
.44421 .0152 L
.44624 .01508 L
.44844 .01498 L
.45084 .0149 L
.45339 .01484 L
.45556 .0148 L
.4568 .01479 L
.45796 .01477 L
.46031 .01475 L
.46156 .01475 L
.46288 .01474 L
.46428 .01473 L
.4656 .01473 L
.4668 .01473 L
.46807 .01472 L
.46917 .01472 L
.47038 .01472 L
.4715 .01472 L
.47252 .01472 L
.47372 .01472 L
.475 .01472 L
.4762 .01472 L
.47733 .01472 L
.47853 .01472 L
.47984 .01472 L
.48051 .01472 L
.48122 .01472 L
.48252 .01472 L
.48374 .01472 L
.48502 .01472 L
.48612 .01472 L
.48732 .01472 L
.48805 .01472 L
.48875 .01472 L
.49004 .01472 L
.49077 .01472 L
.49144 .01472 L
.49217 .01472 L
.49295 .01472 L
.49424 .01472 L
.49545 .01472 L
.49614 .01472 L
.49677 .01472 L
.4975 .01472 L
.4982 .01472 L
Mistroke
.49944 .01472 L
.50014 .01472 L
.50079 .01472 L
.50198 .01472 L
.50323 .01472 L
.50435 .01472 L
.5054 .01472 L
.50655 .01472 L
.50779 .01472 L
.5091 .01472 L
.50985 .01472 L
.51053 .01472 L
.5118 .01472 L
.51243 .01472 L
.51314 .01472 L
.51435 .01472 L
.51565 .01472 L
.51688 .01472 L
.51801 .01472 L
.51908 .01472 L
.52023 .01472 L
.52131 .01472 L
.52229 .01472 L
.52344 .01472 L
.5247 .01472 L
.52588 .01472 L
.52697 .01472 L
.5281 .01472 L
.52915 .01472 L
.53031 .01472 L
.53155 .01472 L
.53285 .01473 L
.53408 .01473 L
.5364 .01474 L
.53765 .01474 L
.539 .01475 L
.54019 .01476 L
.54145 .01477 L
.54383 .01479 L
.54601 .01483 L
.54854 .01488 L
.5509 .01495 L
.55348 .01506 L
.55493 .01514 L
.55625 .01523 L
.55861 .01543 L
.56078 .01567 L
.56317 .01602 L
.56571 .01652 L
.5679 .01709 L
Mistroke
.56996 .01777 L
.57222 .01873 L
.57465 .02006 L
.57718 .02189 L
.57988 .02447 L
.58243 .0277 L
.58474 .03148 L
.58747 .03727 L
.59042 .04569 L
.5932 .05632 L
.59577 .06912 L
.59817 .08445 L
.60042 .10238 L
.60309 .12922 L
.60553 .15992 L
.61051 .24374 L
.61585 .36013 L
.62065 .46312 L
.62307 .50467 L
.62575 .53953 L
.62803 .56062 L
.6293 .56958 L
.63048 .57628 L
.63264 .58553 L
.63373 .58897 L
.63492 .59202 L
.63632 .59481 L
.63764 .59684 L
.63883 .59826 L
.64011 .59946 L
.64152 .60046 L
.643 .60125 L
.64427 .60176 L
.64567 .60219 L
.64697 .60249 L
.64816 .6027 L
.64953 .60288 L
.65083 .60301 L
.65203 .6031 L
.65315 .60317 L
.65437 .60322 L
.65567 .60326 L
.65692 .60329 L
.65762 .6033 L
.65828 .60331 L
.65898 .60331 L
.65961 .60332 L
.66034 .60332 L
.66104 .60332 L
.66227 .60332 L
Mistroke
.6634 .60331 L
.66465 .6033 L
.66597 .60328 L
.66729 .60326 L
.6687 .60323 L
.67127 .60316 L
.67431 .60305 L
.6771 .60291 L
.67954 .60274 L
.6818 .60255 L
.68429 .60228 L
.68694 .6019 L
.68973 .60137 L
.69236 .60071 L
.69472 .59995 L
.69728 .59889 L
.69964 .59764 L
.70218 .59594 L
.70457 .59388 L
.70676 .59155 L
.70932 .58812 L
.71211 .58332 L
.71474 .57753 L
.71718 .57083 L
.71994 .56139 L
.72253 .55041 L
.72738 .52346 L
.7326 .48393 L
.73823 .42962 L
.7477 .32353 L
.75783 .2185 L
.76366 .1705 L
.76895 .13533 L
.77434 .10698 L
.77931 .08639 L
.78395 .07114 L
.78906 .05793 L
.7942 .04765 L
.79965 .03931 L
.80443 .03369 L
.80958 .02902 L
.81443 .02562 L
.81888 .0232 L
.82364 .02117 L
.82872 .01951 L
.83351 .01831 L
.83786 .01746 L
.84299 .01668 L
.84853 .01603 L
.85376 .01554 L
Mistroke
.85628 .01535 L
.85858 .01519 L
.86083 .01507 L
.86328 .01497 L
.86587 .01488 L
.86703 .01486 L
.86832 .01483 L
.8706 .01479 L
.87186 .01478 L
.87304 .01477 L
.87514 .01475 L
.87632 .01474 L
.8774 .01474 L
.87861 .01473 L
.87989 .01473 L
.88221 .01473 L
.88363 .01472 L
.88496 .01472 L
.88616 .01472 L
.88747 .01472 L
.88875 .01472 L
.89011 .01472 L
.89139 .01472 L
.89255 .01472 L
.89393 .01472 L
.8954 .01472 L
.89677 .01472 L
.89807 .01472 L
.89931 .01472 L
.90066 .01472 L
.90194 .01472 L
.90311 .01472 L
.90426 .01472 L
.90533 .01472 L
.90645 .01472 L
.90767 .01472 L
.909 .01472 L
.91026 .01472 L
.91139 .01472 L
.91262 .01472 L
.91395 .01472 L
.91537 .01472 L
.91657 .01472 L
.91791 .01472 L
.91907 .01472 L
.92029 .01472 L
.92134 .01472 L
.92248 .01472 L
.92371 .01472 L
.92503 .01472 L
Mistroke
.92627 .01472 L
.9274 .01472 L
.92855 .01472 L
.9296 .01472 L
.93076 .01472 L
.93198 .01472 L
.93305 .01472 L
.93404 .01472 L
.93513 .01472 L
.93631 .01472 L
.93748 .01472 L
.93877 .01472 L
.93942 .01472 L
.94012 .01472 L
.94139 .01472 L
.94259 .01472 L
.94385 .01472 L
.94493 .01472 L
.94611 .01472 L
.94683 .01472 L
.94751 .01472 L
.94878 .01472 L
.94949 .01472 L
.95015 .01472 L
.95087 .01472 L
.95163 .01472 L
.9529 .01472 L
.95408 .01472 L
.95538 .01472 L
.95611 .01472 L
.95678 .01472 L
.95797 .01472 L
.95925 .01472 L
.96045 .01472 L
.96154 .01472 L
.96282 .01472 L
.96355 .01472 L
.96421 .01472 L
.96544 .01472 L
.96673 .01472 L
.96786 .01472 L
.96906 .01472 L
.9702 .01472 L
.97124 .01472 L
.97246 .01472 L
.97315 .01472 L
.97378 .01472 L
.97495 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "The Fourier transform of the filter coefficients ",
  Cell[BoxData[
      FormBox[
        RowBox[{"H", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), "/", \(\@2\), 
          \(e\^\(-i  k  \[Omega]\)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.1"],
  " is called the frequency response function or transfer function. Again, it \
is easy to implement it in ",
  StyleBox["Mathematica", "TI"],
  ". "
}], "Text",
  CellTags->{"S1.3.1", "1.126"}],

Cell[TextData[{
  "This defines the magnitude of the response function ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]H \((\[Omega])\)\[RightBracketingBar]\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " using (",
  ButtonBox["3.8",
    ButtonData:>{"Wavelets 1.3.1", "1.91"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.127"}],

Cell["\<\
splineResponseH[n_, w_]:=Module[{sig},
sig[x_]=sigma[2n+2, x];
Sqrt[Simplify[sig[w]/sig[2w]]]/2^(n+1)]\
\>", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S1.3.1"],

Cell[TextData[{
  "Here is the plot of the magnitude of the response function for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.128"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splineResponseH[2, w]], {w, -2Pi, 2Pi},
Ticks->{Range[-2Pi, 2Pi, Pi], Automatic},
AxesLabel -> {\"w\", \"|H(w)|\"}]\
\>", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.588604 [
[.02381 .00222 -15 -9 ]
[.02381 .00222 15 0 ]
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -18 0 ]
[.5 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2 Pi)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-Pi)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(Pi)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2 Pi)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|H\\(w\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04652 .60332 L
.04797 .60332 L
.04923 .60332 L
.05058 .60332 L
.05185 .60332 L
.05302 .60332 L
.05534 .60331 L
.05665 .60331 L
.05786 .60331 L
.06008 .60331 L
.06121 .6033 L
.06244 .6033 L
.0651 .60329 L
.06644 .60328 L
.0679 .60327 L
.07049 .60325 L
.0729 .60322 L
.07437 .6032 L
.07576 .60317 L
.07835 .6031 L
.08115 .603 L
.08272 .60293 L
.08418 .60285 L
.08662 .60267 L
.0889 .60246 L
.0914 .60215 L
.09409 .6017 L
.0969 .60106 L
.09957 .60024 L
Mistroke
.10197 .59928 L
.10458 .59793 L
.10714 .59619 L
.10991 .59373 L
.11252 .59071 L
.11492 .58717 L
.11948 .57787 L
.12178 .57155 L
.12429 .56307 L
.12954 .539 L
.13248 .52112 L
.13515 .50183 L
.14528 .40489 L
.15534 .29138 L
.16601 .18772 L
.17513 .12434 L
.18031 .09786 L
.18517 .07821 L
.18988 .06314 L
.19482 .05073 L
.19905 .04238 L
.20366 .0352 L
.20865 .02925 L
.21397 .02454 L
.219 .02131 L
.22356 .01917 L
.22842 .01752 L
.23087 .01689 L
.23356 .01633 L
.23586 .01594 L
.23833 .01561 L
.24064 .01536 L
.24278 .01518 L
.24545 .015 L
.24687 .01493 L
.24837 .01487 L
.24958 .01483 L
.25088 .0148 L
.25231 .01477 L
.25366 .01475 L
.25486 .01474 L
.25618 .01473 L
.25685 .01472 L
.25756 .01472 L
.25884 .01472 L
.26012 .01472 L
.26133 .01472 L
.26241 .01472 L
.26359 .01472 L
.26482 .01472 L
Mistroke
.26594 .01472 L
.26724 .01472 L
.26847 .01473 L
.2696 .01474 L
.27066 .01476 L
.27181 .01478 L
.27304 .0148 L
.27439 .01484 L
.27585 .01489 L
.2785 .01501 L
.28107 .01518 L
.28344 .01539 L
.28597 .01567 L
.28832 .016 L
.29112 .0165 L
.29367 .01707 L
.29889 .01865 L
.30176 .01981 L
.30448 .02113 L
.30907 .02398 L
.31414 .02823 L
.31943 .03424 L
.3244 .04175 L
.32903 .05082 L
.33327 .0613 L
.33793 .07571 L
.34283 .09488 L
.35238 .1473 L
.35773 .18716 L
.36258 .23053 L
.38096 .43095 L
.38581 .47813 L
.39095 .51851 L
.39533 .54464 L
.40015 .56538 L
.40286 .57398 L
.40534 .58027 L
.40819 .586 L
.4109 .5902 L
.4134 .59321 L
.41572 .59542 L
.41826 .59732 L
.42096 .59887 L
.42358 .6 L
.42634 .6009 L
.4287 .60149 L
.43128 .60197 L
.43407 .60236 L
.43705 .60266 L
.43986 .60286 L
Mistroke
.44242 .60299 L
.44501 .60309 L
.4474 .60316 L
.45002 .60321 L
.45134 .60323 L
.4528 .60325 L
.45524 .60327 L
.45661 .60328 L
.45787 .60329 L
.45903 .60329 L
.4603 .6033 L
.46261 .6033 L
.46394 .60331 L
.46516 .60331 L
.46648 .60331 L
.46792 .60331 L
.46909 .60331 L
.47035 .60332 L
.47168 .60332 L
.47292 .60332 L
.47413 .60332 L
.47543 .60332 L
.47667 .60332 L
.47781 .60332 L
.47884 .60332 L
.47998 .60332 L
.48116 .60332 L
.48228 .60332 L
.4835 .60332 L
.48419 .60332 L
.48484 .60332 L
.48614 .60332 L
.48687 .60332 L
.48754 .60332 L
.48873 .60332 L
.49002 .60332 L
.49124 .60332 L
.49236 .60332 L
.49366 .60332 L
.49488 .60332 L
.49558 .60332 L
.49621 .60332 L
.49695 .60332 L
.49765 .60332 L
.49832 .60332 L
.49904 .60332 L
.50033 .60332 L
.50111 .60332 L
.50186 .60332 L
.50252 .60332 L
Mistroke
.50324 .60332 L
.50449 .60332 L
.50562 .60332 L
.50693 .60332 L
.50817 .60332 L
.50932 .60332 L
.51038 .60332 L
.51154 .60332 L
.51277 .60332 L
.514 .60332 L
.5147 .60332 L
.51533 .60332 L
.5165 .60332 L
.51774 .60332 L
.51839 .60332 L
.51909 .60332 L
.52035 .60332 L
.52112 .60332 L
.52185 .60332 L
.52321 .60332 L
.52443 .60332 L
.52577 .60332 L
.52717 .60332 L
.52848 .60332 L
.5297 .60332 L
.53082 .60332 L
.53333 .60331 L
.53473 .60331 L
.53602 .60331 L
.53744 .6033 L
.53895 .6033 L
.54149 .60329 L
.54293 .60328 L
.54429 .60327 L
.54671 .60325 L
.54897 .60322 L
.55145 .60318 L
.5541 .60312 L
.55688 .60302 L
.55951 .6029 L
.56187 .60275 L
.56444 .60252 L
.56666 .60227 L
.5691 .60191 L
.57166 .60141 L
.57405 .60079 L
.57629 .60005 L
.57833 .59921 L
.58069 .59797 L
.58293 .59649 L
Mistroke
.58552 .5943 L
.58796 .59166 L
.59252 .5847 L
.59508 .57931 L
.59743 .57314 L
.60018 .56419 L
.60274 .55384 L
.60701 .53164 L
.61168 .49915 L
.62113 .40859 L
.63017 .30641 L
.63977 .20864 L
.64478 .16745 L
.6503 .13028 L
.65539 .10304 L
.66005 .08309 L
.66532 .06531 L
.67101 .05074 L
.67602 .04103 L
.68129 .0333 L
.68627 .02783 L
.6909 .024 L
.69599 .02089 L
.69862 .01964 L
.70142 .01854 L
.70396 .01771 L
.70675 .01697 L
.71166 .016 L
.71443 .01562 L
.7174 .01531 L
.72021 .01509 L
.72277 .01495 L
.72401 .01489 L
.72534 .01485 L
.72648 .01481 L
.72772 .01479 L
.72917 .01476 L
.72984 .01475 L
.73055 .01474 L
.73118 .01474 L
.73188 .01473 L
.73311 .01472 L
.73439 .01472 L
.73556 .01472 L
.73621 .01472 L
.73691 .01472 L
.73819 .01472 L
.73938 .01472 L
.74065 .01472 L
.74173 .01472 L
Mistroke
.74292 .01472 L
.74421 .01473 L
.7454 .01474 L
.74671 .01476 L
.74811 .01478 L
.74944 .01481 L
.7507 .01484 L
.75304 .01493 L
.75536 .01505 L
.7575 .0152 L
.75984 .01541 L
.76231 .01569 L
.76479 .01605 L
.76746 .01653 L
.77226 .01772 L
.77519 .01869 L
.77797 .01981 L
.78318 .02259 L
.78777 .02592 L
.79283 .03083 L
.79811 .03774 L
.80307 .04634 L
.80769 .05666 L
.81193 .06853 L
.82149 .10637 L
.82622 .1323 L
.83128 .16647 L
.8404 .24647 L
.85116 .3648 L
.86109 .46988 L
.86606 .5109 L
.87132 .54358 L
.87405 .55644 L
.8766 .56628 L
.87958 .57544 L
.88242 .58221 L
.88484 .58678 L
.88749 .59072 L
.88992 .59356 L
.89212 .5956 L
.89475 .59751 L
.89754 .59906 L
.90013 .60013 L
.90256 .60091 L
.90497 .60151 L
.90722 .60193 L
.90969 .60229 L
.91234 .60258 L
.91511 .6028 L
.91774 .60295 L
Mistroke
.9201 .60305 L
.92266 .60313 L
.92488 .60318 L
.92732 .60322 L
.92987 .60325 L
.93226 .60328 L
.93449 .60329 L
.93654 .6033 L
.93878 .6033 L
.93991 .60331 L
.94114 .60331 L
.94333 .60331 L
.94457 .60331 L
.94571 .60332 L
.94781 .60332 L
.94886 .60332 L
.95003 .60332 L
.95106 .60332 L
.95204 .60332 L
.95316 .60332 L
.95419 .60332 L
.95516 .60332 L
.95606 .60332 L
.95704 .60332 L
.95809 .60332 L
.95932 .60332 L
.96045 .60332 L
.96168 .60332 L
.96299 .60332 L
.96413 .60332 L
.96519 .60332 L
.96635 .60332 L
.96759 .60332 L
.9687 .60332 L
.96991 .60332 L
.97104 .60332 L
.97209 .60332 L
.97304 .60332 L
.97408 .60332 L
.97517 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] H \((\[Omega])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 5\)], "InlineFormula",
    CellTags->"S1.3.1"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.1", "1.129"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[splineResponseH[5, w]], {w, -2Pi, 2Pi},
Ticks->{Range[-2Pi, 2Pi, Pi], Automatic},
AxesLabel -> {\"w\", \"|H(w)|\"}]\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"S1.3.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.588604 [
[.02381 .00222 -15 -9 ]
[.02381 .00222 15 0 ]
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.7381 .00222 -6 -9 ]
[.7381 .00222 6 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -18 0 ]
[.5 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2 Pi)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-Pi)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(Pi)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2 Pi)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|H\\(w\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03394 .60332 L
.03504 .60332 L
.03631 .60332 L
.03746 .60332 L
.03874 .60332 L
.03946 .60332 L
.04012 .60332 L
.04133 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04722 .60332 L
.04797 .60332 L
.04862 .60332 L
.04933 .60332 L
.05061 .60332 L
.05186 .60332 L
.05302 .60332 L
.05414 .60332 L
.05519 .60332 L
.05634 .60332 L
.05759 .60332 L
.05882 .60332 L
.06012 .60332 L
.06123 .60332 L
.06244 .60332 L
.06315 .60332 L
.06381 .60332 L
.06453 .60332 L
.06529 .60332 L
.06657 .60332 L
.06729 .60332 L
.06797 .60332 L
.06924 .60332 L
.0704 .60332 L
.07103 .60332 L
.07173 .60332 L
.073 .60332 L
Mistroke
.07376 .60332 L
.07448 .60332 L
.07583 .60332 L
.07659 .60332 L
.07728 .60332 L
.07809 .60332 L
.07885 .60332 L
.08011 .60332 L
.08077 .60332 L
.08149 .60332 L
.08224 .60332 L
.08294 .60332 L
.08427 .60332 L
.08544 .60332 L
.08673 .60332 L
.08807 .60332 L
.08933 .60332 L
.09051 .60332 L
.09158 .60331 L
.09276 .60331 L
.09401 .60331 L
.09527 .60331 L
.09663 .6033 L
.0979 .6033 L
.09906 .60329 L
.10042 .60328 L
.1019 .60327 L
.1033 .60325 L
.10458 .60322 L
.10584 .60319 L
.10703 .60315 L
.1081 .6031 L
.10927 .60304 L
.11053 .60295 L
.11188 .60283 L
.11303 .60269 L
.1143 .60249 L
.11547 .60226 L
.11655 .60198 L
.11773 .60161 L
.11898 .60109 L
.12108 .59988 L
.12227 .59892 L
.12338 .5978 L
.12467 .59614 L
.12607 .5938 L
.12739 .59093 L
.12861 .58756 L
.13092 .57866 L
.13208 .57258 L
Mistroke
.13336 .56434 L
.13602 .54085 L
.13751 .52318 L
.13887 .50388 L
.14404 .40555 L
.14877 .2986 L
.15323 .20937 L
.1557 .16948 L
.15838 .13424 L
.1606 .11056 L
.16303 .08959 L
.16576 .07128 L
.16864 .0566 L
.1713 .0463 L
.17379 .03891 L
.17631 .03312 L
.1786 .02901 L
.18125 .02535 L
.18376 .02272 L
.18613 .0208 L
.18836 .01941 L
.1908 .01822 L
.19343 .01726 L
.19604 .01656 L
.19878 .01601 L
.20113 .01567 L
.20369 .01539 L
.20611 .0152 L
.20831 .01507 L
.21084 .01496 L
.21324 .01489 L
.21545 .01483 L
.2175 .0148 L
.21974 .01477 L
.22087 .01476 L
.22211 .01475 L
.22461 .01474 L
.22602 .01473 L
.22733 .01473 L
.22857 .01473 L
.22973 .01472 L
.23107 .01472 L
.23229 .01472 L
.23342 .01472 L
.23461 .01472 L
.23563 .01472 L
.23675 .01472 L
.23796 .01472 L
.23925 .01472 L
.24047 .01472 L
Mistroke
.24158 .01472 L
.24287 .01472 L
.24353 .01472 L
.24425 .01472 L
.24553 .01472 L
.24672 .01472 L
.24745 .01472 L
.24813 .01472 L
.24942 .01472 L
.25014 .01472 L
.2508 .01472 L
.25154 .01472 L
.25232 .01472 L
.25363 .01472 L
.25438 .01472 L
.25506 .01472 L
.25631 .01472 L
.25695 .01472 L
.25764 .01472 L
.25885 .01472 L
.26014 .01472 L
.26136 .01472 L
.26247 .01472 L
.26365 .01472 L
.26476 .01472 L
.26597 .01472 L
.26728 .01472 L
.26857 .01472 L
.26922 .01472 L
.26994 .01472 L
.2712 .01472 L
.27238 .01472 L
.27357 .01472 L
.2747 .01472 L
.27571 .01472 L
.27681 .01472 L
.27801 .01472 L
.27928 .01472 L
.28036 .01472 L
.28155 .01472 L
.28221 .01472 L
.28293 .01472 L
.28425 .01472 L
.28553 .01472 L
.28672 .01472 L
.28813 .01472 L
.28941 .01472 L
.29088 .01472 L
.29227 .01472 L
.29349 .01472 L
Mistroke
.29478 .01473 L
.29709 .01473 L
.29838 .01474 L
.29958 .01474 L
.3009 .01475 L
.30231 .01476 L
.30355 .01477 L
.30491 .01478 L
.30732 .01482 L
.30868 .01484 L
.31014 .01487 L
.31278 .01495 L
.3153 .01506 L
.31795 .01522 L
.32021 .0154 L
.32269 .01567 L
.32513 .01603 L
.32734 .01646 L
.3299 .01712 L
.33231 .01794 L
.33455 .01893 L
.3366 .02009 L
.33886 .0217 L
.34125 .0239 L
.34379 .02693 L
.3462 .03066 L
.34836 .03492 L
.35071 .04077 L
.35326 .04894 L
.35598 .0603 L
.3583 .07275 L
.36086 .09024 L
.3654 .13385 L
.36796 .16732 L
.3703 .20463 L
.37918 .39238 L
.38391 .48733 L
.38655 .52646 L
.38896 .55239 L
.39121 .56945 L
.39248 .57663 L
.39365 .58199 L
.3958 .5893 L
.39688 .59201 L
.39807 .59442 L
.39945 .59658 L
.40076 .59816 L
.40194 .59927 L
.40322 .60021 L
.40461 .60099 L
Mistroke
.40609 .60161 L
.40749 .60205 L
.40876 .60235 L
.41004 .60258 L
.41123 .60275 L
.41253 .60289 L
.41391 .603 L
.4151 .60307 L
.41622 .60313 L
.41745 .60317 L
.41876 .60321 L
.41998 .60324 L
.42132 .60326 L
.42273 .60327 L
.42405 .60329 L
.42528 .60329 L
.4264 .6033 L
.42764 .6033 L
.42894 .60331 L
.43026 .60331 L
.43168 .60331 L
.43301 .60332 L
.43423 .60332 L
.43565 .60332 L
.43646 .60332 L
.4372 .60332 L
.43856 .60332 L
.43925 .60332 L
.44001 .60332 L
.44135 .60332 L
.44263 .60332 L
.44377 .60332 L
.44502 .60332 L
.44573 .60332 L
.44637 .60332 L
.44707 .60332 L
.44781 .60332 L
.44851 .60332 L
.44915 .60332 L
.4504 .60332 L
.45157 .60332 L
.45266 .60332 L
.45386 .60332 L
.45514 .60332 L
.45578 .60332 L
.45648 .60332 L
.45775 .60332 L
.45899 .60332 L
.46013 .60332 L
.46137 .60332 L
Mistroke
.46256 .60332 L
.46362 .60332 L
.46478 .60332 L
.46604 .60332 L
.46674 .60332 L
.46738 .60332 L
.46862 .60332 L
.46979 .60332 L
.47089 .60332 L
.47205 .60332 L
.47304 .60332 L
.47413 .60332 L
.47531 .60332 L
.47657 .60332 L
.47775 .60332 L
.47884 .60332 L
.48011 .60332 L
.48076 .60332 L
.48147 .60332 L
.48273 .60332 L
.48391 .60332 L
.48458 .60332 L
.48529 .60332 L
.48656 .60332 L
.48727 .60332 L
.48793 .60332 L
.48865 .60332 L
.48942 .60332 L
.49072 .60332 L
.49145 .60332 L
.49212 .60332 L
.49336 .60332 L
.49468 .60332 L
.49585 .60332 L
.49695 .60332 L
.49816 .60332 L
.49946 .60332 L
.50014 .60332 L
.50079 .60332 L
.502 .60332 L
.5033 .60332 L
.50403 .60332 L
.5047 .60332 L
.50583 .60332 L
.50707 .60332 L
.50837 .60332 L
.50957 .60332 L
.51026 .60332 L
.51101 .60332 L
.51171 .60332 L
Mistroke
.51236 .60332 L
.51359 .60332 L
.5149 .60332 L
.51558 .60332 L
.5163 .60332 L
.51762 .60332 L
.51838 .60332 L
.51918 .60332 L
.51986 .60332 L
.52061 .60332 L
.52126 .60332 L
.52197 .60332 L
.52325 .60332 L
.5245 .60332 L
.52565 .60332 L
.52689 .60332 L
.5276 .60332 L
.52826 .60332 L
.52896 .60332 L
.52959 .60332 L
.53033 .60332 L
.53103 .60332 L
.53219 .60332 L
.53343 .60332 L
.5346 .60332 L
.53566 .60332 L
.53691 .60332 L
.53762 .60332 L
.53826 .60332 L
.53945 .60332 L
.54071 .60332 L
.54194 .60332 L
.54263 .60332 L
.54327 .60332 L
.54444 .60332 L
.54569 .60332 L
.5468 .60332 L
.54785 .60332 L
.54899 .60332 L
.55022 .60332 L
.55153 .60332 L
.55227 .60332 L
.55295 .60332 L
.5542 .60332 L
.55491 .60332 L
.55554 .60332 L
.55674 .60332 L
.55805 .60332 L
.55928 .60332 L
.56041 .60332 L
Mistroke
.56147 .60332 L
.56261 .60332 L
.56368 .60332 L
.56466 .60332 L
.56581 .60332 L
.56706 .60332 L
.56824 .60331 L
.56933 .60331 L
.57045 .60331 L
.5715 .60331 L
.57266 .6033 L
.5739 .6033 L
.57514 .60329 L
.57644 .60328 L
.57755 .60327 L
.57876 .60326 L
.58008 .60323 L
.58129 .60321 L
.58263 .60317 L
.58404 .60311 L
.58527 .60305 L
.58642 .60297 L
.58768 .60287 L
.58903 .60271 L
.59023 .60254 L
.59153 .60229 L
.59277 .60198 L
.59391 .60161 L
.59607 .60064 L
.59727 .59988 L
.59837 .59901 L
.59968 .59767 L
.60107 .59583 L
.60226 .59381 L
.60355 .59099 L
.60496 .58707 L
.60646 .58157 L
.60787 .57482 L
.60916 .56706 L
.61166 .5465 L
.61307 .53104 L
.61438 .51398 L
.61932 .42526 L
.62832 .22953 L
.63079 .18648 L
.63338 .14891 L
.63801 .09941 L
.64065 .07942 L
.6431 .06491 L
.64579 .05257 L
Mistroke
.64865 .04261 L
.65135 .03558 L
.65388 .03052 L
.65616 .02699 L
.65863 .02402 L
.661 .02182 L
.66353 .02 L
.66593 .0187 L
.66812 .01778 L
.67068 .01695 L
.67347 .01629 L
.6761 .01584 L
.67854 .01553 L
.68104 .01529 L
.68339 .01513 L
.68596 .015 L
.68741 .01495 L
.68874 .0149 L
.69127 .01484 L
.6927 .01482 L
.69403 .0148 L
.69672 .01477 L
.69823 .01475 L
.6996 .01475 L
.7019 .01473 L
.70321 .01473 L
.70443 .01473 L
.7057 .01472 L
.7069 .01472 L
.70829 .01472 L
.70956 .01472 L
.71066 .01472 L
.71184 .01472 L
.71295 .01472 L
.71396 .01472 L
.71514 .01472 L
.71643 .01472 L
.71764 .01472 L
.71875 .01472 L
.71996 .01472 L
.72125 .01472 L
.72246 .01472 L
.72357 .01472 L
.72488 .01472 L
.72561 .01472 L
.72629 .01472 L
.72754 .01472 L
.72817 .01472 L
.72886 .01472 L
.72954 .01472 L
Mistroke
.73025 .01472 L
.73151 .01472 L
.73222 .01472 L
.73288 .01472 L
.7336 .01472 L
.73437 .01472 L
.73504 .01472 L
.73577 .01472 L
.73708 .01472 L
.73836 .01472 L
.73954 .01472 L
.7408 .01472 L
.74199 .01472 L
.74305 .01472 L
.74422 .01472 L
.74548 .01472 L
.74619 .01472 L
.74683 .01472 L
.74807 .01472 L
.74924 .01472 L
.75035 .01472 L
.75152 .01472 L
.75251 .01472 L
.7536 .01472 L
.75478 .01472 L
.75604 .01472 L
.75723 .01472 L
.75832 .01472 L
.7596 .01472 L
.76096 .01472 L
.76212 .01472 L
.7634 .01472 L
.76477 .01472 L
.76625 .01472 L
.76765 .01472 L
.76893 .01472 L
.7702 .01472 L
.77138 .01473 L
.77268 .01473 L
.77407 .01473 L
.77539 .01474 L
.77663 .01475 L
.77896 .01476 L
.78012 .01477 L
.78136 .01479 L
.78361 .01482 L
.78498 .01484 L
.78628 .01487 L
.78871 .01494 L
.79128 .01505 L
Mistroke
.79365 .01518 L
.79626 .01539 L
.79902 .01569 L
.8012 .01601 L
.80355 .01646 L
.80577 .01702 L
.8078 .01768 L
.81005 .0186 L
.81252 .01992 L
.8151 .02174 L
.81749 .02395 L
.82012 .02711 L
.82254 .03092 L
.82519 .03638 L
.82801 .04405 L
.83045 .05275 L
.83273 .06307 L
.83524 .07746 L
.83794 .09738 L
.84032 .11975 L
.84292 .1503 L
.84765 .22531 L
.85652 .41768 L
.85908 .46928 L
.86185 .51444 L
.86312 .53102 L
.86446 .54577 L
.86562 .55641 L
.86686 .56588 L
.86807 .57342 L
.86917 .57906 L
.87132 .58734 L
.87253 .59073 L
.87384 .59363 L
.87508 .59576 L
.87622 .59733 L
.87742 .59864 L
.87872 .59973 L
.87994 .60053 L
.88106 .60111 L
.8823 .60162 L
.88366 .60204 L
.88508 .60237 L
.8864 .60261 L
.88781 .60279 L
.88914 .60292 L
.89033 .60301 L
.89162 .60309 L
.89303 .60315 L
.89453 .6032 L
Mistroke
.8958 .60323 L
.8972 .60325 L
.8985 .60327 L
.8997 .60328 L
.90102 .60329 L
.90243 .6033 L
.90364 .6033 L
.90478 .60331 L
.90603 .60331 L
.90738 .60331 L
.90851 .60331 L
.90974 .60332 L
.91103 .60332 L
.91223 .60332 L
.91335 .60332 L
.91438 .60332 L
.91556 .60332 L
.91667 .60332 L
.91788 .60332 L
.9192 .60332 L
.91987 .60332 L
.92059 .60332 L
.92189 .60332 L
.92317 .60332 L
.9244 .60332 L
.9255 .60332 L
.9267 .60332 L
.92744 .60332 L
.92813 .60332 L
.92943 .60332 L
.93016 .60332 L
.93083 .60332 L
.93161 .60332 L
.93234 .60332 L
.93355 .60332 L
.9342 .60332 L
.93489 .60332 L
.93561 .60332 L
.93629 .60332 L
.93758 .60332 L
.93872 .60332 L
.93994 .60332 L
.9411 .60332 L
.94217 .60332 L
.94334 .60332 L
.94463 .60332 L
.94528 .60332 L
.94598 .60332 L
.94723 .60332 L
.94792 .60332 L
Mistroke
.94856 .60332 L
.94926 .60332 L
.95 .60332 L
.95124 .60332 L
.95194 .60332 L
.95261 .60332 L
.95384 .60332 L
.95496 .60332 L
.95626 .60332 L
.95749 .60332 L
.95865 .60332 L
.9597 .60332 L
.96092 .60332 L
.96206 .60332 L
.96312 .60332 L
.9641 .60332 L
.96517 .60332 L
.9663 .60332 L
.96745 .60332 L
.96867 .60332 L
.96983 .60332 L
.97089 .60332 L
.97212 .60332 L
.97277 .60332 L
.97347 .60332 L
.97474 .60332 L
.97591 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],

Cell[TextData[{
  "We see that the response function ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] H \((\[Omega])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " is 1 around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and 0 around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". This kind of filter is called a lowpass filter, since it retains the low\
\[Hyphen]frequency part of a function multiplying it and suppresses the high\
\[Hyphen]frequency part. The response function ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " associated with the filter ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm
      \`G \((\[Omega])\) = -\(e\^\(-i  \[Omega]\)\) 
        \(H \((\[Omega] + \[Pi])\)\)\&_\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". The graph of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] G \((\[Omega])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " is simply that of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] H \((\[Omega])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.3.1"],
  " translated by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ". So it is 0 around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 0\)], "InlineFormula",
    CellTags->"S1.3.1"],
  " and 1 around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.1"],
  ", and it corresponds to a highpass filter."
}], "Text",
  CellTags->{"S1.3.1", "1.130"}],

Cell["1.3.2 Other Examples", "Subsection",
  CellTags->{"S1.3.2", "2.1"}],

Cell["\<\
Another way of getting a scaling function and wavelet basis is by \
first choosing the scaling function in Fourier space such that it satisfies \
various conditions for a scaling function. We will give two examples to \
illustrate the idea. \
\>", "Text",
  CellTags->{"S1.3.2", "2.2"}],

Cell["Shannon Wavelet", "Subsubsection",
  CellTags->{"S1.3.2", "2.3"}],

Cell[TextData[{
  "In the Haar system, the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is the box function and in Fourier space ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is, apart from a phase factor, ",
  Cell[BoxData[
      \(TraditionalForm\`sin  \[Omega]\/2/\((\[Omega]\/2)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ". Now if we reverse the roles of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and let "
}], "Text",
  CellTags->{"S1.3.2", "2.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\&^\), \((\[Omega])\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["1",
                  "DisplayFormula"], 
                StyleBox[\(-\[Pi] \[LessEqual] \[Omega] < \[Pi]\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise", \),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.2", "2.5"}],

Cell["then ", "Text",
  CellTags->{"S1.3.2", "2.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "\[Phi]", \((t)\), "=", \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Phi]\&^\), \((
        \[Omega])\), \(e\^\(i  \[Omega]  t\)\), " ", 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\), \(e\^\(i  \[Omega]  t\)\), " ", 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(\(sin  \[Pi]  t\)\/\(\[Pi]  t\)\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.10) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.2", "2.7"}],

Cell[TextData[{
  "(See Walter (1994).) In order to see that the above ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is indeed a scaling function associated with a multiresolution analysis, \
we first introduce the idea of band\[Hyphen]limited functions. A function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] \(L\^2\) \((R)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " is ",
  StyleBox["band limited", "TI"],
  " if its Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is zero when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is outside certain frequency band, that is, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) > 
        \[CapitalOmega]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". It is well known that a band\[Hyphen]limited function can be expressed \
as "
}], "Text",
  CellTags->{"S1.3.2", "2.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "f", \((\(\[Pi]\/\[CapitalOmega]\) n)\), 
        \(\(sin \((\[CapitalOmega]  t - \[Pi]  n)\)\)\/\(\[CapitalOmega]  t - 
              \[Pi]  n\)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.11) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.2", "2.9"}],

Cell[TextData[{
  "This is what is called the ",
  StyleBox["Shannon sampling theorem", "TI"],
  ". It says that a band\[Hyphen]limited function can be recovered from its \
discrete sample points. The above identity can be shown by first writing ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " in terms of its Fourier series:"
}], "Text",
  CellTags->{"S1.3.2", "2.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\&^\), \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(c\_n\), 
        \(e\^\(-i \( \[Pi]\/\[CapitalOmega]\) n  \[Omega]\)\), "   ", 
        \(" for "\), "   ", "\[VerticalSeparator]", 
        \(\[Omega] \[VerticalSeparator] \), "\[LessEqual]", 
        "\[CapitalOmega]"}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.11"}],

Cell["where ", "Text",
  CellTags->{"S1.3.2", "2.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(c\_n\), "=", \(1\/\(2  \[CapitalOmega]\)\), 
        \(\[Integral]\_\(-\[CapitalOmega]\)\%\[CapitalOmega]\), \(f\&^\), \((
        \[Omega])\), \(e\^\(i \( \[Pi]\/\[CapitalOmega]\) n  \[Omega]\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(\[Pi]\/\[CapitalOmega]\), 
        \(1\/\(2  \[Pi]\)\), \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(f\&^\), \((\[Omega])\), 
        \(e\^\(i \((\(\[Pi]\/\[CapitalOmega]\) n)\) \[Omega]\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(\[Pi]\/\[CapitalOmega]\), "f", \((
        \(\[Pi]\/\[CapitalOmega]\) n)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.13"}],

Cell["On the other hand, ", "Text",
  CellTags->{"S1.3.2", "2.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "f", \((t)\), "=", \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(f\&^\), \((\[Omega])
        \), \(e\^\(i  \[Omega]  t\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_\(-\[CapitalOmega]\)\%\[CapitalOmega]\), \(f\&^\), \((
        \[Omega])\), \(e\^\(i  \[Omega]  t\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(1\/\(2  \[Pi]\)\), 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(c\_n\), 
        \(\[Integral]\_\(-\[CapitalOmega]\)\%\[CapitalOmega]\), 
        \(e\^\(i \((t - n  \[Pi]\/\[CapitalOmega])\) \[Omega]\)\), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "f", \((\(\[Pi]\/\[CapitalOmega]\) n)\), 
        \(\(sin \((\[CapitalOmega]  t - \[Pi]  n)\)\)\/\(\[CapitalOmega]  t - 
              \[Pi]  n\)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.15"}],

Cell[TextData[{
  "If we let ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " be the space of functions ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] \(L\^2\) \((R)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " whose Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " vanishes for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) > 
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", then from the Shannon sampling theorem (",
  ButtonBox["3.11",
    ButtonData:>{"Wavelets 1.3.2", "2.9"},
    ButtonStyle->"AddOnsLink"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " can be written as (setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega] = \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ") "
}], "Text",
  CellTags->{"S1.3.2", "2.16"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "f", \((n)\), 
        \(\(sin  \[Pi] \((t - n)\)\)\/\(\[Pi] \((t - n)\)\)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.17"}],

Cell[TextData[{
  "This says that the functions ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\[Phi] \((t - n)\)} = {
          \(sin  \[Pi] \((t - n)\)\)\/\(\[Pi] \((t - n)\)\)}\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " form a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The basis is also orthonormal since we can easily check that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "l",
            LimitsPositioning->True], 
          \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                  \)\[RightBracketingBar]\^2\), "=", "1"}], TraditionalForm]],
     "InlineFormula",
    CellTags->"S1.3.2"],
  ". \nThe multiresolution analysis consists of spaces ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " that are scaled versions of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". For example, the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " consists of all square integrable functions whose Fourier transforms \
vanish for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) > 2  
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". Obviously ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0 \[Subset] V\_1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) \[Element] V\_0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", we need to show that ",
  Cell[BoxData[
      \(TraditionalForm\`g \((t)\) = f \((2  t)\) \[Element] V\_1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ", and vice versa. Since "
}], "Text",
  CellTags->{"S1.3.2", "2.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{"g", \((t/2)\), "=", "f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "f", \((n)\), 
        \(\(sin  \[Pi] \((t - n)\)\)\/\(\[Pi] \((t - n)\)\)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "g", \((n/2)\), 
        \(\(sin  \[Pi] \((t - n)\)\)\/\(\[Pi] \((t - n)\)\)\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.19"}],

Cell["we have ", "Text",
  CellTags->{"S1.3.2", "2.20"}],

Cell[BoxData[
    FormBox[
      RowBox[{"g", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], "g", \((n/2)\), 
        \(\(sin  \[Pi] \((2  t - n)\)\)\/\(\[Pi] \((2  t - n)\)\)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.21"}],

Cell[TextData[{
  "That is, ",
  Cell[BoxData[
      \(TraditionalForm\`g \((t)\) = f \((2  t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is a band\[Hyphen]limited function with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega] = 2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". Similarly, we can complete the proof that ",
  Cell[BoxData[
      \(TraditionalForm\`{V\_j}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " form a multiresolution analysis with the scaling function "
}], "Text",
  CellTags->{"S1.3.2", "2.22"}],

Cell[BoxData[
    \(TraditionalForm\`\[Phi] \((t)\) = sin  \[Pi]  t/\[Pi]  t.\)], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.23"}],

Cell[TextData[{
  "This is called the Shannon multiresolution analysis.\nNext we look at the \
response function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The dilation equation in Fourier space is (see (",
  ButtonBox["2.7",
    ButtonData:>{"Wavelets 1.2.5", "5.9"},
    ButtonStyle->"AddOnsLink"],
  ")) "
}], "Text",
  CellTags->{"S1.3.2", "2.24"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\).\)], "DisplayFormula",
  CellTags->{"S1.3.2", "2.25"}],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]\/2)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi] \[LessEqual] \[Omega] < 2  \[Pi]\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " and zero elsewhere, we can identify ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega]/2)\) = \(\[Phi]\&^\) \((\[Omega])\)\)],
     "InlineFormula",
    CellTags->"S1.3.2"],
  " on ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Omega] \[Element] \(\[InvisibleSpace]\([\(-2\) \[Pi], 2  \[Pi]]
        \)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm
      \`H \((\[Omega])\) = \(\[Phi]\&^\) \((2  \[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Omega] \[Element] \(\[InvisibleSpace]\([\(-\[Pi], \[Pi]\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ". However, the frequency response function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " ought to be ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "\[Hyphen]periodic, so we \"periodize\" it by extending it periodically. \
This is accomplished by forming the infinite sum "
}], "Text",
  CellTags->{"S1.3.2", "2.26"}],

Cell[BoxData[
    FormBox[
      RowBox[{"H", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\[Phi]\&^\), \((
        2 \((\[Omega] + 2  \[Pi]  l)\))\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.27"}],

Cell[TextData[{
  "This defines ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.28"}],

Cell["\<\
(shannonPhiHat[w_]:= 1 /; -N[Pi] <= w < N[Pi];
 shannonPhiHat[w_]:= 0 /; w >= N[Pi] || w < -N[Pi])\
\>", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"S1.3.2"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is given by the sum of translated box functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.29"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Sum[shannonPhiHat[2w + 4Pi l],
{l, -4, 4}]], {w, -3Pi, 3Pi},
AxesLabel -> {\"w\", \"H(w)\"},
Ticks -> {Range[-2Pi, 2Pi, Pi], {1}}]\
\>", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0505254 0.0147151 0.588604 [
[.18254 .00222 -15 -9 ]
[.18254 .00222 15 0 ]
[.34127 .00222 -9 -9 ]
[.34127 .00222 9 0 ]
[.65873 .00222 -6 -9 ]
[.65873 .00222 6 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -12 0 ]
[.5 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(-2 Pi)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-Pi)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(Pi)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2 Pi)] .81746 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(H\\(w\\))] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .01472 L
.06244 .01472 L
.08255 .01472 L
.08806 .01472 L
.09396 .01472 L
.09682 .01472 L
.09952 .01472 L
.1007 .01472 L
.10195 .01472 L
.1026 .01472 L
.10332 .60332 L
.10458 .60332 L
.14487 .60332 L
.18364 .60332 L
.20335 .60332 L
.22486 .60332 L
.23483 .60332 L
.24546 .60332 L
.25062 .60332 L
.25548 .60332 L
.25761 .60332 L
.25985 .60332 L
.26102 .60332 L
.26231 .01472 L
.26348 .01472 L
.26457 .01472 L
.30348 .01472 L
.34484 .01472 L
.36554 .01472 L
.38469 .01472 L
.40327 .01472 L
.41266 .01472 L
.41523 .01472 L
.418 .01472 L
.41928 .01472 L
.41997 .01472 L
.42062 .01472 L
.42176 .60332 L
.42302 .60332 L
.46206 .60332 L
.50356 .60332 L
.52436 .60332 L
.54354 .60332 L
.56223 .60332 L
.57165 .60332 L
.57423 .60332 L
.57565 .60332 L
.577 .60332 L
.57825 .60332 L
Mistroke
.57896 .60332 L
.57962 .01472 L
.58077 .01472 L
.58201 .01472 L
.62364 .01472 L
.66376 .01472 L
.70236 .01472 L
.72234 .01472 L
.7272 .01472 L
.7324 .01472 L
.73393 .01472 L
.73538 .01472 L
.73669 .01472 L
.73742 .01472 L
.7381 .60332 L
.73933 .60332 L
.74068 .60332 L
.74342 .60332 L
.78367 .60332 L
.82241 .60332 L
.8421 .60332 L
.86361 .60332 L
.87356 .60332 L
.88417 .60332 L
.88933 .60332 L
.89186 .60332 L
.89419 .60332 L
.89529 .60332 L
.89631 .60332 L
.89738 .01472 L
.89856 .01472 L
.90328 .01472 L
.94216 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "We plot ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (solid line) and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (dashed line) together. It is clear that the dilation equation is \
satisfied since their product gives ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.30"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{Sum[shannonPhiHat[w + 4Pi l],
{l, -4, 4}], shannonPhiHat[w/2]}], {w, -4Pi, 4Pi},
PlotStyle -> {{}, Dashing[{0.02}]},
Ticks -> {Range[-3Pi, 3Pi, Pi], {1}},
PlotLabel -> \"H(w/2) and phihat(w/2)\"]\
\>", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.588604 [
[.14286 .00222 -15 -9 ]
[.14286 .00222 15 0 ]
[.2619 .00222 -15 -9 ]
[.2619 .00222 15 0 ]
[.38095 .00222 -9 -9 ]
[.38095 .00222 9 0 ]
[.61905 .00222 -6 -9 ]
[.61905 .00222 6 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.85714 .00222 -12 -9 ]
[.85714 .00222 12 0 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14286 .01472 m
.14286 .02097 L
s
[(-3 Pi)] .14286 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-2 Pi)] .2619 .00222 0 1 Mshowa
.38095 .01472 m
.38095 .02097 L
s
[(-Pi)] .38095 .00222 0 1 Mshowa
.61905 .01472 m
.61905 .02097 L
s
[(Pi)] .61905 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2 Pi)] .7381 .00222 0 1 Mshowa
.85714 .01472 m
.85714 .02097 L
s
[(3 Pi)] .85714 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(H\\(w/2\\) and phihat\\(w/2\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.08255 .60332 L
.10458 .60332 L
.11448 .60332 L
.12507 .60332 L
.1302 .60332 L
.13506 .60332 L
.13942 .60332 L
.14061 .60332 L
.14188 .60332 L
.14296 .01472 L
.14415 .01472 L
.18444 .01472 L
.22321 .01472 L
.26444 .01472 L
.30414 .01472 L
.34234 .01472 L
.36201 .01472 L
.36767 .01472 L
.37301 .01472 L
.3778 .01472 L
.37911 .01472 L
.37983 .01472 L
.3805 .01472 L
.38168 .60332 L
.38298 .60332 L
.42189 .60332 L
.46325 .60332 L
.5031 .60332 L
.54143 .60332 L
.56081 .60332 L
.58221 .60332 L
.59196 .60332 L
.60246 .60332 L
.60729 .60332 L
.61238 .60332 L
.61448 .60332 L
.61672 .60332 L
.61801 .60332 L
.61919 .01472 L
.62036 .01472 L
.62148 .01472 L
.65994 .01472 L
.70086 .01472 L
.74026 .01472 L
.77815 .01472 L
.79923 .01472 L
.81849 .01472 L
.82802 .01472 L
Mistroke
.83841 .01472 L
.84316 .01472 L
.84822 .01472 L
.85068 .01472 L
.85299 .01472 L
.85507 .01472 L
.85624 .01472 L
.85731 .60332 L
.85858 .60332 L
.85978 .60332 L
.86203 .60332 L
.86708 .60332 L
.87618 .60332 L
.89685 .60332 L
.93524 .60332 L
.97607 .60332 L
.97619 .60332 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .60332 L
.26425 .60332 L
.26698 .60332 L
.27279 .60332 L
.28302 .60332 L
.30316 .60332 L
.3438 .60332 L
.38293 .60332 L
.42451 .60332 L
.46458 .60332 L
.50313 .60332 L
.54413 .60332 L
.58362 .60332 L
.62159 .60332 L
.66202 .60332 L
.70093 .60332 L
.7111 .60332 L
.72217 .60332 L
.72723 .60332 L
.73262 .60332 L
.73483 .60332 L
.73599 .60332 L
.73721 .60332 L
.73786 .60332 L
.73858 .01472 L
.73983 .01472 L
.74229 .01472 L
.78285 .01472 L
.82189 .01472 L
.86339 .01472 L
.90337 .01472 L
.94184 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "The graph of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]G \((\[Omega]/2)\)\[RightBracketingBar]\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " is simply that of ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (solid line in the above graph) translated to the left by ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". Here are the graphs of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]G \((\[Omega]/2)\)\[RightBracketingBar]\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " (solid line) and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (dashed line) plotted together. "
}], "Text",
  CellTags->{"S1.3.2", "2.31"}],

Cell[TextData[{
  "We see that ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega]/2 + \[Pi])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " overlap only when ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Pi] \[LessEqual] 
        \( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) 
        \[LessEqual] 2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". "
}], "MathCaption",
  CellTags->{"S1.3.2", "2.32"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{Sum[shannonPhiHat[w+2Pi+4Pi l],
{l, -4, 4}], shannonPhiHat[w/2]}], {w, -6Pi, 6Pi},
PlotStyle -> {{}, Dashing[{0.02}]},
Ticks -> {Range[-4Pi, 4Pi, 2Pi], {1}},
PlotLabel -> \"|G(w/2)| and phihat(w/2)\"]\
\>", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0252627 0.0147151 0.588604 [
[.18254 .00222 -15 -9 ]
[.18254 .00222 15 0 ]
[.34127 .00222 -15 -9 ]
[.34127 .00222 15 0 ]
[.65873 .00222 -12 -9 ]
[.65873 .00222 12 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .63053 -72 0 ]
[.5 .63053 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(-4 Pi)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-2 Pi)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2 Pi)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(4 Pi)] .81746 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(|G\\(w/2\\)| and phihat\\(w/2\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .60332 L
.06244 .60332 L
.08255 .60332 L
.08806 .60332 L
.09396 .60332 L
.09682 .60332 L
.09952 .60332 L
.1007 .60332 L
.10195 .60332 L
.1026 .60332 L
.10332 .01472 L
.10458 .01472 L
.14487 .01472 L
.18364 .01472 L
.20335 .01472 L
.22486 .01472 L
.23483 .01472 L
.24546 .01472 L
.25062 .01472 L
.25548 .01472 L
.25761 .01472 L
.25985 .01472 L
.26102 .01472 L
.26231 .60332 L
.26348 .60332 L
.26457 .60332 L
.30348 .60332 L
.34484 .60332 L
.36554 .60332 L
.38469 .60332 L
.40327 .60332 L
.41266 .60332 L
.41523 .60332 L
.418 .60332 L
.41928 .60332 L
.41997 .60332 L
.42062 .60332 L
.42176 .01472 L
.42302 .01472 L
.46206 .01472 L
.50356 .01472 L
.52436 .01472 L
.54354 .01472 L
.56223 .01472 L
.57165 .01472 L
.57423 .01472 L
.57565 .01472 L
.577 .01472 L
.57825 .01472 L
Mistroke
.57896 .01472 L
.57962 .60332 L
.58077 .60332 L
.58201 .60332 L
.62364 .60332 L
.66376 .60332 L
.70236 .60332 L
.72234 .60332 L
.7272 .60332 L
.7324 .60332 L
.73393 .60332 L
.73538 .60332 L
.73669 .60332 L
.73742 .60332 L
.7381 .01472 L
.73933 .01472 L
.74068 .01472 L
.74342 .01472 L
.78367 .01472 L
.82241 .01472 L
.8421 .01472 L
.86361 .01472 L
.87356 .01472 L
.88417 .01472 L
.88933 .01472 L
.89186 .01472 L
.89419 .01472 L
.89529 .01472 L
.89631 .01472 L
.89738 .60332 L
.89856 .60332 L
.90328 .60332 L
.94216 .60332 L
.97619 .60332 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.28158 .01472 L
.30316 .01472 L
.31323 .01472 L
.32392 .01472 L
.33304 .01472 L
.33554 .01472 L
.33823 .01472 L
.33953 .01472 L
.34076 .01472 L
.34187 .60332 L
.34309 .60332 L
.38373 .60332 L
.42286 .60332 L
.46444 .60332 L
.50451 .60332 L
.54306 .60332 L
.58406 .60332 L
.60448 .60332 L
.62355 .60332 L
.64188 .60332 L
.64715 .60332 L
.65215 .60332 L
.65433 .60332 L
.65664 .60332 L
.65785 .60332 L
.65853 .60332 L
.65918 .01472 L
.66031 .01472 L
.66152 .01472 L
.70266 .01472 L
.74229 .01472 L
.78039 .01472 L
.82096 .01472 L
.86 .01472 L
.9015 .01472 L
.94148 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell["So we have, ", "Text",
  CellTags->{"S1.3.2", "2.33"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Psi]\&^\), \((\[Omega])\), "=", "-", \(e\^\(-i  \[Omega]/2\)\), 
        \(\(H \((\[Omega]/2 + \[Pi])\)\)\&_\), \(\[Phi]\&^\), \((\[Omega]/2)
        \), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox[\(-e\^\(-i \[Omega]/2\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(\[Pi] \[LessEqual] 
                    \( \[VerticalSeparator] 
                      \(\[Omega] \[VerticalSeparator] \)\) \[LessEqual] 2 
                    \[Pi]\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise", \),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.2", "2.34"}],

Cell["and ", "Text",
  CellTags->{"S1.3.2", "2.35"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(\[Psi] \((t)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Psi]\&^\),
                 \((\[Omega])\), \(e\^\(i \[Omega] t\)\), " ", 
                StyleBox[\("dt"\),
                  "TI"], "=", "-", \(1\/\(2 \[Pi]\)\), 
                RowBox[{"(", 
                  RowBox[{
                  \(\[Integral]\_\(\(-2\) \[Pi]\)\%\(-\[Pi]\)\), 
                    \(e\^\(i \((t - 1/2)\) \[Omega]\)\), " ", 
                    RowBox[{
                      StyleBox[\("d"\),
                        "TI"], "\[Omega]"}], "+", 
                    \(\[Integral]\_\[Pi]\%\(2 \[Pi]\)\), 
                    \(e\^\(i \((t - 1/2)\) \[Omega]\)\), " ", 
                    RowBox[{
                      StyleBox[\("d"\),
                        "TI"], "\[Omega]"}]}], ")"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            
            StyleBox[
              \(\(sin \[Pi] \((t - 1\/2)\) - sin 2 \[Pi] \((t - 1\/2)
                    \)\)\/\(\[Pi] \((t - 1\/2)\)\)\),
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\n(3.12) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.2", "2.36"}],

Cell[TextData[{
  "This is referred to as the ",
  StyleBox["Shannon wavelet", "TI"],
  "."
}], "Text",
  CellTags->{"S1.3.2", "2.37"}],

Cell[TextData[{
  "We can get the above result using ",
  StyleBox["Mathematica", "TI"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.38"}],

Cell[CellGroupData[{

Cell["\<\
Together[ComplexExpand[
(Integrate[-E^(-I w/2) E^(I w t),{w,-2Pi,-Pi}]+
Integrate[-E^(-I w/2) E^(I w t),{w,Pi,2Pi}])/(2Pi)]]\
\>", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(\(-\(\(2\ \((Cos[\[Pi]\ t] - Sin[2\ \[Pi]\ t])\)\)\/\(\[Pi]\ \((
            \(-1\) + 2\ t)\)\)\)\)\)], "Output",
  CellLabel->"Out[39]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell["The functions ", "Text",
  CellTags->{"S1.3.2", "2.39"}],

Cell[TextData[{
  StyleBox["ShannonPhi[", "MR"],
  StyleBox["t", "TI"],
  StyleBox["]", "MR"],
  "  and  ",
  StyleBox["ShannonPsi[", "MR"],
  StyleBox["t", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.2", "2.40"}],

Cell[TextData[{
  "give the Shannon scaling function (",
  ButtonBox["3.10",
    ButtonData:>{"Wavelets 1.3.2", "2.7"},
    ButtonStyle->"AddOnsLink"],
  ") and wavelet (",
  ButtonBox["3.12",
    ButtonData:>{"Wavelets 1.3.2", "2.36"},
    ButtonStyle->"AddOnsLink"],
  "), respectively. "
}], "Text",
  CellTags->{"S1.3.2", "2.41"}],

Cell[TextData[{
  "This is the Shannon scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.42"}],

Cell[CellGroupData[{

Cell["\<\
Plot[ShannonPhi[t], {t, -10, 10}, PlotRange -> All,
AxesLabel -> {\"t\", \"Shannon phi(t)\"}]\
\>", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.119753 0.483591 [
[.02381 .10725 -9 -9 ]
[.02381 .10725 9 0 ]
[.2619 .10725 -6 -9 ]
[.2619 .10725 6 0 ]
[.7381 .10725 -3 -9 ]
[.7381 .10725 3 0 ]
[.97619 .10725 -6 -9 ]
[.97619 .10725 6 0 ]
[1.025 .11975 0 -4.5 ]
[1.025 .11975 6 4.5 ]
[.4875 .02304 -24 -4.5 ]
[.4875 .02304 0 4.5 ]
[.4875 .21647 -18 -4.5 ]
[.4875 .21647 0 4.5 ]
[.4875 .31319 -18 -4.5 ]
[.4875 .31319 0 4.5 ]
[.4875 .40991 -18 -4.5 ]
[.4875 .40991 0 4.5 ]
[.4875 .50663 -18 -4.5 ]
[.4875 .50663 0 4.5 ]
[.4875 .60334 -6 -4.5 ]
[.4875 .60334 0 4.5 ]
[.5 .64303 -42 0 ]
[.5 .64303 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .11975 m
.02381 .126 L
s
[(-10)] .02381 .10725 0 1 Mshowa
.2619 .11975 m
.2619 .126 L
s
[(-5)] .2619 .10725 0 1 Mshowa
.7381 .11975 m
.7381 .126 L
s
[(5)] .7381 .10725 0 1 Mshowa
.97619 .11975 m
.97619 .126 L
s
[(10)] .97619 .10725 0 1 Mshowa
.125 Mabswid
.07143 .11975 m
.07143 .1235 L
s
.11905 .11975 m
.11905 .1235 L
s
.16667 .11975 m
.16667 .1235 L
s
.21429 .11975 m
.21429 .1235 L
s
.30952 .11975 m
.30952 .1235 L
s
.35714 .11975 m
.35714 .1235 L
s
.40476 .11975 m
.40476 .1235 L
s
.45238 .11975 m
.45238 .1235 L
s
.54762 .11975 m
.54762 .1235 L
s
.59524 .11975 m
.59524 .1235 L
s
.64286 .11975 m
.64286 .1235 L
s
.69048 .11975 m
.69048 .1235 L
s
.78571 .11975 m
.78571 .1235 L
s
.83333 .11975 m
.83333 .1235 L
s
.88095 .11975 m
.88095 .1235 L
s
.92857 .11975 m
.92857 .1235 L
s
.25 Mabswid
0 .11975 m
1 .11975 L
s
[(t)] 1.025 .11975 -1 0 Mshowa
.5 .02304 m
.50625 .02304 L
s
[(-0.2)] .4875 .02304 1 0 Mshowa
.5 .21647 m
.50625 .21647 L
s
[(0.2)] .4875 .21647 1 0 Mshowa
.5 .31319 m
.50625 .31319 L
s
[(0.4)] .4875 .31319 1 0 Mshowa
.5 .40991 m
.50625 .40991 L
s
[(0.6)] .4875 .40991 1 0 Mshowa
.5 .50663 m
.50625 .50663 L
s
[(0.8)] .4875 .50663 1 0 Mshowa
.5 .60334 m
.50625 .60334 L
s
[(1)] .4875 .60334 1 0 Mshowa
.125 Mabswid
.5 .04721 m
.50375 .04721 L
s
.5 .07139 m
.50375 .07139 L
s
.5 .09557 m
.50375 .09557 L
s
.5 .14393 m
.50375 .14393 L
s
.5 .16811 m
.50375 .16811 L
s
.5 .19229 m
.50375 .19229 L
s
.5 .24065 m
.50375 .24065 L
s
.5 .26483 m
.50375 .26483 L
s
.5 .28901 m
.50375 .28901 L
s
.5 .33737 m
.50375 .33737 L
s
.5 .36155 m
.50375 .36155 L
s
.5 .38573 m
.50375 .38573 L
s
.5 .43409 m
.50375 .43409 L
s
.5 .45827 m
.50375 .45827 L
s
.5 .48245 m
.50375 .48245 L
s
.5 .53081 m
.50375 .53081 L
s
.5 .55499 m
.50375 .55499 L
s
.5 .57917 m
.50375 .57917 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Shannon phi\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .11975 m
.02846 .11506 L
.03279 .111 L
.03754 .10728 L
.0402 .10569 L
.04262 .10459 L
.04385 .10418 L
.04516 .10385 L
.04627 .10366 L
.0475 .10355 L
.04882 .10356 L
.04957 .10361 L
.05024 .1037 L
.05156 .10396 L
.05281 .10431 L
.05397 .10474 L
.0552 .10529 L
.05742 .10653 L
.06244 .1104 L
.07287 .12138 L
.07835 .12742 L
.08134 .13041 L
.08414 .13286 L
.0868 .13481 L
.08922 .13621 L
.0906 .13682 L
.0919 .13728 L
.09257 .13747 L
.09328 .13763 L
.09406 .13776 L
.09479 .13783 L
.09594 .13788 L
.09719 .1378 L
.09836 .13762 L
.09944 .13735 L
.10064 .13696 L
.10194 .1364 L
.10458 .13488 L
.10739 .13274 L
.11004 .13028 L
.11499 .12478 L
.12612 .11093 L
.13079 .10586 L
.13335 .10357 L
.13574 .10181 L
.13832 .10039 L
.13969 .09985 L
.14046 .09962 L
.14116 .09945 L
.14239 .09927 L
Mistroke
.14308 .09922 L
.14373 .09921 L
.14491 .0993 L
.14616 .09953 L
.14741 .09989 L
.14878 .10045 L
.1502 .10121 L
.15154 .10207 L
.15647 .10646 L
.16185 .11299 L
.16761 .12113 L
.1727 .12844 L
.1781 .13535 L
.18271 .13989 L
.18398 .14085 L
.18534 .14172 L
.18661 .14239 L
.1878 .14287 L
.18904 .14322 L
.18969 .14334 L
.19039 .14343 L
.19113 .14346 L
.19182 .14344 L
.19312 .14328 L
.19434 .14296 L
.19546 .14253 L
.19669 .14192 L
.198 .1411 L
.20073 .13886 L
.20328 .13616 L
.20908 .12824 L
.21872 .11225 L
.22416 .10363 L
.22921 .0972 L
.23161 .0949 L
.233 .09384 L
.23427 .09304 L
.2356 .0924 L
.2363 .09215 L
.23704 .09195 L
.23828 .09175 L
.23899 .09172 L
.23964 .09175 L
.24093 .09195 L
.24215 .09234 L
.24324 .09283 L
.24443 .09354 L
.24708 .09572 L
.24954 .09844 L
.25382 .10462 L
Mistroke
.25854 .11308 L
.26809 .13229 L
.27329 .14182 L
.27585 .14577 L
.27823 .14886 L
.28038 .15108 L
.28148 .152 L
.28267 .1528 L
.28398 .15346 L
.28521 .15386 L
.28641 .15404 L
.28751 .15401 L
.28872 .15377 L
.29002 .15327 L
.29124 .15256 L
.29235 .15172 L
.29508 .14891 L
.29767 .14529 L
.30281 .13569 L
.30839 .1226 L
.3186 .09697 L
.3236 .08647 L
.32579 .08278 L
.32818 .07953 L
.32932 .07831 L
.33053 .07724 L
.3318 .07639 L
.33299 .07587 L
.33366 .0757 L
.33439 .0756 L
.33571 .07568 L
.33699 .07609 L
.33817 .07675 L
.33949 .0778 L
.34072 .0791 L
.34353 .08311 L
.34626 .08839 L
.3492 .09542 L
.35877 .12532 L
.36896 .15907 L
.37198 .16727 L
.37483 .17359 L
.37738 .17788 L
.37882 .17964 L
.38013 .18082 L
.38138 .18152 L
.38254 .18182 L
.38381 .18172 L
.38453 .18148 L
.38518 .18113 L
Mistroke
.38649 .18007 L
.38723 .17926 L
.38791 .17838 L
.39049 .17387 L
.39278 .16835 L
.39523 .16089 L
.39968 .1438 L
.4098 .09324 L
.41494 .06616 L
.42041 .04067 L
.42308 .03066 L
.42558 .02316 L
.42668 .02056 L
.42784 .0183 L
.4291 .01642 L
.43027 .01529 L
.43147 .01474 L
.43276 .01488 L
.43398 .01572 L
.43509 .0171 L
.43639 .0195 L
.4378 .02308 L
.44037 .03223 L
.44315 .04598 L
.4461 .06498 L
.4514 .10998 L
.46094 .22023 L
.47148 .36453 L
.4809 .48519 L
.48564 .53418 L
.48836 .55716 L
.49082 .57434 L
.49355 .58887 L
.49504 .59477 L
.49573 .59697 L
.49646 .59895 L
.49777 .60159 L
.49897 .60297 L
.50027 .60332 L
.50101 .60299 L
.5017 .60233 L
.50299 .60022 L
.50421 .59714 L
.50531 .59351 L
.50651 .58862 L
.50919 .57426 L
.51168 .55692 L
.51676 .51061 L
.52226 .44728 L
.53223 .313 L
Mistroke
.54186 .18468 L
.55085 .0893 L
.55544 .05449 L
.55802 .0397 L
.56037 .02924 L
.56162 .02486 L
.56294 .02108 L
.56363 .01946 L
.56439 .01796 L
.56509 .01684 L
.56574 .01602 L
.567 .01499 L
.56766 .01475 L
.56836 .01472 L
.56953 .01516 L
.57081 .01633 L
.5715 .01723 L
.57224 .01843 L
.57358 .02114 L
.5761 .02796 L
.57903 .03843 L
.58174 .05002 L
.59189 .10227 L
.60095 .14648 L
.60356 .1567 L
.60604 .16495 L
.60829 .17109 L
.61068 .17614 L
.61194 .17817 L
.61261 .17906 L
.61333 .17989 L
.6146 .18098 L
.61579 .1816 L
.61646 .18178 L
.6172 .18183 L
.61797 .18173 L
.61869 .18149 L
.61998 .18073 L
.6207 .18012 L
.62135 .17946 L
.62381 .17605 L
.62648 .17087 L
.63133 .15822 L
.6407 .12713 L
.64587 .10983 L
.65078 .09547 L
.65355 .08881 L
.65656 .08296 L
.65789 .0809 L
.6593 .07907 L
Mistroke
.66063 .07769 L
.66185 .07673 L
.6625 .07634 L
.66319 .07601 L
.66388 .07578 L
.66464 .07563 L
.6653 .07559 L
.66601 .07564 L
.66728 .07597 L
.66791 .07625 L
.6686 .07663 L
.66986 .07755 L
.67108 .07871 L
.67221 .08 L
.67689 .08738 L
.68128 .0967 L
.69129 .12181 L
.69604 .13318 L
.70105 .14317 L
.70367 .14727 L
.70505 .14907 L
.70653 .1507 L
.7079 .15193 L
.70914 .1528 L
.71039 .15345 L
.71156 .15384 L
.71272 .15403 L
.71396 .15401 L
.71513 .15377 L
.7162 .15339 L
.71745 .15273 L
.71881 .15177 L
.72129 .1494 L
.72388 .14616 L
.72663 .14195 L
.73158 .13294 L
.7412 .11357 L
.74542 .10588 L
.75004 .09897 L
.75264 .096 L
.75506 .0939 L
.7564 .09303 L
.75762 .09243 L
.75829 .09218 L
.75902 .09196 L
.75971 .09182 L
.76035 .09175 L
.76099 .09172 L
.76168 .09175 L
.76293 .09194 L
Mistroke
.76368 .09215 L
.76441 .09241 L
.76576 .09306 L
.76718 .09396 L
.7685 .095 L
.7715 .09798 L
.77662 .10479 L
.78126 .11221 L
.78633 .12079 L
.79168 .12939 L
.79645 .13584 L
.79898 .13857 L
.80169 .14088 L
.80297 .14172 L
.80418 .14237 L
.80527 .14283 L
.80646 .14318 L
.80758 .14339 L
.80877 .14346 L
.80979 .14341 L
.81091 .14323 L
.81222 .14286 L
.81288 .14261 L
.8136 .14229 L
.81607 .14081 L
.81896 .13843 L
.82164 .13564 L
.83172 .1221 L
.83676 .11487 L
.84223 .10789 L
.84474 .10522 L
.8474 .10287 L
.84966 .10129 L
.85094 .10059 L
.85216 .10005 L
.85332 .09966 L
.85458 .09938 L
.85572 .09924 L
.85679 .09921 L
.85805 .09932 L
.85919 .09953 L
.86051 .09992 L
.86176 .10042 L
.86401 .10165 L
.86607 .10311 L
.87074 .10742 L
.88061 .11932 L
.88604 .12601 L
.89119 .13146 L
.8935 .13348 L
Mistroke
.89597 .13524 L
.89725 .13599 L
.89867 .13667 L
.89996 .13717 L
.90116 .13751 L
.90228 .13773 L
.90345 .13785 L
.90445 .13787 L
.90554 .1378 L
.90672 .13763 L
.90799 .13732 L
.90918 .13691 L
.91026 .13646 L
.91263 .13518 L
.91514 .13343 L
.91964 .12946 L
.92981 .11836 L
.93438 .11345 L
.93871 .1094 L
.9411 .10753 L
.9437 .10587 L
.94484 .10527 L
.94606 .10473 L
.94721 .10431 L
.94826 .104 L
.94917 .1038 L
.95014 .10365 L
.9511 .10356 L
.95216 .10354 L
.95308 .10359 L
.95406 .10371 L
.95499 .10388 L
.95584 .10409 L
.95753 .10465 L
.95936 .10546 L
.96269 .10744 L
.96971 .11328 L
.97619 .11975 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "We display the Shannon wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.43"}],

Cell[CellGroupData[{

Cell["\<\
Plot[ShannonPsi[t], {t, -10, 10}, PlotRange -> All,
AxesLabel -> {\"t\", \"Shannon psi(t)\"}]\
\>", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.33582 0.321349 [
[.02381 .32332 -9 -9 ]
[.02381 .32332 9 0 ]
[.2619 .32332 -6 -9 ]
[.2619 .32332 6 0 ]
[.7381 .32332 -3 -9 ]
[.7381 .32332 3 0 ]
[.97619 .32332 -6 -9 ]
[.97619 .32332 6 0 ]
[1.025 .33582 0 -4.5 ]
[1.025 .33582 6 4.5 ]
[.4875 .01447 -12 -4.5 ]
[.4875 .01447 0 4.5 ]
[.4875 .09481 -30 -4.5 ]
[.4875 .09481 0 4.5 ]
[.4875 .17515 -24 -4.5 ]
[.4875 .17515 0 4.5 ]
[.4875 .25548 -30 -4.5 ]
[.4875 .25548 0 4.5 ]
[.4875 .41616 -24 -4.5 ]
[.4875 .41616 0 4.5 ]
[.4875 .49649 -18 -4.5 ]
[.4875 .49649 0 4.5 ]
[.4875 .57683 -24 -4.5 ]
[.4875 .57683 0 4.5 ]
[.5 .64303 -42 0 ]
[.5 .64303 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .33582 m
.02381 .34207 L
s
[(-10)] .02381 .32332 0 1 Mshowa
.2619 .33582 m
.2619 .34207 L
s
[(-5)] .2619 .32332 0 1 Mshowa
.7381 .33582 m
.7381 .34207 L
s
[(5)] .7381 .32332 0 1 Mshowa
.97619 .33582 m
.97619 .34207 L
s
[(10)] .97619 .32332 0 1 Mshowa
.125 Mabswid
.07143 .33582 m
.07143 .33957 L
s
.11905 .33582 m
.11905 .33957 L
s
.16667 .33582 m
.16667 .33957 L
s
.21429 .33582 m
.21429 .33957 L
s
.30952 .33582 m
.30952 .33957 L
s
.35714 .33582 m
.35714 .33957 L
s
.40476 .33582 m
.40476 .33957 L
s
.45238 .33582 m
.45238 .33957 L
s
.54762 .33582 m
.54762 .33957 L
s
.59524 .33582 m
.59524 .33957 L
s
.64286 .33582 m
.64286 .33957 L
s
.69048 .33582 m
.69048 .33957 L
s
.78571 .33582 m
.78571 .33957 L
s
.83333 .33582 m
.83333 .33957 L
s
.88095 .33582 m
.88095 .33957 L
s
.92857 .33582 m
.92857 .33957 L
s
.25 Mabswid
0 .33582 m
1 .33582 L
s
[(t)] 1.025 .33582 -1 0 Mshowa
.5 .01447 m
.50625 .01447 L
s
[(-1)] .4875 .01447 1 0 Mshowa
.5 .09481 m
.50625 .09481 L
s
[(-0.75)] .4875 .09481 1 0 Mshowa
.5 .17515 m
.50625 .17515 L
s
[(-0.5)] .4875 .17515 1 0 Mshowa
.5 .25548 m
.50625 .25548 L
s
[(-0.25)] .4875 .25548 1 0 Mshowa
.5 .41616 m
.50625 .41616 L
s
[(0.25)] .4875 .41616 1 0 Mshowa
.5 .49649 m
.50625 .49649 L
s
[(0.5)] .4875 .49649 1 0 Mshowa
.5 .57683 m
.50625 .57683 L
s
[(0.75)] .4875 .57683 1 0 Mshowa
.125 Mabswid
.5 .03054 m
.50375 .03054 L
s
.5 .04661 m
.50375 .04661 L
s
.5 .06267 m
.50375 .06267 L
s
.5 .07874 m
.50375 .07874 L
s
.5 .11088 m
.50375 .11088 L
s
.5 .12694 m
.50375 .12694 L
s
.5 .14301 m
.50375 .14301 L
s
.5 .15908 m
.50375 .15908 L
s
.5 .19121 m
.50375 .19121 L
s
.5 .20728 m
.50375 .20728 L
s
.5 .22335 m
.50375 .22335 L
s
.5 .23942 m
.50375 .23942 L
s
.5 .27155 m
.50375 .27155 L
s
.5 .28762 m
.50375 .28762 L
s
.5 .30369 m
.50375 .30369 L
s
.5 .31975 m
.50375 .31975 L
s
.5 .35189 m
.50375 .35189 L
s
.5 .36796 m
.50375 .36796 L
s
.5 .38402 m
.50375 .38402 L
s
.5 .40009 m
.50375 .40009 L
s
.5 .43223 m
.50375 .43223 L
s
.5 .44829 m
.50375 .44829 L
s
.5 .46436 m
.50375 .46436 L
s
.5 .48043 m
.50375 .48043 L
s
.5 .51256 m
.50375 .51256 L
s
.5 .52863 m
.50375 .52863 L
s
.5 .5447 m
.50375 .5447 L
s
.5 .56076 m
.50375 .56076 L
s
.5 .5929 m
.50375 .5929 L
s
.5 .60897 m
.50375 .60897 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Shannon psi\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .34556 m
.02846 .33954 L
.03068 .33692 L
.03279 .33486 L
.03398 .33393 L
.03527 .33312 L
.03645 .33259 L
.03754 .33227 L
.03871 .33212 L
.04 .33217 L
.04065 .33228 L
.04135 .33245 L
.04262 .33289 L
.04393 .33352 L
.04516 .33422 L
.04793 .33603 L
.05057 .33774 L
.05172 .33838 L
.05297 .33896 L
.0542 .33937 L
.05533 .3396 L
.05641 .33966 L
.05756 .33955 L
.05876 .33922 L
.05989 .33871 L
.06112 .33793 L
.06244 .33685 L
.06787 .33027 L
.07073 .32608 L
.07376 .32184 L
.07641 .31886 L
.07714 .31822 L
.07792 .31763 L
.07859 .31721 L
.07933 .31685 L
.08064 .31649 L
.08136 .31645 L
.08202 .31652 L
.08321 .31689 L
.08448 .31764 L
.08514 .31817 L
.08584 .31884 L
.08708 .32029 L
.0899 .32468 L
.09501 .33531 L
.10001 .34615 L
.10238 .35042 L
.10458 .3535 L
.1057 .35468 L
.1069 .35562 L
Mistroke
.10758 .35601 L
.10822 .35628 L
.10942 .35651 L
.11057 .35641 L
.11163 .35606 L
.11279 .35539 L
.11402 .35438 L
.11652 .35153 L
.11885 .34816 L
.12415 .33972 L
.12653 .33638 L
.1277 .33498 L
.12878 .33386 L
.12974 .33302 L
.1308 .33228 L
.13187 .33172 L
.133 .33136 L
.13423 .33121 L
.13535 .33129 L
.13659 .33162 L
.13789 .33219 L
.13902 .33285 L
.14007 .33358 L
.14247 .33549 L
.14493 .33754 L
.14753 .33938 L
.14889 .34007 L
.14967 .34035 L
.15039 .34053 L
.15166 .34065 L
.15237 .34059 L
.15302 .34045 L
.15429 .33995 L
.15546 .33922 L
.15675 .3381 L
.15812 .33659 L
.16296 .32906 L
.16722 .32118 L
.16945 .31737 L
.1718 .31409 L
.17305 .31278 L
.17372 .31223 L
.17443 .31176 L
.17567 .31125 L
.17684 .31115 L
.17811 .31149 L
.17931 .31225 L
.18039 .31329 L
.18156 .31479 L
.18392 .3189 L
Mistroke
.18644 .3247 L
.19101 .33738 L
.19599 .35099 L
.19735 .35411 L
.1988 .357 L
.20006 .35906 L
.20142 .36079 L
.20221 .36155 L
.20294 .36208 L
.20364 .36244 L
.20437 .36265 L
.20565 .36262 L
.20637 .36239 L
.20705 .36203 L
.20774 .36153 L
.2084 .36093 L
.20963 .35953 L
.2124 .35519 L
.21718 .3455 L
.21972 .3403 L
.22245 .33546 L
.22372 .33363 L
.22505 .33206 L
.22619 .33103 L
.22744 .33023 L
.22861 .32982 L
.22986 .32972 L
.23104 .32994 L
.23211 .33039 L
.23343 .33122 L
.23465 .33222 L
.23739 .33504 L
.23997 .3379 L
.24238 .34026 L
.24343 .34108 L
.24443 .34168 L
.24559 .34214 L
.24664 .3423 L
.2478 .34219 L
.24888 .34177 L
.25007 .34098 L
.25133 .33973 L
.25256 .33811 L
.25389 .33596 L
.2563 .33111 L
.2608 .32004 L
.26541 .30906 L
.26674 .30655 L
.26799 .3046 L
.26912 .30325 L
Mistroke
.27034 .30226 L
.27099 .30196 L
.27171 .30182 L
.27245 .30188 L
.27315 .30214 L
.2744 .30309 L
.27511 .30391 L
.27575 .30483 L
.27699 .30705 L
.27834 .31013 L
.28079 .31731 L
.28648 .33895 L
.28928 .35007 L
.29185 .35929 L
.29419 .36615 L
.29538 .36892 L
.29666 .37127 L
.29795 .37294 L
.29915 .37386 L
.29988 .37411 L
.30057 .37413 L
.30188 .37361 L
.303 .37259 L
.30425 .3709 L
.30555 .36855 L
.30677 .36588 L
.31129 .35328 L
.3139 .34541 L
.31664 .33782 L
.31898 .33257 L
.32031 .33028 L
.32154 .32864 L
.32285 .32746 L
.32409 .32689 L
.32521 .32681 L
.32642 .32717 L
.32773 .32806 L
.3284 .32868 L
.32913 .32949 L
.33163 .33301 L
.3343 .33745 L
.33571 .33976 L
.33721 .34199 L
.33865 .34376 L
.33996 .34493 L
.34127 .34559 L
.34251 .34568 L
.34375 .34519 L
.34505 .34403 L
.34617 .34249 L
Mistroke
.34739 .34024 L
.35012 .33316 L
.35266 .32445 L
.35743 .30542 L
.35978 .29645 L
.36195 .2894 L
.36315 .28626 L
.36448 .28358 L
.36517 .28256 L
.36581 .28184 L
.36649 .28134 L
.36723 .28113 L
.36845 .28154 L
.36974 .28302 L
.37083 .28515 L
.37203 .28838 L
.37345 .29337 L
.37474 .29893 L
.37763 .31445 L
.38284 .34861 L
.3877 .37903 L
.39015 .39073 L
.39154 .39577 L
.39284 .39928 L
.39403 .40142 L
.39516 .40246 L
.39618 .40258 L
.39728 .40184 L
.39848 .40004 L
.39976 .39705 L
.40085 .39368 L
.40205 .38919 L
.42286 .32056 L
.42814 .33436 L
.43071 .34303 L
.43305 .3501 L
.43433 .35312 L
.43553 .35521 L
.4368 .35643 L
.43752 .35661 L
.43818 .35642 L
.43948 .35501 L
.44022 .35357 L
.44091 .35177 L
.4423 .34684 L
.4438 .33957 L
.44626 .32347 L
.44894 .30093 L
.45383 .25326 L
.45614 .23179 L
Mistroke
.45741 .22132 L
.4586 .2127 L
.45971 .20598 L
.46092 .20042 L
.46201 .19709 L
.46302 .19562 L
.46419 .19599 L
.46525 .19837 L
.46648 .20364 L
.46765 .21118 L
.46873 .22035 L
.46972 .23069 L
.47198 .26043 L
.47674 .34717 L
.48181 .45616 L
.48415 .50398 L
.48668 .54839 L
.48784 .56527 L
.48906 .58009 L
.4901 .59008 L
.49125 .59798 L
.49195 .60118 L
.49261 .60298 L
.49385 .60312 L
.49455 .6013 L
.49519 .59842 L
.4959 .59391 L
.49664 .5876 L
.49788 .57375 L
.49903 .55706 L
.50166 .50664 L
.50664 .37473 L
.51207 .21115 L
.51455 .1431 L
.5172 .08283 L
.51848 .05949 L
.51969 .04166 L
.52078 .02932 L
.52195 .02008 L
.52311 .01526 L
.5242 .01472 L
.52538 .01851 L
.52665 .02758 L
.52729 .03406 L
.52799 .0425 L
.52925 .06143 L
.53162 .1082 L
.53623 .23111 L
.54049 .36024 L
.54514 .4878 L
Mistroke
.54776 .54288 L
.549 .56335 L
.55015 .57875 L
.55122 .58983 L
.55236 .59807 L
.55363 .60288 L
.55479 .60332 L
.55588 .60037 L
.55706 .59364 L
.55817 .58408 L
.5592 .57272 L
.56167 .5366 L
.56398 .49401 L
.56922 .38217 L
.5743 .28205 L
.57569 .25979 L
.57716 .23943 L
.57844 .22482 L
.57982 .21233 L
.58047 .20764 L
.58115 .20354 L
.58238 .19834 L
.58352 .19588 L
.58478 .19576 L
.5855 .19684 L
.58615 .19851 L
.5869 .2012 L
.58761 .20445 L
.58888 .21178 L
.59026 .22165 L
.59506 .26586 L
.59769 .29171 L
.60015 .31386 L
.60255 .33186 L
.60474 .34428 L
.60599 .34944 L
.60718 .35303 L
.60843 .35545 L
.60914 .35622 L
.6098 .35656 L
.61096 .35634 L
.61206 .35525 L
.61305 .35362 L
.61411 .35127 L
.6187 .33699 L
.62108 .32925 L
.62239 .32554 L
.62363 .32262 L
.62478 .32053 L
.62603 .31905 L
Mistroke
.62717 .3185 L
.62822 .31871 L
.62946 .31985 L
.63063 .32181 L
.63191 .32492 L
.63328 .32933 L
.63609 .34116 L
.63866 .35431 L
.64123 .36825 L
.64398 .38223 L
.64532 .38816 L
.64657 .393 L
.64772 .39665 L
.64893 .39963 L
.65022 .40171 L
.65141 .40257 L
.65268 .40233 L
.65341 .40164 L
.65409 .40064 L
.65482 .39919 L
.65551 .39745 L
.65681 .39328 L
.65973 .38005 L
.66936 .31827 L
.67213 .30257 L
.67349 .29618 L
.67473 .29122 L
.67585 .28758 L
.67707 .28451 L
.6783 .28242 L
.6796 .28129 L
.68084 .28122 L
.68201 .28203 L
.68306 .28345 L
.6842 .28565 L
.68544 .28876 L
.68676 .29275 L
.68913 .30126 L
.69368 .31954 L
.698 .33467 L
.70035 .34049 L
.70168 .34285 L
.70292 .34441 L
.70406 .3453 L
.70509 .34567 L
.70629 .3456 L
.70741 .34509 L
.70865 .34409 L
.70995 .34261 L
.71228 .33918 L
Mistroke
.71481 .33493 L
.71754 .33071 L
.71875 .32919 L
.7199 .32805 L
.72093 .32732 L
.72205 .32687 L
.72311 .32681 L
.72423 .32715 L
.7252 .32779 L
.72626 .32885 L
.7275 .33057 L
.72864 .33256 L
.7312 .33837 L
.73584 .35179 L
.74057 .36521 L
.74194 .36828 L
.74323 .37067 L
.74438 .37232 L
.74564 .37353 L
.74673 .37407 L
.74794 .37406 L
.7492 .37338 L
.75038 .37211 L
.75148 .37038 L
.75249 .36838 L
.75476 .36248 L
.75996 .34371 L
.7655 .32189 L
.76819 .3131 L
.76951 .30957 L
.77072 .30687 L
.77183 .30489 L
.773 .30332 L
.77417 .30231 L
.77545 .30183 L
.77673 .302 L
.77794 .30273 L
.77903 .30383 L
.78021 .30544 L
.78285 .31042 L
.7853 .31617 L
.79003 .32813 L
.79235 .33332 L
.79447 .33722 L
.79558 .33883 L
.79678 .34026 L
.79799 .34131 L
.79926 .34201 L
.79995 .34222 L
.80058 .3423 L
Mistroke
.80131 .34228 L
.80199 .34215 L
.80321 .34167 L
.80454 .34083 L
.80582 .33975 L
.80724 .33835 L
.81009 .33518 L
.81275 .33242 L
.81392 .33142 L
.81521 .33055 L
.81642 .32999 L
.81771 .32972 L
.81839 .32973 L
.81912 .32984 L
.82044 .33037 L
.8217 .33125 L
.82233 .33182 L
.82302 .33256 L
.8254 .33582 L
.83021 .34502 L
.83469 .35422 L
.836 .35656 L
.83741 .35876 L
.83866 .36035 L
.83998 .36162 L
.84118 .36235 L
.84249 .36269 L
.84368 .36254 L
.8448 .36201 L
.84546 .36151 L
.84619 .3608 L
.84751 .35912 L
.85 .35468 L
.8529 .34776 L
.8556 .34029 L
.86068 .32597 L
.86335 .31963 L
.86481 .31679 L
.86617 .31462 L
.86737 .31313 L
.86865 .31199 L
.86938 .31156 L
.87007 .31129 L
.87136 .31115 L
.87255 .31144 L
.87365 .31205 L
.87485 .31305 L
.87613 .31448 L
.88086 .32202 L
.88584 .33115 L
Mistroke
.8879 .33444 L
.89009 .33729 L
.89136 .33856 L
.8925 .33946 L
.89366 .34011 L
.89474 .34049 L
.89588 .34064 L
.89709 .34056 L
.89811 .3403 L
.89924 .33983 L
.90046 .33915 L
.90176 .33825 L
.90412 .33636 L
.90683 .33412 L
.90816 .33314 L
.9094 .33237 L
.91052 .33182 L
.91171 .33141 L
.91303 .33121 L
.91423 .33128 L
.91537 .33158 L
.91659 .33214 L
.91762 .33283 L
.91876 .33379 L
.92129 .33664 L
.92365 .34 L
.92825 .34736 L
.93028 .3504 L
.93251 .35326 L
.93368 .35446 L
.93495 .35547 L
.93565 .35589 L
.93628 .35618 L
.93754 .35649 L
.93823 .35651 L
.93887 .35642 L
.93958 .35621 L
.94033 .35586 L
.94105 .3554 L
.94173 .35485 L
.943 .35355 L
.94548 .35003 L
.94776 .34585 L
.95291 .33463 L
.95517 .3297 L
.95758 .32493 L
.95982 .32127 L
.96194 .31867 L
.96308 .31768 L
.96432 .31693 L
Mistroke
.96545 .31655 L
.96649 .31645 L
.96764 .31663 L
.96891 .31715 L
.96955 .31753 L
.97024 .31803 L
.97149 .31913 L
.97619 .32505 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "We see that the scaling function and the wavelet decay very slowly in \
time. This is due to the discontinuities in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The lack of smoothness of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " in frequency space gives rise to its poor localization in time. The Haar \
wavelet is just the opposite extreme where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is discontinuous in time. Unlike Battle\[Hyphen]Lemari\[EAcute] wavelets, \
where the filter coefficients decay exponentially, the filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " for Shannon wavelet decay as ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(-1\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ":"
}], "Text",
  CellTags->{"S1.3.2", "2.44"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(h\_k\),
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              "=", \(\@2\), \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\), "H", \((\[Omega])\), 
                \(e\^\(i k \[Omega]\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "=", \(\@2\), \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Pi]/2\)\%\(\[Pi]/2\)\), 
                \(e\^\(i k \[Omega]\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], "\[Null]"},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"=", 
                RowBox[{"{", GridBox[{
                      {
                        StyleBox[\(\@2\/2\),
                          "DisplayFormula"], 
                        StyleBox[\(k = 0\),
                          "DisplayFormula"]},
                      {
                        
                        StyleBox[
                          \(\(\@2\) 
                            \((\(-1\))\)\^\(\((k - 1)\)/2\)\/\(\[Pi] k\)\),
                          "DisplayFormula"], 
                        StyleBox[\(k " odd"\),
                          "DisplayFormula"]},
                      {
                        StyleBox["0",
                          "DisplayFormula"], 
                        StyleBox[\("otherwise".\),
                          "DisplayFormula"]}
                      },
                    ColumnAlignments->{Left}]}]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Left}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.45"}],

Cell[TextData[{
  "This slow decay of the filter coefficients makes Shannon wavelet less \
practical. To get Shannon filter coefficients from ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["h", 
          RowBox[{"-", 
            StyleBox[\("kmax"\),
              "TI"]}]], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.2"],
  " to ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["h", 
          StyleBox[\("kmax"\),
            "TI"]], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.2"],
  ", we can use "
}], "Text",
  CellTags->{"S1.3.2", "2.46"}],

Cell[TextData[{
  StyleBox["ShannonFilter[", "MR"],
  StyleBox["kmax", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.2", "2.47"}],

Cell["Meyer Wavelet", "Subsubsection",
  CellTags->{"S1.3.2", "2.48"}],

Cell[TextData[{
  "The slow decay of the Shannon wavelet in the time domain can be improved \
by smoothing the scaling function in frequency space. Instead of a sharp \
discontinuity, a smooth function is used to interpolate between ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\) = 1\)], "InlineFormula",
    
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\) = 0\)], "InlineFormula",
    
    CellTags->"S1.3.2"],
  ". For example, the Meyer scaling function is (see Daubechies (1992))"
}], "Text",
  CellTags->{"S1.3.2", "2.49"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\&^\), \((\[Omega])\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["1",
                  "DisplayFormula"], 
                
                StyleBox[
                  \(\( \[VerticalSeparator] 
                      \(\[Omega] \[VerticalSeparator] \)\) \[LessEqual] 2 
                    \[Pi]/3\),
                  "DisplayFormula"]},
              {
                
                StyleBox[
                  \(cos \(\[InvisibleSpace]\([
                    \(\[Pi]\/2\) \[Nu] \((
                      3\/\(2 \[Pi]\) \[VerticalSeparator] \[Omega] 
                        \[VerticalSeparator] \(-1\))\)]\)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(2 \[Pi]/3 \[LessEqual] 
                    \( \[VerticalSeparator] 
                      \(\[Omega] \[VerticalSeparator] \)\) \[LessEqual] 4 
                    \[Pi]/3\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise", \),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.2", "2.50"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is a smooth function satisfying "
}], "Text",
  CellTags->{"S1.3.2", "2.51"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Nu]", \((x)\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\("if "\), 
                    StyleBox[\(x \[LessEqual] 0\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox["1",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{
                    RowBox[{\("if "\), 
                      StyleBox[\(x \[GreaterEqual] 1\),
                        "DisplayFormula"]}], ","}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.2", "2.52"}],

Cell["and ", "Text",
  CellTags->{"S1.3.2", "2.53"}],

Cell[BoxData[
    \(TraditionalForm\`\[Nu] \((x)\) + \[Nu] \((1 - x)\) = 1.\)], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.54"}],

Cell[TextData[{
  "For example, we can choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \(\[InvisibleSpace]\([0, 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " to be a polynomial interpolating between 0 and 1. One choice is "
}], "Text",
  CellTags->{"S1.3.2", "2.55"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[Nu] \((x)\) = \(x\^4\) \((35 - 84  x + 70  x\^2 - 20  x\^3)\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(3.13) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.2", "2.56"}],

Cell[TextData[{
  "We will show how this is obtained at the end of the section. Using ",
  StyleBox["Mathematica", "TI"],
  ", we can easily check that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\) + \[Nu] \((1 - x)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " is satisfied. "
}], "Text",
  CellTags->{"S1.3.2", "2.57"}],

Cell[TextData[{
  "This defines ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.58"}],

Cell[CellGroupData[{

Cell["nu[x_] = x^4 (35 - 84x + 70x^2 - 20x^3)", "Input",
  CellLabel->"In[42]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(x\^4\ \((35 - 84\ x + 70\ x\^2 - 20\ x\^3)\)\)], "Output",
  CellLabel->"Out[42]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " satisfies the identity."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.59"}],

Cell[CellGroupData[{

Cell["Expand[nu[x]+nu[1-x]]", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[43]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "This defines Meyer ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.60"}],

Cell["\<\
meyerPhiHat[w_]:= Which[Abs[w]<=N[2Pi/3], 1,
N[2Pi/3] < Abs[w] < N[4Pi/3],
Cos[Pi/2 nu[3/(2Pi)Abs[w]-1]], True, 0]\
\>", "Input",
  CellLabel->"In[44]:= ",
  CellTags->"S1.3.2"],

Cell[TextData[{
  "With the above ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", the Meyer scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and its translates are plotted here."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.61"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{meyerPhiHat[w], meyerPhiHat[w+2Pi],
meyerPhiHat[w-2Pi]}, {w, -4/3 Pi, 4/3 Pi},
Ticks -> {Range[-2Pi, 2Pi, 2Pi/3], {1}},
PlotStyle -> {{}, Dashing[{0.02}], Dashing[{0.02}]},
AxesLabel -> {\"w\", \"Meyer phihat(w)\"}]\
\>", "Input",
  CellLabel->"In[45]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.113682 0.0147151 0.588604 [
[.02381 .00222 -15 -33 ]
[.02381 .00222 15 0 ]
[.2619 .00222 -15 -33 ]
[.2619 .00222 15 0 ]
[.7381 .00222 -12 -33 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -33 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -45 0 ]
[.5 .64303 45 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-4 Pi)(-----)(  3)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-2 Pi)(-----)(  3)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2 Pi)(----)( 3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4 Pi)(----)( 3)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(Meyer phihat\\(w\\))] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01473 L
.03053 .01473 L
.03163 .01475 L
.03279 .01477 L
.03395 .01481 L
.0352 .01487 L
.03638 .01494 L
.03746 .01502 L
.03873 .01514 L
.04011 .01532 L
.04262 .01575 L
.04396 .01606 L
.04523 .01641 L
.04759 .01723 L
.05014 .01839 L
.0529 .02002 L
.05787 .02415 L
.06244 .02954 L
.0675 .03758 L
.07221 .04731 L
.07782 .06195 L
.08293 .0784 L
.09338 .12151 L
.10458 .18113 L
.12528 .31589 L
.14443 .44023 L
.15401 .49176 L
.16301 .53049 L
.1724 .56036 L
.17738 .57213 L
.18275 .58199 L
.18771 .58882 L
.19233 .59354 L
.19739 .59724 L
.20022 .59877 L
.2028 .59987 L
.20532 .60073 L
.208 .60145 L
.21094 .60204 L
.21365 .60243 L
.21617 .60271 L
.21853 .6029 L
.22111 .60304 L
.22257 .60311 L
.22389 .60315 L
Mistroke
.22519 .60319 L
.2264 .60322 L
.22868 .60326 L
.22995 .60327 L
.23112 .60328 L
.23241 .60329 L
.23377 .6033 L
.23486 .6033 L
.23603 .60331 L
.23713 .60331 L
.23813 .60331 L
.23931 .60332 L
.24059 .60332 L
.2418 .60332 L
.24292 .60332 L
.24411 .60332 L
.24539 .60332 L
.2466 .60332 L
.2477 .60332 L
.24893 .60332 L
.24963 .60332 L
.25028 .60332 L
.25158 .60332 L
.25232 .60332 L
.25298 .60332 L
.25365 .60332 L
.25435 .60332 L
.25562 .60332 L
.25632 .60332 L
.25698 .60332 L
.2577 .60332 L
.25847 .60332 L
.25914 .60332 L
.25987 .60332 L
.26118 .60332 L
.26247 .60332 L
.26366 .60332 L
.30289 .60332 L
.34061 .60332 L
.38078 .60332 L
.41943 .60332 L
.46054 .60332 L
.50013 .60332 L
.53821 .60332 L
.57874 .60332 L
.61775 .60332 L
.65922 .60332 L
.69917 .60332 L
.71746 .60332 L
.72786 .60332 L
Mistroke
.73295 .60332 L
.73536 .60332 L
.7376 .60332 L
.73874 .60332 L
.73995 .60332 L
.74064 .60332 L
.74129 .60332 L
.74251 .60332 L
.74367 .60332 L
.74475 .60332 L
.74592 .60332 L
.74717 .60332 L
.74839 .60332 L
.7497 .60332 L
.75094 .60332 L
.75207 .60332 L
.75276 .60332 L
.7534 .60332 L
.75409 .60332 L
.75484 .60332 L
.75608 .60332 L
.75679 .60332 L
.75745 .60332 L
.75868 .60332 L
.75938 .60332 L
.76003 .60332 L
.76134 .60331 L
.76207 .60331 L
.76274 .60331 L
.76393 .60331 L
.76523 .6033 L
.76645 .6033 L
.76758 .60329 L
.76888 .60328 L
.7701 .60327 L
.77144 .60325 L
.77288 .60323 L
.77438 .6032 L
.77581 .60316 L
.7771 .60312 L
.77849 .60306 L
.78109 .60292 L
.78354 .60273 L
.78592 .60249 L
.78811 .60219 L
.79049 .60177 L
.79309 .60118 L
.79581 .60037 L
.79835 .59941 L
.803 .59701 L
Mistroke
.80724 .59392 L
.81213 .58901 L
.81675 .58276 L
.82136 .57469 L
.82644 .56335 L
.83672 .53151 L
.84623 .49057 L
.85515 .44269 L
.89391 .19008 L
.90401 .13422 L
.91504 .08577 L
.92008 .06835 L
.92545 .05298 L
.93016 .04214 L
.93513 .03311 L
.94041 .02598 L
.94528 .02134 L
.94799 .01945 L
.95052 .01806 L
.95329 .01689 L
.95484 .01639 L
.95627 .016 L
.95883 .01548 L
.96018 .01528 L
.96162 .01511 L
.96286 .01499 L
.96403 .01491 L
.96531 .01484 L
.96602 .01481 L
.96669 .01479 L
.96784 .01476 L
.9691 .01474 L
.97033 .01473 L
.97164 .01472 L
.97287 .01472 L
.97403 .01472 L
.97506 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60332 L
.03944 .60332 L
.04011 .60332 L
.04132 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04726 .60331 L
.04797 .60331 L
.04925 .60331 L
.05041 .60331 L
.05166 .6033 L
.05302 .60329 L
.05414 .60329 L
.05539 .60328 L
.05669 .60326 L
.05791 .60324 L
.06009 .6032 L
.06132 .60317 L
.06244 .60313 L
.0649 .60303 L
.06627 .60295 L
.06752 .60287 L
.06995 .60267 L
.07225 .60241 L
.07492 .60201 L
.07739 .60152 L
.0801 .60082 L
.08297 .59985 L
.08553 .59875 L
.08829 .59727 L
.09326 .59365 L
.09629 .59074 L
.09918 .58738 L
Mistroke
.10458 .5793 L
.10962 .56934 L
.11419 .55802 L
.12442 .52385 L
.13391 .48081 L
.14282 .43111 L
.18143 .17942 L
.19177 .12421 L
.20141 .08335 L
.21146 .05224 L
.21678 .0403 L
.22248 .03064 L
.22506 .02723 L
.22778 .02421 L
.23268 .02011 L
.2354 .01847 L
.23795 .01729 L
.24075 .01633 L
.24232 .01592 L
.24376 .01562 L
.24494 .01541 L
.24619 .01524 L
.24728 .01511 L
.24845 .015 L
.24984 .0149 L
.25114 .01484 L
.25241 .01479 L
.25358 .01476 L
.25481 .01474 L
.25597 .01473 L
.25723 .01472 L
.25794 .01472 L
.25859 .01472 L
.2599 .01472 L
.26063 .01472 L
.26132 .01472 L
.26257 .01472 L
.2632 .01472 L
.2639 .01472 L
.30407 .01472 L
.34272 .01472 L
.38383 .01472 L
.42342 .01472 L
.4615 .01472 L
.50203 .01472 L
.54104 .01472 L
.58251 .01472 L
.62246 .01472 L
.66089 .01472 L
.70178 .01472 L
Mistroke
.74115 .01472 L
.779 .01472 L
.81931 .01472 L
.8581 .01472 L
.89935 .01472 L
.93907 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.57861 .01472 L
.61984 .01472 L
.65954 .01472 L
.69774 .01472 L
.71741 .01472 L
.72307 .01472 L
.72841 .01472 L
.7332 .01472 L
.73451 .01472 L
.7359 .01472 L
.73708 .01472 L
.73838 .01472 L
.73969 .01472 L
.74089 .01472 L
.74152 .01472 L
.74222 .01472 L
.74294 .01472 L
.74362 .01472 L
.74487 .01473 L
.74601 .01475 L
.74727 .01478 L
.74859 .01482 L
.7497 .01488 L
.75089 .01495 L
.75201 .01504 L
.75303 .01514 L
.75423 .01529 L
.75553 .01549 L
.75789 .01597 L
.76041 .01669 L
.76318 .01778 L
.76607 .01931 L
.76877 .02116 L
.77361 .02568 L
.77881 .03256 L
.78406 .042 L
Mistroke
.78894 .05325 L
.79998 .08856 L
.80972 .13144 L
.82008 .18835 L
.8401 .31954 L
.85062 .39007 L
.86172 .45744 L
.87169 .50753 L
.87697 .52927 L
.88263 .54874 L
.88783 .56331 L
.89257 .57398 L
.89733 .58244 L
.90184 .58863 L
.90644 .59339 L
.91152 .59715 L
.91407 .59855 L
.91682 .59977 L
.91919 .6006 L
.92179 .60133 L
.92422 .60185 L
.92648 .60223 L
.92886 .60254 L
.93141 .60279 L
.93379 .60296 L
.93603 .60307 L
.93804 .60315 L
.93918 .60318 L
.94022 .60321 L
.9423 .60325 L
.94344 .60326 L
.94453 .60327 L
.94645 .60329 L
.94754 .6033 L
.94855 .6033 L
.94964 .60331 L
.95066 .60331 L
.95178 .60331 L
.95299 .60331 L
.95418 .60332 L
.95545 .60332 L
.95652 .60332 L
.9577 .60332 L
.95895 .60332 L
.96013 .60332 L
.96118 .60332 L
.96233 .60332 L
.96358 .60332 L
.96421 .60332 L
.9649 .60332 L
Mistroke
.96613 .60332 L
.96728 .60332 L
.96843 .60332 L
.96952 .60332 L
.9705 .60332 L
.97157 .60332 L
.97273 .60332 L
.97397 .60332 L
.97513 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "The fact that ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " form an orthonormal basis can be seen from ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "l",
            LimitsPositioning->True], 
          \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                  \)\[RightBracketingBar]\^2\), "=", "1"}], TraditionalForm]],
     "InlineFormula",
    CellTags->"S1.3.2"],
  ". From the above plot, we see that the supports of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((\[Omega] - 2  \[Pi])\)\)], "InlineFormula",
    
    CellTags->"S1.3.2"],
  " only overlap in the region ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Omega] \[Element] \(\[InvisibleSpace]\([2  \[Pi]/3, 4  \[Pi]/3]
        \)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", so we only need to show that "
}], "Text",
  CellTags->{"S1.3.2", "2.62"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(cos\^2\) \(\[InvisibleSpace]\([
      \(\[Pi]\/2\) \[Nu] \((\(3\/\(2  \[Pi]\)\) \[Omega] - 1)\)]\)\) + 
      \(cos\^2\) \(\[InvisibleSpace]\([
      \(\[Pi]\/2\) \[Nu] \((
        3\/\(2  \[Pi]\) \[VerticalSeparator] \[Omega] - 2  \[Pi] 
          \[VerticalSeparator] \(-1\))\)]\)\) = 1.\)], "DisplayFormula",
  CellTags->{"S1.3.2", "2.63"}],

Cell["\<\
This is true since the second term on the left\[Hyphen]hand side of \
the equation can be written as \
\>", "Text",
  CellTags->{"S1.3.2", "2.64"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(cos\^2\) \(\[InvisibleSpace]\([
      \(\[Pi]\/2\) \[Nu] \((\(-\(3\/\(2  \[Pi]\)\) \[Omega] + 2\))\)]\)\) = 
      \(cos\^2\) \(\[InvisibleSpace]\([
      \[Pi]\/2 - \(\[Pi]\/2\) \[Nu] \((\(3\/\(2  \[Pi]\)\) \[Omega] - 1)\)]
      \)\) = \(sin\^2\) \(\[InvisibleSpace]\([
      \(\[Pi]\/2\) \[Nu] \((\(3\/\(2  \[Pi]\)\) \[Omega] - 1)\)]\)\).\)], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.65"}],

Cell[TextData[{
  "So ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "l",
            LimitsPositioning->True], 
          \(\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)
                  \)\[RightBracketingBar]\^2\), "=", "1"}], TraditionalForm]],
     "InlineFormula",
    CellTags->"S1.3.2"],
  ". As in the last example, we take ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " to be the closed space spanned by the orthonormal basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", and a multiresolution analysis can be constructed. The dilation equation \
gives "
}], "Text",
  CellTags->{"S1.3.2", "2.66"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\) = \(\[Phi]\&^\) \((\[Omega])\) \(\[Phi]\&^\) \((
      \[Omega]/2)\).\)], "DisplayFormula",
  CellTags->{"S1.3.2", "2.67"}],

Cell[TextData[{
  "The last equality holds due to the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " on the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", as is shown in the following graph. "
}], "Text",
  CellTags->{"S1.3.2", "2.68"}],

Cell[TextData[{
  "Here are the graphs of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (dashed line)."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.69"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{meyerPhiHat[w], meyerPhiHat[w/2]},
{w, -8/3 Pi, 8/3 Pi},
PlotStyle -> {{}, Dashing[{0.02}]},
Ticks -> {Range[-4Pi, 4Pi, 4Pi/3], {1}},
AxesLabel -> {\"w\", \"Meyer phihat(w) and phihat(w/2)\"}]\
\>", "Input",
  CellLabel->"In[46]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0568411 0.0147151 0.588604 [
[.02381 .00222 -15 -33 ]
[.02381 .00222 15 0 ]
[.2619 .00222 -15 -33 ]
[.2619 .00222 15 0 ]
[.7381 .00222 -12 -33 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -33 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -93 0 ]
[.5 .64303 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-8 Pi)(-----)(  3)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-4 Pi)(-----)(  3)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(4 Pi)(----)( 3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(8 Pi)(----)( 3)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(Meyer phihat\\(w\\) and phihat\\(w/2\\))] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .01472 L
.26425 .01472 L
.26494 .01473 L
.26567 .01474 L
.26698 .01481 L
.26773 .01488 L
.26855 .01499 L
.26932 .01513 L
.27003 .01531 L
.27137 .01578 L
.27205 .01609 L
.27279 .01652 L
.27412 .01749 L
.27534 .01867 L
.27675 .02043 L
.27808 .02253 L
.28044 .02751 L
.28302 .035 L
.28543 .04427 L
.28809 .05729 L
.29348 .09348 L
.29847 .13903 L
.30316 .19143 L
.32163 .43335 L
.32669 .48872 L
.32948 .51424 L
.3321 .53487 L
.33455 .55107 L
.33721 .56544 L
.3396 .57578 L
.34184 .58343 L
.34425 .58974 L
.34564 .5926 L
.34691 .59478 L
.34949 .59814 L
.35092 .59949 L
.35227 .60049 L
.35343 .60116 L
Mistroke
.35466 .60173 L
.35582 .60215 L
.35687 .60245 L
.35811 .60271 L
.35876 .60282 L
.35945 .60292 L
.36072 .60306 L
.36188 .60315 L
.3632 .60322 L
.3644 .60326 L
.36506 .60327 L
.36578 .60329 L
.36709 .6033 L
.36832 .60331 L
.36962 .60332 L
.37073 .60332 L
.37195 .60332 L
.37265 .60332 L
.37338 .60332 L
.37469 .60332 L
.37542 .60332 L
.3761 .60332 L
.37685 .60332 L
.37764 .60332 L
.37834 .60332 L
.37908 .60332 L
.37979 .60332 L
.38044 .60332 L
.38168 .60332 L
.38298 .60332 L
.42092 .60332 L
.46131 .60332 L
.50019 .60332 L
.54152 .60332 L
.56219 .60332 L
.58133 .60332 L
.59989 .60332 L
.60927 .60332 L
.61184 .60332 L
.61461 .60332 L
.61589 .60332 L
.61723 .60332 L
.61837 .60332 L
.61963 .60332 L
.62095 .60332 L
.62216 .60332 L
.62279 .60332 L
.62349 .60332 L
.62422 .60332 L
.6249 .60332 L
Mistroke
.62616 .60332 L
.62731 .60332 L
.62794 .60332 L
.62863 .60332 L
.62989 .60332 L
.63112 .60331 L
.63223 .60331 L
.63352 .6033 L
.63473 .60328 L
.63585 .60325 L
.63688 .60321 L
.63802 .60315 L
.63922 .60307 L
.64052 .60292 L
.64171 .60275 L
.64308 .60246 L
.64438 .60209 L
.64558 .60163 L
.64669 .6011 L
.64791 .60037 L
.6492 .59939 L
.6505 .59816 L
.65189 .59651 L
.65441 .5925 L
.65587 .58945 L
.65741 .58558 L
.66016 .57669 L
.66273 .56573 L
.66517 .55276 L
.66971 .52098 L
.67461 .47551 L
.67991 .41448 L
.69829 .17442 L
.70286 .12585 L
.70776 .08397 L
.71057 .06502 L
.71314 .05089 L
.71558 .04011 L
.71818 .03124 L
.71959 .02744 L
.72086 .02456 L
.72335 .0203 L
.72474 .01858 L
.72625 .01719 L
.72694 .01669 L
.72767 .01625 L
.72898 .01564 L
.7302 .01525 L
.73151 .01498 L
.73274 .01483 L
Mistroke
.73387 .01476 L
.73519 .01473 L
.73593 .01472 L
.73662 .01472 L
.73789 .01472 L
.73852 .01472 L
.73923 .01472 L
.7795 .01472 L
.81826 .01472 L
.85947 .01472 L
.89917 .01472 L
.93735 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01473 L
.03053 .01473 L
.03163 .01475 L
.03279 .01477 L
.03395 .01481 L
.0352 .01487 L
.03638 .01494 L
.03746 .01502 L
.03873 .01514 L
.04011 .01532 L
.04262 .01575 L
.04396 .01606 L
.04523 .01641 L
.04759 .01723 L
.05014 .01839 L
.0529 .02002 L
.05787 .02415 L
.06244 .02954 L
.0675 .03758 L
.07221 .04731 L
.07782 .06195 L
.08293 .0784 L
.09338 .12151 L
.10458 .18113 L
.12528 .31589 L
.14443 .44023 L
.15401 .49176 L
.16301 .53049 L
.1724 .56036 L
.17738 .57213 L
.18275 .58199 L
.18771 .58882 L
.19233 .59354 L
.19739 .59724 L
.20022 .59877 L
.2028 .59987 L
.20532 .60073 L
.208 .60145 L
.21094 .60204 L
.21365 .60243 L
.21617 .60271 L
.21853 .6029 L
.22111 .60304 L
.22257 .60311 L
.22389 .60315 L
Mistroke
.22519 .60319 L
.2264 .60322 L
.22868 .60326 L
.22995 .60327 L
.23112 .60328 L
.23241 .60329 L
.23377 .6033 L
.23486 .6033 L
.23603 .60331 L
.23713 .60331 L
.23813 .60331 L
.23931 .60332 L
.24059 .60332 L
.2418 .60332 L
.24292 .60332 L
.24411 .60332 L
.24539 .60332 L
.2466 .60332 L
.2477 .60332 L
.24893 .60332 L
.24963 .60332 L
.25028 .60332 L
.25158 .60332 L
.25232 .60332 L
.25298 .60332 L
.25365 .60332 L
.25435 .60332 L
.25562 .60332 L
.25632 .60332 L
.25698 .60332 L
.2577 .60332 L
.25847 .60332 L
.25914 .60332 L
.25987 .60332 L
.26118 .60332 L
.26247 .60332 L
.26366 .60332 L
.30289 .60332 L
.34061 .60332 L
.38078 .60332 L
.41943 .60332 L
.46054 .60332 L
.50013 .60332 L
.53821 .60332 L
.57874 .60332 L
.61775 .60332 L
.65922 .60332 L
.69917 .60332 L
.71746 .60332 L
.72786 .60332 L
Mistroke
.73295 .60332 L
.73536 .60332 L
.7376 .60332 L
.73874 .60332 L
.73995 .60332 L
.74064 .60332 L
.74129 .60332 L
.74251 .60332 L
.74367 .60332 L
.74475 .60332 L
.74592 .60332 L
.74717 .60332 L
.74839 .60332 L
.7497 .60332 L
.75094 .60332 L
.75207 .60332 L
.75276 .60332 L
.7534 .60332 L
.75409 .60332 L
.75484 .60332 L
.75608 .60332 L
.75679 .60332 L
.75745 .60332 L
.75868 .60332 L
.75938 .60332 L
.76003 .60332 L
.76134 .60331 L
.76207 .60331 L
.76274 .60331 L
.76393 .60331 L
.76523 .6033 L
.76645 .6033 L
.76758 .60329 L
.76888 .60328 L
.7701 .60327 L
.77144 .60325 L
.77288 .60323 L
.77438 .6032 L
.77581 .60316 L
.7771 .60312 L
.77849 .60306 L
.78109 .60292 L
.78354 .60273 L
.78592 .60249 L
.78811 .60219 L
.79049 .60177 L
.79309 .60118 L
.79581 .60037 L
.79835 .59941 L
.803 .59701 L
Mistroke
.80724 .59392 L
.81213 .58901 L
.81675 .58276 L
.82136 .57469 L
.82644 .56335 L
.83672 .53151 L
.84623 .49057 L
.85515 .44269 L
.89391 .19008 L
.90401 .13422 L
.91504 .08577 L
.92008 .06835 L
.92545 .05298 L
.93016 .04214 L
.93513 .03311 L
.94041 .02598 L
.94528 .02134 L
.94799 .01945 L
.95052 .01806 L
.95329 .01689 L
.95484 .01639 L
.95627 .016 L
.95883 .01548 L
.96018 .01528 L
.96162 .01511 L
.96286 .01499 L
.96403 .01491 L
.96531 .01484 L
.96602 .01481 L
.96669 .01479 L
.96784 .01476 L
.9691 .01474 L
.97033 .01473 L
.97164 .01472 L
.97287 .01472 L
.97403 .01472 L
.97506 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " needs to be ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "\[Hyphen]periodic, we again extend it periodically by forming the sum "
}], "Text",
  CellTags->{"S1.3.2", "2.70"}],

Cell[BoxData[
    FormBox[
      RowBox[{"H", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\[Phi]\&^\), \((
        2 \((\[Omega] + 2  \[Pi]  l)\))\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.71"}],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is given by"
}], "Text",
  CellTags->{"S1.3.2", "2.72"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Psi]\&^\), \((\[Omega])\), "=", "G", \((\[Omega]/2)\), 
        \(\[Phi]\&^\), \((\[Omega]/2)\), "=", "-", \(e\^\(-i  \[Omega]/2\)\), 
        \(\(H \((\[Omega]/2 + \[Pi])\)\)\&_\), \(\[Phi]\&^\), \((\[Omega]/2)
        \), "=", "-", \(e\^\(-i  \[Omega]/2\)\), 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\[Phi]\&^\), \((
        \[Omega] + 2  \[Pi] + 4  \[Pi]  l)\), \(\[Phi]\&^\), \((\[Omega]/2)\),
         "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.73"}],

Cell[TextData[{
  "Since the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-8\) \[Pi]/3, 8  \[Pi]/3]
      \)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", only ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(-1\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " terms contribute to the above sum, and we have "
}], "Text",
  CellTags->{"S1.3.2", "2.74"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Psi]\&^\) \((\[Omega])\) = -\(e\^\(-i  \[Omega]/2\)\) \((
      \(\[Phi]\&^\) \((\[Omega] - 2  \[Pi])\) + \(\[Phi]\&^\) \((
        \[Omega] + 2  \[Pi])\))\) \(\[Phi]\&^\) \((\[Omega]/2)\).\)], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.75"}],

Cell[TextData[{
  "Both ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]G \((\[Omega]/2)\)\[RightBracketingBar]\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " (dashed line) and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " (solid line) in the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-4\) \[Pi], 4  \[Pi]]\)\)\)],
     "InlineFormula",
    CellTags->"S1.3.2"],
  " are shown here."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.76"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{meyerPhiHat[w/2], meyerPhiHat[w-2Pi],
meyerPhiHat[w+2Pi]}, {w, -10/3 Pi, 10/3 Pi},
Ticks -> {Range[-4Pi, 4Pi, 4Pi/3], {1}},
PlotStyle -> {{}, Dashing[{0.02}], Dashing[{0.02}]},
AxesLabel -> {\"w\", \"phihat(w/2) and |G(w/2)|\"}]\
\>", "Input",
  CellLabel->"In[47]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0454728 0.0147151 0.588604 [
[.11905 .00222 -15 -33 ]
[.11905 .00222 15 0 ]
[.30952 .00222 -15 -33 ]
[.30952 .00222 15 0 ]
[.69048 .00222 -12 -33 ]
[.69048 .00222 12 0 ]
[.88095 .00222 -12 -33 ]
[.88095 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -72 0 ]
[.5 .64303 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .01472 m
.11905 .02097 L
s
[(-8 Pi)(-----)(  3)] .11905 .00222 0 1 Mshowa
.30952 .01472 m
.30952 .02097 L
s
[(-4 Pi)(-----)(  3)] .30952 .00222 0 1 Mshowa
.69048 .01472 m
.69048 .02097 L
s
[(4 Pi)(----)( 3)] .69048 .00222 0 1 Mshowa
.88095 .01472 m
.88095 .02097 L
s
[(8 Pi)(----)( 3)] .88095 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(phihat\\(w/2\\) and |G\\(w/2\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.08255 .01472 L
.0932 .01472 L
.10458 .01472 L
.11009 .01472 L
.1128 .01472 L
.11531 .01472 L
.11758 .01472 L
.11872 .01472 L
.11999 .01472 L
.12125 .01472 L
.12196 .01472 L
.12261 .01472 L
.12387 .01473 L
.12507 .01474 L
.12627 .01478 L
.12736 .01482 L
.12861 .0149 L
.1298 .015 L
.1309 .01513 L
.13191 .01528 L
.13419 .01578 L
.13539 .01613 L
.1365 .01653 L
.13903 .01773 L
.1415 .01937 L
.14415 .02172 L
.14671 .02468 L
.14944 .02867 L
.15433 .03833 L
.15959 .05282 L
.16539 .07429 L
.17577 .1279 L
.18551 .19494 L
.20399 .34794 L
.21446 .43222 L
.2242 .49768 L
.23389 .54565 L
.23931 .56479 L
.24424 .57783 L
.24945 .58772 L
.25239 .59183 L
.25509 .59482 L
.25767 .59706 L
.26007 .5987 L
.26258 .60003 L
.26534 .60112 L
.26792 .60185 L
.27032 .60234 L
Mistroke
.2717 .60255 L
.27295 .60271 L
.27441 .60286 L
.27575 .60297 L
.27691 .60305 L
.27819 .60311 L
.27948 .60317 L
.28084 .60321 L
.28203 .60324 L
.28332 .60326 L
.28453 .60328 L
.28563 .60329 L
.28678 .6033 L
.288 .60331 L
.28904 .60331 L
.29019 .60331 L
.29143 .60332 L
.29212 .60332 L
.29275 .60332 L
.29392 .60332 L
.29515 .60332 L
.29623 .60332 L
.29739 .60332 L
.29847 .60332 L
.29946 .60332 L
.30062 .60332 L
.30188 .60332 L
.30307 .60332 L
.30416 .60332 L
.30542 .60332 L
.30662 .60332 L
.30769 .60332 L
.30885 .60332 L
.31012 .60332 L
.31147 .60332 L
.31388 .60332 L
.32297 .60332 L
.34362 .60332 L
.38134 .60332 L
.42151 .60332 L
.46016 .60332 L
.50127 .60332 L
.54086 .60332 L
.57894 .60332 L
.61947 .60332 L
.65848 .60332 L
.66871 .60332 L
.6798 .60332 L
.68489 .60332 L
.68767 .60332 L
Mistroke
.68903 .60332 L
.69028 .60332 L
.69142 .60332 L
.6925 .60332 L
.69364 .60332 L
.69488 .60332 L
.69615 .60332 L
.69686 .60332 L
.69751 .60332 L
.69876 .60332 L
.69995 .60332 L
.70111 .60332 L
.70236 .60332 L
.70353 .60332 L
.70461 .60332 L
.70587 .60332 L
.70658 .60332 L
.70723 .60332 L
.70844 .60332 L
.70972 .60331 L
.71094 .60331 L
.71225 .6033 L
.71349 .6033 L
.71463 .60329 L
.71589 .60327 L
.71726 .60325 L
.7187 .60322 L
.72004 .60318 L
.7212 .60314 L
.72245 .60308 L
.72355 .60302 L
.72472 .60293 L
.72694 .60272 L
.72898 .60245 L
.73132 .60202 L
.73352 .60147 L
.73593 .60066 L
.73852 .59949 L
.74107 .59797 L
.74378 .59587 L
.74866 .59048 L
.75165 .58594 L
.75446 .58065 L
.75971 .5677 L
.76475 .55097 L
.76938 .5315 L
.77981 .47263 L
.80029 .31152 L
.81028 .22787 L
.81937 .1595 L
Mistroke
.82818 .10517 L
.83775 .06192 L
.84301 .04512 L
.84786 .03359 L
.8525 .02574 L
.85484 .0228 L
.85742 .02024 L
.8599 .01838 L
.86121 .0176 L
.86261 .01691 L
.86395 .01636 L
.86517 .01596 L
.86641 .01563 L
.86755 .01538 L
.86866 .01519 L
.86984 .01504 L
.87102 .01493 L
.87232 .01484 L
.87344 .01479 L
.87465 .01475 L
.87578 .01473 L
.87682 .01472 L
.87811 .01472 L
.87876 .01472 L
.87948 .01472 L
.88076 .01472 L
.88195 .01472 L
.88263 .01472 L
.88335 .01472 L
.88464 .01472 L
.88754 .01472 L
.89769 .01472 L
.93579 .01472 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.30316 .01472 L
.34309 .01472 L
.3815 .01472 L
.42237 .01472 L
.46172 .01472 L
.49955 .01472 L
.53984 .01472 L
.55838 .01472 L
.57861 .01472 L
.58392 .01472 L
.58957 .01472 L
.59232 .01472 L
.59367 .01472 L
.59491 .01472 L
.59604 .01472 L
.59723 .01472 L
.59843 .01475 L
.59975 .01486 L
.60039 .01496 L
.60109 .01511 L
.60237 .01556 L
.60361 .01627 L
.60476 .01724 L
.606 .01869 L
.60737 .02089 L
.60879 .02398 L
.61014 .02772 L
.61257 .03693 L
.6148 .0485 L
.61725 .06502 L
.61984 .08706 L
.62484 .14351 L
.62938 .20894 L
.63958 .37913 L
.64411 .44929 L
.64902 .51135 L
.65128 .53382 L
.65367 .55337 L
.65571 .56683 L
.65794 .57832 L
.65926 .58368 L
.66047 .58783 L
.66173 .59139 L
Mistroke
.66287 .59404 L
.66506 .5978 L
.66625 .59928 L
.66738 .60036 L
.66862 .60127 L
.66992 .60196 L
.67103 .60239 L
.67225 .60272 L
.67357 .60297 L
.67431 .60306 L
.67498 .60313 L
.67628 .60322 L
.67752 .60327 L
.67857 .60329 L
.67973 .60331 L
.68094 .60331 L
.68208 .60332 L
.68314 .60332 L
.68411 .60332 L
.68518 .60332 L
.6863 .60332 L
.68744 .60332 L
.68866 .60332 L
.68981 .60332 L
.69085 .60332 L
.69208 .60332 L
.69342 .60332 L
.69583 .60332 L
.7368 .60332 L
.77626 .60332 L
.8142 .60332 L
.83532 .60332 L
.85459 .60332 L
.86414 .60332 L
.86918 .60332 L
.87454 .60332 L
.87679 .60332 L
.87921 .60332 L
.87989 .60332 L
.8806 .60332 L
.88187 .60332 L
.88306 .60332 L
.88437 .60332 L
.88556 .60332 L
.88665 .60332 L
.8879 .60332 L
.88908 .60332 L
.89017 .60331 L
.89118 .60331 L
.89229 .6033 L
Mistroke
.89347 .60328 L
.89467 .60324 L
.89599 .60317 L
.89723 .60305 L
.89839 .60288 L
.89953 .60264 L
.90056 .60233 L
.90176 .60184 L
.90289 .60122 L
.90412 .6003 L
.90542 .599 L
.90653 .59758 L
.90775 .5956 L
.90907 .59291 L
.91047 .58927 L
.91301 .58035 L
.91537 .56881 L
.91793 .55211 L
.92259 .50929 L
.92713 .45202 L
.93132 .38782 L
.94031 .23667 L
.94503 .16463 L
.95 .10311 L
.95265 .07745 L
.95555 .05525 L
.95818 .04011 L
.96063 .0299 L
.96193 .02583 L
.96316 .02274 L
.96427 .0205 L
.96546 .01865 L
.96674 .01716 L
.96793 .01619 L
.9692 .0155 L
.96993 .01523 L
.97061 .01505 L
.97132 .01491 L
.9721 .01481 L
.97284 .01476 L
.97353 .01473 L
.97482 .01472 L
.97554 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.06244 .28263 L
.07216 .44176 L
.07496 .48016 L
.0776 .51142 L
.08001 .53522 L
.08255 .55565 L
.0854 .57295 L
.08802 .58439 L
.08948 .58914 L
.09085 .59271 L
.09234 .59578 L
.09396 .59825 L
.09532 .59978 L
.0968 .60101 L
.09748 .60144 L
.0982 .60183 L
.0995 .60236 L
.10016 .60256 L
.10087 .60274 L
.10217 .60297 L
.10342 .60312 L
.10458 .6032 L
.10578 .60326 L
.10687 .60329 L
.10813 .6033 L
.10932 .60331 L
.11043 .60332 L
.11145 .60332 L
.11256 .60332 L
.11375 .60332 L
.11494 .60332 L
.11622 .60332 L
.11743 .60332 L
.11854 .60332 L
.11977 .60332 L
.12046 .60332 L
.12111 .60332 L
.12382 .60332 L
.14415 .60332 L
.1832 .60332 L
.22469 .60332 L
.26468 .60332 L
.28299 .60332 L
.2934 .60332 L
.29849 .60332 L
.30314 .60332 L
.30549 .60332 L
.30674 .60332 L
.30806 .60332 L
Mistroke
.30933 .60332 L
.31048 .60332 L
.31164 .60332 L
.31272 .60332 L
.31398 .60332 L
.31461 .60332 L
.3153 .60332 L
.31653 .60332 L
.31767 .60332 L
.31837 .60332 L
.31902 .60331 L
.32025 .60331 L
.32094 .6033 L
.32158 .60329 L
.32228 .60327 L
.32302 .60325 L
.32432 .60318 L
.32551 .60308 L
.32681 .60291 L
.32747 .60278 L
.32818 .60262 L
.3294 .60224 L
.3307 .60166 L
.33192 .60091 L
.33303 .6 L
.33445 .59846 L
.33575 .59658 L
.33719 .5939 L
.33871 .59023 L
.34126 .58169 L
.34271 .57529 L
.34406 .56814 L
.34906 .53071 L
.35188 .50122 L
.3545 .4686 L
.36439 .31224 L
.37331 .16875 L
.37833 .10567 L
.38294 .06357 L
.38517 .04864 L
.38762 .0361 L
.38885 .03115 L
.39017 .02679 L
.39141 .02349 L
.39255 .02105 L
.39372 .01909 L
.39498 .0175 L
.3961 .01648 L
.39728 .01573 L
.39834 .01528 L
Mistroke
.39933 .01501 L
.40041 .01484 L
.40158 .01475 L
.40224 .01473 L
.40295 .01472 L
.40422 .01472 L
.40499 .01472 L
.40573 .01472 L
.40709 .01472 L
.41234 .01472 L
.42217 .01472 L
.46074 .01472 L
.50177 .01472 L
.54127 .01472 L
.57927 .01472 L
.61971 .01472 L
.65864 .01472 L
.70002 .01472 L
.73988 .01472 L
.77823 .01472 L
.81904 .01472 L
.85832 .01472 L
.89609 .01472 L
.93632 .01472 L
.97502 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "The product of the above two graphs gives ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Psi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.77"}],

Cell[CellGroupData[{

Cell["\<\
Plot[(meyerPhiHat[w-2Pi]+meyerPhiHat[w+2Pi])*
meyerPhiHat[w/2], {w,-4Pi, 4Pi},
Ticks -> {Range[-4Pi, 4Pi, 2Pi], {1}},
AxesLabel -> {\"w\", \"|psihat(w)|\"}]\
\>", "Input",
  CellLabel->"In[48]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.037894 0.0147151 0.588604 [
[.02381 .00222 -15 -9 ]
[.02381 .00222 15 0 ]
[.2619 .00222 -15 -9 ]
[.2619 .00222 15 0 ]
[.7381 .00222 -12 -9 ]
[.7381 .00222 12 0 ]
[.97619 .00222 -12 -9 ]
[.97619 .00222 12 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-4 Pi)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-2 Pi)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2 Pi)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4 Pi)] .97619 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.5 0 m
.5 .61803 L
s
[(|psihat\\(w\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.16408 .01472 L
.17277 .01472 L
.17735 .01472 L
.17986 .01472 L
.18109 .01472 L
.18221 .01472 L
.18341 .01472 L
.1847 .01472 L
.18537 .01472 L
.1861 .01472 L
.1868 .01473 L
.18744 .01474 L
.18867 .01478 L
.18978 .01484 L
.19106 .01495 L
.19227 .01511 L
.19343 .01532 L
.19465 .01562 L
.19569 .01596 L
.19684 .01642 L
.19807 .01704 L
.19939 .01787 L
.20178 .01987 L
.20447 .02303 L
.2074 .02779 L
.21017 .03372 L
.21273 .04063 L
.21757 .0578 L
.22272 .08249 L
.23209 .14522 L
.24219 .2352 L
.26047 .41778 L
.27004 .49677 L
.27546 .53117 L
.28051 .55591 L
.28326 .56658 L
.28585 .57496 L
.29071 .58677 L
.29343 .59149 L
.29594 .59485 L
.29869 .59762 L
.30009 .59872 L
.30161 .59972 L
.30292 .60043 L
.30414 .60099 L
.3054 .60147 L
Mistroke
.30654 .60183 L
.30872 .60236 L
.30992 .60258 L
.31104 .60274 L
.31228 .60289 L
.31358 .60301 L
.3147 .60309 L
.31592 .60315 L
.31723 .6032 L
.31796 .60323 L
.31864 .60325 L
.31928 .60326 L
.31997 .60327 L
.32118 .60329 L
.32232 .6033 L
.32338 .60331 L
.32454 .60331 L
.3258 .60331 L
.32705 .60332 L
.32836 .60332 L
.32948 .60332 L
.3307 .60332 L
.33186 .60332 L
.33291 .60332 L
.33412 .60332 L
.33526 .60332 L
.33632 .60332 L
.33729 .60332 L
.33836 .60332 L
.33949 .60332 L
.34071 .60332 L
.3414 .60332 L
.34203 .60332 L
.3432 .60332 L
.34444 .60332 L
.34555 .60332 L
.34659 .60332 L
.34773 .60332 L
.34896 .60331 L
.35019 .60331 L
.35088 .6033 L
.35153 .60328 L
.35285 .60323 L
.35358 .60318 L
.35425 .60312 L
.35545 .60295 L
.35675 .60264 L
.35798 .60217 L
.35911 .60153 L
.36016 .6007 L
Mistroke
.3613 .59948 L
.36237 .59795 L
.36334 .59615 L
.36449 .59348 L
.36573 .58974 L
.36801 .58026 L
.36925 .57335 L
.37037 .56588 L
.3729 .54456 L
.37523 .51869 L
.37743 .48884 L
.38631 .32613 L
.3912 .22765 L
.39583 .14577 L
.39844 .10785 L
.40129 .07467 L
.40387 .05183 L
.40511 .04328 L
.40626 .03654 L
.40851 .02666 L
.4097 .02294 L
.41099 .01992 L
.41226 .01779 L
.41291 .017 L
.41361 .01631 L
.41485 .01548 L
.416 .01504 L
.41725 .01481 L
.41796 .01475 L
.41861 .01473 L
.4198 .01472 L
.42106 .01472 L
.42219 .01472 L
.42325 .01472 L
.42565 .01472 L
.43596 .01472 L
.45703 .01472 L
.49587 .01472 L
.53717 .01472 L
.55782 .01472 L
.56786 .01472 L
.5726 .01472 L
.57695 .01472 L
.57811 .01472 L
.57919 .01472 L
.58031 .01472 L
.58154 .01473 L
.5828 .01482 L
.58394 .01503 L
.58526 .01553 L
Mistroke
.5865 .01641 L
.58759 .0176 L
.58874 .0194 L
.58973 .02148 L
.59081 .02443 L
.59197 .02846 L
.59323 .03394 L
.59549 .04722 L
.59801 .0678 L
.60077 .09778 L
.60579 .17241 L
.61521 .35718 L
.62052 .45661 L
.62313 .49697 L
.62553 .52776 L
.62767 .5499 L
.63002 .56861 L
.63238 .58215 L
.63367 .58762 L
.63488 .59169 L
.63618 .59512 L
.6376 .59788 L
.63893 .59976 L
.64017 .60099 L
.64128 .60178 L
.64251 .60238 L
.64379 .60279 L
.645 .60302 L
.64563 .60311 L
.64632 .60318 L
.64705 .60323 L
.64772 .60326 L
.64893 .60329 L
.65022 .60331 L
.65095 .60331 L
.65173 .60332 L
.65248 .60332 L
.65317 .60332 L
.65447 .60332 L
.65513 .60332 L
.65585 .60332 L
.65714 .60332 L
.65834 .60332 L
.65966 .60332 L
.66039 .60332 L
.66106 .60332 L
.66228 .60332 L
.66297 .60332 L
.6636 .60332 L
.66477 .60332 L
Mistroke
.666 .60332 L
.66711 .60332 L
.66829 .60332 L
.66941 .60332 L
.67043 .60332 L
.67163 .60332 L
.67293 .60332 L
.67415 .60331 L
.67529 .60331 L
.67648 .60331 L
.67777 .6033 L
.67899 .60329 L
.68011 .60327 L
.68134 .60325 L
.6827 .60321 L
.68411 .60315 L
.68542 .60308 L
.68682 .60297 L
.68815 .60284 L
.68934 .60269 L
.69062 .60249 L
.69203 .6022 L
.69351 .60181 L
.69479 .6014 L
.69617 .60085 L
.69871 .59953 L
.70112 .59778 L
.70346 .59553 L
.70563 .59285 L
.70797 .58922 L
.71055 .58415 L
.71578 .56987 L
.72032 .55231 L
.72522 .52726 L
.7341 .46522 L
.75372 .27604 L
.7641 .1769 L
.7698 .13077 L
.7752 .09448 L
.78034 .06697 L
.78305 .05525 L
.78593 .04482 L
.78834 .03755 L
.791 .03102 L
.79341 .02632 L
.79569 .02281 L
.79817 .01992 L
.80044 .01799 L
.8017 .01717 L
.80288 .01655 L
Mistroke
.80417 .01601 L
.80555 .01557 L
.80674 .01528 L
.80804 .01506 L
.80926 .01492 L
.81039 .01483 L
.81141 .01478 L
.81252 .01474 L
.81369 .01472 L
.81478 .01472 L
.81604 .01472 L
.81668 .01472 L
.81738 .01472 L
.81862 .01472 L
.81979 .01472 L
.82523 .01472 L
.83513 .01472 L
.85369 .01472 L
.89239 .01472 L
.93354 .01472 L
.97317 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "In addition, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " can be written as "
}], "Text",
  CellTags->{"S1.3.2", "2.78"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\&^\), \((\[Omega])\), "=", 
        RowBox[{"{", GridBox[{
              {
                
                StyleBox[
                  \(-\(e\^\(-i \[Omega]/2\)\) sin \(\[InvisibleSpace]\([
                    \(\[Pi]\/2\) \[Nu] \((
                      3\/\(2 \[Pi]\) \[VerticalSeparator] \[Omega] 
                        \[VerticalSeparator] \(-1\))\)]\)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(\(2 \[Pi]\)\/3 \[LessEqual] 
                    \( \[VerticalSeparator] 
                      \(\[Omega] \[VerticalSeparator] \)\) \[LessEqual] 
                    \(4 \[Pi]\)\/3\),
                  "DisplayFormula"]},
              {
                
                StyleBox[
                  \(-\(e\^\(-i \[Omega]/2\)\) cos \(\[InvisibleSpace]\([
                    \(\[Pi]\/2\) \[Nu] \((
                      3\/\(4 \[Pi]\) \[VerticalSeparator] \[Omega] 
                        \[VerticalSeparator] \(-1\))\)]\)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(\(4 \[Pi]\)\/3 \[LessEqual] 
                    \( \[VerticalSeparator] 
                      \(\[Omega] \[VerticalSeparator] \)\) \[LessEqual] 
                    \(8 \[Pi]\)\/3\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\("otherwise".\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.3.2", "2.79"}],

Cell["\<\
The scaling function and wavelet in the time domain are obtained by \
doing the Fourier transforms:\
\>", "Text",
  CellTags->{"S1.3.2", "2.80"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "\[Phi]", \((t)\), "=", \(1\/\(2  \[Pi]\)\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(\[Phi]\&^\), \((
        \[Omega])\), \(e\^\(i  \[Omega]  t\)\), " ", 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}], "=", \(1\/\[Pi]\), 
        \(\[Integral]\_0\%\(4  \[Pi]/3\)\), \(\[Phi]\&^\), \((\[Omega])\), 
        "cos", "\[Omega]", \(t\ \), 
        RowBox[{
          StyleBox[\("d"\),
            "TI"], "\[Omega]"}]}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.3.2", "2.81"}],

Cell["and ", "Text",
  CellTags->{"S1.3.2", "2.82"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(\[Psi] \((t)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              "-", \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                \(e\^\(-i \[Omega]/2\)\), \(\[Phi]\&^\), \((\[Omega]/2)\), 
                \(\[InvisibleSpace]\([
                \(\[Phi]\&^\) \((\[Omega] + 2 \[Pi])\) + \(\[Phi]\&^\) \((
                  \[Omega] - 2 \[Pi])\)]\)\), \(e\^\(i \[Omega] t\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              "-", \(1\/\[Pi]\), \(\[Integral]\_0\%\[Infinity]\), 
                \(\[Phi]\&^\), \((\[Omega]/2)\), \(\[Phi]\&^\), \((
                \[Omega] - 2 \[Pi])\), "cos", "\[Omega]", \((t - 1\/2)\), " ",
                 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "=", "-", \(1\/\[Pi]\), 
                \(\[Integral]\_\(2 \[Pi]/3\)\%\(8 \[Pi]/3\)\), \(\[Phi]\&^\), 
                \((\[Omega]/2)\), \(\[Phi]\&^\), \((\[Omega] - 2 \[Pi])\), 
                "cos", "\[Omega]", \((t - 1\/2)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.83"}],

Cell["\<\
In general, we cannot get an analytic form for the scaling function \
or wavelet, and here we are content to approximate them using summations \
instead of integrals in the Fourier transform formula and plot them. The \
functions \
\>", "Text",
  CellTags->{"S1.3.2", "2.84"}],

Cell[TextData[{
  StyleBox["MeyerPhi[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["k", "TI"],
  StyleBox["]", "MR"],
  "  and  ",
  StyleBox["MeyerPsi[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["k", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.2", "2.85"}],

Cell[TextData[{
  "give, respectively, the approximate Meyer scaling function and wavelet \
with the interpolating polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " has ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " continuous derivatives. We will call ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " the order of Meyer ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The integrals are approximated by a summation with intervals of size ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\((3  k)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". "
}], "Text",
  CellTags->{"S1.3.2", "2.86"}],

Cell[TextData[{
  "For example, here is the Meyer ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\) = x\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \(\[InvisibleSpace]\([0, 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.87"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[MeyerPhi[0, t, 20]], {t, -10, 10},
AxesLabel -> {\"t\", \"Meyer phi(t) of order 0\"},
PlotRange -> All]\
\>", "Input",
  CellLabel->"In[49]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.102754 0.458766 [
[.02381 .09025 -9 -9 ]
[.02381 .09025 9 0 ]
[.2619 .09025 -6 -9 ]
[.2619 .09025 6 0 ]
[.7381 .09025 -3 -9 ]
[.7381 .09025 3 0 ]
[.97619 .09025 -6 -9 ]
[.97619 .09025 6 0 ]
[1.025 .10275 0 -4.5 ]
[1.025 .10275 6 4.5 ]
[.4875 .011 -24 -4.5 ]
[.4875 .011 0 4.5 ]
[.4875 .19451 -18 -4.5 ]
[.4875 .19451 0 4.5 ]
[.4875 .28626 -18 -4.5 ]
[.4875 .28626 0 4.5 ]
[.4875 .37801 -18 -4.5 ]
[.4875 .37801 0 4.5 ]
[.4875 .46977 -18 -4.5 ]
[.4875 .46977 0 4.5 ]
[.4875 .56152 -6 -4.5 ]
[.4875 .56152 0 4.5 ]
[.5 .64303 -69 0 ]
[.5 .64303 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .10275 m
.02381 .109 L
s
[(-10)] .02381 .09025 0 1 Mshowa
.2619 .10275 m
.2619 .109 L
s
[(-5)] .2619 .09025 0 1 Mshowa
.7381 .10275 m
.7381 .109 L
s
[(5)] .7381 .09025 0 1 Mshowa
.97619 .10275 m
.97619 .109 L
s
[(10)] .97619 .09025 0 1 Mshowa
.125 Mabswid
.07143 .10275 m
.07143 .1065 L
s
.11905 .10275 m
.11905 .1065 L
s
.16667 .10275 m
.16667 .1065 L
s
.21429 .10275 m
.21429 .1065 L
s
.30952 .10275 m
.30952 .1065 L
s
.35714 .10275 m
.35714 .1065 L
s
.40476 .10275 m
.40476 .1065 L
s
.45238 .10275 m
.45238 .1065 L
s
.54762 .10275 m
.54762 .1065 L
s
.59524 .10275 m
.59524 .1065 L
s
.64286 .10275 m
.64286 .1065 L
s
.69048 .10275 m
.69048 .1065 L
s
.78571 .10275 m
.78571 .1065 L
s
.83333 .10275 m
.83333 .1065 L
s
.88095 .10275 m
.88095 .1065 L
s
.92857 .10275 m
.92857 .1065 L
s
.25 Mabswid
0 .10275 m
1 .10275 L
s
[(t)] 1.025 .10275 -1 0 Mshowa
.5 .011 m
.50625 .011 L
s
[(-0.2)] .4875 .011 1 0 Mshowa
.5 .19451 m
.50625 .19451 L
s
[(0.2)] .4875 .19451 1 0 Mshowa
.5 .28626 m
.50625 .28626 L
s
[(0.4)] .4875 .28626 1 0 Mshowa
.5 .37801 m
.50625 .37801 L
s
[(0.6)] .4875 .37801 1 0 Mshowa
.5 .46977 m
.50625 .46977 L
s
[(0.8)] .4875 .46977 1 0 Mshowa
.5 .56152 m
.50625 .56152 L
s
[(1)] .4875 .56152 1 0 Mshowa
.125 Mabswid
.5 .03394 m
.50375 .03394 L
s
.5 .05688 m
.50375 .05688 L
s
.5 .07982 m
.50375 .07982 L
s
.5 .12569 m
.50375 .12569 L
s
.5 .14863 m
.50375 .14863 L
s
.5 .17157 m
.50375 .17157 L
s
.5 .21745 m
.50375 .21745 L
s
.5 .24038 m
.50375 .24038 L
s
.5 .26332 m
.50375 .26332 L
s
.5 .3092 m
.50375 .3092 L
s
.5 .33214 m
.50375 .33214 L
s
.5 .35508 m
.50375 .35508 L
s
.5 .40095 m
.50375 .40095 L
s
.5 .42389 m
.50375 .42389 L
s
.5 .44683 m
.50375 .44683 L
s
.5 .4927 m
.50375 .4927 L
s
.5 .51564 m
.50375 .51564 L
s
.5 .53858 m
.50375 .53858 L
s
.5 .58446 m
.50375 .58446 L
s
.5 .6074 m
.50375 .6074 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Meyer phi\\(t\\) of order 0)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .10321 m
.02605 .10338 L
.02846 .10353 L
.03072 .10365 L
.03172 .10369 L
.03279 .10372 L
.03405 .10375 L
.03521 .10377 L
.03646 .10377 L
.03717 .10377 L
.03784 .10376 L
.03904 .10374 L
.04014 .10371 L
.04141 .10366 L
.04262 .1036 L
.045 .10346 L
.04753 .10326 L
.0521 .10283 L
.05749 .10228 L
.06244 .10183 L
.0651 .10165 L
.06644 .10157 L
.06791 .10151 L
.06868 .10149 L
.06939 .10147 L
.0702 .10146 L
.07097 .10145 L
.07168 .10145 L
.07234 .10145 L
.07306 .10146 L
.07382 .10147 L
.07509 .10151 L
.0758 .10154 L
.07645 .10157 L
.07892 .10172 L
.08166 .10195 L
.08454 .10226 L
.09423 .10349 L
.09702 .10381 L
.09965 .10408 L
.10202 .10427 L
.10335 .10435 L
.10458 .10441 L
.10572 .10444 L
.10694 .10447 L
.10809 .10447 L
.10915 .10446 L
.11038 .10444 L
.11108 .10441 L
.11172 .10438 L
Mistroke
.11291 .10432 L
.11417 .10423 L
.11691 .10398 L
.1195 .10367 L
.12432 .10298 L
.13308 .10165 L
.13548 .10135 L
.1368 .10121 L
.13805 .1011 L
.13922 .10101 L
.14048 .10093 L
.14163 .10088 L
.14269 .10084 L
.14385 .10083 L
.14495 .10083 L
.14615 .10085 L
.14744 .1009 L
.14872 .10098 L
.15007 .10108 L
.15248 .10132 L
.15741 .10202 L
.16281 .10297 L
.16744 .10378 L
.16999 .10416 L
.17239 .10447 L
.17463 .10468 L
.17589 .10477 L
.17706 .10483 L
.17804 .10486 L
.17911 .10487 L
.18024 .10486 L
.18129 .10483 L
.18255 .10477 L
.18318 .10473 L
.18389 .10468 L
.18629 .10443 L
.18909 .10402 L
.19173 .10354 L
.20162 .10135 L
.20596 .1005 L
.20815 .10016 L
.2094 .10001 L
.21054 .09989 L
.2118 .0998 L
.21249 .09976 L
.21314 .09974 L
.2143 .09972 L
.21556 .09973 L
.21672 .09977 L
.21796 .09986 L
Mistroke
.21901 .09996 L
.22017 .1001 L
.23096 .10271 L
.23628 .10444 L
.24122 .10591 L
.24352 .10647 L
.24568 .10688 L
.24688 .10706 L
.24817 .10721 L
.24935 .10731 L
.25043 .10735 L
.25163 .10736 L
.25276 .10733 L
.25399 .10724 L
.25532 .10709 L
.2567 .10688 L
.25801 .10662 L
.26047 .10599 L
.26516 .10438 L
.27013 .10228 L
.27443 .10042 L
.27906 .09869 L
.28165 .09794 L
.28278 .09769 L
.28402 .09746 L
.28519 .0973 L
.28628 .0972 L
.28744 .09714 L
.28867 .09715 L
.28938 .09718 L
.29004 .09723 L
.29076 .0973 L
.29153 .09741 L
.29281 .09764 L
.29422 .09798 L
.29683 .0988 L
.29927 .09978 L
.30968 .10521 L
.31217 .10646 L
.31481 .10761 L
.3161 .10808 L
.31731 .10845 L
.31841 .10874 L
.31957 .10897 L
.32063 .10912 L
.32179 .10921 L
.32285 .10923 L
.32384 .10918 L
.325 .10905 L
.32606 .10885 L
Mistroke
.32729 .10854 L
.32844 .10816 L
.33085 .1071 L
.33308 .10584 L
.33811 .10214 L
.34713 .09451 L
.34972 .09265 L
.351 .09186 L
.35219 .09122 L
.35335 .0907 L
.35441 .09033 L
.35558 .09003 L
.35683 .08985 L
.35749 .08981 L
.3582 .08983 L
.35946 .08999 L
.36016 .09015 L
.36082 .09036 L
.36231 .091 L
.36361 .09177 L
.3648 .09265 L
.36747 .09521 L
.36993 .09825 L
.3726 .1022 L
.37745 .11071 L
.38235 .12001 L
.38493 .12468 L
.38764 .1291 L
.39003 .13235 L
.39129 .13376 L
.39264 .13498 L
.39388 .13583 L
.39501 .13635 L
.39614 .13662 L
.39721 .13662 L
.39842 .13632 L
.39971 .13563 L
.4008 .13473 L
.402 .1334 L
.4033 .13158 L
.40469 .12915 L
.4072 .12357 L
.41015 .11508 L
.41296 .1053 L
.41822 .08346 L
.42782 .04083 L
.43059 .0306 L
.43319 .02283 L
.43433 .02015 L
.43553 .01785 L
Mistroke
.43685 .01602 L
.43805 .01502 L
.4392 .01472 L
.44025 .01502 L
.44145 .01609 L
.4426 .01784 L
.44365 .02013 L
.44462 .02282 L
.44683 .03105 L
.44905 .0424 L
.4515 .05854 L
.45645 .10268 L
.47746 .40216 L
.4819 .46663 L
.48665 .5256 L
.48938 .55319 L
.49186 .57345 L
.49305 .58147 L
.49435 .5888 L
.49556 .59435 L
.49669 .59835 L
.49779 .60112 L
.49897 .60287 L
.50028 .60332 L
.50147 .60236 L
.50271 .59998 L
.50341 .59802 L
.50406 .59581 L
.50652 .58406 L
.5086 .57006 L
.51091 .55056 L
.51557 .49959 L
.52592 .34985 L
.53542 .20421 L
.54029 .13951 L
.54483 .08987 L
.54956 .05112 L
.55206 .03634 L
.55474 .0249 L
.55614 .02067 L
.55743 .0178 L
.5581 .01668 L
.55885 .01575 L
.55962 .0151 L
.56035 .01478 L
.56103 .01472 L
.56168 .01489 L
.5629 .01576 L
.56422 .01744 L
.56496 .01872 L
Mistroke
.56565 .02011 L
.56817 .02664 L
.57046 .03427 L
.57558 .05532 L
.58494 .09703 L
.59006 .11575 L
.59256 .12293 L
.59483 .1282 L
.59733 .13251 L
.5987 .13422 L
.6 .13541 L
.60069 .13588 L
.60142 .13625 L
.60272 .13661 L
.60345 .13665 L
.60413 .13658 L
.60487 .1364 L
.60568 .13607 L
.60689 .13534 L
.60821 .13424 L
.61088 .1312 L
.61565 .12365 L
.6205 .1146 L
.62575 .10495 L
.63037 .09784 L
.63271 .09502 L
.63527 .0926 L
.63669 .09158 L
.63748 .09111 L
.63822 .09074 L
.63891 .09045 L
.63967 .0902 L
.64098 .08991 L
.64168 .08984 L
.64231 .08981 L
.64303 .08983 L
.64372 .08991 L
.64493 .09014 L
.64625 .09055 L
.64746 .09106 L
.64878 .09174 L
.65145 .09345 L
.65622 .09728 L
.66104 .10144 L
.66358 .10349 L
.66627 .10542 L
.66862 .10683 L
.66987 .10745 L
.67121 .10803 L
.67244 .10846 L
Mistroke
.67357 .10877 L
.6747 .109 L
.67578 .10915 L
.67709 .10923 L
.67783 .10923 L
.67849 .1092 L
.67979 .10907 L
.68101 .10886 L
.68244 .10852 L
.68376 .10812 L
.68673 .10696 L
.69671 .10175 L
.7014 .0995 L
.70403 .0985 L
.70528 .09811 L
.70643 .09781 L
.70749 .09758 L
.70866 .09738 L
.70984 .09724 L
.71109 .09715 L
.71219 .09714 L
.71337 .09717 L
.71449 .09726 L
.71551 .09739 L
.71672 .09759 L
.718 .09786 L
.72032 .09849 L
.72557 .10042 L
.73109 .10281 L
.73617 .10488 L
.73874 .10576 L
.74114 .10642 L
.74364 .10694 L
.74497 .10713 L
.74572 .10721 L
.7464 .10727 L
.74708 .10732 L
.74781 .10735 L
.74912 .10736 L
.74992 .10734 L
.75068 .1073 L
.75136 .10726 L
.75209 .10719 L
.75346 .10702 L
.75491 .10678 L
.7575 .10623 L
.76722 .10329 L
.77258 .10165 L
.77521 .10097 L
.77764 .10046 L
Mistroke
.78003 .10008 L
.78124 .09993 L
.78194 .09987 L
.78257 .09982 L
.78322 .09978 L
.7839 .09975 L
.78459 .09972 L
.78534 .09972 L
.78599 .09972 L
.78668 .09973 L
.78793 .09978 L
.78914 .09987 L
.79046 .09999 L
.79284 .1003 L
.7973 .10112 L
.80678 .10324 L
.80916 .10371 L
.81141 .1041 L
.81361 .10442 L
.81564 .10464 L
.8167 .10472 L
.81783 .10479 L
.81908 .10485 L
.82021 .10487 L
.82143 .10486 L
.82274 .10483 L
.82398 .10478 L
.82512 .1047 L
.82754 .10447 L
.83019 .10414 L
.83554 .10327 L
.8412 .10225 L
.84399 .1018 L
.84656 .10144 L
.84889 .10118 L
.85009 .10107 L
.85137 .10097 L
.85265 .1009 L
.85385 .10085 L
.85459 .10084 L
.85528 .10083 L
.85659 .10083 L
.85782 .10086 L
.85894 .1009 L
.86023 .10097 L
.86144 .10105 L
.8636 .10125 L
.86594 .10152 L
.87616 .10305 L
.88146 .10379 L
Mistroke
.88413 .10408 L
.88566 .10422 L
.88706 .10432 L
.88835 .10439 L
.88956 .10443 L
.89085 .10446 L
.89158 .10447 L
.89225 .10447 L
.89337 .10446 L
.8946 .10444 L
.89588 .10439 L
.89709 .10432 L
.90602 .10345 L
.91557 .10224 L
.91839 .10195 L
.92105 .10172 L
.92344 .10157 L
.9241 .10154 L
.92479 .10151 L
.92603 .10148 L
.92719 .10145 L
.92843 .10145 L
.9296 .10145 L
.93067 .10147 L
.93193 .10151 L
.93263 .10153 L
.93329 .10156 L
.93578 .1017 L
.93835 .1019 L
.94078 .10211 L
.94531 .10257 L
.9506 .1031 L
.95292 .1033 L
.95546 .10349 L
.95667 .10356 L
.95797 .10363 L
.95909 .10368 L
.96031 .10372 L
.96102 .10374 L
.96169 .10375 L
.96299 .10377 L
.96417 .10377 L
.96543 .10376 L
.9667 .10373 L
.96741 .10371 L
.96807 .10369 L
.97055 .10359 L
.9733 .10342 L
.97619 .10321 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "Here is the corresponding wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". We see that as expected the scaling function and wavelet decay faster \
than in the case of the Shannon wavelet."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.88"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[MeyerPsi[0, t, 20]], {t, -10, 10},
AxesLabel -> {\"t\", \"Meyer psi(t) of order 0\"},
PlotRange -> All]\
\>", "Input",
  CellLabel->"In[50]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.364242 0.274563 [
[.02381 .35174 -9 -9 ]
[.02381 .35174 9 0 ]
[.2619 .35174 -6 -9 ]
[.2619 .35174 6 0 ]
[.7381 .35174 -3 -9 ]
[.7381 .35174 3 0 ]
[.97619 .35174 -6 -9 ]
[.97619 .35174 6 0 ]
[1.025 .36424 0 -4.5 ]
[1.025 .36424 6 4.5 ]
[.4875 .08968 -12 -4.5 ]
[.4875 .08968 0 4.5 ]
[.4875 .22696 -24 -4.5 ]
[.4875 .22696 0 4.5 ]
[.4875 .50152 -18 -4.5 ]
[.4875 .50152 0 4.5 ]
[.5 .64303 -69 0 ]
[.5 .64303 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .36424 m
.02381 .37049 L
s
[(-10)] .02381 .35174 0 1 Mshowa
.2619 .36424 m
.2619 .37049 L
s
[(-5)] .2619 .35174 0 1 Mshowa
.7381 .36424 m
.7381 .37049 L
s
[(5)] .7381 .35174 0 1 Mshowa
.97619 .36424 m
.97619 .37049 L
s
[(10)] .97619 .35174 0 1 Mshowa
.125 Mabswid
.07143 .36424 m
.07143 .36799 L
s
.11905 .36424 m
.11905 .36799 L
s
.16667 .36424 m
.16667 .36799 L
s
.21429 .36424 m
.21429 .36799 L
s
.30952 .36424 m
.30952 .36799 L
s
.35714 .36424 m
.35714 .36799 L
s
.40476 .36424 m
.40476 .36799 L
s
.45238 .36424 m
.45238 .36799 L
s
.54762 .36424 m
.54762 .36799 L
s
.59524 .36424 m
.59524 .36799 L
s
.64286 .36424 m
.64286 .36799 L
s
.69048 .36424 m
.69048 .36799 L
s
.78571 .36424 m
.78571 .36799 L
s
.83333 .36424 m
.83333 .36799 L
s
.88095 .36424 m
.88095 .36799 L
s
.92857 .36424 m
.92857 .36799 L
s
.25 Mabswid
0 .36424 m
1 .36424 L
s
[(t)] 1.025 .36424 -1 0 Mshowa
.5 .08968 m
.50625 .08968 L
s
[(-1)] .4875 .08968 1 0 Mshowa
.5 .22696 m
.50625 .22696 L
s
[(-0.5)] .4875 .22696 1 0 Mshowa
.5 .50152 m
.50625 .50152 L
s
[(0.5)] .4875 .50152 1 0 Mshowa
.125 Mabswid
.5 .11714 m
.50375 .11714 L
s
.5 .14459 m
.50375 .14459 L
s
.5 .17205 m
.50375 .17205 L
s
.5 .1995 m
.50375 .1995 L
s
.5 .25442 m
.50375 .25442 L
s
.5 .28187 m
.50375 .28187 L
s
.5 .30933 m
.50375 .30933 L
s
.5 .33679 m
.50375 .33679 L
s
.5 .3917 m
.50375 .3917 L
s
.5 .41916 m
.50375 .41916 L
s
.5 .44661 m
.50375 .44661 L
s
.5 .47407 m
.50375 .47407 L
s
.5 .06222 m
.50375 .06222 L
s
.5 .03477 m
.50375 .03477 L
s
.5 .00731 m
.50375 .00731 L
s
.5 .52898 m
.50375 .52898 L
s
.5 .55644 m
.50375 .55644 L
s
.5 .58389 m
.50375 .58389 L
s
.5 .61135 m
.50375 .61135 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Meyer psi\\(t\\) of order 0)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .36396 m
.02499 .36396 L
.02605 .36394 L
.02729 .36392 L
.02846 .36389 L
.03279 .36372 L
.03507 .36363 L
.03633 .36359 L
.0375 .36356 L
.03877 .36354 L
.03944 .36353 L
.04016 .36353 L
.04144 .36354 L
.04262 .36356 L
.04384 .3636 L
.04514 .36366 L
.04748 .3638 L
.05278 .3642 L
.05539 .36438 L
.05667 .36446 L
.05785 .36451 L
.05892 .36455 L
.06006 .36458 L
.0612 .3646 L
.06244 .36461 L
.0637 .3646 L
.06433 .36459 L
.06503 .36458 L
.06649 .36454 L
.06785 .3645 L
.07031 .36441 L
.0716 .36438 L
.07231 .36436 L
.07296 .36434 L
.07372 .36433 L
.07455 .36432 L
.07525 .36432 L
.076 .36433 L
.07677 .36434 L
.0775 .36435 L
.07815 .36437 L
.07886 .36439 L
.08022 .36445 L
.08166 .36454 L
.08424 .36473 L
.08891 .36511 L
.09025 .36521 L
.09153 .36529 L
.09267 .36534 L
.09392 .36539 L
Mistroke
.09465 .36541 L
.09531 .36541 L
.09607 .36542 L
.09678 .36541 L
.09805 .36539 L
.09877 .36537 L
.09943 .36534 L
.10194 .3652 L
.10458 .365 L
.10692 .36482 L
.10946 .36464 L
.11063 .36458 L
.11186 .36452 L
.11292 .36448 L
.11408 .36446 L
.11477 .36445 L
.11541 .36445 L
.1161 .36445 L
.11683 .36446 L
.11806 .36449 L
.11876 .36451 L
.11941 .36453 L
.1219 .36462 L
.12313 .36467 L
.12426 .36471 L
.12534 .36474 L
.12649 .36477 L
.12764 .36478 L
.12891 .36477 L
.12996 .36475 L
.13109 .3647 L
.13216 .36464 L
.13313 .36458 L
.13546 .36436 L
.13799 .36406 L
.1426 .36346 L
.14493 .3632 L
.14615 .36309 L
.14744 .36299 L
.14857 .36293 L
.14981 .36289 L
.15094 .36288 L
.15199 .36288 L
.15263 .3629 L
.15334 .36292 L
.15461 .36297 L
.15585 .36305 L
.157 .36312 L
.15976 .36333 L
.16112 .36343 L
Mistroke
.16235 .36352 L
.16347 .36358 L
.16469 .36363 L
.16598 .36366 L
.16721 .36367 L
.16791 .36366 L
.16855 .36365 L
.16929 .36362 L
.16998 .3636 L
.17121 .36353 L
.17255 .36344 L
.17525 .36322 L
.17814 .36299 L
.17954 .3629 L
.18023 .36286 L
.18087 .36283 L
.18206 .3628 L
.18335 .36279 L
.18449 .36281 L
.18555 .36286 L
.18671 .36293 L
.18797 .36304 L
.19053 .36336 L
.19287 .36371 L
.19786 .36449 L
.19922 .36467 L
.20068 .36482 L
.20139 .36488 L
.20206 .36493 L
.20331 .36499 L
.20455 .36502 L
.20587 .36502 L
.207 .36499 L
.20823 .36493 L
.20957 .36485 L
.21099 .36475 L
.21357 .36456 L
.21496 .36447 L
.21574 .36444 L
.21647 .36441 L
.21717 .36439 L
.2178 .36438 L
.21853 .36439 L
.21922 .3644 L
.22051 .36445 L
.2217 .36454 L
.223 .36467 L
.22438 .36485 L
.22927 .36573 L
.23167 .36619 L
Mistroke
.23389 .36656 L
.23513 .36673 L
.23644 .36686 L
.23776 .36695 L
.23852 .36697 L
.23922 .36698 L
.24044 .36696 L
.24156 .3669 L
.24284 .36678 L
.24407 .36664 L
.26242 .36503 L
.28244 .36315 L
.28668 .36169 L
.28882 .36109 L
.29003 .36083 L
.29116 .36063 L
.2924 .36049 L
.29354 .36042 L
.29484 .36042 L
.29608 .36049 L
.2972 .3606 L
.29824 .36075 L
.3006 .36118 L
.30313 .36171 L
.30551 .36216 L
.3067 .36234 L
.30799 .36248 L
.30868 .36253 L
.30942 .36256 L
.31073 .36255 L
.31187 .36249 L
.31308 .36236 L
.31423 .36218 L
.31528 .36199 L
.32027 .36081 L
.32157 .36052 L
.32296 .36027 L
.32414 .36012 L
.32544 .36002 L
.32617 .36001 L
.32684 .36003 L
.32761 .36009 L
.32834 .36018 L
.32963 .36041 L
.33037 .36059 L
.33105 .36079 L
.33364 .36176 L
.33598 .36286 L
.33849 .36411 L
.34123 .36538 L
Mistroke
.34246 .36584 L
.34376 .36625 L
.345 .36654 L
.34612 .36671 L
.34739 .36679 L
.34811 .36679 L
.34877 .36676 L
.34999 .36663 L
.35128 .36641 L
.35572 .36526 L
.35694 .36494 L
.35822 .36467 L
.35932 .3645 L
.36051 .3644 L
.36179 .36442 L
.36251 .36449 L
.36316 .36459 L
.36443 .36491 L
.36562 .36536 L
.36682 .36594 L
.36792 .36658 L
.37042 .36836 L
.37569 .37268 L
.3772 .37378 L
.37864 .37467 L
.37993 .3753 L
.38066 .37557 L
.38134 .37577 L
.38249 .37598 L
.38358 .37603 L
.38477 .37591 L
.38605 .3756 L
.38732 .37511 L
.38866 .37445 L
.39105 .373 L
.39331 .37152 L
.39544 .37026 L
.39662 .36969 L
.3979 .36921 L
.39906 .36892 L
.40013 .36879 L
.40131 .36879 L
.40261 .36897 L
.40326 .36912 L
.40397 .36933 L
.40524 .3698 L
.40751 .37082 L
.40871 .37137 L
.40999 .37188 L
.41078 .37213 L
Mistroke
.41149 .3723 L
.41221 .3724 L
.41288 .37243 L
.4142 .37224 L
.41494 .37198 L
.41563 .37163 L
.41682 .37075 L
.41813 .36938 L
.4195 .36747 L
.42078 .36527 L
.42579 .35338 L
.42843 .34605 L
.43124 .33867 L
.43368 .33339 L
.43508 .3311 L
.43638 .32951 L
.43758 .32857 L
.43867 .32814 L
.43988 .32814 L
.44114 .32863 L
.44614 .33418 L
.4486 .33758 L
.44968 .33887 L
.45087 .34002 L
.45193 .34075 L
.45293 .34111 L
.45398 .34112 L
.45511 .34069 L
.45634 .33966 L
.45751 .33818 L
.4597 .33426 L
.4621 .32889 L
.46342 .32589 L
.46465 .32333 L
.46581 .32138 L
.46707 .32 L
.4682 .31963 L
.46925 .32019 L
.47038 .32196 L
.47162 .32548 L
.47292 .33112 L
.47413 .33834 L
.47547 .34868 L
.4767 .36025 L
.47945 .39341 L
.48836 .53754 L
.49053 .5679 L
.49172 .58146 L
.49286 .59171 L
.4935 .59617 L
Mistroke
.49419 .5999 L
.49542 .60332 L
.49666 .60244 L
.49782 .59745 L
.49911 .58689 L
.50034 .57207 L
.50144 .55481 L
.50263 .53206 L
.50776 .39362 L
.51214 .24839 L
.51446 .17423 L
.51694 .10508 L
.51837 .07275 L
.51966 .04887 L
.52097 .0309 L
.5222 .01985 L
.52287 .0164 L
.52359 .01472 L
.52486 .01688 L
.52557 .02093 L
.52624 .02657 L
.52697 .03474 L
.52776 .04581 L
.53029 .09578 L
.53296 .16798 L
.53772 .32344 L
.54007 .40034 L
.54262 .47526 L
.54487 .52952 L
.5461 .55341 L
.54725 .57169 L
.54858 .58759 L
.54928 .5938 L
.55003 .59875 L
.55072 .60173 L
.55137 .60323 L
.55259 .60268 L
.55379 .59807 L
.55491 .59051 L
.55614 .57895 L
.55744 .56343 L
.5621 .49096 L
.56701 .41009 L
.56903 .382 L
.5712 .3574 L
.57245 .34613 L
.57358 .33771 L
.57472 .33099 L
.5758 .32618 L
.57705 .32239 L
Mistroke
.57837 .32019 L
.5795 .31962 L
.58074 .32015 L
.58144 .32089 L
.58207 .32178 L
.58351 .32441 L
.5861 .33024 L
.58746 .3333 L
.58892 .3362 L
.59026 .3384 L
.59153 .33991 L
.59222 .34049 L
.59296 .34091 L
.59426 .34116 L
.59501 .34103 L
.59581 .34068 L
.59649 .34023 L
.59724 .33959 L
.60227 .33307 L
.60371 .33119 L
.60509 .3297 L
.60632 .32873 L
.60702 .32836 L
.60767 .32815 L
.60894 .32814 L
.61015 .32863 L
.61122 .3295 L
.61239 .33088 L
.61366 .3329 L
.61501 .33553 L
.61741 .34128 L
.62231 .35468 L
.62471 .36076 L
.62693 .36544 L
.62815 .36752 L
.62949 .36938 L
.63083 .37078 L
.63157 .37136 L
.63226 .37178 L
.63348 .37225 L
.6346 .37242 L
.63589 .37234 L
.63711 .37205 L
.63827 .37164 L
.63931 .37119 L
.64166 .37011 L
.64271 .36967 L
.64384 .36927 L
.64491 .36899 L
.64589 .36883 L
Mistroke
.64704 .36877 L
.64811 .36885 L
.64928 .36908 L
.65054 .3695 L
.65187 .3701 L
.65312 .37079 L
.65547 .37228 L
.65767 .3737 L
.66005 .375 L
.66072 .37529 L
.66142 .37555 L
.66267 .37587 L
.66384 .37602 L
.66512 .37598 L
.66581 .37588 L
.66646 .37572 L
.66769 .3753 L
.669 .37466 L
.67043 .37378 L
.67537 .36985 L
.67778 .36791 L
.68003 .36638 L
.68125 .3657 L
.68237 .3652 L
.68362 .36479 L
.6843 .36463 L
.68495 .36451 L
.68602 .36441 L
.68715 .3644 L
.68822 .36449 L
.68918 .36463 L
.69032 .36486 L
.69156 .36517 L
.69379 .36578 L
.69617 .36637 L
.69686 .36651 L
.69751 .36662 L
.69872 .36675 L
.69987 .3668 L
.70092 .36676 L
.70209 .36663 L
.70332 .36639 L
.70455 .36605 L
.70588 .36558 L
.70829 .36452 L
.71091 .36323 L
.71376 .36186 L
.71511 .3613 L
.71654 .3608 L
.7179 .36043 L
Mistroke
.71913 .3602 L
.71985 .3601 L
.72052 .36005 L
.72125 .36002 L
.72203 .36002 L
.72333 .3601 L
.72407 .36019 L
.72477 .36029 L
.72731 .3608 L
.72963 .36136 L
.7321 .36194 L
.73342 .36219 L
.73411 .3623 L
.73484 .3624 L
.73613 .36251 L
.73731 .36256 L
.73842 .36255 L
.73964 .36248 L
.74091 .36234 L
.74228 .36214 L
.74474 .36166 L
.7472 .36114 L
.74842 .36091 L
.74954 .36073 L
.75055 .36059 L
.75163 .36048 L
.75271 .36042 L
.7539 .36042 L
.75456 .36044 L
.75528 .3605 L
.7566 .36065 L
.75788 .36088 L
.75906 .36116 L
.76462 .36295 L
.76716 .36384 L
.76984 .36465 L
.77095 .36492 L
.77213 .36517 L
.77344 .36538 L
.77465 .36551 L
.7753 .36556 L
.77602 .36559 L
.77731 .36561 L
.77857 .36558 L
.77973 .36552 L
.781 .36542 L
.7824 .36529 L
.78387 .36515 L
.78523 .36503 L
.78641 .36494 L
Mistroke
.7877 .36487 L
.789 .36484 L
.7897 .36483 L
.79036 .36484 L
.79158 .36489 L
.79269 .36497 L
.79398 .3651 L
.79518 .36526 L
.79952 .36598 L
.8019 .36639 L
.80412 .36671 L
.80527 .36683 L
.80651 .36692 L
.80722 .36696 L
.80789 .36698 L
.80915 .36697 L
.81031 .36692 L
.81137 .36684 L
.81255 .36672 L
.81379 .36655 L
.81882 .36564 L
.82156 .36512 L
.82411 .36473 L
.82545 .36458 L
.82614 .36452 L
.82689 .36447 L
.8277 .36442 L
.82848 .3644 L
.82923 .36438 L
.82992 .36438 L
.83116 .36441 L
.83186 .36443 L
.83251 .36447 L
.83526 .36465 L
.83786 .36484 L
.83914 .36492 L
.84034 .36498 L
.84141 .36501 L
.84256 .36502 L
.84383 .36501 L
.84498 .36496 L
.84564 .36492 L
.84633 .36487 L
.84757 .36476 L
.85037 .36441 L
.85544 .3636 L
.85799 .36323 L
.85924 .36309 L
.8604 .36297 L
.86145 .36289 L
Mistroke
.86256 .36283 L
.86368 .3628 L
.86491 .36279 L
.86623 .36281 L
.86743 .36286 L
.86807 .3629 L
.86876 .36294 L
.87015 .36304 L
.87273 .36325 L
.87507 .36344 L
.8762 .36352 L
.87743 .36359 L
.87859 .36363 L
.87966 .36366 L
.88079 .36367 L
.88204 .36365 L
.88334 .36361 L
.88456 .36356 L
.88679 .36341 L
.88882 .36326 L
.89118 .36308 L
.89234 .36301 L
.8934 .36295 L
.8946 .36291 L
.89591 .36288 L
.89701 .36288 L
.89818 .3629 L
.89943 .36295 L
.9006 .36302 L
.90189 .36312 L
.90326 .36326 L
.90765 .3638 L
.90996 .3641 L
.91241 .36439 L
.91379 .36452 L
.91531 .36463 L
.91597 .36467 L
.91669 .36471 L
.91798 .36475 L
.91863 .36477 L
.91933 .36478 L
.92006 .36478 L
.92074 .36477 L
.92196 .36475 L
.92326 .36472 L
.92806 .36453 L
.92923 .3645 L
.93048 .36447 L
.9312 .36446 L
.93186 .36445 L
Mistroke
.93314 .36446 L
.93446 .36448 L
.9352 .3645 L
.93588 .36452 L
.93714 .36458 L
.93848 .36466 L
.9434 .36503 L
.94594 .36522 L
.94728 .3653 L
.94868 .36536 L
.94943 .36539 L
.95025 .36541 L
.951 .36542 L
.95169 .36542 L
.9524 .36541 L
.95306 .3654 L
.95381 .36539 L
.95452 .36536 L
.95568 .36531 L
.95696 .36524 L
.95954 .36505 L
.96418 .36467 L
.96679 .36449 L
.96826 .36441 L
.96896 .36439 L
.9696 .36436 L
.97085 .36434 L
.9715 .36433 L
.9722 .36432 L
.9735 .36433 L
.97468 .36434 L
.9754 .36436 L
.97619 .36438 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "Here is the Meyer wavelet of order 2, that is, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Nu] \((x)\) = \(x\^3\) \((10 - 15  x + 6  x\^2)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \(\[InvisibleSpace]\([0, 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.89"}],

Cell["MeyerPsi[2, t, 20];", "Input",
  CellLabel->"In[51]:= ",
  CellTags->"S1.3.2"],

Cell["Here is the plot of the Meyer wavelet of order 2.", "MathCaption",
  CellTags->{"S1.3.2", "2.90"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[%], {t, -10, 10},
AxesLabel -> {\"t\", \"Meyer psi(t) of order 2\"},
PlotRange -> All]\
\>", "Input",
  CellLabel->"In[52]:= ",
  CellTags->"S1.3.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.351296 0.286248 [
[.02381 .3388 -9 -9 ]
[.02381 .3388 9 0 ]
[.2619 .3388 -6 -9 ]
[.2619 .3388 6 0 ]
[.7381 .3388 -3 -9 ]
[.7381 .3388 3 0 ]
[.97619 .3388 -6 -9 ]
[.97619 .3388 6 0 ]
[1.025 .3513 0 -4.5 ]
[1.025 .3513 6 4.5 ]
[.4875 .06505 -12 -4.5 ]
[.4875 .06505 0 4.5 ]
[.4875 .20817 -24 -4.5 ]
[.4875 .20817 0 4.5 ]
[.4875 .49442 -18 -4.5 ]
[.4875 .49442 0 4.5 ]
[.5 .64303 -69 0 ]
[.5 .64303 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .3513 m
.02381 .35755 L
s
[(-10)] .02381 .3388 0 1 Mshowa
.2619 .3513 m
.2619 .35755 L
s
[(-5)] .2619 .3388 0 1 Mshowa
.7381 .3513 m
.7381 .35755 L
s
[(5)] .7381 .3388 0 1 Mshowa
.97619 .3513 m
.97619 .35755 L
s
[(10)] .97619 .3388 0 1 Mshowa
.125 Mabswid
.07143 .3513 m
.07143 .35505 L
s
.11905 .3513 m
.11905 .35505 L
s
.16667 .3513 m
.16667 .35505 L
s
.21429 .3513 m
.21429 .35505 L
s
.30952 .3513 m
.30952 .35505 L
s
.35714 .3513 m
.35714 .35505 L
s
.40476 .3513 m
.40476 .35505 L
s
.45238 .3513 m
.45238 .35505 L
s
.54762 .3513 m
.54762 .35505 L
s
.59524 .3513 m
.59524 .35505 L
s
.64286 .3513 m
.64286 .35505 L
s
.69048 .3513 m
.69048 .35505 L
s
.78571 .3513 m
.78571 .35505 L
s
.83333 .3513 m
.83333 .35505 L
s
.88095 .3513 m
.88095 .35505 L
s
.92857 .3513 m
.92857 .35505 L
s
.25 Mabswid
0 .3513 m
1 .3513 L
s
[(t)] 1.025 .3513 -1 0 Mshowa
.5 .06505 m
.50625 .06505 L
s
[(-1)] .4875 .06505 1 0 Mshowa
.5 .20817 m
.50625 .20817 L
s
[(-0.5)] .4875 .20817 1 0 Mshowa
.5 .49442 m
.50625 .49442 L
s
[(0.5)] .4875 .49442 1 0 Mshowa
.125 Mabswid
.5 .09367 m
.50375 .09367 L
s
.5 .1223 m
.50375 .1223 L
s
.5 .15092 m
.50375 .15092 L
s
.5 .17955 m
.50375 .17955 L
s
.5 .2368 m
.50375 .2368 L
s
.5 .26542 m
.50375 .26542 L
s
.5 .29405 m
.50375 .29405 L
s
.5 .32267 m
.50375 .32267 L
s
.5 .37992 m
.50375 .37992 L
s
.5 .40855 m
.50375 .40855 L
s
.5 .43717 m
.50375 .43717 L
s
.5 .4658 m
.50375 .4658 L
s
.5 .03642 m
.50375 .03642 L
s
.5 .0078 m
.50375 .0078 L
s
.5 .52304 m
.50375 .52304 L
s
.5 .55167 m
.50375 .55167 L
s
.5 .58029 m
.50375 .58029 L
s
.5 .60892 m
.50375 .60892 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Meyer psi\\(t\\) of order 2)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .35136 m
.02499 .35136 L
.02605 .35136 L
.02729 .35136 L
.02846 .35136 L
.02954 .35136 L
.03053 .35136 L
.03279 .35136 L
.03396 .35136 L
.03506 .35136 L
.03626 .35136 L
.03756 .35136 L
.03821 .35136 L
.03891 .35136 L
.0402 .35135 L
.04145 .35135 L
.04262 .35135 L
.04521 .35134 L
.04765 .35133 L
.05221 .3513 L
.05709 .35127 L
.05986 .35125 L
.06244 .35124 L
.06757 .35122 L
.07299 .3512 L
.08269 .35117 L
.08528 .35116 L
.08666 .35116 L
.08811 .35115 L
.08938 .35115 L
.09005 .35114 L
.09078 .35114 L
.09206 .35114 L
.09325 .35114 L
.09397 .35114 L
.09476 .35114 L
.09558 .35114 L
.09634 .35115 L
.09771 .35115 L
.09918 .35116 L
.10201 .35118 L
.10458 .3512 L
.1139 .3513 L
.11616 .35132 L
.1186 .35133 L
.12127 .35135 L
.12376 .35136 L
.13459 .3514 L
.13942 .35142 L
.14207 .35144 L
Mistroke
.14337 .35144 L
.14456 .35145 L
.14519 .35145 L
.14589 .35145 L
.14659 .35145 L
.14732 .35145 L
.14861 .35145 L
.14982 .35145 L
.15105 .35145 L
.15217 .35144 L
.15469 .35143 L
.15999 .35138 L
.16144 .35137 L
.16297 .35136 L
.16429 .35136 L
.16504 .35135 L
.16574 .35135 L
.167 .35135 L
.16764 .35135 L
.16833 .35135 L
.16957 .35136 L
.17071 .35136 L
.17207 .35137 L
.1733 .35138 L
.17607 .35142 L
.18072 .35149 L
.18337 .35153 L
.18584 .35156 L
.18704 .35157 L
.18819 .35158 L
.1895 .35159 L
.1907 .35159 L
.19198 .35159 L
.19317 .35159 L
.19446 .35159 L
.19512 .35159 L
.19585 .35158 L
.19813 .35157 L
.2006 .35155 L
.20506 .3515 L
.2078 .35147 L
.21035 .35143 L
.213 .35137 L
.21591 .35129 L
.21843 .3512 L
.22073 .35109 L
.22587 .35076 L
.23518 .35002 L
.23744 .34986 L
.23987 .34972 L
Mistroke
.24126 .34966 L
.24254 .34961 L
.24382 .34958 L
.24503 .34956 L
.24633 .34955 L
.24706 .34955 L
.24772 .34956 L
.249 .34958 L
.2502 .34961 L
.25162 .34966 L
.25291 .34971 L
.25585 .34988 L
.2607 .35028 L
.26582 .35085 L
.27603 .35257 L
.2857 .3548 L
.28991 .35567 L
.29203 .35601 L
.29326 .35617 L
.29438 .35628 L
.2956 .35638 L
.29691 .35644 L
.29806 .35646 L
.29928 .35644 L
.3004 .35639 L
.30145 .35631 L
.30259 .3562 L
.30381 .35605 L
.30634 .35562 L
.30908 .355 L
.31405 .35356 L
.32334 .35 L
.3333 .3451 L
.33859 .34246 L
.3415 .34124 L
.34293 .34074 L
.34426 .34036 L
.3455 .34007 L
.34614 .33996 L
.34683 .33986 L
.34759 .33978 L
.3483 .33973 L
.34899 .33971 L
.34963 .33972 L
.35077 .3398 L
.35202 .33997 L
.35332 .34025 L
.35454 .34059 L
.35697 .3415 L
.35918 .34255 L
Mistroke
.36415 .34547 L
.36934 .34894 L
.37497 .35309 L
.3852 .3636 L
.39013 .37052 L
.39285 .37445 L
.39543 .37785 L
.39783 .38037 L
.39848 .38091 L
.39918 .3814 L
.40044 .38204 L
.40168 .38233 L
.40284 .38225 L
.40389 .38188 L
.40502 .38114 L
.40623 .37995 L
.40756 .37816 L
.41023 .37304 L
.41271 .36671 L
.41503 .35976 L
.42031 .34269 L
.42309 .33469 L
.42462 .33104 L
.42605 .32821 L
.42729 .3263 L
.42793 .32552 L
.42863 .32482 L
.42935 .32428 L
.43011 .3239 L
.43082 .32372 L
.43148 .32371 L
.43275 .32405 L
.4339 .32474 L
.43454 .32527 L
.43524 .32593 L
.4365 .32731 L
.439 .33041 L
.44036 .33202 L
.44164 .33327 L
.44273 .33405 L
.44391 .33449 L
.44521 .33438 L
.44639 .33367 L
.44754 .33235 L
.44876 .33024 L
.44991 .32756 L
.45095 .32456 L
.4535 .3151 L
.45591 .30409 L
.45817 .29295 L
Mistroke
.46059 .28166 L
.46176 .27695 L
.46287 .27323 L
.46386 .27066 L
.46495 .26886 L
.46612 .26826 L
.46737 .26938 L
.46844 .27192 L
.46961 .27655 L
.47089 .28383 L
.47225 .2944 L
.47473 .3207 L
.47736 .35796 L
.48012 .40529 L
.48506 .49789 L
.48727 .53618 L
.48849 .55475 L
.48963 .5701 L
.4907 .58218 L
.49186 .59247 L
.49292 .59903 L
.49389 .60253 L
.49504 .60332 L
.49612 .60059 L
.49731 .59364 L
.49858 .58152 L
.49991 .5637 L
.50117 .54214 L
.50354 .49044 L
.51317 .19876 L
.51551 .13234 L
.51804 .07381 L
.51948 .04835 L
.52011 .03929 L
.52081 .03092 L
.52208 .01996 L
.52277 .01643 L
.52341 .01472 L
.52456 .01547 L
.52581 .02178 L
.52699 .03287 L
.52807 .04735 L
.53013 .08504 L
.53231 .13762 L
.53728 .28781 L
.54182 .42968 L
.54413 .49167 L
.54535 .51989 L
.54665 .54588 L
.5479 .56652 L
Mistroke
.54903 .58138 L
.55017 .59249 L
.55124 .59943 L
.55247 .6032 L
.55377 .60243 L
.55488 .5981 L
.5561 .58972 L
.55742 .57682 L
.55882 .55912 L
.56136 .51923 L
.56597 .43367 L
.57087 .34854 L
.57288 .32076 L
.57505 .29721 L
.57629 .28692 L
.57743 .27953 L
.57852 .27428 L
.57967 .27057 L
.58088 .26857 L
.58218 .26843 L
.58341 .26997 L
.58453 .27258 L
.58584 .27687 L
.58726 .28265 L
.58984 .29489 L
.59262 .30843 L
.59522 .31952 L
.59664 .32445 L
.59793 .32812 L
.59937 .33121 L
.60016 .33246 L
.60091 .33337 L
.60217 .33429 L
.60287 .3345 L
.60351 .33451 L
.60475 .33412 L
.60592 .33332 L
.60659 .33271 L
.60729 .33198 L
.60855 .33051 L
.61138 .32701 L
.61253 .32577 L
.61377 .32471 L
.61493 .32402 L
.61599 .32372 L
.61723 .32381 L
.61793 .32409 L
.61858 .32449 L
.61977 .32561 L
.62103 .32733 L
Mistroke
.63115 .35513 L
.63356 .36278 L
.63614 .37003 L
.63857 .37554 L
.63972 .37761 L
.64077 .37918 L
.64181 .38042 L
.64291 .38138 L
.64401 .38201 L
.64522 .38232 L
.64627 .38229 L
.64739 .38196 L
.64845 .3814 L
.64941 .38069 L
.65173 .37839 L
.65425 .37517 L
.65884 .36855 L
.66373 .36195 L
.66891 .35632 L
.67824 .34897 L
.68301 .34577 L
.68815 .3427 L
.6911 .34131 L
.69239 .34082 L
.6938 .34038 L
.69445 .34021 L
.69514 .34006 L
.69639 .33985 L
.69712 .33978 L
.69781 .33973 L
.69911 .33972 L
.70026 .3398 L
.70149 .33996 L
.70266 .34019 L
.70373 .34046 L
.70634 .34132 L
.70882 .34236 L
.7191 .34756 L
.72878 .35186 L
.73299 .35337 L
.73755 .35474 L
.74013 .35537 L
.74249 .35584 L
.74476 .35617 L
.7459 .35629 L
.74715 .35639 L
.74784 .35642 L
.74849 .35644 L
.7497 .35646 L
.75101 .35643 L
Mistroke
.75176 .35639 L
.75244 .35635 L
.75358 .35625 L
.75483 .35611 L
.75738 .35573 L
.76194 .3548 L
.76687 .35364 L
.77577 .35176 L
.78074 .35099 L
.78535 .35043 L
.79042 .34998 L
.79326 .34979 L
.79583 .34966 L
.79715 .34962 L
.79787 .34959 L
.79854 .34958 L
.79974 .34956 L
.80104 .34955 L
.80177 .34955 L
.80247 .34956 L
.80377 .34958 L
.80449 .34959 L
.80517 .34961 L
.80669 .34967 L
.8093 .34981 L
.81166 .34996 L
.81694 .35038 L
.82184 .35077 L
.82451 .35095 L
.827 .35109 L
.82931 .3512 L
.83141 .35128 L
.83375 .35135 L
.83624 .35141 L
.83891 .35145 L
.84138 .35149 L
.84403 .35152 L
.84696 .35155 L
.84932 .35157 L
.85063 .35158 L
.85187 .35158 L
.85254 .35159 L
.85328 .35159 L
.85456 .35159 L
.85587 .35159 L
.85708 .35159 L
.85837 .35159 L
.85902 .35158 L
.85973 .35158 L
.86216 .35155 L
Mistroke
.865 .35152 L
.86765 .35148 L
.87032 .35144 L
.87285 .3514 L
.87513 .35138 L
.87641 .35137 L
.8776 .35136 L
.87867 .35135 L
.87967 .35135 L
.88077 .35135 L
.88196 .35135 L
.88313 .35135 L
.88437 .35136 L
.88658 .35138 L
.89163 .35142 L
.89401 .35143 L
.89506 .35144 L
.89621 .35144 L
.89735 .35145 L
.89856 .35145 L
.89988 .35145 L
.90112 .35145 L
.90228 .35145 L
.90335 .35144 L
.90458 .35144 L
.90575 .35143 L
.91595 .35138 L
.92091 .35136 L
.92335 .35136 L
.92558 .35135 L
.92978 .35133 L
.93198 .35131 L
.93431 .35129 L
.94392 .3512 L
.94628 .35117 L
.9488 .35116 L
.95025 .35115 L
.95157 .35115 L
.95221 .35114 L
.9529 .35114 L
.95415 .35114 L
.95529 .35114 L
.95636 .35114 L
.95753 .35114 L
.95879 .35115 L
.96136 .35116 L
.96372 .35117 L
.97255 .3512 L
.97619 .35121 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "The filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " are given by the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ": "
}], "Text",
  CellTags->{"S1.3.2", "2.91"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(h\_k\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\@2\), \(1\/\(2 \[Pi]\)\), \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\),
                 "H", \((\[Omega])\), \(e\^\(i k \[Omega]\)\), " ", 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}], "=", \(\@2\), \(1\/\(2 \[Pi]\)\), 
                \(\[Integral]\_\(-\[Pi]\)\%\[Pi]\), \(\[Phi]\&^\), \((
                2 \[Omega])\), "cos", "k", \(\[Omega]\ \), 
                RowBox[{
                  StyleBox[\("d"\),
                    "TI"], "\[Omega]"}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{\(\@2\), \(1\/\[Pi]\), 
                RowBox[{"\[InvisibleSpace]", 
                  RowBox[{"[", 
                    RowBox[{
                    \(\[Integral]\_0\%\(\[Pi]/3\)\), "cos", "k", \(\[Omega]\ 
                      \), 
                      RowBox[{
                        StyleBox[\("d"\),
                          "TI"], "\[Omega]"}], "+", 
                      \(\[Integral]\_\(\[Pi]/3\)\%\(2 \[Pi]/3\)\), "cos", 
                      \(\[InvisibleSpace]\([
                      \(\[Pi]\/2\) \[Nu] \((\(3\/\[Pi]\) \[Omega] - 1)\)]\)\),
                       "cos", "k", \(\[Omega]\ \), 
                      RowBox[{
                        StyleBox[\("d"\),
                          "TI"], "\[Omega]"}]}], "]"}]}], ","}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.3.2", "2.92"}],

Cell[TextData[{
  "and they do not have an analytic form for a general ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". In the case of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\) = x\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", that is, linear interpolation between ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\) = 0\)], "InlineFormula",
    
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\) = 1\)], "InlineFormula",
    
    CellTags->"S1.3.2"],
  ", the filter coefficients can be calculated explicitly:"
}], "Text",
  CellTags->{"S1.3.2", "2.93"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(h\_k\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{\(\@2\), \(1\/\[Pi]\), 
                RowBox[{"\[InvisibleSpace]", 
                  RowBox[{"[", 
                    RowBox[{
                    \(\[Integral]\_0\%\(\[Pi]/3\)\), "cos", "k", \(\[Omega]\ 
                      \), 
                      RowBox[{
                        StyleBox[\("d"\),
                          "TI"], "\[Omega]"}], "+", 
                      \(\[Integral]\_\(\[Pi]/3\)\%\(2 \[Pi]/3\)\), "cos", 
                      \(\[InvisibleSpace]\([
                      \(\[Pi]\/2\) \[Nu] \((\(3\/\[Pi]\) \[Omega] - 1)\)]\)\),
                       "cos", "k", \(\[Omega]\ \), 
                      RowBox[{
                        StyleBox[\("d"\),
                          "TI"], "\[Omega]"}]}], "]"}]}]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            
            StyleBox[
              \(\(\@2\/\[Pi]\) 
                \((\(sin \[Pi] k/3\)\/k + 
                    \(4 k sin \[Pi] k/3\)\/\(9 - 4 k\^2\) + 
                    \(6 cos 2 k \[Pi]/3\)\/\(9 - 4 k\^2\))\).\),
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\n(3.14) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.3.2", "2.94"}],

Cell[TextData[{
  "We can use ",
  StyleBox["Mathematica", "TI"],
  " to do the above integration."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.95"}],

Cell[CellGroupData[{

Cell["\<\
(Sqrt[2]/Pi)(Integrate[Cos[k w], {w, 0, Pi/3}]+
Integrate[Cos[Pi/2(3/Pi w -1)]Cos[k w],{w, Pi/3, 2Pi/3}])\
\>", "Input",
  CellLabel->"In[53]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(\(\@2\ 
        \((\(-\(\(6\ Cos[\(2\ k\ \[Pi]\)\/3]\)\/\(\((\(-3\) + 2\ k)\)\ 
                    \((3 + 2\ k)\)\)\)\) + Sin[\(k\ \[Pi]\)\/3]\/k - 
            \(4\ k\ Sin[\(k\ \[Pi]\)\/3]\)\/\(\((\(-3\) + 2\ k)\)\ 
                \((3 + 2\ k)\)\))\)\)\/\[Pi]\)], "Output",
  CellLabel->"Out[53]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " is large, the first two terms in (",
  ButtonBox["3.14",
    ButtonData:>{"Wavelets 1.3.2", "2.94"},
    ButtonStyle->"AddOnsLink"],
  ") cancel and the coefficients decay as ",
  Cell[BoxData[
      \(TraditionalForm\`k\^\(-2\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The smoother the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", the faster the filter coefficients decay. Suppose that in addition to \
imposing continuity of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", we demand that its first ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " derivatives are also continuous, then the conditions ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(d\^l\) \(\[Phi]\&^\) \((\[Omega])\)/d 
         \[Omega]\^l\( \[VerticalSeparator] \_\(\[Omega] = 2  \[Pi]/3\)\) = 0
        \)], "InlineFormula",
    CellTags->"S1.3.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, ..., n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " require that the interpolating polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " be proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(n + 1\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". Similar conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 4  \[Pi]/3\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " give ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " additional constraints, and this means that the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " can be uniquely determined if it is of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(x\^\(n + 1\)\) \((
        c\_0 + \(c\_1\) x + \[CenterEllipsis] + \(c\_n\) x\^n)\)\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ". These conditions can be fulfilled by requiring ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\) + \[Nu] \((1 - x)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ", which imposes symmetry between ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". \nSo for a given smoothness of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", we can solve for the polynomial interpolating function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". It has degree ",
  Cell[BoxData[
      \(TraditionalForm\`2  n + 1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\(n + 1\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " coefficients are determined from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\) + \[Nu] \((1 - x)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.3.2"],
  ". (Although we consider only polynomial interpolating functions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " does not have to be restricted to a polynomial in general.) "
}], "Text",
  CellTags->{"S1.3.2", "2.96"}],

Cell[TextData[{
  "Here is a ",
  StyleBox["Mathematica", "TI"],
  " program which, upon inputting ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", gives the polynomial function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " of order ",
  Cell[BoxData[
      \(TraditionalForm\`2  n + 1\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.97"}],

Cell["\<\
getnu[n_Integer, x_]:= Module[{nu, c},
nu = x^(n+1) Sum[c[i]*x^i, {i, 0, n}];
nu/. Solve[Thread[
CoefficientList[nu + (nu /. x -> 1 - x) - 1, x]==0],
        Array[c, n+1, 0]][[1]]]\
\>", "Input",
  CellLabel->"In[54]:= ",
  CellTags->"S1.3.2"],

Cell[TextData[{
  "For example, this gives the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  " we encountered in (",
  ButtonBox["3.13",
    ButtonData:>{"Wavelets 1.3.2", "2.56"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.98"}],

Cell[CellGroupData[{

Cell["getnu[3, x]", "Input",
  CellLabel->"In[55]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(x\^4\ \((35 - 84\ x + 70\ x\^2 - 20\ x\^3)\)\)], "Output",
  CellLabel->"Out[55]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "This is another ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((x)\)\)], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.99"}],

Cell[CellGroupData[{

Cell["getnu[4, x]", "Input",
  CellLabel->"In[56]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \(x\^5\ \((126 - 420\ x + 540\ x\^2 - 315\ x\^3 + 70\ x\^4)\)\)], "Output",\

  CellLabel->"Out[56]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "To get the filter coefficients associated with the Meyer wavelet of order \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.3.2"],
  ", we can use the function "
}], "Text",
  CellTags->{"S1.3.2", "2.100"}],

Cell[TextData[{
  StyleBox["MeyerFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["kmax", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.3.2", "2.101"}],

Cell[TextData[{
  "It gives ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                SubscriptBox["h", 
                  RowBox[{"-", 
                    StyleBox[\("kmax"\),
                      "TI"]}]], ",", "\[Ellipsis]", ",", 
                SubscriptBox["h", 
                  StyleBox[\("kmax"\),
                    "TI"]]}], "}"}], ",", "-", 
            StyleBox[\("kmax"\),
              "TI"]}], "}"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.2"],
  ". "
}], "Text",
  CellTags->{"S1.3.2", "2.102"}],

Cell[TextData[{
  "This calculates the Meyer filter of order 3 up to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "6"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.3.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.3.2", "2.103"}],

Cell[CellGroupData[{

Cell["MeyerFilter[3, 6]", "Input",
  CellLabel->"In[57]:= ",
  CellTags->"S1.3.2"],

Cell[BoxData[
    \({{\(-0.0243217642129514644`\), 0.0636672491274925356`, 
        0.0306212190576890996`, \(-0.132696507483232806`\), 
        \(-0.0350482588736408384`\), 0.444094669648803375`, 
        0.743750400061954142`, 0.444094669648803375`, 
        \(-0.0350482588736408384`\), \(-0.132696507483232806`\), 
        0.0306212190576890996`, 0.0636672491274925356`, 
        \(-0.0243217642129514644`\)}, \(-6\)}\)], "Output",
  CellLabel->"Out[57]= ",
  CellTags->"S1.3.2"]
}, Open  ]],

Cell[TextData[{
  "As we will see in Section ",
  ButtonBox["1.5",
    ButtonData:>{"Wavelets 1.5"},
    ButtonStyle->"AddOnsLink"],
  ", we can also get the approximate scaling function and wavelet by doing \
inverse wavelet transforms using these filter coefficients. "
}], "Text",
  CellTags->{"S1.3.2", "2.104"}]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{520, 600},
WindowMargins->{{115, Automatic}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1717, 49, 66, 1, 56, "Section",
      CellTags->"Contents"],
    Cell[1786, 52, 409, 14, 76, "Contents",
      CellTags->"Contents"]},
  "S1.3.0"->{
    Cell[2198, 68, 73, 1, 56, "Section",
      CellTags->{"S1.3.0", "0.1"}],
    Cell[2274, 71, 589, 14, 60, "Text",
      CellTags->{"S1.3.0", "0.2"}],
    Cell[2866, 87, 176, 4, 34, "DisplayFormula",
      CellTags->{"S1.3.0", "0.3"}],
    Cell[3045, 93, 3569, 81, 398, "Text",
      CellTags->{"S1.3.0", "0.4"}]},
  "0.1"->{
    Cell[2198, 68, 73, 1, 56, "Section",
      CellTags->{"S1.3.0", "0.1"}]},
  "0.2"->{
    Cell[2274, 71, 589, 14, 60, "Text",
      CellTags->{"S1.3.0", "0.2"}]},
  "0.3"->{
    Cell[2866, 87, 176, 4, 34, "DisplayFormula",
      CellTags->{"S1.3.0", "0.3"}]},
  "0.4"->{
    Cell[3045, 93, 3569, 81, 398, "Text",
      CellTags->{"S1.3.0", "0.4"}]},
  "S1.3.1"->{
    Cell[6617, 176, 98, 1, 39, "Subsection",
      CellTags->{"S1.3.1", "1.1"}],
    Cell[6718, 179, 1011, 17, 161, "Text",
      CellTags->{"S1.3.1", "1.2"}],
    Cell[7732, 198, 72, 1, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.3"}],
    Cell[7807, 201, 4568, 132, 288, "Text",
      CellTags->{"S1.3.1", "1.4"}],
    Cell[12378, 335, 383, 8, 45, "DisplayFormula",
      CellTags->{"S1.3.1", "1.5"}],
    Cell[12764, 345, 777, 23, 42, "Text",
      CellTags->{"S1.3.1", "1.6"}],
    Cell[13544, 370, 1530, 44, 65, "DisplayFormula",
      CellTags->{"S1.3.1", "1.7"}],
    Cell[15077, 416, 754, 21, 59, "Text",
      CellTags->{"S1.3.1", "1.8"}],
    Cell[15834, 439, 774, 21, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.9"}],
    Cell[16611, 462, 3370, 112, 135, "Text",
      CellTags->{"S1.3.1", "1.10"}],
    Cell[19984, 576, 2186, 52, 127, "DisplayFormula",
      CellTags->{"S1.3.1", "1.11"}],
    Cell[22173, 630, 511, 17, 42, "Text",
      CellTags->{"S1.3.1", "1.12"}],
    Cell[22687, 649, 219, 10, 25, "Text",
      CellTags->{"S1.3.1", "1.13"}],
    Cell[22909, 661, 193, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.14"}],
    Cell[23105, 670, 78, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.15"}],
    Cell[23186, 673, 93, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[23282, 677, 458, 14, 48, "MathCaption",
      CellTags->{"S1.3.1", "1.16"}],
    Cell[23765, 695, 169, 5, 51, "Input",
      CellTags->"S1.3.1"],
    Cell[23937, 702, 8348, 559, 186, 8275, 556, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[32300, 1264, 1485, 43, 76, "Text",
      CellTags->{"S1.3.1", "1.17"}],
    Cell[33788, 1309, 218, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.18"}],
    Cell[34031, 1320, 224, 6, 71, "Input",
      CellTags->"S1.3.1"],
    Cell[34258, 1328, 16551, 1080, 186, 16478, 1077, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[50824, 2411, 166, 5, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.19"}],
    Cell[51015, 2420, 135, 5, 51, "Input",
      CellTags->"S1.3.1"],
    Cell[51153, 2427, 102, 3, 23, "Output",
      CellTags->"S1.3.1"],
    Cell[51270, 2433, 88, 1, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.20"}],
    Cell[51361, 2436, 4364, 127, 230, "Text",
      CellTags->{"S1.3.1", "1.21"}],
    Cell[55728, 2565, 2125, 52, 127, "DisplayFormula",
      CellTags->{"S1.3.1", "1.22"}],
    Cell[57856, 2619, 189, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.23"}],
    Cell[58048, 2628, 265, 5, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.24"}],
    Cell[58316, 2635, 173, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.25"}],
    Cell[58492, 2644, 308, 6, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.26"}],
    Cell[58803, 2652, 960, 31, 59, "Text",
      CellTags->{"S1.3.1", "1.27"}],
    Cell[59766, 2685, 261, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.28"}],
    Cell[60030, 2694, 382, 9, 131, "Input",
      CellTags->"S1.3.1"],
    Cell[60415, 2705, 704, 19, 59, "Text",
      CellTags->{"S1.3.1", "1.29"}],
    Cell[61122, 2726, 234, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.30"}],
    Cell[61381, 2737, 83, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[61467, 2741, 23714, 1539, 186, 23641, 1536, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[85196, 4283, 234, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.31"}],
    Cell[85455, 4294, 83, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[85541, 4298, 31469, 2036, 186, 31396, 2033, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[117025, 6337, 218, 7, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.32"}],
    Cell[117246, 6346, 1389, 40, 101, "Text",
      CellTags->{"S1.3.1", "1.33"}],
    Cell[118638, 6388, 707, 16, 49, "DisplayFormula",
      CellTags->{"S1.3.1", "1.34"}],
    Cell[119348, 6406, 958, 31, 42, "Text",
      CellTags->{"S1.3.1", "1.35"}],
    Cell[120309, 6439, 341, 8, 50, "DisplayFormula",
      CellTags->{"S1.3.1", "1.36"}],
    Cell[120653, 6449, 1814, 55, 101, "Text",
      CellTags->{"S1.3.1", "1.37"}],
    Cell[122470, 6506, 692, 14, 105, "DisplayFormula",
      CellTags->{"S1.3.1", "1.38"}],
    Cell[123165, 6522, 101, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.39"}],
    Cell[123269, 6525, 296, 6, 57, "DisplayFormula",
      CellTags->{"S1.3.1", "1.40"}],
    Cell[123568, 6533, 82, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.41"}],
    Cell[123653, 6536, 286, 6, 51, "DisplayFormula",
      CellTags->{"S1.3.1", "1.42"}],
    Cell[123942, 6544, 264, 10, 25, "Text",
      CellTags->{"S1.3.1", "1.43"}],
    Cell[124209, 6556, 217, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.44"}],
    Cell[124451, 6567, 108, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[124562, 6571, 99, 3, 36, "Output",
      CellTags->"S1.3.1"],
    Cell[124676, 6577, 59, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.45"}],
    Cell[124738, 6580, 175, 4, 49, "DisplayFormula",
      CellTags->{"S1.3.1", "1.46"}],
    Cell[124916, 6586, 374, 11, 42, "Text",
      CellTags->{"S1.3.1", "1.47"}],
    Cell[125293, 6599, 486, 10, 61, "DisplayFormula",
      CellTags->{"S1.3.1", "1.48"}],
    Cell[125782, 6611, 1054, 33, 60, "Text",
      CellTags->{"S1.3.1", "1.49"}],
    Cell[126839, 6646, 257, 6, 45, "DisplayFormula",
      CellTags->{"S1.3.1", "1.50"}],
    Cell[127099, 6654, 2328, 64, 194, "Text",
      CellTags->{"S1.3.1", "1.51"}],
    Cell[129430, 6720, 381, 15, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.52"}],
    Cell[129814, 6737, 199, 7, 91, "Input",
      CellTags->"S1.3.1"],
    Cell[130016, 6746, 305, 11, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.53"}],
    Cell[130346, 6761, 127, 5, 51, "Input",
      CellTags->"S1.3.1"],
    Cell[130476, 6768, 107, 3, 36, "Output",
      CellTags->"S1.3.1"],
    Cell[130598, 6774, 1488, 51, 93, "Text",
      CellTags->{"S1.3.1", "1.54"}],
    Cell[132089, 6827, 96, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.55"}],
    Cell[132188, 6830, 102, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[132293, 6834, 569, 18, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.56"}],
    Cell[132887, 6856, 308, 11, 171, "Input",
      CellTags->"S1.3.1"],
    Cell[133198, 6869, 318, 6, 42, "Output",
      CellTags->"S1.3.1"],
    Cell[133531, 6878, 1353, 44, 59, "Text",
      CellTags->{"S1.3.1", "1.57"}],
    Cell[134887, 6924, 221, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.58"}],
    Cell[135133, 6935, 266, 7, 91, "Input",
      CellTags->"S1.3.1"],
    Cell[135402, 6944, 8761, 672, 186, 8688, 669, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[144178, 7619, 330, 8, 48, "MathCaption",
      CellTags->{"S1.3.1", "1.59"}],
    Cell[144533, 7631, 172, 6, 71, "Input",
      CellTags->"S1.3.1"],
    Cell[144708, 7639, 9668, 730, 186, 9595, 727, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[154391, 8372, 1123, 31, 101, "Text",
      CellTags->{"S1.3.1", "1.60"}],
    Cell[155517, 8405, 277, 13, 25, "Text",
      CellTags->{"S1.3.1", "1.61"}],
    Cell[155797, 8420, 652, 20, 25, "Text",
      CellTags->{"S1.3.1", "1.62"}],
    Cell[156452, 8442, 139, 4, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.63"}],
    Cell[156594, 8448, 84, 2, 31, "Input",
      CellTags->"S1.3.1"],
    Cell[156681, 8452, 76, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.64"}],
    Cell[156782, 8457, 195, 6, 71, "Input",
      CellTags->"S1.3.1"],
    Cell[156980, 8465, 10939, 781, 70, 10866, 778, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[167934, 9249, 340, 6, 70, "Text",
      CellTags->{"S1.3.1", "1.65"}],
    Cell[168277, 9257, 276, 13, 70, "Text",
      CellTags->{"S1.3.1", "1.66"}],
    Cell[168556, 9272, 1026, 32, 70, "Text",
      CellTags->{"S1.3.1", "1.67"}],
    Cell[169585, 9306, 279, 9, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.68"}],
    Cell[169867, 9317, 99, 2, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[169969, 9321, 263, 10, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.69"}],
    Cell[170257, 9335, 80, 2, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[170340, 9339, 84, 3, 70, "Output",
      CellTags->"S1.3.1"],
    Cell[170439, 9345, 700, 21, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.70"}],
    Cell[171164, 9370, 233, 7, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[171400, 9379, 15469, 981, 70, 15396, 978, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[186884, 10363, 333, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.71"}],
    Cell[187242, 10374, 116, 2, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[187361, 10378, 111, 3, 70, "Output",
      CellTags->"S1.3.1"],
    Cell[187487, 10384, 130, 4, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.72"}],
    Cell[187642, 10392, 163, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[187808, 10399, 106, 3, 70, "Output",
      CellTags->"S1.3.1"],
    Cell[187929, 10405, 84, 1, 70, "Subsubsection",
      CellTags->{"S1.3.1", "1.73"}],
    Cell[188016, 10408, 1079, 31, 70, "Text",
      CellTags->{"S1.3.1", "1.74"}],
    Cell[189098, 10441, 366, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.75"}],
    Cell[189467, 10451, 483, 16, 70, "Text",
      CellTags->{"S1.3.1", "1.76"}],
    Cell[189953, 10469, 134, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.77"}],
    Cell[190090, 10474, 216, 6, 70, "Text",
      CellTags->{"S1.3.1", "1.78"}],
    Cell[190309, 10482, 269, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.79"}],
    Cell[190581, 10490, 1116, 26, 70, "Text",
      CellTags->{"S1.3.1", "1.80"}],
    Cell[191700, 10518, 187, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.81"}],
    Cell[191890, 10524, 1289, 39, 70, "Text",
      CellTags->{"S1.3.1", "1.82"}],
    Cell[193182, 10565, 209, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.83"}],
    Cell[193394, 10571, 354, 12, 70, "Text",
      CellTags->{"S1.3.1", "1.84"}],
    Cell[193751, 10585, 485, 10, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.85"}],
    Cell[194239, 10597, 366, 11, 70, "Text",
      CellTags->{"S1.3.1", "1.86"}],
    Cell[194608, 10610, 189, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.87"}],
    Cell[194800, 10616, 249, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.88"}],
    Cell[195052, 10625, 330, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.89"}],
    Cell[195385, 10633, 234, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.90"}],
    Cell[195622, 10642, 1621, 38, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.91"}],
    Cell[197246, 10682, 352, 11, 70, "Text",
      CellTags->{"S1.3.1", "1.92"}],
    Cell[197601, 10695, 347, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.93"}],
    Cell[197951, 10706, 257, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.94"}],
    Cell[198211, 10715, 228, 10, 70, "Text",
      CellTags->{"S1.3.1", "1.95"}],
    Cell[198442, 10727, 1192, 42, 70, "Text",
      CellTags->{"S1.3.1", "1.96"}],
    Cell[199637, 10771, 501, 15, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.97"}],
    Cell[200163, 10790, 83, 2, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[200249, 10794, 359, 7, 70, "Output",
      CellTags->"S1.3.1"],
    Cell[200623, 10804, 1274, 31, 70, "Text",
      CellTags->{"S1.3.1", "1.98"}],
    Cell[201900, 10837, 393, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.99"}],
    Cell[202296, 10847, 62, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.100"}],
    Cell[202361, 10850, 220, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.101"}],
    Cell[202584, 10857, 49, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.102"}],
    Cell[202636, 10860, 212, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.103"}],
    Cell[202851, 10866, 53, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.104"}],
    Cell[202907, 10869, 221, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.105"}],
    Cell[203131, 10876, 232, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.106"}],
    Cell[203366, 10885, 298, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.107"}],
    Cell[203667, 10893, 91, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.108"}],
    Cell[203761, 10896, 717, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.109"}],
    Cell[204481, 10915, 1281, 40, 70, "Text",
      CellTags->{"S1.3.1", "1.110"}],
    Cell[205765, 10957, 278, 13, 70, "Text",
      CellTags->{"S1.3.1", "1.111"}],
    Cell[206046, 10972, 1574, 55, 70, "Text",
      CellTags->{"S1.3.1", "1.112"}],
    Cell[207623, 11029, 245, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.113"}],
    Cell[207893, 11040, 189, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[208085, 11048, 4958, 345, 70, 4885, 342, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[213058, 11396, 570, 12, 70, "Text",
      CellTags->{"S1.3.1", "1.114"}],
    Cell[213631, 11410, 210, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.115"}],
    Cell[213866, 11421, 173, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[214042, 11428, 9417, 628, 70, 9344, 625, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[223474, 12059, 346, 11, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.116"}],
    Cell[223845, 12074, 189, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[224037, 12082, 7298, 493, 70, 7225, 490, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[231350, 12578, 291, 8, 70, "Text",
      CellTags->{"S1.3.1", "1.117"}],
    Cell[231644, 12588, 290, 10, 70, "Subsubsection",
      CellTags->{"S1.3.1", "1.118"}],
    Cell[231937, 12600, 805, 23, 70, "Text",
      CellTags->{"S1.3.1", "1.119"}],
    Cell[232745, 12625, 824, 28, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.120"}],
    Cell[233572, 12655, 152, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[233727, 12662, 378, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.121"}],
    Cell[234130, 12679, 180, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[234313, 12686, 8558, 571, 70, 8485, 568, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[242886, 13260, 378, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.122"}],
    Cell[243289, 13277, 180, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[243472, 13284, 12028, 793, 70, 11955, 790, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[255515, 14080, 643, 23, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.123"}],
    Cell[256161, 14105, 192, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[256356, 14113, 275, 8, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.124"}],
    Cell[256656, 14125, 180, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[256839, 14132, 7564, 508, 70, 7491, 505, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[264418, 14643, 285, 9, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.125"}],
    Cell[264728, 14656, 180, 5, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[264911, 14663, 11065, 731, 70, 10992, 728, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[275991, 15397, 543, 14, 70, "Text",
      CellTags->{"S1.3.1", "1.126"}],
    Cell[276537, 15413, 398, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.127"}],
    Cell[276938, 15428, 175, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[277116, 15436, 235, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.128"}],
    Cell[277376, 15447, 202, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[277581, 15455, 8542, 553, 70, 8469, 550, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[286138, 16011, 355, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.129"}],
    Cell[286518, 16028, 202, 6, 70, "Input",
      CellTags->"S1.3.1"],
    Cell[286723, 16036, 13156, 846, 70, 13083, 843, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.1"],
    Cell[299894, 16885, 1920, 57, 70, "Text",
      CellTags->{"S1.3.1", "1.130"}]},
  "1.1"->{
    Cell[6617, 176, 98, 1, 39, "Subsection",
      CellTags->{"S1.3.1", "1.1"}]},
  "1.2"->{
    Cell[6718, 179, 1011, 17, 161, "Text",
      CellTags->{"S1.3.1", "1.2"}]},
  "1.3"->{
    Cell[7732, 198, 72, 1, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.3"}]},
  "1.4"->{
    Cell[7807, 201, 4568, 132, 288, "Text",
      CellTags->{"S1.3.1", "1.4"}]},
  "1.5"->{
    Cell[12378, 335, 383, 8, 45, "DisplayFormula",
      CellTags->{"S1.3.1", "1.5"}]},
  "1.6"->{
    Cell[12764, 345, 777, 23, 42, "Text",
      CellTags->{"S1.3.1", "1.6"}]},
  "1.7"->{
    Cell[13544, 370, 1530, 44, 65, "DisplayFormula",
      CellTags->{"S1.3.1", "1.7"}]},
  "1.8"->{
    Cell[15077, 416, 754, 21, 59, "Text",
      CellTags->{"S1.3.1", "1.8"}]},
  "1.9"->{
    Cell[15834, 439, 774, 21, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.9"}]},
  "1.10"->{
    Cell[16611, 462, 3370, 112, 135, "Text",
      CellTags->{"S1.3.1", "1.10"}]},
  "1.11"->{
    Cell[19984, 576, 2186, 52, 127, "DisplayFormula",
      CellTags->{"S1.3.1", "1.11"}]},
  "1.12"->{
    Cell[22173, 630, 511, 17, 42, "Text",
      CellTags->{"S1.3.1", "1.12"}]},
  "1.13"->{
    Cell[22687, 649, 219, 10, 25, "Text",
      CellTags->{"S1.3.1", "1.13"}]},
  "1.14"->{
    Cell[22909, 661, 193, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.14"}]},
  "1.15"->{
    Cell[23105, 670, 78, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.15"}]},
  "1.16"->{
    Cell[23282, 677, 458, 14, 48, "MathCaption",
      CellTags->{"S1.3.1", "1.16"}]},
  "1.17"->{
    Cell[32300, 1264, 1485, 43, 76, "Text",
      CellTags->{"S1.3.1", "1.17"}]},
  "1.18"->{
    Cell[33788, 1309, 218, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.18"}]},
  "1.19"->{
    Cell[50824, 2411, 166, 5, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.19"}]},
  "1.20"->{
    Cell[51270, 2433, 88, 1, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.20"}]},
  "1.21"->{
    Cell[51361, 2436, 4364, 127, 230, "Text",
      CellTags->{"S1.3.1", "1.21"}]},
  "1.22"->{
    Cell[55728, 2565, 2125, 52, 127, "DisplayFormula",
      CellTags->{"S1.3.1", "1.22"}]},
  "1.23"->{
    Cell[57856, 2619, 189, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.23"}]},
  "1.24"->{
    Cell[58048, 2628, 265, 5, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.24"}]},
  "1.25"->{
    Cell[58316, 2635, 173, 7, 25, "Text",
      CellTags->{"S1.3.1", "1.25"}]},
  "1.26"->{
    Cell[58492, 2644, 308, 6, 47, "DisplayFormula",
      CellTags->{"S1.3.1", "1.26"}]},
  "1.27"->{
    Cell[58803, 2652, 960, 31, 59, "Text",
      CellTags->{"S1.3.1", "1.27"}]},
  "1.28"->{
    Cell[59766, 2685, 261, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.28"}]},
  "1.29"->{
    Cell[60415, 2705, 704, 19, 59, "Text",
      CellTags->{"S1.3.1", "1.29"}]},
  "1.30"->{
    Cell[61122, 2726, 234, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.30"}]},
  "1.31"->{
    Cell[85196, 4283, 234, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.31"}]},
  "1.32"->{
    Cell[117025, 6337, 218, 7, 35, "Subsubsection",
      CellTags->{"S1.3.1", "1.32"}]},
  "1.33"->{
    Cell[117246, 6346, 1389, 40, 101, "Text",
      CellTags->{"S1.3.1", "1.33"}]},
  "1.34"->{
    Cell[118638, 6388, 707, 16, 49, "DisplayFormula",
      CellTags->{"S1.3.1", "1.34"}]},
  "1.35"->{
    Cell[119348, 6406, 958, 31, 42, "Text",
      CellTags->{"S1.3.1", "1.35"}]},
  "1.36"->{
    Cell[120309, 6439, 341, 8, 50, "DisplayFormula",
      CellTags->{"S1.3.1", "1.36"}]},
  "1.37"->{
    Cell[120653, 6449, 1814, 55, 101, "Text",
      CellTags->{"S1.3.1", "1.37"}]},
  "1.38"->{
    Cell[122470, 6506, 692, 14, 105, "DisplayFormula",
      CellTags->{"S1.3.1", "1.38"}]},
  "1.39"->{
    Cell[123165, 6522, 101, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.39"}]},
  "1.40"->{
    Cell[123269, 6525, 296, 6, 57, "DisplayFormula",
      CellTags->{"S1.3.1", "1.40"}]},
  "1.41"->{
    Cell[123568, 6533, 82, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.41"}]},
  "1.42"->{
    Cell[123653, 6536, 286, 6, 51, "DisplayFormula",
      CellTags->{"S1.3.1", "1.42"}]},
  "1.43"->{
    Cell[123942, 6544, 264, 10, 25, "Text",
      CellTags->{"S1.3.1", "1.43"}]},
  "1.44"->{
    Cell[124209, 6556, 217, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.44"}]},
  "1.45"->{
    Cell[124676, 6577, 59, 1, 25, "Text",
      CellTags->{"S1.3.1", "1.45"}]},
  "1.46"->{
    Cell[124738, 6580, 175, 4, 49, "DisplayFormula",
      CellTags->{"S1.3.1", "1.46"}]},
  "1.47"->{
    Cell[124916, 6586, 374, 11, 42, "Text",
      CellTags->{"S1.3.1", "1.47"}]},
  "1.48"->{
    Cell[125293, 6599, 486, 10, 61, "DisplayFormula",
      CellTags->{"S1.3.1", "1.48"}]},
  "1.49"->{
    Cell[125782, 6611, 1054, 33, 60, "Text",
      CellTags->{"S1.3.1", "1.49"}]},
  "1.50"->{
    Cell[126839, 6646, 257, 6, 45, "DisplayFormula",
      CellTags->{"S1.3.1", "1.50"}]},
  "1.51"->{
    Cell[127099, 6654, 2328, 64, 194, "Text",
      CellTags->{"S1.3.1", "1.51"}]},
  "1.52"->{
    Cell[129430, 6720, 381, 15, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.52"}]},
  "1.53"->{
    Cell[130016, 6746, 305, 11, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.53"}]},
  "1.54"->{
    Cell[130598, 6774, 1488, 51, 93, "Text",
      CellTags->{"S1.3.1", "1.54"}]},
  "1.55"->{
    Cell[132089, 6827, 96, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.55"}]},
  "1.56"->{
    Cell[132293, 6834, 569, 18, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.56"}]},
  "1.57"->{
    Cell[133531, 6878, 1353, 44, 59, "Text",
      CellTags->{"S1.3.1", "1.57"}]},
  "1.58"->{
    Cell[134887, 6924, 221, 7, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.58"}]},
  "1.59"->{
    Cell[144178, 7619, 330, 8, 48, "MathCaption",
      CellTags->{"S1.3.1", "1.59"}]},
  "1.60"->{
    Cell[154391, 8372, 1123, 31, 101, "Text",
      CellTags->{"S1.3.1", "1.60"}]},
  "1.61"->{
    Cell[155517, 8405, 277, 13, 25, "Text",
      CellTags->{"S1.3.1", "1.61"}]},
  "1.62"->{
    Cell[155797, 8420, 652, 20, 25, "Text",
      CellTags->{"S1.3.1", "1.62"}]},
  "1.63"->{
    Cell[156452, 8442, 139, 4, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.63"}]},
  "1.64"->{
    Cell[156681, 8452, 76, 1, 31, "MathCaption",
      CellTags->{"S1.3.1", "1.64"}]},
  "1.65"->{
    Cell[167934, 9249, 340, 6, 70, "Text",
      CellTags->{"S1.3.1", "1.65"}]},
  "1.66"->{
    Cell[168277, 9257, 276, 13, 70, "Text",
      CellTags->{"S1.3.1", "1.66"}]},
  "1.67"->{
    Cell[168556, 9272, 1026, 32, 70, "Text",
      CellTags->{"S1.3.1", "1.67"}]},
  "1.68"->{
    Cell[169585, 9306, 279, 9, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.68"}]},
  "1.69"->{
    Cell[169969, 9321, 263, 10, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.69"}]},
  "1.70"->{
    Cell[170439, 9345, 700, 21, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.70"}]},
  "1.71"->{
    Cell[186884, 10363, 333, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.71"}]},
  "1.72"->{
    Cell[187487, 10384, 130, 4, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.72"}]},
  "1.73"->{
    Cell[187929, 10405, 84, 1, 70, "Subsubsection",
      CellTags->{"S1.3.1", "1.73"}]},
  "1.74"->{
    Cell[188016, 10408, 1079, 31, 70, "Text",
      CellTags->{"S1.3.1", "1.74"}]},
  "1.75"->{
    Cell[189098, 10441, 366, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.75"}]},
  "1.76"->{
    Cell[189467, 10451, 483, 16, 70, "Text",
      CellTags->{"S1.3.1", "1.76"}]},
  "1.77"->{
    Cell[189953, 10469, 134, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.77"}]},
  "1.78"->{
    Cell[190090, 10474, 216, 6, 70, "Text",
      CellTags->{"S1.3.1", "1.78"}]},
  "1.79"->{
    Cell[190309, 10482, 269, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.79"}]},
  "1.80"->{
    Cell[190581, 10490, 1116, 26, 70, "Text",
      CellTags->{"S1.3.1", "1.80"}]},
  "1.81"->{
    Cell[191700, 10518, 187, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.81"}]},
  "1.82"->{
    Cell[191890, 10524, 1289, 39, 70, "Text",
      CellTags->{"S1.3.1", "1.82"}]},
  "1.83"->{
    Cell[193182, 10565, 209, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.83"}]},
  "1.84"->{
    Cell[193394, 10571, 354, 12, 70, "Text",
      CellTags->{"S1.3.1", "1.84"}]},
  "1.85"->{
    Cell[193751, 10585, 485, 10, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.85"}]},
  "1.86"->{
    Cell[194239, 10597, 366, 11, 70, "Text",
      CellTags->{"S1.3.1", "1.86"}]},
  "1.87"->{
    Cell[194608, 10610, 189, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.87"}]},
  "1.88"->{
    Cell[194800, 10616, 249, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.88"}]},
  "1.89"->{
    Cell[195052, 10625, 330, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.89"}]},
  "1.90"->{
    Cell[195385, 10633, 234, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.90"}]},
  "1.91"->{
    Cell[195622, 10642, 1621, 38, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.91"}]},
  "1.92"->{
    Cell[197246, 10682, 352, 11, 70, "Text",
      CellTags->{"S1.3.1", "1.92"}]},
  "1.93"->{
    Cell[197601, 10695, 347, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.93"}]},
  "1.94"->{
    Cell[197951, 10706, 257, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.94"}]},
  "1.95"->{
    Cell[198211, 10715, 228, 10, 70, "Text",
      CellTags->{"S1.3.1", "1.95"}]},
  "1.96"->{
    Cell[198442, 10727, 1192, 42, 70, "Text",
      CellTags->{"S1.3.1", "1.96"}]},
  "1.97"->{
    Cell[199637, 10771, 501, 15, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.97"}]},
  "1.98"->{
    Cell[200623, 10804, 1274, 31, 70, "Text",
      CellTags->{"S1.3.1", "1.98"}]},
  "1.99"->{
    Cell[201900, 10837, 393, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.99"}]},
  "1.100"->{
    Cell[202296, 10847, 62, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.100"}]},
  "1.101"->{
    Cell[202361, 10850, 220, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.101"}]},
  "1.102"->{
    Cell[202584, 10857, 49, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.102"}]},
  "1.103"->{
    Cell[202636, 10860, 212, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.103"}]},
  "1.104"->{
    Cell[202851, 10866, 53, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.104"}]},
  "1.105"->{
    Cell[202907, 10869, 221, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.105"}]},
  "1.106"->{
    Cell[203131, 10876, 232, 7, 70, "Text",
      CellTags->{"S1.3.1", "1.106"}]},
  "1.107"->{
    Cell[203366, 10885, 298, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.107"}]},
  "1.108"->{
    Cell[203667, 10893, 91, 1, 70, "Text",
      CellTags->{"S1.3.1", "1.108"}]},
  "1.109"->{
    Cell[203761, 10896, 717, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.1", "1.109"}]},
  "1.110"->{
    Cell[204481, 10915, 1281, 40, 70, "Text",
      CellTags->{"S1.3.1", "1.110"}]},
  "1.111"->{
    Cell[205765, 10957, 278, 13, 70, "Text",
      CellTags->{"S1.3.1", "1.111"}]},
  "1.112"->{
    Cell[206046, 10972, 1574, 55, 70, "Text",
      CellTags->{"S1.3.1", "1.112"}]},
  "1.113"->{
    Cell[207623, 11029, 245, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.113"}]},
  "1.114"->{
    Cell[213058, 11396, 570, 12, 70, "Text",
      CellTags->{"S1.3.1", "1.114"}]},
  "1.115"->{
    Cell[213631, 11410, 210, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.115"}]},
  "1.116"->{
    Cell[223474, 12059, 346, 11, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.116"}]},
  "1.117"->{
    Cell[231350, 12578, 291, 8, 70, "Text",
      CellTags->{"S1.3.1", "1.117"}]},
  "1.118"->{
    Cell[231644, 12588, 290, 10, 70, "Subsubsection",
      CellTags->{"S1.3.1", "1.118"}]},
  "1.119"->{
    Cell[231937, 12600, 805, 23, 70, "Text",
      CellTags->{"S1.3.1", "1.119"}]},
  "1.120"->{
    Cell[232745, 12625, 824, 28, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.120"}]},
  "1.121"->{
    Cell[233727, 12662, 378, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.121"}]},
  "1.122"->{
    Cell[242886, 13260, 378, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.122"}]},
  "1.123"->{
    Cell[255515, 14080, 643, 23, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.123"}]},
  "1.124"->{
    Cell[256356, 14113, 275, 8, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.124"}]},
  "1.125"->{
    Cell[264418, 14643, 285, 9, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.125"}]},
  "1.126"->{
    Cell[275991, 15397, 543, 14, 70, "Text",
      CellTags->{"S1.3.1", "1.126"}]},
  "1.127"->{
    Cell[276537, 15413, 398, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.127"}]},
  "1.128"->{
    Cell[277116, 15436, 235, 7, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.128"}]},
  "1.129"->{
    Cell[286138, 16011, 355, 13, 70, "MathCaption",
      CellTags->{"S1.3.1", "1.129"}]},
  "1.130"->{
    Cell[299894, 16885, 1920, 57, 70, "Text",
      CellTags->{"S1.3.1", "1.130"}]},
  "S1.3.2"->{
    Cell[301817, 16944, 73, 1, 70, "Subsection",
      CellTags->{"S1.3.2", "2.1"}],
    Cell[301893, 16947, 296, 6, 70, "Text",
      CellTags->{"S1.3.2", "2.2"}],
    Cell[302192, 16955, 71, 1, 70, "Subsubsection",
      CellTags->{"S1.3.2", "2.3"}],
    Cell[302266, 16958, 818, 24, 70, "Text",
      CellTags->{"S1.3.2", "2.4"}],
    Cell[303087, 16984, 592, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.5"}],
    Cell[303682, 17003, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.6"}],
    Cell[303737, 17006, 711, 16, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.7"}],
    Cell[304451, 17024, 1123, 30, 70, "Text",
      CellTags->{"S1.3.2", "2.8"}],
    Cell[305577, 17056, 461, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.9"}],
    Cell[306041, 17067, 440, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.10"}],
    Cell[306484, 17079, 440, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.11"}],
    Cell[306927, 17090, 54, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.12"}],
    Cell[306984, 17093, 780, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.13"}],
    Cell[307767, 17112, 67, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.14"}],
    Cell[307837, 17115, 1145, 25, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.15"}],
    Cell[308985, 17142, 1065, 34, 70, "Text",
      CellTags->{"S1.3.2", "2.16"}],
    Cell[310053, 17178, 295, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.17"}],
    Cell[310351, 17187, 1896, 56, 70, "Text",
      CellTags->{"S1.3.2", "2.18"}],
    Cell[312250, 17245, 476, 10, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.19"}],
    Cell[312729, 17257, 56, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.20"}],
    Cell[312788, 17260, 303, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.21"}],
    Cell[313094, 17269, 555, 15, 70, "Text",
      CellTags->{"S1.3.2", "2.22"}],
    Cell[313652, 17286, 134, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.23"}],
    Cell[313789, 17291, 421, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.24"}],
    Cell[314213, 17305, 186, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.25"}],
    Cell[314402, 17311, 1460, 45, 70, "Text",
      CellTags->{"S1.3.2", "2.26"}],
    Cell[315865, 17358, 282, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.27"}],
    Cell[316150, 17367, 207, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.28"}],
    Cell[316360, 17376, 171, 5, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[316534, 17383, 347, 10, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.29"}],
    Cell[316906, 17397, 217, 7, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[317126, 17406, 2753, 169, 70, 2680, 166, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[319894, 17578, 561, 16, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.30"}],
    Cell[320480, 17598, 283, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[320766, 17608, 3388, 208, 70, 3315, 205, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[324169, 17819, 899, 27, 70, "Text",
      CellTags->{"S1.3.2", "2.31"}],
    Cell[325071, 17848, 573, 18, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.32"}],
    Cell[325669, 17870, 288, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[325960, 17880, 3429, 212, 70, 3356, 209, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[329404, 18095, 60, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.33"}],
    Cell[329467, 18098, 914, 25, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.34"}],
    Cell[330384, 18125, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.35"}],
    Cell[330439, 18128, 1652, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.36"}],
    Cell[332094, 18172, 135, 5, 70, "Text",
      CellTags->{"S1.3.2", "2.37"}],
    Cell[332232, 18179, 145, 5, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.38"}],
    Cell[332402, 18188, 197, 6, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[332602, 18196, 181, 4, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[332798, 18203, 62, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.39"}],
    Cell[332863, 18206, 261, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.40"}],
    Cell[333127, 18219, 334, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.41"}],
    Cell[333464, 18232, 217, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.42"}],
    Cell[333706, 18243, 166, 5, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[333875, 18250, 9227, 615, 70, 9154, 612, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[343117, 18868, 211, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.43"}],
    Cell[343353, 18879, 166, 5, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[343522, 18886, 12467, 831, 70, 12394, 828, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[356004, 19720, 1035, 26, 70, "Text",
      CellTags->{"S1.3.2", "2.44"}],
    Cell[357042, 19748, 1936, 51, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.45"}],
    Cell[358981, 19801, 586, 19, 70, "Text",
      CellTags->{"S1.3.2", "2.46"}],
    Cell[359570, 19822, 176, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.47"}],
    Cell[359749, 19831, 70, 1, 70, "Subsubsection",
      CellTags->{"S1.3.2", "2.48"}],
    Cell[359822, 19834, 613, 15, 70, "Text",
      CellTags->{"S1.3.2", "2.49"}],
    Cell[360438, 19851, 1314, 36, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.50"}],
    Cell[361755, 19889, 202, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.51"}],
    Cell[361960, 19898, 828, 24, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.52"}],
    Cell[362791, 19924, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.53"}],
    Cell[362846, 19927, 132, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.54"}],
    Cell[362981, 19932, 411, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.55"}],
    Cell[363395, 19946, 266, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.56"}],
    Cell[363664, 19954, 348, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.57"}],
    Cell[364015, 19966, 192, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.58"}],
    Cell[364232, 19977, 104, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[364339, 19981, 126, 3, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[364480, 19987, 188, 6, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.59"}],
    Cell[364693, 19997, 86, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[364782, 20001, 83, 3, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[364880, 20007, 213, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.60"}],
    Cell[365096, 20016, 187, 6, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[365286, 20024, 373, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.61"}],
    Cell[365684, 20039, 294, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[365981, 20049, 7984, 499, 70, 7911, 496, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[373980, 20551, 1108, 32, 70, "Text",
      CellTags->{"S1.3.2", "2.62"}],
    Cell[375091, 20585, 387, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.63"}],
    Cell[375481, 20595, 157, 4, 70, "Text",
      CellTags->{"S1.3.2", "2.64"}],
    Cell[375641, 20601, 442, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.65"}],
    Cell[376086, 20612, 785, 22, 70, "Text",
      CellTags->{"S1.3.2", "2.66"}],
    Cell[376874, 20636, 255, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.67"}],
    Cell[377132, 20643, 421, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.68"}],
    Cell[377556, 20657, 360, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.69"}],
    Cell[377941, 20672, 271, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[378215, 20682, 7136, 443, 70, 7063, 440, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[385366, 21128, 365, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.70"}],
    Cell[385734, 21141, 277, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.71"}],
    Cell[386014, 21150, 202, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.72"}],
    Cell[386219, 21159, 570, 11, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.73"}],
    Cell[386792, 21172, 630, 20, 70, "Text",
      CellTags->{"S1.3.2", "2.74"}],
    Cell[387425, 21194, 292, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.75"}],
    Cell[387720, 21202, 578, 18, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.76"}],
    Cell[388323, 21224, 307, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[388633, 21234, 8777, 548, 70, 8704, 545, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[397425, 21785, 295, 9, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.77"}],
    Cell[397745, 21798, 229, 7, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[397977, 21807, 5761, 361, 70, 5688, 358, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[403753, 22171, 218, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.78"}],
    Cell[403974, 22180, 1663, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.79"}],
    Cell[405640, 22224, 155, 4, 70, "Text",
      CellTags->{"S1.3.2", "2.80"}],
    Cell[405798, 22230, 582, 14, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.81"}],
    Cell[406383, 22246, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.82"}],
    Cell[406438, 22249, 1768, 43, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.83"}],
    Cell[408209, 22294, 286, 6, 70, "Text",
      CellTags->{"S1.3.2", "2.84"}],
    Cell[408498, 22302, 469, 23, 70, "Text",
      CellTags->{"S1.3.2", "2.85"}],
    Cell[408970, 22327, 1047, 32, 70, "Text",
      CellTags->{"S1.3.2", "2.86"}],
    Cell[410020, 22361, 476, 16, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.87"}],
    Cell[410521, 22381, 190, 6, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[410714, 22389, 10262, 683, 70, 10189, 680, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[420991, 23075, 327, 8, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.88"}],
    Cell[421343, 23087, 190, 6, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[421536, 23095, 12873, 850, 70, 12800, 847, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[434424, 23948, 424, 14, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.89"}],
    Cell[434851, 23964, 84, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[434938, 23968, 104, 1, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.90"}],
    Cell[435067, 23973, 173, 6, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[435243, 23981, 9892, 659, 70, 9819, 656, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.3.2"],
    Cell[445150, 24643, 339, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.91"}],
    Cell[445492, 24656, 1872, 46, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.92"}],
    Cell[447367, 24704, 713, 21, 70, "Text",
      CellTags->{"S1.3.2", "2.93"}],
    Cell[448083, 24727, 1643, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.94"}],
    Cell[449729, 24771, 150, 5, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.95"}],
    Cell[449904, 24780, 178, 5, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[450085, 24787, 344, 7, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[450444, 24797, 3716, 108, 70, "Text",
      CellTags->{"S1.3.2", "2.96"}],
    Cell[454163, 24907, 598, 21, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.97"}],
    Cell[454764, 24930, 254, 8, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[455021, 24940, 330, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.98"}],
    Cell[455376, 24955, 76, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[455455, 24959, 126, 3, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[455596, 24965, 195, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.99"}],
    Cell[455816, 24976, 76, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[455895, 24980, 143, 4, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[456053, 24987, 262, 8, 70, "Text",
      CellTags->{"S1.3.2", "2.100"}],
    Cell[456318, 24997, 228, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.101"}],
    Cell[456549, 25009, 615, 20, 70, "Text",
      CellTags->{"S1.3.2", "2.102"}],
    Cell[457167, 25031, 300, 10, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.103"}],
    Cell[457492, 25045, 82, 2, 70, "Input",
      CellTags->"S1.3.2"],
    Cell[457577, 25049, 483, 9, 70, "Output",
      CellTags->"S1.3.2"],
    Cell[458075, 25061, 316, 8, 70, "Text",
      CellTags->{"S1.3.2", "2.104"}]},
  "2.1"->{
    Cell[301817, 16944, 73, 1, 70, "Subsection",
      CellTags->{"S1.3.2", "2.1"}]},
  "2.2"->{
    Cell[301893, 16947, 296, 6, 70, "Text",
      CellTags->{"S1.3.2", "2.2"}]},
  "2.3"->{
    Cell[302192, 16955, 71, 1, 70, "Subsubsection",
      CellTags->{"S1.3.2", "2.3"}]},
  "2.4"->{
    Cell[302266, 16958, 818, 24, 70, "Text",
      CellTags->{"S1.3.2", "2.4"}]},
  "2.5"->{
    Cell[303087, 16984, 592, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.5"}]},
  "2.6"->{
    Cell[303682, 17003, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.6"}]},
  "2.7"->{
    Cell[303737, 17006, 711, 16, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.7"}]},
  "2.8"->{
    Cell[304451, 17024, 1123, 30, 70, "Text",
      CellTags->{"S1.3.2", "2.8"}]},
  "2.9"->{
    Cell[305577, 17056, 461, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.9"}]},
  "2.10"->{
    Cell[306041, 17067, 440, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.10"}]},
  "2.11"->{
    Cell[306484, 17079, 440, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.11"}]},
  "2.12"->{
    Cell[306927, 17090, 54, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.12"}]},
  "2.13"->{
    Cell[306984, 17093, 780, 17, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.13"}]},
  "2.14"->{
    Cell[307767, 17112, 67, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.14"}]},
  "2.15"->{
    Cell[307837, 17115, 1145, 25, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.15"}]},
  "2.16"->{
    Cell[308985, 17142, 1065, 34, 70, "Text",
      CellTags->{"S1.3.2", "2.16"}]},
  "2.17"->{
    Cell[310053, 17178, 295, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.17"}]},
  "2.18"->{
    Cell[310351, 17187, 1896, 56, 70, "Text",
      CellTags->{"S1.3.2", "2.18"}]},
  "2.19"->{
    Cell[312250, 17245, 476, 10, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.19"}]},
  "2.20"->{
    Cell[312729, 17257, 56, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.20"}]},
  "2.21"->{
    Cell[312788, 17260, 303, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.21"}]},
  "2.22"->{
    Cell[313094, 17269, 555, 15, 70, "Text",
      CellTags->{"S1.3.2", "2.22"}]},
  "2.23"->{
    Cell[313652, 17286, 134, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.23"}]},
  "2.24"->{
    Cell[313789, 17291, 421, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.24"}]},
  "2.25"->{
    Cell[314213, 17305, 186, 4, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.25"}]},
  "2.26"->{
    Cell[314402, 17311, 1460, 45, 70, "Text",
      CellTags->{"S1.3.2", "2.26"}]},
  "2.27"->{
    Cell[315865, 17358, 282, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.27"}]},
  "2.28"->{
    Cell[316150, 17367, 207, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.28"}]},
  "2.29"->{
    Cell[316534, 17383, 347, 10, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.29"}]},
  "2.30"->{
    Cell[319894, 17578, 561, 16, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.30"}]},
  "2.31"->{
    Cell[324169, 17819, 899, 27, 70, "Text",
      CellTags->{"S1.3.2", "2.31"}]},
  "2.32"->{
    Cell[325071, 17848, 573, 18, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.32"}]},
  "2.33"->{
    Cell[329404, 18095, 60, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.33"}]},
  "2.34"->{
    Cell[329467, 18098, 914, 25, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.34"}]},
  "2.35"->{
    Cell[330384, 18125, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.35"}]},
  "2.36"->{
    Cell[330439, 18128, 1652, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.36"}]},
  "2.37"->{
    Cell[332094, 18172, 135, 5, 70, "Text",
      CellTags->{"S1.3.2", "2.37"}]},
  "2.38"->{
    Cell[332232, 18179, 145, 5, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.38"}]},
  "2.39"->{
    Cell[332798, 18203, 62, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.39"}]},
  "2.40"->{
    Cell[332863, 18206, 261, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.40"}]},
  "2.41"->{
    Cell[333127, 18219, 334, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.41"}]},
  "2.42"->{
    Cell[333464, 18232, 217, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.42"}]},
  "2.43"->{
    Cell[343117, 18868, 211, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.43"}]},
  "2.44"->{
    Cell[356004, 19720, 1035, 26, 70, "Text",
      CellTags->{"S1.3.2", "2.44"}]},
  "2.45"->{
    Cell[357042, 19748, 1936, 51, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.45"}]},
  "2.46"->{
    Cell[358981, 19801, 586, 19, 70, "Text",
      CellTags->{"S1.3.2", "2.46"}]},
  "2.47"->{
    Cell[359570, 19822, 176, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.47"}]},
  "2.48"->{
    Cell[359749, 19831, 70, 1, 70, "Subsubsection",
      CellTags->{"S1.3.2", "2.48"}]},
  "2.49"->{
    Cell[359822, 19834, 613, 15, 70, "Text",
      CellTags->{"S1.3.2", "2.49"}]},
  "2.50"->{
    Cell[360438, 19851, 1314, 36, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.50"}]},
  "2.51"->{
    Cell[361755, 19889, 202, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.51"}]},
  "2.52"->{
    Cell[361960, 19898, 828, 24, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.52"}]},
  "2.53"->{
    Cell[362791, 19924, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.53"}]},
  "2.54"->{
    Cell[362846, 19927, 132, 3, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.54"}]},
  "2.55"->{
    Cell[362981, 19932, 411, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.55"}]},
  "2.56"->{
    Cell[363395, 19946, 266, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.56"}]},
  "2.57"->{
    Cell[363664, 19954, 348, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.57"}]},
  "2.58"->{
    Cell[364015, 19966, 192, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.58"}]},
  "2.59"->{
    Cell[364480, 19987, 188, 6, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.59"}]},
  "2.60"->{
    Cell[364880, 20007, 213, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.60"}]},
  "2.61"->{
    Cell[365286, 20024, 373, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.61"}]},
  "2.62"->{
    Cell[373980, 20551, 1108, 32, 70, "Text",
      CellTags->{"S1.3.2", "2.62"}]},
  "2.63"->{
    Cell[375091, 20585, 387, 8, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.63"}]},
  "2.64"->{
    Cell[375481, 20595, 157, 4, 70, "Text",
      CellTags->{"S1.3.2", "2.64"}]},
  "2.65"->{
    Cell[375641, 20601, 442, 9, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.65"}]},
  "2.66"->{
    Cell[376086, 20612, 785, 22, 70, "Text",
      CellTags->{"S1.3.2", "2.66"}]},
  "2.67"->{
    Cell[376874, 20636, 255, 5, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.67"}]},
  "2.68"->{
    Cell[377132, 20643, 421, 12, 70, "Text",
      CellTags->{"S1.3.2", "2.68"}]},
  "2.69"->{
    Cell[377556, 20657, 360, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.69"}]},
  "2.70"->{
    Cell[385366, 21128, 365, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.70"}]},
  "2.71"->{
    Cell[385734, 21141, 277, 7, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.71"}]},
  "2.72"->{
    Cell[386014, 21150, 202, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.72"}]},
  "2.73"->{
    Cell[386219, 21159, 570, 11, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.73"}]},
  "2.74"->{
    Cell[386792, 21172, 630, 20, 70, "Text",
      CellTags->{"S1.3.2", "2.74"}]},
  "2.75"->{
    Cell[387425, 21194, 292, 6, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.75"}]},
  "2.76"->{
    Cell[387720, 21202, 578, 18, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.76"}]},
  "2.77"->{
    Cell[397425, 21785, 295, 9, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.77"}]},
  "2.78"->{
    Cell[403753, 22171, 218, 7, 70, "Text",
      CellTags->{"S1.3.2", "2.78"}]},
  "2.79"->{
    Cell[403974, 22180, 1663, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.79"}]},
  "2.80"->{
    Cell[405640, 22224, 155, 4, 70, "Text",
      CellTags->{"S1.3.2", "2.80"}]},
  "2.81"->{
    Cell[405798, 22230, 582, 14, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.81"}]},
  "2.82"->{
    Cell[406383, 22246, 52, 1, 70, "Text",
      CellTags->{"S1.3.2", "2.82"}]},
  "2.83"->{
    Cell[406438, 22249, 1768, 43, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.83"}]},
  "2.84"->{
    Cell[408209, 22294, 286, 6, 70, "Text",
      CellTags->{"S1.3.2", "2.84"}]},
  "2.85"->{
    Cell[408498, 22302, 469, 23, 70, "Text",
      CellTags->{"S1.3.2", "2.85"}]},
  "2.86"->{
    Cell[408970, 22327, 1047, 32, 70, "Text",
      CellTags->{"S1.3.2", "2.86"}]},
  "2.87"->{
    Cell[410020, 22361, 476, 16, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.87"}]},
  "2.88"->{
    Cell[420991, 23075, 327, 8, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.88"}]},
  "2.89"->{
    Cell[434424, 23948, 424, 14, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.89"}]},
  "2.90"->{
    Cell[434938, 23968, 104, 1, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.90"}]},
  "2.91"->{
    Cell[445150, 24643, 339, 11, 70, "Text",
      CellTags->{"S1.3.2", "2.91"}]},
  "2.92"->{
    Cell[445492, 24656, 1872, 46, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.92"}]},
  "2.93"->{
    Cell[447367, 24704, 713, 21, 70, "Text",
      CellTags->{"S1.3.2", "2.93"}]},
  "2.94"->{
    Cell[448083, 24727, 1643, 42, 70, "DisplayFormula",
      CellTags->{"S1.3.2", "2.94"}]},
  "2.95"->{
    Cell[449729, 24771, 150, 5, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.95"}]},
  "2.96"->{
    Cell[450444, 24797, 3716, 108, 70, "Text",
      CellTags->{"S1.3.2", "2.96"}]},
  "2.97"->{
    Cell[454163, 24907, 598, 21, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.97"}]},
  "2.98"->{
    Cell[455021, 24940, 330, 11, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.98"}]},
  "2.99"->{
    Cell[455596, 24965, 195, 7, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.99"}]},
  "2.100"->{
    Cell[456053, 24987, 262, 8, 70, "Text",
      CellTags->{"S1.3.2", "2.100"}]},
  "2.101"->{
    Cell[456318, 24997, 228, 10, 70, "Text",
      CellTags->{"S1.3.2", "2.101"}]},
  "2.102"->{
    Cell[456549, 25009, 615, 20, 70, "Text",
      CellTags->{"S1.3.2", "2.102"}]},
  "2.103"->{
    Cell[457167, 25031, 300, 10, 70, "MathCaption",
      CellTags->{"S1.3.2", "2.103"}]},
  "2.104"->{
    Cell[458075, 25061, 316, 8, 70, "Text",
      CellTags->{"S1.3.2", "2.104"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 459053, 25089},
  {"S1.3.0", 459211, 25094},
  {"0.1", 459539, 25103},
  {"0.2", 459628, 25106},
  {"0.3", 459716, 25109},
  {"0.4", 459813, 25112},
  {"S1.3.1", 459906, 25115},
  {"1.1", 476666, 25528},
  {"1.2", 476759, 25531},
  {"1.3", 476850, 25534},
  {"1.4", 476946, 25537},
  {"1.5", 477038, 25540},
  {"1.6", 477137, 25543},
  {"1.7", 477227, 25546},
  {"1.8", 477328, 25549},
  {"1.9", 477418, 25552},
  {"1.10", 477519, 25555},
  {"1.11", 477614, 25558},
  {"1.12", 477718, 25561},
  {"1.13", 477810, 25564},
  {"1.14", 477902, 25567},
  {"1.15", 477993, 25570},
  {"1.16", 478090, 25573},
  {"1.17", 478189, 25576},
  {"1.18", 478283, 25579},
  {"1.19", 478382, 25582},
  {"1.20", 478481, 25585},
  {"1.21", 478581, 25588},
  {"1.22", 478677, 25591},
  {"1.23", 478782, 25594},
  {"1.24", 478874, 25597},
  {"1.25", 478976, 25600},
  {"1.26", 479068, 25603},
  {"1.27", 479170, 25606},
  {"1.28", 479263, 25609},
  {"1.29", 479362, 25612},
  {"1.30", 479455, 25615},
  {"1.31", 479554, 25618},
  {"1.32", 479653, 25621},
  {"1.33", 479755, 25624},
  {"1.34", 479851, 25627},
  {"1.35", 479955, 25630},
  {"1.36", 480049, 25633},
  {"1.37", 480152, 25636},
  {"1.38", 480248, 25639},
  {"1.39", 480353, 25642},
  {"1.40", 480446, 25645},
  {"1.41", 480549, 25648},
  {"1.42", 480641, 25651},
  {"1.43", 480744, 25654},
  {"1.44", 480838, 25657},
  {"1.45", 480938, 25660},
  {"1.46", 481030, 25663},
  {"1.47", 481133, 25666},
  {"1.48", 481227, 25669},
  {"1.49", 481331, 25672},
  {"1.50", 481426, 25675},
  {"1.51", 481529, 25678},
  {"1.52", 481625, 25681},
  {"1.53", 481726, 25684},
  {"1.54", 481827, 25687},
  {"1.55", 481922, 25690},
  {"1.56", 482021, 25693},
  {"1.57", 482122, 25696},
  {"1.58", 482217, 25699},
  {"1.59", 482317, 25702},
  {"1.60", 482417, 25705},
  {"1.61", 482513, 25708},
  {"1.62", 482607, 25711},
  {"1.63", 482701, 25714},
  {"1.64", 482801, 25717},
  {"1.65", 482900, 25720},
  {"1.66", 482993, 25723},
  {"1.67", 483087, 25726},
  {"1.68", 483182, 25729},
  {"1.69", 483282, 25732},
  {"1.70", 483383, 25735},
  {"1.71", 483484, 25738},
  {"1.72", 483585, 25741},
  {"1.73", 483686, 25744},
  {"1.74", 483788, 25747},
  {"1.75", 483884, 25750},
  {"1.76", 483988, 25753},
  {"1.77", 484083, 25756},
  {"1.78", 484187, 25759},
  {"1.79", 484281, 25762},
  {"1.80", 484385, 25765},
  {"1.81", 484481, 25768},
  {"1.82", 484585, 25771},
  {"1.83", 484681, 25774},
  {"1.84", 484785, 25777},
  {"1.85", 484880, 25780},
  {"1.86", 484985, 25783},
  {"1.87", 485080, 25786},
  {"1.88", 485184, 25789},
  {"1.89", 485278, 25792},
  {"1.90", 485382, 25795},
  {"1.91", 485476, 25798},
  {"1.92", 485582, 25801},
  {"1.93", 485677, 25804},
  {"1.94", 485781, 25807},
  {"1.95", 485875, 25810},
  {"1.96", 485970, 25813},
  {"1.97", 486066, 25816},
  {"1.98", 486168, 25819},
  {"1.99", 486264, 25822},
  {"1.100", 486369, 25825},
  {"1.101", 486464, 25828},
  {"1.102", 486570, 25831},
  {"1.103", 486665, 25834},
  {"1.104", 486771, 25837},
  {"1.105", 486866, 25840},
  {"1.106", 486972, 25843},
  {"1.107", 487068, 25846},
  {"1.108", 487174, 25849},
  {"1.109", 487269, 25852},
  {"1.110", 487376, 25855},
  {"1.111", 487474, 25858},
  {"1.112", 487571, 25861},
  {"1.113", 487669, 25864},
  {"1.114", 487772, 25867},
  {"1.115", 487869, 25870},
  {"1.116", 487972, 25873},
  {"1.117", 488076, 25876},
  {"1.118", 488172, 25879},
  {"1.119", 488278, 25882},
  {"1.120", 488375, 25885},
  {"1.121", 488479, 25888},
  {"1.122", 488583, 25891},
  {"1.123", 488687, 25894},
  {"1.124", 488791, 25897},
  {"1.125", 488894, 25900},
  {"1.126", 488997, 25903},
  {"1.127", 489094, 25906},
  {"1.128", 489198, 25909},
  {"1.129", 489301, 25912},
  {"1.130", 489405, 25915},
  {"S1.3.2", 489504, 25918},
  {"2.1", 502496, 26235},
  {"2.2", 502593, 26238},
  {"2.3", 502685, 26241},
  {"2.4", 502785, 26244},
  {"2.5", 502878, 26247},
  {"2.6", 502981, 26250},
  {"2.7", 503072, 26253},
  {"2.8", 503175, 26256},
  {"2.9", 503269, 26259},
  {"2.10", 503372, 26262},
  {"2.11", 503467, 26265},
  {"2.12", 503571, 26268},
  {"2.13", 503664, 26271},
  {"2.14", 503769, 26274},
  {"2.15", 503862, 26277},
  {"2.16", 503968, 26280},
  {"2.17", 504064, 26283},
  {"2.18", 504168, 26286},
  {"2.19", 504264, 26289},
  {"2.20", 504369, 26292},
  {"2.21", 504462, 26295},
  {"2.22", 504566, 26298},
  {"2.23", 504661, 26301},
  {"2.24", 504765, 26304},
  {"2.25", 504860, 26307},
  {"2.26", 504964, 26310},
  {"2.27", 505060, 26313},
  {"2.28", 505164, 26316},
  {"2.29", 505265, 26319},
  {"2.30", 505367, 26322},
  {"2.31", 505469, 26325},
  {"2.32", 505564, 26328},
  {"2.33", 505666, 26331},
  {"2.34", 505759, 26334},
  {"2.35", 505864, 26337},
  {"2.36", 505957, 26340},
  {"2.37", 506063, 26343},
  {"2.38", 506157, 26346},
  {"2.39", 506258, 26349},
  {"2.40", 506351, 26352},
  {"2.41", 506446, 26355},
  {"2.42", 506541, 26358},
  {"2.43", 506642, 26361},
  {"2.44", 506743, 26364},
  {"2.45", 506839, 26367},
  {"2.46", 506945, 26370},
  {"2.47", 507040, 26373},
  {"2.48", 507134, 26376},
  {"2.49", 507236, 26379},
  {"2.50", 507331, 26382},
  {"2.51", 507437, 26385},
  {"2.52", 507531, 26388},
  {"2.53", 507636, 26391},
  {"2.54", 507729, 26394},
  {"2.55", 507833, 26397},
  {"2.56", 507928, 26400},
  {"2.57", 508032, 26403},
  {"2.58", 508127, 26406},
  {"2.59", 508228, 26409},
  {"2.60", 508329, 26412},
  {"2.61", 508430, 26415},
  {"2.62", 508532, 26418},
  {"2.63", 508628, 26421},
  {"2.64", 508732, 26424},
  {"2.65", 508826, 26427},
  {"2.66", 508930, 26430},
  {"2.67", 509025, 26433},
  {"2.68", 509129, 26436},
  {"2.69", 509224, 26439},
  {"2.70", 509326, 26442},
  {"2.71", 509421, 26445},
  {"2.72", 509525, 26448},
  {"2.73", 509619, 26451},
  {"2.74", 509724, 26454},
  {"2.75", 509819, 26457},
  {"2.76", 509923, 26460},
  {"2.77", 510025, 26463},
  {"2.78", 510126, 26466},
  {"2.79", 510220, 26469},
  {"2.80", 510326, 26472},
  {"2.81", 510420, 26475},
  {"2.82", 510525, 26478},
  {"2.83", 510618, 26481},
  {"2.84", 510724, 26484},
  {"2.85", 510818, 26487},
  {"2.86", 510913, 26490},
  {"2.87", 511009, 26493},
  {"2.88", 511111, 26496},
  {"2.89", 511212, 26499},
  {"2.90", 511314, 26502},
  {"2.91", 511415, 26505},
  {"2.92", 511510, 26508},
  {"2.93", 511616, 26511},
  {"2.94", 511711, 26514},
  {"2.95", 511817, 26517},
  {"2.96", 511918, 26520},
  {"2.97", 512015, 26523},
  {"2.98", 512117, 26526},
  {"2.99", 512219, 26529},
  {"2.100", 512321, 26532},
  {"2.101", 512417, 26535},
  {"2.102", 512514, 26538},
  {"2.103", 512611, 26541},
  {"2.104", 512715, 26544}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 66, 1, 56, "Section",
  CellTags->"Contents"],
Cell[1786, 52, 409, 14, 76, "Contents",
  CellTags->"Contents"],
Cell[2198, 68, 73, 1, 56, "Section",
  CellTags->{"S1.3.0", "0.1"}],
Cell[2274, 71, 589, 14, 60, "Text",
  CellTags->{"S1.3.0", "0.2"}],
Cell[2866, 87, 176, 4, 34, "DisplayFormula",
  CellTags->{"S1.3.0", "0.3"}],
Cell[3045, 93, 3569, 81, 398, "Text",
  CellTags->{"S1.3.0", "0.4"}],
Cell[6617, 176, 98, 1, 39, "Subsection",
  CellTags->{"S1.3.1", "1.1"}],
Cell[6718, 179, 1011, 17, 161, "Text",
  CellTags->{"S1.3.1", "1.2"}],
Cell[7732, 198, 72, 1, 35, "Subsubsection",
  CellTags->{"S1.3.1", "1.3"}],
Cell[7807, 201, 4568, 132, 288, "Text",
  CellTags->{"S1.3.1", "1.4"}],
Cell[12378, 335, 383, 8, 45, "DisplayFormula",
  CellTags->{"S1.3.1", "1.5"}],
Cell[12764, 345, 777, 23, 42, "Text",
  CellTags->{"S1.3.1", "1.6"}],
Cell[13544, 370, 1530, 44, 65, "DisplayFormula",
  CellTags->{"S1.3.1", "1.7"}],
Cell[15077, 416, 754, 21, 59, "Text",
  CellTags->{"S1.3.1", "1.8"}],
Cell[15834, 439, 774, 21, 47, "DisplayFormula",
  CellTags->{"S1.3.1", "1.9"}],
Cell[16611, 462, 3370, 112, 135, "Text",
  CellTags->{"S1.3.1", "1.10"}],
Cell[19984, 576, 2186, 52, 127, "DisplayFormula",
  CellTags->{"S1.3.1", "1.11"}],
Cell[22173, 630, 511, 17, 42, "Text",
  CellTags->{"S1.3.1", "1.12"}],
Cell[22687, 649, 219, 10, 25, "Text",
  CellTags->{"S1.3.1", "1.13"}],
Cell[22909, 661, 193, 7, 25, "Text",
  CellTags->{"S1.3.1", "1.14"}],
Cell[23105, 670, 78, 1, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.15"}],
Cell[23186, 673, 93, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[23282, 677, 458, 14, 48, "MathCaption",
  CellTags->{"S1.3.1", "1.16"}],

Cell[CellGroupData[{
Cell[23765, 695, 169, 5, 51, "Input",
  CellTags->"S1.3.1"],
Cell[23937, 702, 8348, 559, 186, 8275, 556, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[32300, 1264, 1485, 43, 76, "Text",
  CellTags->{"S1.3.1", "1.17"}],
Cell[33788, 1309, 218, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.18"}],

Cell[CellGroupData[{
Cell[34031, 1320, 224, 6, 71, "Input",
  CellTags->"S1.3.1"],
Cell[34258, 1328, 16551, 1080, 186, 16478, 1077, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[50824, 2411, 166, 5, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.19"}],

Cell[CellGroupData[{
Cell[51015, 2420, 135, 5, 51, "Input",
  CellTags->"S1.3.1"],
Cell[51153, 2427, 102, 3, 23, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[51270, 2433, 88, 1, 35, "Subsubsection",
  CellTags->{"S1.3.1", "1.20"}],
Cell[51361, 2436, 4364, 127, 230, "Text",
  CellTags->{"S1.3.1", "1.21"}],
Cell[55728, 2565, 2125, 52, 127, "DisplayFormula",
  CellTags->{"S1.3.1", "1.22"}],
Cell[57856, 2619, 189, 7, 25, "Text",
  CellTags->{"S1.3.1", "1.23"}],
Cell[58048, 2628, 265, 5, 47, "DisplayFormula",
  CellTags->{"S1.3.1", "1.24"}],
Cell[58316, 2635, 173, 7, 25, "Text",
  CellTags->{"S1.3.1", "1.25"}],
Cell[58492, 2644, 308, 6, 47, "DisplayFormula",
  CellTags->{"S1.3.1", "1.26"}],
Cell[58803, 2652, 960, 31, 59, "Text",
  CellTags->{"S1.3.1", "1.27"}],
Cell[59766, 2685, 261, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.28"}],
Cell[60030, 2694, 382, 9, 131, "Input",
  CellTags->"S1.3.1"],
Cell[60415, 2705, 704, 19, 59, "Text",
  CellTags->{"S1.3.1", "1.29"}],
Cell[61122, 2726, 234, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.30"}],

Cell[CellGroupData[{
Cell[61381, 2737, 83, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[61467, 2741, 23714, 1539, 186, 23641, 1536, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[85196, 4283, 234, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.31"}],

Cell[CellGroupData[{
Cell[85455, 4294, 83, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[85541, 4298, 31469, 2036, 186, 31396, 2033, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[117025, 6337, 218, 7, 35, "Subsubsection",
  CellTags->{"S1.3.1", "1.32"}],
Cell[117246, 6346, 1389, 40, 101, "Text",
  CellTags->{"S1.3.1", "1.33"}],
Cell[118638, 6388, 707, 16, 49, "DisplayFormula",
  CellTags->{"S1.3.1", "1.34"}],
Cell[119348, 6406, 958, 31, 42, "Text",
  CellTags->{"S1.3.1", "1.35"}],
Cell[120309, 6439, 341, 8, 50, "DisplayFormula",
  CellTags->{"S1.3.1", "1.36"}],
Cell[120653, 6449, 1814, 55, 101, "Text",
  CellTags->{"S1.3.1", "1.37"}],
Cell[122470, 6506, 692, 14, 105, "DisplayFormula",
  CellTags->{"S1.3.1", "1.38"}],
Cell[123165, 6522, 101, 1, 25, "Text",
  CellTags->{"S1.3.1", "1.39"}],
Cell[123269, 6525, 296, 6, 57, "DisplayFormula",
  CellTags->{"S1.3.1", "1.40"}],
Cell[123568, 6533, 82, 1, 25, "Text",
  CellTags->{"S1.3.1", "1.41"}],
Cell[123653, 6536, 286, 6, 51, "DisplayFormula",
  CellTags->{"S1.3.1", "1.42"}],
Cell[123942, 6544, 264, 10, 25, "Text",
  CellTags->{"S1.3.1", "1.43"}],
Cell[124209, 6556, 217, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.44"}],

Cell[CellGroupData[{
Cell[124451, 6567, 108, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[124562, 6571, 99, 3, 36, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[124676, 6577, 59, 1, 25, "Text",
  CellTags->{"S1.3.1", "1.45"}],
Cell[124738, 6580, 175, 4, 49, "DisplayFormula",
  CellTags->{"S1.3.1", "1.46"}],
Cell[124916, 6586, 374, 11, 42, "Text",
  CellTags->{"S1.3.1", "1.47"}],
Cell[125293, 6599, 486, 10, 61, "DisplayFormula",
  CellTags->{"S1.3.1", "1.48"}],
Cell[125782, 6611, 1054, 33, 60, "Text",
  CellTags->{"S1.3.1", "1.49"}],
Cell[126839, 6646, 257, 6, 45, "DisplayFormula",
  CellTags->{"S1.3.1", "1.50"}],
Cell[127099, 6654, 2328, 64, 194, "Text",
  CellTags->{"S1.3.1", "1.51"}],
Cell[129430, 6720, 381, 15, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.52"}],
Cell[129814, 6737, 199, 7, 91, "Input",
  CellTags->"S1.3.1"],
Cell[130016, 6746, 305, 11, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.53"}],

Cell[CellGroupData[{
Cell[130346, 6761, 127, 5, 51, "Input",
  CellTags->"S1.3.1"],
Cell[130476, 6768, 107, 3, 36, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[130598, 6774, 1488, 51, 93, "Text",
  CellTags->{"S1.3.1", "1.54"}],
Cell[132089, 6827, 96, 1, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.55"}],
Cell[132188, 6830, 102, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[132293, 6834, 569, 18, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.56"}],

Cell[CellGroupData[{
Cell[132887, 6856, 308, 11, 171, "Input",
  CellTags->"S1.3.1"],
Cell[133198, 6869, 318, 6, 42, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[133531, 6878, 1353, 44, 59, "Text",
  CellTags->{"S1.3.1", "1.57"}],
Cell[134887, 6924, 221, 7, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.58"}],

Cell[CellGroupData[{
Cell[135133, 6935, 266, 7, 91, "Input",
  CellTags->"S1.3.1"],
Cell[135402, 6944, 8761, 672, 186, 8688, 669, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[144178, 7619, 330, 8, 48, "MathCaption",
  CellTags->{"S1.3.1", "1.59"}],

Cell[CellGroupData[{
Cell[144533, 7631, 172, 6, 71, "Input",
  CellTags->"S1.3.1"],
Cell[144708, 7639, 9668, 730, 186, 9595, 727, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[154391, 8372, 1123, 31, 101, "Text",
  CellTags->{"S1.3.1", "1.60"}],
Cell[155517, 8405, 277, 13, 25, "Text",
  CellTags->{"S1.3.1", "1.61"}],
Cell[155797, 8420, 652, 20, 25, "Text",
  CellTags->{"S1.3.1", "1.62"}],
Cell[156452, 8442, 139, 4, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.63"}],
Cell[156594, 8448, 84, 2, 31, "Input",
  CellTags->"S1.3.1"],
Cell[156681, 8452, 76, 1, 31, "MathCaption",
  CellTags->{"S1.3.1", "1.64"}],

Cell[CellGroupData[{
Cell[156782, 8457, 195, 6, 71, "Input",
  CellTags->"S1.3.1"],
Cell[156980, 8465, 10939, 781, 70, 10866, 778, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[167934, 9249, 340, 6, 70, "Text",
  CellTags->{"S1.3.1", "1.65"}],
Cell[168277, 9257, 276, 13, 70, "Text",
  CellTags->{"S1.3.1", "1.66"}],
Cell[168556, 9272, 1026, 32, 70, "Text",
  CellTags->{"S1.3.1", "1.67"}],
Cell[169585, 9306, 279, 9, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.68"}],
Cell[169867, 9317, 99, 2, 70, "Input",
  CellTags->"S1.3.1"],
Cell[169969, 9321, 263, 10, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.69"}],

Cell[CellGroupData[{
Cell[170257, 9335, 80, 2, 70, "Input",
  CellTags->"S1.3.1"],
Cell[170340, 9339, 84, 3, 70, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[170439, 9345, 700, 21, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.70"}],

Cell[CellGroupData[{
Cell[171164, 9370, 233, 7, 70, "Input",
  CellTags->"S1.3.1"],
Cell[171400, 9379, 15469, 981, 70, 15396, 978, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[186884, 10363, 333, 7, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.71"}],

Cell[CellGroupData[{
Cell[187242, 10374, 116, 2, 70, "Input",
  CellTags->"S1.3.1"],
Cell[187361, 10378, 111, 3, 70, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[187487, 10384, 130, 4, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.72"}],

Cell[CellGroupData[{
Cell[187642, 10392, 163, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[187808, 10399, 106, 3, 70, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[187929, 10405, 84, 1, 70, "Subsubsection",
  CellTags->{"S1.3.1", "1.73"}],
Cell[188016, 10408, 1079, 31, 70, "Text",
  CellTags->{"S1.3.1", "1.74"}],
Cell[189098, 10441, 366, 8, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.75"}],
Cell[189467, 10451, 483, 16, 70, "Text",
  CellTags->{"S1.3.1", "1.76"}],
Cell[189953, 10469, 134, 3, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.77"}],
Cell[190090, 10474, 216, 6, 70, "Text",
  CellTags->{"S1.3.1", "1.78"}],
Cell[190309, 10482, 269, 6, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.79"}],
Cell[190581, 10490, 1116, 26, 70, "Text",
  CellTags->{"S1.3.1", "1.80"}],
Cell[191700, 10518, 187, 4, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.81"}],
Cell[191890, 10524, 1289, 39, 70, "Text",
  CellTags->{"S1.3.1", "1.82"}],
Cell[193182, 10565, 209, 4, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.83"}],
Cell[193394, 10571, 354, 12, 70, "Text",
  CellTags->{"S1.3.1", "1.84"}],
Cell[193751, 10585, 485, 10, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.85"}],
Cell[194239, 10597, 366, 11, 70, "Text",
  CellTags->{"S1.3.1", "1.86"}],
Cell[194608, 10610, 189, 4, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.87"}],
Cell[194800, 10616, 249, 7, 70, "Text",
  CellTags->{"S1.3.1", "1.88"}],
Cell[195052, 10625, 330, 6, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.89"}],
Cell[195385, 10633, 234, 7, 70, "Text",
  CellTags->{"S1.3.1", "1.90"}],
Cell[195622, 10642, 1621, 38, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.91"}],
Cell[197246, 10682, 352, 11, 70, "Text",
  CellTags->{"S1.3.1", "1.92"}],
Cell[197601, 10695, 347, 9, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.93"}],
Cell[197951, 10706, 257, 7, 70, "Text",
  CellTags->{"S1.3.1", "1.94"}],
Cell[198211, 10715, 228, 10, 70, "Text",
  CellTags->{"S1.3.1", "1.95"}],
Cell[198442, 10727, 1192, 42, 70, "Text",
  CellTags->{"S1.3.1", "1.96"}],
Cell[199637, 10771, 501, 15, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.97"}],

Cell[CellGroupData[{
Cell[200163, 10790, 83, 2, 70, "Input",
  CellTags->"S1.3.1"],
Cell[200249, 10794, 359, 7, 70, "Output",
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[200623, 10804, 1274, 31, 70, "Text",
  CellTags->{"S1.3.1", "1.98"}],
Cell[201900, 10837, 393, 8, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.99"}],
Cell[202296, 10847, 62, 1, 70, "Text",
  CellTags->{"S1.3.1", "1.100"}],
Cell[202361, 10850, 220, 5, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.101"}],
Cell[202584, 10857, 49, 1, 70, "Text",
  CellTags->{"S1.3.1", "1.102"}],
Cell[202636, 10860, 212, 4, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.103"}],
Cell[202851, 10866, 53, 1, 70, "Text",
  CellTags->{"S1.3.1", "1.104"}],
Cell[202907, 10869, 221, 5, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.105"}],
Cell[203131, 10876, 232, 7, 70, "Text",
  CellTags->{"S1.3.1", "1.106"}],
Cell[203366, 10885, 298, 6, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.107"}],
Cell[203667, 10893, 91, 1, 70, "Text",
  CellTags->{"S1.3.1", "1.108"}],
Cell[203761, 10896, 717, 17, 70, "DisplayFormula",
  CellTags->{"S1.3.1", "1.109"}],
Cell[204481, 10915, 1281, 40, 70, "Text",
  CellTags->{"S1.3.1", "1.110"}],
Cell[205765, 10957, 278, 13, 70, "Text",
  CellTags->{"S1.3.1", "1.111"}],
Cell[206046, 10972, 1574, 55, 70, "Text",
  CellTags->{"S1.3.1", "1.112"}],
Cell[207623, 11029, 245, 7, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.113"}],

Cell[CellGroupData[{
Cell[207893, 11040, 189, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[208085, 11048, 4958, 345, 70, 4885, 342, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[213058, 11396, 570, 12, 70, "Text",
  CellTags->{"S1.3.1", "1.114"}],
Cell[213631, 11410, 210, 7, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.115"}],

Cell[CellGroupData[{
Cell[213866, 11421, 173, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[214042, 11428, 9417, 628, 70, 9344, 625, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[223474, 12059, 346, 11, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.116"}],

Cell[CellGroupData[{
Cell[223845, 12074, 189, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[224037, 12082, 7298, 493, 70, 7225, 490, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[231350, 12578, 291, 8, 70, "Text",
  CellTags->{"S1.3.1", "1.117"}],
Cell[231644, 12588, 290, 10, 70, "Subsubsection",
  CellTags->{"S1.3.1", "1.118"}],
Cell[231937, 12600, 805, 23, 70, "Text",
  CellTags->{"S1.3.1", "1.119"}],
Cell[232745, 12625, 824, 28, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.120"}],
Cell[233572, 12655, 152, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[233727, 12662, 378, 13, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.121"}],

Cell[CellGroupData[{
Cell[234130, 12679, 180, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[234313, 12686, 8558, 571, 70, 8485, 568, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[242886, 13260, 378, 13, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.122"}],

Cell[CellGroupData[{
Cell[243289, 13277, 180, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[243472, 13284, 12028, 793, 70, 11955, 790, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[255515, 14080, 643, 23, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.123"}],
Cell[256161, 14105, 192, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[256356, 14113, 275, 8, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.124"}],

Cell[CellGroupData[{
Cell[256656, 14125, 180, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[256839, 14132, 7564, 508, 70, 7491, 505, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[264418, 14643, 285, 9, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.125"}],

Cell[CellGroupData[{
Cell[264728, 14656, 180, 5, 70, "Input",
  CellTags->"S1.3.1"],
Cell[264911, 14663, 11065, 731, 70, 10992, 728, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[275991, 15397, 543, 14, 70, "Text",
  CellTags->{"S1.3.1", "1.126"}],
Cell[276537, 15413, 398, 13, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.127"}],
Cell[276938, 15428, 175, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[277116, 15436, 235, 7, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.128"}],

Cell[CellGroupData[{
Cell[277376, 15447, 202, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[277581, 15455, 8542, 553, 70, 8469, 550, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[286138, 16011, 355, 13, 70, "MathCaption",
  CellTags->{"S1.3.1", "1.129"}],

Cell[CellGroupData[{
Cell[286518, 16028, 202, 6, 70, "Input",
  CellTags->"S1.3.1"],
Cell[286723, 16036, 13156, 846, 70, 13083, 843, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.1"]
}, Open  ]],
Cell[299894, 16885, 1920, 57, 70, "Text",
  CellTags->{"S1.3.1", "1.130"}],
Cell[301817, 16944, 73, 1, 70, "Subsection",
  CellTags->{"S1.3.2", "2.1"}],
Cell[301893, 16947, 296, 6, 70, "Text",
  CellTags->{"S1.3.2", "2.2"}],
Cell[302192, 16955, 71, 1, 70, "Subsubsection",
  CellTags->{"S1.3.2", "2.3"}],
Cell[302266, 16958, 818, 24, 70, "Text",
  CellTags->{"S1.3.2", "2.4"}],
Cell[303087, 16984, 592, 17, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.5"}],
Cell[303682, 17003, 52, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.6"}],
Cell[303737, 17006, 711, 16, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.7"}],
Cell[304451, 17024, 1123, 30, 70, "Text",
  CellTags->{"S1.3.2", "2.8"}],
Cell[305577, 17056, 461, 9, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.9"}],
Cell[306041, 17067, 440, 10, 70, "Text",
  CellTags->{"S1.3.2", "2.10"}],
Cell[306484, 17079, 440, 9, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.11"}],
Cell[306927, 17090, 54, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.12"}],
Cell[306984, 17093, 780, 17, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.13"}],
Cell[307767, 17112, 67, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.14"}],
Cell[307837, 17115, 1145, 25, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.15"}],
Cell[308985, 17142, 1065, 34, 70, "Text",
  CellTags->{"S1.3.2", "2.16"}],
Cell[310053, 17178, 295, 7, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.17"}],
Cell[310351, 17187, 1896, 56, 70, "Text",
  CellTags->{"S1.3.2", "2.18"}],
Cell[312250, 17245, 476, 10, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.19"}],
Cell[312729, 17257, 56, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.20"}],
Cell[312788, 17260, 303, 7, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.21"}],
Cell[313094, 17269, 555, 15, 70, "Text",
  CellTags->{"S1.3.2", "2.22"}],
Cell[313652, 17286, 134, 3, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.23"}],
Cell[313789, 17291, 421, 12, 70, "Text",
  CellTags->{"S1.3.2", "2.24"}],
Cell[314213, 17305, 186, 4, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.25"}],
Cell[314402, 17311, 1460, 45, 70, "Text",
  CellTags->{"S1.3.2", "2.26"}],
Cell[315865, 17358, 282, 7, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.27"}],
Cell[316150, 17367, 207, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.28"}],
Cell[316360, 17376, 171, 5, 70, "Input",
  CellTags->"S1.3.2"],
Cell[316534, 17383, 347, 10, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.29"}],

Cell[CellGroupData[{
Cell[316906, 17397, 217, 7, 70, "Input",
  CellTags->"S1.3.2"],
Cell[317126, 17406, 2753, 169, 70, 2680, 166, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[319894, 17578, 561, 16, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.30"}],

Cell[CellGroupData[{
Cell[320480, 17598, 283, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[320766, 17608, 3388, 208, 70, 3315, 205, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[324169, 17819, 899, 27, 70, "Text",
  CellTags->{"S1.3.2", "2.31"}],
Cell[325071, 17848, 573, 18, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.32"}],

Cell[CellGroupData[{
Cell[325669, 17870, 288, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[325960, 17880, 3429, 212, 70, 3356, 209, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[329404, 18095, 60, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.33"}],
Cell[329467, 18098, 914, 25, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.34"}],
Cell[330384, 18125, 52, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.35"}],
Cell[330439, 18128, 1652, 42, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.36"}],
Cell[332094, 18172, 135, 5, 70, "Text",
  CellTags->{"S1.3.2", "2.37"}],
Cell[332232, 18179, 145, 5, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.38"}],

Cell[CellGroupData[{
Cell[332402, 18188, 197, 6, 70, "Input",
  CellTags->"S1.3.2"],
Cell[332602, 18196, 181, 4, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[332798, 18203, 62, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.39"}],
Cell[332863, 18206, 261, 11, 70, "Text",
  CellTags->{"S1.3.2", "2.40"}],
Cell[333127, 18219, 334, 11, 70, "Text",
  CellTags->{"S1.3.2", "2.41"}],
Cell[333464, 18232, 217, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.42"}],

Cell[CellGroupData[{
Cell[333706, 18243, 166, 5, 70, "Input",
  CellTags->"S1.3.2"],
Cell[333875, 18250, 9227, 615, 70, 9154, 612, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[343117, 18868, 211, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.43"}],

Cell[CellGroupData[{
Cell[343353, 18879, 166, 5, 70, "Input",
  CellTags->"S1.3.2"],
Cell[343522, 18886, 12467, 831, 70, 12394, 828, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[356004, 19720, 1035, 26, 70, "Text",
  CellTags->{"S1.3.2", "2.44"}],
Cell[357042, 19748, 1936, 51, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.45"}],
Cell[358981, 19801, 586, 19, 70, "Text",
  CellTags->{"S1.3.2", "2.46"}],
Cell[359570, 19822, 176, 7, 70, "Text",
  CellTags->{"S1.3.2", "2.47"}],
Cell[359749, 19831, 70, 1, 70, "Subsubsection",
  CellTags->{"S1.3.2", "2.48"}],
Cell[359822, 19834, 613, 15, 70, "Text",
  CellTags->{"S1.3.2", "2.49"}],
Cell[360438, 19851, 1314, 36, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.50"}],
Cell[361755, 19889, 202, 7, 70, "Text",
  CellTags->{"S1.3.2", "2.51"}],
Cell[361960, 19898, 828, 24, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.52"}],
Cell[362791, 19924, 52, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.53"}],
Cell[362846, 19927, 132, 3, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.54"}],
Cell[362981, 19932, 411, 12, 70, "Text",
  CellTags->{"S1.3.2", "2.55"}],
Cell[363395, 19946, 266, 6, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.56"}],
Cell[363664, 19954, 348, 10, 70, "Text",
  CellTags->{"S1.3.2", "2.57"}],
Cell[364015, 19966, 192, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.58"}],

Cell[CellGroupData[{
Cell[364232, 19977, 104, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[364339, 19981, 126, 3, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[364480, 19987, 188, 6, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.59"}],

Cell[CellGroupData[{
Cell[364693, 19997, 86, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[364782, 20001, 83, 3, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[364880, 20007, 213, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.60"}],
Cell[365096, 20016, 187, 6, 70, "Input",
  CellTags->"S1.3.2"],
Cell[365286, 20024, 373, 11, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.61"}],

Cell[CellGroupData[{
Cell[365684, 20039, 294, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[365981, 20049, 7984, 499, 70, 7911, 496, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[373980, 20551, 1108, 32, 70, "Text",
  CellTags->{"S1.3.2", "2.62"}],
Cell[375091, 20585, 387, 8, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.63"}],
Cell[375481, 20595, 157, 4, 70, "Text",
  CellTags->{"S1.3.2", "2.64"}],
Cell[375641, 20601, 442, 9, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.65"}],
Cell[376086, 20612, 785, 22, 70, "Text",
  CellTags->{"S1.3.2", "2.66"}],
Cell[376874, 20636, 255, 5, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.67"}],
Cell[377132, 20643, 421, 12, 70, "Text",
  CellTags->{"S1.3.2", "2.68"}],
Cell[377556, 20657, 360, 11, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.69"}],

Cell[CellGroupData[{
Cell[377941, 20672, 271, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[378215, 20682, 7136, 443, 70, 7063, 440, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[385366, 21128, 365, 11, 70, "Text",
  CellTags->{"S1.3.2", "2.70"}],
Cell[385734, 21141, 277, 7, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.71"}],
Cell[386014, 21150, 202, 7, 70, "Text",
  CellTags->{"S1.3.2", "2.72"}],
Cell[386219, 21159, 570, 11, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.73"}],
Cell[386792, 21172, 630, 20, 70, "Text",
  CellTags->{"S1.3.2", "2.74"}],
Cell[387425, 21194, 292, 6, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.75"}],
Cell[387720, 21202, 578, 18, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.76"}],

Cell[CellGroupData[{
Cell[388323, 21224, 307, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[388633, 21234, 8777, 548, 70, 8704, 545, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[397425, 21785, 295, 9, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.77"}],

Cell[CellGroupData[{
Cell[397745, 21798, 229, 7, 70, "Input",
  CellTags->"S1.3.2"],
Cell[397977, 21807, 5761, 361, 70, 5688, 358, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[403753, 22171, 218, 7, 70, "Text",
  CellTags->{"S1.3.2", "2.78"}],
Cell[403974, 22180, 1663, 42, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.79"}],
Cell[405640, 22224, 155, 4, 70, "Text",
  CellTags->{"S1.3.2", "2.80"}],
Cell[405798, 22230, 582, 14, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.81"}],
Cell[406383, 22246, 52, 1, 70, "Text",
  CellTags->{"S1.3.2", "2.82"}],
Cell[406438, 22249, 1768, 43, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.83"}],
Cell[408209, 22294, 286, 6, 70, "Text",
  CellTags->{"S1.3.2", "2.84"}],
Cell[408498, 22302, 469, 23, 70, "Text",
  CellTags->{"S1.3.2", "2.85"}],
Cell[408970, 22327, 1047, 32, 70, "Text",
  CellTags->{"S1.3.2", "2.86"}],
Cell[410020, 22361, 476, 16, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.87"}],

Cell[CellGroupData[{
Cell[410521, 22381, 190, 6, 70, "Input",
  CellTags->"S1.3.2"],
Cell[410714, 22389, 10262, 683, 70, 10189, 680, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[420991, 23075, 327, 8, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.88"}],

Cell[CellGroupData[{
Cell[421343, 23087, 190, 6, 70, "Input",
  CellTags->"S1.3.2"],
Cell[421536, 23095, 12873, 850, 70, 12800, 847, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[434424, 23948, 424, 14, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.89"}],
Cell[434851, 23964, 84, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[434938, 23968, 104, 1, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.90"}],

Cell[CellGroupData[{
Cell[435067, 23973, 173, 6, 70, "Input",
  CellTags->"S1.3.2"],
Cell[435243, 23981, 9892, 659, 70, 9819, 656, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[445150, 24643, 339, 11, 70, "Text",
  CellTags->{"S1.3.2", "2.91"}],
Cell[445492, 24656, 1872, 46, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.92"}],
Cell[447367, 24704, 713, 21, 70, "Text",
  CellTags->{"S1.3.2", "2.93"}],
Cell[448083, 24727, 1643, 42, 70, "DisplayFormula",
  CellTags->{"S1.3.2", "2.94"}],
Cell[449729, 24771, 150, 5, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.95"}],

Cell[CellGroupData[{
Cell[449904, 24780, 178, 5, 70, "Input",
  CellTags->"S1.3.2"],
Cell[450085, 24787, 344, 7, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[450444, 24797, 3716, 108, 70, "Text",
  CellTags->{"S1.3.2", "2.96"}],
Cell[454163, 24907, 598, 21, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.97"}],
Cell[454764, 24930, 254, 8, 70, "Input",
  CellTags->"S1.3.2"],
Cell[455021, 24940, 330, 11, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.98"}],

Cell[CellGroupData[{
Cell[455376, 24955, 76, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[455455, 24959, 126, 3, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[455596, 24965, 195, 7, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.99"}],

Cell[CellGroupData[{
Cell[455816, 24976, 76, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[455895, 24980, 143, 4, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[456053, 24987, 262, 8, 70, "Text",
  CellTags->{"S1.3.2", "2.100"}],
Cell[456318, 24997, 228, 10, 70, "Text",
  CellTags->{"S1.3.2", "2.101"}],
Cell[456549, 25009, 615, 20, 70, "Text",
  CellTags->{"S1.3.2", "2.102"}],
Cell[457167, 25031, 300, 10, 70, "MathCaption",
  CellTags->{"S1.3.2", "2.103"}],

Cell[CellGroupData[{
Cell[457492, 25045, 82, 2, 70, "Input",
  CellTags->"S1.3.2"],
Cell[457577, 25049, 483, 9, 70, "Output",
  CellTags->"S1.3.2"]
}, Open  ]],
Cell[458075, 25061, 316, 8, 70, "Text",
  CellTags->{"S1.3.2", "2.104"}]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

