(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    508689,      28920]*)
(*NotebookOutlinePosition[    569753,      30667]*)
(*  CellTagsIndexPosition[    563400,      30427]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.4 Orthogonal Wavelets II: Daubechies Wavelets", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 1.4.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.1 Solving for Daubechies Filter Coefficients",
    ButtonData:>{"Wavelets 1.4.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.2 Daubechies' Extremal Phase Filters",
    ButtonData:>{"Wavelets 1.4.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.3 Scaling Function and Mother Wavelet",
    ButtonData:>{"Wavelets 1.4.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.4 Daubechies' Least Asymmetric Filters",
    ButtonData:>{"Wavelets 1.4.4"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.5 Coiflets",
    ButtonData:>{"Wavelets 1.4.5"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.4.6 ",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Phi]",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[" and ",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Psi]",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[" in Fourier Space and the Derivatives of ",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Phi]",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[" and ",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Psi]",
    ButtonData:>{"Wavelets 1.4.6"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["1.4 Orthogonal Wavelets II: Daubechies Wavelets", "Section",
  CellTags->{"S1.4.0", "0.1"}],

Cell[TextData[{
  "We saw in Section ",
  ButtonBox["1.3",
    ButtonData:>{"Wavelets 1.3"},
    ButtonStyle->"AddOnsLink"],
  " that the orthogonalization trick usually renders the wavelets \
noncompactly supported, that is, the set of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\) \[NotEqual] 0\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " is unbounded. It is not at all clear if there exist, apart from the \
simple Haar wavelet, other compactly supported, orthogonal wavelets. However, \
a family of orthogonal wavelets with compact support and a specified number \
of vanishing moments was first constructed by Daubechies, foregoing closed\
\[Hyphen]form analytic expressions for the corresponding wavelets. The \
construction starts by solving for the filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " such that its Fourier transform, the frequency response function, \
satisfies orthogonality and moment conditions. \nIn this section, we will \
outline the procedure for constructing Daubechies wavelets and then show how \
we can write ",
  StyleBox["Mathematica", "TI"],
  " programs that implement the algorithms. We also describe and implement \
the method to compute Daubechies filter coefficients that are as symmetric as \
possible, the so\[Hyphen]called Daubechies' least asymmetric filter \
coefficients. Finally, we discuss coiflets that incorporate moment conditions \
on both ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " and introduce functions that generate coiflet filters. The presentation \
closely follows the book ",
  StyleBox["Ten Lectures on Wavelets", "TI"],
  ", by Ingrid Daubechies (1992), with many mathematical details suppressed. \
For the convenience of the reader, we will follow the notation in the book as \
much as possible. For example, in this section, the frequency response \
function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.0"],
  " will be denoted by ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.0"],
  ". "
}], "Text",
  CellTags->{"S1.4.0", "0.2"}],

Cell["1.4.1 Solving for Daubechies Filter Coefficients", "Subsection",
  CellTags->{"S1.4.1", "1.1"}],

Cell["\<\
In order to construct compactly\[Hyphen]supported, orthogonal \
wavelets, we first look at the dilation equation \
\>", "Text",
  CellTags->{"S1.4.1", "1.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  t - k)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.3"}],

Cell["and the wavelet equation ", "Text",
  CellTags->{"S1.4.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.5"}],

Cell[TextData[{
  "We immediately note from these two equations that the compactness of the \
support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " can be achieved if we choose the number of nonvanishing coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", that is, the filter length, to be finite. This means that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(m\_0\), \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "n",
            LimitsPositioning->True], \(h\_n\), \(e\^\(-i  n  \[Omega]\)\), 
          "/", \(\@2\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.1"],
  " is a trigonometric polynomial. How does one compute ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " once ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " are known? We will see that the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " at the integers solve an eigenvalue problem. Knowing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " at the integers, the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " at the dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " can then be obtained recursively using the scaling equation. Once we know \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", we can use the wavelet equation to generate\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ". \nSo Daubechies' approach to finding ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is to first determine the finite number of filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " such that orthogonality and smoothness or moment conditions are \
guaranteed. To find ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " we start from the Fourier domain where the orthogonality condition for \
the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is (see (",
  ButtonBox["2.11",
    ButtonData:>{"Wavelets 1.2.5", "5.32"},
    ButtonStyle->"AddOnsLink"],
  ")) "
}], "Text",
  CellTags->{"S1.4.1", "1.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftBracketingBar]\(m\_0\) \((\[Omega])\)\[RightBracketingBar]\^2 + 
      \[LeftBracketingBar]\(m\_0\) \((\[Omega] + \[Pi])
            \)\[RightBracketingBar]\^2 = 1.\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.7"}],

Cell[TextData[{
  "The condition that the first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " moments of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " vanish is"
}], "Text",
  CellTags->{"S1.4.1", "1.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(t\^l\), "\[Psi]", \((
        t)\), 
        StyleBox[\("dt"\),
          "TI"], "=", \(0\ \ \ \), \("for"\), "   ", "l", "=", "0", ",", "1", 
        ",", "\[Ellipsis]", ",", "N", "-", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.9"}],

Cell[TextData[{
  "In Fourier space, this condition is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(d\^l\) \(\[Psi]\&^\) \((\[Omega])\)/d 
         \[Omega]\^l\( \[VerticalSeparator] \_\(\[Omega] = 0\)\) = 0\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, ..., N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and this translates into the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\%\((l)\)\) \((\[Pi])\) = 0\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, ..., N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " (where ",
  Cell[BoxData[
      \(TraditionalForm\`N \[GreaterEqual] 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  "). So to satisfy the moment condition (",
  ButtonBox["4.4",
    ButtonData:>{"Wavelets 1.4.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " has to assume the following form: "
}], "Text",
  CellTags->{"S1.4.1", "1.10"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(m\_0\) \((\[Omega])\) \[Proportional] 
      \((\(1 + e\^\(i  \[Omega]\)\)\/2)\)\^N.\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.11"}],

Cell["If we define ", "Text",
  CellTags->{"S1.4.1", "1.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(M\_0\) \((\[Omega])\) = 
      \[LeftBracketingBar]\(m\_0\) \((\[Omega])\)\[RightBracketingBar]\^2, 
      \)], "DisplayFormula",
  CellTags->{"S1.4.1", "1.13"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(M\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`cos  \[Omega]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", the moment\[Hyphen]vanishing condition implies "
}], "Text",
  CellTags->{"S1.4.1", "1.14"}],

Cell[BoxData[
    \(TraditionalForm
    \`M\_0 = \(\((\(cos\^2\) \[Omega]/2)\)\^N\) L \((\[Omega])\), \)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.15"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`cos  \[Omega]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", and the orthogonality condition implies "
}], "Text",
  CellTags->{"S1.4.1", "1.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(M\_0\) \((\[Omega])\) + \(M\_0\) \((\[Omega] + \[Pi])\) = 1.\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.17"}],

Cell[TextData[{
  "Using the identity ",
  Cell[BoxData[
      \(TraditionalForm\`cos  \[Omega] = 1 - 2 \( sin\^2\) \[Omega]/2\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  ", we can write ",
  Cell[BoxData[
      \(TraditionalForm\`L \((\[Omega])\) = P \((\(sin\^2\) \[Omega]/2)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  ". So our task now is to find the form of the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", \"take its square root\" to get ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", and identify the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ". Defining ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(sin\^2\) \[Omega]/2\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", from (",
  ButtonBox["4.6",
    ButtonData:>{"Wavelets 1.4.1", "1.15"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["4.7",
    ButtonData:>{"Wavelets 1.4.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  "), we see that ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " satisfies "
}], "Text",
  CellTags->{"S1.4.1", "1.18"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\((1 - y)\)\^N\) P \((y)\) + \(y\^N\) P \((1 - y)\) = 1, \)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.19"}],

Cell["or ", "Text",
  CellTags->{"S1.4.1", "1.20"}],

Cell[BoxData[
    \(TraditionalForm
    \`P \((y)\) = \(\((1 - y)\)\^\(-N\)\) \((1 - \(y\^N\) P \((1 - y)\))\).
      \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.21"}],

Cell[TextData[{
  "It turns out that the lowest\[Hyphen]degree polynomial that satisfies (",
  ButtonBox["4.8",
    ButtonData:>{"Wavelets 1.4.1", "1.19"},
    ButtonStyle->"AddOnsLink"],
  ") is ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ". So we can find the form of the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " with degree ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " explicitly from (",
  ButtonBox["4.9",
    ButtonData:>{"Wavelets 1.4.1", "1.21"},
    ButtonStyle->"AddOnsLink"],
  ") by expanding ",
  Cell[BoxData[
      \(TraditionalForm\`\((1 - y)\)\^\(-N\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " in a Taylor series and retaining terms up to order ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ": "
}], "Text",
  CellTags->{"S1.4.1", "1.22"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "P", \((y)\), "=", \(\((1 - y)\)\^\(-N\)\), 
        \((1 - \(y\^N\) P \((1 - y)\))\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], 
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(N + k - 1\),
                  "DisplayFormula"]},
              {
                StyleBox["k",
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], ")"}], \(y\^k\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.10) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.23"}],

Cell[TextData[{
  "We notice that ",
  Cell[BoxData[
      \(TraditionalForm\`P \((y)\) \[GreaterEqual] 0\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Element] \(\[InvisibleSpace]\([0, 1]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  ". \nLet us summarize what we have accomplished so far. We have found "
}], "Text",
  CellTags->{"S1.4.1", "1.24"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftBracketingBar]\(m\_0\) \((\[Omega])\)\[RightBracketingBar]\^2 = 
      \(M\_0\) \((\[Omega])\) = \(\((\(cos\^2\) \[Omega]/2)\)\^N\) P \((
      \(sin\^2\) \[Omega]/2)\), \)], "DisplayFormula",
  CellTags->{"S1.4.1", "1.25"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is given by (",
  ButtonBox["4.10",
    ButtonData:>{"Wavelets 1.4.1", "1.23"},
    ButtonStyle->"AddOnsLink"],
  "), such that ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " satisfies the required moment\[Hyphen]vanishing condition and the \
orthogonality condition. Now our remaining task is to \"take the square \
root\" of ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " to get ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ". "
}], "Text",
  CellTags->{"S1.4.1", "1.26"}],

Cell["Spectral Factorization", "Subsubsection",
  CellTags->{"S1.4.1", "1.27"}],

Cell[TextData[{
  "The problem at hand can be stated as follows: given a nonnegative \
trigonometric polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`A \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", extract a polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`B \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] B \((\[Omega])
        \)\( \[VerticalSeparator] \^2\) = A \((\[Omega])\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  ". This amounts to \"taking the square root\" of a polynomial and this \
process of finding ",
  Cell[BoxData[
      \(TraditionalForm\`B \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " given ",
  Cell[BoxData[
      \(TraditionalForm
      \`A \((\[Omega])\) =  \[VerticalSeparator] B \((\[Omega])
        \)\( \[VerticalSeparator] \^2\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is termed ",
  StyleBox["spectral factorization", "TI"],
  ".\nIn our example, we write "
}], "Text",
  CellTags->{"S1.4.1", "1.28"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "A", \((\[Omega])\), "=", "P", \((\(1 - cos  \[Omega]\)\/2)\), "=", 
        "\[Alpha]", 
        UnderoverscriptBox["\[Product]", \(j = 0\), \(N - 1\),
          LimitsPositioning->True], \((c - c\_j)\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.1", "1.29"}],

Cell[TextData[{
  "where we have regarded ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " as a polynomial of degree ",
  Cell[BoxData[
      \(TraditionalForm\`N - 1\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`c = cos  \[Omega]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and expressed it in terms of its roots ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_j}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is a constant). Notice that since the polynomial has real coefficients, \
the roots ",
  Cell[BoxData[
      \(TraditionalForm\`c\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " either are real or occur in complex conjugate pairs. \nOn the other hand, \
we can also write the original polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`z = e\^\(i  \[Omega]\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", "
}], "Text",
  CellTags->{"S1.4.1", "1.30"}],

Cell[BoxData[
    FormBox[
      RowBox[{"A", \((\[Omega])\), "=", "\[Alpha]", 
        UnderoverscriptBox["\[Product]", \(j = 0\), \(N - 1\),
          LimitsPositioning->True], \((\(z + z\^\(-1\)\)\/2 - c\_j)\), "=", 
        "P", \((\(1 - \((z + z\^\(-1\))\)/2\)\/2)\), "\[Congruent]", "p", \((
        z)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.11) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.1", "1.31"}],

Cell[TextData[{
  "We note that the zeros of ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " appear in quadruplets ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.4.1"],
  Cell[BoxData[
      \(TraditionalForm\`z\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j\%\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_\_j\%\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is complex, and in doublets ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.4.1"],
  Cell[BoxData[
      \(TraditionalForm\`r\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r\_j\%\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j = r\_j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is real. So we can write "
}], "Text",
  CellTags->{"S1.4.1", "1.32"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(p \((z)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"\[Alpha]", \(z\^\(-\((N - 1)\)\)\), 
                UnderoverscriptBox["\[Product]", \(j = 0\), \(N - 1\),
                  LimitsPositioning->True], 
                \((z\^2\/2 - \(c\_j\) z + 1\/2)\)}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{\("const "\), \(z\^\(-\((N - 1)\)\)\), 
                UnderscriptBox["\[Product]", "j",
                  LimitsPositioning->True], \((z - z\_j)\), \((z - z\&_\_j)\),
                 \((z - z\_j\%\(-1\))\), \((z - z\&_\_j\%\(-1\))\), 
                UnderscriptBox["\[Product]", "k",
                  LimitsPositioning->True], \(\((z - z\_k)\)\^2\), 
                \(\((z - z\&_\_k)\)\^2\), 
                UnderscriptBox["\[Product]", "l",
                  LimitsPositioning->True], \((z - r\_l)\), 
                \((z - r\_l\%\(-1\))\), "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.1", "1.33"}],

Cell[TextData[{
  "In the preceding we have separated the case ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j = e\^\(i  \[Alpha]\_j\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j = z\&_\_j\%\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and the quadruplet reduces to a doublet of degeneracy 2. \nAfter some \
straightforward algebraic manipulations the polynomial can be written as "
}], "Text",
  CellTags->{"S1.4.1", "1.34"}],

Cell[BoxData[
    FormBox[
      RowBox[{"p", \((z)\), "=", \("const"\), 
        UnderscriptBox["\[Product]", "j",
          LimitsPositioning->True], "\[VerticalSeparator]", \((z - z\_j)\), 
        \((z - z\&_\_j)\), \( \[VerticalSeparator] \^2\), 
        UnderscriptBox["\[Product]", "k",
          LimitsPositioning->True], "\[VerticalSeparator]", 
        \((z - e\^\(i  \[Alpha]\_k\))\), \((z - e\^\(-i  \[Alpha]\_k\))\), 
        \( \[VerticalSeparator] \^2\), 
        UnderscriptBox["\[Product]", "l",
          LimitsPositioning->True], "\[VerticalSeparator]", "z", "-", 
        \(r\_l\), \( \[VerticalSeparator] \^2\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.1", "1.35"}],

Cell[TextData[{
  "Now the \"square root\" of ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " is simply given by, apart from a constant, "
}], "Text",
  CellTags->{"S1.4.1", "1.36"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderscriptBox["\[Product]", "j",
          LimitsPositioning->True], \((z - z\_j)\), \((z - z\&_\_j)\), 
        UnderscriptBox["\[Product]", "k",
          LimitsPositioning->True], \((z - e\^\(i  \[Alpha]\_k\))\), 
        \((z - e\^\(-i  \[Alpha]\_k\))\), 
        UnderscriptBox["\[Product]", "l",
          LimitsPositioning->True], \((z - r\_l)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.1", "1.37"}],

Cell[TextData[{
  "We see that \"taking the square root\" of ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " amounts to selecting half of the zeros of ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " and forming ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Product]", "j",
            LimitsPositioning->True], \((z - z\_j)\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.4.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.4.1"],
  " runs over all indices of selected zeros. "
}], "Text",
  CellTags->{"S1.4.1", "1.38"}],

Cell["1.4.2 Daubechies' Extremal Phase Filters", "Subsection",
  CellTags->{"S1.4.2", "2.1"}],

Cell[TextData[{
  "Now we are in the position to complete the task we set out to do at the \
beginning of Section ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ": to find the filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". We display the relevant formulas here once more. The frequency response \
function is "
}], "Text",
  CellTags->{"S1.4.2", "2.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(m\_0\), \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(h\_n\/\@2\), \(e\^\(-i  \[Omega]  n\)\),
         "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.2", "2.3"}],

Cell[TextData[{
  "The condition that the first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " moments vanish (",
  ButtonBox["4.4",
    ButtonData:>{"Wavelets 1.4.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  ") together with the orthogonality condition (",
  ButtonBox["4.3",
    ButtonData:>{"Wavelets 1.4.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  ") lead to the following form for ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ": "
}], "Text",
  CellTags->{"S1.4.2", "2.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\( \[VerticalSeparator] \(m\_0\) \((\[Omega])
      \)\( \[VerticalSeparator] \^2\) = \(\((\(cos\^2\) \[Omega]/2)\)\^N\) P 
      \((\(sin\^2\) \[Omega]/2)\), \)\)], "DisplayFormula",
  CellTags->{"S1.4.2", "2.5"}],

Cell[TextData[{
  "where the form of ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " is given in (",
  ButtonBox["4.10",
    ButtonData:>{"Wavelets 1.4.1", "1.23"},
    ButtonStyle->"AddOnsLink"],
  "). To determine the spectral factorization of ",
  Cell[BoxData[
      \(TraditionalForm\`P\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " we need first to find the zeros of "
}], "Text",
  CellTags->{"S1.4.2", "2.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(z\^\((N - 1)\)\) P \((\(1 - \(z + z\^\(-1\)\)\/2\)\/2)\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.12) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.2", "2.7"}],

Cell[TextData[{
  "Among each quadruplet of complex roots we pick the pair ",
  Cell[BoxData[
      \(TraditionalForm\`{z\_j, z\&_\_j}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`{z\_j\%\(-1\), z\&_\_j\%\(-1\)}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " that corresponds to both the zeros lying inside or outside the unit \
circle on the complex plane. Although there are six ways of picking two roots \
out of four, we can easily show that other combinations of two roots will not \
lead to a factorization with real coefficients. From each pair of real roots \
we pick the one either inside or outside the unit circle. Among the roots on \
the unit circle we pick one root out of a pair of degenerate roots. Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " is given by "
}], "Text",
  CellTags->{"S1.4.2", "2.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(m\_0\), \((\[Omega])\), "=", \("const "\), \(\((\(z + 1\)\/2)\)\^N\), 
        
        UnderoverscriptBox["\[Product]", \(j = 1\), \(N - 1\),
          LimitsPositioning->True], \((z - z\_j)\), ","}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.2", "2.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " runs through the indices of all selected roots. Notice that this is a \
polynomial of degree ",
  Cell[BoxData[
      \(TraditionalForm\`2  N - 1\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". Since the desired filter coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`h\_j/\@2\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " is the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`z\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " and a phase factor, ",
  Cell[BoxData[
      \(TraditionalForm\`z\^\(-\((2  N - 1)\)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", will not alter the orthogonality and the smoothness properties of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_j/\@2}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " can be obtained by multiplying ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " by a phase factor ",
  Cell[BoxData[
      \(TraditionalForm\`z\^\(-\((2  N - 1)\)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " and extracting the coefficients. (Or, equivalently, ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_j/\@2}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " are given by the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`z\^j\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " in reverse order.) "
}], "Text",
  CellTags->{"S1.4.2", "2.10"}],

Cell[TextData[{
  "Implementation with ",
  StyleBox["Mathematica", "SBO"]
}], "Subsubsection",
  CellTags->{"S1.4.2", "2.11"}],

Cell[TextData[{
  "Once we understand the above procedure of finding ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", it is straightforward to implement it with ",
  StyleBox["Mathematica", "TI"],
  ". We first form the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " given by (",
  ButtonBox["4.11",
    ButtonData:>{"Wavelets 1.4.1", "1.31"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["4.10",
    ButtonData:>{"Wavelets 1.4.1", "1.23"},
    ButtonStyle->"AddOnsLink"],
  "): "
}], "Text",
  CellTags->{"S1.4.2", "2.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{"p", \((z)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], 
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(N + k - 1\),
                  "DisplayFormula"]},
              {
                StyleBox["k",
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], ")"}], 
        \(\((\(1 - \(z + 1/z\)\/2\)\/2)\)\^k\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.2", "2.13"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S1.4.2", "2.14"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.4.2"],

Cell[TextData[{
  "This defines the above ",
  Cell[BoxData[
      \(TraditionalForm\`p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " for a given number of vanishing moments ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.2", "2.15"}],

Cell["\<\
p[n_, z_]:= Sum[Binomial[n+k-1, k]*
((1-(z+1/z)/2)/2)^k, {k, 0, n-1}]\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.4.2"],

Cell[TextData[{
  "Next we find the roots of ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\^\(N - 1\)\) p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". There are various ways of picking the roots to retain, corresponding to \
different choices for the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". In the rest of this section we choose those roots that are inside the \
unit circle. (It can be easily checked that there are no roots on the unit \
circle.) The filter so obtained is called ",
  StyleBox["Daubechies' extremal phase filter", "TI"],
  "."
}], "Text",
  CellTags->{"S1.4.2", "2.16"}],

Cell[TextData[{
  "For example, these are the roots of ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\^\(N - 1\)\) p \((z)\)\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 4\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". The number of roots is ",
  Cell[BoxData[
      \(TraditionalForm\`2 \((N - 1)\) = 6\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". Note that for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", it is important to increase the working precision in finding the roots."
}], "MathCaption",
  CellTags->{"S1.4.2", "2.17"}],

Cell[CellGroupData[{

Cell["\<\
(n = 4;
 roots = Last /@ List @@
 NRoots[z^(n-1)p[n, z]==0, z])\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \({\(0.284096298191821539`\[InvisibleSpace]\) - 0.243228225910379736`\ I, 
      \(0.284096298191821539`\[InvisibleSpace]\) + 0.243228225910379736`\ I, 
      0.328875917786031202`, 
      \(2.03113551209144116`\[InvisibleSpace]\) - 1.73895080764482017`\ I, 
      \(2.03113551209144116`\[InvisibleSpace]\) + 1.73895080764482017`\ I, 
      3.04066046164744374`}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell["\<\
We can plot the roots and see how they are distributed in the \
complex plane. Both the unit circle and the location of the roots are plotted \
here. We see that there is a pair of real roots and a quadruplet of complex \
roots.\
\>", "MathCaption",
  CellTags->{"S1.4.2", "2.18"}],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics[Circle[{0, 0}, 1]],
Graphics[{PointSize[0.015],
Point[{Re[#], Im[#]}]& /@ roots}],
AspectRatio -> Automatic, Axes -> True,
PlotLabel -> \"z-plane\"]\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.4.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86073 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.259509 0.235699 0.430363 0.235699 [
[.02381 .41786 -6 -9 ]
[.02381 .41786 6 0 ]
[.49521 .41786 -3 -9 ]
[.49521 .41786 3 0 ]
[.73091 .41786 -3 -9 ]
[.73091 .41786 3 0 ]
[.96661 .41786 -3 -9 ]
[.96661 .41786 3 0 ]
[.24701 .07681 -24 -4.5 ]
[.24701 .07681 0 4.5 ]
[.24701 .19466 -12 -4.5 ]
[.24701 .19466 0 4.5 ]
[.24701 .31251 -24 -4.5 ]
[.24701 .31251 0 4.5 ]
[.24701 .54821 -18 -4.5 ]
[.24701 .54821 0 4.5 ]
[.24701 .66606 -6 -4.5 ]
[.24701 .66606 0 4.5 ]
[.24701 .78391 -18 -4.5 ]
[.24701 .78391 0 4.5 ]
[.5 .87323 -21 0 ]
[.5 .87323 21 9 ]
[ 0 0 0 0 ]
[ 1 .86073 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .43036 m
.02381 .43661 L
s
[(-1)] .02381 .41786 0 1 Mshowa
.49521 .43036 m
.49521 .43661 L
s
[(1)] .49521 .41786 0 1 Mshowa
.73091 .43036 m
.73091 .43661 L
s
[(2)] .73091 .41786 0 1 Mshowa
.96661 .43036 m
.96661 .43661 L
s
[(3)] .96661 .41786 0 1 Mshowa
.125 Mabswid
.07095 .43036 m
.07095 .43411 L
s
.11809 .43036 m
.11809 .43411 L
s
.16523 .43036 m
.16523 .43411 L
s
.21237 .43036 m
.21237 .43411 L
s
.30665 .43036 m
.30665 .43411 L
s
.35379 .43036 m
.35379 .43411 L
s
.40093 .43036 m
.40093 .43411 L
s
.44807 .43036 m
.44807 .43411 L
s
.54235 .43036 m
.54235 .43411 L
s
.58949 .43036 m
.58949 .43411 L
s
.63663 .43036 m
.63663 .43411 L
s
.68377 .43036 m
.68377 .43411 L
s
.77805 .43036 m
.77805 .43411 L
s
.82519 .43036 m
.82519 .43411 L
s
.87233 .43036 m
.87233 .43411 L
s
.91947 .43036 m
.91947 .43411 L
s
.25 Mabswid
0 .43036 m
1 .43036 L
s
.25951 .07681 m
.26576 .07681 L
s
[(-1.5)] .24701 .07681 1 0 Mshowa
.25951 .19466 m
.26576 .19466 L
s
[(-1)] .24701 .19466 1 0 Mshowa
.25951 .31251 m
.26576 .31251 L
s
[(-0.5)] .24701 .31251 1 0 Mshowa
.25951 .54821 m
.26576 .54821 L
s
[(0.5)] .24701 .54821 1 0 Mshowa
.25951 .66606 m
.26576 .66606 L
s
[(1)] .24701 .66606 1 0 Mshowa
.25951 .78391 m
.26576 .78391 L
s
[(1.5)] .24701 .78391 1 0 Mshowa
.125 Mabswid
.25951 .10038 m
.26326 .10038 L
s
.25951 .12395 m
.26326 .12395 L
s
.25951 .14752 m
.26326 .14752 L
s
.25951 .17109 m
.26326 .17109 L
s
.25951 .21823 m
.26326 .21823 L
s
.25951 .2418 m
.26326 .2418 L
s
.25951 .26537 m
.26326 .26537 L
s
.25951 .28894 m
.26326 .28894 L
s
.25951 .33608 m
.26326 .33608 L
s
.25951 .35965 m
.26326 .35965 L
s
.25951 .38322 m
.26326 .38322 L
s
.25951 .40679 m
.26326 .40679 L
s
.25951 .45393 m
.26326 .45393 L
s
.25951 .4775 m
.26326 .4775 L
s
.25951 .50107 m
.26326 .50107 L
s
.25951 .52464 m
.26326 .52464 L
s
.25951 .57178 m
.26326 .57178 L
s
.25951 .59535 m
.26326 .59535 L
s
.25951 .61892 m
.26326 .61892 L
s
.25951 .64249 m
.26326 .64249 L
s
.25951 .68963 m
.26326 .68963 L
s
.25951 .7132 m
.26326 .7132 L
s
.25951 .73677 m
.26326 .73677 L
s
.25951 .76034 m
.26326 .76034 L
s
.25951 .05324 m
.26326 .05324 L
s
.25951 .02967 m
.26326 .02967 L
s
.25951 .0061 m
.26326 .0061 L
s
.25951 .80748 m
.26326 .80748 L
s
.25951 .83105 m
.26326 .83105 L
s
.25951 .85462 m
.26326 .85462 L
s
.25 Mabswid
.25951 0 m
.25951 .86073 L
s
[(z-plane)] .5 .87323 0 -1 Mshowa
0 0 m
1 0 L
1 .86073 L
0 .86073 L
closepath
clip
newpath
.5 Mabswid
newpath
.25951 .43036 .2357 0 365.73 arc
s
.015 w
.32647 .37303 Mdot
.32647 .48769 Mdot
.33702 .43036 Mdot
.73825 .02049 Mdot
.73825 .84023 Mdot
.97619 .43036 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.2"]
}, Open  ]],

Cell["The roots that are inside the unit circle are selected.", "MathCaption",
  CellTags->{"S1.4.2", "2.19"}],

Cell[CellGroupData[{

Cell["roots = Select[roots, Abs[#]<1&]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \({\(0.284096298191821539`\[InvisibleSpace]\) - 0.243228225910379736`\ I, 
      \(0.284096298191821539`\[InvisibleSpace]\) + 0.243228225910379736`\ I, 
      0.328875917786031202`}\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell[TextData[{
  "The factor ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - z\_j)\) \((z - z\&_\_j)\) \((z - r\_j)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.2"],
  " is formed very conveniently using ",
  StyleBox["Mathematica", "TI"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.2", "2.20"}],

Cell[CellGroupData[{

Cell["Apply[Times, z-roots]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \(\((\(-0.328875917786031202`\) + z)\)\ 
      \((\((\(-0.284096298191821539`\) - 0.243228225910379736`\ I)\) + z)\)\ 
      \((\((\(-0.284096298191821539`\) + 0.243228225910379736`\ I)\) + z)
        \)\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell[TextData[{
  "Now we can use the ",
  StyleBox["Mathematica", "TI"],
  " function ",
  StyleBox["CoefficientList", "MR"],
  " to extract the coefficients of the polynomial ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\((1 + z)\)\^N\) \((z - z\_j)\) \((z - z\&_\_j)\) \((z - r\_j)\)\)],
     "InlineFormula",
    CellTags->"S1.4.2"],
  ". This is a polynomial of degree ",
  Cell[BoxData[
      \(TraditionalForm\`2  N - 1\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", therefore we get a filter of length ",
  Cell[BoxData[
      \(TraditionalForm\`2  N = 8\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". The normalization factor is determined by the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((0)\) = 1\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " or ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), "=", \(\@2\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.2"],
  ". "
}], "Text",
  CellTags->{"S1.4.2", "2.21"}],

Cell["This gives the desired filter coefficients.", "MathCaption",
  CellTags->{"S1.4.2", "2.22"}],

Cell[CellGroupData[{

Cell["\<\
(coef = Re[CoefficientList[(1+z)^n %, z]];
 Reverse[coef]/(Apply[Plus, coef]/N[Sqrt[2]]))\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \({0.230377813308896639`, 0.714846570552916027`, 0.630880767929859054`, 
      \(-0.0279837694168601247`\), \(-0.187034811719093436`\), 
      0.0308413818355607194`, 0.0328830116668852223`, 
      \(-0.0105974017850690382`\)}\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell[TextData[{
  "We collect the above illustrative ",
  StyleBox["Mathematica", "TI"],
  " program lines together to define a function "
}], "Text",
  CellTags->{"S1.4.2", "2.23"}],

Cell[TextData[{
  StyleBox["DaubechiesFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.2", "2.24"}],

Cell[TextData[{
  "that gives Daubechies' extremal phase filter coefficients of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{{h\_0, h\_1, \[Ellipsis], h\_\(2  N - 1\)}, 0}\)], 
    "InlineFormula",
    CellTags->"S1.4.2"],
  ", where the last number 0 is the index of the first coefficient and ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " is the number of vanishing moments of the corresponding wavelet. "
}], "Text",
  CellTags->{"S1.4.2", "2.25"}],

Cell[TextData[{
  "For example, this gives the Daubechies filter coefficients of order ",
  Cell[BoxData[
      \(TraditionalForm\`N = 3\)], "InlineFormula",
    CellTags->"S1.4.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.2", "2.26"}],

Cell[CellGroupData[{

Cell["h3 = DaubechiesFilter[3]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \({{0.332670552950082631`, 0.806891509311092569`, 0.459877502118491587`, 
        \(-0.135011020010254578`\), \(-0.0854412738820266781`\), 
        0.0352262918857095419`}, 0}\)], "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell[TextData[{
  "If we want to display the above result with more digits, we can use ",
  StyleBox["N[", "MR"],
  StyleBox["h3", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["digits", "TI"],
  StyleBox["]", "MR"],
  ". However, if we want the calculation to be carried out with more \
precision than the default machine precision, we can use "
}], "Text",
  CellTags->{"S1.4.2", "2.27"}],

Cell[TextData[{
  StyleBox["DaubechiesFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["prec", "TI"],
  StyleBox["]", "MR"],
  ", "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.2", "2.28"}],

Cell[TextData[{
  "where ",
  StyleBox["prec", "TI"],
  " specifies the working precision. Note that it is important to increase \
the working precision for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ". In general, the larger the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ", the higher the working precision is required in order to get correct \
results. Also, for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.2"],
  " (say, ",
  Cell[BoxData[
      \(TraditionalForm\`N > 25\)], "InlineFormula",
    CellTags->"S1.4.2"],
  ") the above function can run into numerical difficulties. For other \
spectral factorization algorithms, see Strang and Nguyen (1996). "
}], "Text",
  CellTags->{"S1.4.2", "2.29"}],

Cell["\<\
This calculates the Daubechies filter of order 11 with working \
precision 28.\
\>", "MathCaption",
  CellTags->{"S1.4.2", "2.30"}],

Cell[CellGroupData[{

Cell["DaubechiesFilter[11, 28]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \({{0.0186942977614710840254357294062`18.2936, 
        0.14406702115062451279519158501`18.2936, 
        0.449899764356045334768894037631`18.2933, 
        0.68568677491620051112093863206`18.2922, 
        0.411964368947907462925939648733`18.2828, 
        \(-0.162275245027490362240582727238`18.2141\), 
        \(-0.274230846817946961202100945684`18.1875\), 
        0.066043588196683191900614578648`17.8052, 
        0.14981201246637849640665626161`17.9265, 
        \(-0.046479955116684187271617225959`17.5085\), 
        \(-0.066438785695025205278992155367`17.6363\), 
        0.031335090219046076030947984152`17.4312, 
        0.020840904360181063022948112612`17.4083, 
        \(-0.015364820906201599426198116076`17.4883\), 
        \(-0.0033408588730144456060908086041`17.1702\), 
        0.0049284176560590411231707397418`17.6507, 
        \(-0.00030859285881514316517545906207`17.0198\), 
        \(-0.00089302325066626461339008246228`17.8824\), 
        0.000249152523552823498871221687469`17.9737, 
        0.000054439074699368471673578568821`18.0702, 
        \(-0.0000346349841869849955412808516194`18.2569\), 
        4.49427427723651009541564828467`18.2825*^-6}, 0}\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell["\<\
The actual precision is often less than the working precision.\
\>",
   "MathCaption",
  CellTags->{"S1.4.2", "2.31"}],

Cell[CellGroupData[{

Cell["Precision[%]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.4.2"],

Cell[BoxData[
    \(17\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S1.4.2"]
}, Open  ]],

Cell["1.4.3 Scaling Function and Mother Wavelet", "Subsection",
  CellTags->{"S1.4.3", "3.1"}],

Cell[TextData[{
  "We recall that our goal is to find orthonormal scaling functions and \
wavelets that are compactly supported and satisfy certain prescribed moment\
\[Hyphen]vanishing conditions. In Sections ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  " we concentrated on the task of finding the filter coefficients. These \
coefficients are the coefficients appearing in the dilation equation and, \
after appropriate transformation, in the wavelet equation. These equations in \
turn produce the desired scaling function and mother wavelet. \nIn this \
section, we focus on finding the solutions of the dilation and wavelet \
equations given the filter coefficients. As we have said earlier, the \
simultaneous requirements of orthogonality and compact support prevent us \
from finding a closed analytic form for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " in general, so here we will be content with finding them numerically and \
plotting them. \nA compactly supported scaling function satisfies the \
dilation equation "
}], "Text",
  CellTags->{"S1.4.3", "3.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), "n",
          LimitsPositioning->True], \(\@2\), \(h\_k\), "\[Phi]", \((2  t - k)
        \), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), "n",
          LimitsPositioning->True], \(c\_k\), "\[Phi]", \((2  t - k)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.13) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.3", "3.3"}],

Cell[TextData[{
  "where the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, n]\)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". In general, the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " can be ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([n\_1, n\_2]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1 \[NotEqual] 0\)], "InlineFormula",
    CellTags->"S1.4.3"],
  "; in this case, the summation over ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " extends from ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". There is no loss of generality in (",
  ButtonBox["4.13",
    ButtonData:>{"Wavelets 1.4.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  ") since the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " obtained by summing ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " is simply related to that obtained by summing ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`0\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_2 - n\_1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " by a translation by ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". \nThere are various ways of computing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " from (",
  ButtonBox["4.13",
    ButtonData:>{"Wavelets 1.4.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  ") (see Strang (1989) and Strang (1993)). For example, the dilation \
equation can be iterated with ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_j\), \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", \(k = 0\), "n",
            LimitsPositioning->True], \(c\_k\), \(\[Phi]\_\(j - 1\)\), \((
          2  t - k)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  " starting from a box function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ", until it converges. Another method is to perform the iteration in \
Fourier domain. The dilation equation in the frequency domain has the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]/2)\) \(\[Phi]\&^\) \((
        \[Omega]/2)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " which can be iterated to yield "
}], "Text",
  CellTags->{"S1.4.3", "3.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\&^\), \((\[Omega])\), "=", 
        UnderoverscriptBox["\[Product]", \(j = 1\), "\[Infinity]",
          LimitsPositioning->True], "H", \((\[Omega]\/2\^j)\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.3", "3.5"}],

Cell[TextData[{
  "and thence, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". (Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((0)\) = 1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " comes from the normalization of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), 
          StyleBox[\("dt"\),
            "TI"], "=", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  ".) The third way of computing the scaling function is from recursion. We \
will concentrate on this method and explain it in some detail in the \
following. \nWe observe that the two scales in the equation are ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`2  t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". The values of the scaling function at half integers are determined by \
those at integers; the values at quarter integers by those at half integers, \
and so on. So if the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at integers are known, using the dilation equation we can get all the \
values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`t = k/2\^j\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k, j = 1, 2, \[Ellipsis]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". Since any real ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " can be approximated by a dyadic point of the form ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^j\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " to any given accuracy, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at any point ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " can, in principle, be calculated to any prescribed accuracy as long as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " is continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". In practice, we usually calculate the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = k  \[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]", "=", 
          SuperscriptBox["2", 
            RowBox[{"-", 
              SubscriptBox["j", 
                StyleBox[\("max"\),
                  "TI"]]}]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  " and interpolate the values in between. \nThe values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at the integers in fact solve the following eigenvalue problem. From the \
dilation equation (",
  ButtonBox["4.13",
    ButtonData:>{"Wavelets 1.4.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "), we have, when ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " assumes integer values ",
  Cell[BoxData[
      \(TraditionalForm\`i\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ","
}], "Text",
  CellTags->{"S1.4.3", "3.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((i)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  i - k)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(c\_k\), "\[Phi]", \((2  i - k)\), "=", 
        UnderscriptBox["\[Sum]", "j",
          LimitsPositioning->True], \(c\_\(2  i - j\)\), "\[Phi]", \((j)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.14) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.3", "3.7"}],

Cell["This is an eigenvalue equation ", "Text",
  CellTags->{"S1.4.3", "3.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`C \( \[Phi]\& \[RightVector] \) = \(\[Phi]\& \[RightVector] \)\)], 
  "DisplayFormula",
  CellTags->{"S1.4.3", "3.9"}],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " matrix ",
  Cell[BoxData[
      \(TraditionalForm\`C\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " has elements ",
  Cell[BoxData[
      \(TraditionalForm\`\((C)\)\_\(i  j\) = c\_\(2  i - j\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  " and, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi]\& \[RightVector] \) = 
        \((\[Phi] \((0)\), \[Phi] \((1)\), ..., \[Phi] \((n - 1)\))
            \)\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Null]\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " denotes the transpose. In matrix form, "
}], "Text",
  CellTags->{"S1.4.3", "3.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", GridBox[{
                {
                  StyleBox[\(c\_0\),
                    "DisplayFormula"], 
                  StyleBox["0",
                    "DisplayFormula"], 
                  StyleBox["0",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"]},
                {
                  StyleBox[\(c\_2\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_1\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_0\),
                    "DisplayFormula"], 
                  StyleBox["0",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"]},
                {
                  StyleBox[\(c\_4\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_3\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_2\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_1\),
                    "DisplayFormula"], 
                  StyleBox[".",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"]},
                {
                  StyleBox[".",
                    "DisplayFormula"], 
                  StyleBox[\(c\_5\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_4\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_3\),
                    "DisplayFormula"], 
                  StyleBox[".",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"]},
                {
                  StyleBox["\[Null]",
                    "DisplayFormula"], "\[Null]", "\[Null]", "\[Null]", 
                  "\[Null]", "\[Null]", "\[Null]", "\[Null]", "\[Null]"},
                {
                  StyleBox["\[Null]",
                    "DisplayFormula"], "\[Null]", "\[Null]", "\[Null]", 
                  "\[Null]", "\[Null]", "\[Null]", "\[Null]", "\[Null]"},
                {
                  StyleBox["\[Null]",
                    "DisplayFormula"], "\[Null]", "\[Null]", "\[Null]", 
                  "\[Null]", "\[Null]", "\[Null]", "\[Null]", "\[Null]"},
                {
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["\[Null]",
                    "DisplayFormula"], 
                  StyleBox["0",
                    "DisplayFormula"], 
                  StyleBox[\(c\_n\),
                    "DisplayFormula"], 
                  StyleBox[\(c\_\(n - 1\)\),
                    "DisplayFormula"]}
                },
              ColumnAlignments->{Left}], "]"}]}], 
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", GridBox[{
                {
                  StyleBox[\(\[Phi] \((0)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((1)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((2)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((3)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox["\[VerticalEllipsis]",
                    "DisplayFormula"]},
                {
                  StyleBox["\[VerticalEllipsis]",
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((n - 1)\)\),
                    "DisplayFormula"]}
                },
              ColumnAlignments->{Center}], "]"}]}], "=", 
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", GridBox[{
                {
                  StyleBox[\(\[Phi] \((0)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((1)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((2)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((3)\)\),
                    "DisplayFormula"]},
                {
                  StyleBox["\[VerticalEllipsis]",
                    "DisplayFormula"]},
                {
                  StyleBox["\[VerticalEllipsis]",
                    "DisplayFormula"]},
                {
                  StyleBox[\(\[Phi] \((n - 1)\)\),
                    "DisplayFormula"]}
                },
              ColumnAlignments->{Center}], "]"}]}], "."}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.15) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.3", "3.11"}],

Cell[TextData[{
  "Since the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, n]\)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ", we have not included ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((j)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`j > n\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " in the above equation. If we further invoke continuity at ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " (note that this excludes the case of the Haar system where there is a \
discontinuity at ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.4.3"],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((n)\) = 0\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " and it is also dropped from the above equation. \nSo the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at integers are given by the eigenvector of ",
  Cell[BoxData[
      \(TraditionalForm\`C\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " corresponding to the eigenvalue 1. We normalize the vector using ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], "\[Phi]", \((k)\), "=", "1"}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  ". (This will guarantee that the integral of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " is 1.) Then we can begin the recursion to find the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " at half integers, quarter integer, and so on. \nThe function "
}], "Text",
  CellTags->{"S1.4.3", "3.12"}],

Cell[TextData[{
  StyleBox["ScalingFunction[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.3", "3.13"}],

Cell[TextData[{
  "gives a list of points of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"k", "/", 
            SuperscriptBox["2", 
              StyleBox[\("jmax"\),
                "TI"]], ",", "\[Phi]", 
            RowBox[{"(", 
              RowBox[{"k", "/", 
                SuperscriptBox["2", 
                  StyleBox[\("jmax"\),
                    "TI"]]}], ")"}]}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  ", where both ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " and ",
  StyleBox["jmax", "TI"],
  " are integers and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  " assumes values within the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". The values of the scaling function are obtained by first finding the \
eigenvector that solves the eigenvalue problem (",
  ButtonBox["4.14",
    ButtonData:>{"Wavelets 1.4.3", "3.7"},
    ButtonStyle->"AddOnsLink"],
  ") with the given filter ",
  StyleBox["filter", "TI"],
  ", and then recursively finding the values in between down to the scale ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["2", 
          RowBox[{"-", 
            StyleBox[\("jmax"\),
              "TI"]}]], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  ". \nFor example, to get the Daubechies scaling function of order 2, we do \
the following. "
}], "Text",
  CellTags->{"S1.4.3", "3.14"}],

Cell["The filter coefficients are calculated first.", "MathCaption",
  CellTags->{"S1.4.3", "3.15"}],

Cell[CellGroupData[{

Cell["d2 = DaubechiesFilter[2]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    \({{0.482962913144534056`, 0.836516303737807831`, 0.224143868042013361`, 
        \(-0.129409522551260369`\)}, 0}\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "This gives the scaling function at dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^5\)], "InlineFormula",
    CellTags->"S1.4.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.16"}],

Cell["philist = ScalingFunction[d2, 5];", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S1.4.3"],

Cell[TextData[{
  "We can use the function ",
  StyleBox["Short", "MR"],
  " to see the output form without printing out everything."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.17"}],

Cell[CellGroupData[{

Cell["Short[philist]", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    TagBox[
      \({{0, 0.`}, {1\/32, 0.203049852005988684`}, 
        \[LeftSkeleton]94\[RightSkeleton], {3, 0}}\),
      Short]], "Output",
  CellLabel->"Out[13]//Short= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "We plot the scaling function using ",
  StyleBox["ListPlot", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.18"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[philist, PlotJoined -> True,
AxesLabel -> {\"t\", \"phi(t)\"}]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.139102 0.339831 [
[.18254 .1266 -9 -9 ]
[.18254 .1266 9 0 ]
[.34127 .1266 -3 -9 ]
[.34127 .1266 3 0 ]
[.5 .1266 -9 -9 ]
[.5 .1266 9 0 ]
[.65873 .1266 -3 -9 ]
[.65873 .1266 3 0 ]
[.81746 .1266 -9 -9 ]
[.81746 .1266 9 0 ]
[.97619 .1266 -3 -9 ]
[.97619 .1266 3 0 ]
[1.025 .1391 0 -4.5 ]
[1.025 .1391 6 4.5 ]
[.01131 .05414 -30 -4.5 ]
[.01131 .05414 0 4.5 ]
[.01131 .22406 -24 -4.5 ]
[.01131 .22406 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .39397 -24 -4.5 ]
[.01131 .39397 0 4.5 ]
[.01131 .47893 -6 -4.5 ]
[.01131 .47893 0 4.5 ]
[.01131 .56389 -24 -4.5 ]
[.01131 .56389 0 4.5 ]
[.02381 .64303 -18 0 ]
[.02381 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .1391 m
.18254 .14535 L
s
[(0.5)] .18254 .1266 0 1 Mshowa
.34127 .1391 m
.34127 .14535 L
s
[(1)] .34127 .1266 0 1 Mshowa
.5 .1391 m
.5 .14535 L
s
[(1.5)] .5 .1266 0 1 Mshowa
.65873 .1391 m
.65873 .14535 L
s
[(2)] .65873 .1266 0 1 Mshowa
.81746 .1391 m
.81746 .14535 L
s
[(2.5)] .81746 .1266 0 1 Mshowa
.97619 .1391 m
.97619 .14535 L
s
[(3)] .97619 .1266 0 1 Mshowa
.125 Mabswid
.05556 .1391 m
.05556 .14285 L
s
.0873 .1391 m
.0873 .14285 L
s
.11905 .1391 m
.11905 .14285 L
s
.15079 .1391 m
.15079 .14285 L
s
.21429 .1391 m
.21429 .14285 L
s
.24603 .1391 m
.24603 .14285 L
s
.27778 .1391 m
.27778 .14285 L
s
.30952 .1391 m
.30952 .14285 L
s
.37302 .1391 m
.37302 .14285 L
s
.40476 .1391 m
.40476 .14285 L
s
.43651 .1391 m
.43651 .14285 L
s
.46825 .1391 m
.46825 .14285 L
s
.53175 .1391 m
.53175 .14285 L
s
.56349 .1391 m
.56349 .14285 L
s
.59524 .1391 m
.59524 .14285 L
s
.62698 .1391 m
.62698 .14285 L
s
.69048 .1391 m
.69048 .14285 L
s
.72222 .1391 m
.72222 .14285 L
s
.75397 .1391 m
.75397 .14285 L
s
.78571 .1391 m
.78571 .14285 L
s
.84921 .1391 m
.84921 .14285 L
s
.88095 .1391 m
.88095 .14285 L
s
.9127 .1391 m
.9127 .14285 L
s
.94444 .1391 m
.94444 .14285 L
s
.25 Mabswid
0 .1391 m
1 .1391 L
s
[(t)] 1.025 .1391 -1 0 Mshowa
.02381 .05414 m
.03006 .05414 L
s
[(-0.25)] .01131 .05414 1 0 Mshowa
.02381 .22406 m
.03006 .22406 L
s
[(0.25)] .01131 .22406 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.5)] .01131 .30902 1 0 Mshowa
.02381 .39397 m
.03006 .39397 L
s
[(0.75)] .01131 .39397 1 0 Mshowa
.02381 .47893 m
.03006 .47893 L
s
[(1)] .01131 .47893 1 0 Mshowa
.02381 .56389 m
.03006 .56389 L
s
[(1.25)] .01131 .56389 1 0 Mshowa
.125 Mabswid
.02381 .07114 m
.02756 .07114 L
s
.02381 .08813 m
.02756 .08813 L
s
.02381 .10512 m
.02756 .10512 L
s
.02381 .12211 m
.02756 .12211 L
s
.02381 .15609 m
.02756 .15609 L
s
.02381 .17308 m
.02756 .17308 L
s
.02381 .19008 m
.02756 .19008 L
s
.02381 .20707 m
.02756 .20707 L
s
.02381 .24105 m
.02756 .24105 L
s
.02381 .25804 m
.02756 .25804 L
s
.02381 .27503 m
.02756 .27503 L
s
.02381 .29203 m
.02756 .29203 L
s
.02381 .32601 m
.02756 .32601 L
s
.02381 .343 m
.02756 .343 L
s
.02381 .35999 m
.02756 .35999 L
s
.02381 .37698 m
.02756 .37698 L
s
.02381 .41097 m
.02756 .41097 L
s
.02381 .42796 m
.02756 .42796 L
s
.02381 .44495 m
.02756 .44495 L
s
.02381 .46194 m
.02756 .46194 L
s
.02381 .49592 m
.02756 .49592 L
s
.02381 .51292 m
.02756 .51292 L
s
.02381 .52991 m
.02756 .52991 L
s
.02381 .5469 m
.02756 .5469 L
s
.02381 .03715 m
.02756 .03715 L
s
.02381 .02016 m
.02756 .02016 L
s
.02381 .00317 m
.02756 .00317 L
s
.02381 .58088 m
.02756 .58088 L
s
.02381 .59787 m
.02756 .59787 L
s
.02381 .61486 m
.02756 .61486 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi\\(t\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1391 m
.03373 .2081 L
.04365 .24013 L
.05357 .25862 L
.06349 .28702 L
.07341 .2956 L
.08333 .31409 L
.09325 .3362 L
.10317 .35566 L
.1131 .35699 L
.12302 .36823 L
.13294 .38309 L
.14286 .3953 L
.15278 .41281 L
.1627 .42768 L
.17262 .44157 L
.18254 .45617 L
.19246 .45219 L
.20238 .45811 L
.2123 .46766 L
.22222 .47456 L
.23214 .48677 L
.24206 .49632 L
.25198 .5049 L
.2619 .5142 L
.27183 .52835 L
.28175 .53984 L
.29167 .55037 L
.30159 .5616 L
.31151 .57142 L
.32143 .58194 L
.33135 .59272 L
.34127 .60332 L
.35119 .47593 L
.36111 .4225 L
.37103 .39615 L
.38095 .34997 L
.39087 .34343 L
.40079 .31707 L
.41071 .28346 L
.42063 .25516 L
.43056 .26312 L
.44048 .25127 L
.4504 .23216 L
.46032 .21837 L
.47024 .19395 L
.48016 .17485 L
.49008 .15769 L
.5 .1391 L
.50992 .15769 L
Mistroke
.51984 .15645 L
.52976 .14797 L
.53968 .14479 L
.5496 .131 L
.55952 .12251 L
.56944 .11597 L
.57937 .10801 L
.58929 .09032 L
.59921 .07795 L
.60913 .06752 L
.61905 .05567 L
.62897 .04666 L
.63889 .03623 L
.64881 .02528 L
.65873 .01472 L
.66865 .0731 L
.67857 .0945 L
.68849 .10237 L
.69841 .12015 L
.70833 .11811 L
.71825 .12598 L
.72817 .13748 L
.7381 .14632 L
.74802 .13703 L
.75794 .13764 L
.76786 .14188 L
.77778 .14347 L
.7877 .15037 L
.79762 .15461 L
.80754 .15788 L
.81746 .16187 L
.82738 .14726 L
.8373 .14257 L
.84722 .1415 L
.85714 .13778 L
.86706 .13937 L
.87698 .1383 L
.8869 .13626 L
.89683 .13494 L
.90675 .13847 L
.91667 .13934 L
.92659 .13925 L
.93651 .13986 L
.94643 .13906 L
.95635 .13896 L
.96627 .13913 L
.97619 .1391 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "Often it is desirable to have a continuous scaling function at our \
disposal so that various dilated and translated versions of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " can be plotted and visualized. The continuous ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " function can be obtained by linearly interpolating the above ",
  StyleBox["philist", "TI"],
  " using the function ",
  StyleBox["Interpolation", "MR"],
  ". For example, to get the continuous scaling function defined on, say, ",
  Cell[BoxData[
      \(TraditionalForm
      \`t \[Element] \(\[InvisibleSpace]\([\(-20\), 20]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  ", we can do the following. "
}], "Text",
  CellTags->{"S1.4.3", "3.19"}],

Cell[TextData[{
  "This defines a continuous function on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-20\), 20]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  " by interpolation."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.20"}],

Cell[CellGroupData[{

Cell["\<\
phi = Interpolation[Join[{{-20, 0}}, philist,
{{20, 0}}], InterpolationOrder -> 1]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-20.`\), 20.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[15]= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "With the continuous ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ", we can plot its dilated and translated version."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.21"}],

Cell[CellGroupData[{

Cell["\<\
Plot[phi[2t-2], {t, -1, 4}, PlotRange -> All,
AxesLabel -> {\"t\", \"phi(2t-2)\"}]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.137994 0.341881 [
[.02381 .12549 -6 -9 ]
[.02381 .12549 6 0 ]
[.40476 .12549 -3 -9 ]
[.40476 .12549 3 0 ]
[.59524 .12549 -3 -9 ]
[.59524 .12549 3 0 ]
[.78571 .12549 -3 -9 ]
[.78571 .12549 3 0 ]
[.97619 .12549 -3 -9 ]
[.97619 .12549 3 0 ]
[1.025 .13799 0 -4.5 ]
[1.025 .13799 6 4.5 ]
[.20179 .05252 -30 -4.5 ]
[.20179 .05252 0 4.5 ]
[.20179 .22346 -24 -4.5 ]
[.20179 .22346 0 4.5 ]
[.20179 .30893 -18 -4.5 ]
[.20179 .30893 0 4.5 ]
[.20179 .3944 -24 -4.5 ]
[.20179 .3944 0 4.5 ]
[.20179 .47987 -6 -4.5 ]
[.20179 .47987 0 4.5 ]
[.20179 .56535 -24 -4.5 ]
[.20179 .56535 0 4.5 ]
[.21429 .64303 -27 0 ]
[.21429 .64303 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .13799 m
.02381 .14424 L
s
[(-1)] .02381 .12549 0 1 Mshowa
.40476 .13799 m
.40476 .14424 L
s
[(1)] .40476 .12549 0 1 Mshowa
.59524 .13799 m
.59524 .14424 L
s
[(2)] .59524 .12549 0 1 Mshowa
.78571 .13799 m
.78571 .14424 L
s
[(3)] .78571 .12549 0 1 Mshowa
.97619 .13799 m
.97619 .14424 L
s
[(4)] .97619 .12549 0 1 Mshowa
.125 Mabswid
.0619 .13799 m
.0619 .14174 L
s
.1 .13799 m
.1 .14174 L
s
.1381 .13799 m
.1381 .14174 L
s
.17619 .13799 m
.17619 .14174 L
s
.25238 .13799 m
.25238 .14174 L
s
.29048 .13799 m
.29048 .14174 L
s
.32857 .13799 m
.32857 .14174 L
s
.36667 .13799 m
.36667 .14174 L
s
.44286 .13799 m
.44286 .14174 L
s
.48095 .13799 m
.48095 .14174 L
s
.51905 .13799 m
.51905 .14174 L
s
.55714 .13799 m
.55714 .14174 L
s
.63333 .13799 m
.63333 .14174 L
s
.67143 .13799 m
.67143 .14174 L
s
.70952 .13799 m
.70952 .14174 L
s
.74762 .13799 m
.74762 .14174 L
s
.82381 .13799 m
.82381 .14174 L
s
.8619 .13799 m
.8619 .14174 L
s
.9 .13799 m
.9 .14174 L
s
.9381 .13799 m
.9381 .14174 L
s
.25 Mabswid
0 .13799 m
1 .13799 L
s
[(t)] 1.025 .13799 -1 0 Mshowa
.21429 .05252 m
.22054 .05252 L
s
[(-0.25)] .20179 .05252 1 0 Mshowa
.21429 .22346 m
.22054 .22346 L
s
[(0.25)] .20179 .22346 1 0 Mshowa
.21429 .30893 m
.22054 .30893 L
s
[(0.5)] .20179 .30893 1 0 Mshowa
.21429 .3944 m
.22054 .3944 L
s
[(0.75)] .20179 .3944 1 0 Mshowa
.21429 .47987 m
.22054 .47987 L
s
[(1)] .20179 .47987 1 0 Mshowa
.21429 .56535 m
.22054 .56535 L
s
[(1.25)] .20179 .56535 1 0 Mshowa
.125 Mabswid
.21429 .06962 m
.21804 .06962 L
s
.21429 .08671 m
.21804 .08671 L
s
.21429 .10381 m
.21804 .10381 L
s
.21429 .1209 m
.21804 .1209 L
s
.21429 .15509 m
.21804 .15509 L
s
.21429 .17218 m
.21804 .17218 L
s
.21429 .18928 m
.21804 .18928 L
s
.21429 .20637 m
.21804 .20637 L
s
.21429 .24056 m
.21804 .24056 L
s
.21429 .25765 m
.21804 .25765 L
s
.21429 .27475 m
.21804 .27475 L
s
.21429 .29184 m
.21804 .29184 L
s
.21429 .32603 m
.21804 .32603 L
s
.21429 .34312 m
.21804 .34312 L
s
.21429 .36022 m
.21804 .36022 L
s
.21429 .37731 m
.21804 .37731 L
s
.21429 .4115 m
.21804 .4115 L
s
.21429 .42859 m
.21804 .42859 L
s
.21429 .44569 m
.21804 .44569 L
s
.21429 .46278 m
.21804 .46278 L
s
.21429 .49697 m
.21804 .49697 L
s
.21429 .51406 m
.21804 .51406 L
s
.21429 .53116 m
.21804 .53116 L
s
.21429 .54825 m
.21804 .54825 L
s
.21429 .03543 m
.21804 .03543 L
s
.21429 .01834 m
.21804 .01834 L
s
.21429 .00124 m
.21804 .00124 L
s
.21429 .58244 m
.21804 .58244 L
s
.21429 .59953 m
.21804 .59953 L
s
.21429 .61663 m
.21804 .61663 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
[(phi\\(2t-2\\))] .21429 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .13799 m
.06244 .13799 L
.10458 .13799 L
.14415 .13799 L
.18221 .13799 L
.22272 .13799 L
.26171 .13799 L
.30316 .13799 L
.34309 .13799 L
.3815 .13799 L
.39174 .13799 L
.39675 .13799 L
.40134 .13799 L
.40252 .13799 L
.40381 .13799 L
.40503 .14416 L
.40616 .17054 L
.40745 .20069 L
.40867 .21747 L
.41007 .23266 L
.41134 .24356 L
.42237 .31245 L
.43213 .3594 L
.44244 .40738 L
.44669 .42955 L
.44903 .44054 L
.45125 .45139 L
.4525 .45681 L
.45321 .45586 L
.45386 .45498 L
.45502 .45342 L
.45625 .45475 L
.45739 .45705 L
.45847 .45936 L
.45965 .46317 L
.46092 .46727 L
.48096 .53654 L
.49103 .57279 L
.49379 .5826 L
.49674 .59333 L
.49818 .59848 L
.49888 .601 L
.49953 .60332 L
.50074 .57311 L
.50206 .51647 L
.50331 .47085 L
.5045 .44937 L
.50673 .41618 L
.50799 .40494 L
.50868 .39877 L
Mistroke
.50933 .39025 L
.5106 .37046 L
.51175 .35255 L
.51284 .34807 L
.51384 .34586 L
.51493 .34309 L
.51609 .33279 L
.52082 .28338 L
.52208 .27125 L
.52328 .25981 L
.52394 .2551 L
.52466 .25704 L
.52592 .26042 L
.52711 .26145 L
.52838 .25636 L
.53067 .245 L
.5363 .2129 L
.54146 .17529 L
.54383 .16139 L
.54604 .14792 L
.54715 .14092 L
.54834 .14253 L
.54966 .15081 L
.55085 .15658 L
.55216 .15604 L
.55335 .15554 L
.55467 .1523 L
.55606 .14831 L
.56097 .13698 L
.562 .13216 L
.56313 .12804 L
.56517 .12217 L
.56753 .11675 L
.56969 .1114 L
.57093 .10805 L
.57156 .10591 L
.57226 .10176 L
.57464 .08795 L
.57702 .07798 L
.57926 .06984 L
.58908 .03524 L
.59146 .02644 L
.59278 .02165 L
.59401 .01723 L
.59472 .01472 L
.59548 .01765 L
.59617 .03133 L
.59681 .04395 L
.59807 .06874 L
.59877 .07565 L
Mistroke
.59942 .08032 L
.60055 .08851 L
.60163 .09429 L
.60262 .09692 L
.60369 .09979 L
.60488 .10531 L
.60614 .11288 L
.60732 .1188 L
.6084 .11806 L
.60963 .11721 L
.61076 .11857 L
.61199 .12187 L
.6133 .1256 L
.61551 .13419 L
.61668 .13818 L
.61792 .14188 L
.61855 .14376 L
.61924 .14464 L
.62047 .1408 L
.62171 .13688 L
.62288 .13608 L
.62402 .13632 L
.62506 .13661 L
.6262 .13825 L
.6274 .13997 L
.63267 .1464 L
.63757 .15433 L
.63975 .15674 L
.64082 .15815 L
.64181 .15948 L
.64294 .16046 L
.64418 .15438 L
.64522 .14925 L
.64633 .14542 L
.64748 .1436 L
.64855 .1419 L
.64982 .14112 L
.65098 .1407 L
.65219 .1399 L
.65351 .13824 L
.65476 .13667 L
.65591 .13728 L
.6572 .13798 L
.65785 .13822 L
.65857 .13796 L
.66101 .13699 L
.66238 .13604 L
.66367 .13515 L
.66438 .13483 L
.66516 .13448 L
Mistroke
.6658 .13419 L
.66651 .13387 L
.66782 .13518 L
.66848 .13597 L
.6692 .13682 L
.67048 .1376 L
.67168 .13796 L
.67296 .13823 L
.67419 .13819 L
.67529 .13815 L
.67649 .13833 L
.67775 .13859 L
.67894 .13866 L
.68 .13837 L
.68116 .13806 L
.68242 .13792 L
.68306 .1379 L
.68375 .13788 L
.68499 .13788 L
.68614 .13794 L
.68731 .13801 L
.68841 .13801 L
.68939 .138 L
.69047 .13799 L
.69164 .13799 L
.69288 .13799 L
.69511 .13799 L
.73285 .13799 L
.77304 .13799 L
.81172 .13799 L
.85284 .13799 L
.89245 .13799 L
.93055 .13799 L
.9711 .13799 L
.97619 .13799 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "We can also obtain a continuous scaling function by setting the option ",
  StyleBox["Interpolation", "MR"],
  " to ",
  StyleBox["True", "MR"],
  " in the function ",
  StyleBox["ScalingFunction", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.4.3", "3.22"}],

Cell[TextData[{
  StyleBox["ScalingFunction[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["Interpolation", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.3", "3.23"}],

Cell[TextData[{
  "gives the continuous scaling function by linearly interpolating the values \
of the dyadic points. Its output is an object\[NonBreakingSpace]",
  StyleBox["InterpolatingFunction", "MR"],
  ". The domain of the scaling function is, by default, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-100\), 100]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  ". To alter the interpolation domain to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox[\("tmin"\),
              "TI"], ",", 
            StyleBox[\("tmax"\),
              "TI"]}], "}"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  ", use the option ",
  StyleBox["InterpolationDomain", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.4.3"],
  StyleBox["tmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["tmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". "
}], "Text",
  CellTags->{"S1.4.3", "3.24"}],

Cell["This gives the Daubechies scaling function of order 3.", "MathCaption",
  CellTags->{"S1.4.3", "3.25"}],

Cell[CellGroupData[{

Cell["\<\
phi = ScalingFunction[DaubechiesFilter[3], 6, Interpolation -> \
True]\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-100.`\), 100.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "The output is an object ",
  StyleBox["InterpolatingFunction", "MR"],
  " which we have named ",
  StyleBox["phi", "MR"],
  ". The first argument in ",
  StyleBox["InterpolationFunction", "MR"],
  " is the domain of the interpolating function which assumes the default \
value ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-100\), 100]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.3"],
  ". When the object ",
  StyleBox["InterpolationFunction", "MR"],
  " acts on an argument ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " within the interpolation domain, we obtain the value of the scaling \
function at that particular point ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". "
}], "Text",
  CellTags->{"S1.4.3", "3.26"}],

Cell[TextData[{
  "For example, this gives ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((2.413)\)\)], "InlineFormula",
    CellTags->"S1.4.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.27"}],

Cell[CellGroupData[{

Cell["phi[2.413]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    \(\(-0.115841530946558113`\)\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["\<\
We plot two dilated and translated versions of the scaling function \
together.\
\>", "MathCaption",
  CellTags->{"S1.4.3", "3.28"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{phi[t/2], phi[2t-2]}, {t, 0, 8},
PlotStyle -> {{}, Dashing[{0.02}]}, PlotRange -> All,
AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"phi_3(t/2), phi_3(2t-2)\"]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.150324 0.352526 [
[.2619 .13782 -3 -9 ]
[.2619 .13782 3 0 ]
[.5 .13782 -3 -9 ]
[.5 .13782 3 0 ]
[.7381 .13782 -3 -9 ]
[.7381 .13782 3 0 ]
[.97619 .13782 -3 -9 ]
[.97619 .13782 3 0 ]
[1.025 .15032 0 -4.5 ]
[1.025 .15032 6 4.5 ]
[.01131 .06219 -30 -4.5 ]
[.01131 .06219 0 4.5 ]
[.01131 .23846 -24 -4.5 ]
[.01131 .23846 0 4.5 ]
[.01131 .32659 -18 -4.5 ]
[.01131 .32659 0 4.5 ]
[.01131 .41472 -24 -4.5 ]
[.01131 .41472 0 4.5 ]
[.01131 .50285 -6 -4.5 ]
[.01131 .50285 0 4.5 ]
[.01131 .59098 -24 -4.5 ]
[.01131 .59098 0 4.5 ]
[.5 .63053 -69 0 ]
[.5 .63053 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .15032 m
.2619 .15657 L
s
[(2)] .2619 .13782 0 1 Mshowa
.5 .15032 m
.5 .15657 L
s
[(4)] .5 .13782 0 1 Mshowa
.7381 .15032 m
.7381 .15657 L
s
[(6)] .7381 .13782 0 1 Mshowa
.97619 .15032 m
.97619 .15657 L
s
[(8)] .97619 .13782 0 1 Mshowa
.125 Mabswid
.08333 .15032 m
.08333 .15407 L
s
.14286 .15032 m
.14286 .15407 L
s
.20238 .15032 m
.20238 .15407 L
s
.32143 .15032 m
.32143 .15407 L
s
.38095 .15032 m
.38095 .15407 L
s
.44048 .15032 m
.44048 .15407 L
s
.55952 .15032 m
.55952 .15407 L
s
.61905 .15032 m
.61905 .15407 L
s
.67857 .15032 m
.67857 .15407 L
s
.79762 .15032 m
.79762 .15407 L
s
.85714 .15032 m
.85714 .15407 L
s
.91667 .15032 m
.91667 .15407 L
s
.25 Mabswid
0 .15032 m
1 .15032 L
s
[(t)] 1.025 .15032 -1 0 Mshowa
.02381 .06219 m
.03006 .06219 L
s
[(-0.25)] .01131 .06219 1 0 Mshowa
.02381 .23846 m
.03006 .23846 L
s
[(0.25)] .01131 .23846 1 0 Mshowa
.02381 .32659 m
.03006 .32659 L
s
[(0.5)] .01131 .32659 1 0 Mshowa
.02381 .41472 m
.03006 .41472 L
s
[(0.75)] .01131 .41472 1 0 Mshowa
.02381 .50285 m
.03006 .50285 L
s
[(1)] .01131 .50285 1 0 Mshowa
.02381 .59098 m
.03006 .59098 L
s
[(1.25)] .01131 .59098 1 0 Mshowa
.125 Mabswid
.02381 .07982 m
.02756 .07982 L
s
.02381 .09744 m
.02756 .09744 L
s
.02381 .11507 m
.02756 .11507 L
s
.02381 .1327 m
.02756 .1327 L
s
.02381 .16795 m
.02756 .16795 L
s
.02381 .18558 m
.02756 .18558 L
s
.02381 .2032 m
.02756 .2032 L
s
.02381 .22083 m
.02756 .22083 L
s
.02381 .25608 m
.02756 .25608 L
s
.02381 .27371 m
.02756 .27371 L
s
.02381 .29133 m
.02756 .29133 L
s
.02381 .30896 m
.02756 .30896 L
s
.02381 .34421 m
.02756 .34421 L
s
.02381 .36184 m
.02756 .36184 L
s
.02381 .37947 m
.02756 .37947 L
s
.02381 .39709 m
.02756 .39709 L
s
.02381 .43234 m
.02756 .43234 L
s
.02381 .44997 m
.02756 .44997 L
s
.02381 .4676 m
.02756 .4676 L
s
.02381 .48522 m
.02756 .48522 L
s
.02381 .52048 m
.02756 .52048 L
s
.02381 .5381 m
.02756 .5381 L
s
.02381 .55573 m
.02756 .55573 L
s
.02381 .57336 m
.02756 .57336 L
s
.02381 .04457 m
.02756 .04457 L
s
.02381 .02694 m
.02756 .02694 L
s
.02381 .00931 m
.02756 .00931 L
s
.02381 .60861 m
.02756 .60861 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi_3\\(t/2\\), phi_3\\(2t-2\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .15032 m
.06244 .21073 L
.10458 .2849 L
.14415 .36578 L
.18221 .4304 L
.22272 .51252 L
.24141 .55543 L
.25127 .57826 L
.25666 .59116 L
.2593 .59748 L
.26045 .60027 L
.26171 .60332 L
.26301 .6022 L
.26425 .60042 L
.26698 .59585 L
.27279 .58615 L
.28302 .56497 L
.30316 .51889 L
.3438 .42067 L
.3626 .36847 L
.37248 .33565 L
.37789 .31674 L
.37924 .31192 L
.38053 .30735 L
.38168 .30464 L
.38293 .30257 L
.3855 .29847 L
.38825 .29434 L
.39408 .28522 L
.40434 .26739 L
.42451 .22861 L
.46529 .12275 L
.48555 .06145 L
.49038 .04564 L
.49547 .02917 L
.49757 .02233 L
.49872 .01852 L
.49981 .01493 L
.5011 .01472 L
.50227 .01515 L
.50337 .01556 L
.50456 .01636 L
.52273 .03091 L
.54231 .05047 L
.58323 .09117 L
.60359 .11889 L
.60869 .12676 L
.61354 .13492 L
.61565 .13882 L
.61789 .14293 L
Mistroke
.61918 .14503 L
.62035 .14489 L
.62144 .14476 L
.62263 .14462 L
.62378 .1443 L
.62499 .14395 L
.62716 .14348 L
.62837 .14342 L
.62952 .14337 L
.63084 .14292 L
.63204 .14214 L
.63311 .14144 L
.63424 .14095 L
.63548 .14111 L
.63663 .14127 L
.63768 .14141 L
.63866 .14137 L
.63982 .14133 L
.6409 .14129 L
.64205 .1409 L
.6433 .14021 L
.64583 .13885 L
.64696 .13826 L
.64802 .13771 L
.64924 .13742 L
.65035 .13772 L
.65272 .13835 L
.65523 .13894 L
.65654 .13919 L
.65729 .13922 L
.65799 .13925 L
.65921 .13931 L
.66052 .13947 L
.66174 .13974 L
.66308 .14005 L
.66375 .14017 L
.66448 .13995 L
.66579 .13955 L
.67068 .138 L
.67349 .13743 L
.67423 .13729 L
.67502 .13713 L
.67576 .1369 L
.67644 .13668 L
.67774 .13628 L
.67897 .13636 L
.67966 .13693 L
.6803 .13747 L
.68174 .13867 L
.70185 .15647 L
Mistroke
.72218 .17122 L
.72728 .17522 L
.73213 .1792 L
.73423 .18076 L
.73648 .18259 L
.73777 .18364 L
.73894 .18371 L
.74011 .18344 L
.74122 .18319 L
.74999 .18051 L
.75946 .17711 L
.77908 .16984 L
.8201 .15592 L
.84054 .14765 L
.85051 .14279 L
.8528 .14154 L
.85524 .14023 L
.85624 .13969 L
.85731 .13923 L
.8585 .13939 L
.85961 .13955 L
.86412 .1404 L
.86903 .14122 L
.87795 .14289 L
.8976 .14662 L
.90799 .14889 L
.91305 .15026 L
.91526 .15095 L
.91651 .15134 L
.91765 .15133 L
.91887 .15126 L
.92016 .15118 L
.92129 .15108 L
.92253 .15097 L
.92383 .15085 L
.92455 .15082 L
.92522 .1508 L
.92644 .15077 L
.92773 .15074 L
.92847 .15066 L
.92914 .15057 L
.93044 .1504 L
.93117 .1503 L
.93196 .15026 L
.93271 .15026 L
.93339 .15027 L
.93464 .15027 L
.93534 .15028 L
.936 .15027 L
.93734 .15024 L
Mistroke
.93807 .15023 L
.93876 .15022 L
.93995 .15011 L
.94127 .14998 L
.94359 .14975 L
.94488 .14963 L
.94611 .14951 L
.94679 .14952 L
.94753 .1496 L
.94883 .14974 L
.95344 .15025 L
.95835 .15069 L
.95955 .15085 L
.96085 .15103 L
.96208 .15111 L
.9632 .15113 L
.9653 .15119 L
.96641 .15122 L
.9676 .15126 L
.96873 .1513 L
.96976 .15138 L
.97178 .15154 L
.97619 .15182 L
Mfstroke
[ .02 ] 0 setdash
.02381 .15032 m
.06244 .15032 L
.08255 .15032 L
.10458 .15032 L
.11448 .15032 L
.12507 .15032 L
.1302 .15032 L
.13506 .15032 L
.13942 .15032 L
.14061 .15032 L
.14188 .15032 L
.14296 .15087 L
.14415 .15741 L
.16519 .29938 L
.18444 .44502 L
.19394 .52521 L
.19896 .57103 L
.20041 .58487 L
.20112 .59163 L
.20177 .59789 L
.20299 .60026 L
.20432 .59088 L
.21411 .50509 L
.22321 .41785 L
.24363 .22389 L
.25361 .11766 L
.25833 .06096 L
.26041 .03384 L
.26159 .01848 L
.2627 .01549 L
.26375 .01863 L
.26488 .02133 L
.2661 .02671 L
.26721 .02935 L
.26835 .03627 L
.26959 .04383 L
.2709 .04572 L
.27211 .04952 L
.28102 .08594 L
.28337 .09253 L
.28469 .0976 L
.28591 .10573 L
.28811 .12095 L
.29052 .13665 L
.29117 .14138 L
.29186 .14495 L
.29311 .144 L
.29584 .14115 L
.29713 .14128 L
.29836 .13884 L
Mistroke
.29947 .13769 L
.30067 .1389 L
.30192 .13937 L
.30323 .13969 L
.30392 .13885 L
.30468 .13786 L
.30536 .13736 L
.306 .1367 L
.30727 .13844 L
.30842 .14271 L
.31102 .15185 L
.31588 .16754 L
.31802 .17283 L
.32038 .18053 L
.32168 .18368 L
.32289 .1823 L
.32555 .17849 L
.33117 .17047 L
.34137 .15656 L
.34648 .1489 L
.34897 .14392 L
.35005 .14166 L
.35123 .13922 L
.35246 .14 L
.35362 .14078 L
.35618 .14276 L
.36159 .14676 L
.36401 .14902 L
.3652 .1503 L
.36628 .15134 L
.36742 .15101 L
.36864 .15076 L
.36929 .15052 L
.36998 .15026 L
.37123 .15024 L
.37227 .14996 L
.37341 .14952 L
.37464 .14997 L
.37579 .15043 L
.3768 .15086 L
.37787 .15115 L
.37903 .15129 L
.38011 .15161 L
.38134 .15178 L
.38203 .15171 L
.38267 .15164 L
.3851 .15132 L
.38964 .15081 L
.39087 .15066 L
.39155 .15058 L
Mistroke
.39219 .1505 L
.39344 .15026 L
.39458 .15003 L
.39578 .14977 L
.39708 .14986 L
.39982 .1501 L
.40107 .15014 L
.40224 .15026 L
.4033 .15038 L
.40444 .15034 L
.40568 .15032 L
.40699 .15028 L
.40812 .15033 L
.40935 .15037 L
.4105 .15039 L
.41155 .15039 L
.41277 .15037 L
.41392 .15036 L
.41491 .15035 L
.41596 .15034 L
.41712 .15032 L
.41818 .1503 L
.41932 .15031 L
.42057 .15031 L
.42187 .15033 L
.42308 .15032 L
.42422 .15032 L
.42525 .15033 L
.42644 .15033 L
.42756 .15033 L
.42879 .15032 L
.43009 .15032 L
.4312 .15032 L
.43241 .15032 L
.43372 .15032 L
.43446 .15032 L
.43513 .15032 L
.43643 .15032 L
.43767 .15032 L
.43882 .15032 L
.43987 .15032 L
.44108 .15032 L
.44221 .15032 L
.44642 .15032 L
.45595 .15032 L
.49458 .15032 L
.53565 .15032 L
.57521 .15032 L
.61326 .15032 L
.65375 .15032 L
Mistroke
.69273 .15032 L
.73417 .15032 L
.77408 .15032 L
.81249 .15032 L
.85334 .15032 L
.89268 .15032 L
.9305 .15032 L
.97078 .15032 L
.97619 .15032 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["This calculates the Daubechies filter of order 12.", "MathCaption",
  CellTags->{"S1.4.3", "3.29"}],

Cell["d12 = DaubechiesFilter[12];", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S1.4.3"],

Cell["Here is the Daubechies scaling function of order 12.", "MathCaption",
  CellTags->{"S1.4.3", "3.30"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[d12, 6], PlotRange -> All,
PlotJoined -> True, AxesLabel -> {\"t\", \"phi_12(t)\"}]\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0414079 0.209878 0.419644 [
[.23085 .19738 -3 -9 ]
[.23085 .19738 3 0 ]
[.43789 .19738 -6 -9 ]
[.43789 .19738 6 0 ]
[.64493 .19738 -6 -9 ]
[.64493 .19738 6 0 ]
[.85197 .19738 -6 -9 ]
[.85197 .19738 6 0 ]
[1.025 .20988 0 -4.5 ]
[1.025 .20988 6 4.5 ]
[.01131 .04202 -24 -4.5 ]
[.01131 .04202 0 4.5 ]
[.01131 .12595 -24 -4.5 ]
[.01131 .12595 0 4.5 ]
[.01131 .29381 -18 -4.5 ]
[.01131 .29381 0 4.5 ]
[.01131 .37774 -18 -4.5 ]
[.01131 .37774 0 4.5 ]
[.01131 .46166 -18 -4.5 ]
[.01131 .46166 0 4.5 ]
[.01131 .54559 -18 -4.5 ]
[.01131 .54559 0 4.5 ]
[.02381 .64303 -27 0 ]
[.02381 .64303 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23085 .20988 m
.23085 .21613 L
s
[(5)] .23085 .19738 0 1 Mshowa
.43789 .20988 m
.43789 .21613 L
s
[(10)] .43789 .19738 0 1 Mshowa
.64493 .20988 m
.64493 .21613 L
s
[(15)] .64493 .19738 0 1 Mshowa
.85197 .20988 m
.85197 .21613 L
s
[(20)] .85197 .19738 0 1 Mshowa
.125 Mabswid
.06522 .20988 m
.06522 .21363 L
s
.10663 .20988 m
.10663 .21363 L
s
.14803 .20988 m
.14803 .21363 L
s
.18944 .20988 m
.18944 .21363 L
s
.27226 .20988 m
.27226 .21363 L
s
.31366 .20988 m
.31366 .21363 L
s
.35507 .20988 m
.35507 .21363 L
s
.39648 .20988 m
.39648 .21363 L
s
.4793 .20988 m
.4793 .21363 L
s
.5207 .20988 m
.5207 .21363 L
s
.56211 .20988 m
.56211 .21363 L
s
.60352 .20988 m
.60352 .21363 L
s
.68634 .20988 m
.68634 .21363 L
s
.72774 .20988 m
.72774 .21363 L
s
.76915 .20988 m
.76915 .21363 L
s
.81056 .20988 m
.81056 .21363 L
s
.89337 .20988 m
.89337 .21363 L
s
.93478 .20988 m
.93478 .21363 L
s
.97619 .20988 m
.97619 .21363 L
s
.25 Mabswid
0 .20988 m
1 .20988 L
s
[(t)] 1.025 .20988 -1 0 Mshowa
.02381 .04202 m
.03006 .04202 L
s
[(-0.4)] .01131 .04202 1 0 Mshowa
.02381 .12595 m
.03006 .12595 L
s
[(-0.2)] .01131 .12595 1 0 Mshowa
.02381 .29381 m
.03006 .29381 L
s
[(0.2)] .01131 .29381 1 0 Mshowa
.02381 .37774 m
.03006 .37774 L
s
[(0.4)] .01131 .37774 1 0 Mshowa
.02381 .46166 m
.03006 .46166 L
s
[(0.6)] .01131 .46166 1 0 Mshowa
.02381 .54559 m
.03006 .54559 L
s
[(0.8)] .01131 .54559 1 0 Mshowa
.125 Mabswid
.02381 .063 m
.02756 .063 L
s
.02381 .08399 m
.02756 .08399 L
s
.02381 .10497 m
.02756 .10497 L
s
.02381 .14693 m
.02756 .14693 L
s
.02381 .16791 m
.02756 .16791 L
s
.02381 .1889 m
.02756 .1889 L
s
.02381 .23086 m
.02756 .23086 L
s
.02381 .25184 m
.02756 .25184 L
s
.02381 .27282 m
.02756 .27282 L
s
.02381 .31479 m
.02756 .31479 L
s
.02381 .33577 m
.02756 .33577 L
s
.02381 .35675 m
.02756 .35675 L
s
.02381 .39872 m
.02756 .39872 L
s
.02381 .4197 m
.02756 .4197 L
s
.02381 .44068 m
.02756 .44068 L
s
.02381 .48265 m
.02756 .48265 L
s
.02381 .50363 m
.02756 .50363 L
s
.02381 .52461 m
.02756 .52461 L
s
.02381 .02104 m
.02756 .02104 L
s
.02381 6e-05 m
.02756 6e-05 L
s
.02381 .56658 m
.02756 .56658 L
s
.02381 .58756 m
.02756 .58756 L
s
.02381 .60854 m
.02756 .60854 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi_12\\(t\\))] .02381 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .20988 m
.02446 .20988 L
.0251 .20988 L
.02575 .20988 L
.0264 .20988 L
.02704 .20988 L
.02769 .20988 L
.02834 .20988 L
.02899 .20988 L
.02963 .20988 L
.03028 .20988 L
.03093 .20988 L
.03157 .20988 L
.03222 .20988 L
.03287 .20988 L
.03351 .20988 L
.03416 .20988 L
.03481 .20988 L
.03546 .20988 L
.0361 .20988 L
.03675 .20988 L
.0374 .20988 L
.03804 .20988 L
.03869 .20989 L
.03934 .20989 L
.03998 .20989 L
.04063 .20989 L
.04128 .2099 L
.04193 .2099 L
.04257 .20991 L
.04322 .20991 L
.04387 .20992 L
.04451 .20993 L
.04516 .20994 L
.04581 .20995 L
.04645 .20997 L
.0471 .20998 L
.04775 .21 L
.0484 .21002 L
.04904 .21004 L
.04969 .21007 L
.05034 .2101 L
.05098 .21013 L
.05163 .21017 L
.05228 .21021 L
.05292 .21025 L
.05357 .2103 L
.05422 .21036 L
.05487 .21042 L
.05551 .21049 L
Mistroke
.05616 .21056 L
.05681 .21065 L
.05745 .21074 L
.0581 .21084 L
.05875 .21094 L
.05939 .21106 L
.06004 .21119 L
.06069 .21133 L
.06134 .21149 L
.06198 .21165 L
.06263 .21183 L
.06328 .21203 L
.06392 .21224 L
.06457 .21247 L
.06522 .21271 L
.06586 .21297 L
.06651 .21326 L
.06716 .21356 L
.06781 .21389 L
.06845 .21424 L
.0691 .21462 L
.06975 .21502 L
.07039 .21545 L
.07104 .21591 L
.07169 .2164 L
.07233 .21692 L
.07298 .21748 L
.07363 .21807 L
.07428 .2187 L
.07492 .21937 L
.07557 .22008 L
.07622 .22083 L
.07686 .22163 L
.07751 .22247 L
.07816 .22336 L
.0788 .22431 L
.07945 .2253 L
.0801 .22635 L
.08075 .22746 L
.08139 .22862 L
.08204 .22985 L
.08269 .23114 L
.08333 .23249 L
.08398 .23391 L
.08463 .2354 L
.08527 .23696 L
.08592 .2386 L
.08657 .2403 L
.08722 .24209 L
.08786 .24396 L
Mistroke
.08851 .2459 L
.08916 .24793 L
.0898 .25005 L
.09045 .25225 L
.0911 .25454 L
.09174 .25692 L
.09239 .2594 L
.09304 .26196 L
.09369 .26462 L
.09433 .26738 L
.09498 .27023 L
.09563 .27318 L
.09627 .27623 L
.09692 .27938 L
.09757 .28263 L
.09821 .28599 L
.09886 .28944 L
.09951 .293 L
.10016 .29667 L
.1008 .30043 L
.10145 .3043 L
.1021 .30828 L
.10274 .31235 L
.10339 .31653 L
.10404 .32082 L
.10468 .3252 L
.10533 .32969 L
.10598 .33427 L
.10663 .33895 L
.10727 .34373 L
.10792 .34861 L
.10857 .35357 L
.10921 .35863 L
.10986 .36377 L
.11051 .369 L
.11115 .37431 L
.1118 .37969 L
.11245 .38515 L
.1131 .39068 L
.11374 .39628 L
.11439 .40193 L
.11504 .40764 L
.11568 .4134 L
.11633 .41921 L
.11698 .42506 L
.11762 .43094 L
.11827 .43685 L
.11892 .44277 L
.11957 .44872 L
.12021 .45467 L
Mistroke
.12086 .46062 L
.12151 .46656 L
.12215 .47249 L
.1228 .4784 L
.12345 .48427 L
.12409 .49011 L
.12474 .49589 L
.12539 .50163 L
.12604 .50729 L
.12668 .51288 L
.12733 .51839 L
.12798 .52381 L
.12862 .52913 L
.12927 .53433 L
.12992 .53942 L
.13056 .54438 L
.13121 .5492 L
.13186 .55387 L
.13251 .55839 L
.13315 .56274 L
.1338 .56692 L
.13445 .57091 L
.13509 .57472 L
.13574 .57832 L
.13639 .58172 L
.13703 .5849 L
.13768 .58785 L
.13833 .59058 L
.13898 .59306 L
.13962 .59529 L
.14027 .59726 L
.14092 .59897 L
.14156 .60041 L
.14221 .60158 L
.14286 .60245 L
.1435 .60303 L
.14415 .60332 L
.1448 .6033 L
.14545 .60297 L
.14609 .60232 L
.14674 .60136 L
.14739 .60006 L
.14803 .59844 L
.14868 .59649 L
.14933 .59421 L
.14997 .59158 L
.15062 .58862 L
.15127 .58532 L
.15192 .58168 L
.15256 .5777 L
Mistroke
.15321 .57338 L
.15386 .56872 L
.1545 .56372 L
.15515 .55839 L
.1558 .55274 L
.15644 .54675 L
.15709 .54045 L
.15774 .53382 L
.15839 .52689 L
.15903 .51965 L
.15968 .51212 L
.16033 .5043 L
.16097 .49619 L
.16162 .48782 L
.16227 .47918 L
.16291 .47029 L
.16356 .46116 L
.16421 .45181 L
.16486 .44223 L
.1655 .43246 L
.16615 .4225 L
.1668 .41236 L
.16744 .40206 L
.16809 .39162 L
.16874 .38104 L
.16938 .37035 L
.17003 .35956 L
.17068 .34869 L
.17133 .33775 L
.17197 .32676 L
.17262 .31573 L
.17327 .30468 L
.17391 .29362 L
.17456 .28258 L
.17521 .27156 L
.17585 .26059 L
.1765 .24967 L
.17715 .23883 L
.1778 .22808 L
.17844 .21743 L
.17909 .2069 L
.17974 .19651 L
.18038 .18627 L
.18103 .1762 L
.18168 .1663 L
.18232 .1566 L
.18297 .14712 L
.18362 .13786 L
.18427 .12884 L
.18491 .12009 L
Mistroke
.18556 .1116 L
.18621 .10339 L
.18685 .09549 L
.1875 .08789 L
.18815 .08062 L
.18879 .07368 L
.18944 .06709 L
.19009 .06085 L
.19073 .05498 L
.19138 .04948 L
.19203 .04436 L
.19268 .03963 L
.19332 .0353 L
.19397 .03138 L
.19462 .02786 L
.19526 .02475 L
.19591 .02206 L
.19656 .01978 L
.1972 .01793 L
.19785 .01649 L
.1985 .01548 L
.19915 .01489 L
.19979 .01472 L
.20044 .01496 L
.20109 .01562 L
.20173 .01668 L
.20238 .01815 L
.20303 .02001 L
.20367 .02226 L
.20432 .02488 L
.20497 .02788 L
.20562 .03123 L
.20626 .03492 L
.20691 .03894 L
.20756 .04328 L
.2082 .04792 L
.20885 .05285 L
.2095 .05804 L
.21014 .0635 L
.21079 .06919 L
.21144 .0751 L
.21209 .08122 L
.21273 .08752 L
.21338 .094 L
.21403 .10063 L
.21467 .1074 L
.21532 .11429 L
.21597 .1213 L
.21661 .12839 L
.21726 .13557 L
Mistroke
.21791 .1428 L
.21856 .15008 L
.2192 .1574 L
.21985 .16472 L
.2205 .17205 L
.22114 .17936 L
.22179 .18665 L
.22244 .19389 L
.22308 .20107 L
.22373 .20817 L
.22438 .21518 L
.22503 .22209 L
.22567 .22888 L
.22632 .23553 L
.22697 .24203 L
.22761 .24836 L
.22826 .25452 L
.22891 .26049 L
.22955 .26626 L
.2302 .27181 L
.23085 .27714 L
.2315 .28223 L
.23214 .28709 L
.23279 .29169 L
.23344 .29602 L
.23408 .30009 L
.23473 .30388 L
.23538 .30738 L
.23602 .3106 L
.23667 .31351 L
.23732 .31613 L
.23797 .31844 L
.23861 .32043 L
.23926 .32212 L
.23991 .32349 L
.24055 .32454 L
.2412 .32527 L
.24185 .32567 L
.24249 .32576 L
.24314 .32554 L
.24379 .325 L
.24444 .32416 L
.24508 .32301 L
.24573 .32158 L
.24638 .31987 L
.24702 .31788 L
.24767 .31564 L
.24832 .31315 L
.24896 .31043 L
.24961 .30749 L
Mistroke
.25026 .30434 L
.25091 .30101 L
.25155 .29749 L
.2522 .29382 L
.25285 .29 L
.25349 .28606 L
.25414 .282 L
.25479 .27783 L
.25543 .27358 L
.25608 .26925 L
.25673 .26486 L
.25738 .26041 L
.25802 .25592 L
.25867 .2514 L
.25932 .24686 L
.25996 .24231 L
.26061 .23776 L
.26126 .23323 L
.2619 .22872 L
.26255 .22424 L
.2632 .21981 L
.26385 .21544 L
.26449 .21113 L
.26514 .20689 L
.26579 .20273 L
.26643 .19867 L
.26708 .1947 L
.26773 .19085 L
.26837 .18711 L
.26902 .1835 L
.26967 .18002 L
.27032 .17668 L
.27096 .17348 L
.27161 .17043 L
.27226 .16753 L
.2729 .16479 L
.27355 .1622 L
.2742 .15977 L
.27484 .15751 L
.27549 .15542 L
.27614 .1535 L
.27679 .15176 L
.27743 .1502 L
.27808 .14882 L
.27873 .14763 L
.27937 .14663 L
.28002 .14583 L
.28067 .14521 L
.28131 .1448 L
.28196 .14458 L
Mistroke
.28261 .14457 L
.28326 .14475 L
.2839 .14514 L
.28455 .14573 L
.2852 .14652 L
.28584 .14749 L
.28649 .14865 L
.28714 .14999 L
.28778 .15149 L
.28843 .15315 L
.28908 .15496 L
.28973 .1569 L
.29037 .15897 L
.29102 .16115 L
.29167 .16344 L
.29231 .16581 L
.29296 .16826 L
.29361 .17078 L
.29425 .17335 L
.2949 .17596 L
.29555 .1786 L
.2962 .18127 L
.29684 .18394 L
.29749 .18662 L
.29814 .18929 L
.29878 .19196 L
.29943 .19461 L
.30008 .19723 L
.30072 .19982 L
.30137 .20237 L
.30202 .20488 L
.30267 .20733 L
.30331 .20972 L
.30396 .21205 L
.30461 .2143 L
.30525 .21648 L
.3059 .21857 L
.30655 .22058 L
.30719 .22251 L
.30784 .22434 L
.30849 .22608 L
.30914 .22772 L
.30978 .22927 L
.31043 .23072 L
.31108 .23207 L
.31172 .23333 L
.31237 .23449 L
.31302 .23555 L
.31366 .23653 L
.31431 .23743 L
Mistroke
.31496 .23824 L
.31561 .23896 L
.31625 .23961 L
.3169 .24018 L
.31755 .24066 L
.31819 .24107 L
.31884 .24139 L
.31949 .24163 L
.32013 .24178 L
.32078 .24185 L
.32143 .24183 L
.32208 .24172 L
.32272 .24153 L
.32337 .24124 L
.32402 .24085 L
.32466 .24038 L
.32531 .2398 L
.32596 .23914 L
.3266 .23838 L
.32725 .23753 L
.3279 .2366 L
.32855 .23559 L
.32919 .2345 L
.32984 .23335 L
.33049 .23214 L
.33113 .23088 L
.33178 .22958 L
.33243 .22824 L
.33307 .22686 L
.33372 .22546 L
.33437 .22405 L
.33502 .22262 L
.33566 .22118 L
.33631 .21975 L
.33696 .21832 L
.3376 .2169 L
.33825 .21551 L
.3389 .21413 L
.33954 .21279 L
.34019 .21147 L
.34084 .21018 L
.34149 .20893 L
.34213 .20772 L
.34278 .20655 L
.34343 .20543 L
.34407 .20437 L
.34472 .20337 L
.34537 .20243 L
.34601 .20156 L
.34666 .20076 L
Mistroke
.34731 .20002 L
.34796 .19936 L
.3486 .19877 L
.34925 .19825 L
.3499 .1978 L
.35054 .19741 L
.35119 .19709 L
.35184 .19683 L
.35248 .19663 L
.35313 .19649 L
.35378 .19639 L
.35443 .19635 L
.35507 .19634 L
.35572 .19636 L
.35637 .19642 L
.35701 .1965 L
.35766 .1966 L
.35831 .19672 L
.35895 .19686 L
.3596 .19702 L
.36025 .1972 L
.3609 .19739 L
.36154 .19761 L
.36219 .19785 L
.36284 .19811 L
.36348 .19838 L
.36413 .19868 L
.36478 .199 L
.36542 .19935 L
.36607 .19971 L
.36672 .2001 L
.36737 .20052 L
.36801 .20096 L
.36866 .20142 L
.36931 .20191 L
.36995 .20241 L
.3706 .20293 L
.37125 .20347 L
.37189 .20401 L
.37254 .20455 L
.37319 .20511 L
.37384 .20566 L
.37448 .20622 L
.37513 .20678 L
.37578 .20733 L
.37642 .20789 L
.37707 .20844 L
.37772 .20899 L
.37836 .20953 L
.37901 .21006 L
Mistroke
.37966 .21058 L
.38031 .21109 L
.38095 .21159 L
.3816 .21207 L
.38225 .21253 L
.38289 .21298 L
.38354 .2134 L
.38419 .2138 L
.38483 .21418 L
.38548 .21452 L
.38613 .21483 L
.38678 .21511 L
.38742 .21534 L
.38807 .21554 L
.38872 .21569 L
.38936 .2158 L
.39001 .21588 L
.39066 .21591 L
.3913 .21591 L
.39195 .21587 L
.3926 .2158 L
.39325 .21571 L
.39389 .21558 L
.39454 .21543 L
.39519 .21527 L
.39583 .21508 L
.39648 .21488 L
.39713 .21468 L
.39777 .21447 L
.39842 .21425 L
.39907 .21404 L
.39972 .21383 L
.40036 .21363 L
.40101 .21342 L
.40166 .21322 L
.4023 .21303 L
.40295 .21283 L
.4036 .21264 L
.40424 .21245 L
.40489 .21227 L
.40554 .21209 L
.40619 .21191 L
.40683 .21173 L
.40748 .21156 L
.40813 .2114 L
.40877 .21124 L
.40942 .21108 L
.41007 .21093 L
.41071 .21078 L
.41136 .21063 L
Mistroke
.41201 .21049 L
.41266 .21036 L
.4133 .21023 L
.41395 .21011 L
.4146 .21 L
.41524 .20989 L
.41589 .20979 L
.41654 .20969 L
.41718 .20959 L
.41783 .20949 L
.41848 .20939 L
.41913 .20929 L
.41977 .20919 L
.42042 .20909 L
.42107 .20898 L
.42171 .20887 L
.42236 .20877 L
.42301 .20866 L
.42365 .20856 L
.4243 .20846 L
.42495 .20836 L
.4256 .20826 L
.42624 .20817 L
.42689 .20809 L
.42754 .20802 L
.42818 .20796 L
.42883 .20792 L
.42948 .20789 L
.43012 .20787 L
.43077 .20787 L
.43142 .20789 L
.43207 .20792 L
.43271 .20796 L
.43336 .20802 L
.43401 .20808 L
.43465 .20816 L
.4353 .20824 L
.43595 .20833 L
.43659 .20842 L
.43724 .20852 L
.43789 .20862 L
.43854 .20873 L
.43918 .20883 L
.43983 .20894 L
.44048 .20904 L
.44112 .20914 L
.44177 .20924 L
.44242 .20933 L
.44306 .20942 L
.44371 .20951 L
Mistroke
.44436 .2096 L
.44501 .20968 L
.44565 .20976 L
.4463 .20984 L
.44695 .20992 L
.44759 .20999 L
.44824 .21005 L
.44889 .21011 L
.44953 .21016 L
.45018 .21021 L
.45083 .21024 L
.45148 .21027 L
.45212 .2103 L
.45277 .21031 L
.45342 .21032 L
.45406 .21032 L
.45471 .21032 L
.45536 .21031 L
.456 .21029 L
.45665 .21027 L
.4573 .21025 L
.45795 .21023 L
.45859 .2102 L
.45924 .21018 L
.45989 .21016 L
.46053 .21014 L
.46118 .21012 L
.46183 .21011 L
.46247 .2101 L
.46312 .2101 L
.46377 .2101 L
.46442 .2101 L
.46506 .21011 L
.46571 .21012 L
.46636 .21012 L
.467 .21013 L
.46765 .21015 L
.4683 .21016 L
.46894 .21017 L
.46959 .21018 L
.47024 .21019 L
.47089 .21019 L
.47153 .21019 L
.47218 .21019 L
.47283 .21019 L
.47347 .21018 L
.47412 .21018 L
.47477 .21017 L
.47541 .21016 L
.47606 .21014 L
Mistroke
.47671 .21013 L
.47736 .21012 L
.478 .21011 L
.47865 .21009 L
.4793 .21008 L
.47994 .21006 L
.48059 .21004 L
.48124 .21002 L
.48188 .21 L
.48253 .20998 L
.48318 .20996 L
.48383 .20994 L
.48447 .20992 L
.48512 .2099 L
.48577 .20987 L
.48641 .20985 L
.48706 .20982 L
.48771 .2098 L
.48835 .20977 L
.489 .20975 L
.48965 .20973 L
.4903 .20971 L
.49094 .20969 L
.49159 .20968 L
.49224 .20967 L
.49288 .20967 L
.49353 .20966 L
.49418 .20966 L
.49482 .20967 L
.49547 .20968 L
.49612 .20968 L
.49677 .2097 L
.49741 .20971 L
.49806 .20972 L
.49871 .20974 L
.49935 .20976 L
.5 .20978 L
.50065 .20979 L
.50129 .20981 L
.50194 .20983 L
.50259 .20984 L
.50323 .20985 L
.50388 .20986 L
.50453 .20987 L
.50518 .20988 L
.50582 .20989 L
.50647 .20989 L
.50712 .2099 L
.50776 .2099 L
.50841 .2099 L
Mistroke
.50906 .20991 L
.5097 .20991 L
.51035 .20991 L
.511 .20991 L
.51165 .20991 L
.51229 .20991 L
.51294 .20991 L
.51359 .20991 L
.51423 .20991 L
.51488 .20991 L
.51553 .2099 L
.51617 .2099 L
.51682 .2099 L
.51747 .20989 L
.51812 .20989 L
.51876 .20988 L
.51941 .20987 L
.52006 .20987 L
.5207 .20986 L
.52135 .20986 L
.522 .20985 L
.52264 .20985 L
.52329 .20985 L
.52394 .20985 L
.52459 .20985 L
.52523 .20985 L
.52588 .20985 L
.52653 .20985 L
.52717 .20985 L
.52782 .20986 L
.52847 .20986 L
.52911 .20987 L
.52976 .20987 L
.53041 .20988 L
.53106 .20989 L
.5317 .20989 L
.53235 .2099 L
.533 .2099 L
.53364 .20991 L
.53429 .20991 L
.53494 .20991 L
.53558 .20991 L
.53623 .20991 L
.53688 .20991 L
.53753 .20991 L
.53817 .20991 L
.53882 .20991 L
.53947 .20991 L
.54011 .20991 L
.54076 .2099 L
Mistroke
.54141 .2099 L
.54205 .2099 L
.5427 .2099 L
.54335 .20989 L
.544 .20989 L
.54464 .20989 L
.54529 .20989 L
.54594 .20989 L
.54658 .20988 L
.54723 .20988 L
.54788 .20988 L
.54852 .20988 L
.54917 .20987 L
.54982 .20987 L
.55047 .20987 L
.55111 .20987 L
.55176 .20986 L
.55241 .20986 L
.55305 .20986 L
.5537 .20986 L
.55435 .20986 L
.55499 .20986 L
.55564 .20986 L
.55629 .20986 L
.55694 .20986 L
.55758 .20986 L
.55823 .20986 L
.55888 .20986 L
.55952 .20986 L
.56017 .20987 L
.56082 .20987 L
.56146 .20987 L
.56211 .20988 L
.56276 .20988 L
.56341 .20988 L
.56405 .20988 L
.5647 .20988 L
.56535 .20989 L
.56599 .20989 L
.56664 .20989 L
.56729 .20989 L
.56793 .20989 L
.56858 .20989 L
.56923 .20989 L
.56988 .20989 L
.57052 .20989 L
.57117 .20989 L
.57182 .20989 L
.57246 .20989 L
.57311 .20989 L
Mistroke
.57376 .20988 L
.5744 .20988 L
.57505 .20988 L
.5757 .20988 L
.57635 .20988 L
.57699 .20988 L
.57764 .20988 L
.57829 .20988 L
.57893 .20988 L
.57958 .20988 L
.58023 .20988 L
.58087 .20988 L
.58152 .20988 L
.58217 .20988 L
.58282 .20987 L
.58346 .20987 L
.58411 .20987 L
.58476 .20987 L
.5854 .20987 L
.58605 .20987 L
.5867 .20987 L
.58734 .20987 L
.58799 .20987 L
.58864 .20987 L
.58929 .20987 L
.58993 .20987 L
.59058 .20987 L
.59123 .20987 L
.59187 .20988 L
.59252 .20988 L
.59317 .20988 L
.59381 .20988 L
.59446 .20988 L
.59511 .20988 L
.59576 .20988 L
.5964 .20988 L
.59705 .20988 L
.5977 .20988 L
.59834 .20988 L
.59899 .20988 L
.59964 .20988 L
.60028 .20988 L
.60093 .20988 L
.60158 .20988 L
.60223 .20988 L
.60287 .20988 L
.60352 .20988 L
.60417 .20988 L
.60481 .20988 L
.60546 .20988 L
Mistroke
.60611 .20988 L
.60675 .20988 L
.6074 .20988 L
.60805 .20988 L
.6087 .20988 L
.60934 .20988 L
.60999 .20988 L
.61064 .20988 L
.61128 .20988 L
.61193 .20988 L
.61258 .20988 L
.61322 .20988 L
.61387 .20988 L
.61452 .20988 L
.61517 .20988 L
.61581 .20988 L
.61646 .20988 L
.61711 .20988 L
.61775 .20988 L
.6184 .20988 L
.61905 .20988 L
.61969 .20988 L
.62034 .20988 L
.62099 .20988 L
.62164 .20988 L
.62228 .20988 L
.62293 .20988 L
.62358 .20988 L
.62422 .20988 L
.62487 .20988 L
.62552 .20988 L
.62616 .20988 L
.62681 .20988 L
.62746 .20988 L
.62811 .20988 L
.62875 .20988 L
.6294 .20988 L
.63005 .20988 L
.63069 .20988 L
.63134 .20988 L
.63199 .20988 L
.63263 .20988 L
.63328 .20988 L
.63393 .20988 L
.63458 .20988 L
.63522 .20988 L
.63587 .20988 L
.63652 .20988 L
.63716 .20988 L
.63781 .20988 L
Mistroke
.63846 .20988 L
.6391 .20988 L
.63975 .20988 L
.6404 .20988 L
.64105 .20988 L
.64169 .20988 L
.64234 .20988 L
.64299 .20988 L
.64363 .20988 L
.64428 .20988 L
.64493 .20988 L
.64557 .20988 L
.64622 .20988 L
.64687 .20988 L
.64752 .20988 L
.64816 .20988 L
.64881 .20988 L
.64946 .20988 L
.6501 .20988 L
.65075 .20988 L
.6514 .20988 L
.65204 .20988 L
.65269 .20988 L
.65334 .20988 L
.65399 .20988 L
.65463 .20988 L
.65528 .20988 L
.65593 .20988 L
.65657 .20988 L
.65722 .20988 L
.65787 .20988 L
.65851 .20988 L
.65916 .20988 L
.65981 .20988 L
.66046 .20988 L
.6611 .20988 L
.66175 .20988 L
.6624 .20988 L
.66304 .20988 L
.66369 .20988 L
.66434 .20988 L
.66498 .20988 L
.66563 .20988 L
.66628 .20988 L
.66693 .20988 L
.66757 .20988 L
.66822 .20988 L
.66887 .20988 L
.66951 .20988 L
.67016 .20988 L
Mistroke
.67081 .20988 L
.67145 .20988 L
.6721 .20988 L
.67275 .20988 L
.6734 .20988 L
.67404 .20988 L
.67469 .20988 L
.67534 .20988 L
.67598 .20988 L
.67663 .20988 L
.67728 .20988 L
.67792 .20988 L
.67857 .20988 L
.67922 .20988 L
.67987 .20988 L
.68051 .20988 L
.68116 .20988 L
.68181 .20988 L
.68245 .20988 L
.6831 .20988 L
.68375 .20988 L
.68439 .20988 L
.68504 .20988 L
.68569 .20988 L
.68634 .20988 L
.68698 .20988 L
.68763 .20988 L
.68828 .20988 L
.68892 .20988 L
.68957 .20988 L
.69022 .20988 L
.69086 .20988 L
.69151 .20988 L
.69216 .20988 L
.69281 .20988 L
.69345 .20988 L
.6941 .20988 L
.69475 .20988 L
.69539 .20988 L
.69604 .20988 L
.69669 .20988 L
.69733 .20988 L
.69798 .20988 L
.69863 .20988 L
.69928 .20988 L
.69992 .20988 L
.70057 .20988 L
.70122 .20988 L
.70186 .20988 L
.70251 .20988 L
Mistroke
.70316 .20988 L
.7038 .20988 L
.70445 .20988 L
.7051 .20988 L
.70575 .20988 L
.70639 .20988 L
.70704 .20988 L
.70769 .20988 L
.70833 .20988 L
.70898 .20988 L
.70963 .20988 L
.71027 .20988 L
.71092 .20988 L
.71157 .20988 L
.71222 .20988 L
.71286 .20988 L
.71351 .20988 L
.71416 .20988 L
.7148 .20988 L
.71545 .20988 L
.7161 .20988 L
.71674 .20988 L
.71739 .20988 L
.71804 .20988 L
.71869 .20988 L
.71933 .20988 L
.71998 .20988 L
.72063 .20988 L
.72127 .20988 L
.72192 .20988 L
.72257 .20988 L
.72321 .20988 L
.72386 .20988 L
.72451 .20988 L
.72516 .20988 L
.7258 .20988 L
.72645 .20988 L
.7271 .20988 L
.72774 .20988 L
.72839 .20988 L
.72904 .20988 L
.72968 .20988 L
.73033 .20988 L
.73098 .20988 L
.73163 .20988 L
.73227 .20988 L
.73292 .20988 L
.73357 .20988 L
.73421 .20988 L
.73486 .20988 L
Mistroke
.73551 .20988 L
.73615 .20988 L
.7368 .20988 L
.73745 .20988 L
.7381 .20988 L
.73874 .20988 L
.73939 .20988 L
.74004 .20988 L
.74068 .20988 L
.74133 .20988 L
.74198 .20988 L
.74262 .20988 L
.74327 .20988 L
.74392 .20988 L
.74457 .20988 L
.74521 .20988 L
.74586 .20988 L
.74651 .20988 L
.74715 .20988 L
.7478 .20988 L
.74845 .20988 L
.74909 .20988 L
.74974 .20988 L
.75039 .20988 L
.75104 .20988 L
.75168 .20988 L
.75233 .20988 L
.75298 .20988 L
.75362 .20988 L
.75427 .20988 L
.75492 .20988 L
.75556 .20988 L
.75621 .20988 L
.75686 .20988 L
.75751 .20988 L
.75815 .20988 L
.7588 .20988 L
.75945 .20988 L
.76009 .20988 L
.76074 .20988 L
.76139 .20988 L
.76203 .20988 L
.76268 .20988 L
.76333 .20988 L
.76398 .20988 L
.76462 .20988 L
.76527 .20988 L
.76592 .20988 L
.76656 .20988 L
.76721 .20988 L
Mistroke
.76786 .20988 L
.7685 .20988 L
.76915 .20988 L
.7698 .20988 L
.77045 .20988 L
.77109 .20988 L
.77174 .20988 L
.77239 .20988 L
.77303 .20988 L
.77368 .20988 L
.77433 .20988 L
.77497 .20988 L
.77562 .20988 L
.77627 .20988 L
.77692 .20988 L
.77756 .20988 L
.77821 .20988 L
.77886 .20988 L
.7795 .20988 L
.78015 .20988 L
.7808 .20988 L
.78144 .20988 L
.78209 .20988 L
.78274 .20988 L
.78339 .20988 L
.78403 .20988 L
.78468 .20988 L
.78533 .20988 L
.78597 .20988 L
.78662 .20988 L
.78727 .20988 L
.78791 .20988 L
.78856 .20988 L
.78921 .20988 L
.78986 .20988 L
.7905 .20988 L
.79115 .20988 L
.7918 .20988 L
.79244 .20988 L
.79309 .20988 L
.79374 .20988 L
.79438 .20988 L
.79503 .20988 L
.79568 .20988 L
.79633 .20988 L
.79697 .20988 L
.79762 .20988 L
.79827 .20988 L
.79891 .20988 L
.79956 .20988 L
Mistroke
.80021 .20988 L
.80085 .20988 L
.8015 .20988 L
.80215 .20988 L
.8028 .20988 L
.80344 .20988 L
.80409 .20988 L
.80474 .20988 L
.80538 .20988 L
.80603 .20988 L
.80668 .20988 L
.80732 .20988 L
.80797 .20988 L
.80862 .20988 L
.80927 .20988 L
.80991 .20988 L
.81056 .20988 L
.81121 .20988 L
.81185 .20988 L
.8125 .20988 L
.81315 .20988 L
.81379 .20988 L
.81444 .20988 L
.81509 .20988 L
.81573 .20988 L
.81638 .20988 L
.81703 .20988 L
.81768 .20988 L
.81832 .20988 L
.81897 .20988 L
.81962 .20988 L
.82026 .20988 L
.82091 .20988 L
.82156 .20988 L
.8222 .20988 L
.82285 .20988 L
.8235 .20988 L
.82415 .20988 L
.82479 .20988 L
.82544 .20988 L
.82609 .20988 L
.82673 .20988 L
.82738 .20988 L
.82803 .20988 L
.82867 .20988 L
.82932 .20988 L
.82997 .20988 L
.83062 .20988 L
.83126 .20988 L
.83191 .20988 L
Mistroke
.83256 .20988 L
.8332 .20988 L
.83385 .20988 L
.8345 .20988 L
.83514 .20988 L
.83579 .20988 L
.83644 .20988 L
.83709 .20988 L
.83773 .20988 L
.83838 .20988 L
.83903 .20988 L
.83967 .20988 L
.84032 .20988 L
.84097 .20988 L
.84161 .20988 L
.84226 .20988 L
.84291 .20988 L
.84356 .20988 L
.8442 .20988 L
.84485 .20988 L
.8455 .20988 L
.84614 .20988 L
.84679 .20988 L
.84744 .20988 L
.84808 .20988 L
.84873 .20988 L
.84938 .20988 L
.85003 .20988 L
.85067 .20988 L
.85132 .20988 L
.85197 .20988 L
.85261 .20988 L
.85326 .20988 L
.85391 .20988 L
.85455 .20988 L
.8552 .20988 L
.85585 .20988 L
.8565 .20988 L
.85714 .20988 L
.85779 .20988 L
.85844 .20988 L
.85908 .20988 L
.85973 .20988 L
.86038 .20988 L
.86102 .20988 L
.86167 .20988 L
.86232 .20988 L
.86297 .20988 L
.86361 .20988 L
.86426 .20988 L
Mistroke
.86491 .20988 L
.86555 .20988 L
.8662 .20988 L
.86685 .20988 L
.86749 .20988 L
.86814 .20988 L
.86879 .20988 L
.86944 .20988 L
.87008 .20988 L
.87073 .20988 L
.87138 .20988 L
.87202 .20988 L
.87267 .20988 L
.87332 .20988 L
.87396 .20988 L
.87461 .20988 L
.87526 .20988 L
.87591 .20988 L
.87655 .20988 L
.8772 .20988 L
.87785 .20988 L
.87849 .20988 L
.87914 .20988 L
.87979 .20988 L
.88043 .20988 L
.88108 .20988 L
.88173 .20988 L
.88238 .20988 L
.88302 .20988 L
.88367 .20988 L
.88432 .20988 L
.88496 .20988 L
.88561 .20988 L
.88626 .20988 L
.8869 .20988 L
.88755 .20988 L
.8882 .20988 L
.88885 .20988 L
.88949 .20988 L
.89014 .20988 L
.89079 .20988 L
.89143 .20988 L
.89208 .20988 L
.89273 .20988 L
.89337 .20988 L
.89402 .20988 L
.89467 .20988 L
.89532 .20988 L
.89596 .20988 L
.89661 .20988 L
Mistroke
.89726 .20988 L
.8979 .20988 L
.89855 .20988 L
.8992 .20988 L
.89984 .20988 L
.90049 .20988 L
.90114 .20988 L
.90179 .20988 L
.90243 .20988 L
.90308 .20988 L
.90373 .20988 L
.90437 .20988 L
.90502 .20988 L
.90567 .20988 L
.90631 .20988 L
.90696 .20988 L
.90761 .20988 L
.90826 .20988 L
.9089 .20988 L
.90955 .20988 L
.9102 .20988 L
.91084 .20988 L
.91149 .20988 L
.91214 .20988 L
.91278 .20988 L
.91343 .20988 L
.91408 .20988 L
.91473 .20988 L
.91537 .20988 L
.91602 .20988 L
.91667 .20988 L
.91731 .20988 L
.91796 .20988 L
.91861 .20988 L
.91925 .20988 L
.9199 .20988 L
.92055 .20988 L
.9212 .20988 L
.92184 .20988 L
.92249 .20988 L
.92314 .20988 L
.92378 .20988 L
.92443 .20988 L
.92508 .20988 L
.92572 .20988 L
.92637 .20988 L
.92702 .20988 L
.92767 .20988 L
.92831 .20988 L
.92896 .20988 L
Mistroke
.92961 .20988 L
.93025 .20988 L
.9309 .20988 L
.93155 .20988 L
.93219 .20988 L
.93284 .20988 L
.93349 .20988 L
.93414 .20988 L
.93478 .20988 L
.93543 .20988 L
.93608 .20988 L
.93672 .20988 L
.93737 .20988 L
.93802 .20988 L
.93866 .20988 L
.93931 .20988 L
.93996 .20988 L
.94061 .20988 L
.94125 .20988 L
.9419 .20988 L
.94255 .20988 L
.94319 .20988 L
.94384 .20988 L
.94449 .20988 L
.94513 .20988 L
.94578 .20988 L
.94643 .20988 L
.94708 .20988 L
.94772 .20988 L
.94837 .20988 L
.94902 .20988 L
.94966 .20988 L
.95031 .20988 L
.95096 .20988 L
.9516 .20988 L
.95225 .20988 L
.9529 .20988 L
.95355 .20988 L
.95419 .20988 L
.95484 .20988 L
.95549 .20988 L
.95613 .20988 L
.95678 .20988 L
.95743 .20988 L
.95807 .20988 L
.95872 .20988 L
.95937 .20988 L
.96002 .20988 L
.96066 .20988 L
.96131 .20988 L
Mistroke
.96196 .20988 L
.9626 .20988 L
.96325 .20988 L
.9639 .20988 L
.96454 .20988 L
.96519 .20988 L
.96584 .20988 L
.96649 .20988 L
.96713 .20988 L
.96778 .20988 L
.96843 .20988 L
.96907 .20988 L
.96972 .20988 L
.97037 .20988 L
.97101 .20988 L
.97166 .20988 L
.97231 .20988 L
.97296 .20988 L
.9736 .20988 L
.97425 .20988 L
.9749 .20988 L
.97554 .20988 L
.97619 .20988 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "Once the filter coefficients and the scaling function are known, the \
associated mother wavelet can be obtained straightforwardly using the wavelet \
equation (",
  ButtonBox["4.2",
    ButtonData:>{"Wavelets 1.4.1", "1.5"},
    ButtonStyle->"AddOnsLink"],
  "). The function "
}], "Text",
  CellTags->{"S1.4.3", "3.31"}],

Cell[TextData[{
  StyleBox["Wavelet[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.3", "3.32"}],

Cell[TextData[{
  "computes the mother wavelet using the filter ",
  StyleBox["filter", "TI"],
  " at dyadic points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  ", where both ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.4.3"],
  " and ",
  StyleBox["jmax", "TI"],
  " are integers and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.3"],
  " lies within the support of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.3"],
  ". "
}], "Text",
  CellTags->{"S1.4.3", "3.33"}],

Cell[TextData[{
  "This gives the values of the wavelet at dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^6\)], "InlineFormula",
    CellTags->"S1.4.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.34"}],

Cell["psi2 = Wavelet[d2, 6];", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S1.4.3"],

Cell[TextData[{
  StyleBox["psi2", "MR"],
  " contains a list of points."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.35"}],

Cell[CellGroupData[{

Cell["Short[psi2]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    TagBox[\({{\(-1\), 0.`}, \[LeftSkeleton]191\[RightSkeleton], {2, 0}}\),
      Short]], "Output",
  CellLabel->"Out[23]//Short= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["This is the graph of the Daubechies wavelet of order 2.", "MathCaption",
  CellTags->{"S1.4.3", "3.36"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[psi2, PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"psi_2(t)\"}]\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.274246 0.18999 [
[.02381 .26175 -6 -9 ]
[.02381 .26175 6 0 ]
[.18254 .26175 -12 -9 ]
[.18254 .26175 12 0 ]
[.5 .26175 -9 -9 ]
[.5 .26175 9 0 ]
[.65873 .26175 -3 -9 ]
[.65873 .26175 3 0 ]
[.81746 .26175 -9 -9 ]
[.81746 .26175 9 0 ]
[.97619 .26175 -3 -9 ]
[.97619 .26175 3 0 ]
[1.025 .27425 0 -4.5 ]
[1.025 .27425 6 4.5 ]
[.32877 .08426 -12 -4.5 ]
[.32877 .08426 0 4.5 ]
[.32877 .17925 -24 -4.5 ]
[.32877 .17925 0 4.5 ]
[.32877 .36924 -18 -4.5 ]
[.32877 .36924 0 4.5 ]
[.32877 .46424 -6 -4.5 ]
[.32877 .46424 0 4.5 ]
[.32877 .55923 -18 -4.5 ]
[.32877 .55923 0 4.5 ]
[.34127 .64303 -24 0 ]
[.34127 .64303 24 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27425 m
.02381 .2805 L
s
[(-1)] .02381 .26175 0 1 Mshowa
.18254 .27425 m
.18254 .2805 L
s
[(-0.5)] .18254 .26175 0 1 Mshowa
.5 .27425 m
.5 .2805 L
s
[(0.5)] .5 .26175 0 1 Mshowa
.65873 .27425 m
.65873 .2805 L
s
[(1)] .65873 .26175 0 1 Mshowa
.81746 .27425 m
.81746 .2805 L
s
[(1.5)] .81746 .26175 0 1 Mshowa
.97619 .27425 m
.97619 .2805 L
s
[(2)] .97619 .26175 0 1 Mshowa
.125 Mabswid
.05556 .27425 m
.05556 .278 L
s
.0873 .27425 m
.0873 .278 L
s
.11905 .27425 m
.11905 .278 L
s
.15079 .27425 m
.15079 .278 L
s
.21429 .27425 m
.21429 .278 L
s
.24603 .27425 m
.24603 .278 L
s
.27778 .27425 m
.27778 .278 L
s
.30952 .27425 m
.30952 .278 L
s
.37302 .27425 m
.37302 .278 L
s
.40476 .27425 m
.40476 .278 L
s
.43651 .27425 m
.43651 .278 L
s
.46825 .27425 m
.46825 .278 L
s
.53175 .27425 m
.53175 .278 L
s
.56349 .27425 m
.56349 .278 L
s
.59524 .27425 m
.59524 .278 L
s
.62698 .27425 m
.62698 .278 L
s
.69048 .27425 m
.69048 .278 L
s
.72222 .27425 m
.72222 .278 L
s
.75397 .27425 m
.75397 .278 L
s
.78571 .27425 m
.78571 .278 L
s
.84921 .27425 m
.84921 .278 L
s
.88095 .27425 m
.88095 .278 L
s
.9127 .27425 m
.9127 .278 L
s
.94444 .27425 m
.94444 .278 L
s
.25 Mabswid
0 .27425 m
1 .27425 L
s
[(t)] 1.025 .27425 -1 0 Mshowa
.34127 .08426 m
.34752 .08426 L
s
[(-1)] .32877 .08426 1 0 Mshowa
.34127 .17925 m
.34752 .17925 L
s
[(-0.5)] .32877 .17925 1 0 Mshowa
.34127 .36924 m
.34752 .36924 L
s
[(0.5)] .32877 .36924 1 0 Mshowa
.34127 .46424 m
.34752 .46424 L
s
[(1)] .32877 .46424 1 0 Mshowa
.34127 .55923 m
.34752 .55923 L
s
[(1.5)] .32877 .55923 1 0 Mshowa
.125 Mabswid
.34127 .10326 m
.34502 .10326 L
s
.34127 .12225 m
.34502 .12225 L
s
.34127 .14125 m
.34502 .14125 L
s
.34127 .16025 m
.34502 .16025 L
s
.34127 .19825 m
.34502 .19825 L
s
.34127 .21725 m
.34502 .21725 L
s
.34127 .23625 m
.34502 .23625 L
s
.34127 .25525 m
.34502 .25525 L
s
.34127 .29325 m
.34502 .29325 L
s
.34127 .31224 m
.34502 .31224 L
s
.34127 .33124 m
.34502 .33124 L
s
.34127 .35024 m
.34502 .35024 L
s
.34127 .38824 m
.34502 .38824 L
s
.34127 .40724 m
.34502 .40724 L
s
.34127 .42624 m
.34502 .42624 L
s
.34127 .44524 m
.34502 .44524 L
s
.34127 .48324 m
.34502 .48324 L
s
.34127 .50223 m
.34502 .50223 L
s
.34127 .52123 m
.34502 .52123 L
s
.34127 .54023 m
.34502 .54023 L
s
.34127 .06526 m
.34502 .06526 L
s
.34127 .04626 m
.34502 .04626 L
s
.34127 .02726 m
.34502 .02726 L
s
.34127 .00826 m
.34502 .00826 L
s
.34127 .57823 m
.34502 .57823 L
s
.34127 .59723 m
.34502 .59723 L
s
.34127 .61623 m
.34502 .61623 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi_2\\(t\\))] .34127 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .27425 m
.02877 .26719 L
.03373 .26391 L
.03869 .26202 L
.04365 .25911 L
.04861 .25823 L
.05357 .25634 L
.05853 .25408 L
.06349 .25209 L
.06845 .25195 L
.07341 .2508 L
.07837 .24928 L
.08333 .24803 L
.08829 .24624 L
.09325 .24472 L
.09821 .2433 L
.10317 .2418 L
.10813 .24221 L
.1131 .24161 L
.11806 .24063 L
.12302 .23992 L
.12798 .23867 L
.13294 .2377 L
.1379 .23682 L
.14286 .23587 L
.14782 .23442 L
.15278 .23324 L
.15774 .23217 L
.1627 .23102 L
.16766 .23001 L
.17262 .22894 L
.17758 .22783 L
.18254 .22675 L
.1875 .22755 L
.19246 .22735 L
.19742 .22677 L
.20238 .22646 L
.20734 .22561 L
.2123 .22503 L
.21726 .22455 L
.22222 .22399 L
.22718 .22294 L
.23214 .22216 L
.2371 .22149 L
.24206 .22073 L
.24702 .22013 L
.25198 .21945 L
.25694 .21874 L
.2619 .21806 L
.26687 .21686 L
Mistroke
.27183 .21594 L
.27679 .21511 L
.28175 .21421 L
.28671 .21346 L
.29167 .21264 L
.29663 .21179 L
.30159 .21095 L
.30655 .21026 L
.31151 .20948 L
.31647 .20869 L
.32143 .20791 L
.32639 .20709 L
.33135 .20629 L
.33631 .2055 L
.34127 .20471 L
.34623 .26694 L
.35119 .2954 L
.35615 .3115 L
.36111 .33664 L
.36607 .34369 L
.37103 .35978 L
.37599 .37919 L
.38095 .39617 L
.38591 .39659 L
.39087 .40606 L
.39583 .41884 L
.40079 .4292 L
.40575 .4444 L
.41071 .45718 L
.41567 .46908 L
.42063 .48162 L
.4256 .47719 L
.43056 .48181 L
.43552 .48974 L
.44048 .49524 L
.44544 .5056 L
.4504 .51353 L
.45536 .52057 L
.46032 .52827 L
.46528 .5404 L
.47024 .5501 L
.4752 .55892 L
.48016 .56839 L
.48512 .57656 L
.49008 .58538 L
.49504 .59444 L
.5 .60332 L
.50496 .48237 L
.50992 .43101 L
.51488 .40512 L
Mistroke
.51984 .36059 L
.5248 .35335 L
.52976 .32746 L
.53472 .29475 L
.53968 .26703 L
.54464 .27344 L
.5496 .2612 L
.55456 .24214 L
.55952 .22807 L
.56448 .20401 L
.56944 .18495 L
.5744 .16771 L
.57937 .14914 L
.58433 .16554 L
.58929 .16329 L
.59425 .15422 L
.59921 .15015 L
.60417 .13608 L
.60913 .12701 L
.61409 .11977 L
.61905 .11119 L
.62401 .09346 L
.62897 .08073 L
.63393 .06983 L
.63889 .0576 L
.64385 .04804 L
.64881 .03714 L
.65377 .02575 L
.65873 .01472 L
.66369 .10197 L
.66865 .13653 L
.67361 .1518 L
.67857 .18119 L
.68353 .18234 L
.68849 .19761 L
.69345 .21805 L
.69841 .2347 L
.70337 .22552 L
.70833 .23045 L
.71329 .24055 L
.71825 .24687 L
.72321 .26075 L
.72817 .27086 L
.73313 .27957 L
.7381 .2893 L
.74306 .27255 L
.74802 .26991 L
.75298 .27245 L
.75794 .2712 L
.7629 .27752 L
Mistroke
.76786 .28005 L
.77282 .2812 L
.77778 .28337 L
.78274 .29245 L
.7877 .29776 L
.79266 .30168 L
.79762 .30661 L
.80258 .30952 L
.80754 .31343 L
.8125 .31773 L
.81746 .32174 L
.82242 .29945 L
.82738 .29128 L
.83234 .28827 L
.8373 .28148 L
.84226 .28226 L
.84722 .27926 L
.85218 .27487 L
.85714 .27149 L
.8621 .27504 L
.86706 .2748 L
.87202 .27318 L
.87698 .27258 L
.88194 .26994 L
.8869 .26832 L
.89187 .26707 L
.89683 .26555 L
.90179 .27113 L
.90675 .27292 L
.91171 .27333 L
.91667 .27475 L
.92163 .27414 L
.92659 .27455 L
.93155 .27533 L
.93651 .27584 L
.94147 .27449 L
.94643 .27415 L
.95139 .27419 L
.95635 .27396 L
.96131 .27426 L
.96627 .2743 L
.97123 .27424 L
.97619 .27425 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell[TextData[{
  "Again, we can get a continuous wavelet by setting the option ",
  StyleBox["Interpolation", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  " in the function ",
  StyleBox["Wavelet", "MR"],
  ". This gives the continuous wavelet by interpolation."
}], "MathCaption",
  CellTags->{"S1.4.3", "3.37"}],

Cell[CellGroupData[{

Cell["psi2 = Wavelet[d2, 6, Interpolation -> True]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S1.4.3"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-100.`\), 100.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[25]= ",
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["The dilated and translated wavelets are plotted here.", "MathCaption",
  CellTags->{"S1.4.3", "3.38"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{psi2[2t], psi2[4t-3]}, {t, -1, 2},
PlotRange -> All,
AxesLabel -> {\"t\", \"psi_2(2t), psi_2(4t-3)\"}]\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.273405 0.191584 [
[.02381 .26091 -6 -9 ]
[.02381 .26091 6 0 ]
[.18254 .26091 -12 -9 ]
[.18254 .26091 12 0 ]
[.5 .26091 -9 -9 ]
[.5 .26091 9 0 ]
[.65873 .26091 -3 -9 ]
[.65873 .26091 3 0 ]
[.81746 .26091 -9 -9 ]
[.81746 .26091 9 0 ]
[.97619 .26091 -3 -9 ]
[.97619 .26091 3 0 ]
[1.025 .27341 0 -4.5 ]
[1.025 .27341 6 4.5 ]
[.32877 .08182 -12 -4.5 ]
[.32877 .08182 0 4.5 ]
[.32877 .17761 -24 -4.5 ]
[.32877 .17761 0 4.5 ]
[.32877 .3692 -18 -4.5 ]
[.32877 .3692 0 4.5 ]
[.32877 .46499 -6 -4.5 ]
[.32877 .46499 0 4.5 ]
[.32877 .56078 -18 -4.5 ]
[.32877 .56078 0 4.5 ]
[.34127 .64303 -66 0 ]
[.34127 .64303 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27341 m
.02381 .27966 L
s
[(-1)] .02381 .26091 0 1 Mshowa
.18254 .27341 m
.18254 .27966 L
s
[(-0.5)] .18254 .26091 0 1 Mshowa
.5 .27341 m
.5 .27966 L
s
[(0.5)] .5 .26091 0 1 Mshowa
.65873 .27341 m
.65873 .27966 L
s
[(1)] .65873 .26091 0 1 Mshowa
.81746 .27341 m
.81746 .27966 L
s
[(1.5)] .81746 .26091 0 1 Mshowa
.97619 .27341 m
.97619 .27966 L
s
[(2)] .97619 .26091 0 1 Mshowa
.125 Mabswid
.05556 .27341 m
.05556 .27716 L
s
.0873 .27341 m
.0873 .27716 L
s
.11905 .27341 m
.11905 .27716 L
s
.15079 .27341 m
.15079 .27716 L
s
.21429 .27341 m
.21429 .27716 L
s
.24603 .27341 m
.24603 .27716 L
s
.27778 .27341 m
.27778 .27716 L
s
.30952 .27341 m
.30952 .27716 L
s
.37302 .27341 m
.37302 .27716 L
s
.40476 .27341 m
.40476 .27716 L
s
.43651 .27341 m
.43651 .27716 L
s
.46825 .27341 m
.46825 .27716 L
s
.53175 .27341 m
.53175 .27716 L
s
.56349 .27341 m
.56349 .27716 L
s
.59524 .27341 m
.59524 .27716 L
s
.62698 .27341 m
.62698 .27716 L
s
.69048 .27341 m
.69048 .27716 L
s
.72222 .27341 m
.72222 .27716 L
s
.75397 .27341 m
.75397 .27716 L
s
.78571 .27341 m
.78571 .27716 L
s
.84921 .27341 m
.84921 .27716 L
s
.88095 .27341 m
.88095 .27716 L
s
.9127 .27341 m
.9127 .27716 L
s
.94444 .27341 m
.94444 .27716 L
s
.25 Mabswid
0 .27341 m
1 .27341 L
s
[(t)] 1.025 .27341 -1 0 Mshowa
.34127 .08182 m
.34752 .08182 L
s
[(-1)] .32877 .08182 1 0 Mshowa
.34127 .17761 m
.34752 .17761 L
s
[(-0.5)] .32877 .17761 1 0 Mshowa
.34127 .3692 m
.34752 .3692 L
s
[(0.5)] .32877 .3692 1 0 Mshowa
.34127 .46499 m
.34752 .46499 L
s
[(1)] .32877 .46499 1 0 Mshowa
.34127 .56078 m
.34752 .56078 L
s
[(1.5)] .32877 .56078 1 0 Mshowa
.125 Mabswid
.34127 .10098 m
.34502 .10098 L
s
.34127 .12014 m
.34502 .12014 L
s
.34127 .1393 m
.34502 .1393 L
s
.34127 .15846 m
.34502 .15846 L
s
.34127 .19677 m
.34502 .19677 L
s
.34127 .21593 m
.34502 .21593 L
s
.34127 .23509 m
.34502 .23509 L
s
.34127 .25425 m
.34502 .25425 L
s
.34127 .29256 m
.34502 .29256 L
s
.34127 .31172 m
.34502 .31172 L
s
.34127 .33088 m
.34502 .33088 L
s
.34127 .35004 m
.34502 .35004 L
s
.34127 .38836 m
.34502 .38836 L
s
.34127 .40751 m
.34502 .40751 L
s
.34127 .42667 m
.34502 .42667 L
s
.34127 .44583 m
.34502 .44583 L
s
.34127 .48415 m
.34502 .48415 L
s
.34127 .50331 m
.34502 .50331 L
s
.34127 .52246 m
.34502 .52246 L
s
.34127 .54162 m
.34502 .54162 L
s
.34127 .06266 m
.34502 .06266 L
s
.34127 .0435 m
.34502 .0435 L
s
.34127 .02435 m
.34502 .02435 L
s
.34127 .00519 m
.34502 .00519 L
s
.34127 .57994 m
.34502 .57994 L
s
.34127 .5991 m
.34502 .5991 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi_2\\(2t\\), psi_2\\(4t-3\\))] .34127 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .27341 m
.06244 .27341 L
.10458 .27341 L
.14415 .27341 L
.16408 .27341 L
.17277 .27341 L
.17735 .27341 L
.17986 .27341 L
.18109 .27341 L
.18221 .27341 L
.18341 .27091 L
.1847 .26721 L
.18537 .26582 L
.1861 .26484 L
.18744 .26306 L
.19227 .25837 L
.20178 .25155 L
.22272 .24077 L
.24403 .23354 L
.24893 .23122 L
.2541 .22895 L
.25641 .22795 L
.25889 .22684 L
.26009 .22631 L
.26123 .22581 L
.26225 .22562 L
.26336 .22599 L
.26452 .22631 L
.26576 .2262 L
.26681 .22612 L
.26798 .22585 L
.27304 .2248 L
.28351 .22198 L
.30249 .2163 L
.32184 .20947 L
.32714 .20786 L
.33272 .20606 L
.33748 .2045 L
.33879 .20408 L
.33951 .20385 L
.34018 .20363 L
.3415 .20909 L
.34269 .23934 L
.34385 .26718 L
.34509 .28151 L
.34732 .3019 L
.35242 .33984 L
.36271 .39662 L
.37228 .43739 L
.37694 .46247 L
Mistroke
.37897 .47241 L
.38004 .47785 L
.38116 .48214 L
.38248 .47977 L
.38369 .47853 L
.38482 .48066 L
.38607 .48321 L
.39129 .49802 L
.40234 .53716 L
.40736 .55734 L
.41274 .57674 L
.41535 .58597 L
.41782 .59503 L
.41889 .59894 L
.42003 .60306 L
.42128 .57342 L
.42244 .51658 L
.42358 .47356 L
.42483 .4475 L
.42613 .42584 L
.42734 .4131 L
.43183 .35671 L
.43673 .31096 L
.44195 .26996 L
.45147 .21633 L
.45565 .1813 L
.45786 .16577 L
.45908 .15656 L
.46024 .14783 L
.46089 .15104 L
.46159 .15573 L
.46282 .16376 L
.46407 .16262 L
.46523 .16156 L
.46645 .15721 L
.46715 .15463 L
.46779 .15232 L
.46846 .1512 L
.46919 .15 L
.47051 .14671 L
.47116 .14301 L
.47185 .13906 L
.47309 .1327 L
.47458 .12723 L
.47592 .1228 L
.48163 .0984 L
.4866 .07171 L
.49199 .04749 L
.49447 .03684 L
.49709 .02481 L
Mistroke
.49817 .01991 L
.49933 .01472 L
.5006 .03296 L
.50179 .07522 L
.50248 .09957 L
.50312 .10872 L
.50433 .12569 L
.50563 .1387 L
.50636 .14325 L
.50704 .14743 L
.51191 .1805 L
.51727 .216 L
.51858 .22497 L
.5193 .22983 L
.51998 .23303 L
.52078 .23003 L
.52151 .2273 L
.52219 .22474 L
.52294 .22551 L
.52418 .228 L
.52535 .23148 L
.528 .24128 L
.53338 .26448 L
.53564 .27326 L
.53803 .28204 L
.53928 .28698 L
.53998 .28654 L
.54064 .28206 L
.5418 .27417 L
.54303 .27076 L
.54427 .26944 L
.54497 .26938 L
.54563 .27005 L
.54631 .27075 L
.54695 .27141 L
.54769 .2713 L
.54837 .27096 L
.54959 .27034 L
.55072 .27321 L
.55329 .27795 L
.5644 .29692 L
.57416 .31253 L
.57551 .31486 L
.57697 .31739 L
.57764 .31849 L
.57835 .31964 L
.57962 .31903 L
.58084 .30797 L
.58197 .2984 L
.58322 .29426 L
Mistroke
.58391 .29197 L
.58455 .2903 L
.58578 .2888 L
.58713 .28666 L
.58786 .28464 L
.58856 .28272 L
.58986 .28088 L
.59099 .28124 L
.59222 .28093 L
.59354 .27932 L
.59476 .27754 L
.59609 .27517 L
.59752 .27294 L
.59818 .27203 L
.59888 .27107 L
.60013 .27196 L
.60082 .27295 L
.60156 .27402 L
.60237 .27414 L
.60313 .27407 L
.60386 .274 L
.60455 .27371 L
.60585 .27286 L
.61052 .27023 L
.61549 .26672 L
.61674 .26607 L
.61808 .26524 L
.61885 .26476 L
.61956 .26579 L
.62023 .26732 L
.62094 .26893 L
.62219 .27074 L
.62335 .27159 L
.62462 .27217 L
.62534 .27229 L
.62599 .2724 L
.63083 .27345 L
.63211 .27341 L
.63283 .27353 L
.63348 .27364 L
.63475 .27397 L
.63596 .27436 L
.63698 .27462 L
.63806 .27484 L
.63924 .27482 L
.64034 .27421 L
.64164 .27361 L
.64287 .27345 L
.64397 .27331 L
.64516 .27333 L
Mistroke
.64646 .27334 L
.64768 .27322 L
.64837 .27315 L
.64901 .27314 L
.64974 .27323 L
.65043 .27332 L
.65111 .2734 L
.65182 .27343 L
.6531 .27345 L
.65381 .27346 L
.65448 .27344 L
.6552 .27342 L
.656 .2734 L
.65722 .2734 L
.6585 .2734 L
.65969 .27341 L
.66079 .27341 L
.66596 .27341 L
.70504 .27341 L
.74658 .27341 L
.7866 .27341 L
.82511 .27341 L
.86606 .27341 L
.90551 .27341 L
.94343 .27341 L
.97619 .27341 L
Mfstroke
.02381 .27341 m
.06244 .27341 L
.10458 .27341 L
.14415 .27341 L
.18221 .27341 L
.22272 .27341 L
.26171 .27341 L
.30316 .27341 L
.34309 .27341 L
.3815 .27341 L
.42237 .27341 L
.46172 .27341 L
.48147 .27341 L
.49012 .27341 L
.49468 .27341 L
.49719 .27341 L
.49842 .27341 L
.49955 .27341 L
.50085 .26852 L
.50152 .26553 L
.50226 .26357 L
.50345 .26149 L
.50471 .25873 L
.50591 .25747 L
.50719 .25574 L
.50839 .2536 L
.5095 .25174 L
.51072 .25097 L
.51135 .25075 L
.51204 .2501 L
.51321 .24877 L
.51445 .24741 L
.51665 .24451 L
.51785 .24307 L
.51896 .24176 L
.52025 .24083 L
.52093 .24105 L
.52166 .24082 L
.52296 .23998 L
.52414 .23917 L
.52973 .23473 L
.53464 .22989 L
.53733 .2276 L
.53864 .22643 L
.53984 .22561 L
.54101 .22631 L
.54213 .22612 L
.54331 .22557 L
.54459 .22523 L
.54591 .22435 L
Mistroke
.54664 .224 L
.54731 .2237 L
.54982 .22254 L
.55902 .21702 L
.56418 .2131 L
.56974 .20941 L
.5723 .20786 L
.57499 .20612 L
.5773 .20462 L
.5786 .20377 L
.57982 .22636 L
.58108 .27701 L
.58226 .30014 L
.58349 .3192 L
.58484 .33929 L
.58768 .37345 L
.5903 .3967 L
.60021 .47889 L
.60909 .52931 L
.61378 .56764 L
.61635 .58561 L
.61762 .59488 L
.61878 .60332 L
.62007 .50486 L
.62075 .46417 L
.62146 .43428 L
.62262 .40851 L
.62389 .36468 L
.62508 .35418 L
.62635 .33005 L
.62754 .29916 L
.62864 .27354 L
.62929 .26778 L
.62997 .27136 L
.63066 .26809 L
.63142 .26052 L
.63406 .22429 L
.63664 .18014 L
.63777 .16418 L
.639 .14879 L
.64016 .16373 L
.64124 .16176 L
.64238 .15407 L
.6436 .1491 L
.64424 .14383 L
.64493 .13589 L
.64619 .12595 L
.64731 .11913 L
.64855 .11078 L
.64972 .09584 L
Mistroke
.65082 .08317 L
.65322 .06044 L
.6553 .04272 L
.65644 .0325 L
.65752 .02254 L
.65817 .01671 L
.65887 .02188 L
.6601 .1033 L
.66134 .13621 L
.66249 .15089 L
.66508 .18253 L
.66644 .20068 L
.6672 .21321 L
.66791 .22352 L
.66921 .22934 L
.6704 .22629 L
.67151 .23232 L
.67271 .24119 L
.67512 .26204 L
.6764 .27221 L
.67708 .27697 L
.67778 .28236 L
.67904 .28219 L
.68019 .27088 L
.68127 .26949 L
.68245 .27143 L
.68485 .27687 L
.68554 .27829 L
.68619 .27943 L
.68741 .2807 L
.68856 .28313 L
.68962 .29097 L
.69079 .29633 L
.69202 .30046 L
.69408 .30752 L
.69631 .31425 L
.69763 .31874 L
.69885 .31343 L
.70001 .29644 L
.70125 .2897 L
.70247 .28569 L
.70362 .28086 L
.70465 .2814 L
.70576 .27869 L
.70709 .27404 L
.70833 .27063 L
.70963 .27419 L
.71031 .27406 L
.71105 .27366 L
.71235 .27219 L
Mistroke
.71359 .27109 L
.7147 .26885 L
.7159 .2673 L
.71696 .26623 L
.7181 .26483 L
.71935 .26962 L
.72052 .27176 L
.72184 .27243 L
.72308 .27376 L
.7242 .27343 L
.72543 .27362 L
.72658 .27428 L
.72763 .27479 L
.72884 .27428 L
.72999 .27349 L
.73104 .27332 L
.73202 .27333 L
.73309 .27312 L
.73422 .27338 L
.73544 .27345 L
.73613 .27343 L
.73676 .2734 L
.73793 .2734 L
.73917 .27341 L
.74028 .27341 L
.74132 .27341 L
.74369 .27341 L
.75385 .27341 L
.77218 .27341 L
.81086 .27341 L
.85198 .27341 L
.89159 .27341 L
.92969 .27341 L
.97024 .27341 L
.97619 .27341 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["This is Daubechies wavelet of order 12.", "MathCaption",
  CellTags->{"S1.4.3", "3.39"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[d12, 6], PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"psi_12(t)\"}]\
\>", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S1.4.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.479296 0.0414079 0.315849 0.319787 [
[.06522 .30335 -9 -9 ]
[.06522 .30335 9 0 ]
[.27226 .30335 -6 -9 ]
[.27226 .30335 6 0 ]
[.68634 .30335 -3 -9 ]
[.68634 .30335 3 0 ]
[.89337 .30335 -6 -9 ]
[.89337 .30335 6 0 ]
[1.025 .31585 0 -4.5 ]
[1.025 .31585 6 4.5 ]
[.4668 .07601 -30 -4.5 ]
[.4668 .07601 0 4.5 ]
[.4668 .15596 -24 -4.5 ]
[.4668 .15596 0 4.5 ]
[.4668 .2359 -30 -4.5 ]
[.4668 .2359 0 4.5 ]
[.4668 .3958 -24 -4.5 ]
[.4668 .3958 0 4.5 ]
[.4668 .47574 -18 -4.5 ]
[.4668 .47574 0 4.5 ]
[.4668 .55569 -24 -4.5 ]
[.4668 .55569 0 4.5 ]
[.4793 .64303 -27 0 ]
[.4793 .64303 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06522 .31585 m
.06522 .3221 L
s
[(-10)] .06522 .30335 0 1 Mshowa
.27226 .31585 m
.27226 .3221 L
s
[(-5)] .27226 .30335 0 1 Mshowa
.68634 .31585 m
.68634 .3221 L
s
[(5)] .68634 .30335 0 1 Mshowa
.89337 .31585 m
.89337 .3221 L
s
[(10)] .89337 .30335 0 1 Mshowa
.125 Mabswid
.10663 .31585 m
.10663 .3196 L
s
.14803 .31585 m
.14803 .3196 L
s
.18944 .31585 m
.18944 .3196 L
s
.23085 .31585 m
.23085 .3196 L
s
.31366 .31585 m
.31366 .3196 L
s
.35507 .31585 m
.35507 .3196 L
s
.39648 .31585 m
.39648 .3196 L
s
.43789 .31585 m
.43789 .3196 L
s
.5207 .31585 m
.5207 .3196 L
s
.56211 .31585 m
.56211 .3196 L
s
.60352 .31585 m
.60352 .3196 L
s
.64493 .31585 m
.64493 .3196 L
s
.72774 .31585 m
.72774 .3196 L
s
.76915 .31585 m
.76915 .3196 L
s
.81056 .31585 m
.81056 .3196 L
s
.85197 .31585 m
.85197 .3196 L
s
.02381 .31585 m
.02381 .3196 L
s
.93478 .31585 m
.93478 .3196 L
s
.97619 .31585 m
.97619 .3196 L
s
.25 Mabswid
0 .31585 m
1 .31585 L
s
[(t)] 1.025 .31585 -1 0 Mshowa
.4793 .07601 m
.48555 .07601 L
s
[(-0.75)] .4668 .07601 1 0 Mshowa
.4793 .15596 m
.48555 .15596 L
s
[(-0.5)] .4668 .15596 1 0 Mshowa
.4793 .2359 m
.48555 .2359 L
s
[(-0.25)] .4668 .2359 1 0 Mshowa
.4793 .3958 m
.48555 .3958 L
s
[(0.25)] .4668 .3958 1 0 Mshowa
.4793 .47574 m
.48555 .47574 L
s
[(0.5)] .4668 .47574 1 0 Mshowa
.4793 .55569 m
.48555 .55569 L
s
[(0.75)] .4668 .55569 1 0 Mshowa
.125 Mabswid
.4793 .01205 m
.48305 .01205 L
s
.4793 .02804 m
.48305 .02804 L
s
.4793 .04403 m
.48305 .04403 L
s
.4793 .06002 m
.48305 .06002 L
s
.4793 .092 m
.48305 .092 L
s
.4793 .10799 m
.48305 .10799 L
s
.4793 .12398 m
.48305 .12398 L
s
.4793 .13997 m
.48305 .13997 L
s
.4793 .17194 m
.48305 .17194 L
s
.4793 .18793 m
.48305 .18793 L
s
.4793 .20392 m
.48305 .20392 L
s
.4793 .21991 m
.48305 .21991 L
s
.4793 .25189 m
.48305 .25189 L
s
.4793 .26788 m
.48305 .26788 L
s
.4793 .28387 m
.48305 .28387 L
s
.4793 .29986 m
.48305 .29986 L
s
.4793 .33184 m
.48305 .33184 L
s
.4793 .34783 m
.48305 .34783 L
s
.4793 .36382 m
.48305 .36382 L
s
.4793 .37981 m
.48305 .37981 L
s
.4793 .41179 m
.48305 .41179 L
s
.4793 .42777 m
.48305 .42777 L
s
.4793 .44376 m
.48305 .44376 L
s
.4793 .45975 m
.48305 .45975 L
s
.4793 .49173 m
.48305 .49173 L
s
.4793 .50772 m
.48305 .50772 L
s
.4793 .52371 m
.48305 .52371 L
s
.4793 .5397 m
.48305 .5397 L
s
.4793 .57168 m
.48305 .57168 L
s
.4793 .58767 m
.48305 .58767 L
s
.4793 .60366 m
.48305 .60366 L
s
.25 Mabswid
.4793 0 m
.4793 .61803 L
s
[(psi_12\\(t\\))] .4793 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .31585 m
.02446 .31585 L
.0251 .31585 L
.02575 .31585 L
.0264 .31585 L
.02704 .31585 L
.02769 .31585 L
.02834 .31585 L
.02899 .31585 L
.02963 .31585 L
.03028 .31585 L
.03093 .31585 L
.03157 .31585 L
.03222 .31585 L
.03287 .31585 L
.03351 .31585 L
.03416 .31585 L
.03481 .31585 L
.03546 .31585 L
.0361 .31585 L
.03675 .31585 L
.0374 .31585 L
.03804 .31585 L
.03869 .31585 L
.03934 .31585 L
.03998 .31585 L
.04063 .31585 L
.04128 .31585 L
.04193 .31585 L
.04257 .31585 L
.04322 .31585 L
.04387 .31585 L
.04451 .31585 L
.04516 .31585 L
.04581 .31585 L
.04645 .31585 L
.0471 .31585 L
.04775 .31585 L
.0484 .31585 L
.04904 .31585 L
.04969 .31585 L
.05034 .31585 L
.05098 .31585 L
.05163 .31585 L
.05228 .31585 L
.05292 .31585 L
.05357 .31585 L
.05422 .31585 L
.05487 .31585 L
.05551 .31585 L
Mistroke
.05616 .31585 L
.05681 .31585 L
.05745 .31585 L
.0581 .31585 L
.05875 .31585 L
.05939 .31585 L
.06004 .31585 L
.06069 .31585 L
.06134 .31585 L
.06198 .31585 L
.06263 .31585 L
.06328 .31585 L
.06392 .31585 L
.06457 .31585 L
.06522 .31585 L
.06586 .31585 L
.06651 .31585 L
.06716 .31585 L
.06781 .31585 L
.06845 .31585 L
.0691 .31585 L
.06975 .31585 L
.07039 .31585 L
.07104 .31585 L
.07169 .31585 L
.07233 .31585 L
.07298 .31585 L
.07363 .31585 L
.07428 .31585 L
.07492 .31585 L
.07557 .31585 L
.07622 .31585 L
.07686 .31585 L
.07751 .31585 L
.07816 .31585 L
.0788 .31585 L
.07945 .31585 L
.0801 .31585 L
.08075 .31585 L
.08139 .31585 L
.08204 .31585 L
.08269 .31585 L
.08333 .31585 L
.08398 .31585 L
.08463 .31585 L
.08527 .31585 L
.08592 .31585 L
.08657 .31585 L
.08722 .31585 L
.08786 .31585 L
Mistroke
.08851 .31585 L
.08916 .31585 L
.0898 .31585 L
.09045 .31585 L
.0911 .31585 L
.09174 .31584 L
.09239 .31584 L
.09304 .31584 L
.09369 .31584 L
.09433 .31584 L
.09498 .31584 L
.09563 .31584 L
.09627 .31584 L
.09692 .31584 L
.09757 .31584 L
.09821 .31584 L
.09886 .31584 L
.09951 .31584 L
.10016 .31584 L
.1008 .31584 L
.10145 .31584 L
.1021 .31584 L
.10274 .31584 L
.10339 .31584 L
.10404 .31584 L
.10468 .31584 L
.10533 .31584 L
.10598 .31584 L
.10663 .31584 L
.10727 .31584 L
.10792 .31584 L
.10857 .31584 L
.10921 .31584 L
.10986 .31584 L
.11051 .31584 L
.11115 .31584 L
.1118 .31584 L
.11245 .31584 L
.1131 .31584 L
.11374 .31584 L
.11439 .31584 L
.11504 .31584 L
.11568 .31584 L
.11633 .31584 L
.11698 .31584 L
.11762 .31584 L
.11827 .31584 L
.11892 .31584 L
.11957 .31584 L
.12021 .31584 L
Mistroke
.12086 .31584 L
.12151 .31584 L
.12215 .31585 L
.1228 .31585 L
.12345 .31585 L
.12409 .31585 L
.12474 .31585 L
.12539 .31585 L
.12604 .31585 L
.12668 .31585 L
.12733 .31585 L
.12798 .31586 L
.12862 .31586 L
.12927 .31586 L
.12992 .31586 L
.13056 .31586 L
.13121 .31586 L
.13186 .31587 L
.13251 .31587 L
.13315 .31587 L
.1338 .31587 L
.13445 .31587 L
.13509 .31588 L
.13574 .31588 L
.13639 .31588 L
.13703 .31588 L
.13768 .31589 L
.13833 .31589 L
.13898 .31589 L
.13962 .3159 L
.14027 .3159 L
.14092 .3159 L
.14156 .31591 L
.14221 .31591 L
.14286 .31591 L
.1435 .31592 L
.14415 .31592 L
.1448 .31592 L
.14545 .31593 L
.14609 .31593 L
.14674 .31594 L
.14739 .31594 L
.14803 .31594 L
.14868 .31595 L
.14933 .31595 L
.14997 .31595 L
.15062 .31596 L
.15127 .31596 L
.15192 .31597 L
.15256 .31597 L
Mistroke
.15321 .31597 L
.15386 .31598 L
.1545 .31598 L
.15515 .31598 L
.1558 .31599 L
.15644 .31599 L
.15709 .31599 L
.15774 .31599 L
.15839 .316 L
.15903 .316 L
.15968 .316 L
.16033 .316 L
.16097 .316 L
.16162 .316 L
.16227 .31601 L
.16291 .31601 L
.16356 .31601 L
.16421 .31601 L
.16486 .316 L
.1655 .316 L
.16615 .316 L
.1668 .316 L
.16744 .316 L
.16809 .31599 L
.16874 .31599 L
.16938 .31598 L
.17003 .31598 L
.17068 .31597 L
.17133 .31597 L
.17197 .31596 L
.17262 .31595 L
.17327 .31594 L
.17391 .31594 L
.17456 .31593 L
.17521 .31591 L
.17585 .3159 L
.1765 .31589 L
.17715 .31588 L
.1778 .31586 L
.17844 .31585 L
.17909 .31584 L
.17974 .31582 L
.18038 .3158 L
.18103 .31578 L
.18168 .31577 L
.18232 .31575 L
.18297 .31573 L
.18362 .31571 L
.18427 .31568 L
.18491 .31566 L
Mistroke
.18556 .31564 L
.18621 .31561 L
.18685 .31559 L
.1875 .31556 L
.18815 .31554 L
.18879 .31551 L
.18944 .31548 L
.19009 .31546 L
.19073 .31543 L
.19138 .3154 L
.19203 .31537 L
.19268 .31534 L
.19332 .31531 L
.19397 .31528 L
.19462 .31525 L
.19526 .31522 L
.19591 .31519 L
.19656 .31515 L
.1972 .31512 L
.19785 .31509 L
.1985 .31506 L
.19915 .31503 L
.19979 .315 L
.20044 .31497 L
.20109 .31494 L
.20173 .31492 L
.20238 .31489 L
.20303 .31486 L
.20367 .31484 L
.20432 .31481 L
.20497 .31479 L
.20562 .31477 L
.20626 .31475 L
.20691 .31473 L
.20756 .31471 L
.2082 .3147 L
.20885 .31469 L
.2095 .31468 L
.21014 .31467 L
.21079 .31466 L
.21144 .31466 L
.21209 .31466 L
.21273 .31466 L
.21338 .31467 L
.21403 .31467 L
.21467 .31469 L
.21532 .3147 L
.21597 .31472 L
.21661 .31474 L
.21726 .31476 L
Mistroke
.21791 .31479 L
.21856 .31482 L
.2192 .31486 L
.21985 .3149 L
.2205 .31494 L
.22114 .31499 L
.22179 .31504 L
.22244 .3151 L
.22308 .31515 L
.22373 .31522 L
.22438 .31529 L
.22503 .31536 L
.22567 .31544 L
.22632 .31552 L
.22697 .3156 L
.22761 .31569 L
.22826 .31578 L
.22891 .31588 L
.22955 .31598 L
.2302 .31609 L
.23085 .3162 L
.2315 .31631 L
.23214 .31643 L
.23279 .31655 L
.23344 .31668 L
.23408 .31681 L
.23473 .31694 L
.23538 .31707 L
.23602 .31721 L
.23667 .31735 L
.23732 .31749 L
.23797 .31764 L
.23861 .31779 L
.23926 .31794 L
.23991 .31809 L
.24055 .31824 L
.2412 .31839 L
.24185 .31854 L
.24249 .31869 L
.24314 .31885 L
.24379 .319 L
.24444 .31915 L
.24508 .3193 L
.24573 .31944 L
.24638 .31959 L
.24702 .31973 L
.24767 .31987 L
.24832 .32 L
.24896 .32014 L
.24961 .32026 L
Mistroke
.25026 .32038 L
.25091 .3205 L
.25155 .32061 L
.2522 .32071 L
.25285 .3208 L
.25349 .32089 L
.25414 .32097 L
.25479 .32104 L
.25543 .3211 L
.25608 .32116 L
.25673 .3212 L
.25738 .32123 L
.25802 .32125 L
.25867 .32126 L
.25932 .32126 L
.25996 .32125 L
.26061 .32122 L
.26126 .32118 L
.2619 .32113 L
.26255 .32107 L
.2632 .32099 L
.26385 .32089 L
.26449 .32078 L
.26514 .32066 L
.26579 .32053 L
.26643 .32037 L
.26708 .32021 L
.26773 .32002 L
.26837 .31982 L
.26902 .31961 L
.26967 .31938 L
.27032 .31913 L
.27096 .31887 L
.27161 .31859 L
.27226 .3183 L
.2729 .31799 L
.27355 .31766 L
.2742 .31732 L
.27484 .31697 L
.27549 .3166 L
.27614 .31621 L
.27679 .31582 L
.27743 .3154 L
.27808 .31498 L
.27873 .31454 L
.27937 .31409 L
.28002 .31363 L
.28067 .31316 L
.28131 .31268 L
.28196 .31219 L
Mistroke
.28261 .3117 L
.28326 .31119 L
.2839 .31068 L
.28455 .31016 L
.2852 .30965 L
.28584 .30912 L
.28649 .3086 L
.28714 .30807 L
.28778 .30755 L
.28843 .30703 L
.28908 .30651 L
.28973 .30599 L
.29037 .30548 L
.29102 .30498 L
.29167 .30449 L
.29231 .30401 L
.29296 .30354 L
.29361 .30308 L
.29425 .30264 L
.2949 .30221 L
.29555 .30181 L
.2962 .30142 L
.29684 .30105 L
.29749 .3007 L
.29814 .30038 L
.29878 .30008 L
.29943 .29981 L
.30008 .29956 L
.30072 .29935 L
.30137 .29916 L
.30202 .29901 L
.30267 .29889 L
.30331 .2988 L
.30396 .29874 L
.30461 .29873 L
.30525 .29874 L
.3059 .2988 L
.30655 .2989 L
.30719 .29903 L
.30784 .29921 L
.30849 .29942 L
.30914 .29968 L
.30978 .29999 L
.31043 .30033 L
.31108 .30072 L
.31172 .30115 L
.31237 .30163 L
.31302 .30216 L
.31366 .30273 L
.31431 .30334 L
Mistroke
.31496 .304 L
.31561 .3047 L
.31625 .30545 L
.3169 .30624 L
.31755 .30708 L
.31819 .30796 L
.31884 .30887 L
.31949 .30983 L
.32013 .31083 L
.32078 .31187 L
.32143 .31295 L
.32208 .31406 L
.32272 .3152 L
.32337 .31638 L
.32402 .31759 L
.32466 .31882 L
.32531 .32008 L
.32596 .32137 L
.3266 .32268 L
.32725 .324 L
.3279 .32534 L
.32855 .3267 L
.32919 .32806 L
.32984 .32943 L
.33049 .33081 L
.33113 .33219 L
.33178 .33356 L
.33243 .33493 L
.33307 .33629 L
.33372 .33763 L
.33437 .33896 L
.33502 .34027 L
.33566 .34155 L
.33631 .3428 L
.33696 .34403 L
.3376 .34522 L
.33825 .34637 L
.3389 .34747 L
.33954 .34854 L
.34019 .34955 L
.34084 .35051 L
.34149 .35142 L
.34213 .35226 L
.34278 .35305 L
.34343 .35377 L
.34407 .35442 L
.34472 .355 L
.34537 .35551 L
.34601 .35594 L
.34666 .35629 L
Mistroke
.34731 .35656 L
.34796 .35674 L
.3486 .35684 L
.34925 .35685 L
.3499 .35676 L
.35054 .35658 L
.35119 .35631 L
.35184 .35593 L
.35248 .35546 L
.35313 .35489 L
.35378 .35421 L
.35443 .35344 L
.35507 .35256 L
.35572 .35157 L
.35637 .35048 L
.35701 .34929 L
.35766 .348 L
.35831 .3466 L
.35895 .3451 L
.3596 .34349 L
.36025 .34179 L
.3609 .33999 L
.36154 .3381 L
.36219 .33611 L
.36284 .33403 L
.36348 .33186 L
.36413 .32961 L
.36478 .32727 L
.36542 .32486 L
.36607 .32238 L
.36672 .31982 L
.36737 .3172 L
.36801 .31452 L
.36866 .31179 L
.36931 .30901 L
.36995 .30619 L
.3706 .30333 L
.37125 .30044 L
.37189 .29752 L
.37254 .2946 L
.37319 .29166 L
.37384 .28872 L
.37448 .28579 L
.37513 .28288 L
.37578 .27998 L
.37642 .27712 L
.37707 .27429 L
.37772 .27151 L
.37836 .26878 L
.37901 .26611 L
Mistroke
.37966 .26351 L
.38031 .26099 L
.38095 .25855 L
.3816 .25621 L
.38225 .25396 L
.38289 .25181 L
.38354 .24978 L
.38419 .24786 L
.38483 .24608 L
.38548 .24442 L
.38613 .2429 L
.38678 .24152 L
.38742 .2403 L
.38807 .23923 L
.38872 .23832 L
.38936 .23758 L
.39001 .23702 L
.39066 .23663 L
.3913 .23642 L
.39195 .2364 L
.3926 .23657 L
.39325 .23694 L
.39389 .23751 L
.39454 .23827 L
.39519 .23925 L
.39583 .24042 L
.39648 .24181 L
.39713 .2434 L
.39777 .2452 L
.39842 .24721 L
.39907 .24943 L
.39972 .25185 L
.40036 .25448 L
.40101 .25731 L
.40166 .26035 L
.4023 .26357 L
.40295 .26699 L
.4036 .2706 L
.40424 .27439 L
.40489 .27835 L
.40554 .28249 L
.40619 .28678 L
.40683 .29124 L
.40748 .29583 L
.40813 .30057 L
.40877 .30543 L
.40942 .31041 L
.41007 .3155 L
.41071 .32068 L
.41136 .32594 L
Mistroke
.41201 .33127 L
.41266 .33666 L
.4133 .34208 L
.41395 .34753 L
.4146 .35299 L
.41524 .35845 L
.41589 .36389 L
.41654 .36929 L
.41718 .37464 L
.41783 .37992 L
.41848 .38512 L
.41913 .39021 L
.41977 .39519 L
.42042 .40003 L
.42107 .40473 L
.42171 .40927 L
.42236 .41362 L
.42301 .41779 L
.42365 .42175 L
.4243 .42549 L
.42495 .42899 L
.4256 .43225 L
.42624 .43525 L
.42689 .43798 L
.42754 .44043 L
.42818 .44258 L
.42883 .44442 L
.42948 .44595 L
.43012 .44715 L
.43077 .44801 L
.43142 .44852 L
.43207 .44868 L
.43271 .44848 L
.43336 .4479 L
.43401 .44695 L
.43465 .44561 L
.4353 .44388 L
.43595 .44177 L
.43659 .43925 L
.43724 .43635 L
.43789 .43304 L
.43854 .42935 L
.43918 .42526 L
.43983 .42078 L
.44048 .41592 L
.44112 .41067 L
.44177 .40506 L
.44242 .39909 L
.44306 .39276 L
.44371 .38609 L
Mistroke
.44436 .3791 L
.44501 .37179 L
.44565 .36418 L
.4463 .35628 L
.44695 .34812 L
.44759 .33972 L
.44824 .33109 L
.44889 .32226 L
.44953 .31324 L
.45018 .30407 L
.45083 .29476 L
.45148 .28536 L
.45212 .27588 L
.45277 .26635 L
.45342 .25682 L
.45406 .2473 L
.45471 .23784 L
.45536 .22847 L
.456 .21922 L
.45665 .21013 L
.4573 .20123 L
.45795 .19256 L
.45859 .18415 L
.45924 .17605 L
.45989 .16829 L
.46053 .16089 L
.46118 .1539 L
.46183 .14735 L
.46247 .14127 L
.46312 .13569 L
.46377 .13063 L
.46442 .12613 L
.46506 .12222 L
.46571 .11891 L
.46636 .11623 L
.467 .1142 L
.46765 .11285 L
.4683 .11219 L
.46894 .11225 L
.46959 .11303 L
.47024 .11454 L
.47089 .11681 L
.47153 .11985 L
.47218 .12365 L
.47283 .12823 L
.47347 .13359 L
.47412 .13973 L
.47477 .14665 L
.47541 .15435 L
.47606 .16281 L
Mistroke
.47671 .17204 L
.47736 .18201 L
.478 .1927 L
.47865 .20409 L
.4793 .21615 L
.47994 .22886 L
.48059 .24218 L
.48124 .25606 L
.48188 .27046 L
.48253 .28535 L
.48318 .30065 L
.48383 .31633 L
.48447 .33231 L
.48512 .34853 L
.48577 .36493 L
.48641 .38142 L
.48706 .39794 L
.48771 .41441 L
.48835 .43075 L
.489 .44687 L
.48965 .46268 L
.4903 .47811 L
.49094 .49307 L
.49159 .50745 L
.49224 .52118 L
.49288 .53415 L
.49353 .54628 L
.49418 .55748 L
.49482 .56765 L
.49547 .57672 L
.49612 .58458 L
.49677 .59117 L
.49741 .59641 L
.49806 .60022 L
.49871 .60255 L
.49935 .60332 L
.5 .60249 L
.50065 .60003 L
.50129 .59589 L
.50194 .59007 L
.50259 .58256 L
.50323 .57337 L
.50388 .56253 L
.50453 .55008 L
.50518 .53606 L
.50582 .52055 L
.50647 .50361 L
.50712 .48535 L
.50776 .46587 L
.50841 .44527 L
Mistroke
.50906 .42369 L
.5097 .40127 L
.51035 .37814 L
.511 .35447 L
.51165 .33041 L
.51229 .30613 L
.51294 .28179 L
.51359 .25755 L
.51423 .23359 L
.51488 .21006 L
.51553 .18714 L
.51617 .16498 L
.51682 .14376 L
.51747 .12364 L
.51812 .10477 L
.51876 .08733 L
.51941 .07146 L
.52006 .05731 L
.5207 .045 L
.52135 .03467 L
.522 .02639 L
.52264 .02027 L
.52329 .01637 L
.52394 .01472 L
.52459 .01534 L
.52523 .01824 L
.52588 .02341 L
.52653 .03081 L
.52717 .04037 L
.52782 .052 L
.52847 .06561 L
.52911 .08105 L
.52976 .09819 L
.53041 .11684 L
.53106 .13683 L
.5317 .15795 L
.53235 .18002 L
.533 .20284 L
.53364 .22621 L
.53429 .24995 L
.53494 .27387 L
.53558 .29778 L
.53623 .32152 L
.53688 .34489 L
.53753 .36772 L
.53817 .38984 L
.53882 .41104 L
.53947 .43117 L
.54011 .45003 L
.54076 .46748 L
Mistroke
.54141 .48337 L
.54205 .49759 L
.5427 .51 L
.54335 .52052 L
.544 .52907 L
.54464 .53557 L
.54529 .53999 L
.54594 .5423 L
.54658 .54248 L
.54723 .54053 L
.54788 .5365 L
.54852 .53046 L
.54917 .52253 L
.54982 .51283 L
.55047 .50153 L
.55111 .48879 L
.55176 .47482 L
.55241 .45981 L
.55305 .44396 L
.5537 .42746 L
.55435 .41049 L
.55499 .3932 L
.55564 .37575 L
.55629 .35828 L
.55694 .34096 L
.55758 .32392 L
.55823 .30731 L
.55888 .29125 L
.55952 .27588 L
.56017 .26133 L
.56082 .24772 L
.56146 .23515 L
.56211 .22369 L
.56276 .2134 L
.56341 .20436 L
.56405 .19661 L
.5647 .19023 L
.56535 .18525 L
.56599 .18171 L
.56664 .17965 L
.56729 .17909 L
.56793 .18004 L
.56858 .1825 L
.56923 .18639 L
.56988 .19161 L
.57052 .19805 L
.57117 .20556 L
.57182 .214 L
.57246 .2232 L
.57311 .23299 L
Mistroke
.57376 .24321 L
.5744 .25371 L
.57505 .26436 L
.5757 .27506 L
.57635 .28571 L
.57699 .29618 L
.57764 .30638 L
.57829 .31621 L
.57893 .32557 L
.57958 .33441 L
.58023 .34265 L
.58087 .35023 L
.58152 .35712 L
.58217 .3633 L
.58282 .36877 L
.58346 .37354 L
.58411 .37761 L
.58476 .38099 L
.5854 .38364 L
.58605 .38555 L
.5867 .38668 L
.58734 .38703 L
.58799 .38656 L
.58864 .38526 L
.58929 .38313 L
.58993 .38021 L
.59058 .37657 L
.59123 .37231 L
.59187 .36752 L
.59252 .3623 L
.59317 .35676 L
.59381 .35099 L
.59446 .3451 L
.59511 .33918 L
.59576 .3333 L
.5964 .32753 L
.59705 .32192 L
.5977 .31655 L
.59834 .3115 L
.59899 .30682 L
.59964 .30258 L
.60028 .2988 L
.60093 .29549 L
.60158 .29265 L
.60223 .29028 L
.60287 .28835 L
.60352 .28682 L
.60417 .28562 L
.60481 .28472 L
.60546 .2841 L
Mistroke
.60611 .28376 L
.60675 .2837 L
.6074 .28395 L
.60805 .28449 L
.6087 .28536 L
.60934 .28655 L
.60999 .28808 L
.61064 .28992 L
.61128 .29203 L
.61193 .29437 L
.61258 .29688 L
.61322 .29952 L
.61387 .30224 L
.61452 .30502 L
.61517 .30782 L
.61581 .31058 L
.61646 .31328 L
.61711 .31588 L
.61775 .31836 L
.6184 .32066 L
.61905 .32275 L
.61969 .32457 L
.62034 .32609 L
.62099 .32731 L
.62164 .32822 L
.62228 .32885 L
.62293 .32922 L
.62358 .32936 L
.62422 .32933 L
.62487 .32916 L
.62552 .3289 L
.62616 .32857 L
.62681 .32818 L
.62746 .32773 L
.62811 .3272 L
.62875 .3266 L
.6294 .32594 L
.63005 .32521 L
.63069 .3244 L
.63134 .32354 L
.63199 .32262 L
.63263 .32167 L
.63328 .32071 L
.63393 .31974 L
.63458 .31877 L
.63522 .3178 L
.63587 .31681 L
.63652 .31584 L
.63716 .31488 L
.63781 .31396 L
Mistroke
.63846 .31309 L
.6391 .31228 L
.63975 .31158 L
.6404 .31101 L
.64105 .31059 L
.64169 .31033 L
.64234 .31021 L
.64299 .31022 L
.64363 .31034 L
.64428 .31056 L
.64493 .31084 L
.64557 .31116 L
.64622 .31151 L
.64687 .31186 L
.64752 .3122 L
.64816 .31256 L
.64881 .31291 L
.64946 .31327 L
.6501 .31362 L
.65075 .31396 L
.6514 .31428 L
.65204 .31458 L
.65269 .31486 L
.65334 .31512 L
.65399 .31534 L
.65463 .31555 L
.65528 .31575 L
.65593 .31595 L
.65657 .31616 L
.65722 .31638 L
.65787 .31662 L
.65851 .31685 L
.65916 .31708 L
.65981 .31729 L
.66046 .31747 L
.6611 .31761 L
.66175 .3177 L
.6624 .31773 L
.66304 .31771 L
.66369 .31765 L
.66434 .31755 L
.66498 .31743 L
.66563 .31729 L
.66628 .31714 L
.66693 .31698 L
.66757 .31682 L
.66822 .31666 L
.66887 .3165 L
.66951 .31633 L
.67016 .31618 L
Mistroke
.67081 .31603 L
.67145 .31591 L
.6721 .31581 L
.67275 .31573 L
.6734 .31567 L
.67404 .31564 L
.67469 .31562 L
.67534 .31563 L
.67598 .31564 L
.67663 .31564 L
.67728 .31564 L
.67792 .31563 L
.67857 .3156 L
.67922 .31557 L
.67987 .31554 L
.68051 .3155 L
.68116 .31547 L
.68181 .31545 L
.68245 .31544 L
.6831 .31544 L
.68375 .31545 L
.68439 .31546 L
.68504 .31548 L
.68569 .31551 L
.68634 .31554 L
.68698 .31557 L
.68763 .31561 L
.68828 .31566 L
.68892 .3157 L
.68957 .31575 L
.69022 .3158 L
.69086 .31586 L
.69151 .31591 L
.69216 .31595 L
.69281 .31598 L
.69345 .31599 L
.6941 .316 L
.69475 .316 L
.69539 .31599 L
.69604 .31597 L
.69669 .31595 L
.69733 .31593 L
.69798 .31592 L
.69863 .3159 L
.69928 .3159 L
.69992 .31589 L
.70057 .31589 L
.70122 .31589 L
.70186 .31589 L
.70251 .31589 L
Mistroke
.70316 .31589 L
.7038 .31588 L
.70445 .31588 L
.7051 .31588 L
.70575 .31589 L
.70639 .31589 L
.70704 .31589 L
.70769 .31589 L
.70833 .31589 L
.70898 .31589 L
.70963 .31588 L
.71027 .31587 L
.71092 .31586 L
.71157 .31584 L
.71222 .31583 L
.71286 .31582 L
.71351 .31581 L
.71416 .31581 L
.7148 .31581 L
.71545 .31581 L
.7161 .31581 L
.71674 .31582 L
.71739 .31582 L
.71804 .31583 L
.71869 .31583 L
.71933 .31584 L
.71998 .31584 L
.72063 .31584 L
.72127 .31585 L
.72192 .31585 L
.72257 .31585 L
.72321 .31586 L
.72386 .31586 L
.72451 .31586 L
.72516 .31586 L
.7258 .31586 L
.72645 .31585 L
.7271 .31585 L
.72774 .31585 L
.72839 .31584 L
.72904 .31584 L
.72968 .31584 L
.73033 .31584 L
.73098 .31584 L
.73163 .31584 L
.73227 .31585 L
.73292 .31585 L
.73357 .31585 L
.73421 .31585 L
.73486 .31585 L
Mistroke
.73551 .31585 L
.73615 .31585 L
.7368 .31585 L
.73745 .31585 L
.7381 .31585 L
.73874 .31585 L
.73939 .31585 L
.74004 .31585 L
.74068 .31585 L
.74133 .31585 L
.74198 .31585 L
.74262 .31585 L
.74327 .31585 L
.74392 .31585 L
.74457 .31585 L
.74521 .31584 L
.74586 .31584 L
.74651 .31585 L
.74715 .31585 L
.7478 .31585 L
.74845 .31585 L
.74909 .31585 L
.74974 .31585 L
.75039 .31585 L
.75104 .31585 L
.75168 .31585 L
.75233 .31585 L
.75298 .31585 L
.75362 .31585 L
.75427 .31585 L
.75492 .31585 L
.75556 .31585 L
.75621 .31585 L
.75686 .31585 L
.75751 .31585 L
.75815 .31585 L
.7588 .31585 L
.75945 .31585 L
.76009 .31585 L
.76074 .31585 L
.76139 .31585 L
.76203 .31585 L
.76268 .31585 L
.76333 .31585 L
.76398 .31585 L
.76462 .31585 L
.76527 .31585 L
.76592 .31585 L
.76656 .31585 L
.76721 .31585 L
Mistroke
.76786 .31585 L
.7685 .31585 L
.76915 .31585 L
.7698 .31585 L
.77045 .31585 L
.77109 .31585 L
.77174 .31585 L
.77239 .31585 L
.77303 .31585 L
.77368 .31585 L
.77433 .31585 L
.77497 .31585 L
.77562 .31585 L
.77627 .31585 L
.77692 .31585 L
.77756 .31585 L
.77821 .31585 L
.77886 .31585 L
.7795 .31585 L
.78015 .31585 L
.7808 .31585 L
.78144 .31585 L
.78209 .31585 L
.78274 .31585 L
.78339 .31585 L
.78403 .31585 L
.78468 .31585 L
.78533 .31585 L
.78597 .31585 L
.78662 .31585 L
.78727 .31585 L
.78791 .31585 L
.78856 .31585 L
.78921 .31585 L
.78986 .31585 L
.7905 .31585 L
.79115 .31585 L
.7918 .31585 L
.79244 .31585 L
.79309 .31585 L
.79374 .31585 L
.79438 .31585 L
.79503 .31585 L
.79568 .31585 L
.79633 .31585 L
.79697 .31585 L
.79762 .31585 L
.79827 .31585 L
.79891 .31585 L
.79956 .31585 L
Mistroke
.80021 .31585 L
.80085 .31585 L
.8015 .31585 L
.80215 .31585 L
.8028 .31585 L
.80344 .31585 L
.80409 .31585 L
.80474 .31585 L
.80538 .31585 L
.80603 .31585 L
.80668 .31585 L
.80732 .31585 L
.80797 .31585 L
.80862 .31585 L
.80927 .31585 L
.80991 .31585 L
.81056 .31585 L
.81121 .31585 L
.81185 .31585 L
.8125 .31585 L
.81315 .31585 L
.81379 .31585 L
.81444 .31585 L
.81509 .31585 L
.81573 .31585 L
.81638 .31585 L
.81703 .31585 L
.81768 .31585 L
.81832 .31585 L
.81897 .31585 L
.81962 .31585 L
.82026 .31585 L
.82091 .31585 L
.82156 .31585 L
.8222 .31585 L
.82285 .31585 L
.8235 .31585 L
.82415 .31585 L
.82479 .31585 L
.82544 .31585 L
.82609 .31585 L
.82673 .31585 L
.82738 .31585 L
.82803 .31585 L
.82867 .31585 L
.82932 .31585 L
.82997 .31585 L
.83062 .31585 L
.83126 .31585 L
.83191 .31585 L
Mistroke
.83256 .31585 L
.8332 .31585 L
.83385 .31585 L
.8345 .31585 L
.83514 .31585 L
.83579 .31585 L
.83644 .31585 L
.83709 .31585 L
.83773 .31585 L
.83838 .31585 L
.83903 .31585 L
.83967 .31585 L
.84032 .31585 L
.84097 .31585 L
.84161 .31585 L
.84226 .31585 L
.84291 .31585 L
.84356 .31585 L
.8442 .31585 L
.84485 .31585 L
.8455 .31585 L
.84614 .31585 L
.84679 .31585 L
.84744 .31585 L
.84808 .31585 L
.84873 .31585 L
.84938 .31585 L
.85003 .31585 L
.85067 .31585 L
.85132 .31585 L
.85197 .31585 L
.85261 .31585 L
.85326 .31585 L
.85391 .31585 L
.85455 .31585 L
.8552 .31585 L
.85585 .31585 L
.8565 .31585 L
.85714 .31585 L
.85779 .31585 L
.85844 .31585 L
.85908 .31585 L
.85973 .31585 L
.86038 .31585 L
.86102 .31585 L
.86167 .31585 L
.86232 .31585 L
.86297 .31585 L
.86361 .31585 L
.86426 .31585 L
Mistroke
.86491 .31585 L
.86555 .31585 L
.8662 .31585 L
.86685 .31585 L
.86749 .31585 L
.86814 .31585 L
.86879 .31585 L
.86944 .31585 L
.87008 .31585 L
.87073 .31585 L
.87138 .31585 L
.87202 .31585 L
.87267 .31585 L
.87332 .31585 L
.87396 .31585 L
.87461 .31585 L
.87526 .31585 L
.87591 .31585 L
.87655 .31585 L
.8772 .31585 L
.87785 .31585 L
.87849 .31585 L
.87914 .31585 L
.87979 .31585 L
.88043 .31585 L
.88108 .31585 L
.88173 .31585 L
.88238 .31585 L
.88302 .31585 L
.88367 .31585 L
.88432 .31585 L
.88496 .31585 L
.88561 .31585 L
.88626 .31585 L
.8869 .31585 L
.88755 .31585 L
.8882 .31585 L
.88885 .31585 L
.88949 .31585 L
.89014 .31585 L
.89079 .31585 L
.89143 .31585 L
.89208 .31585 L
.89273 .31585 L
.89337 .31585 L
.89402 .31585 L
.89467 .31585 L
.89532 .31585 L
.89596 .31585 L
.89661 .31585 L
Mistroke
.89726 .31585 L
.8979 .31585 L
.89855 .31585 L
.8992 .31585 L
.89984 .31585 L
.90049 .31585 L
.90114 .31585 L
.90179 .31585 L
.90243 .31585 L
.90308 .31585 L
.90373 .31585 L
.90437 .31585 L
.90502 .31585 L
.90567 .31585 L
.90631 .31585 L
.90696 .31585 L
.90761 .31585 L
.90826 .31585 L
.9089 .31585 L
.90955 .31585 L
.9102 .31585 L
.91084 .31585 L
.91149 .31585 L
.91214 .31585 L
.91278 .31585 L
.91343 .31585 L
.91408 .31585 L
.91473 .31585 L
.91537 .31585 L
.91602 .31585 L
.91667 .31585 L
.91731 .31585 L
.91796 .31585 L
.91861 .31585 L
.91925 .31585 L
.9199 .31585 L
.92055 .31585 L
.9212 .31585 L
.92184 .31585 L
.92249 .31585 L
.92314 .31585 L
.92378 .31585 L
.92443 .31585 L
.92508 .31585 L
.92572 .31585 L
.92637 .31585 L
.92702 .31585 L
.92767 .31585 L
.92831 .31585 L
.92896 .31585 L
Mistroke
.92961 .31585 L
.93025 .31585 L
.9309 .31585 L
.93155 .31585 L
.93219 .31585 L
.93284 .31585 L
.93349 .31585 L
.93414 .31585 L
.93478 .31585 L
.93543 .31585 L
.93608 .31585 L
.93672 .31585 L
.93737 .31585 L
.93802 .31585 L
.93866 .31585 L
.93931 .31585 L
.93996 .31585 L
.94061 .31585 L
.94125 .31585 L
.9419 .31585 L
.94255 .31585 L
.94319 .31585 L
.94384 .31585 L
.94449 .31585 L
.94513 .31585 L
.94578 .31585 L
.94643 .31585 L
.94708 .31585 L
.94772 .31585 L
.94837 .31585 L
.94902 .31585 L
.94966 .31585 L
.95031 .31585 L
.95096 .31585 L
.9516 .31585 L
.95225 .31585 L
.9529 .31585 L
.95355 .31585 L
.95419 .31585 L
.95484 .31585 L
.95549 .31585 L
.95613 .31585 L
.95678 .31585 L
.95743 .31585 L
.95807 .31585 L
.95872 .31585 L
.95937 .31585 L
.96002 .31585 L
.96066 .31585 L
.96131 .31585 L
Mistroke
.96196 .31585 L
.9626 .31585 L
.96325 .31585 L
.9639 .31585 L
.96454 .31585 L
.96519 .31585 L
.96584 .31585 L
.96649 .31585 L
.96713 .31585 L
.96778 .31585 L
.96843 .31585 L
.96907 .31585 L
.96972 .31585 L
.97037 .31585 L
.97101 .31585 L
.97166 .31585 L
.97231 .31585 L
.97296 .31585 L
.9736 .31585 L
.97425 .31585 L
.9749 .31585 L
.97554 .31585 L
.97619 .31585 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],

Cell["1.4.4 Daubechies' Least Asymmetric Filters", "Subsection",
  CellTags->{"S1.4.4", "4.1"}],

Cell[TextData[{
  "In Sections ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  " and ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  " we illustrated how to find Daubechies filter coefficients by constructing \
the appropriate transfer function ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". The transfer function was formed by systematically retaining the zeros \
inside the unit circle in the course of the spectral factorization procedure. \
Of course, for each quadruplet or doublet roots, we could equally well have \
chosen to retain the roots or root outside the unit circle. Suppose the \
polynomial has a total of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " groups of quadruplet and doublet roots, then we have ",
  Cell[BoxData[
      \(TraditionalForm\`2\^n\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " choices to form ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", each corresponding to selecting a particular set of zeros to retain. \
These different choices result in different phases for ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " and, in turn, different filter coefficients and wavelets, all of which \
satisfy the orthogonality condition (",
  ButtonBox["4.3",
    ButtonData:>{"Wavelets 1.4.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  ") and moment vanishing condition (",
  ButtonBox["4.5",
    ButtonData:>{"Wavelets 1.4.1", "1.11"},
    ButtonStyle->"AddOnsLink"],
  "). In practice, it is a matter of choice which form of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " or wavelets we choose to adopt. \nIn some applications, we would like to \
have filters with certain symmetry properties. For example, if the real \
filter ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k/\@2} = {c\_0, c\_1, ..., c\_n}\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  " is symmetric or antisymmetric about the central coefficient, that is, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i = \[PlusMinus]c\_\(n - i\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", we have "
}], "Text",
  CellTags->{"S1.4.4", "4.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`H \((\[Omega])\) = c\_0 + \(c\_1\) e\^\(-i  \[Omega]\) + ... + \(c\_n\) 
      e\^\(-i  n  \[Omega]\) = \(e\^\(-i  n  \[Omega]/2\)\) 2 
      \((\(c\_0\) cos \( n\/2\) \[Omega] + \(c\_1\) cos \((n\/2 - 1)\) 
          \[Omega] + ...)\)\)], "DisplayFormula",
  CellTags->{"S1.4.4", "4.3"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i = c\_\(n - i\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", and "
}], "Text",
  CellTags->{"S1.4.4", "4.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`H \((\[Omega])\) = c\_0 + \(c\_1\) e\^\(-i  \[Omega]\) + ... + \(c\_n\) 
      e\^\(-i  n  \[Omega]\) = \(e\^\(-i  n  \[Omega]/2\)\) 2  i \((
      \(c\_0\) sin \( n\/2\) \[Omega] + \(c\_1\) sin \((n\/2 - 1)\) 
        \[Omega] + ...)\)\)], "DisplayFormula",
  CellTags->{"S1.4.4", "4.5"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i = -c\_\(n - i\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". In both cases, the transfer function ",
  Cell[BoxData[
      \(TraditionalForm
      \`H \((\[Omega])\) \[Congruent] e\^\(i  \[Phi] \((\[Omega])\)\) 
        \[VerticalSeparator] H \((\[Omega])\) \[VerticalSeparator] \)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  " has a phase which is linear in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Phi] \((\[Omega])\) = \[Alpha]\[Omega] + \[Beta]\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  ". We call such filters ",
  StyleBox["linear phase filters", "TI"],
  " because the phase of its transfer function is linear in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ".\nIt has been shown that within Daubechies' method of constructing \
compactly supported wavelets, one cannot generate a wavelet or filter with \
complete symmetry. However, we can use our freedom of choosing the zeros \
described in Section ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  " to achieve a wavelet with the least asymmetry. The idea is to calculate \
the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " and choose the zeros such that the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is as close to linear as possible. In the following, we will demonstrate \
how we accomplish this (see Daubechies (1992)). \nApart from an overall \
linear phase which we ignore, the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`m\_0\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " can be calculated as follows. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is a product of factors of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - z\_j)\) \((z - z\&_\_j)\)\)], "InlineFormula",
    
    CellTags->"S1.4.4"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - r\_j)\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", the overall phase is the the sum of the phase contribution from each of \
the factor. For a factor of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - z\_j)\) \((z - z\&_\_j)\)\)], "InlineFormula",
    
    CellTags->"S1.4.4"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`z = e\^\(i  \[Omega]\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j = \(R\_j\) e\^\(i  \[Alpha]\_j\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  ", we have "
}], "Text",
  CellTags->{"S1.4.4", "4.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`\((z - z\_j)\) \((z - z\&_\_j)\) = \(e\^\(i  \[Omega]\)\) \((
      1 - \(e\^\(-i  \[Omega]\)\) \(R\_j\) e\^\(i  \[Alpha]\_j\))\) 
      \((e\^\(i  \[Omega]\) - \(R\_j\) e\^\(-i  \[Alpha]\_j\))\) = 
      \(e\^\(i  \[Omega]\)\) \((
      e\^\(i  \[Omega]\) - 2 \( R\_j\) cos  \[Alpha]\_j + \(R\_j\%2\) 
        e\^\(-i  \[Omega]\))\), \)], "DisplayFormula",
  CellTags->{"S1.4.4", "4.7"}],

Cell["\<\
and the corresponding phase is, ignoring linear contributions, \
\
\>", "Text",
  CellTags->{"S1.4.4", "4.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\_j\) \((\[Omega])\) = arctan \((
      \(\((1 - R\_j\%2)\) sin  \[Omega]\)\/\(\((1 + R\_j\%2)\) cos  
          \[Omega] - 2 \( R\_j\) cos  \[Alpha]\_j\))\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.16) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.4", "4.9"}],

Cell[TextData[{
  "Similarly, for a factor of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\((z - r\_j)\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`r\_j\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is real, we have "
}], "Text",
  CellTags->{"S1.4.4", "4.10"}],

Cell[BoxData[
    \(TraditionalForm
    \`\((z - r\_j)\) = e\^\(i  \[Omega]\) - r\_j = \(e\^\(i  \[Omega]/2\)\) 
      \((e\^\(i  \[Omega]/2\) - \(r\_j\) e\^\(-i  \[Omega]/2\))\), \)], 
  "DisplayFormula",
  CellTags->{"S1.4.4", "4.11"}],

Cell["\<\
and the corresponding phase is, again ignoring linear \
contributions, \
\>", "Text",
  CellTags->{"S1.4.4", "4.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\_j\) \((\[Omega])\) = arctan \((
      \(\(1 + r\_j\)\/\(1 - r\_j\)\) tan  \[Omega]\/2)\).\)], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.17) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.4", "4.13"}],

Cell[TextData[{
  "The phase is antisymmetric about ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Pi]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  "; as a consequence we only need to look at the phase in the range ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Omega] \[Element] \(\[InvisibleSpace]\([0, \[Pi]]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  ". Subtracting the linear components, we get the following phase deviations \
for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] z\_j \[VerticalSeparator]  < 1\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  ": "
}], "Text",
  CellTags->{"S1.4.4", "4.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalPhi]\_j\), \((\[Omega])\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox[\(\(\[Phi]\_j\) \((\[Omega])\) - \[Omega]\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" if " cos \[Omega] \[GreaterEqual] 
                    \(2 \(R\_j\) cos \[Alpha]\_j\)\/\(1 + R\_j\%2\)\),
                  "DisplayFormula"]},
              {
                StyleBox[\(\(\[Phi]\_j\) \((\[Omega])\) - \[Omega] + \[Pi]\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" if " cos \[Omega] < 
                    \(2 \(R\_j\) cos \[Alpha]\_j\)\/\(1 + R\_j\%2\)\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.18) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.4", "4.15"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " complex and "
}], "Text",
  CellTags->{"S1.4.4", "4.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[CapitalPhi]\_j\) \((\[Omega])\) = \(\[Phi]\_j\) \((\[Omega])\) - 
      \[Omega]/2\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.19) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.4", "4.17"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`z\_j\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " real. (A ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is added in the expression (",
  ButtonBox["4.18",
    ButtonData:>{"Wavelets 1.4.4", "4.15"},
    ButtonStyle->"AddOnsLink"],
  ") to take into account the discontinuity.) For ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] z\_j \[VerticalSeparator]  > 1\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  ", the sign of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_j\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  " is reversed. The deviation of the phase of ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " from linear phase is given by the sum of the individual phase \
derivations: "
}], "Text",
  CellTags->{"S1.4.4", "4.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CapitalPhi]", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "j",
          LimitsPositioning->True], \(\[CapitalPhi]\_j\), \((\[Omega])\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.4", "4.19"}],

Cell[TextData[{
  "Implementation with ",
  StyleBox["Mathematica", "SBO"]
}], "Subsubsection",
  CellTags->{"S1.4.4", "4.20"}],

Cell[TextData[{
  "In practice, we can proceed to determine the least asymmetric filter as \
follows. First, we find all the roots of the polynomial given by (",
  ButtonBox["4.12",
    ButtonData:>{"Wavelets 1.4.2", "2.7"},
    ButtonStyle->"AddOnsLink"],
  "). The calculation of phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi] \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is facilitated by observing that if the contribution to the phase from \
picking a root (or a pair of roots) inside the unit circle is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_j\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", then the phase contribution from the corresponding root (or roots) \
outside the unit circle is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[CapitalPhi]\_j\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". So we need only pick roots inside the unit circle to evaluate the phase \
contributions. In other words, "
}], "Text",
  CellTags->{"S1.4.4", "4.21"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[CapitalPhi]", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "j",
          LimitsPositioning->True], \(\[Delta]\_j\), \(\[CapitalPhi]\_j\), \((
        \[Omega])\)}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.20) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.4", "4.22"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPhi]\_j\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.4.4"],
  " is given by (",
  ButtonBox["4.18",
    ButtonData:>{"Wavelets 1.4.4", "4.15"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["4.19",
    ButtonData:>{"Wavelets 1.4.4", "4.17"},
    ButtonStyle->"AddOnsLink"],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_j = 1\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", corresponding to choosing a particular root inside or outside of the \
unit circle. Notice that the configurations of ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.4.4"],
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_j\)], "InlineFormula",
    CellTags->"S1.4.4"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(-\[Delta]\_j\)}\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " correspond to two complementary choices of picking the roots and they \
give rise to the same phase with opposite signs. So in selecting the minimum \
phase, we need only consider half of the different configurations of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". \nAgain, the ",
  StyleBox["Mathematica", "TI"],
  " implementation of the procedure outlined above is straightforward. We \
give a step\[Hyphen]by\[Hyphen]step illustration for the case ",
  Cell[BoxData[
      \(TraditionalForm\`N = 6\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". "
}], "Text",
  CellTags->{"S1.4.4", "4.23"}],

Cell[TextData[{
  "First we define the function that calculates the phase according to (",
  ButtonBox["4.19",
    ButtonData:>{"Wavelets 1.4.4", "4.17"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["4.18",
    ButtonData:>{"Wavelets 1.4.4", "4.15"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.24"}],

Cell["\<\
(phase[w_, z_Real]:=ArcTan[(1+z)/(1-z) Tan[w/2]]-w/2;
 phase[w_, z_Complex]:=(ArcTan[(1-#1^2)Sin[w]/
 ((1+#1^2)Cos[w]-2 #1 Cos[#2])]-w + If[Cos[w]<
 2 #1 Cos[#2]/(1+#1^2), Pi, 0])&[Abs[z],Arg[z]])\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S1.4.4"],

Cell["\<\
Again, we need to find the roots of the corresponding polynomial.\
\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.25"}],

Cell["\<\
(n = 6;
 roots = #[[2]]& /@ List @@
 NRoots[z^(n-1) Together[p[n, z]]==0, z]);\
\>", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S1.4.4"],

Cell["\<\
We see that the roots fall into three groups, two quadruplets of \
complex roots and one pair of real roots.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.26"}],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics[Circle[{0, 0}, 1]],
Graphics[{PointSize[0.015],
Point[{Re[#], Im[#]}]& /@ roots}],
AspectRatio -> Automatic, Axes -> True,
PlotLabel -> \"z-plane\"]\
\>", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9321 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.272049 0.24824 0.466049 0.24824 [
[.02381 .45355 -6 -9 ]
[.02381 .45355 6 0 ]
[.52029 .45355 -3 -9 ]
[.52029 .45355 3 0 ]
[.76853 .45355 -3 -9 ]
[.76853 .45355 3 0 ]
[.25955 .09369 -24 -4.5 ]
[.25955 .09369 0 4.5 ]
[.25955 .21781 -12 -4.5 ]
[.25955 .21781 0 4.5 ]
[.25955 .34193 -24 -4.5 ]
[.25955 .34193 0 4.5 ]
[.25955 .59017 -18 -4.5 ]
[.25955 .59017 0 4.5 ]
[.25955 .71429 -6 -4.5 ]
[.25955 .71429 0 4.5 ]
[.25955 .83841 -18 -4.5 ]
[.25955 .83841 0 4.5 ]
[.5 .9446 -21 0 ]
[.5 .9446 21 9 ]
[ 0 0 0 0 ]
[ 1 .9321 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .46605 m
.02381 .4723 L
s
[(-1)] .02381 .45355 0 1 Mshowa
.52029 .46605 m
.52029 .4723 L
s
[(1)] .52029 .45355 0 1 Mshowa
.76853 .46605 m
.76853 .4723 L
s
[(2)] .76853 .45355 0 1 Mshowa
.125 Mabswid
.07346 .46605 m
.07346 .4698 L
s
.12311 .46605 m
.12311 .4698 L
s
.17275 .46605 m
.17275 .4698 L
s
.2224 .46605 m
.2224 .4698 L
s
.3217 .46605 m
.3217 .4698 L
s
.37135 .46605 m
.37135 .4698 L
s
.42099 .46605 m
.42099 .4698 L
s
.47064 .46605 m
.47064 .4698 L
s
.56994 .46605 m
.56994 .4698 L
s
.61959 .46605 m
.61959 .4698 L
s
.66923 .46605 m
.66923 .4698 L
s
.71888 .46605 m
.71888 .4698 L
s
.81818 .46605 m
.81818 .4698 L
s
.86783 .46605 m
.86783 .4698 L
s
.91747 .46605 m
.91747 .4698 L
s
.96712 .46605 m
.96712 .4698 L
s
.25 Mabswid
0 .46605 m
1 .46605 L
s
.27205 .09369 m
.2783 .09369 L
s
[(-1.5)] .25955 .09369 1 0 Mshowa
.27205 .21781 m
.2783 .21781 L
s
[(-1)] .25955 .21781 1 0 Mshowa
.27205 .34193 m
.2783 .34193 L
s
[(-0.5)] .25955 .34193 1 0 Mshowa
.27205 .59017 m
.2783 .59017 L
s
[(0.5)] .25955 .59017 1 0 Mshowa
.27205 .71429 m
.2783 .71429 L
s
[(1)] .25955 .71429 1 0 Mshowa
.27205 .83841 m
.2783 .83841 L
s
[(1.5)] .25955 .83841 1 0 Mshowa
.125 Mabswid
.27205 .11851 m
.2758 .11851 L
s
.27205 .14334 m
.2758 .14334 L
s
.27205 .16816 m
.2758 .16816 L
s
.27205 .19298 m
.2758 .19298 L
s
.27205 .24263 m
.2758 .24263 L
s
.27205 .26746 m
.2758 .26746 L
s
.27205 .29228 m
.2758 .29228 L
s
.27205 .3171 m
.2758 .3171 L
s
.27205 .36675 m
.2758 .36675 L
s
.27205 .39158 m
.2758 .39158 L
s
.27205 .4164 m
.2758 .4164 L
s
.27205 .44122 m
.2758 .44122 L
s
.27205 .49087 m
.2758 .49087 L
s
.27205 .5157 m
.2758 .5157 L
s
.27205 .54052 m
.2758 .54052 L
s
.27205 .56534 m
.2758 .56534 L
s
.27205 .61499 m
.2758 .61499 L
s
.27205 .63982 m
.2758 .63982 L
s
.27205 .66464 m
.2758 .66464 L
s
.27205 .68946 m
.2758 .68946 L
s
.27205 .73911 m
.2758 .73911 L
s
.27205 .76394 m
.2758 .76394 L
s
.27205 .78876 m
.2758 .78876 L
s
.27205 .81358 m
.2758 .81358 L
s
.27205 .06886 m
.2758 .06886 L
s
.27205 .04404 m
.2758 .04404 L
s
.27205 .01922 m
.2758 .01922 L
s
.27205 .86323 m
.2758 .86323 L
s
.27205 .88806 m
.2758 .88806 L
s
.27205 .91288 m
.2758 .91288 L
s
.25 Mabswid
.27205 0 m
.27205 .9321 L
s
[(z-plane)] .5 .9446 0 -1 Mshowa
0 0 m
1 0 L
1 .9321 L
0 .9321 L
closepath
clip
newpath
.5 Mabswid
newpath
.27205 .46605 .24824 0 365.73 arc
s
.015 w
.33892 .378 Mdot
.33892 .5541 Mdot
.35574 .42723 Mdot
.35574 .50487 Mdot
.35956 .46605 Mdot
.60914 .02219 Mdot
.60914 .90991 Mdot
.87801 .18495 Mdot
.87801 .74715 Mdot
.97619 .46605 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["\<\
Only one root from each group is needed to calculate the phase \
contribution. We will select those roots inside the unit circle with the \
nonnegative imaginary part. \
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.27"}],

Cell[CellGroupData[{

Cell["roots = Select[roots, Abs[#]<1 && Im[#]>=0&]", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({\(0.269378736040226662`\[InvisibleSpace]\) + 0.354698148240959243`\ I, 
      \(0.337115622232895528`\[InvisibleSpace]\) + 0.156384269501991068`\ I, 
      0.352542984763080724`}\)], "Output",
  CellLabel->"Out[31]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "These roots are used to compute the phase contribution from each group. \
For example, we can look at the plots of the phase contributions calculated \
from these three roots using the function ",
  StyleBox["phase", "MR"],
  " we defined earlier. "
}], "Text",
  CellTags->{"S1.4.4", "4.28"}],

Cell["\<\
This is the phase deviation from linearity calculated from the \
first of the three roots.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.29"}],

Cell[CellGroupData[{

Cell["\<\
Plot[phase[w, roots[[1]]], {w, 0, Pi},
AxesLabel -> {\"w\", \"phase\"}]\
\>", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.0147151 0.993916 [
[.17539 .00222 -9 -9 ]
[.17539 .00222 9 0 ]
[.32696 .00222 -3 -9 ]
[.32696 .00222 3 0 ]
[.47854 .00222 -9 -9 ]
[.47854 .00222 9 0 ]
[.63011 .00222 -3 -9 ]
[.63011 .00222 3 0 ]
[.78169 .00222 -9 -9 ]
[.78169 .00222 9 0 ]
[.93327 .00222 -3 -9 ]
[.93327 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.01131 .11411 -18 -4.5 ]
[.01131 .11411 0 4.5 ]
[.01131 .2135 -18 -4.5 ]
[.01131 .2135 0 4.5 ]
[.01131 .31289 -18 -4.5 ]
[.01131 .31289 0 4.5 ]
[.01131 .41228 -18 -4.5 ]
[.01131 .41228 0 4.5 ]
[.01131 .51167 -18 -4.5 ]
[.01131 .51167 0 4.5 ]
[.01131 .61106 -18 -4.5 ]
[.01131 .61106 0 4.5 ]
[.02381 .64303 -15 0 ]
[.02381 .64303 15 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .01472 m
.17539 .02097 L
s
[(0.5)] .17539 .00222 0 1 Mshowa
.32696 .01472 m
.32696 .02097 L
s
[(1)] .32696 .00222 0 1 Mshowa
.47854 .01472 m
.47854 .02097 L
s
[(1.5)] .47854 .00222 0 1 Mshowa
.63011 .01472 m
.63011 .02097 L
s
[(2)] .63011 .00222 0 1 Mshowa
.78169 .01472 m
.78169 .02097 L
s
[(2.5)] .78169 .00222 0 1 Mshowa
.93327 .01472 m
.93327 .02097 L
s
[(3)] .93327 .00222 0 1 Mshowa
.125 Mabswid
.05412 .01472 m
.05412 .01847 L
s
.08444 .01472 m
.08444 .01847 L
s
.11476 .01472 m
.11476 .01847 L
s
.14507 .01472 m
.14507 .01847 L
s
.2057 .01472 m
.2057 .01847 L
s
.23602 .01472 m
.23602 .01847 L
s
.26633 .01472 m
.26633 .01847 L
s
.29665 .01472 m
.29665 .01847 L
s
.35728 .01472 m
.35728 .01847 L
s
.38759 .01472 m
.38759 .01847 L
s
.41791 .01472 m
.41791 .01847 L
s
.44822 .01472 m
.44822 .01847 L
s
.50885 .01472 m
.50885 .01847 L
s
.53917 .01472 m
.53917 .01847 L
s
.56948 .01472 m
.56948 .01847 L
s
.5998 .01472 m
.5998 .01847 L
s
.66043 .01472 m
.66043 .01847 L
s
.69074 .01472 m
.69074 .01847 L
s
.72106 .01472 m
.72106 .01847 L
s
.75138 .01472 m
.75138 .01847 L
s
.81201 .01472 m
.81201 .01847 L
s
.84232 .01472 m
.84232 .01847 L
s
.87264 .01472 m
.87264 .01847 L
s
.90295 .01472 m
.90295 .01847 L
s
.96358 .01472 m
.96358 .01847 L
s
.9939 .01472 m
.9939 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.02381 .11411 m
.03006 .11411 L
s
[(0.1)] .01131 .11411 1 0 Mshowa
.02381 .2135 m
.03006 .2135 L
s
[(0.2)] .01131 .2135 1 0 Mshowa
.02381 .31289 m
.03006 .31289 L
s
[(0.3)] .01131 .31289 1 0 Mshowa
.02381 .41228 m
.03006 .41228 L
s
[(0.4)] .01131 .41228 1 0 Mshowa
.02381 .51167 m
.03006 .51167 L
s
[(0.5)] .01131 .51167 1 0 Mshowa
.02381 .61106 m
.03006 .61106 L
s
[(0.6)] .01131 .61106 1 0 Mshowa
.125 Mabswid
.02381 .03459 m
.02756 .03459 L
s
.02381 .05447 m
.02756 .05447 L
s
.02381 .07435 m
.02756 .07435 L
s
.02381 .09423 m
.02756 .09423 L
s
.02381 .13399 m
.02756 .13399 L
s
.02381 .15386 m
.02756 .15386 L
s
.02381 .17374 m
.02756 .17374 L
s
.02381 .19362 m
.02756 .19362 L
s
.02381 .23338 m
.02756 .23338 L
s
.02381 .25325 m
.02756 .25325 L
s
.02381 .27313 m
.02756 .27313 L
s
.02381 .29301 m
.02756 .29301 L
s
.02381 .33277 m
.02756 .33277 L
s
.02381 .35265 m
.02756 .35265 L
s
.02381 .37252 m
.02756 .37252 L
s
.02381 .3924 m
.02756 .3924 L
s
.02381 .43216 m
.02756 .43216 L
s
.02381 .45204 m
.02756 .45204 L
s
.02381 .47192 m
.02756 .47192 L
s
.02381 .49179 m
.02756 .49179 L
s
.02381 .53155 m
.02756 .53155 L
s
.02381 .55143 m
.02756 .55143 L
s
.02381 .57131 m
.02756 .57131 L
s
.02381 .59119 m
.02756 .59119 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phase)] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .04261 L
.10458 .07733 L
.14415 .11778 L
.18221 .16636 L
.22272 .22941 L
.26171 .29942 L
.30316 .37858 L
.34309 .45199 L
.3815 .51296 L
.40095 .53854 L
.42237 .56194 L
.44268 .57929 L
.46172 .59121 L
.4721 .59597 L
.47721 .59787 L
.48196 .59937 L
.48661 .6006 L
.49082 .60152 L
.4955 .60231 L
.49807 .60265 L
.50049 .6029 L
.50165 .603 L
.5029 .6031 L
.50397 .60316 L
.50514 .60322 L
.50586 .60325 L
.50652 .60327 L
.50782 .60331 L
.509 .60332 L
.51025 .60332 L
.51147 .6033 L
.51278 .60327 L
.51402 .60322 L
.51515 .60316 L
.51779 .60298 L
.52057 .60271 L
.52514 .60211 L
.52939 .60138 L
.53904 .59908 L
.54956 .59562 L
.5595 .59148 L
.57808 .58156 L
.61655 .553 L
.65747 .51248 L
.69687 .46544 L
.73476 .41426 L
.7751 .35467 L
.81392 .29342 L
.8552 .22516 L
Mistroke
.89496 .15718 L
.93321 .09047 L
.9739 .01875 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["\<\
We can look at all three phase contributions together by plotting \
them on the same graph.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.30"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[phase[w, #]& /@ roots], {w, 0, Pi},
PlotRange -> {0, 1}, AxesLabel -> {\"w\", \"phase\"}]\
\>", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0 0.618034 [
[.17539 -0.0125 -9 -9 ]
[.17539 -0.0125 9 0 ]
[.32696 -0.0125 -3 -9 ]
[.32696 -0.0125 3 0 ]
[.47854 -0.0125 -9 -9 ]
[.47854 -0.0125 9 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -9 -9 ]
[.78169 -0.0125 9 0 ]
[.93327 -0.0125 -3 -9 ]
[.93327 -0.0125 3 0 ]
[1.025 0 0 -4.5 ]
[1.025 0 6 4.5 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -15 0 ]
[.02381 .64303 15 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .00625 L
s
[(0.5)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(1)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(1.5)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(2)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(2.5)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(3)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75138 0 m
.75138 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(w)] 1.025 0 -1 0 Mshowa
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phase)] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.06244 .01734 L
.10458 .03894 L
.14415 .06409 L
.18221 .09429 L
.22272 .1335 L
.26171 .17703 L
.30316 .22625 L
.34309 .27191 L
.3815 .30982 L
.40095 .32572 L
.42237 .34028 L
.44268 .35106 L
.46172 .35848 L
.4721 .36143 L
.47721 .36261 L
.48196 .36355 L
.48661 .36432 L
.49082 .36488 L
.4955 .36538 L
.49807 .36559 L
.50049 .36575 L
.50165 .36581 L
.5029 .36587 L
.50397 .36591 L
.50514 .36594 L
.50586 .36596 L
.50652 .36598 L
.50782 .366 L
.509 .366 L
.51025 .366 L
.51147 .36599 L
.51278 .36597 L
.51402 .36594 L
.51515 .36591 L
.51779 .36579 L
.52057 .36563 L
.52514 .36525 L
.52939 .3648 L
.53904 .36337 L
.54956 .36122 L
.5595 .35864 L
.57808 .35248 L
.61655 .33471 L
.65747 .30952 L
.69687 .28027 L
.73476 .24844 L
.7751 .21139 L
.81392 .17331 L
.8552 .13086 L
Mistroke
.89496 .08859 L
.93321 .04711 L
.9739 .00251 L
.97619 0 L
Mfstroke
.02381 0 m
.06244 .06737 L
.10458 .13922 L
.14415 .20335 L
.18221 .26002 L
.22272 .31287 L
.26171 .35482 L
.28158 .3725 L
.30316 .38877 L
.32216 .40059 L
.34309 .41091 L
.36292 .41816 L
.37378 .42112 L
.38395 .42327 L
.38891 .4241 L
.39433 .42485 L
.39945 .42541 L
.40189 .42563 L
.4042 .42581 L
.40646 .42595 L
.4089 .42607 L
.41112 .42616 L
.41211 .42619 L
.41317 .42622 L
.41431 .42624 L
.41538 .42625 L
.41665 .42626 L
.41781 .42626 L
.41902 .42626 L
.42033 .42624 L
.42158 .42622 L
.42272 .42619 L
.42514 .42611 L
.42736 .42601 L
.43235 .4257 L
.43675 .42532 L
.44139 .42482 L
.45123 .42343 L
.46199 .4214 L
.4816 .4164 L
.50255 .40932 L
.54405 .39056 L
.58403 .36732 L
.6225 .34093 L
.66342 .30924 L
.70282 .27579 L
.74071 .2414 L
.78105 .20282 L
.81987 .16417 L
.86115 .12183 L
Mistroke
.90091 .08016 L
.93915 .03956 L
.97619 0 L
Mfstroke
.02381 0 m
.06244 .04252 L
.10458 .08637 L
.14415 .12317 L
.18221 .15334 L
.22272 .17924 L
.26171 .19807 L
.28302 .20592 L
.30316 .21185 L
.32313 .21637 L
.34157 .21941 L
.35124 .22059 L
.36029 .22145 L
.36539 .22183 L
.37023 .22212 L
.3729 .22226 L
.37581 .22238 L
.37847 .22247 L
.38092 .22255 L
.38347 .2226 L
.38481 .22262 L
.38623 .22264 L
.38747 .22266 L
.38862 .22266 L
.38988 .22267 L
.39059 .22267 L
.39124 .22267 L
.39243 .22267 L
.39354 .22266 L
.39475 .22265 L
.39604 .22263 L
.39821 .2226 L
.40059 .22255 L
.40331 .22247 L
.4058 .22239 L
.41141 .22214 L
.42157 .22151 L
.43137 .22069 L
.44049 .21973 L
.46119 .21692 L
.50023 .20942 L
.54173 .19872 L
.58171 .18615 L
.62018 .1723 L
.6611 .15597 L
.7005 .13895 L
.73839 .12159 L
.77873 .10223 L
.81755 .08291 L
.85883 .06181 L
Mistroke
.89859 .04108 L
.93684 .02089 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "The total phase is the superposition of the three curves with plus or \
minus one as coefficients. Out of the ",
  Cell[BoxData[
      \(TraditionalForm\`2\^3 = 8\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " combinations, half of them are simply the negative of the other half. So \
we really have four different combinations and, therefore, four different \
total phases. To get the different combinations of phases we can first \
generate the combinations of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  "s, then form the superposition of the phases. "
}], "Text",
  CellTags->{"S1.4.4", "4.31"}],

Cell[TextData[{
  "For example, we choose these four different configurations for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.32"}],

Cell[CellGroupData[{

Cell["\<\
deltas = Flatten[Drop[Outer[List,
{1, -1}, {1, -1}, {1, -1}], -1], 2]\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({{1, 1, 1}, {1, 1, \(-1\)}, {1, \(-1\), 1}, {1, \(-1\), \(-1\)}}\)], 
  "Output",
  CellLabel->"Out[34]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "This loads the package ",
  StyleBox["Graphics`Legend`", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.33"}],

Cell["Needs[\"Graphics`Legend`\"]", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"S1.4.4"],

Cell["This shows the four different total phase deviations.", "MathCaption",
  CellTags->{"S1.4.4", "4.34"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[(phase[w, #]& /@ roots).#& /@ deltas],
{w, 0, Pi}, PlotStyle -> {Dashing[{0.04}],
Dashing[{0.02}], {}, GrayLevel[0.5]},
AxesLabel -> {\"w\", \"phase\"}, PlotLegend -> {1, 2, 3, 4},
LegendPosition -> {1, 0}, LegendSize -> {0.5, 0.5}];\
\>", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48473 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.397292 0.373483 0.242366 0.373483 [
[ 0 0 0 0 ]
[ 1 .48473 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0115413 0.770775 0.473191 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.176378 0.264698 [
[.17539 .16388 -9 -9 ]
[.17539 .16388 9 0 ]
[.32696 .16388 -3 -9 ]
[.32696 .16388 3 0 ]
[.47854 .16388 -9 -9 ]
[.47854 .16388 9 0 ]
[.63011 .16388 -3 -9 ]
[.63011 .16388 3 0 ]
[.78169 .16388 -9 -9 ]
[.78169 .16388 9 0 ]
[.93327 .16388 -3 -9 ]
[.93327 .16388 3 0 ]
[1.025 .17638 0 -4.5 ]
[1.025 .17638 6 4.5 ]
[.01131 .04403 -24 -4.5 ]
[.01131 .04403 0 4.5 ]
[.01131 .30873 -18 -4.5 ]
[.01131 .30873 0 4.5 ]
[.01131 .44108 -6 -4.5 ]
[.01131 .44108 0 4.5 ]
[.01131 .57342 -18 -4.5 ]
[.01131 .57342 0 4.5 ]
[.02381 .64303 -15 0 ]
[.02381 .64303 15 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .17638 m
.17539 .18263 L
s
[(0.5)] .17539 .16388 0 1 Mshowa
.32696 .17638 m
.32696 .18263 L
s
[(1)] .32696 .16388 0 1 Mshowa
.47854 .17638 m
.47854 .18263 L
s
[(1.5)] .47854 .16388 0 1 Mshowa
.63011 .17638 m
.63011 .18263 L
s
[(2)] .63011 .16388 0 1 Mshowa
.78169 .17638 m
.78169 .18263 L
s
[(2.5)] .78169 .16388 0 1 Mshowa
.93327 .17638 m
.93327 .18263 L
s
[(3)] .93327 .16388 0 1 Mshowa
.125 Mabswid
.05412 .17638 m
.05412 .18013 L
s
.08444 .17638 m
.08444 .18013 L
s
.11476 .17638 m
.11476 .18013 L
s
.14507 .17638 m
.14507 .18013 L
s
.2057 .17638 m
.2057 .18013 L
s
.23602 .17638 m
.23602 .18013 L
s
.26633 .17638 m
.26633 .18013 L
s
.29665 .17638 m
.29665 .18013 L
s
.35728 .17638 m
.35728 .18013 L
s
.38759 .17638 m
.38759 .18013 L
s
.41791 .17638 m
.41791 .18013 L
s
.44822 .17638 m
.44822 .18013 L
s
.50885 .17638 m
.50885 .18013 L
s
.53917 .17638 m
.53917 .18013 L
s
.56948 .17638 m
.56948 .18013 L
s
.5998 .17638 m
.5998 .18013 L
s
.66043 .17638 m
.66043 .18013 L
s
.69074 .17638 m
.69074 .18013 L
s
.72106 .17638 m
.72106 .18013 L
s
.75138 .17638 m
.75138 .18013 L
s
.81201 .17638 m
.81201 .18013 L
s
.84232 .17638 m
.84232 .18013 L
s
.87264 .17638 m
.87264 .18013 L
s
.90295 .17638 m
.90295 .18013 L
s
.96358 .17638 m
.96358 .18013 L
s
.9939 .17638 m
.9939 .18013 L
s
.25 Mabswid
0 .17638 m
1 .17638 L
s
[(w)] 1.025 .17638 -1 0 Mshowa
.02381 .04403 m
.03006 .04403 L
s
[(-0.5)] .01131 .04403 1 0 Mshowa
.02381 .30873 m
.03006 .30873 L
s
[(0.5)] .01131 .30873 1 0 Mshowa
.02381 .44108 m
.03006 .44108 L
s
[(1)] .01131 .44108 1 0 Mshowa
.02381 .57342 m
.03006 .57342 L
s
[(1.5)] .01131 .57342 1 0 Mshowa
.125 Mabswid
.02381 .0705 m
.02756 .0705 L
s
.02381 .09697 m
.02756 .09697 L
s
.02381 .12344 m
.02756 .12344 L
s
.02381 .14991 m
.02756 .14991 L
s
.02381 .20285 m
.02756 .20285 L
s
.02381 .22932 m
.02756 .22932 L
s
.02381 .25579 m
.02756 .25579 L
s
.02381 .28226 m
.02756 .28226 L
s
.02381 .3352 m
.02756 .3352 L
s
.02381 .36167 m
.02756 .36167 L
s
.02381 .38814 m
.02756 .38814 L
s
.02381 .41461 m
.02756 .41461 L
s
.02381 .46755 m
.02756 .46755 L
s
.02381 .49402 m
.02756 .49402 L
s
.02381 .52049 m
.02756 .52049 L
s
.02381 .54696 m
.02756 .54696 L
s
.02381 .01756 m
.02756 .01756 L
s
.02381 .59989 m
.02756 .59989 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phase)] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .04 ] 0 setdash
.02381 .17638 m
.06244 .23087 L
.10458 .28967 L
.14415 .34367 L
.18221 .3938 L
.22272 .44432 L
.26171 .489 L
.30316 .53052 L
.34309 .56288 L
.36136 .57474 L
.3815 .58547 L
.40134 .59359 L
.41219 .59699 L
.42237 .5995 L
.42733 .60049 L
.43275 .60141 L
.43752 .60206 L
.44261 .60261 L
.44521 .60283 L
.44765 .60299 L
.44985 .60312 L
.45098 .60317 L
.45222 .60322 L
.45331 .60325 L
.45448 .60328 L
.45571 .6033 L
.45686 .60331 L
.45801 .60332 L
.4591 .60332 L
.46008 .60331 L
.46114 .60329 L
.46235 .60327 L
.46347 .60324 L
.46599 .60314 L
.4682 .60303 L
.47054 .60288 L
.47549 .60246 L
.48091 .60185 L
.49179 .60014 L
.50192 .59799 L
.52238 .59209 L
.54096 .58502 L
.58095 .56486 L
.61941 .53996 L
.66033 .50855 L
.69973 .47437 L
.73762 .43855 L
.77796 .39784 L
.81679 .35669 L
.85806 .31133 L
Mistroke
.89782 .26649 L
.93607 .22269 L
.97619 .17638 L
Mfstroke
[ .02 ] 0 setdash
.02381 .17638 m
.06244 .19445 L
.10458 .21569 L
.14415 .23817 L
.18221 .26245 L
.22272 .29079 L
.26171 .31934 L
.30316 .34906 L
.34309 .37476 L
.3815 .39483 L
.40134 .40297 L
.42237 .40981 L
.43178 .41225 L
.4419 .41447 L
.45139 .41615 L
.4602 .41737 L
.4655 .41795 L
.47031 .41838 L
.47564 .41875 L
.47857 .4189 L
.48134 .41901 L
.48378 .41909 L
.48501 .41912 L
.48636 .41914 L
.48752 .41916 L
.48875 .41917 L
.48992 .41918 L
.49099 .41918 L
.49163 .41918 L
.49232 .41917 L
.49355 .41916 L
.49424 .41915 L
.49488 .41914 L
.49635 .41911 L
.49879 .41905 L
.50143 .41896 L
.50638 .41871 L
.511 .4184 L
.52147 .41742 L
.53167 .41611 L
.54257 .41432 L
.56391 .40977 L
.58406 .40427 L
.62253 .39092 L
.66345 .37322 L
.70285 .35341 L
.74074 .33229 L
.78108 .30802 L
.8199 .28332 L
.86118 .25595 L
Mistroke
.90094 .22882 L
.93918 .20227 L
.97619 .17638 L
Mfstroke
[ ] 0 setdash
.02381 .17638 m
.06244 .17316 L
.08255 .1717 L
.0932 .17103 L
.10458 .17042 L
.11531 .16996 L
.12038 .16979 L
.12507 .16967 L
.12977 .16957 L
.13225 .16953 L
.13352 .16952 L
.13488 .1695 L
.13607 .16949 L
.13716 .16948 L
.13825 .16948 L
.13929 .16948 L
.1405 .16947 L
.14161 .16947 L
.14284 .16948 L
.14415 .16948 L
.14539 .16949 L
.14676 .1695 L
.14951 .16954 L
.15206 .16958 L
.15444 .16963 L
.15981 .16979 L
.16556 .17002 L
.17098 .1703 L
.17611 .17062 L
.18573 .17138 L
.19539 .17235 L
.20564 .17363 L
.22406 .17657 L
.26181 .18509 L
.30202 .19714 L
.3407 .2101 L
.38184 .22341 L
.42147 .23421 L
.45958 .24192 L
.47919 .24479 L
.50014 .24702 L
.51038 .24782 L
.51577 .24816 L
.52148 .24847 L
.52648 .24869 L
.53197 .24889 L
.53696 .24903 L
.53923 .24907 L
.54164 .24911 L
.54422 .24915 L
Mistroke
.54537 .24916 L
.54662 .24917 L
.54738 .24918 L
.54808 .24918 L
.54874 .24918 L
.54946 .24919 L
.55072 .24919 L
.5514 .24919 L
.55204 .24919 L
.55333 .24919 L
.55454 .24918 L
.55563 .24918 L
.55681 .24917 L
.55947 .24914 L
.56192 .24911 L
.5662 .24903 L
.57092 .24891 L
.58046 .24857 L
.59058 .24808 L
.59985 .24752 L
.62072 .24588 L
.66039 .24151 L
.69855 .236 L
.73917 .22903 L
.77826 .22147 L
.81981 .21274 L
.85985 .20382 L
.89837 .19491 L
.93934 .18521 L
.97619 .17638 L
Mfstroke
.5 g
.02381 .17638 m
.06244 .13674 L
.10458 .09644 L
.14415 .06398 L
.18221 .03973 L
.20178 .03035 L
.22272 .02279 L
.23293 .02003 L
.24402 .01771 L
.24911 .01687 L
.25449 .01614 L
.25954 .0156 L
.26416 .01522 L
.26647 .01507 L
.26899 .01493 L
.27137 .01484 L
.27357 .01477 L
.27421 .01476 L
.2749 .01475 L
.27614 .01473 L
.27736 .01472 L
.27847 .01472 L
.27968 .01472 L
.28037 .01472 L
.28101 .01473 L
.28231 .01475 L
.28303 .01476 L
.2837 .01478 L
.28604 .01484 L
.2882 .01493 L
.29309 .01519 L
.29741 .01551 L
.302 .01592 L
.31137 .01702 L
.32147 .01854 L
.33975 .02206 L
.38089 .03249 L
.42051 .04417 L
.45862 .05562 L
.49918 .06735 L
.53823 .07798 L
.57972 .08857 L
.61971 .09823 L
.65817 .10715 L
.69909 .11636 L
.73849 .12504 L
.77638 .1333 L
.81672 .14203 L
.85555 .1504 L
.89682 .15929 L
Mistroke
.93658 .16785 L
.97483 .17609 L
.97619 .17638 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.78945 .22369 m
.78945 .41043 L
.97619 .41043 L
.97619 .22369 L
F
1 g
.77077 .24237 m
.77077 .42911 L
.95752 .42911 L
.95752 .24237 L
F
0 g
.001 w
[ ] 0 setdash
.77077 .24237 m
.95752 .24237 L
.95752 .42911 L
.77077 .42911 L
.77077 .24237 L
s
% Start of sub-graphic
p
0.770775 0.242366 0.957516 0.429108 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0206612 0.206612 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0371901 0.35119 0.243802 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
[(4)] .38988 .1405 -1 0 Mshowa
% Start of sub-graphic
p
0.0535714 0.27686 0.35119 0.483471 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
[(3)] .38988 .38017 -1 0 Mshowa
% Start of sub-graphic
p
0.0535714 0.516529 0.35119 0.72314 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ .13333 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
[(2)] .38988 .61983 -1 0 Mshowa
% Start of sub-graphic
p
0.0535714 0.756198 0.35119 0.96281 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ .26667 ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
[(1)] .38988 .8595 -1 0 Mshowa
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .48473 L
0 .48473 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "We see that curve number 1 corresponds to the largest deviation from \
linear phase and curve number 3 to the smallest. Their ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " configurations can be obtained by extracting the corresponding elements \
from ",
  StyleBox["deltas", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.4.4", "4.35"}],

Cell[TextData[{
  "This is the configuration of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " that produces the maximum phase deviation."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.36"}],

Cell[CellGroupData[{

Cell["deltas[[1]]", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({1, 1, 1}\)], "Output",
  CellLabel->"Out[37]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "This is the configuration of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " that produces the minimum phase deviation."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.37"}],

Cell[CellGroupData[{

Cell["deltas[[3]]", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({1, \(-1\), 1}\)], "Output",
  CellLabel->"Out[38]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "That is, the largest deviation is obtained by adding all the deviations \
together. This corresponds precisely to picking all the roots inside the unit \
circle and it leads to the Daubechies filter we discussed in Section ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  ". For this reason, the filters are called \"extremal phase\" filters. \n\
Having identified the smallest phase configuration, we now proceed to find \
the filter coefficients, this should not pose any more difficulty once the \
roots are selected since we have demonstrated how to obtain the filter \
coefficients from selected roots in Section ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  ". To select appropriate roots, we first identify the positions of ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " where the corresponding roots should be inverted (",
  StyleBox["i.e.", "TI"],
  ", should be outside the unit circle). We also have to make sure that for \
each complex root its conjugate should be included when forming ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". "
}], "Text",
  CellTags->{"S1.4.4", "4.38"}],

Cell["\<\
We invert the second root and include the corresponding complex \
conjugate roots.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.39"}],

Cell[CellGroupData[{

Cell["Join[Conjugate[Cases[#, _Complex]], #]&[roots^%]", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({\(0.269378736040226662`\[InvisibleSpace]\) - 0.354698148240959243`\ I, 
      \(2.44104519777553452`\[InvisibleSpace]\) + 1.13237430987919451`\ I, 
      \(0.269378736040226662`\[InvisibleSpace]\) + 0.354698148240959243`\ I, 
      \(2.44104519777553452`\[InvisibleSpace]\) - 1.13237430987919451`\ I, 
      0.352542984763080724`}\)], "Output",
  CellLabel->"Out[39]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "Once the roots are selected, the filter coefficients are found exactly as \
described in Section ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.40"}],

Cell[CellGroupData[{

Cell["\<\
(coef = Re[CoefficientList[
(1+z)^n Apply[Times, z-%], z]];
Reverse[coef]/(Apply[Plus, coef]/N[Sqrt[2]]))\
\>", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({0.0154041093270447042`, 0.003490712084221947`, 
      \(-0.117990111148519227`\), \(-0.048311742585695363`\), 
      0.491055941927976213`, 0.787641141028649194`, 0.337929421728163248`, 
      \(-0.0726375227863778594`\), \(-0.0210602925123707063`\), 
      0.0447249017707814111`, 0.00176771186425387156`, 
      \(-0.00780070832503242339`\)}\)], "Output",
  CellLabel->"Out[40]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "The above procedure illustrates how we can get the least asymmetric filter \
for given ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". For small ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", it is usually clear by inspection what we mean by smallest phase, the \
curve closest to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " axis as in the above example. However, for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " there can be several curves close to the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " axis and these can cross one another, so it is not obvious which curve \
has the smallest deviation. We define the smallest phase deviation to be the \
one that gives the smallest area under the absolute value of the phase curve. \
"
}], "Text",
  CellTags->{"S1.4.4", "4.41"}],

Cell[TextData[{
  StyleBox["LeastAsymmetricFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.4", "4.42"}],

Cell[TextData[{
  "gives the least asymmetric Daubechies filter coefficients of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " (",
  StyleBox["i.e.", "TI"],
  ", the first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " moments of the corresponding wavelet vanish) by choosing those roots that \
produce the smallest area under the absolute phase curve. "
}], "Text",
  CellTags->{"S1.4.4", "4.43"}],

Cell["This gives the least asymmetric filter of order 7.", "MathCaption",
  CellTags->{"S1.4.4", "4.44"}],

Cell[CellGroupData[{

Cell["h7 = LeastAsymmetricFilter[7]", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({{0.010268176708465202`, 0.00401024487152337805`, 
        \(-0.107808237703292419`\), \(-0.140047240442947167`\), 
        0.288629631750629833`, 0.767764317004879881`, 0.536101917090584301`, 
        0.0174412550868493765`, \(-0.0495528349370386411`\), 
        0.0678926935012214727`, 0.0305155131658792155`, 
        \(-0.0126363034032399479`\), \(-0.0010473848886798267`\), 
        0.00268181456826007602`}, 0}\)], "Output",
  CellLabel->"Out[41]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "As usual, we use the normalization ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), "=", \(\@2\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.4"],
  ". The coefficients given in Daubechies (1992), p. 198 can be obtained by \
multiplying the above result by ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ". Note also that for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 5\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`8\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", the coefficients here are the reverse of those in Daubechies (1992). "
}], "Text",
  CellTags->{"S1.4.4", "4.45"}],

Cell["This gives the result in Daubechies (1992).", "MathCaption",
  CellTags->{"S1.4.4", "4.46"}],

Cell[CellGroupData[{

Cell["N[Sqrt[2] h7, 13]", "Input",
  CellLabel->"In[42]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            StyleBox["0.0145213947619550136`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            StyleBox["0.00567134268574551114`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            RowBox[{"-", 
              StyleBox["0.152463871895538556`",
                StyleBoxAutoDelete->True,
                PrintPrecision->13]}], ",", 
            RowBox[{"-", 
              StyleBox["0.198056706807341686`",
                StyleBoxAutoDelete->True,
                PrintPrecision->13]}], ",", 
            StyleBox["0.408183939724492717`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            StyleBox["1.08578270981441725`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            StyleBox["0.758162601963720739`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            StyleBox["0.024665659488631122`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            RowBox[{"-", 
              StyleBox["0.0700782912219953679`",
                StyleBoxAutoDelete->True,
                PrintPrecision->13]}], ",", 
            StyleBox["0.0960147679354670913`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            StyleBox["0.0431554525819611267`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13], ",", 
            RowBox[{"-", 
              StyleBox["0.0178704316511232308`",
                StyleBoxAutoDelete->True,
                PrintPrecision->13]}], ",", 
            RowBox[{"-", 
              StyleBox["0.00148122591459564523`",
                StyleBoxAutoDelete->True,
                PrintPrecision->13]}], ",", 
            StyleBox["0.00379265853420314558`",
              StyleBoxAutoDelete->True,
              PrintPrecision->13]}], "}"}], ",", "0"}], "}"}]], "Output",
  CellLabel->"Out[42]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "One should exercise caution when using large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " with regard to the precision of the calculation of the roots of a high\
\[Hyphen]degree polynomial. As ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " gets large, say 15 or so, the numerical routine that finds the roots of a \
polynomial quickly loses precision, and for even larger ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " the results can be unreliable. So, in the case of large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", we must make sure that the roots obtained from using ",
  StyleBox["NRoots", "MR"],
  " are indeed correct solutions by increasing the working precision \
appropriately. This, of course, will slow down the speed of finding the \
roots. "
}], "Text",
  CellTags->{"S1.4.4", "4.47"}],

Cell[TextData[{
  "For example, for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 12\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " we need to find the roots of a polynomial of degree ",
  Cell[BoxData[
      \(TraditionalForm\`2 \((N - 1)\) = 22\)], "InlineFormula",
    CellTags->"S1.4.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.4", "4.48"}],

Cell[CellGroupData[{

Cell["\<\
(n=12;
Timing[roots = {Rule @@ #}& /@
(List @@ NRoots[z^(n-1) Together[p[n, z]]==0, z]);])\
\>", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({0.140000000000000568`\ Second, Null}\)], "Output",
  CellLabel->"Out[43]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["\<\
Here we substitute the roots back into our original polynomial to \
check if they indeed produce zeros.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.49"}],

Cell[CellGroupData[{

Cell["Chop[z^(n-1) Together[p[n, z]]/. roots, 10^-8]", "Input",
  CellLabel->"In[44]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      8.6751242633908987`*^-8 - 3.09819370158948004`*^-8\ I, 
      8.6751242633908987`*^-8 + 3.09819370158948004`*^-8\ I, 
      \(-5.7043507695198059`*^-7\) - 8.65242327563464641`*^-7\ I, 
      \(-5.7043507695198059`*^-7\) + 8.65242327563464641`*^-7\ I, 
      1.18091702461242675`*^-6 + 8.38190317153930664`*^-7\ I, 
      1.18091702461242675`*^-6 - 8.38190317153930664`*^-7\ I, 
      \(-1.50501728057861328`*^-6\) - 6.48200511932373046`*^-7\ I, 
      \(-1.50501728057861328`*^-6\) + 6.48200511932373046`*^-7\ I, 
      \(-0.0000151172280311584472`\) - 4.97698783874511718`*^-6\ I, 
      \(-0.0000151172280311584472`\) + 4.97698783874511718`*^-6\ I, 
      \(-3.814697265625`*^-6\)}\)], "Output",
  CellLabel->"Out[44]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell[TextData[{
  "We see that even if we set anything smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-8\)\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " to zero, there are many roots that fail to produce a zero. However, if we \
increase the precision carried out in finding the roots, we can get more \
accurate solutions. "
}], "Text",
  CellTags->{"S1.4.4", "4.50"}],

Cell["\<\
We see that this is much slower than simply using the machine \
precision.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.51"}],

Cell[CellGroupData[{

Cell["\<\
Timing[roots={Rule @@ #}& /@
(List @@ NRoots[z^(n-1) Together[p[n, z]]==0, z, 22]);]\
\>", "Input",
  CellLabel->"In[45]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({4.03000000000000113`\ Second, Null}\)], "Output",
  CellLabel->"Out[45]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["But we get reliable results.", "MathCaption",
  CellTags->{"S1.4.4", "4.52"}],

Cell[CellGroupData[{

Cell["Chop[z^(n-1) Together[p[n, z]] /. roots]", "Input",
  CellLabel->"In[46]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], 
  "Output",
  CellLabel->"Out[46]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["\<\
The actual precision is again less than the working precision of \
22.\
\>", "MathCaption",
  CellTags->{"S1.4.4", "4.53"}],

Cell[CellGroupData[{

Cell["Precision[roots]", "Input",
  CellLabel->"In[47]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \(15\)], "Output",
  CellLabel->"Out[47]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["We can use ", "Text",
  CellTags->{"S1.4.4", "4.54"}],

Cell[TextData[{
  StyleBox["LeastAsymmetricFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["prec", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.4", "4.55"}],

Cell[TextData[{
  "to increase the working precision to ",
  StyleBox["prec", "TI"],
  ". In order to get correct results, it is important to give a sufficiently \
high working precision when calculating filters of large order. When ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " is large, the above filter function can run into numerical difficulties. \
In addition, the number of different phases grows exponentially with ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  ", so calculating the least asymmetric filters with large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " can be very slow. Therefore, one should not attempt to use this function \
with large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.4"],
  " (say, ",
  Cell[BoxData[
      \(TraditionalForm\`N > 20\)], "InlineFormula",
    CellTags->"S1.4.4"],
  "). \nThe least asymmetric scaling function and mother wavelet can be \
obtained using the functions ",
  StyleBox["ScalingFunction", "MR"],
  " and ",
  StyleBox["Wavelet", "MR"],
  ", respectively. "
}], "Text",
  CellTags->{"S1.4.4", "4.56"}],

Cell["This is the least asymmetric scaling function of order 7.", 
  "MathCaption",
  CellTags->{"S1.4.4", "4.57"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[h7, 6], PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"Least Asymmetric phi_7(t)\"]\
\>", "Input",
  CellLabel->"In[48]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0732601 0.144896 0.418933 [
[.17033 .1324 -3 -9 ]
[.17033 .1324 3 0 ]
[.31685 .1324 -3 -9 ]
[.31685 .1324 3 0 ]
[.46337 .1324 -3 -9 ]
[.46337 .1324 3 0 ]
[.60989 .1324 -3 -9 ]
[.60989 .1324 3 0 ]
[.75641 .1324 -6 -9 ]
[.75641 .1324 6 0 ]
[.90293 .1324 -6 -9 ]
[.90293 .1324 6 0 ]
[1.025 .1449 0 -4.5 ]
[1.025 .1449 6 4.5 ]
[.01131 .06111 -24 -4.5 ]
[.01131 .06111 0 4.5 ]
[.01131 .22868 -18 -4.5 ]
[.01131 .22868 0 4.5 ]
[.01131 .31247 -18 -4.5 ]
[.01131 .31247 0 4.5 ]
[.01131 .39626 -18 -4.5 ]
[.01131 .39626 0 4.5 ]
[.01131 .48004 -18 -4.5 ]
[.01131 .48004 0 4.5 ]
[.01131 .56383 -6 -4.5 ]
[.01131 .56383 0 4.5 ]
[.5 .63053 -75 0 ]
[.5 .63053 75 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17033 .1449 m
.17033 .15115 L
s
[(2)] .17033 .1324 0 1 Mshowa
.31685 .1449 m
.31685 .15115 L
s
[(4)] .31685 .1324 0 1 Mshowa
.46337 .1449 m
.46337 .15115 L
s
[(6)] .46337 .1324 0 1 Mshowa
.60989 .1449 m
.60989 .15115 L
s
[(8)] .60989 .1324 0 1 Mshowa
.75641 .1449 m
.75641 .15115 L
s
[(10)] .75641 .1324 0 1 Mshowa
.90293 .1449 m
.90293 .15115 L
s
[(12)] .90293 .1324 0 1 Mshowa
.125 Mabswid
.06044 .1449 m
.06044 .14865 L
s
.09707 .1449 m
.09707 .14865 L
s
.1337 .1449 m
.1337 .14865 L
s
.20696 .1449 m
.20696 .14865 L
s
.24359 .1449 m
.24359 .14865 L
s
.28022 .1449 m
.28022 .14865 L
s
.35348 .1449 m
.35348 .14865 L
s
.39011 .1449 m
.39011 .14865 L
s
.42674 .1449 m
.42674 .14865 L
s
.5 .1449 m
.5 .14865 L
s
.53663 .1449 m
.53663 .14865 L
s
.57326 .1449 m
.57326 .14865 L
s
.64652 .1449 m
.64652 .14865 L
s
.68315 .1449 m
.68315 .14865 L
s
.71978 .1449 m
.71978 .14865 L
s
.79304 .1449 m
.79304 .14865 L
s
.82967 .1449 m
.82967 .14865 L
s
.8663 .1449 m
.8663 .14865 L
s
.93956 .1449 m
.93956 .14865 L
s
.97619 .1449 m
.97619 .14865 L
s
.25 Mabswid
0 .1449 m
1 .1449 L
s
[(t)] 1.025 .1449 -1 0 Mshowa
.02381 .06111 m
.03006 .06111 L
s
[(-0.2)] .01131 .06111 1 0 Mshowa
.02381 .22868 m
.03006 .22868 L
s
[(0.2)] .01131 .22868 1 0 Mshowa
.02381 .31247 m
.03006 .31247 L
s
[(0.4)] .01131 .31247 1 0 Mshowa
.02381 .39626 m
.03006 .39626 L
s
[(0.6)] .01131 .39626 1 0 Mshowa
.02381 .48004 m
.03006 .48004 L
s
[(0.8)] .01131 .48004 1 0 Mshowa
.02381 .56383 m
.03006 .56383 L
s
[(1)] .01131 .56383 1 0 Mshowa
.125 Mabswid
.02381 .08206 m
.02756 .08206 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .12395 m
.02756 .12395 L
s
.02381 .16584 m
.02756 .16584 L
s
.02381 .18679 m
.02756 .18679 L
s
.02381 .20774 m
.02756 .20774 L
s
.02381 .24963 m
.02756 .24963 L
s
.02381 .27058 m
.02756 .27058 L
s
.02381 .29152 m
.02756 .29152 L
s
.02381 .33342 m
.02756 .33342 L
s
.02381 .35436 m
.02756 .35436 L
s
.02381 .37531 m
.02756 .37531 L
s
.02381 .4172 m
.02756 .4172 L
s
.02381 .43815 m
.02756 .43815 L
s
.02381 .4591 m
.02756 .4591 L
s
.02381 .50099 m
.02756 .50099 L
s
.02381 .52194 m
.02756 .52194 L
s
.02381 .54288 m
.02756 .54288 L
s
.02381 .04016 m
.02756 .04016 L
s
.02381 .01922 m
.02756 .01922 L
s
.02381 .58478 m
.02756 .58478 L
s
.02381 .60572 m
.02756 .60572 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Least Asymmetric phi_7\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .1449 m
.02495 .1449 L
.0261 .1449 L
.02724 .1449 L
.02839 .1449 L
.02953 .1449 L
.03068 .1449 L
.03182 .1449 L
.03297 .1449 L
.03411 .1449 L
.03526 .1449 L
.0364 .1449 L
.03755 .1449 L
.03869 .1449 L
.03984 .1449 L
.04098 .1449 L
.04212 .1449 L
.04327 .1449 L
.04441 .1449 L
.04556 .1449 L
.0467 .1449 L
.04785 .1449 L
.04899 .1449 L
.05014 .1449 L
.05128 .1449 L
.05243 .1449 L
.05357 .1449 L
.05472 .1449 L
.05586 .1449 L
.05701 .1449 L
.05815 .1449 L
.05929 .1449 L
.06044 .1449 L
.06158 .1449 L
.06273 .1449 L
.06387 .1449 L
.06502 .1449 L
.06616 .1449 L
.06731 .1449 L
.06845 .1449 L
.0696 .1449 L
.07074 .1449 L
.07189 .1449 L
.07303 .1449 L
.07418 .1449 L
.07532 .1449 L
.07647 .1449 L
.07761 .1449 L
.07875 .1449 L
.0799 .1449 L
Mistroke
.08104 .1449 L
.08219 .1449 L
.08333 .1449 L
.08448 .1449 L
.08562 .1449 L
.08677 .14489 L
.08791 .14489 L
.08906 .14489 L
.0902 .14489 L
.09135 .14489 L
.09249 .14488 L
.09364 .14488 L
.09478 .14488 L
.09592 .14488 L
.09707 .14487 L
.09821 .14487 L
.09936 .14487 L
.1005 .14487 L
.10165 .14487 L
.10279 .14488 L
.10394 .14488 L
.10508 .14488 L
.10623 .14489 L
.10737 .14489 L
.10852 .14489 L
.10966 .1449 L
.11081 .1449 L
.11195 .14491 L
.1131 .14491 L
.11424 .14492 L
.11538 .14492 L
.11653 .14493 L
.11767 .14494 L
.11882 .14495 L
.11996 .14496 L
.12111 .14498 L
.12225 .14499 L
.1234 .14501 L
.12454 .14502 L
.12569 .14504 L
.12683 .14506 L
.12798 .14508 L
.12912 .1451 L
.13027 .14512 L
.13141 .14513 L
.13255 .14515 L
.1337 .14516 L
.13484 .14517 L
.13599 .14517 L
.13713 .14516 L
Mistroke
.13828 .14515 L
.13942 .14513 L
.14057 .1451 L
.14171 .14507 L
.14286 .14503 L
.144 .14499 L
.14515 .14494 L
.14629 .14489 L
.14744 .14484 L
.14858 .14478 L
.14973 .14471 L
.15087 .14465 L
.15201 .14458 L
.15316 .14451 L
.1543 .14444 L
.15545 .14436 L
.15659 .14429 L
.15774 .14421 L
.15888 .14414 L
.16003 .14407 L
.16117 .144 L
.16232 .14392 L
.16346 .14385 L
.16461 .14378 L
.16575 .1437 L
.1669 .14363 L
.16804 .14357 L
.16918 .14351 L
.17033 .14345 L
.17147 .1434 L
.17262 .14337 L
.17376 .14335 L
.17491 .14334 L
.17605 .14335 L
.1772 .14336 L
.17834 .14339 L
.17949 .14343 L
.18063 .14348 L
.18178 .14355 L
.18292 .14363 L
.18407 .14373 L
.18521 .14384 L
.18636 .14396 L
.1875 .14409 L
.18864 .14423 L
.18979 .14437 L
.19093 .14451 L
.19208 .14463 L
.19322 .14476 L
.19437 .14488 L
Mistroke
.19551 .145 L
.19666 .14513 L
.1978 .14526 L
.19895 .14538 L
.20009 .14552 L
.20124 .14566 L
.20238 .14581 L
.20353 .14597 L
.20467 .14613 L
.20582 .14631 L
.20696 .14651 L
.2081 .14674 L
.20925 .14701 L
.21039 .14733 L
.21154 .14768 L
.21268 .14806 L
.21383 .14849 L
.21497 .14895 L
.21612 .14944 L
.21726 .14995 L
.21841 .15047 L
.21955 .15101 L
.2207 .15156 L
.22184 .15213 L
.22299 .15272 L
.22413 .15332 L
.22527 .15393 L
.22642 .15456 L
.22756 .1552 L
.22871 .15586 L
.22985 .15652 L
.231 .15718 L
.23214 .15783 L
.23329 .15848 L
.23443 .15911 L
.23558 .15974 L
.23672 .16037 L
.23787 .16098 L
.23901 .16157 L
.24016 .16213 L
.2413 .16266 L
.24245 .16314 L
.24359 .16355 L
.24473 .16387 L
.24588 .16407 L
.24702 .16415 L
.24817 .16411 L
.24931 .16395 L
.25046 .16369 L
.2516 .1633 L
Mistroke
.25275 .16279 L
.25389 .16217 L
.25504 .16143 L
.25618 .16058 L
.25733 .15963 L
.25847 .15856 L
.25962 .15737 L
.26076 .15608 L
.2619 .15469 L
.26305 .15325 L
.26419 .15177 L
.26534 .15025 L
.26648 .14869 L
.26763 .14707 L
.26877 .14541 L
.26992 .14369 L
.27106 .14193 L
.27221 .14009 L
.27335 .13818 L
.2745 .1362 L
.27564 .13413 L
.27679 .132 L
.27793 .12981 L
.27908 .12754 L
.28022 .1252 L
.28136 .12275 L
.28251 .12018 L
.28365 .1175 L
.2848 .11472 L
.28594 .11183 L
.28709 .10884 L
.28823 .10575 L
.28938 .10258 L
.29052 .09937 L
.29167 .09613 L
.29281 .09286 L
.29396 .08956 L
.2951 .08623 L
.29625 .08286 L
.29739 .07947 L
.29853 .07605 L
.29968 .07258 L
.30082 .06907 L
.30197 .0655 L
.30311 .06191 L
.30426 .05832 L
.3054 .05476 L
.30655 .05122 L
.30769 .04772 L
.30884 .04425 L
Mistroke
.30998 .04082 L
.31113 .03746 L
.31227 .03419 L
.31342 .03103 L
.31456 .02801 L
.31571 .02516 L
.31685 .02252 L
.31799 .02023 L
.31914 .01832 L
.32028 .01682 L
.32143 .01573 L
.32257 .01503 L
.32372 .01472 L
.32486 .01482 L
.32601 .01533 L
.32715 .01623 L
.3283 .01751 L
.32944 .01915 L
.33059 .02117 L
.33173 .02358 L
.33288 .0264 L
.33402 .02961 L
.33516 .03317 L
.33631 .03701 L
.33745 .0411 L
.3386 .04545 L
.33974 .05006 L
.34089 .05493 L
.34203 .06006 L
.34318 .06544 L
.34432 .07109 L
.34547 .07706 L
.34661 .08336 L
.34776 .08999 L
.3489 .09693 L
.35005 .10417 L
.35119 .11167 L
.35234 .11945 L
.35348 .12751 L
.35462 .13585 L
.35577 .14445 L
.35691 .15331 L
.35806 .16241 L
.3592 .17177 L
.36035 .1814 L
.36149 .19126 L
.36264 .20133 L
.36378 .21157 L
.36493 .22193 L
.36607 .23244 L
Mistroke
.36722 .24308 L
.36836 .25385 L
.36951 .26475 L
.37065 .27579 L
.37179 .28696 L
.37294 .29835 L
.37408 .30996 L
.37523 .32178 L
.37637 .33379 L
.37752 .34592 L
.37866 .35813 L
.37981 .37043 L
.38095 .38279 L
.3821 .39521 L
.38324 .40765 L
.38439 .42007 L
.38553 .43242 L
.38668 .4447 L
.38782 .45686 L
.38897 .46884 L
.39011 .48056 L
.39125 .49184 L
.3924 .50256 L
.39354 .51274 L
.39469 .52234 L
.39583 .53138 L
.39698 .53987 L
.39812 .54777 L
.39927 .55508 L
.40041 .56186 L
.40156 .56813 L
.4027 .57389 L
.40385 .57915 L
.40499 .58382 L
.40614 .5879 L
.40728 .59143 L
.40842 .59443 L
.40957 .59697 L
.41071 .59909 L
.41186 .60079 L
.413 .60204 L
.41415 .60289 L
.41529 .60331 L
.41644 .60332 L
.41758 .6029 L
.41873 .60197 L
.41987 .60049 L
.42102 .5985 L
.42216 .59601 L
.42331 .59306 L
Mistroke
.42445 .58969 L
.4256 .58589 L
.42674 .58169 L
.42788 .57715 L
.42903 .57232 L
.43017 .5672 L
.43132 .56181 L
.43246 .55611 L
.43361 .5501 L
.43475 .54381 L
.4359 .53725 L
.43704 .53048 L
.43819 .5235 L
.43933 .51631 L
.44048 .5089 L
.44162 .5013 L
.44277 .4935 L
.44391 .48549 L
.44505 .47724 L
.4462 .46866 L
.44734 .45969 L
.44849 .45036 L
.44963 .44069 L
.45078 .43074 L
.45192 .42054 L
.45307 .41011 L
.45421 .39945 L
.45536 .38861 L
.4565 .37762 L
.45765 .36654 L
.45879 .3554 L
.45994 .34418 L
.46108 .33291 L
.46223 .32167 L
.46337 .31053 L
.46451 .29964 L
.46566 .2891 L
.4668 .27892 L
.46795 .26911 L
.46909 .25967 L
.47024 .25059 L
.47138 .24191 L
.47253 .23363 L
.47367 .22567 L
.47482 .218 L
.47596 .21064 L
.47711 .20359 L
.47825 .19691 L
.4794 .19063 L
.48054 .18471 L
Mistroke
.48168 .17915 L
.48283 .1739 L
.48397 .16895 L
.48512 .16432 L
.48626 .16 L
.48741 .15597 L
.48855 .15221 L
.4897 .14873 L
.49084 .14555 L
.49199 .14274 L
.49313 .14032 L
.49428 .13826 L
.49542 .13653 L
.49657 .13512 L
.49771 .13399 L
.49886 .13312 L
.5 .13247 L
.50114 .13195 L
.50229 .13151 L
.50343 .13113 L
.50458 .1308 L
.50572 .13057 L
.50687 .13044 L
.50801 .13039 L
.50916 .13041 L
.5103 .13048 L
.51145 .13062 L
.51259 .13083 L
.51374 .13112 L
.51488 .13145 L
.51603 .13184 L
.51717 .13229 L
.51832 .13284 L
.51946 .1336 L
.5206 .13459 L
.52175 .1358 L
.52289 .13723 L
.52404 .13885 L
.52518 .14062 L
.52633 .14257 L
.52747 .14468 L
.52862 .14688 L
.52976 .14915 L
.53091 .15147 L
.53205 .15382 L
.5332 .15624 L
.53434 .15872 L
.53549 .16122 L
.53663 .16369 L
.53777 .16608 L
Mistroke
.53892 .16834 L
.54006 .17048 L
.54121 .17248 L
.54235 .17433 L
.5435 .17604 L
.54464 .1776 L
.54579 .179 L
.54693 .18031 L
.54808 .18153 L
.54922 .18267 L
.55037 .18371 L
.55151 .18463 L
.55266 .1854 L
.5538 .18604 L
.55495 .18656 L
.55609 .18694 L
.55723 .18717 L
.55838 .18726 L
.55952 .1872 L
.56067 .18702 L
.56181 .18674 L
.56296 .18633 L
.5641 .18581 L
.56525 .18514 L
.56639 .1843 L
.56754 .18334 L
.56868 .18225 L
.56983 .18105 L
.57097 .17975 L
.57212 .17837 L
.57326 .17694 L
.5744 .17554 L
.57555 .1742 L
.57669 .17293 L
.57784 .17172 L
.57898 .17057 L
.58013 .16946 L
.58127 .16841 L
.58242 .16743 L
.58356 .16649 L
.58471 .16559 L
.58585 .16472 L
.587 .16388 L
.58814 .1631 L
.58929 .16238 L
.59043 .1617 L
.59158 .16104 L
.59272 .16036 L
.59386 .15963 L
.59501 .15886 L
Mistroke
.59615 .15806 L
.5973 .15722 L
.59844 .15635 L
.59959 .15545 L
.60073 .15454 L
.60188 .15363 L
.60302 .15276 L
.60417 .15191 L
.60531 .1511 L
.60646 .15029 L
.6076 .14949 L
.60875 .14871 L
.60989 .14795 L
.61103 .14722 L
.61218 .14652 L
.61332 .14585 L
.61447 .1452 L
.61561 .14459 L
.61676 .14403 L
.6179 .14351 L
.61905 .14302 L
.62019 .14255 L
.62134 .14208 L
.62248 .14164 L
.62363 .14122 L
.62477 .14082 L
.62592 .14045 L
.62706 .14011 L
.62821 .13981 L
.62935 .13956 L
.63049 .13938 L
.63164 .13926 L
.63278 .1392 L
.63393 .13919 L
.63507 .13923 L
.63622 .13933 L
.63736 .13947 L
.63851 .13965 L
.63965 .13989 L
.6408 .14016 L
.64194 .14047 L
.64309 .14082 L
.64423 .1412 L
.64538 .1416 L
.64652 .14202 L
.64766 .14242 L
.64881 .1428 L
.64995 .14314 L
.6511 .14345 L
.65224 .14374 L
Mistroke
.65339 .144 L
.65453 .14423 L
.65568 .14444 L
.65682 .14462 L
.65797 .14479 L
.65911 .14495 L
.66026 .1451 L
.6614 .14523 L
.66255 .14533 L
.66369 .14541 L
.66484 .14547 L
.66598 .14553 L
.66712 .14559 L
.66827 .14565 L
.66941 .1457 L
.67056 .14575 L
.6717 .14581 L
.67285 .14586 L
.67399 .14591 L
.67514 .14595 L
.67628 .14596 L
.67743 .14596 L
.67857 .14594 L
.67972 .14592 L
.68086 .14589 L
.68201 .14585 L
.68315 .1458 L
.68429 .14576 L
.68544 .14573 L
.68658 .14571 L
.68773 .14569 L
.68887 .14568 L
.69002 .14568 L
.69116 .14567 L
.69231 .14568 L
.69345 .14569 L
.6946 .14571 L
.69574 .14573 L
.69689 .14576 L
.69803 .1458 L
.69918 .14584 L
.70032 .14588 L
.70147 .14593 L
.70261 .14597 L
.70375 .14599 L
.7049 .14601 L
.70604 .14601 L
.70719 .146 L
.70833 .14598 L
.70948 .14595 L
Mistroke
.71062 .14591 L
.71177 .14587 L
.71291 .14582 L
.71406 .14577 L
.7152 .14573 L
.71635 .14567 L
.71749 .14561 L
.71864 .14555 L
.71978 .14549 L
.72092 .14542 L
.72207 .14537 L
.72321 .14531 L
.72436 .14526 L
.7255 .14522 L
.72665 .14518 L
.72779 .14514 L
.72894 .14511 L
.73008 .14508 L
.73123 .14505 L
.73237 .14502 L
.73352 .14498 L
.73466 .14495 L
.73581 .14493 L
.73695 .1449 L
.7381 .14488 L
.73924 .14486 L
.74038 .14484 L
.74153 .14483 L
.74267 .14482 L
.74382 .14482 L
.74496 .14481 L
.74611 .14481 L
.74725 .14481 L
.7484 .14482 L
.74954 .14483 L
.75069 .14484 L
.75183 .14486 L
.75298 .14488 L
.75412 .1449 L
.75527 .14492 L
.75641 .14495 L
.75755 .14497 L
.7587 .14499 L
.75984 .14501 L
.76099 .14502 L
.76213 .14503 L
.76328 .14504 L
.76442 .14505 L
.76557 .14505 L
.76671 .14505 L
Mistroke
.76786 .14505 L
.769 .14505 L
.77015 .14504 L
.77129 .14504 L
.77244 .14503 L
.77358 .14502 L
.77473 .14501 L
.77587 .145 L
.77701 .14499 L
.77816 .14498 L
.7793 .14498 L
.78045 .14497 L
.78159 .14497 L
.78274 .14496 L
.78388 .14496 L
.78503 .14495 L
.78617 .14495 L
.78732 .14494 L
.78846 .14493 L
.78961 .14493 L
.79075 .14492 L
.7919 .14491 L
.79304 .14491 L
.79418 .1449 L
.79533 .14489 L
.79647 .14489 L
.79762 .14489 L
.79876 .14488 L
.79991 .14488 L
.80105 .14488 L
.8022 .14487 L
.80334 .14487 L
.80449 .14487 L
.80563 .14487 L
.80678 .14487 L
.80792 .14487 L
.80907 .14488 L
.81021 .14488 L
.81136 .14488 L
.8125 .14489 L
.81364 .14489 L
.81479 .14489 L
.81593 .14489 L
.81708 .1449 L
.81822 .1449 L
.81937 .1449 L
.82051 .1449 L
.82166 .1449 L
.8228 .1449 L
.82395 .1449 L
Mistroke
.82509 .1449 L
.82624 .1449 L
.82738 .1449 L
.82853 .1449 L
.82967 .1449 L
.83082 .1449 L
.83196 .1449 L
.8331 .1449 L
.83425 .1449 L
.83539 .1449 L
.83654 .1449 L
.83768 .1449 L
.83883 .1449 L
.83997 .1449 L
.84112 .1449 L
.84226 .1449 L
.84341 .1449 L
.84455 .1449 L
.8457 .1449 L
.84684 .1449 L
.84799 .1449 L
.84913 .1449 L
.85027 .1449 L
.85142 .1449 L
.85256 .1449 L
.85371 .1449 L
.85485 .1449 L
.856 .1449 L
.85714 .1449 L
.85829 .1449 L
.85943 .1449 L
.86058 .1449 L
.86172 .1449 L
.86287 .1449 L
.86401 .1449 L
.86516 .1449 L
.8663 .1449 L
.86745 .1449 L
.86859 .1449 L
.86973 .1449 L
.87088 .1449 L
.87202 .1449 L
.87317 .1449 L
.87431 .1449 L
.87546 .1449 L
.8766 .1449 L
.87775 .1449 L
.87889 .1449 L
.88004 .1449 L
.88118 .1449 L
Mistroke
.88233 .1449 L
.88347 .1449 L
.88462 .1449 L
.88576 .1449 L
.8869 .1449 L
.88805 .1449 L
.88919 .1449 L
.89034 .1449 L
.89148 .1449 L
.89263 .1449 L
.89377 .1449 L
.89492 .1449 L
.89606 .1449 L
.89721 .1449 L
.89835 .1449 L
.8995 .1449 L
.90064 .1449 L
.90179 .1449 L
.90293 .1449 L
.90408 .1449 L
.90522 .1449 L
.90636 .1449 L
.90751 .1449 L
.90865 .1449 L
.9098 .1449 L
.91094 .1449 L
.91209 .1449 L
.91323 .1449 L
.91438 .1449 L
.91552 .1449 L
.91667 .1449 L
.91781 .1449 L
.91896 .1449 L
.9201 .1449 L
.92125 .1449 L
.92239 .1449 L
.92353 .1449 L
.92468 .1449 L
.92582 .1449 L
.92697 .1449 L
.92811 .1449 L
.92926 .1449 L
.9304 .1449 L
.93155 .1449 L
.93269 .1449 L
.93384 .1449 L
.93498 .1449 L
.93613 .1449 L
.93727 .1449 L
.93842 .1449 L
Mistroke
.93956 .1449 L
.94071 .1449 L
.94185 .1449 L
.94299 .1449 L
.94414 .1449 L
.94528 .1449 L
.94643 .1449 L
.94757 .1449 L
.94872 .1449 L
.94986 .1449 L
.95101 .1449 L
.95215 .1449 L
.9533 .1449 L
.95444 .1449 L
.95559 .1449 L
.95673 .1449 L
.95788 .1449 L
.95902 .1449 L
.96016 .1449 L
.96131 .1449 L
.96245 .1449 L
.9636 .1449 L
.96474 .1449 L
.96589 .1449 L
.96703 .1449 L
.96818 .1449 L
.96932 .1449 L
.97047 .1449 L
.97161 .1449 L
.97276 .1449 L
.9739 .1449 L
.97505 .1449 L
.97619 .1449 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["This is the least asymmetric wavelet of order 7.", "MathCaption",
  CellTags->{"S1.4.4", "4.58"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[h7, 6], PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"Least Asymmetric psi_7(t)\"]\
\>", "Input",
  CellLabel->"In[49]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.46337 0.0732601 0.290561 0.24802 [
[.02381 .27806 -6 -9 ]
[.02381 .27806 6 0 ]
[.17033 .27806 -6 -9 ]
[.17033 .27806 6 0 ]
[.31685 .27806 -6 -9 ]
[.31685 .27806 6 0 ]
[.60989 .27806 -3 -9 ]
[.60989 .27806 3 0 ]
[.75641 .27806 -3 -9 ]
[.75641 .27806 3 0 ]
[.90293 .27806 -3 -9 ]
[.90293 .27806 3 0 ]
[1.025 .29056 0 -4.5 ]
[1.025 .29056 6 4.5 ]
[.45087 .04254 -12 -4.5 ]
[.45087 .04254 0 4.5 ]
[.45087 .16655 -24 -4.5 ]
[.45087 .16655 0 4.5 ]
[.45087 .41457 -18 -4.5 ]
[.45087 .41457 0 4.5 ]
[.45087 .53858 -6 -4.5 ]
[.45087 .53858 0 4.5 ]
[.5 .63053 -75 0 ]
[.5 .63053 75 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .29056 m
.02381 .29681 L
s
[(-6)] .02381 .27806 0 1 Mshowa
.17033 .29056 m
.17033 .29681 L
s
[(-4)] .17033 .27806 0 1 Mshowa
.31685 .29056 m
.31685 .29681 L
s
[(-2)] .31685 .27806 0 1 Mshowa
.60989 .29056 m
.60989 .29681 L
s
[(2)] .60989 .27806 0 1 Mshowa
.75641 .29056 m
.75641 .29681 L
s
[(4)] .75641 .27806 0 1 Mshowa
.90293 .29056 m
.90293 .29681 L
s
[(6)] .90293 .27806 0 1 Mshowa
.125 Mabswid
.06044 .29056 m
.06044 .29431 L
s
.09707 .29056 m
.09707 .29431 L
s
.1337 .29056 m
.1337 .29431 L
s
.20696 .29056 m
.20696 .29431 L
s
.24359 .29056 m
.24359 .29431 L
s
.28022 .29056 m
.28022 .29431 L
s
.35348 .29056 m
.35348 .29431 L
s
.39011 .29056 m
.39011 .29431 L
s
.42674 .29056 m
.42674 .29431 L
s
.5 .29056 m
.5 .29431 L
s
.53663 .29056 m
.53663 .29431 L
s
.57326 .29056 m
.57326 .29431 L
s
.64652 .29056 m
.64652 .29431 L
s
.68315 .29056 m
.68315 .29431 L
s
.71978 .29056 m
.71978 .29431 L
s
.79304 .29056 m
.79304 .29431 L
s
.82967 .29056 m
.82967 .29431 L
s
.8663 .29056 m
.8663 .29431 L
s
.93956 .29056 m
.93956 .29431 L
s
.97619 .29056 m
.97619 .29431 L
s
.25 Mabswid
0 .29056 m
1 .29056 L
s
[(t)] 1.025 .29056 -1 0 Mshowa
.46337 .04254 m
.46962 .04254 L
s
[(-1)] .45087 .04254 1 0 Mshowa
.46337 .16655 m
.46962 .16655 L
s
[(-0.5)] .45087 .16655 1 0 Mshowa
.46337 .41457 m
.46962 .41457 L
s
[(0.5)] .45087 .41457 1 0 Mshowa
.46337 .53858 m
.46962 .53858 L
s
[(1)] .45087 .53858 1 0 Mshowa
.125 Mabswid
.46337 .06734 m
.46712 .06734 L
s
.46337 .09214 m
.46712 .09214 L
s
.46337 .11695 m
.46712 .11695 L
s
.46337 .14175 m
.46712 .14175 L
s
.46337 .19135 m
.46712 .19135 L
s
.46337 .21615 m
.46712 .21615 L
s
.46337 .24096 m
.46712 .24096 L
s
.46337 .26576 m
.46712 .26576 L
s
.46337 .31536 m
.46712 .31536 L
s
.46337 .34016 m
.46712 .34016 L
s
.46337 .36497 m
.46712 .36497 L
s
.46337 .38977 m
.46712 .38977 L
s
.46337 .43937 m
.46712 .43937 L
s
.46337 .46417 m
.46712 .46417 L
s
.46337 .48898 m
.46712 .48898 L
s
.46337 .51378 m
.46712 .51378 L
s
.46337 .01774 m
.46712 .01774 L
s
.46337 .56338 m
.46712 .56338 L
s
.46337 .58818 m
.46712 .58818 L
s
.46337 .61299 m
.46712 .61299 L
s
.25 Mabswid
.46337 0 m
.46337 .61803 L
s
[(Least Asymmetric psi_7\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .29056 m
.02495 .29056 L
.0261 .29056 L
.02724 .29056 L
.02839 .29056 L
.02953 .29056 L
.03068 .29056 L
.03182 .29056 L
.03297 .29056 L
.03411 .29056 L
.03526 .29056 L
.0364 .29056 L
.03755 .29056 L
.03869 .29056 L
.03984 .29056 L
.04098 .29056 L
.04212 .29056 L
.04327 .29056 L
.04441 .29056 L
.04556 .29056 L
.0467 .29056 L
.04785 .29056 L
.04899 .29056 L
.05014 .29056 L
.05128 .29056 L
.05243 .29056 L
.05357 .29056 L
.05472 .29056 L
.05586 .29056 L
.05701 .29056 L
.05815 .29056 L
.05929 .29056 L
.06044 .29056 L
.06158 .29056 L
.06273 .29056 L
.06387 .29056 L
.06502 .29056 L
.06616 .29056 L
.06731 .29056 L
.06845 .29056 L
.0696 .29056 L
.07074 .29056 L
.07189 .29056 L
.07303 .29056 L
.07418 .29056 L
.07532 .29056 L
.07647 .29056 L
.07761 .29056 L
.07875 .29056 L
.0799 .29056 L
Mistroke
.08104 .29056 L
.08219 .29056 L
.08333 .29056 L
.08448 .29056 L
.08562 .29056 L
.08677 .29056 L
.08791 .29056 L
.08906 .29056 L
.0902 .29056 L
.09135 .29056 L
.09249 .29056 L
.09364 .29056 L
.09478 .29056 L
.09592 .29056 L
.09707 .29056 L
.09821 .29056 L
.09936 .29056 L
.1005 .29056 L
.10165 .29056 L
.10279 .29056 L
.10394 .29056 L
.10508 .29056 L
.10623 .29056 L
.10737 .29056 L
.10852 .29056 L
.10966 .29056 L
.11081 .29056 L
.11195 .29056 L
.1131 .29056 L
.11424 .29056 L
.11538 .29056 L
.11653 .29057 L
.11767 .29057 L
.11882 .29057 L
.11996 .29057 L
.12111 .29057 L
.12225 .29058 L
.1234 .29058 L
.12454 .29058 L
.12569 .29058 L
.12683 .29059 L
.12798 .29059 L
.12912 .29059 L
.13027 .29059 L
.13141 .2906 L
.13255 .2906 L
.1337 .2906 L
.13484 .2906 L
.13599 .2906 L
.13713 .2906 L
Mistroke
.13828 .2906 L
.13942 .2906 L
.14057 .29059 L
.14171 .29059 L
.14286 .29058 L
.144 .29058 L
.14515 .29057 L
.14629 .29056 L
.14744 .29055 L
.14858 .29054 L
.14973 .29054 L
.15087 .29053 L
.15201 .29052 L
.15316 .2905 L
.1543 .29049 L
.15545 .29048 L
.15659 .29047 L
.15774 .29046 L
.15888 .29044 L
.16003 .29043 L
.16117 .29042 L
.16232 .2904 L
.16346 .29039 L
.16461 .29038 L
.16575 .29036 L
.1669 .29035 L
.16804 .29034 L
.16918 .29033 L
.17033 .29032 L
.17147 .29031 L
.17262 .2903 L
.17376 .2903 L
.17491 .2903 L
.17605 .2903 L
.1772 .29031 L
.17834 .29032 L
.17949 .29032 L
.18063 .29034 L
.18178 .29035 L
.18292 .29037 L
.18407 .29039 L
.18521 .29041 L
.18636 .29043 L
.1875 .29045 L
.18864 .29048 L
.18979 .29051 L
.19093 .29054 L
.19208 .29057 L
.19322 .2906 L
.19437 .29063 L
Mistroke
.19551 .29066 L
.19666 .2907 L
.1978 .29073 L
.19895 .29077 L
.20009 .2908 L
.20124 .29084 L
.20238 .29088 L
.20353 .29092 L
.20467 .29096 L
.20582 .291 L
.20696 .29105 L
.2081 .29109 L
.20925 .29113 L
.21039 .29117 L
.21154 .29122 L
.21268 .29126 L
.21383 .2913 L
.21497 .29134 L
.21612 .29139 L
.21726 .29143 L
.21841 .29147 L
.21955 .29151 L
.2207 .29155 L
.22184 .29159 L
.22299 .29163 L
.22413 .29167 L
.22527 .29171 L
.22642 .29174 L
.22756 .29177 L
.22871 .2918 L
.22985 .29183 L
.231 .29185 L
.23214 .29188 L
.23329 .29189 L
.23443 .29191 L
.23558 .29193 L
.23672 .29194 L
.23787 .29195 L
.23901 .29195 L
.24016 .29196 L
.2413 .29196 L
.24245 .29196 L
.24359 .29196 L
.24473 .29196 L
.24588 .29196 L
.24702 .29195 L
.24817 .29195 L
.24931 .29194 L
.25046 .29194 L
.2516 .29193 L
Mistroke
.25275 .29193 L
.25389 .29191 L
.25504 .2919 L
.25618 .29187 L
.25733 .29185 L
.25847 .29181 L
.25962 .29178 L
.26076 .29174 L
.2619 .29171 L
.26305 .29167 L
.26419 .29165 L
.26534 .29163 L
.26648 .29162 L
.26763 .29161 L
.26877 .2916 L
.26992 .29159 L
.27106 .29158 L
.27221 .29157 L
.27335 .29156 L
.2745 .29154 L
.27564 .29152 L
.27679 .29149 L
.27793 .29145 L
.27908 .2914 L
.28022 .29132 L
.28136 .29122 L
.28251 .29107 L
.28365 .29087 L
.2848 .29064 L
.28594 .29037 L
.28709 .29006 L
.28823 .2897 L
.28938 .28931 L
.29052 .2889 L
.29167 .28847 L
.29281 .28801 L
.29396 .28754 L
.2951 .28704 L
.29625 .28652 L
.29739 .28597 L
.29853 .2854 L
.29968 .28479 L
.30082 .28415 L
.30197 .28349 L
.30311 .28279 L
.30426 .28208 L
.3054 .28136 L
.30655 .28063 L
.30769 .2799 L
.30884 .27915 L
Mistroke
.30998 .27838 L
.31113 .27762 L
.31227 .27687 L
.31342 .27612 L
.31456 .2754 L
.31571 .2747 L
.31685 .27406 L
.31799 .27351 L
.31914 .27307 L
.32028 .27274 L
.32143 .27253 L
.32257 .27243 L
.32372 .27243 L
.32486 .27255 L
.32601 .27277 L
.32715 .27309 L
.3283 .27348 L
.32944 .27395 L
.33059 .2745 L
.33173 .27515 L
.33288 .2759 L
.33402 .27673 L
.33516 .27765 L
.33631 .27866 L
.33745 .27975 L
.3386 .28092 L
.33974 .28217 L
.34089 .28347 L
.34203 .28483 L
.34318 .28625 L
.34432 .28771 L
.34547 .28924 L
.34661 .29084 L
.34776 .29248 L
.3489 .29417 L
.35005 .29589 L
.35119 .29762 L
.35234 .29935 L
.35348 .30105 L
.35462 .30266 L
.35577 .30416 L
.35691 .30554 L
.35806 .30679 L
.3592 .30792 L
.36035 .30894 L
.36149 .30984 L
.36264 .31062 L
.36378 .31131 L
.36493 .31194 L
.36607 .31249 L
Mistroke
.36722 .31296 L
.36836 .31333 L
.36951 .31359 L
.37065 .31375 L
.37179 .3138 L
.37294 .31373 L
.37408 .31354 L
.37523 .31321 L
.37637 .31277 L
.37752 .31224 L
.37866 .31164 L
.37981 .31096 L
.38095 .31022 L
.3821 .30938 L
.38324 .30845 L
.38439 .30746 L
.38553 .30643 L
.38668 .30537 L
.38782 .3043 L
.38897 .30326 L
.39011 .3023 L
.39125 .30155 L
.3924 .30107 L
.39354 .30085 L
.39469 .3009 L
.39583 .30122 L
.39698 .30179 L
.39812 .30262 L
.39927 .30369 L
.40041 .30489 L
.40156 .30617 L
.4027 .30756 L
.40385 .30907 L
.40499 .31072 L
.40614 .31256 L
.40728 .31457 L
.40842 .31675 L
.40957 .31919 L
.41071 .32191 L
.41186 .32491 L
.413 .32815 L
.41415 .33152 L
.41529 .33496 L
.41644 .3385 L
.41758 .34211 L
.41873 .34583 L
.41987 .34968 L
.42102 .35352 L
.42216 .3573 L
.42331 .361 L
Mistroke
.42445 .36453 L
.4256 .36778 L
.42674 .37059 L
.42788 .37256 L
.42903 .37348 L
.43017 .37338 L
.43132 .37223 L
.43246 .37005 L
.43361 .36692 L
.43475 .36276 L
.4359 .35764 L
.43704 .35182 L
.43819 .34543 L
.43933 .33844 L
.44048 .33085 L
.44162 .32252 L
.44277 .31339 L
.44391 .30356 L
.44505 .29303 L
.4462 .28173 L
.44734 .26966 L
.44849 .25684 L
.44963 .24334 L
.45078 .22939 L
.45192 .21513 L
.45307 .20055 L
.45421 .18565 L
.45536 .17028 L
.4565 .15442 L
.45765 .13835 L
.45879 .12222 L
.45994 .1061 L
.46108 .09022 L
.46223 .07482 L
.46337 .06024 L
.46451 .04735 L
.46566 .0366 L
.4668 .02799 L
.46795 .02159 L
.46909 .01727 L
.47024 .01492 L
.47138 .01472 L
.47253 .01659 L
.47367 .02012 L
.47482 .02514 L
.47596 .03163 L
.47711 .0396 L
.47825 .04933 L
.4794 .06091 L
.48054 .07414 L
Mistroke
.48168 .0889 L
.48283 .10506 L
.48397 .12249 L
.48512 .14121 L
.48626 .16112 L
.48741 .18192 L
.48855 .20347 L
.4897 .22575 L
.49084 .24878 L
.49199 .27295 L
.49313 .29833 L
.49428 .32457 L
.49542 .35142 L
.49657 .3787 L
.49771 .40604 L
.49886 .4332 L
.5 .45969 L
.50114 .4844 L
.50229 .50671 L
.50343 .52659 L
.50458 .54394 L
.50572 .55899 L
.50687 .57189 L
.50801 .58235 L
.50916 .5904 L
.5103 .59642 L
.51145 .60054 L
.51259 .60284 L
.51374 .60332 L
.51488 .60161 L
.51603 .59764 L
.51717 .59168 L
.51832 .58395 L
.51946 .57489 L
.5206 .5648 L
.52175 .55359 L
.52289 .54133 L
.52404 .52826 L
.52518 .51439 L
.52633 .4998 L
.52747 .48442 L
.52862 .46771 L
.52976 .44949 L
.53091 .43007 L
.53205 .40965 L
.5332 .3885 L
.53434 .367 L
.53549 .34524 L
.53663 .32359 L
.53777 .30293 L
Mistroke
.53892 .28373 L
.54006 .26606 L
.54121 .24998 L
.54235 .23526 L
.5435 .22175 L
.54464 .20972 L
.54579 .1992 L
.54693 .19005 L
.54808 .18224 L
.54922 .17566 L
.55037 .17029 L
.55151 .16641 L
.55266 .16403 L
.5538 .16293 L
.55495 .16288 L
.55609 .16332 L
.55723 .16393 L
.55838 .1648 L
.55952 .16589 L
.56067 .16719 L
.56181 .16874 L
.56296 .17046 L
.5641 .17242 L
.56525 .1751 L
.56639 .17866 L
.56754 .18298 L
.56868 .18798 L
.56983 .1934 L
.57097 .19902 L
.57212 .2049 L
.57326 .21093 L
.5744 .21679 L
.57555 .22232 L
.57669 .22746 L
.57784 .23218 L
.57898 .23667 L
.58013 .24097 L
.58127 .24497 L
.58242 .24861 L
.58356 .25182 L
.58471 .25453 L
.58585 .25684 L
.587 .25878 L
.58814 .26026 L
.58929 .26132 L
.59043 .26206 L
.59158 .2626 L
.59272 .26332 L
.59386 .26443 L
.59501 .26588 L
Mistroke
.59615 .26766 L
.5973 .26971 L
.59844 .27194 L
.59959 .27443 L
.60073 .27714 L
.60188 .27985 L
.60302 .2825 L
.60417 .28506 L
.60531 .28753 L
.60646 .29005 L
.6076 .29267 L
.60875 .2953 L
.60989 .29788 L
.61103 .30035 L
.61218 .30264 L
.61332 .30479 L
.61447 .30679 L
.61561 .3086 L
.61676 .3102 L
.6179 .31161 L
.61905 .31286 L
.62019 .31407 L
.62134 .31532 L
.62248 .31656 L
.62363 .31777 L
.62477 .31892 L
.62592 .31995 L
.62706 .32089 L
.62821 .3217 L
.62935 .32228 L
.63049 .32259 L
.63164 .32262 L
.63278 .32239 L
.63393 .32195 L
.63507 .32134 L
.63622 .32053 L
.63736 .31952 L
.63851 .3183 L
.63965 .31688 L
.6408 .31529 L
.64194 .31356 L
.64309 .31166 L
.64423 .30962 L
.64538 .30749 L
.64652 .30531 L
.64766 .30322 L
.64881 .3013 L
.64995 .29954 L
.6511 .29795 L
.65224 .29651 L
Mistroke
.65339 .29521 L
.65453 .29407 L
.65568 .29308 L
.65682 .29219 L
.65797 .29137 L
.65911 .29061 L
.66026 .28993 L
.6614 .28937 L
.66255 .28894 L
.66369 .28861 L
.66484 .28837 L
.66598 .28817 L
.66712 .28798 L
.66827 .28783 L
.66941 .2877 L
.67056 .28759 L
.6717 .28749 L
.67285 .2874 L
.67399 .28733 L
.67514 .28734 L
.67628 .28745 L
.67743 .28765 L
.67857 .28792 L
.67972 .28824 L
.68086 .2886 L
.68201 .28898 L
.68315 .28938 L
.68429 .28975 L
.68544 .29007 L
.68658 .29034 L
.68773 .29054 L
.68887 .2907 L
.69002 .29084 L
.69116 .29094 L
.69231 .29099 L
.69345 .291 L
.6946 .29095 L
.69574 .29087 L
.69689 .29075 L
.69803 .29058 L
.69918 .29037 L
.70032 .29012 L
.70147 .28986 L
.70261 .28962 L
.70375 .28942 L
.7049 .28927 L
.70604 .28916 L
.70719 .28908 L
.70833 .28904 L
.70948 .28903 L
Mistroke
.71062 .28905 L
.71177 .28908 L
.71291 .2891 L
.71406 .28912 L
.7152 .28914 L
.71635 .28918 L
.71749 .28923 L
.71864 .28929 L
.71978 .28936 L
.72092 .28943 L
.72207 .28949 L
.72321 .28955 L
.72436 .28962 L
.7255 .28967 L
.72665 .28972 L
.72779 .28976 L
.72894 .2898 L
.73008 .28985 L
.73123 .28991 L
.73237 .28998 L
.73352 .29007 L
.73466 .29016 L
.73581 .29025 L
.73695 .29035 L
.7381 .29044 L
.73924 .29053 L
.74038 .2906 L
.74153 .29066 L
.74267 .2907 L
.74382 .29073 L
.74496 .29076 L
.74611 .29077 L
.74725 .29078 L
.7484 .29077 L
.74954 .29075 L
.75069 .29073 L
.75183 .2907 L
.75298 .29065 L
.75412 .2906 L
.75527 .29055 L
.75641 .29048 L
.75755 .29043 L
.7587 .29038 L
.75984 .29034 L
.76099 .29031 L
.76213 .29029 L
.76328 .29027 L
.76442 .29027 L
.76557 .29026 L
.76671 .29027 L
Mistroke
.76786 .29027 L
.769 .29027 L
.77015 .29028 L
.77129 .29028 L
.77244 .2903 L
.77358 .29031 L
.77473 .29033 L
.77587 .29034 L
.77701 .29036 L
.77816 .29037 L
.7793 .29039 L
.78045 .2904 L
.78159 .29041 L
.78274 .29042 L
.78388 .29042 L
.78503 .29043 L
.78617 .29044 L
.78732 .29046 L
.78846 .29047 L
.78961 .29049 L
.79075 .29051 L
.7919 .29052 L
.79304 .29054 L
.79418 .29056 L
.79533 .29057 L
.79647 .29058 L
.79762 .29059 L
.79876 .2906 L
.79991 .29061 L
.80105 .29061 L
.8022 .29062 L
.80334 .29062 L
.80449 .29062 L
.80563 .29062 L
.80678 .29062 L
.80792 .29061 L
.80907 .2906 L
.81021 .2906 L
.81136 .29059 L
.8125 .29058 L
.81364 .29057 L
.81479 .29057 L
.81593 .29056 L
.81708 .29056 L
.81822 .29056 L
.81937 .29056 L
.82051 .29055 L
.82166 .29055 L
.8228 .29055 L
.82395 .29055 L
Mistroke
.82509 .29055 L
.82624 .29055 L
.82738 .29055 L
.82853 .29055 L
.82967 .29055 L
.83082 .29055 L
.83196 .29055 L
.8331 .29055 L
.83425 .29055 L
.83539 .29055 L
.83654 .29055 L
.83768 .29055 L
.83883 .29055 L
.83997 .29055 L
.84112 .29055 L
.84226 .29055 L
.84341 .29055 L
.84455 .29055 L
.8457 .29055 L
.84684 .29055 L
.84799 .29056 L
.84913 .29056 L
.85027 .29056 L
.85142 .29056 L
.85256 .29056 L
.85371 .29056 L
.85485 .29056 L
.856 .29056 L
.85714 .29056 L
.85829 .29056 L
.85943 .29056 L
.86058 .29056 L
.86172 .29056 L
.86287 .29056 L
.86401 .29056 L
.86516 .29056 L
.8663 .29056 L
.86745 .29056 L
.86859 .29056 L
.86973 .29056 L
.87088 .29056 L
.87202 .29056 L
.87317 .29056 L
.87431 .29056 L
.87546 .29056 L
.8766 .29056 L
.87775 .29056 L
.87889 .29056 L
.88004 .29056 L
.88118 .29056 L
Mistroke
.88233 .29056 L
.88347 .29056 L
.88462 .29056 L
.88576 .29056 L
.8869 .29056 L
.88805 .29056 L
.88919 .29056 L
.89034 .29056 L
.89148 .29056 L
.89263 .29056 L
.89377 .29056 L
.89492 .29056 L
.89606 .29056 L
.89721 .29056 L
.89835 .29056 L
.8995 .29056 L
.90064 .29056 L
.90179 .29056 L
.90293 .29056 L
.90408 .29056 L
.90522 .29056 L
.90636 .29056 L
.90751 .29056 L
.90865 .29056 L
.9098 .29056 L
.91094 .29056 L
.91209 .29056 L
.91323 .29056 L
.91438 .29056 L
.91552 .29056 L
.91667 .29056 L
.91781 .29056 L
.91896 .29056 L
.9201 .29056 L
.92125 .29056 L
.92239 .29056 L
.92353 .29056 L
.92468 .29056 L
.92582 .29056 L
.92697 .29056 L
.92811 .29056 L
.92926 .29056 L
.9304 .29056 L
.93155 .29056 L
.93269 .29056 L
.93384 .29056 L
.93498 .29056 L
.93613 .29056 L
.93727 .29056 L
.93842 .29056 L
Mistroke
.93956 .29056 L
.94071 .29056 L
.94185 .29056 L
.94299 .29056 L
.94414 .29056 L
.94528 .29056 L
.94643 .29056 L
.94757 .29056 L
.94872 .29056 L
.94986 .29056 L
.95101 .29056 L
.95215 .29056 L
.9533 .29056 L
.95444 .29056 L
.95559 .29056 L
.95673 .29056 L
.95788 .29056 L
.95902 .29056 L
.96016 .29056 L
.96131 .29056 L
.96245 .29056 L
.9636 .29056 L
.96474 .29056 L
.96589 .29056 L
.96703 .29056 L
.96818 .29056 L
.96932 .29056 L
.97047 .29056 L
.97161 .29056 L
.97276 .29056 L
.9739 .29056 L
.97505 .29056 L
.97619 .29056 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["This is the least asymmetric filter of order 11.", "MathCaption",
  CellTags->{"S1.4.4", "4.59"}],

Cell[CellGroupData[{

Cell["h11 = LeastAsymmetricFilter[11, 22]", "Input",
  CellLabel->"In[50]:= ",
  CellTags->"S1.4.4"],

Cell[BoxData[
    \({{0.0004892636102619029496788`11.678, 
        0.000110535097642690302162424`11.673, 
        \(-0.0063896036664546648218088`11.6761\), 
        \(-0.0020034719001089792166664`11.6202\), 
        0.043000190681551325563287`11.6608, 
        0.035266759564464618493865`11.5951, 
        \(-0.1446023437053118918239`11.6129\), 
        \(-0.20465479449578828596426`11.571\), 
        0.23768990904925750983556`11.5113, 0.73034354908838955339367`11.5844, 
        0.57202297801007577104903`11.5324, 0.09719839445890551875289`11.131, 
        \(-0.02283265102256226061637`10.6518\), 
        0.06997679961073292972167`11.1545, 
        0.037037415978858183948661`11.1075, 
        \(-0.02408084159586357833175`11.1857\), 
        \(-0.00985793482878921302394`11.1887\), 
        0.006512495674771519870281`11.3763, 
        0.0005883527353969824681472`11.1139, 
        \(-0.0017343662672978376911674`11.6158\), 
        \(-0.000038795655736148034970198`11.4371\), 
        0.00017172195069934809369115`11.6743}, 0}\)], "Output",
  CellLabel->"Out[50]= ",
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["This is the plot of the scaling function.", "MathCaption",
  CellTags->{"S1.4.4", "4.60"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[h11, 5], PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"Least Asymmetric phi_11(t)\"]\
\>", "Input",
  CellLabel->"In[51]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.169057 0.411367 [
[.25057 .15656 -3 -9 ]
[.25057 .15656 3 0 ]
[.47732 .15656 -6 -9 ]
[.47732 .15656 6 0 ]
[.70408 .15656 -6 -9 ]
[.70408 .15656 6 0 ]
[.93084 .15656 -6 -9 ]
[.93084 .15656 6 0 ]
[1.025 .16906 0 -4.5 ]
[1.025 .16906 6 4.5 ]
[.01131 .00451 -24 -4.5 ]
[.01131 .00451 0 4.5 ]
[.01131 .08678 -24 -4.5 ]
[.01131 .08678 0 4.5 ]
[.01131 .25133 -18 -4.5 ]
[.01131 .25133 0 4.5 ]
[.01131 .3336 -18 -4.5 ]
[.01131 .3336 0 4.5 ]
[.01131 .41588 -18 -4.5 ]
[.01131 .41588 0 4.5 ]
[.01131 .49815 -18 -4.5 ]
[.01131 .49815 0 4.5 ]
[.01131 .58042 -6 -4.5 ]
[.01131 .58042 0 4.5 ]
[.5 .63053 -78 0 ]
[.5 .63053 78 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25057 .16906 m
.25057 .17531 L
s
[(5)] .25057 .15656 0 1 Mshowa
.47732 .16906 m
.47732 .17531 L
s
[(10)] .47732 .15656 0 1 Mshowa
.70408 .16906 m
.70408 .17531 L
s
[(15)] .70408 .15656 0 1 Mshowa
.93084 .16906 m
.93084 .17531 L
s
[(20)] .93084 .15656 0 1 Mshowa
.125 Mabswid
.06916 .16906 m
.06916 .17281 L
s
.11451 .16906 m
.11451 .17281 L
s
.15986 .16906 m
.15986 .17281 L
s
.20522 .16906 m
.20522 .17281 L
s
.29592 .16906 m
.29592 .17281 L
s
.34127 .16906 m
.34127 .17281 L
s
.38662 .16906 m
.38662 .17281 L
s
.43197 .16906 m
.43197 .17281 L
s
.52268 .16906 m
.52268 .17281 L
s
.56803 .16906 m
.56803 .17281 L
s
.61338 .16906 m
.61338 .17281 L
s
.65873 .16906 m
.65873 .17281 L
s
.74943 .16906 m
.74943 .17281 L
s
.79478 .16906 m
.79478 .17281 L
s
.84014 .16906 m
.84014 .17281 L
s
.88549 .16906 m
.88549 .17281 L
s
.97619 .16906 m
.97619 .17281 L
s
.25 Mabswid
0 .16906 m
1 .16906 L
s
[(t)] 1.025 .16906 -1 0 Mshowa
.02381 .00451 m
.03006 .00451 L
s
[(-0.4)] .01131 .00451 1 0 Mshowa
.02381 .08678 m
.03006 .08678 L
s
[(-0.2)] .01131 .08678 1 0 Mshowa
.02381 .25133 m
.03006 .25133 L
s
[(0.2)] .01131 .25133 1 0 Mshowa
.02381 .3336 m
.03006 .3336 L
s
[(0.4)] .01131 .3336 1 0 Mshowa
.02381 .41588 m
.03006 .41588 L
s
[(0.6)] .01131 .41588 1 0 Mshowa
.02381 .49815 m
.03006 .49815 L
s
[(0.8)] .01131 .49815 1 0 Mshowa
.02381 .58042 m
.03006 .58042 L
s
[(1)] .01131 .58042 1 0 Mshowa
.125 Mabswid
.02381 .02508 m
.02756 .02508 L
s
.02381 .04565 m
.02756 .04565 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .10735 m
.02756 .10735 L
s
.02381 .12792 m
.02756 .12792 L
s
.02381 .14849 m
.02756 .14849 L
s
.02381 .18963 m
.02756 .18963 L
s
.02381 .21019 m
.02756 .21019 L
s
.02381 .23076 m
.02756 .23076 L
s
.02381 .2719 m
.02756 .2719 L
s
.02381 .29247 m
.02756 .29247 L
s
.02381 .31304 m
.02756 .31304 L
s
.02381 .35417 m
.02756 .35417 L
s
.02381 .37474 m
.02756 .37474 L
s
.02381 .39531 m
.02756 .39531 L
s
.02381 .43645 m
.02756 .43645 L
s
.02381 .45701 m
.02756 .45701 L
s
.02381 .47758 m
.02756 .47758 L
s
.02381 .51872 m
.02756 .51872 L
s
.02381 .53929 m
.02756 .53929 L
s
.02381 .55986 m
.02756 .55986 L
s
.02381 .60099 m
.02756 .60099 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(Least Asymmetric phi_11\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .16906 m
.02523 .16906 L
.02664 .16906 L
.02806 .16906 L
.02948 .16906 L
.0309 .16906 L
.03231 .16906 L
.03373 .16906 L
.03515 .16906 L
.03656 .16906 L
.03798 .16906 L
.0394 .16906 L
.04082 .16906 L
.04223 .16906 L
.04365 .16906 L
.04507 .16906 L
.04649 .16906 L
.0479 .16906 L
.04932 .16906 L
.05074 .16906 L
.05215 .16906 L
.05357 .16906 L
.05499 .16906 L
.05641 .16906 L
.05782 .16906 L
.05924 .16906 L
.06066 .16906 L
.06207 .16906 L
.06349 .16906 L
.06491 .16906 L
.06633 .16906 L
.06774 .16906 L
.06916 .16906 L
.07058 .16906 L
.072 .16906 L
.07341 .16906 L
.07483 .16906 L
.07625 .16906 L
.07766 .16906 L
.07908 .16906 L
.0805 .16906 L
.08192 .16906 L
.08333 .16906 L
.08475 .16906 L
.08617 .16906 L
.08759 .16906 L
.089 .16906 L
.09042 .16906 L
.09184 .16906 L
.09325 .16906 L
Mistroke
.09467 .16906 L
.09609 .16906 L
.09751 .16906 L
.09892 .16906 L
.10034 .16906 L
.10176 .16906 L
.10317 .16906 L
.10459 .16906 L
.10601 .16906 L
.10743 .16906 L
.10884 .16906 L
.11026 .16906 L
.11168 .16906 L
.1131 .16906 L
.11451 .16906 L
.11593 .16906 L
.11735 .16906 L
.11876 .16906 L
.12018 .16906 L
.1216 .16906 L
.12302 .16906 L
.12443 .16906 L
.12585 .16906 L
.12727 .16906 L
.12868 .16906 L
.1301 .16906 L
.13152 .16906 L
.13294 .16906 L
.13435 .16906 L
.13577 .16906 L
.13719 .16906 L
.13861 .16906 L
.14002 .16906 L
.14144 .16906 L
.14286 .16906 L
.14427 .16906 L
.14569 .16906 L
.14711 .16906 L
.14853 .16906 L
.14994 .16906 L
.15136 .16906 L
.15278 .16906 L
.1542 .16906 L
.15561 .16905 L
.15703 .16905 L
.15845 .16905 L
.15986 .16905 L
.16128 .16905 L
.1627 .16905 L
.16412 .16905 L
Mistroke
.16553 .16905 L
.16695 .16905 L
.16837 .16906 L
.16978 .16906 L
.1712 .16906 L
.17262 .16906 L
.17404 .16906 L
.17545 .16907 L
.17687 .16907 L
.17829 .16907 L
.17971 .16907 L
.18112 .16907 L
.18254 .16908 L
.18396 .16908 L
.18537 .16908 L
.18679 .16908 L
.18821 .16908 L
.18963 .16907 L
.19104 .16907 L
.19246 .16907 L
.19388 .16906 L
.19529 .16906 L
.19671 .16906 L
.19813 .16905 L
.19955 .16905 L
.20096 .16905 L
.20238 .16905 L
.2038 .16904 L
.20522 .16904 L
.20663 .16904 L
.20805 .16903 L
.20947 .16903 L
.21088 .16902 L
.2123 .16901 L
.21372 .169 L
.21514 .16899 L
.21655 .16897 L
.21797 .16896 L
.21939 .16895 L
.2208 .16894 L
.22222 .16893 L
.22364 .16891 L
.22506 .16891 L
.22647 .1689 L
.22789 .1689 L
.22931 .16891 L
.23073 .16893 L
.23214 .16895 L
.23356 .16899 L
.23498 .16904 L
Mistroke
.23639 .16909 L
.23781 .16916 L
.23923 .16923 L
.24065 .16931 L
.24206 .1694 L
.24348 .16948 L
.2449 .16956 L
.24632 .16964 L
.24773 .16972 L
.24915 .1698 L
.25057 .16987 L
.25198 .16994 L
.2534 .17 L
.25482 .17005 L
.25624 .17009 L
.25765 .17012 L
.25907 .17014 L
.26049 .17014 L
.2619 .17013 L
.26332 .1701 L
.26474 .17006 L
.26616 .17 L
.26757 .16993 L
.26899 .16983 L
.27041 .16972 L
.27183 .16957 L
.27324 .16939 L
.27466 .16917 L
.27608 .1689 L
.27749 .16858 L
.27891 .1682 L
.28033 .16777 L
.28175 .1673 L
.28316 .16679 L
.28458 .16624 L
.286 .16566 L
.28741 .16507 L
.28883 .16448 L
.29025 .16389 L
.29167 .16331 L
.29308 .16276 L
.2945 .16225 L
.29592 .16178 L
.29734 .16139 L
.29875 .16107 L
.30017 .16085 L
.30159 .16074 L
.303 .16074 L
.30442 .16087 L
.30584 .16113 L
Mistroke
.30726 .16152 L
.30867 .16204 L
.31009 .16269 L
.31151 .16345 L
.31293 .16434 L
.31434 .16537 L
.31576 .16653 L
.31718 .16784 L
.31859 .1693 L
.32001 .17094 L
.32143 .17275 L
.32285 .17475 L
.32426 .17693 L
.32568 .17926 L
.3271 .18173 L
.32851 .18432 L
.32993 .18701 L
.33135 .18977 L
.33277 .19257 L
.33418 .19537 L
.3356 .19813 L
.33702 .20082 L
.33844 .2034 L
.33985 .20581 L
.34127 .208 L
.34269 .20991 L
.3441 .21147 L
.34552 .21263 L
.34694 .21336 L
.34836 .2136 L
.34977 .21334 L
.35119 .21255 L
.35261 .21122 L
.35402 .20937 L
.35544 .207 L
.35686 .20411 L
.35828 .20071 L
.35969 .19677 L
.36111 .1923 L
.36253 .1873 L
.36395 .18175 L
.36536 .17567 L
.36678 .16905 L
.3682 .16191 L
.36961 .15429 L
.37103 .14623 L
.37245 .13779 L
.37387 .12903 L
.37528 .11999 L
.3767 .11074 L
Mistroke
.37812 .10135 L
.37954 .09189 L
.38095 .08247 L
.38237 .07317 L
.38379 .06411 L
.3852 .0554 L
.38662 .04718 L
.38804 .03961 L
.38946 .03283 L
.39087 .02698 L
.39229 .02216 L
.39371 .01846 L
.39512 .01596 L
.39654 .01472 L
.39796 .01477 L
.39938 .01615 L
.40079 .01885 L
.40221 .02289 L
.40363 .02829 L
.40505 .03507 L
.40646 .04325 L
.40788 .05282 L
.4093 .06378 L
.41071 .0761 L
.41213 .08976 L
.41355 .10471 L
.41497 .1209 L
.41638 .13825 L
.4178 .15667 L
.41922 .17608 L
.42063 .19642 L
.42205 .21761 L
.42347 .23956 L
.42489 .26215 L
.4263 .28525 L
.42772 .30873 L
.42914 .3324 L
.43056 .35609 L
.43197 .37961 L
.43339 .40271 L
.43481 .42518 L
.43622 .44683 L
.43764 .46749 L
.43906 .48701 L
.44048 .5053 L
.44189 .52222 L
.44331 .53769 L
.44473 .55164 L
.44615 .56402 L
.44756 .57479 L
Mistroke
.44898 .58389 L
.4504 .59129 L
.45181 .59692 L
.45323 .60079 L
.45465 .60292 L
.45607 .60332 L
.45748 .60205 L
.4589 .59914 L
.46032 .59464 L
.46173 .58861 L
.46315 .58113 L
.46457 .57226 L
.46599 .56203 L
.4674 .5505 L
.46882 .53772 L
.47024 .52376 L
.47166 .50874 L
.47307 .49278 L
.47449 .47604 L
.47591 .45867 L
.47732 .44083 L
.47874 .42274 L
.48016 .40457 L
.48158 .38652 L
.48299 .36871 L
.48441 .35128 L
.48583 .33432 L
.48724 .31793 L
.48866 .30223 L
.49008 .28728 L
.4915 .27315 L
.49291 .2599 L
.49433 .24756 L
.49575 .2362 L
.49717 .22584 L
.49858 .2165 L
.5 .20815 L
.50142 .20075 L
.50283 .19425 L
.50425 .18861 L
.50567 .18381 L
.50709 .1798 L
.5085 .17655 L
.50992 .17403 L
.51134 .17223 L
.51276 .17114 L
.51417 .17076 L
.51559 .17105 L
.51701 .17197 L
.51842 .17345 L
Mistroke
.51984 .1754 L
.52126 .17776 L
.52268 .18043 L
.52409 .18333 L
.52551 .18634 L
.52693 .18939 L
.52834 .19241 L
.52976 .19534 L
.53118 .19814 L
.5326 .20075 L
.53401 .20311 L
.53543 .20519 L
.53685 .20694 L
.53827 .20832 L
.53968 .20933 L
.5411 .20995 L
.54252 .21017 L
.54393 .21 L
.54535 .20947 L
.54677 .20864 L
.54819 .20756 L
.5496 .20627 L
.55102 .20479 L
.55244 .20315 L
.55385 .20138 L
.55527 .19948 L
.55669 .19748 L
.55811 .19536 L
.55952 .19314 L
.56094 .19081 L
.56236 .1884 L
.56378 .18594 L
.56519 .18345 L
.56661 .18097 L
.56803 .17851 L
.56944 .17609 L
.57086 .17375 L
.57228 .1715 L
.5737 .16937 L
.57511 .16735 L
.57653 .16548 L
.57795 .16375 L
.57937 .16219 L
.58078 .16083 L
.5822 .15968 L
.58362 .15875 L
.58503 .15805 L
.58645 .15757 L
.58787 .15731 L
.58929 .15725 L
Mistroke
.5907 .15737 L
.59212 .15763 L
.59354 .15801 L
.59495 .15848 L
.59637 .15901 L
.59779 .15959 L
.59921 .16022 L
.60062 .16088 L
.60204 .16156 L
.60346 .16225 L
.60488 .16295 L
.60629 .16365 L
.60771 .16435 L
.60913 .16503 L
.61054 .16569 L
.61196 .16632 L
.61338 .16692 L
.6148 .16749 L
.61621 .16803 L
.61763 .16855 L
.61905 .16903 L
.62046 .16949 L
.62188 .16991 L
.6233 .17031 L
.62472 .17066 L
.62613 .17096 L
.62755 .17121 L
.62897 .17139 L
.63039 .17151 L
.6318 .17157 L
.63322 .17157 L
.63464 .17151 L
.63605 .17141 L
.63747 .17128 L
.63889 .17112 L
.64031 .17094 L
.64172 .17075 L
.64314 .17055 L
.64456 .17035 L
.64598 .17014 L
.64739 .16994 L
.64881 .16974 L
.65023 .16956 L
.65164 .16939 L
.65306 .16923 L
.65448 .1691 L
.6559 .16899 L
.65731 .16889 L
.65873 .16882 L
.66015 .16875 L
Mistroke
.66156 .1687 L
.66298 .16865 L
.6644 .16861 L
.66582 .16857 L
.66723 .16853 L
.66865 .16849 L
.67007 .16846 L
.67149 .16844 L
.6729 .16842 L
.67432 .16841 L
.67574 .16841 L
.67715 .16842 L
.67857 .16843 L
.67999 .16846 L
.68141 .16848 L
.68282 .16852 L
.68424 .16855 L
.68566 .16859 L
.68707 .16864 L
.68849 .16868 L
.68991 .16873 L
.69133 .16878 L
.69274 .16883 L
.69416 .16887 L
.69558 .16892 L
.697 .16895 L
.69841 .16899 L
.69983 .16901 L
.70125 .16903 L
.70266 .16905 L
.70408 .16906 L
.7055 .16906 L
.70692 .16907 L
.70833 .16907 L
.70975 .16907 L
.71117 .16907 L
.71259 .16908 L
.714 .16908 L
.71542 .16908 L
.71684 .16908 L
.71825 .16908 L
.71967 .16909 L
.72109 .16909 L
.72251 .16909 L
.72392 .16909 L
.72534 .16909 L
.72676 .16909 L
.72817 .1691 L
.72959 .1691 L
.73101 .1691 L
Mistroke
.73243 .1691 L
.73384 .1691 L
.73526 .1691 L
.73668 .16909 L
.7381 .16909 L
.73951 .16908 L
.74093 .16908 L
.74235 .16908 L
.74376 .16907 L
.74518 .16907 L
.7466 .16907 L
.74802 .16907 L
.74943 .16906 L
.75085 .16906 L
.75227 .16906 L
.75368 .16906 L
.7551 .16906 L
.75652 .16906 L
.75794 .16906 L
.75935 .16906 L
.76077 .16906 L
.76219 .16906 L
.76361 .16906 L
.76502 .16906 L
.76644 .16906 L
.76786 .16906 L
.76927 .16906 L
.77069 .16906 L
.77211 .16906 L
.77353 .16906 L
.77494 .16906 L
.77636 .16906 L
.77778 .16906 L
.7792 .16906 L
.78061 .16906 L
.78203 .16906 L
.78345 .16906 L
.78486 .16906 L
.78628 .16906 L
.7877 .16906 L
.78912 .16906 L
.79053 .16906 L
.79195 .16906 L
.79337 .16906 L
.79478 .16906 L
.7962 .16906 L
.79762 .16906 L
.79904 .16906 L
.80045 .16906 L
.80187 .16906 L
Mistroke
.80329 .16906 L
.80471 .16906 L
.80612 .16906 L
.80754 .16906 L
.80896 .16906 L
.81037 .16906 L
.81179 .16906 L
.81321 .16906 L
.81463 .16906 L
.81604 .16906 L
.81746 .16906 L
.81888 .16906 L
.82029 .16906 L
.82171 .16906 L
.82313 .16906 L
.82455 .16906 L
.82596 .16906 L
.82738 .16906 L
.8288 .16906 L
.83022 .16906 L
.83163 .16906 L
.83305 .16906 L
.83447 .16906 L
.83588 .16906 L
.8373 .16906 L
.83872 .16906 L
.84014 .16906 L
.84155 .16906 L
.84297 .16906 L
.84439 .16906 L
.8458 .16906 L
.84722 .16906 L
.84864 .16906 L
.85006 .16906 L
.85147 .16906 L
.85289 .16906 L
.85431 .16906 L
.85573 .16906 L
.85714 .16906 L
.85856 .16906 L
.85998 .16906 L
.86139 .16906 L
.86281 .16906 L
.86423 .16906 L
.86565 .16906 L
.86706 .16906 L
.86848 .16906 L
.8699 .16906 L
.87132 .16906 L
.87273 .16906 L
Mistroke
.87415 .16906 L
.87557 .16906 L
.87698 .16906 L
.8784 .16906 L
.87982 .16906 L
.88124 .16906 L
.88265 .16906 L
.88407 .16906 L
.88549 .16906 L
.8869 .16906 L
.88832 .16906 L
.88974 .16906 L
.89116 .16906 L
.89257 .16906 L
.89399 .16906 L
.89541 .16906 L
.89683 .16906 L
.89824 .16906 L
.89966 .16906 L
.90108 .16906 L
.90249 .16906 L
.90391 .16906 L
.90533 .16906 L
.90675 .16906 L
.90816 .16906 L
.90958 .16906 L
.911 .16906 L
.91241 .16906 L
.91383 .16906 L
.91525 .16906 L
.91667 .16906 L
.91808 .16906 L
.9195 .16906 L
.92092 .16906 L
.92234 .16906 L
.92375 .16906 L
.92517 .16906 L
.92659 .16906 L
.928 .16906 L
.92942 .16906 L
.93084 .16906 L
.93226 .16906 L
.93367 .16906 L
.93509 .16906 L
.93651 .16906 L
.93793 .16906 L
.93934 .16906 L
.94076 .16906 L
.94218 .16906 L
.94359 .16906 L
Mistroke
.94501 .16906 L
.94643 .16906 L
.94785 .16906 L
.94926 .16906 L
.95068 .16906 L
.9521 .16906 L
.95351 .16906 L
.95493 .16906 L
.95635 .16906 L
.95777 .16906 L
.95918 .16906 L
.9606 .16906 L
.96202 .16906 L
.96344 .16906 L
.96485 .16906 L
.96627 .16906 L
.96769 .16906 L
.9691 .16906 L
.97052 .16906 L
.97194 .16906 L
.97336 .16906 L
.97477 .16906 L
.97619 .16906 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["This is the wavelet.", "MathCaption",
  CellTags->{"S1.4.4", "4.61"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[h11, 5], PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"Least Asymmetric psi_11(t)\"]\
\>", "Input",
  CellLabel->"In[52]:= ",
  CellTags->"S1.4.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.477324 0.0453515 0.315216 0.257969 [
[.02381 .30272 -9 -9 ]
[.02381 .30272 9 0 ]
[.25057 .30272 -6 -9 ]
[.25057 .30272 6 0 ]
[.70408 .30272 -3 -9 ]
[.70408 .30272 3 0 ]
[.93084 .30272 -6 -9 ]
[.93084 .30272 6 0 ]
[1.025 .31522 0 -4.5 ]
[1.025 .31522 6 4.5 ]
[.46482 .05725 -12 -4.5 ]
[.46482 .05725 0 4.5 ]
[.46482 .18623 -24 -4.5 ]
[.46482 .18623 0 4.5 ]
[.46482 .4442 -18 -4.5 ]
[.46482 .4442 0 4.5 ]
[.46482 .57318 -6 -4.5 ]
[.46482 .57318 0 4.5 ]
[.5 .63053 -78 0 ]
[.5 .63053 78 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .31522 m
.02381 .32147 L
s
[(-10)] .02381 .30272 0 1 Mshowa
.25057 .31522 m
.25057 .32147 L
s
[(-5)] .25057 .30272 0 1 Mshowa
.70408 .31522 m
.70408 .32147 L
s
[(5)] .70408 .30272 0 1 Mshowa
.93084 .31522 m
.93084 .32147 L
s
[(10)] .93084 .30272 0 1 Mshowa
.125 Mabswid
.06916 .31522 m
.06916 .31897 L
s
.11451 .31522 m
.11451 .31897 L
s
.15986 .31522 m
.15986 .31897 L
s
.20522 .31522 m
.20522 .31897 L
s
.29592 .31522 m
.29592 .31897 L
s
.34127 .31522 m
.34127 .31897 L
s
.38662 .31522 m
.38662 .31897 L
s
.43197 .31522 m
.43197 .31897 L
s
.52268 .31522 m
.52268 .31897 L
s
.56803 .31522 m
.56803 .31897 L
s
.61338 .31522 m
.61338 .31897 L
s
.65873 .31522 m
.65873 .31897 L
s
.74943 .31522 m
.74943 .31897 L
s
.79478 .31522 m
.79478 .31897 L
s
.84014 .31522 m
.84014 .31897 L
s
.88549 .31522 m
.88549 .31897 L
s
.97619 .31522 m
.97619 .31897 L
s
.25 Mabswid
0 .31522 m
1 .31522 L
s
[(t)] 1.025 .31522 -1 0 Mshowa
.47732 .05725 m
.48357 .05725 L
s
[(-1)] .46482 .05725 1 0 Mshowa
.47732 .18623 m
.48357 .18623 L
s
[(-0.5)] .46482 .18623 1 0 Mshowa
.47732 .4442 m
.48357 .4442 L
s
[(0.5)] .46482 .4442 1 0 Mshowa
.47732 .57318 m
.48357 .57318 L
s
[(1)] .46482 .57318 1 0 Mshowa
.125 Mabswid
.47732 .08304 m
.48107 .08304 L
s
.47732 .10884 m
.48107 .10884 L
s
.47732 .13464 m
.48107 .13464 L
s
.47732 .16043 m
.48107 .16043 L
s
.47732 .21203 m
.48107 .21203 L
s
.47732 .23783 m
.48107 .23783 L
s
.47732 .26362 m
.48107 .26362 L
s
.47732 .28942 m
.48107 .28942 L
s
.47732 .34101 m
.48107 .34101 L
s
.47732 .36681 m
.48107 .36681 L
s
.47732 .39261 m
.48107 .39261 L
s
.47732 .4184 m
.48107 .4184 L
s
.47732 .47 m
.48107 .47 L
s
.47732 .49579 m
.48107 .49579 L
s
.47732 .52159 m
.48107 .52159 L
s
.47732 .54739 m
.48107 .54739 L
s
.47732 .03145 m
.48107 .03145 L
s
.47732 .00565 m
.48107 .00565 L
s
.47732 .59898 m
.48107 .59898 L
s
.25 Mabswid
.47732 0 m
.47732 .61803 L
s
[(Least Asymmetric psi_11\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .31522 m
.02523 .31522 L
.02664 .31522 L
.02806 .31522 L
.02948 .31522 L
.0309 .31522 L
.03231 .31522 L
.03373 .31522 L
.03515 .31522 L
.03656 .31522 L
.03798 .31522 L
.0394 .31522 L
.04082 .31522 L
.04223 .31522 L
.04365 .31522 L
.04507 .31522 L
.04649 .31522 L
.0479 .31522 L
.04932 .31522 L
.05074 .31522 L
.05215 .31522 L
.05357 .31522 L
.05499 .31522 L
.05641 .31522 L
.05782 .31522 L
.05924 .31522 L
.06066 .31522 L
.06207 .31522 L
.06349 .31522 L
.06491 .31522 L
.06633 .31522 L
.06774 .31522 L
.06916 .31522 L
.07058 .31522 L
.072 .31522 L
.07341 .31522 L
.07483 .31522 L
.07625 .31522 L
.07766 .31522 L
.07908 .31522 L
.0805 .31522 L
.08192 .31522 L
.08333 .31522 L
.08475 .31522 L
.08617 .31522 L
.08759 .31522 L
.089 .31522 L
.09042 .31522 L
.09184 .31522 L
.09325 .31522 L
Mistroke
.09467 .31522 L
.09609 .31522 L
.09751 .31522 L
.09892 .31522 L
.10034 .31522 L
.10176 .31522 L
.10317 .31522 L
.10459 .31522 L
.10601 .31522 L
.10743 .31522 L
.10884 .31522 L
.11026 .31522 L
.11168 .31522 L
.1131 .31522 L
.11451 .31522 L
.11593 .31522 L
.11735 .31522 L
.11876 .31522 L
.12018 .31522 L
.1216 .31522 L
.12302 .31522 L
.12443 .31522 L
.12585 .31522 L
.12727 .31522 L
.12868 .31522 L
.1301 .31522 L
.13152 .31522 L
.13294 .31522 L
.13435 .31522 L
.13577 .31522 L
.13719 .31522 L
.13861 .31522 L
.14002 .31522 L
.14144 .31522 L
.14286 .31522 L
.14427 .31522 L
.14569 .31522 L
.14711 .31522 L
.14853 .31522 L
.14994 .31522 L
.15136 .31522 L
.15278 .31522 L
.1542 .31522 L
.15561 .31522 L
.15703 .31522 L
.15845 .31521 L
.15986 .31521 L
.16128 .31521 L
.1627 .31521 L
.16412 .31521 L
Mistroke
.16553 .31521 L
.16695 .31522 L
.16837 .31522 L
.16978 .31522 L
.1712 .31522 L
.17262 .31522 L
.17404 .31522 L
.17545 .31522 L
.17687 .31522 L
.17829 .31522 L
.17971 .31522 L
.18112 .31522 L
.18254 .31522 L
.18396 .31522 L
.18537 .31522 L
.18679 .31522 L
.18821 .31522 L
.18963 .31522 L
.19104 .31522 L
.19246 .31522 L
.19388 .31522 L
.19529 .31522 L
.19671 .31522 L
.19813 .31521 L
.19955 .31521 L
.20096 .31521 L
.20238 .31521 L
.2038 .31521 L
.20522 .31521 L
.20663 .31521 L
.20805 .31521 L
.20947 .31521 L
.21088 .3152 L
.2123 .3152 L
.21372 .3152 L
.21514 .3152 L
.21655 .3152 L
.21797 .3152 L
.21939 .3152 L
.2208 .31519 L
.22222 .31519 L
.22364 .31519 L
.22506 .31519 L
.22647 .31519 L
.22789 .31519 L
.22931 .31519 L
.23073 .3152 L
.23214 .3152 L
.23356 .31521 L
.23498 .31522 L
Mistroke
.23639 .31523 L
.23781 .31524 L
.23923 .31526 L
.24065 .31527 L
.24206 .31529 L
.24348 .31531 L
.2449 .31533 L
.24632 .31535 L
.24773 .31536 L
.24915 .31538 L
.25057 .3154 L
.25198 .31541 L
.2534 .31542 L
.25482 .31543 L
.25624 .31543 L
.25765 .31543 L
.25907 .31542 L
.26049 .31541 L
.2619 .3154 L
.26332 .31538 L
.26474 .31535 L
.26616 .31532 L
.26757 .31529 L
.26899 .31525 L
.27041 .31521 L
.27183 .31516 L
.27324 .31511 L
.27466 .31506 L
.27608 .31501 L
.27749 .31495 L
.27891 .3149 L
.28033 .31484 L
.28175 .31479 L
.28316 .31474 L
.28458 .31469 L
.286 .31464 L
.28741 .3146 L
.28883 .31456 L
.29025 .31453 L
.29167 .3145 L
.29308 .31448 L
.2945 .31447 L
.29592 .31445 L
.29734 .31444 L
.29875 .31443 L
.30017 .31443 L
.30159 .31442 L
.303 .31441 L
.30442 .31441 L
.30584 .3144 L
Mistroke
.30726 .31441 L
.30867 .31441 L
.31009 .31442 L
.31151 .31443 L
.31293 .31446 L
.31434 .31449 L
.31576 .31453 L
.31718 .31459 L
.31859 .31466 L
.32001 .31477 L
.32143 .31491 L
.32285 .31508 L
.32426 .31529 L
.32568 .31553 L
.3271 .31581 L
.32851 .31612 L
.32993 .31646 L
.33135 .31682 L
.33277 .31719 L
.33418 .31758 L
.3356 .31797 L
.33702 .31836 L
.33844 .31875 L
.33985 .31913 L
.34127 .3195 L
.34269 .31984 L
.3441 .32015 L
.34552 .32042 L
.34694 .32066 L
.34836 .32084 L
.34977 .32097 L
.35119 .32104 L
.35261 .32106 L
.35402 .32104 L
.35544 .32099 L
.35686 .3209 L
.35828 .32076 L
.35969 .32057 L
.36111 .32031 L
.36253 .31996 L
.36395 .31951 L
.36536 .31894 L
.36678 .31824 L
.3682 .31738 L
.36961 .31637 L
.37103 .31522 L
.37245 .31392 L
.37387 .31248 L
.37528 .3109 L
.3767 .30916 L
Mistroke
.37812 .30726 L
.37954 .30523 L
.38095 .30311 L
.38237 .30094 L
.38379 .29879 L
.3852 .29673 L
.38662 .29483 L
.38804 .29318 L
.38946 .29187 L
.39087 .29098 L
.39229 .29056 L
.39371 .29062 L
.39512 .29117 L
.39654 .29225 L
.39796 .29389 L
.39938 .29612 L
.40079 .29895 L
.40221 .30235 L
.40363 .30624 L
.40505 .31052 L
.40646 .31505 L
.40788 .3197 L
.4093 .32429 L
.41071 .32861 L
.41213 .33243 L
.41355 .33559 L
.41497 .33798 L
.41638 .33956 L
.4178 .3403 L
.41922 .34013 L
.42063 .33899 L
.42205 .33679 L
.42347 .33352 L
.42489 .32926 L
.4263 .32418 L
.42772 .31848 L
.42914 .31243 L
.43056 .30635 L
.43197 .30061 L
.43339 .29571 L
.43481 .29214 L
.43622 .29022 L
.43764 .2902 L
.43906 .29213 L
.44048 .29602 L
.44189 .30194 L
.44331 .30997 L
.44473 .32015 L
.44615 .33243 L
.44756 .34653 L
Mistroke
.44898 .36205 L
.4504 .37856 L
.45181 .39551 L
.45323 .41219 L
.45465 .42775 L
.45607 .44109 L
.45748 .45119 L
.4589 .45732 L
.46032 .45895 L
.46173 .4559 L
.46315 .4481 L
.46457 .4354 L
.46599 .41774 L
.4674 .39521 L
.46882 .36806 L
.47024 .33684 L
.47166 .30223 L
.47307 .2649 L
.47449 .22575 L
.47591 .18596 L
.47732 .147 L
.47874 .11066 L
.48016 .07869 L
.48158 .05236 L
.48299 .03259 L
.48441 .01994 L
.48583 .01472 L
.48724 .01724 L
.48866 .02764 L
.49008 .04571 L
.4915 .07102 L
.49291 .10293 L
.49433 .14067 L
.49575 .1836 L
.49717 .23083 L
.49858 .28102 L
.5 .33248 L
.50142 .38319 L
.50283 .43115 L
.50425 .47489 L
.50567 .51328 L
.50709 .54545 L
.5085 .57086 L
.50992 .58903 L
.51134 .59975 L
.51276 .60332 L
.51417 .6002 L
.51559 .59087 L
.51701 .57585 L
.51842 .55543 L
Mistroke
.51984 .53011 L
.52126 .5008 L
.52268 .46871 L
.52409 .43524 L
.52551 .40182 L
.52693 .36947 L
.52834 .33903 L
.52976 .31125 L
.53118 .28667 L
.5326 .26566 L
.53401 .24831 L
.53543 .23429 L
.53685 .2232 L
.53827 .21475 L
.53968 .20878 L
.5411 .20527 L
.54252 .20419 L
.54393 .20523 L
.54535 .20796 L
.54677 .21196 L
.54819 .21679 L
.5496 .22213 L
.55102 .22773 L
.55244 .23322 L
.55385 .23836 L
.55527 .24307 L
.55669 .24742 L
.55811 .25172 L
.55952 .25631 L
.56094 .26132 L
.56236 .26681 L
.56378 .27272 L
.56519 .27898 L
.56661 .28556 L
.56803 .2924 L
.56944 .29934 L
.57086 .30624 L
.57228 .31296 L
.5737 .31941 L
.57511 .32564 L
.57653 .33165 L
.57795 .33737 L
.57937 .34265 L
.58078 .34732 L
.5822 .35122 L
.58362 .35426 L
.58503 .3564 L
.58645 .35761 L
.58787 .35788 L
.58929 .35727 L
Mistroke
.5907 .35587 L
.59212 .3539 L
.59354 .35154 L
.59495 .34894 L
.59637 .3462 L
.59779 .34337 L
.59921 .34047 L
.60062 .33758 L
.60204 .33474 L
.60346 .33197 L
.60488 .32927 L
.60629 .32666 L
.60771 .32417 L
.60913 .32184 L
.61054 .31973 L
.61196 .31785 L
.61338 .31616 L
.6148 .31464 L
.61621 .31324 L
.61763 .31193 L
.61905 .31071 L
.62046 .30957 L
.62188 .30849 L
.6233 .30749 L
.62472 .30657 L
.62613 .30579 L
.62755 .30521 L
.62897 .30483 L
.63039 .30466 L
.6318 .30469 L
.63322 .30491 L
.63464 .30528 L
.63605 .3058 L
.63747 .30642 L
.63889 .30712 L
.64031 .30787 L
.64172 .30865 L
.64314 .30944 L
.64456 .31025 L
.64598 .31105 L
.64739 .31184 L
.64881 .31258 L
.65023 .31326 L
.65164 .31386 L
.65306 .31438 L
.65448 .3148 L
.6559 .31513 L
.65731 .31537 L
.65873 .31553 L
.66015 .31564 L
Mistroke
.66156 .31572 L
.66298 .31578 L
.6644 .31583 L
.66582 .31589 L
.66723 .31595 L
.66865 .31601 L
.67007 .31608 L
.67149 .31615 L
.6729 .31621 L
.67432 .31626 L
.67574 .31629 L
.67715 .31631 L
.67857 .31633 L
.67999 .31634 L
.68141 .31635 L
.68282 .31634 L
.68424 .31633 L
.68566 .31629 L
.68707 .31624 L
.68849 .31618 L
.68991 .3161 L
.69133 .316 L
.69274 .31589 L
.69416 .31578 L
.69558 .31567 L
.697 .31557 L
.69841 .31549 L
.69983 .31541 L
.70125 .31535 L
.70266 .31531 L
.70408 .31527 L
.7055 .31525 L
.70692 .31523 L
.70833 .31521 L
.70975 .3152 L
.71117 .31519 L
.71259 .31518 L
.714 .31518 L
.71542 .31518 L
.71684 .31518 L
.71825 .31518 L
.71967 .31518 L
.72109 .31518 L
.72251 .31518 L
.72392 .31518 L
.72534 .31517 L
.72676 .31517 L
.72817 .31516 L
.72959 .31515 L
.73101 .31515 L
Mistroke
.73243 .31514 L
.73384 .31514 L
.73526 .31515 L
.73668 .31515 L
.7381 .31516 L
.73951 .31516 L
.74093 .31517 L
.74235 .31518 L
.74376 .31518 L
.74518 .31519 L
.7466 .31519 L
.74802 .3152 L
.74943 .3152 L
.75085 .3152 L
.75227 .31521 L
.75368 .31521 L
.7551 .31521 L
.75652 .31521 L
.75794 .31521 L
.75935 .31521 L
.76077 .31521 L
.76219 .31521 L
.76361 .31521 L
.76502 .31521 L
.76644 .31521 L
.76786 .31521 L
.76927 .31521 L
.77069 .31521 L
.77211 .31521 L
.77353 .31521 L
.77494 .31521 L
.77636 .31521 L
.77778 .31522 L
.7792 .31522 L
.78061 .31522 L
.78203 .31522 L
.78345 .31522 L
.78486 .31522 L
.78628 .31522 L
.7877 .31522 L
.78912 .31522 L
.79053 .31522 L
.79195 .31522 L
.79337 .31522 L
.79478 .31522 L
.7962 .31522 L
.79762 .31522 L
.79904 .31522 L
.80045 .31522 L
.80187 .31522 L
Mistroke
.80329 .31521 L
.80471 .31521 L
.80612 .31522 L
.80754 .31522 L
.80896 .31522 L
.81037 .31522 L
.81179 .31522 L
.81321 .31522 L
.81463 .31522 L
.81604 .31522 L
.81746 .31522 L
.81888 .31522 L
.82029 .31522 L
.82171 .31522 L
.82313 .31522 L
.82455 .31522 L
.82596 .31522 L
.82738 .31522 L
.8288 .31522 L
.83022 .31522 L
.83163 .31522 L
.83305 .31522 L
.83447 .31522 L
.83588 .31522 L
.8373 .31522 L
.83872 .31522 L
.84014 .31522 L
.84155 .31522 L
.84297 .31522 L
.84439 .31522 L
.8458 .31522 L
.84722 .31522 L
.84864 .31522 L
.85006 .31522 L
.85147 .31522 L
.85289 .31522 L
.85431 .31522 L
.85573 .31522 L
.85714 .31522 L
.85856 .31522 L
.85998 .31522 L
.86139 .31522 L
.86281 .31522 L
.86423 .31522 L
.86565 .31522 L
.86706 .31522 L
.86848 .31522 L
.8699 .31522 L
.87132 .31522 L
.87273 .31522 L
Mistroke
.87415 .31522 L
.87557 .31522 L
.87698 .31522 L
.8784 .31522 L
.87982 .31522 L
.88124 .31522 L
.88265 .31522 L
.88407 .31522 L
.88549 .31522 L
.8869 .31522 L
.88832 .31522 L
.88974 .31522 L
.89116 .31522 L
.89257 .31522 L
.89399 .31522 L
.89541 .31522 L
.89683 .31522 L
.89824 .31522 L
.89966 .31522 L
.90108 .31522 L
.90249 .31522 L
.90391 .31522 L
.90533 .31522 L
.90675 .31522 L
.90816 .31522 L
.90958 .31522 L
.911 .31522 L
.91241 .31522 L
.91383 .31522 L
.91525 .31522 L
.91667 .31522 L
.91808 .31522 L
.9195 .31522 L
.92092 .31522 L
.92234 .31522 L
.92375 .31522 L
.92517 .31522 L
.92659 .31522 L
.928 .31522 L
.92942 .31522 L
.93084 .31522 L
.93226 .31522 L
.93367 .31522 L
.93509 .31522 L
.93651 .31522 L
.93793 .31522 L
.93934 .31522 L
.94076 .31522 L
.94218 .31522 L
.94359 .31522 L
Mistroke
.94501 .31522 L
.94643 .31522 L
.94785 .31522 L
.94926 .31522 L
.95068 .31522 L
.9521 .31522 L
.95351 .31522 L
.95493 .31522 L
.95635 .31522 L
.95777 .31522 L
.95918 .31522 L
.9606 .31522 L
.96202 .31522 L
.96344 .31522 L
.96485 .31522 L
.96627 .31522 L
.96769 .31522 L
.9691 .31522 L
.97052 .31522 L
.97194 .31522 L
.97336 .31522 L
.97477 .31522 L
.97619 .31522 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],

Cell["1.4.5 Coiflets", "Subsection",
  CellTags->{"S1.4.5", "5.1"}],

Cell[TextData[{
  "Coiflets are another variation on Daubechies wavelets. They are so named \
by I. Daubechies because R. Coifman suggested the construction of orthonormal \
wavelet basis with vanishing moment conditions both for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " as well as for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.5"],
  ". The idea is to find the form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " that satisfies the orthogonality condition and both moment conditions for \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.5"],
  ". These moment conditions are "
}], "Text",
  CellTags->{"S1.4.5", "5.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(t\^l\), "\[Psi]", \((
        t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(0\ \ \ \), \(" for "\), "l", "=", "0", ",", "1", ",", 
        "\[Ellipsis]", ",", "N", "-", "1"}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.5", "5.3"}],

Cell["and ", "Text",
  CellTags->{"S1.4.5", "5.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), " ", 
        
        StyleBox[\("dt"\),
          "TI"], "=", "1", \(, \ \ \ \), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(t\^l\), "\[Phi]", 
        \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(0\ \ \ \), \(" for "\), "l", "=", "1", ",", 
        "\[Ellipsis]", ",", "N", "-", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.4.5", "5.5"}],

Cell[TextData[{
  "These two moment conditions translate into the following conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.5"],
  ": "
}], "Text",
  CellTags->{"S1.4.5", "5.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(m\_0\%\((l)\)\) \((\[Pi])\) = \(0\ \ \ \) " for " l = 0, 1, 
      \[Ellipsis], N - 1, \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.21) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.5", "5.7"}],

Cell["and ", "Text",
  CellTags->{"S1.4.5", "5.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(m\_0\) \((0)\) = 1 \(, \ \) \(m\_0\%\((l)\)\) \((0)\) = \(0\ \ \ \) 
      " for " l = 1, 2, \[Ellipsis], N - 1.\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.22) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.5", "5.9"}],

Cell[TextData[{
  "It can be shown that the following form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " fulfills both the moment conditions given in (",
  ButtonBox["4.21",
    ButtonData:>{"Wavelets 1.4.5", "5.7"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["4.22",
    ButtonData:>{"Wavelets 1.4.5", "5.9"},
    ButtonStyle->"AddOnsLink"],
  "): "
}], "Text",
  CellTags->{"S1.4.5", "5.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(m\_0\), \((\[Omega])\), "=", \(\((\(cos\^2\) \[Omega]\/2)\)\^K\), 
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", 
            RowBox[{
              UnderoverscriptBox["\[Sum]", \(k = 0\), \(K - 1\),
                LimitsPositioning->True], 
              RowBox[{"(", GridBox[{
                    {
                      StyleBox[\(K - 1 + k\),
                        "DisplayFormula"]},
                    {
                      StyleBox["k",
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], ")"}], 
              \(\((\(sin\^2\) \[Omega]\/2)\)\^k\), "+", 
              \(\((\(sin\^2\) \[Omega]\/2)\)\^K\), "f", \((\[Omega])\)}], 
            "]"}]}]}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.23) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.5", "5.11"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`2  K = N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " is chosen to be "
}], "Text",
  CellTags->{"S1.4.5", "5.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((\[Omega])\), "=", 
        UnderoverscriptBox["\[Sum]", \(n = 0\), \(2  K - 1\),
          LimitsPositioning->True], \(f\_n\), \(e\^\(i  n  \[Omega]\)\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.5", "5.13"}],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_n}\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " are determined by requiring ",
  Cell[BoxData[
      \(TraditionalForm\`\(m\_0\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " given in (",
  ButtonBox["4.23",
    ButtonData:>{"Wavelets 1.4.5", "5.11"},
    ButtonStyle->"AddOnsLink"],
  ") to satisfy the orthogonality condition. For more details on how to solve \
for coiflet coefficients, see Daubechies (1993). \nThe function "
}], "Text",
  CellTags->{"S1.4.5", "5.14"}],

Cell[TextData[{
  StyleBox["CoifletFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.5", "5.15"}],

Cell[TextData[{
  "generates the coiflet filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  ". Note that ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " here has to be even. ",
  StyleBox["CoifletFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["prec", "TI"],
  StyleBox["]", "MR"],
  " computes coiflet filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " with working precision ",
  StyleBox["prec", "TI"],
  ". Again we emphasis that for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " it is important to increase the working precision in order to get correct \
results. In addition, we warn the reader that for large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " the algorithm for finding coiflet filter can run into numerical \
difficulties. Therefore, one should not use this function with large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.5"],
  " (say, ",
  Cell[BoxData[
      \(TraditionalForm\`N > 18\)], "InlineFormula",
    CellTags->"S1.4.5"],
  "). "
}], "Text",
  CellTags->{"S1.4.5", "5.16"}],

Cell["This gives the second\[Hyphen]order coiflet filter.", "MathCaption",
  CellTags->{"S1.4.5", "5.17"}],

Cell[CellGroupData[{

Cell["c2 = CoifletFilter[2, 18]", "Input",
  CellLabel->"In[53]:= ",
  CellTags->"S1.4.5"],

Cell[BoxData[
    \({{\(-0.072732619512526448037939201947`17.8042\), 
        0.33789766245748176968825583775`17.7997, 
        0.85257202021160042047672043633`17.8131, 
        0.38486484686485774722475403997`17.7542, 
        \(-0.072732619512526448037939201947`17.6143\), 
        \(-0.015655728135791992512166343274`17.6281\)}, \(-2\)}\)], "Output",
  CellLabel->"Out[53]= ",
  CellTags->"S1.4.5"]
}, Open  ]],

Cell[TextData[{
  "Again, we can plot the scaling function using ",
  StyleBox["ScalingFunction", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.5", "5.18"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[c2, 5],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"coiflet phi of order 2\"}];\
\>", "Input",
  CellLabel->"In[54]:= ",
  CellTags->"S1.4.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.114947 0.293945 [
[.02381 .10245 -6 -9 ]
[.02381 .10245 6 0 ]
[.21429 .10245 -6 -9 ]
[.21429 .10245 6 0 ]
[.59524 .10245 -3 -9 ]
[.59524 .10245 3 0 ]
[.78571 .10245 -3 -9 ]
[.78571 .10245 3 0 ]
[.97619 .10245 -3 -9 ]
[.97619 .10245 3 0 ]
[1.025 .11495 0 -4.5 ]
[1.025 .11495 6 4.5 ]
[.39226 .26192 -18 -4.5 ]
[.39226 .26192 0 4.5 ]
[.39226 .40889 -6 -4.5 ]
[.39226 .40889 0 4.5 ]
[.39226 .55586 -18 -4.5 ]
[.39226 .55586 0 4.5 ]
[.40476 .64303 -66 0 ]
[.40476 .64303 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .11495 m
.02381 .1212 L
s
[(-2)] .02381 .10245 0 1 Mshowa
.21429 .11495 m
.21429 .1212 L
s
[(-1)] .21429 .10245 0 1 Mshowa
.59524 .11495 m
.59524 .1212 L
s
[(1)] .59524 .10245 0 1 Mshowa
.78571 .11495 m
.78571 .1212 L
s
[(2)] .78571 .10245 0 1 Mshowa
.97619 .11495 m
.97619 .1212 L
s
[(3)] .97619 .10245 0 1 Mshowa
.125 Mabswid
.0619 .11495 m
.0619 .1187 L
s
.1 .11495 m
.1 .1187 L
s
.1381 .11495 m
.1381 .1187 L
s
.17619 .11495 m
.17619 .1187 L
s
.25238 .11495 m
.25238 .1187 L
s
.29048 .11495 m
.29048 .1187 L
s
.32857 .11495 m
.32857 .1187 L
s
.36667 .11495 m
.36667 .1187 L
s
.44286 .11495 m
.44286 .1187 L
s
.48095 .11495 m
.48095 .1187 L
s
.51905 .11495 m
.51905 .1187 L
s
.55714 .11495 m
.55714 .1187 L
s
.63333 .11495 m
.63333 .1187 L
s
.67143 .11495 m
.67143 .1187 L
s
.70952 .11495 m
.70952 .1187 L
s
.74762 .11495 m
.74762 .1187 L
s
.82381 .11495 m
.82381 .1187 L
s
.8619 .11495 m
.8619 .1187 L
s
.9 .11495 m
.9 .1187 L
s
.9381 .11495 m
.9381 .1187 L
s
.25 Mabswid
0 .11495 m
1 .11495 L
s
[(t)] 1.025 .11495 -1 0 Mshowa
.40476 .26192 m
.41101 .26192 L
s
[(0.5)] .39226 .26192 1 0 Mshowa
.40476 .40889 m
.41101 .40889 L
s
[(1)] .39226 .40889 1 0 Mshowa
.40476 .55586 m
.41101 .55586 L
s
[(1.5)] .39226 .55586 1 0 Mshowa
.125 Mabswid
.40476 .14434 m
.40851 .14434 L
s
.40476 .17374 m
.40851 .17374 L
s
.40476 .20313 m
.40851 .20313 L
s
.40476 .23252 m
.40851 .23252 L
s
.40476 .29131 m
.40851 .29131 L
s
.40476 .32071 m
.40851 .32071 L
s
.40476 .3501 m
.40851 .3501 L
s
.40476 .3795 m
.40851 .3795 L
s
.40476 .43829 m
.40851 .43829 L
s
.40476 .46768 m
.40851 .46768 L
s
.40476 .49708 m
.40851 .49708 L
s
.40476 .52647 m
.40851 .52647 L
s
.40476 .08555 m
.40851 .08555 L
s
.40476 .05616 m
.40851 .05616 L
s
.40476 .02676 m
.40851 .02676 L
s
.40476 .58526 m
.40851 .58526 L
s
.40476 .61465 m
.40851 .61465 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(coiflet phi of order 2)] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .11495 m
.02976 .11495 L
.03571 .11494 L
.04167 .11496 L
.04762 .11505 L
.05357 .11488 L
.05952 .11486 L
.06548 .11465 L
.07143 .11393 L
.07738 .11494 L
.08333 .1156 L
.08929 .1159 L
.09524 .11581 L
.10119 .1173 L
.10714 .11783 L
.1131 .11963 L
.11905 .12484 L
.125 .11846 L
.13095 .11504 L
.1369 .11243 L
.14286 .10861 L
.14881 .10776 L
.15476 .10568 L
.16071 .10458 L
.16667 .10654 L
.17262 .09834 L
.17857 .0921 L
.18452 .08815 L
.19048 .08689 L
.19643 .07498 L
.20238 .06944 L
.20833 .0555 L
.21429 .01874 L
.22024 .05935 L
.22619 .08076 L
.23214 .09534 L
.2381 .11452 L
.24405 .1261 L
.25 .13903 L
.25595 .15389 L
.2619 .17187 L
.26786 .17852 L
.27381 .18789 L
.27976 .19852 L
.28571 .20908 L
.29167 .21862 L
.29762 .2291 L
.30357 .23796 L
.30952 .24263 L
.31548 .2616 L
Mistroke
.32143 .27685 L
.32738 .29127 L
.33333 .30757 L
.33929 .31883 L
.34524 .33238 L
.35119 .34375 L
.35714 .34868 L
.3631 .37514 L
.36905 .39739 L
.375 .41491 L
.38095 .42703 L
.3869 .46068 L
.39286 .48142 L
.39881 .5192 L
.40476 .60332 L
.41071 .53038 L
.41667 .49647 L
.42262 .47632 L
.42857 .44658 L
.43452 .4331 L
.44048 .41643 L
.44643 .3964 L
.45238 .37159 L
.45833 .36451 L
.46429 .353 L
.47024 .34 L
.47619 .32833 L
.48214 .31395 L
.4881 .30055 L
.49405 .2866 L
.5 .27076 L
.50595 .26118 L
.5119 .25013 L
.51786 .23832 L
.52381 .22638 L
.52976 .2156 L
.53571 .20392 L
.54167 .19365 L
.54762 .1871 L
.55357 .16797 L
.55952 .15138 L
.56548 .13737 L
.57143 .1261 L
.57738 .10372 L
.58333 .08805 L
.58929 .06347 L
.59524 .01472 L
.60119 .04793 L
.60714 .06078 L
.6131 .06645 L
Mistroke
.61905 .07716 L
.625 .07927 L
.63095 .08311 L
.6369 .08861 L
.64286 .09636 L
.64881 .09569 L
.65476 .09717 L
.66071 .09924 L
.66667 .10043 L
.67262 .10381 L
.67857 .10622 L
.68452 .10953 L
.69048 .11554 L
.69643 .1125 L
.70238 .11171 L
.70833 .11172 L
.71429 .11117 L
.72024 .11155 L
.72619 .11176 L
.73214 .11175 L
.7381 .11141 L
.74405 .11228 L
.75 .11287 L
.75595 .1133 L
.7619 .11371 L
.76786 .11435 L
.77381 .11483 L
.77976 .11555 L
.78571 .11696 L
.79167 .11606 L
.79762 .11574 L
.80357 .11562 L
.80952 .11536 L
.81548 .11533 L
.82143 .11526 L
.82738 .11514 L
.83333 .11494 L
.83929 .11502 L
.84524 .11503 L
.85119 .11502 L
.85714 .11502 L
.8631 .11499 L
.86905 .11497 L
.875 .11495 L
.88095 .1149 L
.8869 .11493 L
.89286 .11494 L
.89881 .11494 L
.90476 .11495 L
.91071 .11494 L
Mistroke
.91667 .11495 L
.92262 .11495 L
.92857 .11495 L
.93452 .11495 L
.94048 .11495 L
.94643 .11495 L
.95238 .11495 L
.95833 .11495 L
.96429 .11495 L
.97024 .11495 L
.97619 .11495 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],

Cell["\<\
This gives the wavelet. Note that our definition of the wavelet \
here differs from that of Daubechies by a sign. \
\>", "MathCaption",
  CellTags->{"S1.4.5", "5.19"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[c2, 5],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"coiflet psi of order 2\"}];\
\>", "Input",
  CellLabel->"In[55]:= ",
  CellTags->"S1.4.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.397174 0.163129 [
[.02381 .38467 -6 -9 ]
[.02381 .38467 6 0 ]
[.21429 .38467 -6 -9 ]
[.21429 .38467 6 0 ]
[.59524 .38467 -3 -9 ]
[.59524 .38467 3 0 ]
[.78571 .38467 -3 -9 ]
[.78571 .38467 3 0 ]
[.97619 .38467 -3 -9 ]
[.97619 .38467 3 0 ]
[1.025 .39717 0 -4.5 ]
[1.025 .39717 6 4.5 ]
[.39226 .07092 -12 -4.5 ]
[.39226 .07092 0 4.5 ]
[.39226 .15248 -24 -4.5 ]
[.39226 .15248 0 4.5 ]
[.39226 .23405 -12 -4.5 ]
[.39226 .23405 0 4.5 ]
[.39226 .31561 -24 -4.5 ]
[.39226 .31561 0 4.5 ]
[.39226 .47874 -18 -4.5 ]
[.39226 .47874 0 4.5 ]
[.39226 .5603 -6 -4.5 ]
[.39226 .5603 0 4.5 ]
[.40476 .64303 -66 0 ]
[.40476 .64303 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .39717 m
.02381 .40342 L
s
[(-2)] .02381 .38467 0 1 Mshowa
.21429 .39717 m
.21429 .40342 L
s
[(-1)] .21429 .38467 0 1 Mshowa
.59524 .39717 m
.59524 .40342 L
s
[(1)] .59524 .38467 0 1 Mshowa
.78571 .39717 m
.78571 .40342 L
s
[(2)] .78571 .38467 0 1 Mshowa
.97619 .39717 m
.97619 .40342 L
s
[(3)] .97619 .38467 0 1 Mshowa
.125 Mabswid
.0619 .39717 m
.0619 .40092 L
s
.1 .39717 m
.1 .40092 L
s
.1381 .39717 m
.1381 .40092 L
s
.17619 .39717 m
.17619 .40092 L
s
.25238 .39717 m
.25238 .40092 L
s
.29048 .39717 m
.29048 .40092 L
s
.32857 .39717 m
.32857 .40092 L
s
.36667 .39717 m
.36667 .40092 L
s
.44286 .39717 m
.44286 .40092 L
s
.48095 .39717 m
.48095 .40092 L
s
.51905 .39717 m
.51905 .40092 L
s
.55714 .39717 m
.55714 .40092 L
s
.63333 .39717 m
.63333 .40092 L
s
.67143 .39717 m
.67143 .40092 L
s
.70952 .39717 m
.70952 .40092 L
s
.74762 .39717 m
.74762 .40092 L
s
.82381 .39717 m
.82381 .40092 L
s
.8619 .39717 m
.8619 .40092 L
s
.9 .39717 m
.9 .40092 L
s
.9381 .39717 m
.9381 .40092 L
s
.25 Mabswid
0 .39717 m
1 .39717 L
s
[(t)] 1.025 .39717 -1 0 Mshowa
.40476 .07092 m
.41101 .07092 L
s
[(-2)] .39226 .07092 1 0 Mshowa
.40476 .15248 m
.41101 .15248 L
s
[(-1.5)] .39226 .15248 1 0 Mshowa
.40476 .23405 m
.41101 .23405 L
s
[(-1)] .39226 .23405 1 0 Mshowa
.40476 .31561 m
.41101 .31561 L
s
[(-0.5)] .39226 .31561 1 0 Mshowa
.40476 .47874 m
.41101 .47874 L
s
[(0.5)] .39226 .47874 1 0 Mshowa
.40476 .5603 m
.41101 .5603 L
s
[(1)] .39226 .5603 1 0 Mshowa
.125 Mabswid
.40476 .08723 m
.40851 .08723 L
s
.40476 .10354 m
.40851 .10354 L
s
.40476 .11985 m
.40851 .11985 L
s
.40476 .13617 m
.40851 .13617 L
s
.40476 .16879 m
.40851 .16879 L
s
.40476 .18511 m
.40851 .18511 L
s
.40476 .20142 m
.40851 .20142 L
s
.40476 .21773 m
.40851 .21773 L
s
.40476 .25036 m
.40851 .25036 L
s
.40476 .26667 m
.40851 .26667 L
s
.40476 .28298 m
.40851 .28298 L
s
.40476 .2993 m
.40851 .2993 L
s
.40476 .33192 m
.40851 .33192 L
s
.40476 .34824 m
.40851 .34824 L
s
.40476 .36455 m
.40851 .36455 L
s
.40476 .38086 m
.40851 .38086 L
s
.40476 .41349 m
.40851 .41349 L
s
.40476 .4298 m
.40851 .4298 L
s
.40476 .44611 m
.40851 .44611 L
s
.40476 .46243 m
.40851 .46243 L
s
.40476 .49505 m
.40851 .49505 L
s
.40476 .51136 m
.40851 .51136 L
s
.40476 .52768 m
.40851 .52768 L
s
.40476 .54399 m
.40851 .54399 L
s
.40476 .0546 m
.40851 .0546 L
s
.40476 .03829 m
.40851 .03829 L
s
.40476 .02198 m
.40851 .02198 L
s
.40476 .00566 m
.40851 .00566 L
s
.40476 .57662 m
.40851 .57662 L
s
.40476 .59293 m
.40851 .59293 L
s
.40476 .60924 m
.40851 .60924 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(coiflet psi of order 2)] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .39717 m
.02976 .39717 L
.03571 .39717 L
.04167 .39718 L
.04762 .39719 L
.05357 .39717 L
.05952 .39716 L
.06548 .39714 L
.07143 .39705 L
.07738 .39717 L
.08333 .39725 L
.08929 .39729 L
.09524 .39728 L
.10119 .39745 L
.10714 .39752 L
.1131 .39773 L
.11905 .39836 L
.125 .39759 L
.13095 .39719 L
.1369 .39687 L
.14286 .39642 L
.14881 .39632 L
.15476 .39607 L
.16071 .39594 L
.16667 .39617 L
.17262 .39519 L
.17857 .39445 L
.18452 .39397 L
.19048 .39382 L
.19643 .3924 L
.20238 .39174 L
.20833 .39007 L
.21429 .38568 L
.22024 .39053 L
.22619 .39311 L
.23214 .39482 L
.2381 .39696 L
.24405 .39861 L
.25 .40019 L
.25595 .40228 L
.2619 .40554 L
.26786 .40478 L
.27381 .40489 L
.27976 .40569 L
.28571 .40709 L
.29167 .40595 L
.29762 .40638 L
.30357 .40468 L
.30952 .39722 L
.31548 .4093 L
Mistroke
.32143 .41637 L
.32738 .42211 L
.33333 .42993 L
.33929 .43258 L
.34524 .43739 L
.35119 .44043 L
.35714 .43801 L
.3631 .45377 L
.36905 .46601 L
.375 .47417 L
.38095 .47756 L
.3869 .49988 L
.39286 .51087 L
.39881 .53679 L
.40476 .60332 L
.41071 .53219 L
.41667 .4955 L
.42262 .47028 L
.42857 .43528 L
.43452 .41943 L
.44048 .39804 L
.44643 .37712 L
.45238 .36146 L
.45833 .32951 L
.46429 .30005 L
.47024 .27592 L
.47619 .26014 L
.48214 .21301 L
.4881 .18421 L
.49405 .13176 L
.5 .01472 L
.50595 .1165 L
.5119 .16377 L
.51786 .19222 L
.52381 .23487 L
.52976 .2519 L
.53571 .27503 L
.54167 .30078 L
.54762 .32751 L
.55357 .34868 L
.55952 .37219 L
.56548 .39381 L
.57143 .40934 L
.57738 .44577 L
.58333 .4705 L
.58929 .50972 L
.59524 .58887 L
.60119 .53289 L
.60714 .51051 L
.6131 .4999 L
Mistroke
.61905 .48092 L
.625 .47639 L
.63095 .46887 L
.6369 .45876 L
.64286 .44538 L
.64881 .44443 L
.65476 .44025 L
.66071 .43531 L
.66667 .43202 L
.67262 .42435 L
.67857 .41877 L
.68452 .41104 L
.69048 .39712 L
.69643 .40406 L
.70238 .40581 L
.70833 .40573 L
.71429 .4069 L
.72024 .40599 L
.72619 .40545 L
.73214 .40544 L
.7381 .40626 L
.74405 .40404 L
.75 .40253 L
.75595 .40141 L
.7619 .40035 L
.76786 .3987 L
.77381 .39748 L
.77976 .39561 L
.78571 .39199 L
.79167 .39429 L
.79762 .39513 L
.80357 .39544 L
.80952 .39611 L
.81548 .39618 L
.82143 .39637 L
.82738 .39668 L
.83333 .3972 L
.83929 .39699 L
.84524 .39696 L
.85119 .39699 L
.85714 .39697 L
.8631 .39706 L
.86905 .3971 L
.875 .39717 L
.88095 .39729 L
.8869 .39722 L
.89286 .3972 L
.89881 .39719 L
.90476 .39717 L
.91071 .39718 L
Mistroke
.91667 .39718 L
.92262 .39718 L
.92857 .39717 L
.93452 .39717 L
.94048 .39717 L
.94643 .39717 L
.95238 .39717 L
.95833 .39717 L
.96429 .39717 L
.97024 .39717 L
.97619 .39717 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],

Cell["Here is the coiflet filter of order 12.", "MathCaption",
  CellTags->{"S1.4.5", "5.20"}],

Cell[CellGroupData[{

Cell["c12 = CoifletFilter[12, 20]", "Input",
  CellLabel->"In[56]:= ",
  CellTags->"S1.4.5"],

Cell[BoxData[
    \({{0.0000507754878363405600550831`13.1521, 
        \(-0.000081170026267848392317662`13.15\), 
        \(-0.00062461304392568347521351`13.1486\), 
        0.001091624712325902847765828`13.1359, 
        0.003539019871540997663382406`13.1237, 
        \(-0.00702940639100272765678817`13.0915\), 
        \(-0.01223157779003791132905569`13.0374\), 
        0.02964577289132383585380858`13.0191, 
        0.0287861143466655651742981`12.8765, 
        \(-0.0996730020460117335982175`12.9703\), 
        \(-0.0487640721756738668193144`12.6974\), 
        0.425819545012838430883531`13.0323, 
        0.768403257579892341610292`13.0624, 
        0.440401191126852746584988`12.9889, 
        \(-0.0581089179726147945540725`12.5036\), 
        \(-0.1122608079648172183040239`12.7425\), 
        0.0418524906761362659007832`12.5229, 
        0.0388813262515107535028465`12.6205, 
        \(-0.0229501532798490639004061`12.612\), 
        \(-0.01265006790873235016115309`12.6192\), 
        0.00959109017590405152717577`12.7506, 
        0.00385765827059368620116524`12.7362, 
        \(-0.00307393950720855875438268`12.9068\), 
        \(-0.001157435013427334610365136`12.9289\), 
        0.000769854730750726571462938`13.0393, 
        0.0003252223590102407565936795`13.0801, 
        \(-0.0001545771992797994893966778`13.1168\), 
        \(-0.0000752800430693596401105292`13.1379\), 
        0.00002473655932872322576360959`13.1451, 
        0.00001313985135402143978436884`13.1504, 
        \(-2.924385559757522634082796`13.1513*^-6\), 
        \(-1.659619295102420642796992`13.1521*^-6\), 
        2.255997852816181758882919`13.1522*^-7, 
        1.350324499356144548151223`13.1522*^-7, 
        \(-8.48714339626243581617419`13.1522*^-9\), 
        \(-5.30908841719689263709505`13.1522*^-9\)}, \(-12\)}\)], "Output",
  CellLabel->"Out[56]= ",
  CellTags->"S1.4.5"]
}, Open  ]],

Cell["We plot the scaling function.", "MathCaption",
  CellTags->{"S1.4.5", "5.21"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[c12, 5], Axes -> False,
Frame -> True, PlotRange -> {{-6, 6}, All},
PlotJoined -> True,
PlotLabel -> \"coiflet phi of order 12\"]\
\>", "Input",
  CellLabel->"In[57]:= ",
  CellTags->"S1.4.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.107624 0.455112 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0166 -24 -4.5 ]
[-0.0125 .0166 0 4.5 ]
[-0.0125 .10762 -6 -4.5 ]
[-0.0125 .10762 0 4.5 ]
[-0.0125 .19865 -18 -4.5 ]
[-0.0125 .19865 0 4.5 ]
[-0.0125 .28967 -18 -4.5 ]
[-0.0125 .28967 0 4.5 ]
[-0.0125 .38069 -18 -4.5 ]
[-0.0125 .38069 0 4.5 ]
[-0.0125 .47171 -18 -4.5 ]
[-0.0125 .47171 0 4.5 ]
[-0.0125 .56274 -6 -4.5 ]
[-0.0125 .56274 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -69 0 ]
[.5 .63053 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(-4)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(4)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0166 m
.00625 .0166 L
s
[(-0.2)] -0.0125 .0166 1 0 Mshowa
0 .10762 m
.00625 .10762 L
s
[(0)] -0.0125 .10762 1 0 Mshowa
0 .19865 m
.00625 .19865 L
s
[(0.2)] -0.0125 .19865 1 0 Mshowa
0 .28967 m
.00625 .28967 L
s
[(0.4)] -0.0125 .28967 1 0 Mshowa
0 .38069 m
.00625 .38069 L
s
[(0.6)] -0.0125 .38069 1 0 Mshowa
0 .47171 m
.00625 .47171 L
s
[(0.8)] -0.0125 .47171 1 0 Mshowa
0 .56274 m
.00625 .56274 L
s
[(1)] -0.0125 .56274 1 0 Mshowa
.125 Mabswid
0 .03936 m
.00375 .03936 L
s
0 .06211 m
.00375 .06211 L
s
0 .08487 m
.00375 .08487 L
s
0 .13038 m
.00375 .13038 L
s
0 .15314 m
.00375 .15314 L
s
0 .17589 m
.00375 .17589 L
s
0 .2214 m
.00375 .2214 L
s
0 .24416 m
.00375 .24416 L
s
0 .26691 m
.00375 .26691 L
s
0 .31242 m
.00375 .31242 L
s
0 .33518 m
.00375 .33518 L
s
0 .35794 m
.00375 .35794 L
s
0 .40345 m
.00375 .40345 L
s
0 .4262 m
.00375 .4262 L
s
0 .44896 m
.00375 .44896 L
s
0 .49447 m
.00375 .49447 L
s
0 .51723 m
.00375 .51723 L
s
0 .53998 m
.00375 .53998 L
s
0 .58549 m
.00375 .58549 L
s
0 .60825 m
.00375 .60825 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0166 m
1 .0166 L
s
.99375 .10762 m
1 .10762 L
s
.99375 .19865 m
1 .19865 L
s
.99375 .28967 m
1 .28967 L
s
.99375 .38069 m
1 .38069 L
s
.99375 .47171 m
1 .47171 L
s
.99375 .56274 m
1 .56274 L
s
.125 Mabswid
.99625 .03936 m
1 .03936 L
s
.99625 .06211 m
1 .06211 L
s
.99625 .08487 m
1 .08487 L
s
.99625 .13038 m
1 .13038 L
s
.99625 .15314 m
1 .15314 L
s
.99625 .17589 m
1 .17589 L
s
.99625 .2214 m
1 .2214 L
s
.99625 .24416 m
1 .24416 L
s
.99625 .26691 m
1 .26691 L
s
.99625 .31242 m
1 .31242 L
s
.99625 .33518 m
1 .33518 L
s
.99625 .35794 m
1 .35794 L
s
.99625 .40345 m
1 .40345 L
s
.99625 .4262 m
1 .4262 L
s
.99625 .44896 m
1 .44896 L
s
.99625 .49447 m
1 .49447 L
s
.99625 .51723 m
1 .51723 L
s
.99625 .53998 m
1 .53998 L
s
.99625 .58549 m
1 .58549 L
s
.99625 .60825 m
1 .60825 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(coiflet phi of order 12)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10765 m
.0026 .10765 L
.00521 .10766 L
.00781 .10766 L
.01042 .10767 L
.01302 .10767 L
.01563 .10767 L
.01823 .10767 L
.02083 .10767 L
.02344 .10767 L
.02604 .10766 L
.02865 .10765 L
.03125 .10764 L
.03385 .10762 L
.03646 .10761 L
.03906 .10759 L
.04167 .10757 L
.04427 .10755 L
.04688 .10752 L
.04948 .1075 L
.05208 .10747 L
.05469 .10744 L
.05729 .10742 L
.0599 .10739 L
.0625 .10737 L
.0651 .10735 L
.06771 .10733 L
.07031 .10732 L
.07292 .1073 L
.07552 .10729 L
.07813 .10728 L
.08073 .10727 L
.08333 .10726 L
.08594 .10726 L
.08854 .10726 L
.09115 .10726 L
.09375 .10727 L
.09635 .10729 L
.09896 .10732 L
.10156 .10735 L
.10417 .1074 L
.10677 .10746 L
.10938 .10754 L
.11198 .10763 L
.11458 .10773 L
.11719 .10785 L
.11979 .10798 L
.1224 .10812 L
.125 .10828 L
.1276 .10845 L
Mistroke
.13021 .10863 L
.13281 .10882 L
.13542 .109 L
.13802 .10918 L
.14063 .10936 L
.14323 .10952 L
.14583 .10966 L
.14844 .10977 L
.15104 .10987 L
.15365 .10993 L
.15625 .10997 L
.15885 .10998 L
.16146 .10996 L
.16406 .10991 L
.16667 .10983 L
.16927 .10971 L
.17188 .10955 L
.17448 .10936 L
.17708 .10913 L
.17969 .10886 L
.18229 .10855 L
.1849 .1082 L
.1875 .10781 L
.1901 .10738 L
.19271 .10691 L
.19531 .1064 L
.19792 .10586 L
.20052 .10527 L
.20313 .10465 L
.20573 .104 L
.20833 .10332 L
.21094 .10262 L
.21354 .10191 L
.21615 .1012 L
.21875 .10052 L
.22135 .09988 L
.22396 .0993 L
.22656 .09879 L
.22917 .09838 L
.23177 .09807 L
.23438 .09789 L
.23698 .09784 L
.23958 .09792 L
.24219 .09814 L
.24479 .09851 L
.2474 .09904 L
.25 .09973 L
.2526 .10057 L
.25521 .10157 L
.25781 .10273 L
Mistroke
.26042 .10403 L
.26302 .10547 L
.26563 .10703 L
.26823 .10869 L
.27083 .11045 L
.27344 .11228 L
.27604 .11418 L
.27865 .11613 L
.28125 .11812 L
.28385 .12015 L
.28646 .12219 L
.28906 .12423 L
.29167 .12624 L
.29427 .12821 L
.29688 .1301 L
.29948 .13187 L
.30208 .13347 L
.30469 .13486 L
.30729 .136 L
.3099 .13685 L
.3125 .13738 L
.3151 .13754 L
.31771 .13731 L
.32031 .13666 L
.32292 .13557 L
.32552 .13403 L
.32813 .13203 L
.33073 .12954 L
.33333 .12656 L
.33594 .12311 L
.33854 .11921 L
.34115 .11488 L
.34375 .11018 L
.34635 .10513 L
.34896 .0998 L
.35156 .09425 L
.35417 .08853 L
.35677 .08272 L
.35938 .07687 L
.36198 .07103 L
.36458 .06525 L
.36719 .05959 L
.36979 .05411 L
.3724 .04888 L
.375 .04397 L
.3776 .03944 L
.38021 .0354 L
.38281 .03192 L
.38542 .02911 L
.38802 .02705 L
Mistroke
.39063 .02584 L
.39323 .02554 L
.39583 .02624 L
.39844 .028 L
.40104 .03091 L
.40365 .03503 L
.40625 .0404 L
.40885 .04708 L
.41146 .05511 L
.41406 .06451 L
.41667 .07531 L
.41927 .0875 L
.42188 .10103 L
.42448 .11587 L
.42708 .13192 L
.42969 .14911 L
.43229 .16734 L
.4349 .1865 L
.4375 .20647 L
.4401 .22713 L
.44271 .24838 L
.44531 .27009 L
.44792 .29217 L
.45052 .31449 L
.45313 .33692 L
.45573 .35933 L
.45833 .38158 L
.46094 .40353 L
.46354 .42503 L
.46615 .44594 L
.46875 .46611 L
.47135 .48539 L
.47396 .50364 L
.47656 .52074 L
.47917 .53657 L
.48177 .551 L
.48438 .5639 L
.48698 .57516 L
.48958 .58466 L
.49219 .59231 L
.49479 .59801 L
.4974 .6017 L
.5 .60332 L
.5026 .60284 L
.50521 .60027 L
.50781 .59564 L
.51042 .58902 L
.51302 .58047 L
.51562 .5701 L
.51823 .55799 L
Mistroke
.52083 .54426 L
.52344 .52902 L
.52604 .5124 L
.52865 .49451 L
.53125 .47548 L
.53385 .45543 L
.53646 .4345 L
.53906 .41285 L
.54167 .39063 L
.54427 .36798 L
.54687 .34506 L
.54948 .322 L
.55208 .29894 L
.55469 .27604 L
.55729 .25342 L
.5599 .2312 L
.5625 .2095 L
.5651 .18845 L
.56771 .16817 L
.57031 .1488 L
.57292 .13045 L
.57552 .11325 L
.57812 .09728 L
.58073 .08265 L
.58333 .06942 L
.58594 .05765 L
.58854 .04735 L
.59115 .03854 L
.59375 .03117 L
.59635 .02523 L
.59896 .02067 L
.60156 .01744 L
.60417 .01548 L
.60677 .01472 L
.60937 .01507 L
.61198 .01647 L
.61458 .01884 L
.61719 .02208 L
.61979 .0261 L
.6224 .0308 L
.625 .03608 L
.6276 .04185 L
.63021 .048 L
.63281 .05447 L
.63542 .06118 L
.63802 .06804 L
.64062 .07499 L
.64323 .08197 L
.64583 .08891 L
.64844 .09575 L
Mistroke
.65104 .10241 L
.65365 .10883 L
.65625 .11492 L
.65885 .12062 L
.66146 .12587 L
.66406 .13061 L
.66667 .13482 L
.66927 .13845 L
.67187 .14149 L
.67448 .14393 L
.67708 .14579 L
.67969 .14709 L
.68229 .14782 L
.6849 .14803 L
.6875 .14773 L
.6901 .14696 L
.69271 .14576 L
.69531 .14418 L
.69792 .14225 L
.70052 .14002 L
.70312 .13755 L
.70573 .1349 L
.70833 .1321 L
.71094 .12921 L
.71354 .12627 L
.71615 .12331 L
.71875 .12035 L
.72135 .11743 L
.72396 .11455 L
.72656 .11174 L
.72917 .10902 L
.73177 .10641 L
.73437 .10392 L
.73698 .10159 L
.73958 .09943 L
.74219 .09747 L
.74479 .09573 L
.7474 .09421 L
.75 .09293 L
.7526 .09189 L
.75521 .0911 L
.75781 .09055 L
.76042 .09023 L
.76302 .09013 L
.76562 .09025 L
.76823 .09058 L
.77083 .0911 L
.77344 .09179 L
.77604 .09264 L
.77865 .09363 L
Mistroke
.78125 .09473 L
.78385 .09591 L
.78646 .09715 L
.78906 .09843 L
.79167 .09972 L
.79427 .101 L
.79687 .10226 L
.79948 .10348 L
.80208 .10466 L
.80469 .10578 L
.80729 .10686 L
.8099 .10787 L
.8125 .10882 L
.8151 .1097 L
.81771 .11051 L
.82031 .11124 L
.82292 .1119 L
.82552 .11247 L
.82812 .11296 L
.83073 .11336 L
.83333 .11368 L
.83594 .11391 L
.83854 .11407 L
.84115 .11414 L
.84375 .11415 L
.84635 .11408 L
.84896 .11394 L
.85156 .11374 L
.85417 .11347 L
.85677 .11315 L
.85937 .11279 L
.86198 .11238 L
.86458 .11194 L
.86719 .11148 L
.86979 .11101 L
.8724 .11053 L
.875 .11006 L
.8776 .1096 L
.88021 .10916 L
.88281 .10874 L
.88542 .10834 L
.88802 .10797 L
.89062 .10762 L
.89323 .1073 L
.89583 .10701 L
.89844 .10675 L
.90104 .10652 L
.90365 .10631 L
.90625 .10613 L
.90885 .10599 L
Mistroke
.91146 .10587 L
.91406 .10577 L
.91667 .1057 L
.91927 .10565 L
.92187 .10563 L
.92448 .10562 L
.92708 .10563 L
.92969 .10567 L
.93229 .10572 L
.9349 .10578 L
.9375 .10587 L
.9401 .10597 L
.94271 .10608 L
.94531 .1062 L
.94792 .10633 L
.95052 .10646 L
.95312 .1066 L
.95573 .10674 L
.95833 .10688 L
.96094 .10701 L
.96354 .10714 L
.96615 .10726 L
.96875 .10737 L
.97135 .10748 L
.97396 .10758 L
.97656 .10767 L
.97917 .10775 L
.98177 .10783 L
.98437 .10789 L
.98698 .10795 L
.98958 .10799 L
.99219 .10803 L
.99479 .10806 L
.9974 .10809 L
1 .10811 L
Mfstroke
1 .10811 m
1 .10811 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],

Cell["This is the wavelet.", "MathCaption",
  CellTags->{"S1.4.5", "5.22"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[c12, 5], Axes -> False,
Frame -> True, PlotRange -> {{-6, 6}, All},
PlotJoined -> True,
PlotLabel -> \"coiflet phi of order 12\"]\
\>", "Input",
  CellLabel->"In[58]:= ",
  CellTags->"S1.4.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.361601 0.27433 [
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08727 -12 -4.5 ]
[-0.0125 .08727 0 4.5 ]
[-0.0125 .22444 -24 -4.5 ]
[-0.0125 .22444 0 4.5 ]
[-0.0125 .3616 -6 -4.5 ]
[-0.0125 .3616 0 4.5 ]
[-0.0125 .49877 -18 -4.5 ]
[-0.0125 .49877 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -69 0 ]
[.5 .63053 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(-4)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-2)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(2)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(4)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08727 m
.00625 .08727 L
s
[(-1)] -0.0125 .08727 1 0 Mshowa
0 .22444 m
.00625 .22444 L
s
[(-0.5)] -0.0125 .22444 1 0 Mshowa
0 .3616 m
.00625 .3616 L
s
[(0)] -0.0125 .3616 1 0 Mshowa
0 .49877 m
.00625 .49877 L
s
[(0.5)] -0.0125 .49877 1 0 Mshowa
.125 Mabswid
0 .1147 m
.00375 .1147 L
s
0 .14214 m
.00375 .14214 L
s
0 .16957 m
.00375 .16957 L
s
0 .197 m
.00375 .197 L
s
0 .25187 m
.00375 .25187 L
s
0 .2793 m
.00375 .2793 L
s
0 .30673 m
.00375 .30673 L
s
0 .33417 m
.00375 .33417 L
s
0 .38903 m
.00375 .38903 L
s
0 .41647 m
.00375 .41647 L
s
0 .4439 m
.00375 .4439 L
s
0 .47133 m
.00375 .47133 L
s
0 .05984 m
.00375 .05984 L
s
0 .0324 m
.00375 .0324 L
s
0 .00497 m
.00375 .00497 L
s
0 .5262 m
.00375 .5262 L
s
0 .55363 m
.00375 .55363 L
s
0 .58106 m
.00375 .58106 L
s
0 .6085 m
.00375 .6085 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.04167 .61428 m
.04167 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.125 .61428 m
.125 .61803 L
s
.20833 .61428 m
.20833 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.375 .61428 m
.375 .61803 L
s
.41667 .61428 m
.41667 .61803 L
s
.45833 .61428 m
.45833 .61803 L
s
.54167 .61428 m
.54167 .61803 L
s
.58333 .61428 m
.58333 .61803 L
s
.625 .61428 m
.625 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.79167 .61428 m
.79167 .61803 L
s
.875 .61428 m
.875 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.95833 .61428 m
.95833 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .08727 m
1 .08727 L
s
.99375 .22444 m
1 .22444 L
s
.99375 .3616 m
1 .3616 L
s
.99375 .49877 m
1 .49877 L
s
.125 Mabswid
.99625 .1147 m
1 .1147 L
s
.99625 .14214 m
1 .14214 L
s
.99625 .16957 m
1 .16957 L
s
.99625 .197 m
1 .197 L
s
.99625 .25187 m
1 .25187 L
s
.99625 .2793 m
1 .2793 L
s
.99625 .30673 m
1 .30673 L
s
.99625 .33417 m
1 .33417 L
s
.99625 .38903 m
1 .38903 L
s
.99625 .41647 m
1 .41647 L
s
.99625 .4439 m
1 .4439 L
s
.99625 .47133 m
1 .47133 L
s
.99625 .05984 m
1 .05984 L
s
.99625 .0324 m
1 .0324 L
s
.99625 .00497 m
1 .00497 L
s
.99625 .5262 m
1 .5262 L
s
.99625 .55363 m
1 .55363 L
s
.99625 .58106 m
1 .58106 L
s
.99625 .6085 m
1 .6085 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(coiflet phi of order 12)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36172 m
.0026 .36171 L
.00521 .3617 L
.00781 .36169 L
.01042 .36167 L
.01302 .36165 L
.01563 .36163 L
.01823 .36161 L
.02083 .36158 L
.02344 .36155 L
.02604 .36152 L
.02865 .36149 L
.03125 .36146 L
.03385 .36142 L
.03646 .36139 L
.03906 .36135 L
.04167 .36131 L
.04427 .36127 L
.04688 .36123 L
.04948 .36119 L
.05208 .36116 L
.05469 .36112 L
.05729 .3611 L
.0599 .36107 L
.0625 .36105 L
.0651 .36104 L
.06771 .36103 L
.07031 .36103 L
.07292 .36104 L
.07552 .36106 L
.07813 .36108 L
.08073 .36111 L
.08333 .36115 L
.08594 .3612 L
.08854 .36126 L
.09115 .36133 L
.09375 .36141 L
.09635 .36149 L
.09896 .36158 L
.10156 .36168 L
.10417 .36179 L
.10677 .3619 L
.10938 .36201 L
.11198 .36213 L
.11458 .36226 L
.11719 .36238 L
.11979 .36251 L
.1224 .36264 L
.125 .36277 L
.1276 .3629 L
Mistroke
.13021 .36302 L
.13281 .36314 L
.13542 .36325 L
.13802 .36335 L
.14063 .36344 L
.14323 .3635 L
.14583 .36355 L
.14844 .36358 L
.15104 .36359 L
.15365 .36358 L
.15625 .36354 L
.15885 .36347 L
.16146 .36338 L
.16406 .36325 L
.16667 .3631 L
.16927 .36293 L
.17188 .36272 L
.17448 .36249 L
.17708 .36223 L
.17969 .36195 L
.18229 .36164 L
.1849 .36132 L
.1875 .36098 L
.1901 .36062 L
.19271 .36025 L
.19531 .35987 L
.19792 .35948 L
.20052 .35909 L
.20313 .3587 L
.20573 .35831 L
.20833 .35792 L
.21094 .35754 L
.21354 .35718 L
.21615 .35683 L
.21875 .35652 L
.22135 .35623 L
.22396 .35598 L
.22656 .35578 L
.22917 .35563 L
.23177 .35553 L
.23438 .35549 L
.23698 .35551 L
.23958 .3556 L
.24219 .35576 L
.24479 .35599 L
.2474 .35629 L
.25 .35667 L
.2526 .35713 L
.25521 .35765 L
.25781 .35825 L
Mistroke
.26042 .35892 L
.26302 .35965 L
.26563 .36045 L
.26823 .3613 L
.27083 .3622 L
.27344 .36314 L
.27604 .36413 L
.27865 .36514 L
.28125 .36618 L
.28385 .36724 L
.28646 .3683 L
.28906 .36937 L
.29167 .37042 L
.29427 .37146 L
.29688 .37246 L
.29948 .37343 L
.30208 .37435 L
.30469 .37522 L
.30729 .37601 L
.3099 .37672 L
.3125 .37733 L
.3151 .37783 L
.31771 .37821 L
.32031 .37845 L
.32292 .37854 L
.32552 .37845 L
.32813 .3782 L
.33073 .37776 L
.33333 .37714 L
.33594 .37634 L
.33854 .37533 L
.34115 .37411 L
.34375 .37266 L
.34635 .37098 L
.34896 .36906 L
.35156 .36692 L
.35417 .36456 L
.35677 .36201 L
.35938 .3593 L
.36198 .35649 L
.36458 .35365 L
.36719 .35082 L
.36979 .34805 L
.3724 .34536 L
.375 .34278 L
.3776 .34035 L
.38021 .3381 L
.38281 .33609 L
.38542 .33434 L
.38802 .33286 L
Mistroke
.39063 .33169 L
.39323 .33085 L
.39583 .33035 L
.39844 .33016 L
.40104 .33017 L
.40365 .33024 L
.40625 .33024 L
.40885 .33003 L
.41146 .32954 L
.41406 .32873 L
.41667 .32756 L
.41927 .32602 L
.42188 .32418 L
.42448 .32212 L
.42708 .31999 L
.42969 .31796 L
.43229 .31615 L
.4349 .31466 L
.4375 .31365 L
.4401 .31337 L
.44271 .31415 L
.44531 .31642 L
.44792 .32055 L
.45052 .32688 L
.45313 .33567 L
.45573 .34708 L
.45833 .36121 L
.46094 .37801 L
.46354 .39721 L
.46615 .41835 L
.46875 .44086 L
.47135 .46411 L
.47396 .48752 L
.47656 .51052 L
.47917 .53245 L
.48177 .55257 L
.48438 .56997 L
.48698 .58373 L
.48958 .59301 L
.49219 .59703 L
.49479 .59511 L
.4974 .5867 L
.5 .57142 L
.5026 .5492 L
.50521 .52042 L
.50781 .48581 L
.51042 .4463 L
.51302 .40298 L
.51562 .35688 L
.51823 .30911 L
Mistroke
.52083 .26088 L
.52344 .2135 L
.52604 .16835 L
.52865 .12683 L
.53125 .09018 L
.53385 .05958 L
.53646 .03617 L
.53906 .02096 L
.54167 .01472 L
.54427 .0178 L
.54687 .03003 L
.54948 .05077 L
.55208 .07915 L
.55469 .11408 L
.55729 .15446 L
.5599 .19907 L
.5625 .24656 L
.5651 .29553 L
.56771 .3446 L
.57031 .39245 L
.57292 .43789 L
.57552 .47978 L
.57812 .51692 L
.58073 .54823 L
.58333 .57284 L
.58594 .5902 L
.58854 .60026 L
.59115 .60332 L
.59375 .59987 L
.59635 .59059 L
.59896 .57626 L
.60156 .55774 L
.60417 .53603 L
.60677 .5121 L
.60937 .48682 L
.61198 .46099 L
.61458 .43528 L
.61719 .41038 L
.61979 .38701 L
.6224 .36589 L
.625 .34758 L
.6276 .33245 L
.63021 .32062 L
.63281 .312 L
.63542 .30641 L
.63802 .30357 L
.64062 .30307 L
.64323 .30448 L
.64583 .30729 L
.64844 .31102 L
Mistroke
.65104 .31533 L
.65365 .31997 L
.65625 .32473 L
.65885 .32941 L
.66146 .33377 L
.66406 .33759 L
.66667 .3407 L
.66927 .34301 L
.67187 .3445 L
.67448 .34522 L
.67708 .34525 L
.67969 .34469 L
.68229 .34372 L
.6849 .34255 L
.6875 .34139 L
.6901 .34043 L
.69271 .33976 L
.69531 .33942 L
.69792 .33945 L
.70052 .33983 L
.70312 .34059 L
.70573 .34174 L
.70833 .34325 L
.71094 .34509 L
.71354 .34723 L
.71615 .34961 L
.71875 .3522 L
.72135 .35495 L
.72396 .35775 L
.72656 .36053 L
.72917 .36318 L
.73177 .36564 L
.73437 .36785 L
.73698 .3698 L
.73958 .37147 L
.74219 .37286 L
.74479 .37396 L
.7474 .37479 L
.75 .37535 L
.7526 .37568 L
.75521 .37578 L
.75781 .37567 L
.76042 .37538 L
.76302 .3749 L
.76562 .37428 L
.76823 .37355 L
.77083 .37273 L
.77344 .37186 L
.77604 .37095 L
.77865 .37004 L
Mistroke
.78125 .36912 L
.78385 .36822 L
.78646 .36735 L
.78906 .36651 L
.79167 .36572 L
.79427 .36496 L
.79687 .36425 L
.79948 .3636 L
.80208 .36299 L
.80469 .36243 L
.80729 .36193 L
.8099 .36147 L
.8125 .36105 L
.8151 .36068 L
.81771 .36034 L
.82031 .36004 L
.82292 .35977 L
.82552 .35954 L
.82812 .35934 L
.83073 .35918 L
.83333 .35904 L
.83594 .35894 L
.83854 .35886 L
.84115 .35881 L
.84375 .35879 L
.84635 .3588 L
.84896 .35883 L
.85156 .35889 L
.85417 .35897 L
.85677 .35908 L
.85937 .3592 L
.86198 .35935 L
.86458 .35951 L
.86719 .35968 L
.86979 .35985 L
.8724 .36003 L
.875 .36022 L
.8776 .36039 L
.88021 .36057 L
.88281 .36074 L
.88542 .3609 L
.88802 .36105 L
.89062 .36119 L
.89323 .36132 L
.89583 .36144 L
.89844 .36155 L
.90104 .36165 L
.90365 .36173 L
.90625 .36181 L
.90885 .36187 L
Mistroke
.91146 .36192 L
.91406 .36197 L
.91667 .362 L
.91927 .36203 L
.92187 .36206 L
.92448 .36207 L
.92708 .36208 L
.92969 .36209 L
.93229 .36208 L
.9349 .36208 L
.9375 .36206 L
.9401 .36205 L
.94271 .36202 L
.94531 .362 L
.94792 .36197 L
.95052 .36194 L
.95312 .36191 L
.95573 .36188 L
.95833 .36185 L
.96094 .36182 L
.96354 .36179 L
.96615 .36176 L
.96875 .36173 L
.97135 .36171 L
.97396 .36169 L
.97656 .36167 L
.97917 .36165 L
.98177 .36163 L
.98437 .36162 L
.98698 .36161 L
.98958 .3616 L
.99219 .36159 L
.99479 .36158 L
.9974 .36158 L
1 .36157 L
Mfstroke
1 .36157 m
1 .36157 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],

Cell[TextData[{
  "1.4.6 ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " in Fourier Space and the Derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.6"]
}], "Subsection",
  CellTags->{"S1.4.6", "6.1"}],

Cell[TextData[{
  "The Fourier transform of the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " and the basic wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " can be generated easily using ",
  StyleBox["Mathematica", "TI"],
  ". Here we simply give some examples to show how it is done.\nFirst, we \
define the response function ",
  StyleBox["response[", "MR"],
  StyleBox["w", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " that gives ",
  Cell[BoxData[
      FormBox[
        RowBox[{"F", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(f\_k\), \(e\^\(-i  k  \[Omega]\)\), 
          "/", \(\@2\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.6"],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("filter"\),
            "TI"], "=", \({{f\_\(-m\), f\_\(-m + 1\), \[Ellipsis]}, -m}\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.6"],
  "."
}], "Text",
  CellTags->{"S1.4.6", "6.2"}],

Cell["This defines the response function.", "MathCaption",
  CellTags->{"S1.4.6", "6.3"}],

Cell["\<\
response[w_, h_]:= Table[E^(-I w k),
{k, h[[2]], h[[2]]+Length[h[[1]]]-1}].h[[1]]/Sqrt[2]\
\>", "Input",
  CellLabel->"In[59]:= ",
  CellTags->"S1.4.6"],

Cell["This gives the Daubechies filter of order 2.", "MathCaption",
  CellTags->{"S1.4.6", "6.4"}],

Cell["d2 = DaubechiesFilter[2];", "Input",
  CellLabel->"In[60]:= ",
  CellTags->"S1.4.6"],

Cell["\<\
The absolute value of the response function of Daubechies filter of \
order 2 is plotted here.\
\>", "MathCaption",
  CellTags->{"S1.4.6", "6.5"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[response[w, d2]]], {w, -Pi, Pi},
AxesLabel -> {\"w\", \"|H(w)|\"}]\
\>", "Input",
  CellLabel->"In[61]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.588604 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -18 0 ]
[.5 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-3)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-2)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-1)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(1)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(2)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(3)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|H\\(w\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01473 L
.02605 .01477 L
.02729 .01485 L
.02846 .01495 L
.03053 .01522 L
.03279 .01561 L
.03527 .01617 L
.0379 .01691 L
.04262 .01863 L
.04749 .02091 L
.05205 .02351 L
.06244 .0311 L
.07305 .04114 L
.08274 .05229 L
.10458 .08374 L
.14429 .15961 L
.18248 .24724 L
.22313 .34468 L
.26226 .43164 L
.28223 .47052 L
.30384 .50709 L
.32294 .53418 L
.34391 .55805 L
.36384 .57521 L
.37486 .58254 L
.38491 .58799 L
.39425 .5921 L
.40442 .59563 L
.41516 .59842 L
.42041 .59948 L
.42533 .60031 L
.43473 .60153 L
.43972 .60201 L
.44511 .60241 L
.45045 .60271 L
.45607 .60294 L
.46087 .60308 L
.46358 .60314 L
.46611 .60318 L
.46857 .60322 L
.47116 .60325 L
.47401 .60327 L
.47664 .60329 L
.47908 .6033 L
.48137 .60331 L
.48268 .60331 L
.48388 .60331 L
.48526 .60331 L
.48657 .60332 L
Mistroke
.48774 .60332 L
.48881 .60332 L
.49003 .60332 L
.49119 .60332 L
.49226 .60332 L
.49324 .60332 L
.49432 .60332 L
.49547 .60332 L
.49662 .60332 L
.49786 .60332 L
.49903 .60332 L
.50009 .60332 L
.50134 .60332 L
.50204 .60332 L
.5027 .60332 L
.50389 .60332 L
.50516 .60332 L
.5063 .60332 L
.50755 .60332 L
.50885 .60332 L
.51006 .60332 L
.5112 .60332 L
.51224 .60332 L
.51343 .60332 L
.51456 .60331 L
.51578 .60331 L
.51708 .60331 L
.51941 .6033 L
.52071 .6033 L
.52192 .60329 L
.52467 .60328 L
.52704 .60326 L
.52928 .60324 L
.53349 .60319 L
.53585 .60315 L
.53803 .6031 L
.54296 .60297 L
.54759 .6028 L
.55257 .60255 L
.55728 .60224 L
.5616 .60189 L
.57163 .60076 L
.57668 .59999 L
.5822 .59898 L
.59246 .59653 L
.60178 .59359 L
.61255 .5892 L
.62273 .58395 L
.64271 .57014 L
.66116 .55284 L
Mistroke
.6799 .53047 L
.70053 .50019 L
.74084 .42523 L
.77963 .33818 L
.82087 .23923 L
.8606 .14921 L
.89882 .0783 L
.9185 .05075 L
.92858 .03945 L
.93948 .02952 L
.94933 .02268 L
.95365 .02033 L
.95839 .01822 L
.96287 .01668 L
.96705 .01564 L
.96936 .01523 L
.97146 .01496 L
.97262 .01486 L
.97389 .01477 L
.97509 .01473 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "The higher the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.4.6"],
  ", the flatter ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " is at ",
  Cell[BoxData[
      \(TraditionalForm\`w = \[Pi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  ". This can be seen clearly by superimposing the two response functions of \
order 2 (solid line) and order 12 (dashed line) together. "
}], "MathCaption",
  CellTags->{"S1.4.6", "6.6"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[{response[w, d2], response[w, d12]}]],
{w, -Pi, Pi}, PlotStyle->{{},Dashing[{0.02}]},
AxesLabel -> {\"w\", \"|H(w)| of order 2 and 12\"}]\
\>", "Input",
  CellLabel->"In[62]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.588604 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -72 0 ]
[.5 .64303 72 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-3)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-2)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-1)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(1)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(2)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(3)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(|H\\(w\\)| of order 2 and 12)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01473 L
.02605 .01477 L
.02729 .01485 L
.02846 .01495 L
.03053 .01522 L
.03279 .01561 L
.03527 .01617 L
.0379 .01691 L
.04262 .01863 L
.04749 .02091 L
.05205 .02351 L
.06244 .0311 L
.07305 .04114 L
.08274 .05229 L
.10458 .08374 L
.14429 .15961 L
.18248 .24724 L
.22313 .34468 L
.26226 .43164 L
.28223 .47052 L
.30384 .50709 L
.32294 .53418 L
.34391 .55805 L
.36384 .57521 L
.37486 .58254 L
.38491 .58799 L
.39425 .5921 L
.40442 .59563 L
.41516 .59842 L
.42041 .59948 L
.42533 .60031 L
.43473 .60153 L
.43972 .60201 L
.44511 .60241 L
.45045 .60271 L
.45607 .60294 L
.46087 .60308 L
.46358 .60314 L
.46611 .60318 L
.46857 .60322 L
.47116 .60325 L
.47401 .60327 L
.47664 .60329 L
.47908 .6033 L
.48137 .60331 L
.48268 .60331 L
.48388 .60331 L
.48526 .60331 L
.48657 .60332 L
Mistroke
.48774 .60332 L
.48881 .60332 L
.49003 .60332 L
.49119 .60332 L
.49226 .60332 L
.49324 .60332 L
.49432 .60332 L
.49547 .60332 L
.49662 .60332 L
.49786 .60332 L
.49903 .60332 L
.50009 .60332 L
.50134 .60332 L
.50204 .60332 L
.5027 .60332 L
.50389 .60332 L
.50516 .60332 L
.5063 .60332 L
.50755 .60332 L
.50885 .60332 L
.51006 .60332 L
.5112 .60332 L
.51224 .60332 L
.51343 .60332 L
.51456 .60331 L
.51578 .60331 L
.51708 .60331 L
.51941 .6033 L
.52071 .6033 L
.52192 .60329 L
.52467 .60328 L
.52704 .60326 L
.52928 .60324 L
.53349 .60319 L
.53585 .60315 L
.53803 .6031 L
.54296 .60297 L
.54759 .6028 L
.55257 .60255 L
.55728 .60224 L
.5616 .60189 L
.57163 .60076 L
.57668 .59999 L
.5822 .59898 L
.59246 .59653 L
.60178 .59359 L
.61255 .5892 L
.62273 .58395 L
.64271 .57014 L
.66116 .55284 L
Mistroke
.6799 .53047 L
.70053 .50019 L
.74084 .42523 L
.77963 .33818 L
.82087 .23923 L
.8606 .14921 L
.89882 .0783 L
.9185 .05075 L
.92858 .03945 L
.93948 .02952 L
.94933 .02268 L
.95365 .02033 L
.95839 .01822 L
.96287 .01668 L
.96705 .01564 L
.96936 .01523 L
.97146 .01496 L
.97262 .01486 L
.97389 .01477 L
.97509 .01473 L
.97619 .01472 L
Mfstroke
[ .02 ] 0 setdash
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04327 .01472 L
.04396 .01472 L
.04519 .01472 L
.04588 .01472 L
.04652 .01472 L
.04722 .01472 L
.04797 .01472 L
.04862 .01472 L
.04933 .01472 L
.05061 .01472 L
.05186 .01472 L
.05302 .01472 L
.05414 .01472 L
.05519 .01472 L
.05634 .01472 L
.05759 .01472 L
.05882 .01472 L
.06012 .01472 L
.06123 .01472 L
.06244 .01472 L
.06315 .01472 L
.06381 .01472 L
.06451 .01472 L
.06529 .01472 L
.06659 .01472 L
.06797 .01472 L
.06923 .01472 L
.07057 .01472 L
.07184 .01472 L
.073 .01472 L
.07443 .01472 L
.07577 .01472 L
Mistroke
.07723 .01472 L
.07878 .01472 L
.08027 .01472 L
.08166 .01472 L
.08292 .01472 L
.08427 .01472 L
.08673 .01472 L
.08812 .01472 L
.08942 .01472 L
.09205 .01472 L
.09352 .01473 L
.09486 .01473 L
.09725 .01473 L
.09985 .01474 L
.10231 .01475 L
.10458 .01477 L
.10701 .01479 L
.10923 .01481 L
.11167 .01485 L
.11423 .0149 L
.11647 .01495 L
.11856 .01501 L
.12328 .01521 L
.12597 .01537 L
.12851 .01556 L
.13326 .01604 L
.13592 .0164 L
.13837 .0168 L
.1439 .01804 L
.14859 .01952 L
.15362 .02169 L
.15837 .02443 L
.1627 .02765 L
.16778 .03247 L
.1733 .03924 L
.17848 .04727 L
.18335 .0565 L
.19274 .07953 L
.2031 .11384 L
.2241 .21177 L
.26276 .43543 L
.27312 .48567 L
.28278 .52383 L
.29284 .55407 L
.29817 .56628 L
.30387 .57672 L
.30918 .58428 L
.31409 .58966 L
.31948 .59409 L
.32223 .59585 L
Mistroke
.32519 .59742 L
.32777 .59856 L
.33014 .59943 L
.33478 .60076 L
.33736 .60131 L
.34019 .60179 L
.34287 .60215 L
.34533 .60242 L
.34789 .60263 L
.35065 .60282 L
.35309 .60294 L
.35566 .60304 L
.35797 .60311 L
.36012 .60316 L
.36249 .6032 L
.36502 .60323 L
.36772 .60326 L
.36925 .60327 L
.37066 .60328 L
.37325 .60329 L
.37455 .6033 L
.37599 .6033 L
.37848 .60331 L
.37988 .60331 L
.38116 .60331 L
.38351 .60331 L
.3847 .60331 L
.386 .60332 L
.38854 .60332 L
.38997 .60332 L
.39129 .60332 L
.39371 .60332 L
.39494 .60332 L
.39628 .60332 L
.39748 .60332 L
.39861 .60332 L
.39992 .60332 L
.40111 .60332 L
.40327 .60332 L
.40449 .60332 L
.40562 .60332 L
.40694 .60332 L
.40837 .60332 L
.40972 .60332 L
.41095 .60332 L
.41207 .60332 L
.4133 .60332 L
.41458 .60332 L
.41577 .60332 L
.41718 .60332 L
Mistroke
.41851 .60332 L
.4197 .60332 L
.42099 .60332 L
.42166 .60332 L
.4224 .60332 L
.42312 .60332 L
.4239 .60332 L
.42462 .60332 L
.42528 .60332 L
.42658 .60332 L
.42786 .60332 L
.42907 .60332 L
.43016 .60332 L
.43134 .60332 L
.43262 .60332 L
.43327 .60332 L
.43398 .60332 L
.43524 .60332 L
.43642 .60332 L
.4376 .60332 L
.43872 .60332 L
.43973 .60332 L
.44083 .60332 L
.44202 .60332 L
.44328 .60332 L
.44436 .60332 L
.44555 .60332 L
.44686 .60332 L
.44752 .60332 L
.44824 .60332 L
.4507 .60332 L
.45624 .60332 L
.46627 .60332 L
.47156 .60332 L
.47654 .60332 L
.48108 .60332 L
.48588 .60332 L
.48836 .60332 L
.4911 .60332 L
.4923 .60332 L
.49359 .60332 L
.4948 .60332 L
.49593 .60332 L
.49666 .60332 L
.49732 .60332 L
.49806 .60332 L
.49885 .60332 L
.49953 .60332 L
.50027 .60332 L
.50097 .60332 L
Mistroke
.50162 .60332 L
.50283 .60332 L
.50351 .60332 L
.50415 .60332 L
.50545 .60332 L
.50682 .60332 L
.50943 .60332 L
.51184 .60332 L
.5173 .60332 L
.52201 .60332 L
.52721 .60332 L
.53625 .60332 L
.54577 .60332 L
.54811 .60332 L
.5506 .60332 L
.55134 .60332 L
.55204 .60332 L
.55334 .60332 L
.55456 .60332 L
.55588 .60332 L
.557 .60332 L
.55823 .60332 L
.55951 .60332 L
.56071 .60332 L
.56183 .60332 L
.56285 .60332 L
.56403 .60332 L
.56515 .60332 L
.56634 .60332 L
.56766 .60332 L
.56832 .60332 L
.56904 .60332 L
.57033 .60332 L
.57155 .60332 L
.57284 .60332 L
.57393 .60332 L
.57514 .60332 L
.57587 .60332 L
.57656 .60332 L
.57786 .60332 L
.57858 .60332 L
.57925 .60332 L
.58077 .60332 L
.58198 .60332 L
.58332 .60332 L
.58471 .60332 L
.58601 .60332 L
.58726 .60332 L
.58859 .60332 L
.58984 .60332 L
Mistroke
.59098 .60332 L
.59232 .60332 L
.59377 .60332 L
.59514 .60332 L
.5964 .60332 L
.59758 .60332 L
.59869 .60332 L
.5999 .60332 L
.6012 .60332 L
.60256 .60332 L
.60385 .60332 L
.605 .60332 L
.60627 .60332 L
.6085 .60332 L
.60973 .60332 L
.61088 .60332 L
.61293 .60332 L
.61408 .60332 L
.61514 .60331 L
.61739 .60331 L
.61866 .60331 L
.61984 .60331 L
.62224 .60331 L
.62358 .6033 L
.62479 .6033 L
.6271 .60329 L
.62964 .60328 L
.6323 .60326 L
.63478 .60324 L
.6371 .60321 L
.63922 .60317 L
.64166 .60312 L
.64398 .60305 L
.64649 .60296 L
.64915 .60283 L
.65166 .60267 L
.65394 .60249 L
.65662 .60221 L
.65953 .60184 L
.66227 .60138 L
.66478 .60086 L
.6695 .59955 L
.67214 .59859 L
.67455 .59755 L
.67923 .59496 L
.68365 .59169 L
.6888 .58666 L
.69356 .58062 L
.69879 .57217 L
.70433 .56086 L
Mistroke
.71373 .53543 L
.72385 .4986 L
.74214 .40891 L
.76183 .29291 L
.78334 .17307 L
.7933 .12802 L
.80391 .08957 L
.81393 .06242 L
.82302 .04475 L
.82789 .03763 L
.83304 .03162 L
.83748 .0275 L
.84225 .02403 L
.84738 .0212 L
.85217 .01925 L
.8551 .01832 L
.85787 .01759 L
.86055 .01701 L
.86307 .01656 L
.86765 .01593 L
.87008 .01568 L
.87271 .01546 L
.87531 .01529 L
.87805 .01514 L
.88039 .01505 L
.88296 .01496 L
.88537 .0149 L
.88757 .01486 L
.8901 .01482 L
.89249 .01479 L
.89471 .01477 L
.89675 .01476 L
.899 .01475 L
.90137 .01474 L
.9039 .01473 L
.90629 .01473 L
.90845 .01472 L
.9108 .01472 L
.91213 .01472 L
.91334 .01472 L
.91464 .01472 L
.91605 .01472 L
.91736 .01472 L
.91856 .01472 L
.9197 .01472 L
.92093 .01472 L
.92208 .01472 L
.92312 .01472 L
.92517 .01472 L
.92632 .01472 L
Mistroke
.92757 .01472 L
.92874 .01472 L
.92983 .01472 L
.93095 .01472 L
.932 .01472 L
.93315 .01472 L
.93439 .01472 L
.93562 .01472 L
.93692 .01472 L
.93803 .01472 L
.93923 .01472 L
.94044 .01472 L
.94155 .01472 L
.94277 .01472 L
.94405 .01472 L
.94517 .01472 L
.94622 .01472 L
.94737 .01472 L
.9486 .01472 L
.94969 .01472 L
.95088 .01472 L
.95201 .01472 L
.95305 .01472 L
.95408 .01472 L
.95502 .01472 L
.95609 .01472 L
.95711 .01472 L
.95822 .01472 L
.95944 .01472 L
.96071 .01472 L
.96189 .01472 L
.963 .01472 L
.96401 .01472 L
.96518 .01472 L
.96628 .01472 L
.96748 .01472 L
.96875 .01472 L
.96984 .01472 L
.97103 .01472 L
.97232 .01472 L
.97304 .01472 L
.9737 .01472 L
.97497 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "The response function ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " associated with the highpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " can be obtained similarly. Note that the graph of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] G \((\[Omega])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.4.6"],
  " is simply that of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] H \((w + \[Pi])\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.4.6"],
  ", that is, the graph of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] H \((w)\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S1.4.6"],
  " translated by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  ". On the other hand, we can also directly input the filter ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " into the function ",
  StyleBox["response", "MR"],
  " to get ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " is obtained by using ",
  StyleBox["HighpassFilter[", "MR"],
  StyleBox["h", "TI"],
  StyleBox["]", "MR"],
  "."
}], "Text",
  CellTags->{"S1.4.6", "6.7"}],

Cell["This shows the response function of the highpass filter.", "MathCaption",
  CellTags->{"S1.4.6", "6.8"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[response[w, HighpassFilter[d2]]]],
{w, -Pi, Pi},
AxesLabel -> {\"w\", \"highpass filter |G(w)|\"}]\
\>", "Input",
  CellLabel->"In[63]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.151576 0.0147151 0.588604 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -66 0 ]
[.5 .64303 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-3)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-2)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-1)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(1)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(2)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(3)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(highpass filter |G\\(w\\)|)] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60332 L
.02846 .60332 L
.02954 .60332 L
.03053 .60332 L
.03163 .60332 L
.03279 .60332 L
.03395 .60332 L
.0352 .60332 L
.03638 .60332 L
.03746 .60332 L
.03873 .60331 L
.04011 .60331 L
.04141 .60331 L
.04262 .60331 L
.04521 .6033 L
.04765 .60329 L
.04984 .60327 L
.05221 .60325 L
.05481 .60322 L
.05754 .60319 L
.06244 .60309 L
.06507 .60302 L
.06746 .60295 L
.07283 .60274 L
.07781 .60247 L
.08253 .60214 L
.08802 .60164 L
.09309 .60107 L
.09862 .60029 L
.10458 .59926 L
.11421 .59709 L
.12324 .5944 L
.13399 .59026 L
.14385 .58545 L
.16277 .57311 L
.18347 .55442 L
.20308 .5313 L
.22403 .50069 L
.26553 .42339 L
.30551 .33327 L
.34398 .24091 L
.3849 .14819 L
.40525 .10801 L
.4243 .0757 L
.44373 .04904 L
.46219 .03041 L
.47189 .02343 L
Mistroke
.47738 .02037 L
.48247 .01812 L
.48719 .01653 L
.48941 .01596 L
.49145 .01553 L
.49382 .01514 L
.49506 .01499 L
.49638 .01486 L
.49752 .01478 L
.49859 .01474 L
.49976 .01472 L
.50101 .01473 L
.50223 .01477 L
.50293 .01481 L
.50358 .01486 L
.5049 .01498 L
.50631 .01516 L
.50887 .01559 L
.51121 .01611 L
.51661 .01777 L
.52229 .02021 L
.53191 .02593 L
.54242 .03442 L
.56207 .05628 L
.58304 .08747 L
.62459 .16853 L
.66462 .26152 L
.70314 .35364 L
.74411 .44312 L
.76451 .48143 L
.78357 .51249 L
.80304 .53909 L
.82151 .55944 L
.84183 .57651 L
.86038 .58764 L
.87002 .59193 L
.88027 .59552 L
.88901 .59789 L
.89868 .59985 L
.90359 .60062 L
.90876 .60129 L
.918 .60218 L
.92316 .60252 L
.92795 .60277 L
.93322 .60297 L
.93617 .60306 L
.93885 .60312 L
.94337 .6032 L
.94565 .60323 L
.94816 .60326 L
Mistroke
.9503 .60327 L
.9526 .60329 L
.95477 .6033 L
.95676 .6033 L
.95796 .60331 L
.95923 .60331 L
.96033 .60331 L
.96152 .60331 L
.96293 .60332 L
.96425 .60332 L
.96554 .60332 L
.96672 .60332 L
.96786 .60332 L
.96892 .60332 L
.97008 .60332 L
.97133 .60332 L
.97263 .60332 L
.97387 .60332 L
.97498 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "Iterating the frequency space equivalents of the dilation and wavelet \
equations (",
  ButtonBox["2.7",
    ButtonData:>{"Wavelets 1.2.5", "5.9"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["2.8",
    ButtonData:>{"Wavelets 1.2.5", "5.13"},
    ButtonStyle->"AddOnsLink"],
  "), we have "
}], "Text",
  CellTags->{"S1.4.6", "6.9"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\&^\), \((\[Omega])\), "=", 
        UnderoverscriptBox["\[Product]", \(j = 1\), "\[Infinity]",
          LimitsPositioning->True], "H", \((\[Omega]\/2\^j)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.6", "6.10"}],

Cell["and ", "Text",
  CellTags->{"S1.4.6", "6.11"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\&^\), \((\[Omega])\), "=", "G", \((\[Omega]\/2)\), 
        UnderoverscriptBox["\[Product]", \(j = 2\), "\[Infinity]",
          LimitsPositioning->True], "H", \((\[Omega]\/2\^j)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.4.6", "6.12"}],

Cell[TextData[{
  "In practice, we approximate the infinite product by a finite product. Here \
is the ",
  StyleBox["Mathematica", "TI"],
  " implementation. "
}], "Text",
  CellTags->{"S1.4.6", "6.13"}],

Cell["\<\
This is the Fourier transform of Daubechies scaling function of \
order 2.\
\>", "MathCaption",
  CellTags->{"S1.4.6", "6.14"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[Product[response[w/2^i, d2],
{i, 10}]]], {w, -10Pi, 10Pi}, PlotRange -> All,
AxesLabel -> {\"w\", \"Daubechies |phihat(w)| of order 2\"}]\
\>", "Input",
  CellLabel->"In[64]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0151576 0.0147151 0.588604 [
[.04527 .00222 -9 -9 ]
[.04527 .00222 9 0 ]
[.19685 .00222 -9 -9 ]
[.19685 .00222 9 0 ]
[.34842 .00222 -9 -9 ]
[.34842 .00222 9 0 ]
[.65158 .00222 -6 -9 ]
[.65158 .00222 6 0 ]
[.80315 .00222 -6 -9 ]
[.80315 .00222 6 0 ]
[.95473 .00222 -6 -9 ]
[.95473 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -99 0 ]
[.5 .64303 99 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-30)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-20)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-10)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(10)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(20)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(30)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Daubechies |phihat\\(w\\)| of order 2)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.04262 .02091 L
.0522 .026 L
.05496 .02723 L
.05756 .02821 L
.0599 .02892 L
.06122 .02923 L
.06244 .02948 L
.0637 .02967 L
.06436 .02975 L
.06507 .02982 L
.06582 .02987 L
.06653 .0299 L
.06716 .02992 L
.06786 .02991 L
.06911 .02986 L
.06981 .02981 L
.07045 .02975 L
.07169 .02959 L
.07286 .0294 L
.07528 .02886 L
.07751 .02822 L
.08255 .02638 L
.09395 .02123 L
.09951 .01886 L
.10458 .01706 L
.10681 .01641 L
.10925 .01581 L
.11135 .0154 L
.11366 .01505 L
.11493 .01491 L
.11612 .01482 L
.11737 .01475 L
.11808 .01473 L
.11872 .01472 L
.11981 .01472 L
.121 .01476 L
.12225 .01484 L
.1234 .01494 L
.1247 .0151 L
.1261 .01532 L
.12864 .01584 L
.13111 .01651 L
.13339 .01726 L
.13858 .01944 L
.14407 .0224 L
.1535 .02838 L
.1587 .03162 L
.16127 .03305 L
.16364 .03421 L
Mistroke
.16604 .03519 L
.16822 .03588 L
.16947 .03619 L
.17064 .0364 L
.17187 .03656 L
.17257 .03661 L
.17321 .03664 L
.17426 .03664 L
.17524 .03658 L
.17632 .03646 L
.17747 .03626 L
.17867 .03597 L
.17982 .03562 L
.18195 .03479 L
.20021 .02133 L
.20521 .01774 L
.20658 .01694 L
.20802 .01622 L
.20927 .0157 L
.2106 .01525 L
.21186 .01495 L
.21301 .01478 L
.21416 .01472 L
.21525 .01475 L
.21652 .01492 L
.21769 .0152 L
.21898 .01565 L
.22034 .01627 L
.22269 .01772 L
.22522 .01979 L
.22978 .02472 L
.24015 .03947 L
.24579 .04756 L
.24857 .05105 L
.25114 .05384 L
.25342 .05588 L
.25594 .05759 L
.25725 .05824 L
.25848 .05869 L
.25977 .059 L
.2605 .0591 L
.26117 .05915 L
.26244 .0591 L
.26365 .0589 L
.26473 .05859 L
.2659 .05813 L
.26718 .05748 L
.26853 .05662 L
.27096 .05468 L
.2753 .0501 L
Mistroke
.28007 .04388 L
.29088 .02863 L
.29601 .02247 L
.30076 .01812 L
.30307 .0166 L
.30425 .01599 L
.30553 .01545 L
.30626 .01521 L
.30693 .01503 L
.30825 .01479 L
.30945 .01472 L
.31072 .01478 L
.31185 .01498 L
.31306 .01532 L
.3142 .01578 L
.31524 .01632 L
.31778 .01812 L
.32019 .02045 L
.32271 .02358 L
.32538 .02765 L
.33019 .03683 L
.34107 .06427 L
.35045 .08901 L
.35302 .09469 L
.35572 .09974 L
.35803 .10313 L
.35934 .10463 L
.36056 .10574 L
.3617 .1065 L
.36294 .10702 L
.36411 .10721 L
.36519 .10711 L
.36616 .1068 L
.36723 .10621 L
.36835 .10532 L
.3694 .10423 L
.37178 .10085 L
.37395 .09671 L
.37884 .08412 L
.38806 .05277 L
.39312 .03562 L
.3956 .02836 L
.39788 .02277 L
.39918 .02015 L
.4006 .01781 L
.40129 .01689 L
.40202 .01608 L
.4028 .01542 L
.40353 .015 L
.40419 .01478 L
Mistroke
.40491 .01472 L
.40621 .01512 L
.40747 .01616 L
.40864 .01772 L
.40983 .0199 L
.41095 .02252 L
.41349 .03057 L
.41596 .04129 L
.41862 .05599 L
.42386 .09419 L
.42872 .13957 L
.43975 .26644 L
.44939 .38392 L
.45983 .49153 L
.46533 .5338 L
.46775 .54877 L
.47039 .56271 L
.47273 .57291 L
.47523 .58181 L
.47788 .58909 L
.48035 .59417 L
.48274 .59772 L
.48409 .59922 L
.48534 .60033 L
.48653 .60116 L
.48764 .60177 L
.4888 .60227 L
.49008 .60267 L
.49116 .6029 L
.4923 .60308 L
.49328 .60318 L
.49435 .60325 L
.4955 .60329 L
.49673 .60331 L
.49789 .60332 L
.49895 .60332 L
.50014 .60332 L
.50126 .60332 L
.50248 .60332 L
.5038 .6033 L
.50445 .60329 L
.50517 .60327 L
.50648 .6032 L
.50775 .60307 L
.50893 .60289 L
.51013 .60261 L
.51126 .60224 L
.51228 .60181 L
.51338 .60122 L
.51458 .60038 L
Mistroke
.51585 .59927 L
.51813 .59657 L
.5206 .59239 L
.52326 .58621 L
.52576 .57851 L
.52804 .56974 L
.53363 .54049 L
.53892 .50208 L
.54859 .40692 L
.55886 .28365 L
.56848 .16929 L
.57729 .08481 L
.58187 .05305 L
.58417 .04067 L
.58668 .02996 L
.58921 .0221 L
.59063 .01897 L
.59192 .01689 L
.59312 .01559 L
.59443 .01484 L
.59566 .01475 L
.59679 .01516 L
.59785 .01596 L
.59898 .01723 L
.60005 .0188 L
.60103 .02052 L
.60568 .03198 L
.61508 .06398 L
.61987 .08018 L
.6225 .08798 L
.62497 .0943 L
.62724 .0991 L
.62932 .10257 L
.63043 .10403 L
.63164 .10531 L
.63285 .10627 L
.63413 .10692 L
.6348 .10711 L
.63553 .1072 L
.63685 .10708 L
.63814 .10659 L
.63932 .10583 L
.64061 .10469 L
.64202 .10307 L
.64488 .09871 L
.65004 .08785 L
.65488 .07538 L
.66527 .04742 L
.67038 .03561 L
.67513 .0268 L
Mistroke
.67942 .02089 L
.68182 .01846 L
.68399 .01679 L
.68524 .01606 L
.68638 .01553 L
.68764 .0151 L
.68828 .01495 L
.68897 .01482 L
.69014 .01472 L
.6914 .01476 L
.69258 .01492 L
.69366 .01519 L
.69484 .01559 L
.69595 .01608 L
.69847 .01757 L
.70093 .01949 L
.70358 .02203 L
.71275 .03362 L
.72267 .04756 L
.72538 .0509 L
.72829 .05397 L
.73103 .0563 L
.73351 .05785 L
.73476 .05841 L
.73545 .05865 L
.73609 .05884 L
.73722 .05906 L
.73846 .05915 L
.73916 .05913 L
.73981 .05907 L
.74105 .05883 L
.74174 .05863 L
.74238 .05839 L
.74383 .05772 L
.7463 .0561 L
.74854 .05415 L
.75356 .04841 L
.76456 .03244 L
.76938 .02578 L
.77193 .02271 L
.77466 .01991 L
.7772 .0178 L
.77952 .01634 L
.78064 .01581 L
.78185 .01534 L
.78299 .01503 L
.78405 .01483 L
.78523 .01472 L
.78633 .01473 L
.78755 .01485 L
Mistroke
.78885 .01511 L
.78951 .01528 L
.79022 .01551 L
.79152 .01601 L
.79395 .01724 L
.79918 .02085 L
.80475 .02548 L
.80963 .02949 L
.81479 .03308 L
.81734 .03446 L
.81869 .03506 L
.82014 .0356 L
.82147 .036 L
.82268 .03629 L
.8239 .03649 L
.82506 .0366 L
.8257 .03663 L
.8264 .03664 L
.82714 .03663 L
.82783 .03659 L
.82906 .03645 L
.82975 .03634 L
.83038 .03622 L
.83321 .03545 L
.83463 .03494 L
.83618 .03429 L
.84662 .0283 L
.85635 .02215 L
.86139 .01946 L
.86404 .01826 L
.86686 .01717 L
.86931 .01638 L
.87202 .01569 L
.8732 .01545 L
.87448 .01522 L
.8756 .01506 L
.87678 .01492 L
.87802 .01482 L
.87916 .01475 L
.87987 .01473 L
.88053 .01472 L
.88176 .01472 L
.88295 .01476 L
.88403 .01483 L
.88523 .01493 L
.88649 .01507 L
.88868 .0154 L
.89072 .01581 L
.89537 .01704 L
.91402 .02489 L
Mistroke
.91913 .02705 L
.92193 .02805 L
.92456 .02882 L
.92679 .02933 L
.92804 .02955 L
.92919 .02971 L
.93038 .02983 L
.93168 .0299 L
.93234 .02991 L
.93304 .02991 L
.9343 .02987 L
.935 .02981 L
.93573 .02974 L
.93705 .02956 L
.93847 .0293 L
.94004 .02893 L
.94283 .02807 L
.94544 .02706 L
.95556 .02191 L
.96054 .01924 L
.96527 .01706 L
.96788 .01611 L
.96925 .0157 L
.97072 .01533 L
.97207 .01507 L
.9733 .01489 L
.97453 .01477 L
.97569 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell["\<\
This shows the absolute value of the mother wavelet in the \
frequency domain.\
\>", "MathCaption",
  CellTags->{"S1.4.6", "6.15"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[response[w/2, HighpassFilter[d2]]*
Product[response[w/2^i, d2], {i, 2, 10}]]],
{w, -10Pi, 10Pi}, PlotRange -> All,
AxesLabel -> {\"w\", \"Daubechies |psihat(w)| of order 2\"}]\
\>", "Input",
  CellLabel->"In[65]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0151576 0.0147151 0.695028 [
[.04527 .00222 -9 -9 ]
[.04527 .00222 9 0 ]
[.19685 .00222 -9 -9 ]
[.19685 .00222 9 0 ]
[.34842 .00222 -9 -9 ]
[.34842 .00222 9 0 ]
[.65158 .00222 -6 -9 ]
[.65158 .00222 6 0 ]
[.80315 .00222 -6 -9 ]
[.80315 .00222 6 0 ]
[.95473 .00222 -6 -9 ]
[.95473 .00222 6 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 10 6.28125 ]
[.4875 .15372 -18 -4.5 ]
[.4875 .15372 0 4.5 ]
[.4875 .29273 -18 -4.5 ]
[.4875 .29273 0 4.5 ]
[.4875 .43173 -18 -4.5 ]
[.4875 .43173 0 4.5 ]
[.4875 .57074 -18 -4.5 ]
[.4875 .57074 0 4.5 ]
[.5 .64303 -101 0 ]
[.5 .64303 101 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-30)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-20)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-10)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(10)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(20)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(30)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .15372 m
.50625 .15372 L
s
[(0.2)] .4875 .15372 1 0 Mshowa
.5 .29273 m
.50625 .29273 L
s
[(0.4)] .4875 .29273 1 0 Mshowa
.5 .43173 m
.50625 .43173 L
s
[(0.6)] .4875 .43173 1 0 Mshowa
.5 .57074 m
.50625 .57074 L
s
[(0.8)] .4875 .57074 1 0 Mshowa
.125 Mabswid
.5 .04947 m
.50375 .04947 L
s
.5 .08422 m
.50375 .08422 L
s
.5 .11897 m
.50375 .11897 L
s
.5 .18847 m
.50375 .18847 L
s
.5 .22322 m
.50375 .22322 L
s
.5 .25797 m
.50375 .25797 L
s
.5 .32748 m
.50375 .32748 L
s
.5 .36223 m
.50375 .36223 L
s
.5 .39698 m
.50375 .39698 L
s
.5 .46648 m
.50375 .46648 L
s
.5 .50123 m
.50375 .50123 L
s
.5 .53599 m
.50375 .53599 L
s
.5 .60549 m
.50375 .60549 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Daubechies) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.000 12.813 moveto
(\\310) show
135.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(psihat) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.000 12.813 moveto
(H) show
177.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
183.000 12.813 moveto
(L) show
189.000 12.813 moveto
(\\310) show
201.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(of) show
219.000 12.813 moveto
(order) show
255.000 12.813 moveto
(2) show
261.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .06717 m
.06244 .04218 L
.07216 .03158 L
.0775 .02649 L
.08255 .0225 L
.08542 .02064 L
.08852 .01896 L
.09111 .01782 L
.09396 .01682 L
.09664 .01611 L
.09801 .01581 L
.09948 .01555 L
.10086 .01535 L
.10211 .0152 L
.10341 .01507 L
.10458 .01498 L
.10583 .0149 L
.10701 .01484 L
.10826 .0148 L
.1089 .01478 L
.10961 .01476 L
.11079 .01474 L
.11204 .01473 L
.1132 .01472 L
.11428 .01472 L
.11494 .01472 L
.11565 .01472 L
.11695 .01472 L
.11822 .01472 L
.11939 .01472 L
.12065 .01472 L
.12137 .01472 L
.12205 .01472 L
.12275 .01472 L
.1234 .01472 L
.12412 .01472 L
.12487 .01472 L
.12608 .01473 L
.12717 .01474 L
.12844 .01477 L
.12964 .0148 L
.13075 .01484 L
.13177 .01489 L
.13289 .01496 L
.13408 .01505 L
.13527 .01517 L
.13656 .01533 L
.13887 .01572 L
.14029 .01603 L
.14163 .01638 L
Mistroke
.14415 .01722 L
.14675 .01836 L
.1492 .01971 L
.15376 .02309 L
.15868 .02806 L
.164 .03504 L
.1824 .06877 L
.19186 .08717 L
.20198 .10372 L
.2078 .1112 L
.21309 .11666 L
.21564 .1188 L
.21842 .12073 L
.21969 .12146 L
.22103 .12213 L
.22219 .12261 L
.22345 .12303 L
.22464 .12332 L
.22589 .1235 L
.22705 .12356 L
.22813 .12351 L
.2294 .12332 L
.23056 .12302 L
.2312 .1228 L
.2319 .12251 L
.23316 .12187 L
.23546 .12027 L
.2379 .11797 L
.24226 .11225 L
.24737 .10307 L
.25214 .09243 L
.26299 .0643 L
.26799 .05154 L
.27343 .03923 L
.27822 .03038 L
.28085 .02645 L
.28332 .02335 L
.28571 .02091 L
.2879 .01911 L
.29033 .01756 L
.29169 .01689 L
.29295 .01637 L
.29502 .01571 L
.29612 .01546 L
.29729 .01524 L
.29852 .01506 L
.29969 .01494 L
.30073 .01486 L
.30187 .0148 L
.3031 .01476 L
Mistroke
.30422 .01474 L
.30552 .01472 L
.30675 .01472 L
.30788 .01472 L
.30893 .01472 L
.31009 .01472 L
.31132 .01472 L
.31202 .01472 L
.31267 .01472 L
.31338 .01472 L
.31413 .01473 L
.31539 .01475 L
.31611 .01477 L
.31677 .01479 L
.31802 .01486 L
.31916 .01495 L
.32048 .01511 L
.32172 .01533 L
.32293 .01561 L
.32426 .01601 L
.32565 .01658 L
.32696 .01725 L
.32929 .01887 L
.3318 .02134 L
.33458 .02516 L
.33752 .03064 L
.34002 .03666 L
.34275 .04481 L
.34805 .06567 L
.35304 .09177 L
.36238 .15593 L
.38334 .33349 L
.40167 .47021 L
.41208 .53577 L
.41717 .56325 L
.42182 .58367 L
.42418 .5917 L
.42542 .59518 L
.42674 .59825 L
.42802 .60056 L
.42917 .60207 L
.43032 .603 L
.43141 .60332 L
.43267 .60299 L
.4333 .60253 L
.43399 .6018 L
.43522 .59991 L
.43637 .59745 L
.43772 .59365 L
.43895 .58934 L
Mistroke
.44171 .57668 L
.44441 .56037 L
.4469 .5419 L
.45253 .48902 L
.46276 .36303 L
.47254 .22912 L
.47794 .16037 L
.48307 .10378 L
.48782 .06201 L
.49051 .04374 L
.49301 .0306 L
.49419 .02569 L
.49531 .02188 L
.49632 .01914 L
.49741 .01692 L
.49859 .01536 L
.49985 .01472 L
.50092 .01499 L
.5021 .01616 L
.50331 .0183 L
.50463 .02172 L
.50588 .02597 L
.50703 .03078 L
.51154 .05726 L
.51387 .07552 L
.51644 .09897 L
.52166 .15554 L
.53992 .39872 L
.54934 .5082 L
.55408 .54952 L
.55679 .56811 L
.55926 .5816 L
.56198 .59267 L
.56348 .59706 L
.56417 .59868 L
.56489 .60012 L
.5662 .60203 L
.56741 .60303 L
.56871 .60331 L
.56945 .60311 L
.57014 .6027 L
.57143 .60137 L
.57265 .59944 L
.57375 .59719 L
.57495 .59421 L
.57763 .58571 L
.58011 .57584 L
.5907 .51921 L
.60067 .45437 L
.61928 .31153 L
Mistroke
.63769 .15539 L
.64273 .11855 L
.64813 .08508 L
.65323 .06001 L
.65787 .04279 L
.66043 .03549 L
.66279 .02999 L
.66538 .02522 L
.66813 .02142 L
.67051 .01903 L
.67275 .01742 L
.67403 .01673 L
.6752 .01621 L
.67649 .01577 L
.67784 .01542 L
.67916 .01517 L
.68037 .015 L
.68103 .01493 L
.68175 .01487 L
.68306 .0148 L
.68429 .01476 L
.68559 .01473 L
.68669 .01472 L
.68791 .01472 L
.68865 .01472 L
.68935 .01472 L
.69066 .01472 L
.69139 .01472 L
.69206 .01472 L
.69281 .01472 L
.6936 .01472 L
.6949 .01472 L
.69613 .01474 L
.69682 .01476 L
.69747 .01477 L
.69817 .0148 L
.69892 .01484 L
.70015 .01493 L
.70084 .01499 L
.70148 .01506 L
.70266 .01523 L
.7039 .01546 L
.70606 .01603 L
.70729 .01646 L
.70844 .01694 L
.711 .01835 L
.71335 .02008 L
.71605 .02266 L
.71862 .02574 L
.72318 .03274 L
Mistroke
.7274 .04096 L
.73698 .06422 L
.74755 .09168 L
.75274 .10328 L
.75751 .11189 L
.76186 .1177 L
.76405 .11985 L
.76645 .12163 L
.76771 .12233 L
.76886 .12282 L
.7695 .12304 L
.77019 .12323 L
.77145 .12346 L
.77263 .12356 L
.77387 .12352 L
.77494 .12339 L
.77612 .12315 L
.77733 .12278 L
.77847 .12235 L
.78104 .12106 L
.78354 .11941 L
.78621 .11727 L
.79547 .10719 L
.8064 .09031 L
.81633 .07133 L
.82644 .0513 L
.83196 .0414 L
.83714 .03342 L
.84191 .02738 L
.84627 .02306 L
.85111 .01952 L
.85378 .0181 L
.85632 .01705 L
.85875 .01628 L
.86095 .01576 L
.86217 .01553 L
.86348 .01533 L
.86462 .01519 L
.86587 .01506 L
.86696 .01497 L
.86812 .0149 L
.86934 .01484 L
.87049 .0148 L
.87163 .01477 L
.87271 .01475 L
.87367 .01473 L
.87473 .01473 L
.87597 .01472 L
.87713 .01472 L
.87841 .01472 L
Mistroke
.87913 .01472 L
.87979 .01472 L
.8811 .01472 L
.88185 .01472 L
.88254 .01472 L
.88381 .01472 L
.88451 .01472 L
.88516 .01472 L
.8864 .01472 L
.88754 .01473 L
.88879 .01474 L
.88942 .01475 L
.89012 .01476 L
.89128 .01479 L
.89253 .01483 L
.89371 .01488 L
.89479 .01494 L
.89707 .01512 L
.89837 .01525 L
.89959 .01541 L
.90204 .01582 L
.90469 .01644 L
.90702 .01714 L
.90947 .01806 L
.91386 .02022 L
.91899 .02363 L
.92377 .02763 L
.93461 .03888 L
.94512 .05042 L
.95029 .05542 L
.95505 .05932 L
.95929 .06213 L
.96396 .06449 L
.96639 .0654 L
.96866 .06608 L
.97106 .06662 L
.9724 .06684 L
.97363 .067 L
.97486 .06711 L
.97555 .06715 L
.97619 .06717 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "This is coiflet ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Phi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " of order 12."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.16"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[Product[response[w/2^i, c12],
{i, 10}]]], {w, -5Pi, 5Pi}, PlotRange -> All,
AxesLabel -> {\"w\", \"coiflet |phihat(w)| of order 12\"}]\
\>", "Input",
  CellLabel->"In[66]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0303152 0.0147151 0.588604 [
[.04527 .00222 -9 -9 ]
[.04527 .00222 9 0 ]
[.19685 .00222 -9 -9 ]
[.19685 .00222 9 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -6 -9 ]
[.80315 .00222 6 0 ]
[.95473 .00222 -6 -9 ]
[.95473 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -93 0 ]
[.5 .64303 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-15)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-10)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-5)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(5)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(10)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(15)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(coiflet |phihat\\(w\\)| of order 12)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01498 m
.03279 .01487 L
.03793 .01481 L
.04262 .01477 L
.04517 .01476 L
.04758 .01475 L
.05012 .01474 L
.05288 .01473 L
.0553 .01473 L
.05785 .01472 L
.06004 .01472 L
.06244 .01472 L
.06379 .01472 L
.06525 .01472 L
.06654 .01472 L
.06792 .01472 L
.06928 .01472 L
.07051 .01472 L
.07169 .01472 L
.07293 .01472 L
.07438 .01472 L
.07571 .01472 L
.07715 .01472 L
.07797 .01472 L
.07873 .01472 L
.08011 .01472 L
.08137 .01472 L
.08207 .01472 L
.08282 .01472 L
.08349 .01472 L
.0842 .01472 L
.08546 .01472 L
.08664 .01472 L
.08732 .01472 L
.08804 .01472 L
.08933 .01472 L
.08998 .01472 L
.09068 .01472 L
.09194 .01472 L
.0927 .01472 L
.09343 .01472 L
.09408 .01472 L
.09479 .01472 L
.09596 .01472 L
.09726 .01472 L
.09791 .01472 L
.09861 .01472 L
.09988 .01472 L
.10114 .01472 L
.10234 .01472 L
Mistroke
.10341 .01472 L
.10458 .01472 L
.10523 .01472 L
.10592 .01472 L
.10714 .01472 L
.10846 .01472 L
.10921 .01472 L
.10991 .01472 L
.11118 .01472 L
.11233 .01472 L
.11297 .01472 L
.11366 .01472 L
.11492 .01472 L
.11605 .01472 L
.11729 .01472 L
.11858 .01472 L
.11979 .01472 L
.12092 .01472 L
.12196 .01472 L
.1231 .01472 L
.12429 .01472 L
.12561 .01472 L
.12681 .01472 L
.12747 .01472 L
.12819 .01472 L
.12949 .01472 L
.13071 .01472 L
.13201 .01472 L
.13311 .01472 L
.13432 .01472 L
.13505 .01472 L
.13575 .01472 L
.13705 .01472 L
.13778 .01472 L
.13846 .01472 L
.1392 .01472 L
.13999 .01472 L
.14128 .01472 L
.1425 .01472 L
.1432 .01472 L
.14384 .01472 L
.14454 .01472 L
.14528 .01472 L
.14651 .01472 L
.1472 .01472 L
.14784 .01472 L
.14902 .01472 L
.15027 .01472 L
.15138 .01472 L
.15243 .01472 L
Mistroke
.15357 .01472 L
.15481 .01472 L
.15611 .01472 L
.15685 .01472 L
.15754 .01472 L
.15879 .01472 L
.16013 .01472 L
.16144 .01472 L
.16268 .01472 L
.16379 .01472 L
.16499 .01472 L
.16614 .01472 L
.16721 .01472 L
.16839 .01472 L
.16965 .01472 L
.17097 .01472 L
.17222 .01472 L
.17334 .01472 L
.17456 .01472 L
.17677 .01473 L
.17789 .01473 L
.17913 .01473 L
.18131 .01474 L
.18335 .01475 L
.18579 .01477 L
.18805 .0148 L
.19054 .01484 L
.1932 .0149 L
.19599 .01498 L
.19862 .01509 L
.20099 .01521 L
.20355 .01538 L
.20823 .01579 L
.21318 .01634 L
.22206 .01743 L
.22459 .01768 L
.22584 .01778 L
.227 .01786 L
.22813 .01793 L
.22916 .01797 L
.2303 .018 L
.23151 .01801 L
.23282 .01801 L
.23402 .01798 L
.23534 .01792 L
.23601 .01789 L
.23673 .01784 L
.23928 .01763 L
.24165 .01737 L
.25043 .01621 L
Mistroke
.25506 .01566 L
.25997 .01522 L
.26256 .01505 L
.26394 .01498 L
.26542 .01492 L
.26678 .01488 L
.26802 .01484 L
.26928 .01481 L
.27046 .01479 L
.27173 .01477 L
.27289 .01476 L
.27417 .01474 L
.27554 .01474 L
.27674 .01473 L
.27803 .01472 L
.27925 .01472 L
.28038 .01472 L
.28145 .01472 L
.2826 .01472 L
.28369 .01472 L
.28468 .01472 L
.28584 .01472 L
.28711 .01472 L
.2883 .01472 L
.28941 .01472 L
.29054 .01472 L
.2916 .01472 L
.29277 .01472 L
.29403 .01472 L
.29528 .01472 L
.2966 .01472 L
.29772 .01472 L
.29895 .01472 L
.30027 .01472 L
.30148 .01472 L
.30212 .01472 L
.30282 .01472 L
.30355 .01472 L
.30423 .01472 L
.30549 .01472 L
.30663 .01472 L
.30727 .01472 L
.30796 .01472 L
.30922 .01472 L
.31045 .01472 L
.31156 .01472 L
.31285 .01472 L
.31406 .01472 L
.31518 .01472 L
.31622 .01472 L
Mistroke
.31735 .01472 L
.31855 .01472 L
.31986 .01472 L
.32105 .01472 L
.3217 .01472 L
.32242 .01472 L
.32372 .01472 L
.32494 .01472 L
.32623 .01472 L
.32733 .01472 L
.32854 .01472 L
.32923 .01472 L
.32996 .01472 L
.33126 .01472 L
.33199 .01472 L
.33266 .01472 L
.3334 .01472 L
.3342 .01472 L
.33488 .01472 L
.33563 .01472 L
.33633 .01472 L
.33697 .01472 L
.3382 .01473 L
.3395 .01473 L
.34071 .01474 L
.34203 .01476 L
.34328 .01478 L
.34444 .01481 L
.34548 .01485 L
.34663 .0149 L
.34783 .01498 L
.34895 .01507 L
.35019 .01521 L
.3515 .0154 L
.35261 .01562 L
.35383 .01592 L
.35515 .01634 L
.35656 .01692 L
.35789 .01762 L
.3591 .01842 L
.36145 .02051 L
.36362 .02323 L
.366 .02738 L
.36852 .03343 L
.37071 .04039 L
.37276 .04862 L
.37742 .07478 L
.38 .0943 L
.38239 .11596 L
.38781 .17772 L
Mistroke
.39768 .32374 L
.40658 .45545 L
.41159 .51317 L
.4162 .55165 L
.41866 .56651 L
.42135 .57888 L
.4227 .58374 L
.42415 .58806 L
.42678 .59391 L
.42806 .596 L
.42945 .59782 L
.43068 .59909 L
.43198 .60016 L
.43316 .60091 L
.43445 .60155 L
.43563 .602 L
.43673 .60233 L
.43782 .60258 L
.43901 .60279 L
.44025 .60295 L
.4414 .60305 L
.44249 .60313 L
.44348 .60318 L
.44461 .60322 L
.44569 .60325 L
.44686 .60327 L
.4481 .60329 L
.44916 .6033 L
.45032 .60331 L
.45157 .60331 L
.45227 .60331 L
.45291 .60331 L
.45416 .60332 L
.45534 .60332 L
.45659 .60332 L
.4573 .60332 L
.45794 .60332 L
.45913 .60332 L
.46039 .60332 L
.46152 .60332 L
.46257 .60332 L
.46372 .60332 L
.46496 .60332 L
.46628 .60332 L
.46702 .60332 L
.46771 .60332 L
.46897 .60332 L
.46961 .60332 L
.47031 .60332 L
.47153 .60332 L
Mistroke
.47283 .60332 L
.47406 .60332 L
.47519 .60332 L
.47632 .60332 L
.47753 .60332 L
.47867 .60332 L
.4797 .60332 L
.48092 .60332 L
.48223 .60332 L
.48348 .60332 L
.48462 .60332 L
.4857 .60332 L
.4867 .60332 L
.4878 .60332 L
.48898 .60332 L
.49022 .60332 L
.49139 .60332 L
.49254 .60332 L
.49359 .60332 L
.49473 .60332 L
.49596 .60332 L
.49704 .60332 L
.49818 .60332 L
.49943 .60332 L
.50059 .60332 L
.50187 .60332 L
.50259 .60332 L
.50324 .60332 L
.50455 .60332 L
.50576 .60332 L
.50645 .60332 L
.5071 .60332 L
.50777 .60332 L
.50851 .60332 L
.50976 .60332 L
.51091 .60332 L
.51154 .60332 L
.51223 .60332 L
.51348 .60332 L
.51473 .60332 L
.51591 .60332 L
.51697 .60332 L
.51811 .60332 L
.51936 .60332 L
.52068 .60332 L
.5218 .60332 L
.52304 .60332 L
.5242 .60332 L
.52525 .60332 L
.52647 .60332 L
Mistroke
.52762 .60332 L
.52869 .60332 L
.52967 .60332 L
.53075 .60332 L
.5319 .60332 L
.53304 .60332 L
.53429 .60332 L
.53559 .60332 L
.5368 .60332 L
.53793 .60332 L
.53897 .60332 L
.54016 .60332 L
.54128 .60332 L
.54251 .60332 L
.54381 .60332 L
.54492 .60332 L
.54613 .60332 L
.54744 .60331 L
.54818 .60331 L
.54885 .60331 L
.55015 .6033 L
.55139 .6033 L
.55255 .60328 L
.55359 .60327 L
.5548 .60324 L
.55593 .6032 L
.55699 .60316 L
.55796 .6031 L
.55902 .60302 L
.56014 .6029 L
.56128 .60274 L
.5625 .60251 L
.56365 .60223 L
.56469 .60189 L
.56592 .60139 L
.56726 .60067 L
.56851 .59978 L
.56968 .59875 L
.57092 .59738 L
.57211 .59576 L
.57433 .59171 L
.57673 .58554 L
.57934 .57607 L
.58162 .56504 L
.58404 .54997 L
.5884 .51326 L
.59397 .44825 L
.59922 .37227 L
.60902 .22113 L
.61407 .15437 L
Mistroke
.61878 .10488 L
.6237 .06743 L
.62631 .05299 L
.6291 .04109 L
.63147 .03344 L
.63406 .02726 L
.6365 .02306 L
.63876 .02029 L
.64079 .0185 L
.64195 .01772 L
.64303 .01712 L
.64521 .01621 L
.64644 .01584 L
.64757 .01558 L
.64885 .01535 L
.65005 .01518 L
.65113 .01506 L
.65231 .01497 L
.65359 .01489 L
.65494 .01483 L
.6561 .0148 L
.65737 .01477 L
.65856 .01475 L
.65964 .01474 L
.66089 .01473 L
.66208 .01472 L
.66318 .01472 L
.66419 .01472 L
.6653 .01472 L
.66649 .01472 L
.66717 .01472 L
.66789 .01472 L
.66918 .01472 L
.6699 .01472 L
.67057 .01472 L
.6713 .01472 L
.67209 .01472 L
.67276 .01472 L
.6735 .01472 L
.6742 .01472 L
.67484 .01472 L
.67606 .01472 L
.67735 .01472 L
.67851 .01472 L
.67977 .01472 L
.68095 .01472 L
.68203 .01472 L
.68323 .01472 L
.68454 .01472 L
.68521 .01472 L
Mistroke
.68592 .01472 L
.68719 .01472 L
.68843 .01472 L
.68913 .01472 L
.68979 .01472 L
.69048 .01472 L
.69111 .01472 L
.69184 .01472 L
.69253 .01472 L
.69376 .01472 L
.69489 .01472 L
.69613 .01472 L
.69746 .01472 L
.69877 .01472 L
.6995 .01472 L
.70018 .01472 L
.70142 .01472 L
.70274 .01472 L
.70343 .01472 L
.70418 .01472 L
.70488 .01472 L
.70552 .01472 L
.70627 .01472 L
.70709 .01472 L
.70786 .01472 L
.70857 .01472 L
.70973 .01472 L
.71098 .01472 L
.71215 .01472 L
.71323 .01472 L
.71449 .01472 L
.7152 .01472 L
.71586 .01472 L
.71707 .01472 L
.71836 .01472 L
.71906 .01472 L
.71971 .01472 L
.7204 .01472 L
.72116 .01472 L
.72245 .01473 L
.7238 .01473 L
.72503 .01474 L
.72635 .01475 L
.7276 .01476 L
.72873 .01478 L
.73102 .01482 L
.73232 .01485 L
.73355 .01489 L
.736 .01498 L
.73865 .01512 L
Mistroke
.74099 .01529 L
.74344 .01551 L
.74783 .01599 L
.75787 .01731 L
.76076 .01763 L
.76218 .01776 L
.76349 .01785 L
.76468 .01792 L
.76594 .01798 L
.7672 .01801 L
.76792 .01801 L
.76859 .01801 L
.76982 .018 L
.77051 .01798 L
.77115 .01796 L
.77232 .0179 L
.77357 .01783 L
.77596 .01763 L
.77812 .01741 L
.78835 .01616 L
.7929 .01568 L
.79529 .01547 L
.79781 .01529 L
.80003 .01516 L
.80246 .01504 L
.80467 .01496 L
.80672 .0149 L
.80924 .01484 L
.81054 .01482 L
.81198 .0148 L
.8144 .01477 L
.81572 .01476 L
.81696 .01475 L
.81816 .01474 L
.8193 .01474 L
.82145 .01473 L
.82264 .01473 L
.82376 .01473 L
.82507 .01472 L
.82628 .01472 L
.82759 .01472 L
.82901 .01472 L
.83027 .01472 L
.83159 .01472 L
.83278 .01472 L
.83389 .01472 L
.8351 .01472 L
.83641 .01472 L
.8378 .01472 L
.83858 .01472 L
Mistroke
.83931 .01472 L
.84064 .01472 L
.84131 .01472 L
.84206 .01472 L
.84334 .01472 L
.84405 .01472 L
.84471 .01472 L
.84593 .01472 L
.84721 .01472 L
.84844 .01472 L
.84914 .01472 L
.84978 .01472 L
.85096 .01472 L
.85221 .01472 L
.85332 .01472 L
.85437 .01472 L
.85551 .01472 L
.85675 .01472 L
.85805 .01472 L
.85879 .01472 L
.85948 .01472 L
.86073 .01472 L
.86144 .01472 L
.86207 .01472 L
.86328 .01472 L
.86458 .01472 L
.86581 .01472 L
.86694 .01472 L
.868 .01472 L
.86914 .01472 L
.87022 .01472 L
.8712 .01472 L
.87235 .01472 L
.8736 .01472 L
.87478 .01472 L
.87587 .01472 L
.87699 .01472 L
.87805 .01472 L
.8792 .01472 L
.88045 .01472 L
.88168 .01472 L
.88298 .01472 L
.88409 .01472 L
.8853 .01472 L
.88594 .01472 L
.88662 .01472 L
.88784 .01472 L
.88916 .01472 L
.8899 .01472 L
.8906 .01472 L
Mistroke
.89186 .01472 L
.89301 .01472 L
.89364 .01472 L
.89434 .01472 L
.89559 .01472 L
.89671 .01472 L
.89794 .01472 L
.89923 .01472 L
.90044 .01472 L
.90157 .01472 L
.90261 .01472 L
.90374 .01472 L
.90494 .01472 L
.90625 .01472 L
.90744 .01472 L
.9081 .01472 L
.90882 .01472 L
.91012 .01472 L
.91133 .01472 L
.91263 .01472 L
.91373 .01472 L
.91494 .01472 L
.91567 .01472 L
.91636 .01472 L
.91767 .01472 L
.91839 .01472 L
.91907 .01472 L
.91986 .01472 L
.9206 .01472 L
.92194 .01472 L
.92316 .01472 L
.92448 .01472 L
.9259 .01472 L
.92714 .01472 L
.92827 .01472 L
.92958 .01472 L
.93081 .01472 L
.93301 .01472 L
.93426 .01472 L
.9354 .01472 L
.93781 .01472 L
.93918 .01472 L
.94046 .01472 L
.94305 .01472 L
.9445 .01473 L
.94584 .01473 L
.94838 .01473 L
.95074 .01474 L
.95333 .01475 L
.9561 .01477 L
Mistroke
.95901 .01479 L
.96176 .01481 L
.9669 .01486 L
.97619 .01498 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "Here is coiflet ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftBracketingBar]\(\[Psi]\&^\) \((\[Omega])
          \)\[RightBracketingBar]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " of order 12."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.17"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[response[w, HighpassFilter[c12]]*
Product[response[w/2^i, c12], {i, 2, 10}]]],
{w, -5Pi, 5Pi}, PlotRange -> All,
AxesLabel -> {\"w\", \"coiflet |psihat(w)| of order 12\"}]\
\>", "Input",
  CellLabel->"In[67]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0303152 0.0147151 0.588604 [
[.04527 .00222 -9 -9 ]
[.04527 .00222 9 0 ]
[.19685 .00222 -9 -9 ]
[.19685 .00222 9 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -6 -9 ]
[.80315 .00222 6 0 ]
[.95473 .00222 -6 -9 ]
[.95473 .00222 6 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -93 0 ]
[.5 .64303 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-15)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-10)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-5)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(5)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(10)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(15)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.07559 .01472 m
.07559 .01847 L
s
.1059 .01472 m
.1059 .01847 L
s
.13622 .01472 m
.13622 .01847 L
s
.16653 .01472 m
.16653 .01847 L
s
.22716 .01472 m
.22716 .01847 L
s
.25748 .01472 m
.25748 .01847 L
s
.28779 .01472 m
.28779 .01847 L
s
.31811 .01472 m
.31811 .01847 L
s
.37874 .01472 m
.37874 .01847 L
s
.40905 .01472 m
.40905 .01847 L
s
.43937 .01472 m
.43937 .01847 L
s
.46968 .01472 m
.46968 .01847 L
s
.53032 .01472 m
.53032 .01847 L
s
.56063 .01472 m
.56063 .01847 L
s
.59095 .01472 m
.59095 .01847 L
s
.62126 .01472 m
.62126 .01847 L
s
.68189 .01472 m
.68189 .01847 L
s
.71221 .01472 m
.71221 .01847 L
s
.74252 .01472 m
.74252 .01847 L
s
.77284 .01472 m
.77284 .01847 L
s
.83347 .01472 m
.83347 .01847 L
s
.86378 .01472 m
.86378 .01847 L
s
.8941 .01472 m
.8941 .01847 L
s
.92441 .01472 m
.92441 .01847 L
s
.01496 .01472 m
.01496 .01847 L
s
.98504 .01472 m
.98504 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(w)] 1.025 .01472 -1 0 Mshowa
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(coiflet |psihat\\(w\\)| of order 12)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01509 m
.02846 .01497 L
.03279 .01489 L
.03754 .01482 L
.0402 .0148 L
.04262 .01478 L
.04516 .01476 L
.0475 .01475 L
.05008 .01474 L
.05281 .01473 L
.05518 .01473 L
.05739 .01472 L
.05983 .01472 L
.06119 .01472 L
.06244 .01472 L
.06504 .01472 L
.06649 .01472 L
.0678 .01472 L
.06903 .01472 L
.07036 .01472 L
.07162 .01472 L
.07277 .01472 L
.07342 .01472 L
.07412 .01472 L
.07539 .01472 L
.07616 .01472 L
.07689 .01472 L
.07754 .01472 L
.07825 .01472 L
.07895 .01472 L
.0797 .01472 L
.08038 .01472 L
.08103 .01472 L
.08179 .01472 L
.08248 .01472 L
.08324 .01472 L
.08405 .01472 L
.08533 .01472 L
.0865 .01472 L
.08715 .01472 L
.08785 .01472 L
.08913 .01472 L
.09032 .01472 L
.09159 .01472 L
.09266 .01472 L
.09385 .01472 L
.09457 .01472 L
.09525 .01472 L
.09652 .01472 L
.09724 .01472 L
Mistroke
.0979 .01472 L
.09862 .01472 L
.09939 .01472 L
.10007 .01472 L
.1008 .01472 L
.10212 .01472 L
.1034 .01472 L
.10458 .01472 L
.10585 .01472 L
.10705 .01472 L
.10812 .01472 L
.10929 .01472 L
.11057 .01472 L
.11121 .01472 L
.11192 .01472 L
.11317 .01472 L
.11434 .01472 L
.11546 .01472 L
.11663 .01472 L
.11763 .01472 L
.11872 .01472 L
.11991 .01472 L
.12117 .01472 L
.12236 .01472 L
.12344 .01472 L
.12474 .01472 L
.12539 .01472 L
.1261 .01472 L
.12737 .01472 L
.12855 .01472 L
.12927 .01472 L
.12995 .01472 L
.13122 .01472 L
.13193 .01472 L
.13259 .01472 L
.13332 .01472 L
.13409 .01472 L
.13527 .01472 L
.13654 .01472 L
.13775 .01472 L
.13885 .01472 L
.14008 .01472 L
.14077 .01472 L
.14142 .01472 L
.14272 .01472 L
.14345 .01472 L
.14412 .01472 L
.14531 .01472 L
.14642 .01472 L
.14764 .01472 L
Mistroke
.14896 .01472 L
.14961 .01472 L
.15033 .01472 L
.15164 .01472 L
.15291 .01472 L
.15408 .01472 L
.15529 .01472 L
.15642 .01472 L
.15744 .01472 L
.15854 .01472 L
.15974 .01472 L
.16101 .01472 L
.16209 .01472 L
.16328 .01472 L
.16395 .01472 L
.16468 .01472 L
.166 .01472 L
.16728 .01472 L
.16847 .01472 L
.16975 .01472 L
.17117 .01472 L
.17265 .01472 L
.17403 .01472 L
.17526 .01472 L
.17656 .01473 L
.17886 .01473 L
.18015 .01474 L
.18135 .01474 L
.18267 .01475 L
.18407 .01476 L
.18532 .01477 L
.1867 .01478 L
.18912 .01481 L
.19049 .01484 L
.19196 .01487 L
.1946 .01494 L
.19727 .01504 L
.1998 .01517 L
.20207 .01533 L
.20454 .01555 L
.207 .01583 L
.20922 .01615 L
.21178 .01662 L
.21419 .01718 L
.21849 .01853 L
.22091 .01953 L
.22313 .02063 L
.22785 .0237 L
.23291 .02833 L
.23767 .03432 L
Mistroke
.24201 .04146 L
.24723 .05248 L
.25276 .06627 L
.25504 .07154 L
.25629 .07398 L
.25749 .07582 L
.25816 .07661 L
.25889 .07723 L
.26018 .07767 L
.26148 .07718 L
.26269 .07581 L
.26389 .07361 L
.26519 .07034 L
.26755 .06244 L
.27196 .04451 L
.27446 .03503 L
.2771 .02697 L
.27935 .02201 L
.28064 .01994 L
.28183 .01843 L
.28312 .01721 L
.2838 .01671 L
.28452 .01627 L
.28515 .01595 L
.28585 .01567 L
.28708 .0153 L
.28826 .01506 L
.28954 .0149 L
.29075 .01482 L
.29186 .01477 L
.29315 .01474 L
.29436 .01473 L
.29505 .01472 L
.29568 .01472 L
.29641 .01472 L
.2971 .01472 L
.29776 .01472 L
.29847 .01472 L
.29974 .01472 L
.30045 .01472 L
.30111 .01472 L
.30183 .01472 L
.30261 .01472 L
.3033 .01472 L
.30395 .01472 L
.30516 .01472 L
.30646 .01472 L
.30719 .01472 L
.30786 .01472 L
.30899 .01472 L
Mistroke
.31023 .01472 L
.31153 .01472 L
.31274 .01472 L
.31342 .01472 L
.31417 .01472 L
.31487 .01472 L
.31553 .01472 L
.31676 .01472 L
.31807 .01472 L
.31874 .01472 L
.31947 .01472 L
.32078 .01472 L
.32154 .01472 L
.32235 .01472 L
.32303 .01472 L
.32378 .01472 L
.32443 .01473 L
.32514 .01474 L
.32642 .01478 L
.32767 .01485 L
.32882 .01497 L
.33006 .01522 L
.33077 .01543 L
.33143 .0157 L
.33213 .01608 L
.33276 .01652 L
.3335 .01719 L
.33419 .01801 L
.33536 .01988 L
.3366 .0228 L
.33766 .02627 L
.33883 .03144 L
.34008 .03889 L
.34143 .04965 L
.34271 .06289 L
.34388 .07803 L
.35378 .32441 L
.35639 .40459 L
.35922 .48015 L
.36052 .50854 L
.3619 .53373 L
.36309 .55144 L
.36437 .56655 L
.36565 .57802 L
.36682 .58578 L
.368 .59143 L
.36912 .59523 L
.37042 .5982 L
.37163 .59997 L
.37232 .60068 L
Mistroke
.37295 .60118 L
.37368 .60162 L
.37436 .60194 L
.37547 .6023 L
.37664 .60255 L
.37764 .60269 L
.37873 .60281 L
.37991 .6029 L
.38117 .60298 L
.38346 .60308 L
.38469 .60312 L
.386 .60316 L
.38835 .60321 L
.38966 .60323 L
.39089 .60325 L
.39225 .60326 L
.39368 .60327 L
.39484 .60328 L
.39611 .60329 L
.39834 .6033 L
.3996 .6033 L
.40095 .60331 L
.40221 .60331 L
.40337 .60331 L
.40449 .60331 L
.40572 .60331 L
.40695 .60332 L
.40826 .60332 L
.40941 .60332 L
.41065 .60332 L
.41181 .60332 L
.41288 .60332 L
.41391 .60332 L
.415 .60332 L
.4162 .60332 L
.41731 .60332 L
.41845 .60332 L
.41952 .60332 L
.42048 .60332 L
.42152 .60332 L
.42277 .60332 L
.4239 .60332 L
.42521 .60332 L
.42645 .60332 L
.4276 .60332 L
.42866 .60331 L
.42982 .6033 L
.43105 .60328 L
.43229 .60323 L
.43298 .60318 L
Mistroke
.43362 .60312 L
.43485 .6029 L
.43602 .60251 L
.43668 .60217 L
.43738 .60168 L
.43864 .60034 L
.43941 .59911 L
.44014 .59757 L
.4408 .59582 L
.4415 .59343 L
.44282 .58734 L
.44405 .57922 L
.44539 .56695 L
.44684 .54918 L
.44835 .52481 L
.44979 .49603 L
.45248 .4282 L
.45728 .28119 L
.45983 .20537 L
.46258 .13645 L
.46384 .11066 L
.46517 .08767 L
.46641 .07009 L
.46755 .05671 L
.46872 .04576 L
.46978 .03786 L
.47096 .03105 L
.47222 .02566 L
.47354 .0217 L
.47475 .01918 L
.47539 .01821 L
.47608 .01735 L
.47681 .01665 L
.47749 .01615 L
.47875 .01551 L
.47989 .01516 L
.48053 .01504 L
.48122 .01493 L
.48247 .01482 L
.48372 .01476 L
.4849 .01474 L
.48596 .01472 L
.4871 .01472 L
.48835 .01472 L
.48967 .01472 L
.49079 .01472 L
.49203 .01472 L
.49318 .01472 L
.49424 .01472 L
.49546 .01472 L
Mistroke
.49661 .01472 L
.49767 .01472 L
.49866 .01472 L
.49974 .01472 L
.50089 .01472 L
.50203 .01472 L
.50327 .01472 L
.50457 .01472 L
.50578 .01472 L
.50692 .01472 L
.50795 .01472 L
.50915 .01472 L
.51027 .01472 L
.5115 .01472 L
.5128 .01472 L
.5139 .01472 L
.51512 .01474 L
.51643 .01477 L
.51717 .0148 L
.51784 .01484 L
.51914 .01498 L
.52038 .01523 L
.52153 .01563 L
.52258 .0162 L
.52379 .01721 L
.52492 .01865 L
.52598 .02058 L
.52695 .02299 L
.52801 .02653 L
.52913 .03152 L
.53027 .03821 L
.53149 .04753 L
.53368 .07123 L
.53502 .09082 L
.53629 .11324 L
.53867 .16566 L
.54367 .31092 L
.54836 .45103 L
.55071 .50671 L
.55193 .52974 L
.55325 .55039 L
.55469 .56782 L
.55606 .58003 L
.55671 .58451 L
.5574 .5885 L
.55864 .59394 L
.55988 .59763 L
.56103 .59986 L
.56229 .60139 L
.56292 .60191 L
Mistroke
.56361 .60234 L
.56479 .6028 L
.56604 .60307 L
.56723 .6032 L
.56831 .60326 L
.56943 .60329 L
.57046 .60331 L
.5716 .60331 L
.57281 .60332 L
.57385 .60332 L
.57484 .60332 L
.57591 .60332 L
.57707 .60332 L
.57833 .60332 L
.57947 .60332 L
.58079 .60332 L
.58203 .60332 L
.58318 .60332 L
.58424 .60332 L
.58541 .60332 L
.58664 .60332 L
.58788 .60332 L
.58922 .60332 L
.59048 .60332 L
.59163 .60332 L
.59297 .60332 L
.59444 .60331 L
.59583 .60331 L
.59711 .60331 L
.59844 .60331 L
.59987 .60331 L
.60123 .6033 L
.60247 .6033 L
.60484 .60328 L
.60603 .60328 L
.60733 .60327 L
.61005 .60323 L
.61157 .60321 L
.61296 .60318 L
.61425 .60315 L
.61566 .60311 L
.61699 .60306 L
.61821 .60301 L
.61933 .60295 L
.62055 .60287 L
.62178 .60276 L
.62307 .60259 L
.62422 .60238 L
.62544 .60201 L
.62659 .60147 L
Mistroke
.62763 .60072 L
.62828 .60007 L
.62897 .59919 L
.6302 .59694 L
.63088 .59521 L
.63152 .5932 L
.63227 .59029 L
.63298 .58686 L
.63425 .57877 L
.63541 .56878 L
.63666 .55473 L
.63802 .53507 L
.64053 .48585 L
.64331 .4134 L
.64893 .24052 L
.65144 .17098 L
.65414 .11088 L
.65539 .08917 L
.6567 .07025 L
.65791 .05605 L
.65904 .04556 L
.66027 .03658 L
.6616 .02934 L
.66278 .0247 L
.66403 .02118 L
.66514 .01898 L
.66619 .01753 L
.66733 .01645 L
.66857 .0157 L
.66987 .01524 L
.67061 .01507 L
.67129 .01496 L
.67255 .01483 L
.67325 .01479 L
.67389 .01476 L
.67509 .01474 L
.67639 .01472 L
.67762 .01472 L
.67875 .01472 L
.67982 .01472 L
.68096 .01472 L
.68203 .01472 L
.68301 .01472 L
.68416 .01472 L
.68541 .01472 L
.68659 .01472 L
.68768 .01472 L
.6888 .01472 L
.68986 .01472 L
.69101 .01472 L
Mistroke
.69225 .01472 L
.69349 .01472 L
.69479 .01472 L
.6959 .01472 L
.69711 .01472 L
.69843 .01472 L
.69965 .01472 L
.70029 .01472 L
.70099 .01472 L
.70172 .01472 L
.7024 .01472 L
.70366 .01472 L
.70481 .01472 L
.70544 .01472 L
.70613 .01473 L
.70739 .01475 L
.70863 .01479 L
.70974 .01485 L
.71103 .01496 L
.71224 .01515 L
.71337 .01541 L
.7144 .01576 L
.71554 .0163 L
.71673 .0171 L
.71804 .0183 L
.71923 .01975 L
.72061 .02194 L
.72191 .02457 L
.72422 .0307 L
.72673 .03935 L
.72946 .05033 L
.73239 .0622 L
.73381 .06725 L
.73515 .0713 L
.73636 .07416 L
.73769 .07634 L
.73893 .07744 L
.74005 .07766 L
.74135 .07705 L
.74258 .07573 L
.74371 .07396 L
.74476 .07196 L
.74712 .06656 L
.75207 .05415 L
.75751 .04236 L
.7628 .03365 L
.76773 .02765 L
.77295 .0231 L
.77587 .02119 L
.77854 .01978 L
Mistroke
.78334 .01789 L
.78576 .01719 L
.78844 .01658 L
.79072 .01616 L
.79317 .01581 L
.79547 .01555 L
.79761 .01535 L
.80013 .01518 L
.80288 .01503 L
.80557 .01493 L
.80694 .0149 L
.80843 .01486 L
.80983 .01483 L
.81111 .01481 L
.81231 .01479 L
.81364 .01478 L
.81593 .01476 L
.81719 .01475 L
.81836 .01474 L
.81961 .01474 L
.82095 .01473 L
.82334 .01473 L
.82481 .01472 L
.82619 .01472 L
.82742 .01472 L
.82876 .01472 L
.82996 .01472 L
.83127 .01472 L
.83263 .01472 L
.83391 .01472 L
.8351 .01472 L
.83619 .01472 L
.83745 .01472 L
.83864 .01472 L
.8397 .01472 L
.84088 .01472 L
.8421 .01472 L
.84325 .01472 L
.84433 .01472 L
.84531 .01472 L
.84639 .01472 L
.84752 .01472 L
.84868 .01472 L
.84991 .01472 L
.85107 .01472 L
.85213 .01472 L
.85338 .01472 L
.85408 .01472 L
.85473 .01472 L
.85591 .01472 L
Mistroke
.85717 .01472 L
.85839 .01472 L
.85971 .01472 L
.86096 .01472 L
.86211 .01472 L
.86315 .01472 L
.8643 .01472 L
.8655 .01472 L
.86663 .01472 L
.86786 .01472 L
.86917 .01472 L
.87028 .01472 L
.87151 .01472 L
.87282 .01472 L
.87356 .01472 L
.87423 .01472 L
.87554 .01472 L
.87677 .01472 L
.87783 .01472 L
.87899 .01472 L
.8802 .01472 L
.88134 .01472 L
.8824 .01472 L
.88337 .01472 L
.88449 .01472 L
.88556 .01472 L
.8867 .01472 L
.88792 .01472 L
.88907 .01472 L
.89012 .01472 L
.89135 .01472 L
.89204 .01472 L
.89268 .01472 L
.89385 .01472 L
.89509 .01472 L
.89631 .01472 L
.897 .01472 L
.89764 .01472 L
.89881 .01472 L
.90005 .01472 L
.90116 .01472 L
.9022 .01472 L
.90334 .01472 L
.90457 .01472 L
.90581 .01472 L
.90651 .01472 L
.90716 .01472 L
.90847 .01472 L
.90921 .01472 L
.90987 .01472 L
Mistroke
.91107 .01472 L
.91237 .01472 L
.9136 .01472 L
.91473 .01472 L
.91579 .01472 L
.91693 .01472 L
.918 .01472 L
.91898 .01472 L
.92012 .01472 L
.92137 .01472 L
.92255 .01472 L
.92364 .01472 L
.92488 .01472 L
.92604 .01472 L
.92708 .01472 L
.92821 .01472 L
.92944 .01472 L
.93074 .01472 L
.93185 .01472 L
.93307 .01472 L
.93559 .01472 L
.93701 .01472 L
.93833 .01472 L
.94074 .01472 L
.94196 .01472 L
.9433 .01472 L
.94562 .01473 L
.94811 .01473 L
.95046 .01474 L
.95262 .01475 L
.95515 .01476 L
.9575 .01478 L
.96007 .0148 L
.96282 .01483 L
.96572 .01486 L
.96845 .01491 L
.97355 .01502 L
.97619 .01509 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "The derivatives of the scaling function can be obtained by formally \
differentiating the dilation equation (",
  ButtonBox["4.13",
    ButtonData:>{"Wavelets 1.4.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "). Again, we can obtain the integer values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\((m)\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " by solving the eigenvalue problem"
}], "Text",
  CellTags->{"S1.4.6", "6.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(1\/2\^m\), \(\[Phi]\^\((m)\)\), \((t)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), "n",
          LimitsPositioning->True], \(\@2\), \(h\_k\), \(\[Phi]\^\((m)\)\), 
        \((2  t - k)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = 0\), "n",
          LimitsPositioning->True], \(c\_k\), \(\[Phi]\^\((m)\)\), \((
        2  t - k)\), ","}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(4.24) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.4.6", "6.19"}],

Cell["\<\
and obtain the values at the dyadic points recursively. The \
function \
\>", "Text",
  CellTags->{"S1.4.6", "6.20"}],

Cell[TextData[{
  StyleBox["DScalingFunction[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["m", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.6", "6.21"}],

Cell[TextData[{
  "gives the ",
  Cell[BoxData[
      \(TraditionalForm\`m\^th\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " derivative of the scaling function generated from the filter ",
  StyleBox["filter", "TI"],
  " at the dyadic points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.6"],
  ". "
}], "Text",
  CellTags->{"S1.4.6", "6.22"}],

Cell["\<\
This gives the first derivative of the Daubechies scaling function \
of order 3.\
\>", "MathCaption",
  CellTags->{"S1.4.6", "6.23"}],

Cell["\<\
(h3 = DaubechiesFilter[3];
 DScalingFunction[h3, 6, 1];)\
\>", "Input",
  CellLabel->"In[68]:= ",
  CellTags->"S1.4.6"],

Cell[TextData[{
  "This shows the graph of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[Prime]\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.24"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotRange -> All, PlotJoined -> True,
AxesLabel -> {\"t\", \"phi'(t)\"}]\
\>", "Input",
  CellLabel->"In[69]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.368744 0.142939 [
[.21429 .35624 -3 -9 ]
[.21429 .35624 3 0 ]
[.40476 .35624 -3 -9 ]
[.40476 .35624 3 0 ]
[.59524 .35624 -3 -9 ]
[.59524 .35624 3 0 ]
[.78571 .35624 -3 -9 ]
[.78571 .35624 3 0 ]
[.97619 .35624 -3 -9 ]
[.97619 .35624 3 0 ]
[1.025 .36874 0 -4.5 ]
[1.025 .36874 6 4.5 ]
[.01131 .08287 -12 -4.5 ]
[.01131 .08287 0 4.5 ]
[.01131 .22581 -12 -4.5 ]
[.01131 .22581 0 4.5 ]
[.01131 .51168 -6 -4.5 ]
[.01131 .51168 0 4.5 ]
[.02381 .64303 -21 0 ]
[.02381 .64303 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .36874 m
.21429 .37499 L
s
[(1)] .21429 .35624 0 1 Mshowa
.40476 .36874 m
.40476 .37499 L
s
[(2)] .40476 .35624 0 1 Mshowa
.59524 .36874 m
.59524 .37499 L
s
[(3)] .59524 .35624 0 1 Mshowa
.78571 .36874 m
.78571 .37499 L
s
[(4)] .78571 .35624 0 1 Mshowa
.97619 .36874 m
.97619 .37499 L
s
[(5)] .97619 .35624 0 1 Mshowa
.125 Mabswid
.0619 .36874 m
.0619 .37249 L
s
.1 .36874 m
.1 .37249 L
s
.1381 .36874 m
.1381 .37249 L
s
.17619 .36874 m
.17619 .37249 L
s
.25238 .36874 m
.25238 .37249 L
s
.29048 .36874 m
.29048 .37249 L
s
.32857 .36874 m
.32857 .37249 L
s
.36667 .36874 m
.36667 .37249 L
s
.44286 .36874 m
.44286 .37249 L
s
.48095 .36874 m
.48095 .37249 L
s
.51905 .36874 m
.51905 .37249 L
s
.55714 .36874 m
.55714 .37249 L
s
.63333 .36874 m
.63333 .37249 L
s
.67143 .36874 m
.67143 .37249 L
s
.70952 .36874 m
.70952 .37249 L
s
.74762 .36874 m
.74762 .37249 L
s
.82381 .36874 m
.82381 .37249 L
s
.8619 .36874 m
.8619 .37249 L
s
.9 .36874 m
.9 .37249 L
s
.9381 .36874 m
.9381 .37249 L
s
.25 Mabswid
0 .36874 m
1 .36874 L
s
[(t)] 1.025 .36874 -1 0 Mshowa
.02381 .08287 m
.03006 .08287 L
s
[(-2)] .01131 .08287 1 0 Mshowa
.02381 .22581 m
.03006 .22581 L
s
[(-1)] .01131 .22581 1 0 Mshowa
.02381 .51168 m
.03006 .51168 L
s
[(1)] .01131 .51168 1 0 Mshowa
.125 Mabswid
.02381 .11145 m
.02756 .11145 L
s
.02381 .14004 m
.02756 .14004 L
s
.02381 .16863 m
.02756 .16863 L
s
.02381 .19722 m
.02756 .19722 L
s
.02381 .25439 m
.02756 .25439 L
s
.02381 .28298 m
.02756 .28298 L
s
.02381 .31157 m
.02756 .31157 L
s
.02381 .34016 m
.02756 .34016 L
s
.02381 .39733 m
.02756 .39733 L
s
.02381 .42592 m
.02756 .42592 L
s
.02381 .45451 m
.02756 .45451 L
s
.02381 .48309 m
.02756 .48309 L
s
.02381 .05428 m
.02756 .05428 L
s
.02381 .02569 m
.02756 .02569 L
s
.02381 .54027 m
.02756 .54027 L
s
.02381 .56886 m
.02756 .56886 L
s
.02381 .59745 m
.02756 .59745 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi'\\(t\\))] .02381 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .36874 m
.02679 .53128 L
.02976 .54148 L
.03274 .50501 L
.03571 .55232 L
.03869 .49618 L
.04167 .51356 L
.04464 .56297 L
.04762 .56385 L
.0506 .4943 L
.05357 .50418 L
.05655 .53293 L
.05952 .52265 L
.0625 .57077 L
.06548 .57516 L
.06845 .56171 L
.07143 .57609 L
.0744 .50112 L
.07738 .50218 L
.08036 .52968 L
.08333 .51268 L
.08631 .54476 L
.08929 .54324 L
.09226 .52639 L
.09524 .53231 L
.09821 .58112 L
.10119 .58345 L
.10417 .57409 L
.10714 .58812 L
.11012 .56849 L
.1131 .57382 L
.11607 .58946 L
.11905 .58911 L
.12202 .51028 L
.125 .50943 L
.12798 .53067 L
.13095 .51056 L
.13393 .54488 L
.1369 .53978 L
.13988 .51791 L
.14286 .52172 L
.14583 .55713 L
.14881 .55581 L
.15179 .54613 L
.15476 .55419 L
.15774 .53495 L
.16071 .53629 L
.16369 .54596 L
.16667 .54258 L
.16964 .59097 L
Mistroke
.17262 .59445 L
.1756 .58272 L
.17857 .59693 L
.18155 .58184 L
.18452 .58698 L
.1875 .60124 L
.19048 .60189 L
.19345 .57815 L
.19643 .58103 L
.1994 .59053 L
.20238 .58669 L
.20536 .60218 L
.20833 .60332 L
.21131 .59854 L
.21429 .60294 L
.21726 .1284 L
.22024 .1002 L
.22321 .20979 L
.22619 .07299 L
.22917 .2385 L
.23214 .18959 L
.23512 .04706 L
.2381 .04624 L
.24107 .25432 L
.24405 .22744 L
.24702 .14449 L
.25 .17721 L
.25298 .03734 L
.25595 .02661 L
.25893 .06863 L
.2619 .02839 L
.26488 .24652 L
.26786 .24529 L
.27083 .16759 L
.27381 .21844 L
.27679 .12787 L
.27976 .13403 L
.28274 .18435 L
.28571 .1691 L
.28869 .02957 L
.29167 .02462 L
.29464 .05354 L
.29762 .01472 L
.3006 .07331 L
.30357 .05967 L
.30655 .01618 L
.30952 .019 L
.3125 .25881 L
.31548 .26368 L
.31845 .20177 L
Mistroke
.32143 .26465 L
.3244 .1637 L
.32738 .1813 L
.33036 .2494 L
.33333 .24022 L
.33631 .13529 L
.33929 .14149 L
.34226 .17304 L
.34524 .15087 L
.34821 .21127 L
.35119 .20946 L
.35417 .18245 L
.35714 .19488 L
.36012 .05208 L
.3631 .04384 L
.36607 .08127 L
.36905 .0409 L
.37202 .08829 L
.375 .07512 L
.37798 .0346 L
.38095 .03488 L
.38393 .10834 L
.3869 .10195 L
.38988 .07567 L
.39286 .08941 L
.39583 .04517 L
.39881 .044 L
.40179 .06058 L
.40476 .0496 L
.40774 .50026 L
.41071 .52589 L
.41369 .41818 L
.41667 .5469 L
.41964 .38949 L
.42262 .43416 L
.4256 .56754 L
.42857 .56695 L
.43155 .3622 L
.43452 .38583 L
.4375 .46438 L
.44048 .43014 L
.44345 .5633 L
.44643 .57137 L
.4494 .52825 L
.45238 .56488 L
.45536 .36257 L
.45833 .3621 L
.46131 .43247 L
.46429 .38416 L
.46726 .46561 L
Mistroke
.47024 .4585 L
.47321 .41084 L
.47619 .42331 L
.47917 .55128 L
.48214 .5544 L
.48512 .52603 L
.4881 .56057 L
.49107 .5048 L
.49405 .51596 L
.49702 .55479 L
.5 .55071 L
.50298 .30647 L
.50595 .2992 L
.50893 .3597 L
.5119 .29398 L
.51488 .39315 L
.51786 .37317 L
.52083 .30235 L
.52381 .30928 L
.52679 .41382 L
.52976 .40536 L
.53274 .37102 L
.53571 .39139 L
.53869 .32786 L
.54167 .32751 L
.54464 .35277 L
.54762 .33795 L
.5506 .47829 L
.55357 .48432 L
.55655 .44469 L
.55952 .48277 L
.5625 .43333 L
.56548 .44425 L
.56845 .48246 L
.57143 .47998 L
.5744 .40426 L
.57738 .40842 L
.58036 .43248 L
.58333 .41651 L
.58631 .45851 L
.58929 .45745 L
.59226 .43863 L
.59524 .44738 L
.59821 .31955 L
.60119 .31209 L
.60417 .34462 L
.60714 .3083 L
.61012 .35119 L
.6131 .33905 L
.61607 .30226 L
Mistroke
.61905 .30237 L
.62202 .36579 L
.625 .35968 L
.62798 .33641 L
.63095 .34786 L
.63393 .30869 L
.6369 .30718 L
.63988 .32116 L
.64286 .31106 L
.64583 .3612 L
.64881 .36155 L
.65179 .34394 L
.65476 .35602 L
.65774 .3365 L
.66071 .33834 L
.66369 .35007 L
.66667 .3472 L
.66964 .31462 L
.67262 .31392 L
.6756 .32134 L
.67857 .31262 L
.68155 .3269 L
.68452 .32417 L
.6875 .31439 L
.69048 .31553 L
.69345 .39988 L
.69643 .40322 L
.6994 .38297 L
.70238 .40622 L
.70536 .37346 L
.70833 .38101 L
.71131 .40585 L
.71429 .40431 L
.71726 .36835 L
.72024 .37195 L
.72321 .3847 L
.72619 .37822 L
.72917 .40103 L
.73214 .40182 L
.73512 .39367 L
.7381 .39949 L
.74107 .35369 L
.74405 .35241 L
.74702 .36633 L
.75 .35443 L
.75298 .37148 L
.75595 .36859 L
.75893 .35668 L
.7619 .35822 L
.76488 .38422 L
Mistroke
.76786 .38358 L
.77083 .37629 L
.77381 .38237 L
.77679 .36911 L
.77976 .37021 L
.78274 .37723 L
.78571 .37505 L
.78869 .36423 L
.79167 .36406 L
.79464 .36612 L
.79762 .3632 L
.8006 .36836 L
.80357 .36736 L
.80655 .3639 L
.80952 .36431 L
.8125 .3671 L
.81548 .36659 L
.81845 .3655 L
.82143 .36586 L
.8244 .36362 L
.82738 .36341 L
.83036 .36397 L
.83333 .36329 L
.83631 .37231 L
.83929 .37258 L
.84226 .37004 L
.84524 .37242 L
.84821 .36897 L
.85119 .36961 L
.85417 .37206 L
.85714 .37179 L
.86012 .36713 L
.8631 .36733 L
.86607 .36872 L
.86905 .36769 L
.87202 .37022 L
.875 .3701 L
.87798 .36889 L
.88095 .36937 L
.88393 .36828 L
.8869 .36819 L
.88988 .36861 L
.89286 .3683 L
.89583 .36853 L
.89881 .36846 L
.90179 .36821 L
.90476 .3682 L
.90774 .36913 L
.91071 .36911 L
.91369 .36883 L
Mistroke
.91667 .36905 L
.91964 .3686 L
.92262 .36864 L
.9256 .36888 L
.92857 .36881 L
.93155 .36869 L
.93452 .3687 L
.9375 .36872 L
.94048 .36869 L
.94345 .36878 L
.94643 .36877 L
.9494 .36873 L
.95238 .36875 L
.95536 .36874 L
.95833 .36874 L
.96131 .36875 L
.96429 .36874 L
.96726 .36874 L
.97024 .36874 L
.97321 .36874 L
.97619 .36874 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "Although formally ",
  StyleBox["DScalingFunction[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["m", "TI"],
  StyleBox["]", "MR"],
  " can return a list of values that are obtained from solving the \
corresponding eigenvalue problem (",
  ButtonBox["4.24",
    ButtonData:>{"Wavelets 1.4.6", "6.19"},
    ButtonStyle->"AddOnsLink"],
  ") as long as ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^m\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " is an eigenvalue, there is no guarantee that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\((m)\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " exists. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_3\%\[Prime]\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " is not smooth and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_3\%\[Prime]\[Prime]\) \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.4.6"],
  " does not exist, but ",
  StyleBox["DScalingFunction[", "MR"],
  StyleBox["h3", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["2]", "MR"],
  " nevertheless gives a result that is obtained from the solution to the \
eigenvalue problem (",
  ButtonBox["4.24",
    ButtonData:>{"Wavelets 1.4.6", "6.19"},
    ButtonStyle->"AddOnsLink"],
  ") with ",
  Cell[BoxData[
      \(TraditionalForm\`m = 2\)], "InlineFormula",
    CellTags->"S1.4.6"],
  ". "
}], "Text",
  CellTags->{"S1.4.6", "6.25"}],

Cell[TextData[{
  StyleBox["DScalingFunction", "MR"],
  " gives a result as long as a solution to the eigenvalue problem (",
  ButtonBox["4.24",
    ButtonData:>{"Wavelets 1.4.6", "6.19"},
    ButtonStyle->"AddOnsLink"],
  ") exists."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.26"}],

Cell["DScalingFunction[DaubechiesFilter[2], 7, 1];", "Input",
  CellLabel->"In[70]:= ",
  CellTags->"S1.4.6"],

Cell[TextData[{
  "The above result is plotted here. In fact, the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_2\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " does not exist and this can be seen from the lack of continuity of the \
graph."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.27"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotRange -> All, PlotJoined -> True,
AxesLabel -> {\"t\", \"``phi_2'(t)''\"}]\
\>", "Input",
  CellLabel->"In[71]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.399462 0.0229675 [
[.18254 .38696 -9 -9 ]
[.18254 .38696 9 0 ]
[.34127 .38696 -3 -9 ]
[.34127 .38696 3 0 ]
[.5 .38696 -9 -9 ]
[.5 .38696 9 0 ]
[.65873 .38696 -3 -9 ]
[.65873 .38696 3 0 ]
[.81746 .38696 -9 -9 ]
[.81746 .38696 9 0 ]
[.97619 .38696 -3 -9 ]
[.97619 .38696 3 0 ]
[1.025 .39946 0 -4.5 ]
[1.025 .39946 6 4.5 ]
[.01131 .05495 -18 -4.5 ]
[.01131 .05495 0 4.5 ]
[.01131 .16979 -18 -4.5 ]
[.01131 .16979 0 4.5 ]
[.01131 .28462 -12 -4.5 ]
[.01131 .28462 0 4.5 ]
[.01131 .5143 -6 -4.5 ]
[.01131 .5143 0 4.5 ]
[.02381 .64303 -39 0 ]
[.02381 .64303 39 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .39946 m
.18254 .40571 L
s
[(0.5)] .18254 .38696 0 1 Mshowa
.34127 .39946 m
.34127 .40571 L
s
[(1)] .34127 .38696 0 1 Mshowa
.5 .39946 m
.5 .40571 L
s
[(1.5)] .5 .38696 0 1 Mshowa
.65873 .39946 m
.65873 .40571 L
s
[(2)] .65873 .38696 0 1 Mshowa
.81746 .39946 m
.81746 .40571 L
s
[(2.5)] .81746 .38696 0 1 Mshowa
.97619 .39946 m
.97619 .40571 L
s
[(3)] .97619 .38696 0 1 Mshowa
.125 Mabswid
.05556 .39946 m
.05556 .40321 L
s
.0873 .39946 m
.0873 .40321 L
s
.11905 .39946 m
.11905 .40321 L
s
.15079 .39946 m
.15079 .40321 L
s
.21429 .39946 m
.21429 .40321 L
s
.24603 .39946 m
.24603 .40321 L
s
.27778 .39946 m
.27778 .40321 L
s
.30952 .39946 m
.30952 .40321 L
s
.37302 .39946 m
.37302 .40321 L
s
.40476 .39946 m
.40476 .40321 L
s
.43651 .39946 m
.43651 .40321 L
s
.46825 .39946 m
.46825 .40321 L
s
.53175 .39946 m
.53175 .40321 L
s
.56349 .39946 m
.56349 .40321 L
s
.59524 .39946 m
.59524 .40321 L
s
.62698 .39946 m
.62698 .40321 L
s
.69048 .39946 m
.69048 .40321 L
s
.72222 .39946 m
.72222 .40321 L
s
.75397 .39946 m
.75397 .40321 L
s
.78571 .39946 m
.78571 .40321 L
s
.84921 .39946 m
.84921 .40321 L
s
.88095 .39946 m
.88095 .40321 L
s
.9127 .39946 m
.9127 .40321 L
s
.94444 .39946 m
.94444 .40321 L
s
.25 Mabswid
0 .39946 m
1 .39946 L
s
[(t)] 1.025 .39946 -1 0 Mshowa
.02381 .05495 m
.03006 .05495 L
s
[(-15)] .01131 .05495 1 0 Mshowa
.02381 .16979 m
.03006 .16979 L
s
[(-10)] .01131 .16979 1 0 Mshowa
.02381 .28462 m
.03006 .28462 L
s
[(-5)] .01131 .28462 1 0 Mshowa
.02381 .5143 m
.03006 .5143 L
s
[(5)] .01131 .5143 1 0 Mshowa
.125 Mabswid
.02381 .07792 m
.02756 .07792 L
s
.02381 .10088 m
.02756 .10088 L
s
.02381 .12385 m
.02756 .12385 L
s
.02381 .14682 m
.02756 .14682 L
s
.02381 .19275 m
.02756 .19275 L
s
.02381 .21572 m
.02756 .21572 L
s
.02381 .23869 m
.02756 .23869 L
s
.02381 .26166 m
.02756 .26166 L
s
.02381 .30759 m
.02756 .30759 L
s
.02381 .33056 m
.02756 .33056 L
s
.02381 .35353 m
.02756 .35353 L
s
.02381 .37649 m
.02756 .37649 L
s
.02381 .42243 m
.02756 .42243 L
s
.02381 .4454 m
.02756 .4454 L
s
.02381 .46836 m
.02756 .46836 L
s
.02381 .49133 m
.02756 .49133 L
s
.02381 .03198 m
.02756 .03198 L
s
.02381 .00901 m
.02756 .00901 L
s
.02381 .53727 m
.02756 .53727 L
s
.02381 .56023 m
.02756 .56023 L
s
.02381 .5832 m
.02756 .5832 L
s
.02381 .60617 m
.02756 .60617 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(``phi_2'\\(t\\)'')] .02381 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .39946 m
.02629 .60332 L
.02877 .5487 L
.03125 .49407 L
.03373 .50871 L
.03621 .45409 L
.03869 .46872 L
.04117 .48336 L
.04365 .47944 L
.04613 .42481 L
.04861 .43945 L
.05109 .45409 L
.05357 .45016 L
.05605 .4648 L
.05853 .46088 L
.06101 .45696 L
.06349 .45801 L
.06597 .40338 L
.06845 .41802 L
.07093 .43266 L
.07341 .42873 L
.07589 .44337 L
.07837 .43945 L
.08085 .43553 L
.08333 .43658 L
.08581 .45121 L
.08829 .44729 L
.09077 .44337 L
.09325 .44442 L
.09573 .4405 L
.09821 .44155 L
.10069 .4426 L
.10317 .44232 L
.10565 .3877 L
.10813 .40233 L
.11062 .41697 L
.1131 .41305 L
.11558 .42768 L
.11806 .42376 L
.12054 .41984 L
.12302 .42089 L
.1255 .43553 L
.12798 .43161 L
.13046 .42768 L
.13294 .42873 L
.13542 .42481 L
.1379 .42586 L
.14038 .42691 L
.14286 .42663 L
.14534 .44127 L
Mistroke
.14782 .43735 L
.1503 .43343 L
.15278 .43448 L
.15526 .43055 L
.15774 .43161 L
.16022 .43266 L
.1627 .43237 L
.16518 .42845 L
.16766 .4295 L
.17014 .43055 L
.17262 .43027 L
.1751 .43132 L
.17758 .43104 L
.18006 .43076 L
.18254 .43084 L
.18502 .37621 L
.1875 .39085 L
.18998 .40549 L
.19246 .40156 L
.19494 .4162 L
.19742 .41228 L
.1999 .40836 L
.20238 .40941 L
.20486 .42404 L
.20734 .42012 L
.20982 .4162 L
.2123 .41725 L
.21478 .41333 L
.21726 .41438 L
.21974 .41543 L
.22222 .41515 L
.2247 .42979 L
.22718 .42586 L
.22966 .42194 L
.23214 .42299 L
.23462 .41907 L
.2371 .42012 L
.23958 .42117 L
.24206 .42089 L
.24454 .41697 L
.24702 .41802 L
.2495 .41907 L
.25198 .41879 L
.25446 .41984 L
.25694 .41956 L
.25942 .41928 L
.2619 .41935 L
.26438 .43399 L
.26687 .43007 L
.26935 .42614 L
Mistroke
.27183 .4272 L
.27431 .42327 L
.27679 .42432 L
.27927 .42538 L
.28175 .42509 L
.28423 .42117 L
.28671 .42222 L
.28919 .42327 L
.29167 .42299 L
.29415 .42404 L
.29663 .42376 L
.29911 .42348 L
.30159 .42356 L
.30407 .41963 L
.30655 .42068 L
.30903 .42174 L
.31151 .42145 L
.31399 .4225 L
.31647 .42222 L
.31895 .42194 L
.32143 .42202 L
.32391 .42307 L
.32639 .42279 L
.32887 .4225 L
.33135 .42258 L
.33383 .4223 L
.33631 .42237 L
.33879 .42245 L
.34127 .42243 L
.34375 .01472 L
.34623 .12396 L
.34871 .23321 L
.35119 .20394 L
.35367 .31318 L
.35615 .28391 L
.35863 .25464 L
.36111 .26248 L
.36359 .37173 L
.36607 .34246 L
.36855 .31318 L
.37103 .32103 L
.37351 .29175 L
.37599 .2996 L
.37847 .30744 L
.38095 .30534 L
.38343 .41459 L
.38591 .38531 L
.38839 .35604 L
.39087 .36388 L
.39335 .33461 L
Mistroke
.39583 .34246 L
.39831 .3503 L
.40079 .3482 L
.40327 .31892 L
.40575 .32677 L
.40823 .33461 L
.41071 .33251 L
.41319 .34035 L
.41567 .33825 L
.41815 .33615 L
.42063 .33671 L
.42312 .44596 L
.4256 .41669 L
.42808 .38741 L
.43056 .39526 L
.43304 .36599 L
.43552 .37383 L
.438 .38167 L
.44048 .37957 L
.44296 .3503 L
.44544 .35814 L
.44792 .36599 L
.4504 .36388 L
.45288 .37173 L
.45536 .36963 L
.45784 .36752 L
.46032 .36809 L
.4628 .33881 L
.46528 .34666 L
.46776 .3545 L
.47024 .3524 L
.47272 .36024 L
.4752 .35814 L
.47768 .35604 L
.48016 .3566 L
.48264 .36445 L
.48512 .36235 L
.4876 .36024 L
.49008 .36081 L
.49256 .35871 L
.49504 .35927 L
.49752 .35983 L
.5 .35968 L
.50248 .46893 L
.50496 .43965 L
.50744 .41038 L
.50992 .41823 L
.5124 .38895 L
.51488 .3968 L
.51736 .40464 L
Mistroke
.51984 .40254 L
.52232 .37327 L
.5248 .38111 L
.52728 .38895 L
.52976 .38685 L
.53224 .3947 L
.53472 .39259 L
.5372 .39049 L
.53968 .39106 L
.54216 .36178 L
.54464 .36963 L
.54712 .37747 L
.5496 .37537 L
.55208 .38321 L
.55456 .38111 L
.55704 .37901 L
.55952 .37957 L
.562 .38741 L
.56448 .38531 L
.56696 .38321 L
.56944 .38377 L
.57192 .38167 L
.5744 .38224 L
.57688 .3828 L
.57937 .38265 L
.58185 .35338 L
.58433 .36122 L
.58681 .36906 L
.58929 .36696 L
.59177 .3748 L
.59425 .3727 L
.59673 .3706 L
.59921 .37116 L
.60169 .37901 L
.60417 .37691 L
.60665 .3748 L
.60913 .37537 L
.61161 .37327 L
.61409 .37383 L
.61657 .37439 L
.61905 .37424 L
.62153 .38209 L
.62401 .37998 L
.62649 .37788 L
.62897 .37845 L
.63145 .37634 L
.63393 .37691 L
.63641 .37747 L
.63889 .37732 L
.64137 .37522 L
Mistroke
.64385 .37578 L
.64633 .37634 L
.64881 .37619 L
.65129 .37676 L
.65377 .3766 L
.65625 .37645 L
.65873 .37649 L
.66121 .58035 L
.66369 .52573 L
.66617 .4711 L
.66865 .48574 L
.67113 .43112 L
.67361 .44575 L
.67609 .46039 L
.67857 .45647 L
.68105 .40185 L
.68353 .41648 L
.68601 .43112 L
.68849 .4272 L
.69097 .44183 L
.69345 .43791 L
.69593 .43399 L
.69841 .43504 L
.70089 .38042 L
.70337 .39505 L
.70585 .40969 L
.70833 .40577 L
.71081 .4204 L
.71329 .41648 L
.71577 .41256 L
.71825 .41361 L
.72073 .42825 L
.72321 .42432 L
.72569 .4204 L
.72817 .42145 L
.73065 .41753 L
.73313 .41858 L
.73562 .41963 L
.7381 .41935 L
.74058 .36473 L
.74306 .37937 L
.74554 .394 L
.74802 .39008 L
.7505 .40472 L
.75298 .40079 L
.75546 .39687 L
.75794 .39792 L
.76042 .41256 L
.7629 .40864 L
.76538 .40472 L
Mistroke
.76786 .40577 L
.77034 .40185 L
.77282 .4029 L
.7753 .40395 L
.77778 .40367 L
.78026 .4183 L
.78274 .41438 L
.78522 .41046 L
.7877 .41151 L
.79018 .40759 L
.79266 .40864 L
.79514 .40969 L
.79762 .40941 L
.8001 .40549 L
.80258 .40654 L
.80506 .40759 L
.80754 .40731 L
.81002 .40836 L
.8125 .40807 L
.81498 .40779 L
.81746 .40787 L
.81994 .35325 L
.82242 .36788 L
.8249 .38252 L
.82738 .3786 L
.82986 .39323 L
.83234 .38931 L
.83482 .38539 L
.8373 .38644 L
.83978 .40108 L
.84226 .39715 L
.84474 .39323 L
.84722 .39428 L
.8497 .39036 L
.85218 .39141 L
.85466 .39246 L
.85714 .39218 L
.85962 .40682 L
.8621 .4029 L
.86458 .39897 L
.86706 .40002 L
.86954 .3961 L
.87202 .39715 L
.8745 .3982 L
.87698 .39792 L
.87946 .394 L
.88194 .39505 L
.88442 .3961 L
.8869 .39582 L
.88938 .39687 L
Mistroke
.89187 .39659 L
.89435 .39631 L
.89683 .39638 L
.89931 .41102 L
.90179 .4071 L
.90427 .40318 L
.90675 .40423 L
.90923 .40031 L
.91171 .40136 L
.91419 .40241 L
.91667 .40213 L
.91915 .3982 L
.92163 .39926 L
.92411 .40031 L
.92659 .40002 L
.92907 .40108 L
.93155 .40079 L
.93403 .40051 L
.93651 .40059 L
.93899 .39667 L
.94147 .39772 L
.94395 .39877 L
.94643 .39849 L
.94891 .39954 L
.95139 .39926 L
.95387 .39897 L
.95635 .39905 L
.95883 .4001 L
.96131 .39982 L
.96379 .39954 L
.96627 .39961 L
.96875 .39933 L
.97123 .39941 L
.97371 .39948 L
.97619 .39946 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "Here is the second derivative of Daubechies ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_12\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.28"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[DScalingFunction[d12, 6, 2],
PlotRange -> All, PlotJoined -> True,
AxesLabel -> {\"t\", \"phi_12''(t)\"}]\
\>", "Input",
  CellLabel->"In[72]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0414079 0.27777 0.0791759 [
[.23085 .26527 -3 -9 ]
[.23085 .26527 3 0 ]
[.43789 .26527 -6 -9 ]
[.43789 .26527 6 0 ]
[.64493 .26527 -6 -9 ]
[.64493 .26527 6 0 ]
[.85197 .26527 -6 -9 ]
[.85197 .26527 6 0 ]
[1.025 .27777 0 -4.5 ]
[1.025 .27777 6 4.5 ]
[.01131 .04024 -12 -4.5 ]
[.01131 .04024 0 4.5 ]
[.01131 .11942 -12 -4.5 ]
[.01131 .11942 0 4.5 ]
[.01131 .19859 -12 -4.5 ]
[.01131 .19859 0 4.5 ]
[.01131 .35695 -6 -4.5 ]
[.01131 .35695 0 4.5 ]
[.01131 .43612 -6 -4.5 ]
[.01131 .43612 0 4.5 ]
[.01131 .5153 -6 -4.5 ]
[.01131 .5153 0 4.5 ]
[.01131 .59447 -6 -4.5 ]
[.01131 .59447 0 4.5 ]
[.02381 .64303 -33 0 ]
[.02381 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23085 .27777 m
.23085 .28402 L
s
[(5)] .23085 .26527 0 1 Mshowa
.43789 .27777 m
.43789 .28402 L
s
[(10)] .43789 .26527 0 1 Mshowa
.64493 .27777 m
.64493 .28402 L
s
[(15)] .64493 .26527 0 1 Mshowa
.85197 .27777 m
.85197 .28402 L
s
[(20)] .85197 .26527 0 1 Mshowa
.125 Mabswid
.06522 .27777 m
.06522 .28152 L
s
.10663 .27777 m
.10663 .28152 L
s
.14803 .27777 m
.14803 .28152 L
s
.18944 .27777 m
.18944 .28152 L
s
.27226 .27777 m
.27226 .28152 L
s
.31366 .27777 m
.31366 .28152 L
s
.35507 .27777 m
.35507 .28152 L
s
.39648 .27777 m
.39648 .28152 L
s
.4793 .27777 m
.4793 .28152 L
s
.5207 .27777 m
.5207 .28152 L
s
.56211 .27777 m
.56211 .28152 L
s
.60352 .27777 m
.60352 .28152 L
s
.68634 .27777 m
.68634 .28152 L
s
.72774 .27777 m
.72774 .28152 L
s
.76915 .27777 m
.76915 .28152 L
s
.81056 .27777 m
.81056 .28152 L
s
.89337 .27777 m
.89337 .28152 L
s
.93478 .27777 m
.93478 .28152 L
s
.97619 .27777 m
.97619 .28152 L
s
.25 Mabswid
0 .27777 m
1 .27777 L
s
[(t)] 1.025 .27777 -1 0 Mshowa
.02381 .04024 m
.03006 .04024 L
s
[(-3)] .01131 .04024 1 0 Mshowa
.02381 .11942 m
.03006 .11942 L
s
[(-2)] .01131 .11942 1 0 Mshowa
.02381 .19859 m
.03006 .19859 L
s
[(-1)] .01131 .19859 1 0 Mshowa
.02381 .35695 m
.03006 .35695 L
s
[(1)] .01131 .35695 1 0 Mshowa
.02381 .43612 m
.03006 .43612 L
s
[(2)] .01131 .43612 1 0 Mshowa
.02381 .5153 m
.03006 .5153 L
s
[(3)] .01131 .5153 1 0 Mshowa
.02381 .59447 m
.03006 .59447 L
s
[(4)] .01131 .59447 1 0 Mshowa
.125 Mabswid
.02381 .05608 m
.02756 .05608 L
s
.02381 .07191 m
.02756 .07191 L
s
.02381 .08775 m
.02756 .08775 L
s
.02381 .10358 m
.02756 .10358 L
s
.02381 .13525 m
.02756 .13525 L
s
.02381 .15109 m
.02756 .15109 L
s
.02381 .16692 m
.02756 .16692 L
s
.02381 .18276 m
.02756 .18276 L
s
.02381 .21443 m
.02756 .21443 L
s
.02381 .23026 m
.02756 .23026 L
s
.02381 .2461 m
.02756 .2461 L
s
.02381 .26193 m
.02756 .26193 L
s
.02381 .29361 m
.02756 .29361 L
s
.02381 .30944 m
.02756 .30944 L
s
.02381 .32528 m
.02756 .32528 L
s
.02381 .34111 m
.02756 .34111 L
s
.02381 .37278 m
.02756 .37278 L
s
.02381 .38862 m
.02756 .38862 L
s
.02381 .40445 m
.02756 .40445 L
s
.02381 .42029 m
.02756 .42029 L
s
.02381 .45196 m
.02756 .45196 L
s
.02381 .46779 m
.02756 .46779 L
s
.02381 .48363 m
.02756 .48363 L
s
.02381 .49946 m
.02756 .49946 L
s
.02381 .53113 m
.02756 .53113 L
s
.02381 .54697 m
.02756 .54697 L
s
.02381 .5628 m
.02756 .5628 L
s
.02381 .57864 m
.02756 .57864 L
s
.02381 .02441 m
.02756 .02441 L
s
.02381 .00857 m
.02756 .00857 L
s
.02381 .61031 m
.02756 .61031 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi_12''\\(t\\))] .02381 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .27777 m
.02446 .27777 L
.0251 .27777 L
.02575 .27777 L
.0264 .27777 L
.02704 .27777 L
.02769 .27777 L
.02834 .27777 L
.02899 .27778 L
.02963 .27778 L
.03028 .27778 L
.03093 .27779 L
.03157 .2778 L
.03222 .27781 L
.03287 .27782 L
.03351 .27783 L
.03416 .27785 L
.03481 .27787 L
.03546 .27789 L
.0361 .27792 L
.03675 .27796 L
.0374 .27799 L
.03804 .27804 L
.03869 .27808 L
.03934 .27814 L
.03998 .2782 L
.04063 .27827 L
.04128 .27834 L
.04193 .27843 L
.04257 .27852 L
.04322 .27862 L
.04387 .27873 L
.04451 .27885 L
.04516 .27898 L
.04581 .27912 L
.04645 .27928 L
.0471 .27945 L
.04775 .27963 L
.0484 .27983 L
.04904 .28004 L
.04969 .28027 L
.05034 .28052 L
.05098 .28078 L
.05163 .28106 L
.05228 .28136 L
.05292 .28168 L
.05357 .28202 L
.05422 .28237 L
.05487 .28275 L
.05551 .28315 L
Mistroke
.05616 .28358 L
.05681 .28402 L
.05745 .28449 L
.0581 .28498 L
.05875 .28549 L
.05939 .28604 L
.06004 .28661 L
.06069 .28721 L
.06134 .28784 L
.06198 .2885 L
.06263 .28919 L
.06328 .28992 L
.06392 .29068 L
.06457 .29147 L
.06522 .29231 L
.06586 .29318 L
.06651 .29409 L
.06716 .29503 L
.06781 .29602 L
.06845 .29705 L
.0691 .29812 L
.06975 .29923 L
.07039 .30038 L
.07104 .30157 L
.07169 .30279 L
.07233 .30405 L
.07298 .30534 L
.07363 .30667 L
.07428 .30804 L
.07492 .30943 L
.07557 .31086 L
.07622 .31231 L
.07686 .31379 L
.07751 .31529 L
.07816 .31682 L
.0788 .31837 L
.07945 .31993 L
.0801 .3215 L
.08075 .32309 L
.08139 .32469 L
.08204 .32631 L
.08269 .32793 L
.08333 .32955 L
.08398 .33116 L
.08463 .33277 L
.08527 .33437 L
.08592 .33596 L
.08657 .33751 L
.08722 .33904 L
.08786 .34054 L
Mistroke
.08851 .342 L
.08916 .34341 L
.0898 .34479 L
.09045 .34612 L
.0911 .3474 L
.09174 .34862 L
.09239 .34978 L
.09304 .35088 L
.09369 .35191 L
.09433 .35286 L
.09498 .35375 L
.09563 .35455 L
.09627 .35527 L
.09692 .35592 L
.09757 .35649 L
.09821 .35698 L
.09886 .35737 L
.09951 .35767 L
.10016 .35786 L
.1008 .35795 L
.10145 .35791 L
.1021 .35774 L
.10274 .35743 L
.10339 .35697 L
.10404 .35636 L
.10468 .35559 L
.10533 .35466 L
.10598 .35356 L
.10663 .35228 L
.10727 .35081 L
.10792 .34914 L
.10857 .34727 L
.10921 .3452 L
.10986 .34291 L
.11051 .34041 L
.11115 .33768 L
.1118 .33473 L
.11245 .33159 L
.1131 .32825 L
.11374 .3247 L
.11439 .32094 L
.11504 .31698 L
.11568 .3128 L
.11633 .30842 L
.11698 .30384 L
.11762 .29904 L
.11827 .29405 L
.11892 .28884 L
.11957 .28344 L
.12021 .27787 L
Mistroke
.12086 .27213 L
.12151 .26623 L
.12215 .26016 L
.1228 .25392 L
.12345 .24751 L
.12409 .24097 L
.12474 .2343 L
.12539 .2275 L
.12604 .22061 L
.12668 .21363 L
.12733 .20659 L
.12798 .19951 L
.12862 .19244 L
.12927 .18537 L
.12992 .17832 L
.13056 .17128 L
.13121 .16426 L
.13186 .15728 L
.13251 .15036 L
.13315 .14349 L
.1338 .1367 L
.13445 .12996 L
.13509 .12329 L
.13574 .11673 L
.13639 .11029 L
.13703 .10395 L
.13768 .09771 L
.13833 .09156 L
.13898 .08548 L
.13962 .07952 L
.14027 .07367 L
.14092 .06795 L
.14156 .06239 L
.14221 .05699 L
.14286 .05179 L
.1435 .04685 L
.14415 .04223 L
.1448 .03791 L
.14545 .03393 L
.14609 .03026 L
.14674 .02689 L
.14739 .02391 L
.14803 .02131 L
.14868 .01911 L
.14933 .01735 L
.14997 .01601 L
.15062 .0151 L
.15127 .01472 L
.15192 .01485 L
.15256 .0155 L
Mistroke
.15321 .01665 L
.15386 .01825 L
.1545 .02025 L
.15515 .02273 L
.1558 .02569 L
.15644 .02913 L
.15709 .03311 L
.15774 .03756 L
.15839 .04251 L
.15903 .04804 L
.15968 .05414 L
.16033 .06081 L
.16097 .06804 L
.16162 .07575 L
.16227 .08389 L
.16291 .09251 L
.16356 .10161 L
.16421 .11117 L
.16486 .12121 L
.1655 .13163 L
.16615 .14241 L
.1668 .15358 L
.16744 .16508 L
.16809 .17687 L
.16874 .1889 L
.16938 .20102 L
.17003 .21316 L
.17068 .22535 L
.17133 .23753 L
.17197 .24973 L
.17262 .26196 L
.17327 .27413 L
.17391 .28625 L
.17456 .29839 L
.17521 .31054 L
.17585 .3227 L
.1765 .33486 L
.17715 .34691 L
.1778 .35883 L
.17844 .37068 L
.17909 .38249 L
.17974 .39429 L
.18038 .40616 L
.18103 .41797 L
.18168 .42972 L
.18232 .44147 L
.18297 .45317 L
.18362 .46477 L
.18427 .47622 L
.18491 .48729 L
Mistroke
.18556 .49789 L
.18621 .50805 L
.18685 .51776 L
.1875 .52708 L
.18815 .53606 L
.18879 .54452 L
.18944 .55246 L
.19009 .55994 L
.19073 .56689 L
.19138 .57338 L
.19203 .57936 L
.19268 .58459 L
.19332 .58904 L
.19397 .59281 L
.19462 .59591 L
.19526 .59849 L
.19591 .60064 L
.19656 .60217 L
.1972 .60305 L
.19785 .60332 L
.1985 .60287 L
.19915 .60178 L
.19979 .6 L
.20044 .59724 L
.20109 .59345 L
.20173 .58869 L
.20238 .58295 L
.20303 .57646 L
.20367 .56932 L
.20432 .56136 L
.20497 .55262 L
.20562 .5432 L
.20626 .53306 L
.20691 .52241 L
.20756 .51131 L
.2082 .49956 L
.20885 .48726 L
.2095 .47456 L
.21014 .46154 L
.21079 .44854 L
.21144 .43573 L
.21209 .42296 L
.21273 .41033 L
.21338 .39788 L
.21403 .38554 L
.21467 .37346 L
.21532 .36162 L
.21597 .34969 L
.21661 .33766 L
.21726 .32556 L
Mistroke
.21791 .31338 L
.21856 .30141 L
.2192 .28973 L
.21985 .27808 L
.2205 .26645 L
.22114 .25482 L
.22179 .24307 L
.22244 .23142 L
.22308 .21986 L
.22373 .20809 L
.22438 .19619 L
.22503 .18427 L
.22567 .17243 L
.22632 .16113 L
.22697 .15056 L
.22761 .14049 L
.22826 .13095 L
.22891 .12185 L
.22955 .11303 L
.2302 .10479 L
.23085 .09711 L
.2315 .08964 L
.23214 .08245 L
.23279 .07545 L
.23344 .06867 L
.23408 .06263 L
.23473 .05742 L
.23538 .05273 L
.23602 .04857 L
.23667 .04474 L
.23732 .04104 L
.23797 .03791 L
.23861 .03539 L
.23926 .03322 L
.23991 .03162 L
.24055 .03055 L
.2412 .03011 L
.24185 .03093 L
.24249 .03317 L
.24314 .03662 L
.24379 .04131 L
.24444 .04695 L
.24508 .0533 L
.24573 .06072 L
.24638 .06908 L
.24702 .07805 L
.24767 .08765 L
.24832 .09758 L
.24896 .10776 L
.24961 .11869 L
Mistroke
.25026 .13031 L
.25091 .14223 L
.25155 .15434 L
.2522 .16619 L
.25285 .17745 L
.25349 .1885 L
.25414 .19923 L
.25479 .20931 L
.25543 .2189 L
.25608 .22784 L
.25673 .23623 L
.25738 .24478 L
.25802 .25361 L
.25867 .26251 L
.25932 .2715 L
.25996 .28018 L
.26061 .28829 L
.26126 .2964 L
.2619 .30444 L
.26255 .31219 L
.2632 .31983 L
.26385 .32704 L
.26449 .33384 L
.26514 .34096 L
.26579 .34837 L
.26643 .35575 L
.26708 .363 L
.26773 .36949 L
.26837 .37491 L
.26902 .37983 L
.26967 .38424 L
.27032 .38804 L
.27096 .39155 L
.27161 .39443 L
.27226 .39678 L
.2729 .39941 L
.27355 .40238 L
.2742 .40561 L
.27484 .40915 L
.27549 .41229 L
.27614 .41479 L
.27679 .41727 L
.27743 .41967 L
.27808 .42201 L
.27873 .42453 L
.27937 .42663 L
.28002 .42826 L
.28067 .43004 L
.28131 .43174 L
.28196 .43318 L
Mistroke
.28261 .43426 L
.28326 .43405 L
.2839 .43227 L
.28455 .42936 L
.2852 .42525 L
.28584 .42008 L
.28649 .4142 L
.28714 .40716 L
.28778 .39915 L
.28843 .39093 L
.28908 .38254 L
.28973 .37418 L
.29037 .36594 L
.29102 .35705 L
.29167 .34743 L
.29231 .33777 L
.29296 .32813 L
.29361 .31881 L
.29425 .31022 L
.2949 .30178 L
.29555 .29361 L
.2962 .28645 L
.29684 .28016 L
.29749 .27467 L
.29814 .2699 L
.29878 .2648 L
.29943 .25906 L
.30008 .25326 L
.30072 .24735 L
.30137 .24165 L
.30202 .23655 L
.30267 .23138 L
.30331 .22624 L
.30396 .22183 L
.30461 .21803 L
.30525 .21508 L
.3059 .21299 L
.30655 .21067 L
.30719 .208 L
.30784 .20562 L
.30849 .20353 L
.30914 .20225 L
.30978 .20217 L
.31043 .20243 L
.31108 .20302 L
.31172 .20443 L
.31237 .20627 L
.31302 .2087 L
.31366 .21159 L
.31431 .21374 L
Mistroke
.31496 .21492 L
.31561 .21549 L
.31625 .21532 L
.3169 .21502 L
.31755 .21495 L
.31819 .21434 L
.31884 .2133 L
.31949 .21227 L
.32013 .21104 L
.32078 .21014 L
.32143 .20964 L
.32208 .20861 L
.32272 .20711 L
.32337 .20566 L
.32402 .20434 L
.32466 .20394 L
.32531 .20489 L
.32596 .20648 L
.3266 .20883 L
.32725 .21225 L
.3279 .21637 L
.32855 .2215 L
.32919 .22747 L
.32984 .23316 L
.33049 .23838 L
.33113 .24331 L
.33178 .24786 L
.33243 .25275 L
.33307 .25825 L
.33372 .26351 L
.33437 .26856 L
.33502 .2736 L
.33566 .27828 L
.33631 .28313 L
.33696 .28809 L
.3376 .29208 L
.33825 .29515 L
.3389 .29767 L
.33954 .29971 L
.34019 .30222 L
.34084 .30563 L
.34149 .30909 L
.34213 .31264 L
.34278 .31636 L
.34343 .31977 L
.34407 .32342 L
.34472 .32717 L
.34537 .32992 L
.34601 .33164 L
.34666 .33236 L
Mistroke
.34731 .33204 L
.34796 .33169 L
.3486 .33161 L
.34925 .33097 L
.3499 .32986 L
.35054 .32823 L
.35119 .3257 L
.35184 .32313 L
.35248 .32054 L
.35313 .31709 L
.35378 .31305 L
.35443 .30859 L
.35507 .30381 L
.35572 .29985 L
.35637 .2971 L
.35701 .29491 L
.35766 .29344 L
.35831 .29253 L
.35895 .29178 L
.3596 .29185 L
.36025 .29259 L
.3609 .29315 L
.36154 .29357 L
.36219 .29369 L
.36284 .29341 L
.36348 .29368 L
.36413 .29461 L
.36478 .29549 L
.36542 .29633 L
.36607 .29683 L
.36672 .29659 L
.36737 .2963 L
.36801 .29588 L
.36866 .2946 L
.36931 .29266 L
.36995 .29009 L
.3706 .287 L
.37125 .28445 L
.37189 .28274 L
.37254 .28133 L
.37319 .28029 L
.37384 .27932 L
.37448 .27803 L
.37513 .27712 L
.37578 .27652 L
.37642 .27554 L
.37707 .27435 L
.37772 .2727 L
.37836 .27058 L
.37901 .26901 L
Mistroke
.37966 .26811 L
.38031 .26729 L
.38095 .26655 L
.3816 .26541 L
.38225 .26349 L
.38289 .26158 L
.38354 .2597 L
.38419 .25735 L
.38483 .25489 L
.38548 .25214 L
.38613 .24919 L
.38678 .24713 L
.38742 .24612 L
.38807 .24584 L
.38872 .24637 L
.38936 .24717 L
.39001 .2479 L
.39066 .24924 L
.3913 .2511 L
.39195 .25307 L
.3926 .25532 L
.39325 .25741 L
.39389 .25928 L
.39454 .26177 L
.39519 .26485 L
.39583 .26809 L
.39648 .27146 L
.39713 .27433 L
.39777 .27634 L
.39842 .27812 L
.39907 .27956 L
.39972 .28037 L
.40036 .28081 L
.40101 .28061 L
.40166 .27986 L
.4023 .27946 L
.40295 .27951 L
.4036 .27981 L
.40424 .28042 L
.40489 .28081 L
.40554 .28073 L
.40619 .2808 L
.40683 .28098 L
.40748 .28102 L
.40813 .28115 L
.40877 .28098 L
.40942 .28053 L
.41007 .2806 L
.41071 .28116 L
.41136 .28191 L
Mistroke
.41201 .28284 L
.41266 .28333 L
.4133 .28307 L
.41395 .28269 L
.4146 .28214 L
.41524 .28128 L
.41589 .28042 L
.41654 .27921 L
.41718 .27773 L
.41783 .27675 L
.41848 .27629 L
.41913 .27627 L
.41977 .27675 L
.42042 .27711 L
.42107 .27717 L
.42171 .27746 L
.42236 .27794 L
.42301 .27856 L
.42365 .27954 L
.4243 .28041 L
.42495 .28115 L
.4256 .28233 L
.42624 .28384 L
.42689 .28552 L
.42754 .28735 L
.42818 .2887 L
.42883 .28933 L
.42948 .28968 L
.43012 .28966 L
.43077 .2893 L
.43142 .28884 L
.43207 .28793 L
.43271 .28664 L
.43336 .28552 L
.43401 .28455 L
.43465 .28378 L
.4353 .28325 L
.43595 .28246 L
.43659 .28129 L
.43724 .28016 L
.43789 .27905 L
.43854 .27805 L
.43918 .27736 L
.43983 .2766 L
.44048 .27581 L
.44112 .27544 L
.44177 .27541 L
.44242 .27566 L
.44306 .27616 L
.44371 .27637 L
Mistroke
.44436 .27611 L
.44501 .27574 L
.44565 .27521 L
.4463 .27461 L
.44695 .27417 L
.44759 .27353 L
.44824 .27275 L
.44889 .27226 L
.44953 .27199 L
.45018 .27203 L
.45083 .2724 L
.45148 .27258 L
.45212 .27251 L
.45277 .27249 L
.45342 .27252 L
.45406 .27273 L
.45471 .2733 L
.45536 .27385 L
.456 .27438 L
.45665 .27521 L
.4573 .27619 L
.45795 .27736 L
.45859 .2787 L
.45924 .2797 L
.45989 .28026 L
.46053 .2806 L
.46118 .28069 L
.46183 .28066 L
.46247 .28068 L
.46312 .28045 L
.46377 .28002 L
.46442 .27964 L
.46506 .27926 L
.46571 .279 L
.46636 .2789 L
.467 .27857 L
.46765 .27798 L
.4683 .27736 L
.46894 .2767 L
.46959 .27618 L
.47024 .27594 L
.47089 .2757 L
.47153 .27549 L
.47218 .27553 L
.47283 .27572 L
.47347 .2761 L
.47412 .27668 L
.47477 .27706 L
.47541 .2772 L
.47606 .27724 L
Mistroke
.47671 .27714 L
.47736 .27706 L
.478 .27711 L
.47865 .27706 L
.4793 .27693 L
.47994 .2769 L
.48059 .27689 L
.48124 .27702 L
.48188 .2773 L
.48253 .2774 L
.48318 .27732 L
.48383 .27721 L
.48447 .27706 L
.48512 .27704 L
.48577 .27726 L
.48641 .27749 L
.48706 .27774 L
.48771 .27813 L
.48835 .27855 L
.489 .27909 L
.48965 .27974 L
.4903 .28019 L
.49094 .28041 L
.49159 .2805 L
.49224 .28041 L
.49288 .28032 L
.49353 .28031 L
.49418 .28019 L
.49482 .27998 L
.49547 .27976 L
.49612 .27949 L
.49677 .27927 L
.49741 .27913 L
.49806 .27885 L
.49871 .27843 L
.49935 .27796 L
.5 .27744 L
.50065 .27703 L
.50129 .27682 L
.50194 .27665 L
.50259 .27652 L
.50323 .27652 L
.50388 .27655 L
.50453 .27672 L
.50518 .27699 L
.50582 .27717 L
.50647 .27725 L
.50712 .27726 L
.50776 .27718 L
.50841 .27715 L
Mistroke
.50906 .27722 L
.5097 .27725 L
.51035 .27727 L
.511 .2773 L
.51165 .2773 L
.51229 .27737 L
.51294 .2775 L
.51359 .27753 L
.51423 .27746 L
.51488 .27735 L
.51553 .2772 L
.51617 .27713 L
.51682 .2772 L
.51747 .27728 L
.51812 .2774 L
.51876 .27756 L
.51941 .27773 L
.52006 .27796 L
.5207 .27826 L
.52135 .27846 L
.522 .27857 L
.52264 .2786 L
.52329 .27855 L
.52394 .27852 L
.52459 .27855 L
.52523 .27855 L
.52588 .27851 L
.52653 .27847 L
.52717 .27836 L
.52782 .27829 L
.52847 .27824 L
.52911 .27812 L
.52976 .27794 L
.53041 .27772 L
.53106 .27746 L
.5317 .27727 L
.53235 .27719 L
.533 .27713 L
.53364 .2771 L
.53429 .27712 L
.53494 .27714 L
.53558 .27722 L
.53623 .27736 L
.53688 .27745 L
.53753 .27751 L
.53817 .27753 L
.53882 .27751 L
.53947 .27753 L
.54011 .27759 L
.54076 .27765 L
Mistroke
.54141 .27771 L
.54205 .27776 L
.5427 .27777 L
.54335 .27781 L
.544 .27787 L
.54464 .27787 L
.54529 .27783 L
.54594 .27777 L
.54658 .27767 L
.54723 .27762 L
.54788 .27763 L
.54852 .27766 L
.54917 .2777 L
.54982 .27777 L
.55047 .27782 L
.55111 .2779 L
.55176 .278 L
.55241 .27807 L
.55305 .27811 L
.5537 .27811 L
.55435 .27808 L
.55499 .27806 L
.55564 .27808 L
.55629 .2781 L
.55694 .2781 L
.55758 .27809 L
.55823 .27805 L
.55888 .27802 L
.55952 .278 L
.56017 .27794 L
.56082 .27787 L
.56146 .27777 L
.56211 .27765 L
.56276 .27756 L
.56341 .27752 L
.56405 .2775 L
.5647 .2775 L
.56535 .27751 L
.56599 .27751 L
.56664 .27754 L
.56729 .27759 L
.56793 .27762 L
.56858 .27765 L
.56923 .27766 L
.56988 .27764 L
.57052 .27765 L
.57117 .27768 L
.57182 .27772 L
.57246 .27775 L
.57311 .27778 L
Mistroke
.57376 .27779 L
.5744 .2778 L
.57505 .27783 L
.5757 .27782 L
.57635 .27781 L
.57699 .27778 L
.57764 .27773 L
.57829 .27771 L
.57893 .27771 L
.57958 .27772 L
.58023 .27773 L
.58087 .27776 L
.58152 .27777 L
.58217 .27779 L
.58282 .27783 L
.58346 .27785 L
.58411 .27787 L
.58476 .27787 L
.5854 .27785 L
.58605 .27785 L
.5867 .27786 L
.58734 .27787 L
.58799 .27788 L
.58864 .27788 L
.58929 .27787 L
.58993 .27786 L
.59058 .27786 L
.59123 .27784 L
.59187 .27781 L
.59252 .27778 L
.59317 .27773 L
.59381 .2777 L
.59446 .27769 L
.59511 .27768 L
.59576 .27768 L
.5964 .27769 L
.59705 .27769 L
.5977 .27769 L
.59834 .27771 L
.59899 .27772 L
.59964 .27773 L
.60028 .27773 L
.60093 .27773 L
.60158 .27773 L
.60223 .27774 L
.60287 .27776 L
.60352 .27777 L
.60417 .27779 L
.60481 .27779 L
.60546 .27779 L
Mistroke
.60611 .2778 L
.60675 .2778 L
.6074 .27779 L
.60805 .27778 L
.6087 .27776 L
.60934 .27775 L
.60999 .27775 L
.61064 .27775 L
.61128 .27776 L
.61193 .27776 L
.61258 .27777 L
.61322 .27777 L
.61387 .27778 L
.61452 .27779 L
.61517 .27779 L
.61581 .27779 L
.61646 .27779 L
.61711 .27779 L
.61775 .27779 L
.6184 .2778 L
.61905 .2778 L
.61969 .27781 L
.62034 .2778 L
.62099 .2778 L
.62164 .2778 L
.62228 .27779 L
.62293 .27778 L
.62358 .27777 L
.62422 .27776 L
.62487 .27775 L
.62552 .27774 L
.62616 .27774 L
.62681 .27774 L
.62746 .27775 L
.62811 .27775 L
.62875 .27775 L
.6294 .27775 L
.63005 .27776 L
.63069 .27776 L
.63134 .27776 L
.63199 .27776 L
.63263 .27776 L
.63328 .27776 L
.63393 .27777 L
.63458 .27777 L
.63522 .27778 L
.63587 .27778 L
.63652 .27778 L
.63716 .27778 L
.63781 .27778 L
Mistroke
.63846 .27778 L
.6391 .27777 L
.63975 .27777 L
.6404 .27776 L
.64105 .27776 L
.64169 .27776 L
.64234 .27777 L
.64299 .27777 L
.64363 .27777 L
.64428 .27777 L
.64493 .27777 L
.64557 .27777 L
.64622 .27778 L
.64687 .27777 L
.64752 .27777 L
.64816 .27777 L
.64881 .27777 L
.64946 .27778 L
.6501 .27778 L
.65075 .27778 L
.6514 .27778 L
.65204 .27778 L
.65269 .27778 L
.65334 .27778 L
.65399 .27778 L
.65463 .27777 L
.65528 .27777 L
.65593 .27777 L
.65657 .27776 L
.65722 .27776 L
.65787 .27776 L
.65851 .27776 L
.65916 .27776 L
.65981 .27776 L
.66046 .27777 L
.6611 .27777 L
.66175 .27777 L
.6624 .27777 L
.66304 .27777 L
.66369 .27777 L
.66434 .27777 L
.66498 .27777 L
.66563 .27777 L
.66628 .27777 L
.66693 .27777 L
.66757 .27777 L
.66822 .27777 L
.66887 .27777 L
.66951 .27777 L
.67016 .27777 L
Mistroke
.67081 .27777 L
.67145 .27777 L
.6721 .27777 L
.67275 .27777 L
.6734 .27777 L
.67404 .27777 L
.67469 .27777 L
.67534 .27777 L
.67598 .27777 L
.67663 .27777 L
.67728 .27777 L
.67792 .27777 L
.67857 .27777 L
.67922 .27777 L
.67987 .27777 L
.68051 .27777 L
.68116 .27777 L
.68181 .27777 L
.68245 .27777 L
.6831 .27777 L
.68375 .27777 L
.68439 .27777 L
.68504 .27777 L
.68569 .27777 L
.68634 .27777 L
.68698 .27777 L
.68763 .27777 L
.68828 .27777 L
.68892 .27777 L
.68957 .27777 L
.69022 .27777 L
.69086 .27777 L
.69151 .27777 L
.69216 .27777 L
.69281 .27777 L
.69345 .27777 L
.6941 .27777 L
.69475 .27777 L
.69539 .27777 L
.69604 .27777 L
.69669 .27777 L
.69733 .27777 L
.69798 .27777 L
.69863 .27777 L
.69928 .27777 L
.69992 .27777 L
.70057 .27777 L
.70122 .27777 L
.70186 .27777 L
.70251 .27777 L
Mistroke
.70316 .27777 L
.7038 .27777 L
.70445 .27777 L
.7051 .27777 L
.70575 .27777 L
.70639 .27777 L
.70704 .27777 L
.70769 .27777 L
.70833 .27777 L
.70898 .27777 L
.70963 .27777 L
.71027 .27777 L
.71092 .27777 L
.71157 .27777 L
.71222 .27777 L
.71286 .27777 L
.71351 .27777 L
.71416 .27777 L
.7148 .27777 L
.71545 .27777 L
.7161 .27777 L
.71674 .27777 L
.71739 .27777 L
.71804 .27777 L
.71869 .27777 L
.71933 .27777 L
.71998 .27777 L
.72063 .27777 L
.72127 .27777 L
.72192 .27777 L
.72257 .27777 L
.72321 .27777 L
.72386 .27777 L
.72451 .27777 L
.72516 .27777 L
.7258 .27777 L
.72645 .27777 L
.7271 .27777 L
.72774 .27777 L
.72839 .27777 L
.72904 .27777 L
.72968 .27777 L
.73033 .27777 L
.73098 .27777 L
.73163 .27777 L
.73227 .27777 L
.73292 .27777 L
.73357 .27777 L
.73421 .27777 L
.73486 .27777 L
Mistroke
.73551 .27777 L
.73615 .27777 L
.7368 .27777 L
.73745 .27777 L
.7381 .27777 L
.73874 .27777 L
.73939 .27777 L
.74004 .27777 L
.74068 .27777 L
.74133 .27777 L
.74198 .27777 L
.74262 .27777 L
.74327 .27777 L
.74392 .27777 L
.74457 .27777 L
.74521 .27777 L
.74586 .27777 L
.74651 .27777 L
.74715 .27777 L
.7478 .27777 L
.74845 .27777 L
.74909 .27777 L
.74974 .27777 L
.75039 .27777 L
.75104 .27777 L
.75168 .27777 L
.75233 .27777 L
.75298 .27777 L
.75362 .27777 L
.75427 .27777 L
.75492 .27777 L
.75556 .27777 L
.75621 .27777 L
.75686 .27777 L
.75751 .27777 L
.75815 .27777 L
.7588 .27777 L
.75945 .27777 L
.76009 .27777 L
.76074 .27777 L
.76139 .27777 L
.76203 .27777 L
.76268 .27777 L
.76333 .27777 L
.76398 .27777 L
.76462 .27777 L
.76527 .27777 L
.76592 .27777 L
.76656 .27777 L
.76721 .27777 L
Mistroke
.76786 .27777 L
.7685 .27777 L
.76915 .27777 L
.7698 .27777 L
.77045 .27777 L
.77109 .27777 L
.77174 .27777 L
.77239 .27777 L
.77303 .27777 L
.77368 .27777 L
.77433 .27777 L
.77497 .27777 L
.77562 .27777 L
.77627 .27777 L
.77692 .27777 L
.77756 .27777 L
.77821 .27777 L
.77886 .27777 L
.7795 .27777 L
.78015 .27777 L
.7808 .27777 L
.78144 .27777 L
.78209 .27777 L
.78274 .27777 L
.78339 .27777 L
.78403 .27777 L
.78468 .27777 L
.78533 .27777 L
.78597 .27777 L
.78662 .27777 L
.78727 .27777 L
.78791 .27777 L
.78856 .27777 L
.78921 .27777 L
.78986 .27777 L
.7905 .27777 L
.79115 .27777 L
.7918 .27777 L
.79244 .27777 L
.79309 .27777 L
.79374 .27777 L
.79438 .27777 L
.79503 .27777 L
.79568 .27777 L
.79633 .27777 L
.79697 .27777 L
.79762 .27777 L
.79827 .27777 L
.79891 .27777 L
.79956 .27777 L
Mistroke
.80021 .27777 L
.80085 .27777 L
.8015 .27777 L
.80215 .27777 L
.8028 .27777 L
.80344 .27777 L
.80409 .27777 L
.80474 .27777 L
.80538 .27777 L
.80603 .27777 L
.80668 .27777 L
.80732 .27777 L
.80797 .27777 L
.80862 .27777 L
.80927 .27777 L
.80991 .27777 L
.81056 .27777 L
.81121 .27777 L
.81185 .27777 L
.8125 .27777 L
.81315 .27777 L
.81379 .27777 L
.81444 .27777 L
.81509 .27777 L
.81573 .27777 L
.81638 .27777 L
.81703 .27777 L
.81768 .27777 L
.81832 .27777 L
.81897 .27777 L
.81962 .27777 L
.82026 .27777 L
.82091 .27777 L
.82156 .27777 L
.8222 .27777 L
.82285 .27777 L
.8235 .27777 L
.82415 .27777 L
.82479 .27777 L
.82544 .27777 L
.82609 .27777 L
.82673 .27777 L
.82738 .27777 L
.82803 .27777 L
.82867 .27777 L
.82932 .27777 L
.82997 .27777 L
.83062 .27777 L
.83126 .27777 L
.83191 .27777 L
Mistroke
.83256 .27777 L
.8332 .27777 L
.83385 .27777 L
.8345 .27777 L
.83514 .27777 L
.83579 .27777 L
.83644 .27777 L
.83709 .27777 L
.83773 .27777 L
.83838 .27777 L
.83903 .27777 L
.83967 .27777 L
.84032 .27777 L
.84097 .27777 L
.84161 .27777 L
.84226 .27777 L
.84291 .27777 L
.84356 .27777 L
.8442 .27777 L
.84485 .27777 L
.8455 .27777 L
.84614 .27777 L
.84679 .27777 L
.84744 .27777 L
.84808 .27777 L
.84873 .27777 L
.84938 .27777 L
.85003 .27777 L
.85067 .27777 L
.85132 .27777 L
.85197 .27777 L
.85261 .27777 L
.85326 .27777 L
.85391 .27777 L
.85455 .27777 L
.8552 .27777 L
.85585 .27777 L
.8565 .27777 L
.85714 .27777 L
.85779 .27777 L
.85844 .27777 L
.85908 .27777 L
.85973 .27777 L
.86038 .27777 L
.86102 .27777 L
.86167 .27777 L
.86232 .27777 L
.86297 .27777 L
.86361 .27777 L
.86426 .27777 L
Mistroke
.86491 .27777 L
.86555 .27777 L
.8662 .27777 L
.86685 .27777 L
.86749 .27777 L
.86814 .27777 L
.86879 .27777 L
.86944 .27777 L
.87008 .27777 L
.87073 .27777 L
.87138 .27777 L
.87202 .27777 L
.87267 .27777 L
.87332 .27777 L
.87396 .27777 L
.87461 .27777 L
.87526 .27777 L
.87591 .27777 L
.87655 .27777 L
.8772 .27777 L
.87785 .27777 L
.87849 .27777 L
.87914 .27777 L
.87979 .27777 L
.88043 .27777 L
.88108 .27777 L
.88173 .27777 L
.88238 .27777 L
.88302 .27777 L
.88367 .27777 L
.88432 .27777 L
.88496 .27777 L
.88561 .27777 L
.88626 .27777 L
.8869 .27777 L
.88755 .27777 L
.8882 .27777 L
.88885 .27777 L
.88949 .27777 L
.89014 .27777 L
.89079 .27777 L
.89143 .27777 L
.89208 .27777 L
.89273 .27777 L
.89337 .27777 L
.89402 .27777 L
.89467 .27777 L
.89532 .27777 L
.89596 .27777 L
.89661 .27777 L
Mistroke
.89726 .27777 L
.8979 .27777 L
.89855 .27777 L
.8992 .27777 L
.89984 .27777 L
.90049 .27777 L
.90114 .27777 L
.90179 .27777 L
.90243 .27777 L
.90308 .27777 L
.90373 .27777 L
.90437 .27777 L
.90502 .27777 L
.90567 .27777 L
.90631 .27777 L
.90696 .27777 L
.90761 .27777 L
.90826 .27777 L
.9089 .27777 L
.90955 .27777 L
.9102 .27777 L
.91084 .27777 L
.91149 .27777 L
.91214 .27777 L
.91278 .27777 L
.91343 .27777 L
.91408 .27777 L
.91473 .27777 L
.91537 .27777 L
.91602 .27777 L
.91667 .27777 L
.91731 .27777 L
.91796 .27777 L
.91861 .27777 L
.91925 .27777 L
.9199 .27777 L
.92055 .27777 L
.9212 .27777 L
.92184 .27777 L
.92249 .27777 L
.92314 .27777 L
.92378 .27777 L
.92443 .27777 L
.92508 .27777 L
.92572 .27777 L
.92637 .27777 L
.92702 .27777 L
.92767 .27777 L
.92831 .27777 L
.92896 .27777 L
Mistroke
.92961 .27777 L
.93025 .27777 L
.9309 .27777 L
.93155 .27777 L
.93219 .27777 L
.93284 .27777 L
.93349 .27777 L
.93414 .27777 L
.93478 .27777 L
.93543 .27777 L
.93608 .27777 L
.93672 .27777 L
.93737 .27777 L
.93802 .27777 L
.93866 .27777 L
.93931 .27777 L
.93996 .27777 L
.94061 .27777 L
.94125 .27777 L
.9419 .27777 L
.94255 .27777 L
.94319 .27777 L
.94384 .27777 L
.94449 .27777 L
.94513 .27777 L
.94578 .27777 L
.94643 .27777 L
.94708 .27777 L
.94772 .27777 L
.94837 .27777 L
.94902 .27777 L
.94966 .27777 L
.95031 .27777 L
.95096 .27777 L
.9516 .27777 L
.95225 .27777 L
.9529 .27777 L
.95355 .27777 L
.95419 .27777 L
.95484 .27777 L
.95549 .27777 L
.95613 .27777 L
.95678 .27777 L
.95743 .27777 L
.95807 .27777 L
.95872 .27777 L
.95937 .27777 L
.96002 .27777 L
.96066 .27777 L
.96131 .27777 L
Mistroke
.96196 .27777 L
.9626 .27777 L
.96325 .27777 L
.9639 .27777 L
.96454 .27777 L
.96519 .27777 L
.96584 .27777 L
.96649 .27777 L
.96713 .27777 L
.96778 .27777 L
.96843 .27777 L
.96907 .27777 L
.96972 .27777 L
.97037 .27777 L
.97101 .27777 L
.97166 .27777 L
.97231 .27777 L
.97296 .27777 L
.9736 .27777 L
.97425 .27777 L
.9749 .27777 L
.97554 .27777 L
.97619 .27777 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell["This gives the coiflet filter of order 6.", "MathCaption",
  CellTags->{"S1.4.6", "6.29"}],

Cell["c6 = CoifletFilter[6];", "Input",
  CellLabel->"In[73]:= ",
  CellTags->"S1.4.6"],

Cell[TextData[{
  "We plot the coiflet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " of order 6 here (dashed line) along with its derivative (solid line)."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.30"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction=Identity},
{ListPlot[DScalingFunction[c6, 6, 1],
PlotRange -> {{-4, 4}, All}, PlotJoined -> True,
AxesLabel -> {\"t\", \"phi(t) and phi'(t)\"}],
ListPlot[ScalingFunction[c6, 6], PlotJoined -> True,
PlotStyle -> Dashing[{0.01}]]}]]\
\>", "Input",
  CellLabel->"In[74]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.311413 0.183407 [
[0 .29891 -6 -9 ]
[0 .29891 6 0 ]
[.125 .29891 -6 -9 ]
[.125 .29891 6 0 ]
[.25 .29891 -6 -9 ]
[.25 .29891 6 0 ]
[.375 .29891 -6 -9 ]
[.375 .29891 6 0 ]
[.625 .29891 -3 -9 ]
[.625 .29891 3 0 ]
[.75 .29891 -3 -9 ]
[.75 .29891 3 0 ]
[.875 .29891 -3 -9 ]
[.875 .29891 3 0 ]
[1 .29891 -3 -9 ]
[1 .29891 3 0 ]
[1.025 .31141 0 -4.5 ]
[1.025 .31141 6 4.5 ]
[.4875 .0363 -24 -4.5 ]
[.4875 .0363 0 4.5 ]
[.4875 .12801 -12 -4.5 ]
[.4875 .12801 0 4.5 ]
[.4875 .21971 -24 -4.5 ]
[.4875 .21971 0 4.5 ]
[.4875 .40312 -18 -4.5 ]
[.4875 .40312 0 4.5 ]
[.4875 .49482 -6 -4.5 ]
[.4875 .49482 0 4.5 ]
[.4875 .58652 -18 -4.5 ]
[.4875 .58652 0 4.5 ]
[.5 .64303 -54 0 ]
[.5 .64303 54 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .31141 m
0 .31766 L
s
[(-4)] 0 .29891 0 1 Mshowa
.125 .31141 m
.125 .31766 L
s
[(-3)] .125 .29891 0 1 Mshowa
.25 .31141 m
.25 .31766 L
s
[(-2)] .25 .29891 0 1 Mshowa
.375 .31141 m
.375 .31766 L
s
[(-1)] .375 .29891 0 1 Mshowa
.625 .31141 m
.625 .31766 L
s
[(1)] .625 .29891 0 1 Mshowa
.75 .31141 m
.75 .31766 L
s
[(2)] .75 .29891 0 1 Mshowa
.875 .31141 m
.875 .31766 L
s
[(3)] .875 .29891 0 1 Mshowa
1 .31141 m
1 .31766 L
s
[(4)] 1 .29891 0 1 Mshowa
.125 Mabswid
.025 .31141 m
.025 .31516 L
s
.05 .31141 m
.05 .31516 L
s
.075 .31141 m
.075 .31516 L
s
.1 .31141 m
.1 .31516 L
s
.15 .31141 m
.15 .31516 L
s
.175 .31141 m
.175 .31516 L
s
.2 .31141 m
.2 .31516 L
s
.225 .31141 m
.225 .31516 L
s
.275 .31141 m
.275 .31516 L
s
.3 .31141 m
.3 .31516 L
s
.325 .31141 m
.325 .31516 L
s
.35 .31141 m
.35 .31516 L
s
.4 .31141 m
.4 .31516 L
s
.425 .31141 m
.425 .31516 L
s
.45 .31141 m
.45 .31516 L
s
.475 .31141 m
.475 .31516 L
s
.525 .31141 m
.525 .31516 L
s
.55 .31141 m
.55 .31516 L
s
.575 .31141 m
.575 .31516 L
s
.6 .31141 m
.6 .31516 L
s
.65 .31141 m
.65 .31516 L
s
.675 .31141 m
.675 .31516 L
s
.7 .31141 m
.7 .31516 L
s
.725 .31141 m
.725 .31516 L
s
.775 .31141 m
.775 .31516 L
s
.8 .31141 m
.8 .31516 L
s
.825 .31141 m
.825 .31516 L
s
.85 .31141 m
.85 .31516 L
s
.9 .31141 m
.9 .31516 L
s
.925 .31141 m
.925 .31516 L
s
.95 .31141 m
.95 .31516 L
s
.975 .31141 m
.975 .31516 L
s
.25 Mabswid
0 .31141 m
1 .31141 L
s
[(t)] 1.025 .31141 -1 0 Mshowa
.5 .0363 m
.50625 .0363 L
s
[(-1.5)] .4875 .0363 1 0 Mshowa
.5 .12801 m
.50625 .12801 L
s
[(-1)] .4875 .12801 1 0 Mshowa
.5 .21971 m
.50625 .21971 L
s
[(-0.5)] .4875 .21971 1 0 Mshowa
.5 .40312 m
.50625 .40312 L
s
[(0.5)] .4875 .40312 1 0 Mshowa
.5 .49482 m
.50625 .49482 L
s
[(1)] .4875 .49482 1 0 Mshowa
.5 .58652 m
.50625 .58652 L
s
[(1.5)] .4875 .58652 1 0 Mshowa
.125 Mabswid
.5 .05464 m
.50375 .05464 L
s
.5 .07298 m
.50375 .07298 L
s
.5 .09132 m
.50375 .09132 L
s
.5 .10967 m
.50375 .10967 L
s
.5 .14635 m
.50375 .14635 L
s
.5 .16469 m
.50375 .16469 L
s
.5 .18303 m
.50375 .18303 L
s
.5 .20137 m
.50375 .20137 L
s
.5 .23805 m
.50375 .23805 L
s
.5 .25639 m
.50375 .25639 L
s
.5 .27473 m
.50375 .27473 L
s
.5 .29307 m
.50375 .29307 L
s
.5 .32975 m
.50375 .32975 L
s
.5 .34809 m
.50375 .34809 L
s
.5 .36643 m
.50375 .36643 L
s
.5 .38478 m
.50375 .38478 L
s
.5 .42146 m
.50375 .42146 L
s
.5 .4398 m
.50375 .4398 L
s
.5 .45814 m
.50375 .45814 L
s
.5 .47648 m
.50375 .47648 L
s
.5 .51316 m
.50375 .51316 L
s
.5 .5315 m
.50375 .5315 L
s
.5 .54984 m
.50375 .54984 L
s
.5 .56818 m
.50375 .56818 L
s
.5 .01796 m
.50375 .01796 L
s
.5 .60486 m
.50375 .60486 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(phi\\(t\\) and phi'\\(t\\))] .5 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .31167 m
.00195 .31183 L
.00391 .31193 L
.00586 .312 L
.00781 .31208 L
.00977 .31213 L
.01172 .31216 L
.01367 .31216 L
.01563 .31208 L
.01758 .31199 L
.01953 .31197 L
.02148 .31198 L
.02344 .31199 L
.02539 .31203 L
.02734 .31205 L
.0293 .31208 L
.03125 .31219 L
.0332 .31228 L
.03516 .31231 L
.03711 .3123 L
.03906 .3122 L
.04102 .31207 L
.04297 .31199 L
.04492 .31193 L
.04688 .31189 L
.04883 .31184 L
.05078 .31167 L
.05273 .31144 L
.05469 .31125 L
.05664 .311 L
.05859 .31067 L
.06055 .31026 L
.0625 .30964 L
.06445 .309 L
.06641 .30858 L
.06836 .30825 L
.07031 .30802 L
.07227 .30788 L
.07422 .3077 L
.07617 .30756 L
.07813 .30755 L
.08008 .30757 L
.08203 .3076 L
.08398 .30765 L
.08594 .30763 L
.08789 .30766 L
.08984 .3078 L
.0918 .30803 L
.09375 .30838 L
.0957 .30876 L
Mistroke
.09766 .30902 L
.09961 .30926 L
.10156 .30952 L
.10352 .30975 L
.10547 .30995 L
.10742 .31011 L
.10938 .31012 L
.11133 .31012 L
.11328 .31029 L
.11523 .31054 L
.11719 .31085 L
.11914 .31122 L
.12109 .31156 L
.12305 .31192 L
.125 .31241 L
.12695 .31291 L
.12891 .31335 L
.13086 .31373 L
.13281 .31391 L
.13477 .31408 L
.13672 .31444 L
.13867 .31489 L
.14063 .31557 L
.14258 .31624 L
.14453 .31649 L
.14648 .31659 L
.14844 .31674 L
.15039 .31671 L
.15234 .31652 L
.1543 .3161 L
.15625 .31506 L
.1582 .314 L
.16016 .31353 L
.16211 .31338 L
.16406 .31371 L
.16602 .31425 L
.16797 .3145 L
.16992 .31476 L
.17188 .31511 L
.17383 .31554 L
.17578 .3164 L
.17773 .31742 L
.17969 .31816 L
.18164 .31914 L
.18359 .32066 L
.18555 .32261 L
.1875 .32552 L
.18945 .32851 L
.19141 .33039 L
.19336 .33178 L
Mistroke
.19531 .33288 L
.19727 .33351 L
.19922 .33406 L
.20117 .33425 L
.20313 .33347 L
.20508 .33247 L
.20703 .33194 L
.20898 .33153 L
.21094 .33132 L
.21289 .33115 L
.21484 .3305 L
.2168 .3297 L
.21875 .32901 L
.2207 .32814 L
.22266 .32712 L
.22461 .32585 L
.22656 .3239 L
.22852 .32184 L
.23047 .32017 L
.23242 .31865 L
.23438 .31768 L
.23633 .31661 L
.23828 .3143 L
.24023 .31146 L
.24219 .30866 L
.24414 .3053 L
.24609 .30144 L
.24805 .29696 L
.25 .29082 L
.25195 .28456 L
.25391 .2798 L
.25586 .27581 L
.25781 .27291 L
.25977 .27057 L
.26172 .26763 L
.26367 .26479 L
.26563 .2623 L
.26758 .26009 L
.26953 .25877 L
.27148 .25788 L
.27344 .25658 L
.27539 .25588 L
.27734 .25629 L
.2793 .25764 L
.28125 .26103 L
.2832 .26473 L
.28516 .26661 L
.28711 .26769 L
.28906 .26791 L
.29102 .26755 L
Mistroke
.29297 .26782 L
.29492 .26799 L
.29688 .26743 L
.29883 .26673 L
.30078 .2658 L
.30273 .26486 L
.30469 .26485 L
.30664 .2646 L
.30859 .26316 L
.31055 .26101 L
.3125 .25727 L
.31445 .25345 L
.31641 .25188 L
.31836 .2513 L
.32031 .25098 L
.32227 .25169 L
.32422 .25303 L
.32617 .25536 L
.32813 .26011 L
.33008 .26541 L
.33203 .26913 L
.33398 .27243 L
.33594 .27551 L
.33789 .27829 L
.33984 .28182 L
.3418 .28537 L
.34375 .28773 L
.3457 .29047 L
.34766 .29463 L
.34961 .29991 L
.35156 .30741 L
.35352 .31559 L
.35547 .32263 L
.35742 .32951 L
.35938 .33561 L
.36133 .34215 L
.36328 .35181 L
.36523 .36283 L
.36719 .37336 L
.36914 .38547 L
.37109 .3995 L
.37305 .41548 L
.375 .43629 L
.37695 .45755 L
.37891 .4742 L
.38086 .48862 L
.38281 .50064 L
.38477 .51087 L
.38672 .52212 L
.38867 .53262 L
Mistroke
.39063 .54084 L
.39258 .5482 L
.39453 .55482 L
.39648 .56089 L
.39844 .56806 L
.40039 .57423 L
.40234 .57766 L
.4043 .57914 L
.40625 .5772 L
.4082 .57444 L
.41016 .57455 L
.41211 .57569 L
.41406 .57734 L
.41602 .57977 L
.41797 .58155 L
.41992 .58364 L
.42188 .58756 L
.42383 .59153 L
.42578 .59425 L
.42773 .59625 L
.42969 .59671 L
.43164 .59677 L
.43359 .59801 L
.43555 .59953 L
.4375 .60151 L
.43945 .60332 L
.44141 .60331 L
.44336 .60249 L
.44531 .60201 L
.44727 .60051 L
.44922 .59759 L
.45117 .59333 L
.45313 .58619 L
.45508 .57839 L
.45703 .57296 L
.45898 .56816 L
.46094 .56313 L
.46289 .55871 L
.46484 .55397 L
.4668 .54967 L
.46875 .54801 L
.4707 .54593 L
.47266 .54071 L
.47461 .53342 L
.47656 .52276 L
.47852 .51071 L
.48047 .50019 L
.48242 .48959 L
.48438 .47915 L
.48633 .4679 L
Mistroke
.48828 .45272 L
.49023 .43577 L
.49219 .41982 L
.49414 .40168 L
.49609 .38036 L
.49805 .35611 L
.5 .32508 L
.50195 .29328 L
.50391 .26805 L
.50586 .24585 L
.50781 .22644 L
.50977 .20957 L
.51172 .1917 L
.51367 .17512 L
.51563 .16246 L
.51758 .15096 L
.51953 .13929 L
.52148 .12786 L
.52344 .1149 L
.52539 .1028 L
.52734 .09417 L
.5293 .08768 L
.53125 .08439 L
.5332 .08215 L
.53516 .07727 L
.53711 .07173 L
.53906 .0666 L
.54102 .06088 L
.54297 .05529 L
.54492 .04925 L
.54688 .0408 L
.54883 .03245 L
.55078 .02687 L
.55273 .02267 L
.55469 .01984 L
.55664 .01816 L
.55859 .01614 L
.56055 .01472 L
.5625 .01501 L
.56445 .01571 L
.56641 .01617 L
.56836 .01651 L
.57031 .01575 L
.57227 .01521 L
.57422 .01631 L
.57617 .0183 L
.57813 .02175 L
.58008 .02554 L
.58203 .02741 L
.58398 .02875 L
Mistroke
.58594 .03082 L
.58789 .03222 L
.58984 .033 L
.5918 .0329 L
.59375 .02976 L
.5957 .02678 L
.59766 .02732 L
.59961 .0299 L
.60156 .03524 L
.60352 .04206 L
.60547 .04773 L
.60742 .05377 L
.60938 .06059 L
.61133 .06818 L
.61328 .07825 L
.61523 .0895 L
.61719 .0997 L
.61914 .11147 L
.62109 .12607 L
.62305 .14301 L
.625 .16503 L
.62695 .18772 L
.62891 .20542 L
.63086 .22092 L
.63281 .23468 L
.63477 .24654 L
.63672 .2589 L
.63867 .27017 L
.64063 .2781 L
.64258 .28519 L
.64453 .2931 L
.64648 .30114 L
.64844 .31034 L
.65039 .31922 L
.65234 .32571 L
.6543 .3309 L
.65625 .33457 L
.6582 .33753 L
.66016 .34175 L
.66211 .34612 L
.66406 .34963 L
.66602 .35335 L
.66797 .35737 L
.66992 .36176 L
.67188 .36786 L
.67383 .37383 L
.67578 .37727 L
.67773 .37953 L
.67969 .38117 L
.68164 .38169 L
Mistroke
.68359 .38186 L
.68555 .38112 L
.6875 .37801 L
.68945 .37453 L
.69141 .37258 L
.69336 .37132 L
.69531 .3712 L
.69727 .37152 L
.69922 .37077 L
.70117 .36984 L
.70313 .36903 L
.70508 .36827 L
.70703 .36832 L
.70898 .36865 L
.71094 .36827 L
.71289 .36833 L
.71484 .36938 L
.7168 .37125 L
.71875 .37513 L
.7207 .37913 L
.72266 .3809 L
.72461 .38157 L
.72656 .38104 L
.72852 .37966 L
.73047 .37874 L
.73242 .37749 L
.73438 .37526 L
.73633 .37264 L
.73828 .3695 L
.74023 .36608 L
.74219 .36331 L
.74414 .36004 L
.74609 .35542 L
.74805 .34984 L
.75 .3424 L
.75195 .33468 L
.75391 .32889 L
.75586 .32391 L
.75781 .31943 L
.75977 .31567 L
.76172 .31188 L
.76367 .30859 L
.76563 .30678 L
.76758 .30529 L
.76953 .30318 L
.77148 .30089 L
.77344 .29816 L
.77539 .29542 L
.77734 .29351 L
.7793 .29196 L
Mistroke
.78125 .29062 L
.7832 .28951 L
.78516 .28826 L
.78711 .28713 L
.78906 .28655 L
.79102 .28602 L
.79297 .28522 L
.79492 .28429 L
.79688 .28277 L
.79883 .28136 L
.80078 .28107 L
.80273 .2813 L
.80469 .28162 L
.80664 .28247 L
.80859 .2837 L
.81055 .28546 L
.8125 .28854 L
.81445 .2918 L
.81641 .294 L
.81836 .29573 L
.82031 .29689 L
.82227 .29769 L
.82422 .29886 L
.82617 .29996 L
.82813 .3006 L
.83008 .30113 L
.83203 .30153 L
.83398 .30187 L
.83594 .30255 L
.83789 .30306 L
.83984 .30301 L
.8418 .30257 L
.84375 .30139 L
.8457 .3001 L
.84766 .29957 L
.84961 .29937 L
.85156 .29939 L
.85352 .29967 L
.85547 .29988 L
.85742 .30024 L
.85938 .30109 L
.86133 .30204 L
.86328 .30281 L
.86523 .30352 L
.86719 .30399 L
.86914 .30447 L
.87109 .30526 L
.87305 .30619 L
.875 .30732 L
.87695 .30849 L
Mistroke
.87891 .30939 L
.88086 .31018 L
.88281 .31099 L
.88477 .31168 L
.88672 .31231 L
.88867 .31281 L
.89063 .31303 L
.89258 .31319 L
.89453 .31356 L
.89648 .314 L
.89844 .31449 L
.90039 .31502 L
.90234 .31547 L
.9043 .31592 L
.90625 .31649 L
.9082 .31703 L
.91016 .31744 L
.91211 .31777 L
.91406 .31792 L
.91602 .318 L
.91797 .31817 L
.91992 .31834 L
.92188 .31854 L
.92383 .31871 L
.92578 .31865 L
.92773 .3185 L
.92969 .31838 L
.93164 .31814 L
.93359 .31775 L
.93555 .31721 L
.9375 .31634 L
.93945 .31543 L
.94141 .3148 L
.94336 .31431 L
.94531 .31393 L
.94727 .31365 L
.94922 .31331 L
.95117 .31301 L
.95313 .31288 L
.95508 .31278 L
.95703 .31266 L
.95898 .31253 L
.96094 .31233 L
.96289 .31214 L
.96484 .3121 L
.9668 .31213 L
.96875 .31229 L
.9707 .31249 L
.97266 .31255 L
.97461 .31256 L
Mistroke
.97656 .31257 L
.97852 .31254 L
.98047 .3125 L
.98242 .31242 L
.98438 .31224 L
.98633 .31204 L
.98828 .31193 L
.99023 .31186 L
.99219 .31183 L
.99414 .31183 L
.99609 .31179 L
.99805 .31176 L
1 .31177 L
Mfstroke
1 .31177 m
1 .31177 L
s
[ .01 ] 0 setdash
0 .31136 m
.00195 .31137 L
.00391 .31137 L
.00586 .31138 L
.00781 .31139 L
.00977 .3114 L
.01172 .31141 L
.01367 .31143 L
.01563 .31144 L
.01758 .31145 L
.01953 .31146 L
.02148 .31146 L
.02344 .31147 L
.02539 .31148 L
.02734 .31149 L
.0293 .3115 L
.03125 .31151 L
.0332 .31153 L
.03516 .31154 L
.03711 .31156 L
.03906 .31157 L
.04102 .31158 L
.04297 .31159 L
.04492 .3116 L
.04688 .31161 L
.04883 .31161 L
.05078 .31162 L
.05273 .31162 L
.05469 .31162 L
.05664 .31161 L
.05859 .31161 L
.06055 .31159 L
.0625 .31157 L
.06445 .31154 L
.06641 .31149 L
.06836 .31145 L
.07031 .3114 L
.07227 .31134 L
.07422 .31129 L
.07617 .31123 L
.07813 .31117 L
.08008 .31111 L
.08203 .31105 L
.08398 .31099 L
.08594 .31093 L
.08789 .31087 L
.08984 .31081 L
.0918 .31076 L
.09375 .31071 L
.0957 .31066 L
Mistroke
.09766 .31062 L
.09961 .31059 L
.10156 .31055 L
.10352 .31053 L
.10547 .3105 L
.10742 .31048 L
.10938 .31046 L
.11133 .31044 L
.11328 .31042 L
.11523 .31041 L
.11719 .31039 L
.11914 .31039 L
.12109 .31039 L
.12305 .31039 L
.125 .31041 L
.12695 .31043 L
.12891 .31045 L
.13086 .31049 L
.13281 .31052 L
.13477 .31056 L
.13672 .31061 L
.13867 .31066 L
.14063 .31072 L
.14258 .31079 L
.14453 .31087 L
.14648 .31095 L
.14844 .31103 L
.15039 .31111 L
.15234 .31119 L
.1543 .31127 L
.15625 .31134 L
.1582 .31138 L
.16016 .31142 L
.16211 .31145 L
.16406 .31148 L
.16602 .31152 L
.16797 .31157 L
.16992 .31162 L
.17188 .31168 L
.17383 .31174 L
.17578 .31181 L
.17773 .31189 L
.17969 .31199 L
.18164 .3121 L
.18359 .31224 L
.18555 .3124 L
.1875 .31259 L
.18945 .31284 L
.19141 .31312 L
.19336 .31343 L
Mistroke
.19531 .31376 L
.19727 .3141 L
.19922 .31445 L
.20117 .3148 L
.20313 .31516 L
.20508 .31549 L
.20703 .31582 L
.20898 .31613 L
.21094 .31644 L
.21289 .31676 L
.21484 .31706 L
.2168 .31735 L
.21875 .31763 L
.2207 .3179 L
.22266 .31815 L
.22461 .31839 L
.22656 .3186 L
.22852 .31878 L
.23047 .31893 L
.23242 .31905 L
.23438 .31916 L
.23633 .31925 L
.23828 .31931 L
.24023 .31934 L
.24219 .31931 L
.24414 .31925 L
.24609 .31912 L
.24805 .31893 L
.25 .31866 L
.25195 .31829 L
.25391 .31783 L
.25586 .3173 L
.25781 .31672 L
.25977 .3161 L
.26172 .31544 L
.26367 .31474 L
.26563 .31399 L
.26758 .3132 L
.26953 .31239 L
.27148 .31156 L
.27344 .31071 L
.27539 .30985 L
.27734 .30898 L
.2793 .30813 L
.28125 .30731 L
.2832 .30656 L
.28516 .30585 L
.28711 .30515 L
.28906 .30448 L
.29102 .30379 L
Mistroke
.29297 .30311 L
.29492 .30243 L
.29688 .30175 L
.29883 .30105 L
.30078 .30035 L
.30273 .29963 L
.30469 .2989 L
.30664 .29817 L
.30859 .29743 L
.31055 .29666 L
.3125 .29585 L
.31445 .29497 L
.31641 .29405 L
.31836 .29311 L
.32031 .29217 L
.32227 .29123 L
.32422 .29031 L
.32617 .28941 L
.32813 .28857 L
.33008 .28781 L
.33203 .28712 L
.33398 .28649 L
.33594 .2859 L
.33789 .28536 L
.33984 .28487 L
.3418 .28444 L
.34375 .28405 L
.3457 .2837 L
.34766 .2834 L
.34961 .28318 L
.35156 .28306 L
.35352 .28306 L
.35547 .28318 L
.35742 .28341 L
.35938 .28374 L
.36133 .28417 L
.36328 .28472 L
.36523 .28544 L
.36719 .28632 L
.36914 .28738 L
.37109 .28865 L
.37305 .29015 L
.375 .29192 L
.37695 .29405 L
.37891 .29647 L
.38086 .29912 L
.38281 .30199 L
.38477 .30503 L
.38672 .30823 L
.38867 .31161 L
Mistroke
.39063 .31513 L
.39258 .31877 L
.39453 .32253 L
.39648 .32638 L
.39844 .33033 L
.40039 .33439 L
.40234 .33853 L
.4043 .3427 L
.40625 .34688 L
.4082 .351 L
.41016 .35511 L
.41211 .35923 L
.41406 .36337 L
.41602 .36755 L
.41797 .37176 L
.41992 .37599 L
.42188 .38027 L
.42383 .38462 L
.42578 .38902 L
.42773 .39346 L
.42969 .39791 L
.43164 .40237 L
.43359 .40684 L
.43555 .41133 L
.4375 .41584 L
.43945 .42039 L
.44141 .42496 L
.44336 .42951 L
.44531 .43405 L
.44727 .43859 L
.44922 .44308 L
.45117 .44752 L
.45313 .45188 L
.45508 .4561 L
.45703 .46023 L
.45898 .46428 L
.46094 .46825 L
.46289 .47215 L
.46484 .47598 L
.4668 .47973 L
.46875 .48344 L
.4707 .48713 L
.47266 .49075 L
.47461 .49428 L
.47656 .49767 L
.47852 .50088 L
.48047 .50391 L
.48242 .50678 L
.48438 .50947 L
.48633 .51201 L
Mistroke
.48828 .51435 L
.49023 .51642 L
.49219 .51824 L
.49414 .5198 L
.49609 .52104 L
.49805 .52193 L
.5 .52241 L
.50195 .52236 L
.50391 .52187 L
.50586 .52102 L
.50781 .51983 L
.50977 .51838 L
.51172 .51665 L
.51367 .51464 L
.51563 .51241 L
.51758 .51 L
.51953 .50739 L
.52148 .50462 L
.52344 .50165 L
.52539 .49848 L
.52734 .49515 L
.5293 .4917 L
.53125 .48817 L
.5332 .48461 L
.53516 .481 L
.53711 .47729 L
.53906 .47351 L
.54102 .46964 L
.54297 .46568 L
.54492 .46163 L
.54688 .45748 L
.54883 .45318 L
.55078 .44877 L
.55273 .44429 L
.55469 .43975 L
.55664 .43519 L
.55859 .43059 L
.56055 .42596 L
.5625 .42133 L
.56445 .4167 L
.56641 .41208 L
.56836 .40747 L
.57031 .40286 L
.57227 .39824 L
.57422 .39361 L
.57617 .38902 L
.57813 .38446 L
.58008 .37997 L
.58203 .37552 L
.58398 .37109 L
Mistroke
.58594 .36669 L
.58789 .36232 L
.58984 .35796 L
.5918 .35361 L
.59375 .34924 L
.5957 .34481 L
.59766 .34037 L
.59961 .33595 L
.60156 .33158 L
.60352 .32732 L
.60547 .32316 L
.60742 .31908 L
.60938 .31511 L
.61133 .31125 L
.61328 .30752 L
.61523 .30397 L
.61719 .30059 L
.61914 .29736 L
.62109 .29435 L
.62305 .29158 L
.625 .28911 L
.62695 .28701 L
.62891 .28522 L
.63086 .28369 L
.63281 .28239 L
.63477 .28128 L
.63672 .28036 L
.63867 .27963 L
.64063 .27906 L
.64258 .27859 L
.64453 .27824 L
.64648 .27802 L
.64844 .27792 L
.65039 .27798 L
.65234 .27816 L
.6543 .27842 L
.65625 .27876 L
.6582 .27914 L
.66016 .27958 L
.66211 .28009 L
.66406 .28066 L
.66602 .28128 L
.66797 .28197 L
.66992 .28272 L
.67188 .28355 L
.67383 .28449 L
.67578 .28549 L
.67773 .28654 L
.67969 .28762 L
.68164 .28871 L
Mistroke
.68359 .28981 L
.68555 .29091 L
.6875 .29198 L
.68945 .29299 L
.69141 .29396 L
.69336 .2949 L
.69531 .29584 L
.69727 .29677 L
.69922 .29771 L
.70117 .29863 L
.70313 .29954 L
.70508 .30043 L
.70703 .30132 L
.70898 .30221 L
.71094 .3031 L
.71289 .30399 L
.71484 .30489 L
.7168 .3058 L
.71875 .30676 L
.7207 .3078 L
.72266 .30887 L
.72461 .30996 L
.72656 .31106 L
.72852 .31213 L
.73047 .31319 L
.73242 .31424 L
.73438 .31525 L
.73633 .31623 L
.73828 .31716 L
.74023 .31804 L
.74219 .31887 L
.74414 .31966 L
.74609 .32039 L
.74805 .32103 L
.75 .32158 L
.75195 .322 L
.75391 .32231 L
.75586 .32255 L
.75781 .32271 L
.75977 .3228 L
.76172 .32284 L
.76367 .32282 L
.76563 .32276 L
.76758 .32268 L
.76953 .32257 L
.77148 .32242 L
.77344 .32223 L
.77539 .322 L
.77734 .32174 L
.7793 .32145 L
Mistroke
.78125 .32113 L
.7832 .3208 L
.78516 .32045 L
.78711 .32008 L
.78906 .31969 L
.79102 .3193 L
.79297 .3189 L
.79492 .31848 L
.79688 .31805 L
.79883 .31758 L
.80078 .31711 L
.80273 .31664 L
.80469 .31617 L
.80664 .31571 L
.80859 .31527 L
.81055 .31485 L
.8125 .31446 L
.81445 .31413 L
.81641 .31385 L
.81836 .31359 L
.82031 .31335 L
.82227 .31313 L
.82422 .31293 L
.82617 .31274 L
.82813 .31257 L
.83008 .3124 L
.83203 .31224 L
.83398 .31209 L
.83594 .31195 L
.83789 .31181 L
.83984 .31168 L
.8418 .31155 L
.84375 .3114 L
.8457 .31124 L
.84766 .31105 L
.84961 .31087 L
.85156 .31068 L
.85352 .31049 L
.85547 .31031 L
.85742 .31013 L
.85938 .30996 L
.86133 .30981 L
.86328 .30967 L
.86523 .30954 L
.86719 .30942 L
.86914 .30931 L
.87109 .30921 L
.87305 .30912 L
.875 .30905 L
.87695 .30899 L
Mistroke
.87891 .30895 L
.88086 .30893 L
.88281 .30891 L
.88477 .30891 L
.88672 .30892 L
.88867 .30894 L
.89063 .30896 L
.89258 .30899 L
.89453 .30902 L
.89648 .30906 L
.89844 .3091 L
.90039 .30915 L
.90234 .30922 L
.9043 .30928 L
.90625 .30936 L
.9082 .30944 L
.91016 .30953 L
.91211 .30963 L
.91406 .30973 L
.91602 .30983 L
.91797 .30994 L
.91992 .31004 L
.92188 .31015 L
.92383 .31026 L
.92578 .31038 L
.92773 .31049 L
.92969 .3106 L
.93164 .31071 L
.93359 .31081 L
.93555 .3109 L
.9375 .31099 L
.93945 .31106 L
.94141 .31112 L
.94336 .31117 L
.94531 .31121 L
.94727 .31124 L
.94922 .31128 L
.95117 .3113 L
.95313 .31133 L
.95508 .31135 L
.95703 .31137 L
.95898 .31139 L
.96094 .3114 L
.96289 .31142 L
.96484 .31143 L
.9668 .31144 L
.96875 .31145 L
.9707 .31147 L
.97266 .31148 L
.97461 .3115 L
Mistroke
.97656 .31152 L
.97852 .31154 L
.98047 .31156 L
.98242 .31157 L
.98438 .31159 L
.98633 .3116 L
.98828 .31161 L
.99023 .31161 L
.99219 .31162 L
.99414 .31163 L
.99609 .31163 L
.99805 .31164 L
1 .31164 L
Mfstroke
1 .31164 m
1 .31164 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],

Cell[TextData[{
  "The derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " can be obtained from the derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " and the wavelet equation."
}], "Text",
  CellTags->{"S1.4.6", "6.31"}],

Cell[TextData[{
  StyleBox["DWavelet[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["m", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.4.6", "6.32"}],

Cell[TextData[{
  "gives the ",
  Cell[BoxData[
      \(TraditionalForm\`m\^th\)], "InlineFormula",
    CellTags->"S1.4.6"],
  " derivative of the wavelet generated from the filter ",
  StyleBox["filter", "TI"],
  " at the dyadic points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.4.6"],
  ". "
}], "Text",
  CellTags->{"S1.4.6", "6.33"}],

Cell[TextData[{
  "Plotted here is the derivative of Daubechies ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_3\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.4.6"],
  "."
}], "MathCaption",
  CellTags->{"S1.4.6", "6.34"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[DWavelet[h3, 6, 1],
PlotRange -> All, PlotJoined -> True,
AxesLabel -> {\"t\", \"psi_3'(t)\"}]\
\>", "Input",
  CellLabel->"In[75]:= ",
  CellTags->"S1.4.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.352271 0.0388258 [
[.02381 .33977 -6 -9 ]
[.02381 .33977 6 0 ]
[.21429 .33977 -6 -9 ]
[.21429 .33977 6 0 ]
[.59524 .33977 -3 -9 ]
[.59524 .33977 3 0 ]
[.78571 .33977 -3 -9 ]
[.78571 .33977 3 0 ]
[.97619 .33977 -3 -9 ]
[.97619 .33977 3 0 ]
[1.025 .35227 0 -4.5 ]
[1.025 .35227 6 4.5 ]
[.39226 .04166 -12 -4.5 ]
[.39226 .04166 0 4.5 ]
[.39226 .11932 -12 -4.5 ]
[.39226 .11932 0 4.5 ]
[.39226 .19697 -12 -4.5 ]
[.39226 .19697 0 4.5 ]
[.39226 .27462 -12 -4.5 ]
[.39226 .27462 0 4.5 ]
[.39226 .42992 -6 -4.5 ]
[.39226 .42992 0 4.5 ]
[.39226 .50757 -6 -4.5 ]
[.39226 .50757 0 4.5 ]
[.39226 .58523 -6 -4.5 ]
[.39226 .58523 0 4.5 ]
[.40476 .64303 -27 0 ]
[.40476 .64303 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .35227 m
.02381 .35852 L
s
[(-2)] .02381 .33977 0 1 Mshowa
.21429 .35227 m
.21429 .35852 L
s
[(-1)] .21429 .33977 0 1 Mshowa
.59524 .35227 m
.59524 .35852 L
s
[(1)] .59524 .33977 0 1 Mshowa
.78571 .35227 m
.78571 .35852 L
s
[(2)] .78571 .33977 0 1 Mshowa
.97619 .35227 m
.97619 .35852 L
s
[(3)] .97619 .33977 0 1 Mshowa
.125 Mabswid
.0619 .35227 m
.0619 .35602 L
s
.1 .35227 m
.1 .35602 L
s
.1381 .35227 m
.1381 .35602 L
s
.17619 .35227 m
.17619 .35602 L
s
.25238 .35227 m
.25238 .35602 L
s
.29048 .35227 m
.29048 .35602 L
s
.32857 .35227 m
.32857 .35602 L
s
.36667 .35227 m
.36667 .35602 L
s
.44286 .35227 m
.44286 .35602 L
s
.48095 .35227 m
.48095 .35602 L
s
.51905 .35227 m
.51905 .35602 L
s
.55714 .35227 m
.55714 .35602 L
s
.63333 .35227 m
.63333 .35602 L
s
.67143 .35227 m
.67143 .35602 L
s
.70952 .35227 m
.70952 .35602 L
s
.74762 .35227 m
.74762 .35602 L
s
.82381 .35227 m
.82381 .35602 L
s
.8619 .35227 m
.8619 .35602 L
s
.9 .35227 m
.9 .35602 L
s
.9381 .35227 m
.9381 .35602 L
s
.25 Mabswid
0 .35227 m
1 .35227 L
s
[(t)] 1.025 .35227 -1 0 Mshowa
.40476 .04166 m
.41101 .04166 L
s
[(-8)] .39226 .04166 1 0 Mshowa
.40476 .11932 m
.41101 .11932 L
s
[(-6)] .39226 .11932 1 0 Mshowa
.40476 .19697 m
.41101 .19697 L
s
[(-4)] .39226 .19697 1 0 Mshowa
.40476 .27462 m
.41101 .27462 L
s
[(-2)] .39226 .27462 1 0 Mshowa
.40476 .42992 m
.41101 .42992 L
s
[(2)] .39226 .42992 1 0 Mshowa
.40476 .50757 m
.41101 .50757 L
s
[(4)] .39226 .50757 1 0 Mshowa
.40476 .58523 m
.41101 .58523 L
s
[(6)] .39226 .58523 1 0 Mshowa
.125 Mabswid
.40476 .06108 m
.40851 .06108 L
s
.40476 .08049 m
.40851 .08049 L
s
.40476 .0999 m
.40851 .0999 L
s
.40476 .13873 m
.40851 .13873 L
s
.40476 .15814 m
.40851 .15814 L
s
.40476 .17756 m
.40851 .17756 L
s
.40476 .21638 m
.40851 .21638 L
s
.40476 .23579 m
.40851 .23579 L
s
.40476 .25521 m
.40851 .25521 L
s
.40476 .29403 m
.40851 .29403 L
s
.40476 .31345 m
.40851 .31345 L
s
.40476 .33286 m
.40851 .33286 L
s
.40476 .37168 m
.40851 .37168 L
s
.40476 .3911 m
.40851 .3911 L
s
.40476 .41051 m
.40851 .41051 L
s
.40476 .44934 m
.40851 .44934 L
s
.40476 .46875 m
.40851 .46875 L
s
.40476 .48816 m
.40851 .48816 L
s
.40476 .52699 m
.40851 .52699 L
s
.40476 .5464 m
.40851 .5464 L
s
.40476 .56581 m
.40851 .56581 L
s
.40476 .02225 m
.40851 .02225 L
s
.40476 .00284 m
.40851 .00284 L
s
.40476 .60464 m
.40851 .60464 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(psi_3'\\(t\\))] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .35227 m
.02679 .35695 L
.02976 .35724 L
.03274 .35619 L
.03571 .35755 L
.03869 .35594 L
.04167 .35644 L
.04464 .35786 L
.04762 .35788 L
.0506 .35588 L
.05357 .35617 L
.05655 .35699 L
.05952 .3567 L
.0625 .35808 L
.06548 .35821 L
.06845 .35782 L
.07143 .35824 L
.0744 .35608 L
.07738 .35611 L
.08036 .3569 L
.08333 .35641 L
.08631 .35733 L
.08929 .35729 L
.09226 .35681 L
.09524 .35698 L
.09821 .35838 L
.10119 .35845 L
.10417 .35818 L
.10714 .35858 L
.11012 .35802 L
.1131 .35817 L
.11607 .35862 L
.11905 .35861 L
.12202 .35634 L
.125 .35632 L
.12798 .35693 L
.13095 .35635 L
.13393 .35734 L
.1369 .35719 L
.13988 .35656 L
.14286 .35667 L
.14583 .35769 L
.14881 .35765 L
.15179 .35737 L
.15476 .35761 L
.15774 .35705 L
.16071 .35709 L
.16369 .35737 L
.16667 .35727 L
.16964 .35866 L
Mistroke
.17262 .35876 L
.1756 .35843 L
.17857 .35883 L
.18155 .3584 L
.18452 .35855 L
.1875 .35896 L
.19048 .35898 L
.19345 .35829 L
.19643 .35838 L
.1994 .35865 L
.20238 .35854 L
.20536 .35899 L
.20833 .35902 L
.21131 .35888 L
.21429 .35901 L
.21726 .32098 L
.22024 .31864 L
.22321 .32726 L
.22619 .31623 L
.22917 .32941 L
.23214 .3254 L
.23512 .31389 L
.2381 .31373 L
.24107 .33015 L
.24405 .32789 L
.24702 .32119 L
.25 .32368 L
.25298 .31244 L
.25595 .31147 L
.25893 .3147 L
.2619 .31138 L
.26488 .3289 L
.26786 .3287 L
.27083 .32235 L
.27381 .32636 L
.27679 .31894 L
.27976 .31935 L
.28274 .32332 L
.28571 .32199 L
.28869 .31066 L
.29167 .31017 L
.29464 .3124 L
.29762 .30918 L
.3006 .31381 L
.30357 .31262 L
.30655 .30902 L
.30952 .30916 L
.3125 .32788 L
.31548 .32815 L
.31845 .32318 L
Mistroke
.32143 .32801 L
.3244 .31995 L
.32738 .32123 L
.33036 .32646 L
.33333 .32563 L
.33631 .3173 L
.33929 .31768 L
.34226 .32003 L
.34524 .31819 L
.34821 .32281 L
.35119 .32256 L
.35417 .32033 L
.35714 .3212 L
.36012 .30983 L
.3631 .30907 L
.36607 .31191 L
.36905 .30862 L
.37202 .31224 L
.375 .31109 L
.37798 .30779 L
.38095 .3077 L
.38393 .31337 L
.3869 .31276 L
.38988 .31057 L
.39286 .31155 L
.39583 .30795 L
.39881 .30775 L
.40179 .30894 L
.40476 .30796 L
.40774 .53409 L
.41071 .54797 L
.41369 .49657 L
.41667 .56212 L
.41964 .48373 L
.42262 .50753 L
.4256 .57591 L
.42857 .57678 L
.43155 .47893 L
.43452 .49227 L
.4375 .53209 L
.44048 .51721 L
.44345 .58406 L
.44643 .58974 L
.4494 .57044 L
.45238 .5901 L
.45536 .48607 L
.45833 .48717 L
.46131 .52486 L
.46429 .501 L
.46726 .54495 L
Mistroke
.47024 .54249 L
.47321 .51886 L
.47619 .52667 L
.47917 .59392 L
.48214 .59679 L
.48512 .58346 L
.4881 .60253 L
.49107 .57499 L
.49405 .58201 L
.49702 .60332 L
.5 .60247 L
.50298 .0917 L
.50595 .06497 L
.50893 .18407 L
.5119 .03905 L
.51488 .22482 L
.51786 .17449 L
.52083 .02187 L
.52381 .02462 L
.52679 .24498 L
.52976 .21842 L
.53274 .13367 L
.53571 .16986 L
.53869 .02407 L
.54167 .01472 L
.54464 .06096 L
.54762 .02041 L
.5506 .27214 L
.55357 .27399 L
.55655 .1895 L
.55952 .25078 L
.5625 .15034 L
.56548 .16085 L
.56845 .22184 L
.57143 .20776 L
.5744 .05403 L
.57738 .05191 L
.58036 .08782 L
.58333 .04751 L
.58631 .11707 L
.58929 .10512 L
.59226 .05951 L
.59524 .06613 L
.59821 .53882 L
.60119 .56023 L
.60417 .44925 L
.60714 .58148 L
.61012 .40241 L
.6131 .44696 L
.61607 .58763 L
Mistroke
.61905 .58179 L
.62202 .38185 L
.625 .40436 L
.62798 .47855 L
.63095 .44442 L
.63393 .57483 L
.6369 .5816 L
.63988 .53814 L
.64286 .5732 L
.64583 .32389 L
.64881 .31934 L
.65179 .39862 L
.65476 .33575 L
.65774 .43188 L
.66071 .41861 L
.66369 .35575 L
.66667 .36675 L
.66964 .51274 L
.67262 .51181 L
.6756 .47417 L
.67857 .51027 L
.68155 .43981 L
.68452 .44846 L
.6875 .48974 L
.69048 .48036 L
.69345 .27864 L
.69643 .27122 L
.6994 .31763 L
.70238 .26203 L
.70536 .34305 L
.70833 .32465 L
.71131 .2642 L
.71429 .26831 L
.71726 .34815 L
.72024 .33915 L
.72321 .31018 L
.72619 .32389 L
.72917 .27133 L
.73214 .26883 L
.73512 .28653 L
.7381 .27256 L
.74107 .39161 L
.74405 .39477 L
.74702 .35884 L
.75 .38971 L
.75298 .34477 L
.75595 .35225 L
.75893 .38335 L
.7619 .37918 L
.76488 .31262 L
Mistroke
.76786 .31427 L
.77083 .33287 L
.77381 .31732 L
.77679 .35133 L
.77976 .34851 L
.78274 .33051 L
.78571 .33608 L
.78869 .36385 L
.79167 .36428 L
.79464 .359 L
.79762 .36649 L
.8006 .35325 L
.80357 .35582 L
.80655 .3647 L
.80952 .36363 L
.8125 .35649 L
.81548 .3578 L
.81845 .36058 L
.82143 .35967 L
.8244 .36541 L
.82738 .36596 L
.83036 .36451 L
.83333 .36626 L
.83631 .34312 L
.83929 .34242 L
.84226 .34896 L
.84524 .34284 L
.84821 .35168 L
.85119 .35004 L
.85417 .34375 L
.85714 .34445 L
.86012 .35642 L
.8631 .3559 L
.86607 .35233 L
.86905 .35496 L
.87202 .34847 L
.875 .34879 L
.87798 .3519 L
.88095 .35066 L
.88393 .35347 L
.8869 .35369 L
.88988 .35263 L
.89286 .3534 L
.89583 .35282 L
.89881 .35301 L
.90179 .35364 L
.90476 .35367 L
.90774 .35129 L
.91071 .35133 L
.91369 .35205 L
Mistroke
.91667 .35149 L
.91964 .35263 L
.92262 .35254 L
.9256 .35192 L
.92857 .35211 L
.93155 .35241 L
.93452 .35238 L
.9375 .35234 L
.94048 .35241 L
.94345 .35218 L
.94643 .35219 L
.9494 .3523 L
.95238 .35226 L
.95536 .35228 L
.95833 .35229 L
.96131 .35226 L
.96429 .35227 L
.96726 .35227 L
.97024 .35227 L
.97321 .35227 L
.97619 .35227 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{520, 600},
WindowMargins->{{147, Automatic}, {Automatic, 32}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1717, 49, 90, 1, 56, "Section",
      CellTags->"Contents"],
    Cell[1810, 52, 1566, 51, 144, "Contents",
      CellTags->"Contents"]},
  "S1.4.0"->{
    Cell[3379, 105, 97, 1, 56, "Section",
      CellTags->{"S1.4.0", "0.1"}],
    Cell[3479, 108, 2478, 56, 305, "Text",
      CellTags->{"S1.4.0", "0.2"}]},
  "0.1"->{
    Cell[3379, 105, 97, 1, 56, "Section",
      CellTags->{"S1.4.0", "0.1"}]},
  "0.2"->{
    Cell[3479, 108, 2478, 56, 305, "Text",
      CellTags->{"S1.4.0", "0.2"}]},
  "S1.4.1"->{
    Cell[5960, 166, 101, 1, 39, "Subsection",
      CellTags->{"S1.4.1", "1.1"}],
    Cell[6064, 169, 168, 4, 42, "Text",
      CellTags->{"S1.4.1", "1.2"}],
    Cell[6235, 175, 363, 8, 46, "DisplayFormula",
      CellTags->{"S1.4.1", "1.3"}],
    Cell[6601, 185, 72, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.4"}],
    Cell[6676, 188, 368, 8, 46, "DisplayFormula",
      CellTags->{"S1.4.1", "1.5"}],
    Cell[7047, 198, 3034, 87, 206, "Text",
      CellTags->{"S1.4.1", "1.6"}],
    Cell[10084, 287, 367, 7, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.7"}],
    Cell[10454, 296, 309, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.8"}],
    Cell[10766, 309, 464, 11, 43, "DisplayFormula",
      CellTags->{"S1.4.1", "1.9"}],
    Cell[11233, 322, 1140, 35, 60, "Text",
      CellTags->{"S1.4.1", "1.10"}],
    Cell[12376, 359, 284, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.1", "1.11"}],
    Cell[12663, 367, 61, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.12"}],
    Cell[12727, 370, 205, 5, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.13"}],
    Cell[12935, 377, 363, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.14"}],
    Cell[13301, 390, 261, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.1", "1.15"}],
    Cell[13565, 398, 349, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.16"}],
    Cell[13917, 411, 263, 6, 31, "DisplayFormula",
      CellTags->{"S1.4.1", "1.17"}],
    Cell[14183, 419, 1271, 41, 59, "Text",
      CellTags->{"S1.4.1", "1.18"}],
    Cell[15457, 462, 260, 6, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.19"}],
    Cell[15720, 470, 51, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.20"}],
    Cell[15774, 473, 274, 6, 33, "DisplayFormula",
      CellTags->{"S1.4.1", "1.21"}],
    Cell[16051, 481, 991, 31, 59, "Text",
      CellTags->{"S1.4.1", "1.22"}],
    Cell[17045, 514, 705, 19, 56, "DisplayFormula",
      CellTags->{"S1.4.1", "1.23"}],
    Cell[17753, 535, 417, 12, 50, "Text",
      CellTags->{"S1.4.1", "1.24"}],
    Cell[18173, 549, 272, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.1", "1.25"}],
    Cell[18448, 556, 767, 25, 42, "Text",
      CellTags->{"S1.4.1", "1.26"}],
    Cell[19218, 583, 79, 1, 35, "Subsubsection",
      CellTags->{"S1.4.1", "1.27"}],
    Cell[19300, 586, 1109, 32, 84, "Text",
      CellTags->{"S1.4.1", "1.28"}],
    Cell[20412, 620, 326, 8, 68, "DisplayFormula",
      CellTags->{"S1.4.1", "1.29"}],
    Cell[20741, 630, 1195, 37, 85, "Text",
      CellTags->{"S1.4.1", "1.30"}],
    Cell[21939, 669, 490, 9, 68, "DisplayFormula",
      CellTags->{"S1.4.1", "1.31"}],
    Cell[22432, 680, 1464, 51, 46, "Text",
      CellTags->{"S1.4.1", "1.32"}],
    Cell[23899, 733, 1369, 33, 105, "DisplayFormula",
      CellTags->{"S1.4.1", "1.33"}],
    Cell[25271, 768, 500, 12, 70, "Text",
      CellTags->{"S1.4.1", "1.34"}],
    Cell[25774, 782, 711, 14, 47, "DisplayFormula",
      CellTags->{"S1.4.1", "1.35"}],
    Cell[26488, 798, 238, 7, 25, "Text",
      CellTags->{"S1.4.1", "1.36"}],
    Cell[26729, 807, 483, 11, 47, "DisplayFormula",
      CellTags->{"S1.4.1", "1.37"}],
    Cell[27215, 820, 733, 23, 44, "Text",
      CellTags->{"S1.4.1", "1.38"}]},
  "1.1"->{
    Cell[5960, 166, 101, 1, 39, "Subsection",
      CellTags->{"S1.4.1", "1.1"}]},
  "1.2"->{
    Cell[6064, 169, 168, 4, 42, "Text",
      CellTags->{"S1.4.1", "1.2"}]},
  "1.3"->{
    Cell[6235, 175, 363, 8, 46, "DisplayFormula",
      CellTags->{"S1.4.1", "1.3"}]},
  "1.4"->{
    Cell[6601, 185, 72, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.4"}]},
  "1.5"->{
    Cell[6676, 188, 368, 8, 46, "DisplayFormula",
      CellTags->{"S1.4.1", "1.5"}]},
  "1.6"->{
    Cell[7047, 198, 3034, 87, 206, "Text",
      CellTags->{"S1.4.1", "1.6"}]},
  "1.7"->{
    Cell[10084, 287, 367, 7, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.7"}]},
  "1.8"->{
    Cell[10454, 296, 309, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.8"}]},
  "1.9"->{
    Cell[10766, 309, 464, 11, 43, "DisplayFormula",
      CellTags->{"S1.4.1", "1.9"}]},
  "1.10"->{
    Cell[11233, 322, 1140, 35, 60, "Text",
      CellTags->{"S1.4.1", "1.10"}]},
  "1.11"->{
    Cell[12376, 359, 284, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.1", "1.11"}]},
  "1.12"->{
    Cell[12663, 367, 61, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.12"}]},
  "1.13"->{
    Cell[12727, 370, 205, 5, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.13"}]},
  "1.14"->{
    Cell[12935, 377, 363, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.14"}]},
  "1.15"->{
    Cell[13301, 390, 261, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.1", "1.15"}]},
  "1.16"->{
    Cell[13565, 398, 349, 11, 25, "Text",
      CellTags->{"S1.4.1", "1.16"}]},
  "1.17"->{
    Cell[13917, 411, 263, 6, 31, "DisplayFormula",
      CellTags->{"S1.4.1", "1.17"}]},
  "1.18"->{
    Cell[14183, 419, 1271, 41, 59, "Text",
      CellTags->{"S1.4.1", "1.18"}]},
  "1.19"->{
    Cell[15457, 462, 260, 6, 32, "DisplayFormula",
      CellTags->{"S1.4.1", "1.19"}]},
  "1.20"->{
    Cell[15720, 470, 51, 1, 25, "Text",
      CellTags->{"S1.4.1", "1.20"}]},
  "1.21"->{
    Cell[15774, 473, 274, 6, 33, "DisplayFormula",
      CellTags->{"S1.4.1", "1.21"}]},
  "1.22"->{
    Cell[16051, 481, 991, 31, 59, "Text",
      CellTags->{"S1.4.1", "1.22"}]},
  "1.23"->{
    Cell[17045, 514, 705, 19, 56, "DisplayFormula",
      CellTags->{"S1.4.1", "1.23"}]},
  "1.24"->{
    Cell[17753, 535, 417, 12, 50, "Text",
      CellTags->{"S1.4.1", "1.24"}]},
  "1.25"->{
    Cell[18173, 549, 272, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.1", "1.25"}]},
  "1.26"->{
    Cell[18448, 556, 767, 25, 42, "Text",
      CellTags->{"S1.4.1", "1.26"}]},
  "1.27"->{
    Cell[19218, 583, 79, 1, 35, "Subsubsection",
      CellTags->{"S1.4.1", "1.27"}]},
  "1.28"->{
    Cell[19300, 586, 1109, 32, 84, "Text",
      CellTags->{"S1.4.1", "1.28"}]},
  "1.29"->{
    Cell[20412, 620, 326, 8, 68, "DisplayFormula",
      CellTags->{"S1.4.1", "1.29"}]},
  "1.30"->{
    Cell[20741, 630, 1195, 37, 85, "Text",
      CellTags->{"S1.4.1", "1.30"}]},
  "1.31"->{
    Cell[21939, 669, 490, 9, 68, "DisplayFormula",
      CellTags->{"S1.4.1", "1.31"}]},
  "1.32"->{
    Cell[22432, 680, 1464, 51, 46, "Text",
      CellTags->{"S1.4.1", "1.32"}]},
  "1.33"->{
    Cell[23899, 733, 1369, 33, 105, "DisplayFormula",
      CellTags->{"S1.4.1", "1.33"}]},
  "1.34"->{
    Cell[25271, 768, 500, 12, 70, "Text",
      CellTags->{"S1.4.1", "1.34"}]},
  "1.35"->{
    Cell[25774, 782, 711, 14, 47, "DisplayFormula",
      CellTags->{"S1.4.1", "1.35"}]},
  "1.36"->{
    Cell[26488, 798, 238, 7, 25, "Text",
      CellTags->{"S1.4.1", "1.36"}]},
  "1.37"->{
    Cell[26729, 807, 483, 11, 47, "DisplayFormula",
      CellTags->{"S1.4.1", "1.37"}]},
  "1.38"->{
    Cell[27215, 820, 733, 23, 44, "Text",
      CellTags->{"S1.4.1", "1.38"}]},
  "S1.4.2"->{
    Cell[27951, 845, 93, 1, 39, "Subsection",
      CellTags->{"S1.4.2", "2.1"}],
    Cell[28047, 848, 482, 13, 59, "Text",
      CellTags->{"S1.4.2", "2.2"}],
    Cell[28532, 863, 273, 6, 57, "DisplayFormula",
      CellTags->{"S1.4.2", "2.3"}],
    Cell[28808, 871, 582, 19, 42, "Text",
      CellTags->{"S1.4.2", "2.4"}],
    Cell[29393, 892, 256, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.2", "2.5"}],
    Cell[29652, 899, 469, 15, 42, "Text",
      CellTags->{"S1.4.2", "2.6"}],
    Cell[30124, 916, 260, 6, 71, "DisplayFormula",
      CellTags->{"S1.4.2", "2.7"}],
    Cell[30387, 924, 949, 20, 112, "Text",
      CellTags->{"S1.4.2", "2.8"}],
    Cell[31339, 946, 322, 8, 68, "DisplayFormula",
      CellTags->{"S1.4.2", "2.9"}],
    Cell[31664, 956, 1710, 52, 99, "Text",
      CellTags->{"S1.4.2", "2.10"}],
    Cell[33377, 1010, 127, 4, 35, "Subsubsection",
      CellTags->{"S1.4.2", "2.11"}],
    Cell[33507, 1016, 657, 21, 42, "Text",
      CellTags->{"S1.4.2", "2.12"}],
    Cell[34167, 1039, 557, 16, 67, "DisplayFormula",
      CellTags->{"S1.4.2", "2.13"}],
    Cell[34727, 1057, 78, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.14"}],
    Cell[34808, 1060, 93, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[34904, 1064, 334, 11, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.15"}],
    Cell[35241, 1077, 141, 5, 51, "Input",
      CellTags->"S1.4.2"],
    Cell[35385, 1084, 674, 16, 76, "Text",
      CellTags->{"S1.4.2", "2.16"}],
    Cell[36062, 1102, 657, 19, 65, "MathCaption",
      CellTags->{"S1.4.2", "2.17"}],
    Cell[36744, 1125, 135, 6, 71, "Input",
      CellTags->"S1.4.2"],
    Cell[36882, 1133, 441, 8, 42, "Output",
      CellTags->"S1.4.2"],
    Cell[37338, 1144, 291, 6, 65, "MathCaption",
      CellTags->{"S1.4.2", "2.18"}],
    Cell[37654, 1154, 234, 8, 111, "Input",
      CellTags->"S1.4.2"],
    Cell[37891, 1164, 3680, 262, 186, 3607, 259, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.2"],
    Cell[41586, 1429, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.19"}],
    Cell[41721, 1434, 96, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[41820, 1438, 260, 5, 23, "Output",
      CellTags->"S1.4.2"],
    Cell[42095, 1446, 303, 10, 32, "MathCaption",
      CellTags->{"S1.4.2", "2.20"}],
    Cell[42423, 1460, 85, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[42511, 1464, 282, 6, 42, "Output",
      CellTags->"S1.4.2"],
    Cell[42808, 1473, 1075, 33, 83, "Text",
      CellTags->{"S1.4.2", "2.21"}],
    Cell[43886, 1508, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.22"}],
    Cell[44009, 1513, 161, 5, 51, "Input",
      CellTags->"S1.4.2"],
    Cell[44173, 1520, 305, 6, 42, "Output",
      CellTags->"S1.4.2"],
    Cell[44493, 1529, 182, 5, 25, "Text",
      CellTags->{"S1.4.2", "2.23"}],
    Cell[44678, 1536, 175, 7, 25, "Text",
      CellTags->{"S1.4.2", "2.24"}],
    Cell[44856, 1545, 603, 16, 59, "Text",
      CellTags->{"S1.4.2", "2.25"}],
    Cell[45462, 1563, 239, 7, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.26"}],
    Cell[45726, 1574, 88, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[45817, 1578, 254, 5, 42, "Output",
      CellTags->"S1.4.2"],
    Cell[46086, 1586, 392, 11, 59, "Text",
      CellTags->{"S1.4.2", "2.27"}],
    Cell[46481, 1599, 232, 10, 25, "Text",
      CellTags->{"S1.4.2", "2.28"}],
    Cell[46716, 1611, 862, 24, 76, "Text",
      CellTags->{"S1.4.2", "2.29"}],
    Cell[47581, 1637, 141, 4, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.30"}],
    Cell[47747, 1645, 88, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[47838, 1649, 1261, 24, 213, "Output",
      CellTags->"S1.4.2"],
    Cell[49114, 1676, 128, 4, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.31"}],
    Cell[49267, 1684, 77, 2, 31, "Input",
      CellTags->"S1.4.2"],
    Cell[49347, 1688, 84, 3, 23, "Output",
      CellTags->"S1.4.2"]},
  "2.1"->{
    Cell[27951, 845, 93, 1, 39, "Subsection",
      CellTags->{"S1.4.2", "2.1"}]},
  "2.2"->{
    Cell[28047, 848, 482, 13, 59, "Text",
      CellTags->{"S1.4.2", "2.2"}]},
  "2.3"->{
    Cell[28532, 863, 273, 6, 57, "DisplayFormula",
      CellTags->{"S1.4.2", "2.3"}]},
  "2.4"->{
    Cell[28808, 871, 582, 19, 42, "Text",
      CellTags->{"S1.4.2", "2.4"}]},
  "2.5"->{
    Cell[29393, 892, 256, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.2", "2.5"}]},
  "2.6"->{
    Cell[29652, 899, 469, 15, 42, "Text",
      CellTags->{"S1.4.2", "2.6"}]},
  "2.7"->{
    Cell[30124, 916, 260, 6, 71, "DisplayFormula",
      CellTags->{"S1.4.2", "2.7"}]},
  "2.8"->{
    Cell[30387, 924, 949, 20, 112, "Text",
      CellTags->{"S1.4.2", "2.8"}]},
  "2.9"->{
    Cell[31339, 946, 322, 8, 68, "DisplayFormula",
      CellTags->{"S1.4.2", "2.9"}]},
  "2.10"->{
    Cell[31664, 956, 1710, 52, 99, "Text",
      CellTags->{"S1.4.2", "2.10"}]},
  "2.11"->{
    Cell[33377, 1010, 127, 4, 35, "Subsubsection",
      CellTags->{"S1.4.2", "2.11"}]},
  "2.12"->{
    Cell[33507, 1016, 657, 21, 42, "Text",
      CellTags->{"S1.4.2", "2.12"}]},
  "2.13"->{
    Cell[34167, 1039, 557, 16, 67, "DisplayFormula",
      CellTags->{"S1.4.2", "2.13"}]},
  "2.14"->{
    Cell[34727, 1057, 78, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.14"}]},
  "2.15"->{
    Cell[34904, 1064, 334, 11, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.15"}]},
  "2.16"->{
    Cell[35385, 1084, 674, 16, 76, "Text",
      CellTags->{"S1.4.2", "2.16"}]},
  "2.17"->{
    Cell[36062, 1102, 657, 19, 65, "MathCaption",
      CellTags->{"S1.4.2", "2.17"}]},
  "2.18"->{
    Cell[37338, 1144, 291, 6, 65, "MathCaption",
      CellTags->{"S1.4.2", "2.18"}]},
  "2.19"->{
    Cell[41586, 1429, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.19"}]},
  "2.20"->{
    Cell[42095, 1446, 303, 10, 32, "MathCaption",
      CellTags->{"S1.4.2", "2.20"}]},
  "2.21"->{
    Cell[42808, 1473, 1075, 33, 83, "Text",
      CellTags->{"S1.4.2", "2.21"}]},
  "2.22"->{
    Cell[43886, 1508, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.22"}]},
  "2.23"->{
    Cell[44493, 1529, 182, 5, 25, "Text",
      CellTags->{"S1.4.2", "2.23"}]},
  "2.24"->{
    Cell[44678, 1536, 175, 7, 25, "Text",
      CellTags->{"S1.4.2", "2.24"}]},
  "2.25"->{
    Cell[44856, 1545, 603, 16, 59, "Text",
      CellTags->{"S1.4.2", "2.25"}]},
  "2.26"->{
    Cell[45462, 1563, 239, 7, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.26"}]},
  "2.27"->{
    Cell[46086, 1586, 392, 11, 59, "Text",
      CellTags->{"S1.4.2", "2.27"}]},
  "2.28"->{
    Cell[46481, 1599, 232, 10, 25, "Text",
      CellTags->{"S1.4.2", "2.28"}]},
  "2.29"->{
    Cell[46716, 1611, 862, 24, 76, "Text",
      CellTags->{"S1.4.2", "2.29"}]},
  "2.30"->{
    Cell[47581, 1637, 141, 4, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.30"}]},
  "2.31"->{
    Cell[49114, 1676, 128, 4, 31, "MathCaption",
      CellTags->{"S1.4.2", "2.31"}]},
  "S1.4.3"->{
    Cell[49446, 1694, 94, 1, 39, "Subsection",
      CellTags->{"S1.4.3", "3.1"}],
    Cell[49543, 1697, 1414, 30, 194, "Text",
      CellTags->{"S1.4.3", "3.2"}],
    Cell[50960, 1729, 519, 11, 54, "DisplayFormula",
      CellTags->{"S1.4.3", "3.3"}],
    Cell[51482, 1742, 3269, 100, 170, "Text",
      CellTags->{"S1.4.3", "3.4"}],
    Cell[54754, 1844, 289, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.3", "3.5"}],
    Cell[55046, 1852, 3699, 107, 228, "Text",
      CellTags->{"S1.4.3", "3.6"}],
    Cell[58748, 1961, 600, 12, 48, "DisplayFormula",
      CellTags->{"S1.4.3", "3.7"}],
    Cell[59351, 1975, 78, 1, 25, "Text",
      CellTags->{"S1.4.3", "3.8"}],
    Cell[59432, 1978, 160, 4, 32, "DisplayFormula",
      CellTags->{"S1.4.3", "3.9"}],
    Cell[59595, 1984, 818, 27, 43, "Text",
      CellTags->{"S1.4.3", "3.10"}],
    Cell[60416, 2013, 6303, 167, 155, "DisplayFormula",
      CellTags->{"S1.4.3", "3.11"}],
    Cell[66722, 2182, 1990, 56, 143, "Text",
      CellTags->{"S1.4.3", "3.12"}],
    Cell[68715, 2240, 235, 10, 25, "Text",
      CellTags->{"S1.4.3", "3.13"}],
    Cell[68953, 2252, 1706, 52, 101, "Text",
      CellTags->{"S1.4.3", "3.14"}],
    Cell[70662, 2306, 100, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.15"}],
    Cell[70787, 2311, 89, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[70879, 2315, 193, 4, 23, "Output",
      CellTags->"S1.4.3"],
    Cell[71087, 2322, 221, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.16"}],
    Cell[71311, 2331, 98, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[71412, 2335, 184, 5, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.17"}],
    Cell[71621, 2344, 79, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[71703, 2348, 211, 6, 50, "Output",
      CellTags->"S1.4.3"],
    Cell[71929, 2357, 143, 5, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.18"}],
    Cell[72097, 2366, 144, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[72244, 2373, 5570, 390, 186, 5497, 387, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[77829, 2766, 853, 22, 76, "Text",
      CellTags->{"S1.4.3", "3.19"}],
    Cell[78685, 2790, 264, 8, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.20"}],
    Cell[78974, 2802, 155, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[79132, 2809, 174, 5, 23, "Output",
      CellTags->"S1.4.3"],
    Cell[79321, 2817, 240, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.21"}],
    Cell[79586, 2828, 155, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[79744, 2835, 6790, 462, 186, 6717, 459, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[86549, 3300, 274, 9, 42, "Text",
      CellTags->{"S1.4.3", "3.22"}],
    Cell[86826, 3311, 342, 16, 25, "Text",
      CellTags->{"S1.4.3", "3.23"}],
    Cell[87171, 3329, 1111, 36, 76, "Text",
      CellTags->{"S1.4.3", "3.24"}],
    Cell[88285, 3367, 109, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.25"}],
    Cell[88419, 3372, 143, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[88565, 3379, 176, 5, 23, "Output",
      CellTags->"S1.4.3"],
    Cell[88756, 3387, 865, 26, 76, "Text",
      CellTags->{"S1.4.3", "3.26"}],
    Cell[89624, 3415, 208, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.27"}],
    Cell[89857, 3426, 75, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[89935, 3430, 108, 3, 23, "Output",
      CellTags->"S1.4.3"],
    Cell[90058, 3436, 142, 4, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.28"}],
    Cell[90225, 3444, 235, 7, 91, "Input",
      CellTags->"S1.4.3"],
    Cell[90463, 3453, 8729, 578, 186, 8656, 575, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[99207, 4034, 105, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.29"}],
    Cell[99315, 4037, 92, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[99410, 4041, 107, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.30"}],
    Cell[99542, 4046, 181, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[99726, 4053, 27047, 1746, 186, 26974, 1743, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[126788, 5802, 341, 9, 42, "Text",
      CellTags->{"S1.4.3", "3.31"}],
    Cell[127132, 5813, 227, 10, 25, "Text",
      CellTags->{"S1.4.3", "3.32"}],
    Cell[127362, 5825, 880, 31, 42, "Text",
      CellTags->{"S1.4.3", "3.33"}],
    Cell[128245, 5858, 226, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.34"}],
    Cell[128474, 5867, 87, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[128564, 5871, 124, 4, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.35"}],
    Cell[128713, 5879, 76, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[128792, 5883, 169, 4, 37, "Output",
      CellTags->"S1.4.3"],
    Cell[128976, 5890, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.36"}],
    Cell[129111, 5895, 161, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[129275, 5902, 6895, 473, 186, 6822, 470, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[136185, 6378, 342, 11, 48, "MathCaption",
      CellTags->{"S1.4.3", "3.37"}],
    Cell[136552, 6393, 109, 2, 31, "Input",
      CellTags->"S1.4.3"],
    Cell[136664, 6397, 176, 5, 23, "Output",
      CellTags->"S1.4.3"],
    Cell[136855, 6405, 108, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.38"}],
    Cell[136988, 6410, 181, 6, 71, "Input",
      CellTags->"S1.4.3"],
    Cell[137172, 6418, 10415, 693, 186, 10342, 690, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"],
    Cell[147602, 7114, 94, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.39"}],
    Cell[147721, 7119, 173, 5, 51, "Input",
      CellTags->"S1.4.3"],
    Cell[147897, 7126, 27216, 1770, 186, 27143, 1767, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.3"]},
  "3.1"->{
    Cell[49446, 1694, 94, 1, 39, "Subsection",
      CellTags->{"S1.4.3", "3.1"}]},
  "3.2"->{
    Cell[49543, 1697, 1414, 30, 194, "Text",
      CellTags->{"S1.4.3", "3.2"}]},
  "3.3"->{
    Cell[50960, 1729, 519, 11, 54, "DisplayFormula",
      CellTags->{"S1.4.3", "3.3"}]},
  "3.4"->{
    Cell[51482, 1742, 3269, 100, 170, "Text",
      CellTags->{"S1.4.3", "3.4"}]},
  "3.5"->{
    Cell[54754, 1844, 289, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.3", "3.5"}]},
  "3.6"->{
    Cell[55046, 1852, 3699, 107, 228, "Text",
      CellTags->{"S1.4.3", "3.6"}]},
  "3.7"->{
    Cell[58748, 1961, 600, 12, 48, "DisplayFormula",
      CellTags->{"S1.4.3", "3.7"}]},
  "3.8"->{
    Cell[59351, 1975, 78, 1, 25, "Text",
      CellTags->{"S1.4.3", "3.8"}]},
  "3.9"->{
    Cell[59432, 1978, 160, 4, 32, "DisplayFormula",
      CellTags->{"S1.4.3", "3.9"}]},
  "3.10"->{
    Cell[59595, 1984, 818, 27, 43, "Text",
      CellTags->{"S1.4.3", "3.10"}]},
  "3.11"->{
    Cell[60416, 2013, 6303, 167, 155, "DisplayFormula",
      CellTags->{"S1.4.3", "3.11"}]},
  "3.12"->{
    Cell[66722, 2182, 1990, 56, 143, "Text",
      CellTags->{"S1.4.3", "3.12"}]},
  "3.13"->{
    Cell[68715, 2240, 235, 10, 25, "Text",
      CellTags->{"S1.4.3", "3.13"}]},
  "3.14"->{
    Cell[68953, 2252, 1706, 52, 101, "Text",
      CellTags->{"S1.4.3", "3.14"}]},
  "3.15"->{
    Cell[70662, 2306, 100, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.15"}]},
  "3.16"->{
    Cell[71087, 2322, 221, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.16"}]},
  "3.17"->{
    Cell[71412, 2335, 184, 5, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.17"}]},
  "3.18"->{
    Cell[71929, 2357, 143, 5, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.18"}]},
  "3.19"->{
    Cell[77829, 2766, 853, 22, 76, "Text",
      CellTags->{"S1.4.3", "3.19"}]},
  "3.20"->{
    Cell[78685, 2790, 264, 8, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.20"}]},
  "3.21"->{
    Cell[79321, 2817, 240, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.21"}]},
  "3.22"->{
    Cell[86549, 3300, 274, 9, 42, "Text",
      CellTags->{"S1.4.3", "3.22"}]},
  "3.23"->{
    Cell[86826, 3311, 342, 16, 25, "Text",
      CellTags->{"S1.4.3", "3.23"}]},
  "3.24"->{
    Cell[87171, 3329, 1111, 36, 76, "Text",
      CellTags->{"S1.4.3", "3.24"}]},
  "3.25"->{
    Cell[88285, 3367, 109, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.25"}]},
  "3.26"->{
    Cell[88756, 3387, 865, 26, 76, "Text",
      CellTags->{"S1.4.3", "3.26"}]},
  "3.27"->{
    Cell[89624, 3415, 208, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.27"}]},
  "3.28"->{
    Cell[90058, 3436, 142, 4, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.28"}]},
  "3.29"->{
    Cell[99207, 4034, 105, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.29"}]},
  "3.30"->{
    Cell[99410, 4041, 107, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.30"}]},
  "3.31"->{
    Cell[126788, 5802, 341, 9, 42, "Text",
      CellTags->{"S1.4.3", "3.31"}]},
  "3.32"->{
    Cell[127132, 5813, 227, 10, 25, "Text",
      CellTags->{"S1.4.3", "3.32"}]},
  "3.33"->{
    Cell[127362, 5825, 880, 31, 42, "Text",
      CellTags->{"S1.4.3", "3.33"}]},
  "3.34"->{
    Cell[128245, 5858, 226, 7, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.34"}]},
  "3.35"->{
    Cell[128564, 5871, 124, 4, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.35"}]},
  "3.36"->{
    Cell[128976, 5890, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.36"}]},
  "3.37"->{
    Cell[136185, 6378, 342, 11, 48, "MathCaption",
      CellTags->{"S1.4.3", "3.37"}]},
  "3.38"->{
    Cell[136855, 6405, 108, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.38"}]},
  "3.39"->{
    Cell[147602, 7114, 94, 1, 31, "MathCaption",
      CellTags->{"S1.4.3", "3.39"}]},
  "S1.4.4"->{
    Cell[175128, 8899, 95, 1, 39, "Subsection",
      CellTags->{"S1.4.4", "4.1"}],
    Cell[175226, 8902, 2468, 61, 238, "Text",
      CellTags->{"S1.4.4", "4.2"}],
    Cell[177697, 8965, 330, 6, 44, "DisplayFormula",
      CellTags->{"S1.4.4", "4.3"}],
    Cell[178030, 8973, 186, 7, 25, "Text",
      CellTags->{"S1.4.4", "4.4"}],
    Cell[178219, 8982, 331, 6, 44, "DisplayFormula",
      CellTags->{"S1.4.4", "4.5"}],
    Cell[178553, 8990, 2905, 80, 249, "Text",
      CellTags->{"S1.4.4", "4.6"}],
    Cell[181461, 9072, 430, 8, 36, "DisplayFormula",
      CellTags->{"S1.4.4", "4.7"}],
    Cell[181894, 9082, 120, 4, 25, "Text",
      CellTags->{"S1.4.4", "4.8"}],
    Cell[182017, 9088, 364, 7, 59, "DisplayFormula",
      CellTags->{"S1.4.4", "4.9"}],
    Cell[182384, 9097, 332, 11, 26, "Text",
      CellTags->{"S1.4.4", "4.10"}],
    Cell[182719, 9110, 237, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.4", "4.11"}],
    Cell[182959, 9117, 127, 4, 25, "Text",
      CellTags->{"S1.4.4", "4.12"}],
    Cell[183089, 9123, 300, 7, 53, "DisplayFormula",
      CellTags->{"S1.4.4", "4.13"}],
    Cell[183392, 9132, 679, 20, 61, "Text",
      CellTags->{"S1.4.4", "4.14"}],
    Cell[184074, 9154, 1008, 25, 99, "DisplayFormula",
      CellTags->{"S1.4.4", "4.15"}],
    Cell[185085, 9181, 179, 7, 26, "Text",
      CellTags->{"S1.4.4", "4.16"}],
    Cell[185267, 9190, 285, 6, 33, "DisplayFormula",
      CellTags->{"S1.4.4", "4.17"}],
    Cell[185555, 9198, 1002, 31, 61, "Text",
      CellTags->{"S1.4.4", "4.18"}],
    Cell[186560, 9231, 276, 6, 47, "DisplayFormula",
      CellTags->{"S1.4.4", "4.19"}],
    Cell[186839, 9239, 127, 4, 35, "Subsubsection",
      CellTags->{"S1.4.4", "4.20"}],
    Cell[186969, 9245, 1021, 23, 95, "Text",
      CellTags->{"S1.4.4", "4.21"}],
    Cell[187993, 9270, 391, 8, 47, "DisplayFormula",
      CellTags->{"S1.4.4", "4.22"}],
    Cell[188387, 9280, 1781, 52, 137, "Text",
      CellTags->{"S1.4.4", "4.23"}],
    Cell[190171, 9334, 353, 11, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.24"}],
    Cell[190527, 9347, 269, 7, 91, "Input",
      CellTags->"S1.4.4"],
    Cell[190799, 9356, 130, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.25"}],
    Cell[190932, 9362, 151, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[191086, 9370, 171, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.26"}],
    Cell[191282, 9378, 235, 8, 111, "Input",
      CellTags->"S1.4.4"],
    Cell[191520, 9388, 3578, 260, 186, 3505, 257, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[195113, 9651, 231, 5, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.27"}],
    Cell[195369, 9660, 109, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[195481, 9664, 261, 5, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[195757, 9672, 312, 7, 59, "Text",
      CellTags->{"S1.4.4", "4.28"}],
    Cell[196072, 9681, 153, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.29"}],
    Cell[196250, 9689, 144, 5, 51, "Input",
      CellTags->"S1.4.4"],
    Cell[196397, 9696, 4824, 335, 186, 4751, 332, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[201236, 10034, 154, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.30"}],
    Cell[201415, 10042, 176, 5, 51, "Input",
      CellTags->"S1.4.4"],
    Cell[201594, 10049, 5912, 412, 186, 5839, 409, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[207521, 10464, 678, 15, 93, "Text",
      CellTags->{"S1.4.4", "4.31"}],
    Cell[208202, 10481, 237, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.32"}],
    Cell[208464, 10492, 142, 5, 51, "Input",
      CellTags->"S1.4.4"],
    Cell[208609, 10499, 149, 4, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[208773, 10506, 139, 5, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.33"}],
    Cell[208915, 10513, 92, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[209010, 10517, 108, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.34"}],
    Cell[209143, 10522, 320, 8, 111, "Input",
      CellTags->"S1.4.4"],
    Cell[209466, 10532, 10335, 697, 186, 10262, 694, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[219816, 11232, 408, 11, 59, "Text",
      CellTags->{"S1.4.4", "4.35"}],
    Cell[220227, 11245, 245, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.36"}],
    Cell[220497, 11256, 76, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[220576, 11260, 91, 3, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[220682, 11266, 245, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.37"}],
    Cell[220952, 11277, 76, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[221031, 11281, 96, 3, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[221142, 11287, 1449, 32, 169, "Text",
      CellTags->{"S1.4.4", "4.38"}],
    Cell[222594, 11321, 145, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.39"}],
    Cell[222764, 11329, 113, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[222880, 11333, 413, 7, 42, "Output",
      CellTags->"S1.4.4"],
    Cell[223308, 11343, 271, 8, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.40"}],
    Cell[223604, 11355, 178, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[223785, 11363, 426, 8, 61, "Output",
      CellTags->"S1.4.4"],
    Cell[224226, 11374, 1072, 28, 93, "Text",
      CellTags->{"S1.4.4", "4.41"}],
    Cell[225301, 11404, 180, 7, 25, "Text",
      CellTags->{"S1.4.4", "4.42"}],
    Cell[225484, 11413, 502, 14, 59, "Text",
      CellTags->{"S1.4.4", "4.43"}],
    Cell[225989, 11429, 105, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.44"}],
    Cell[226119, 11434, 94, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[226216, 11438, 498, 9, 61, "Output",
      CellTags->"S1.4.4"],
    Cell[226729, 11450, 821, 24, 63, "Text",
      CellTags->{"S1.4.4", "4.45"}],
    Cell[227553, 11476, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.46"}],
    Cell[227676, 11481, 82, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[227761, 11485, 2126, 53, 99, "Output",
      CellTags->"S1.4.4"],
    Cell[229902, 11541, 1021, 25, 110, "Text",
      CellTags->{"S1.4.4", "4.47"}],
    Cell[230926, 11568, 354, 11, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.48"}],
    Cell[231305, 11583, 163, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[231471, 11591, 119, 3, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[231605, 11597, 166, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.49"}],
    Cell[231796, 11605, 111, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[231910, 11609, 806, 14, 118, "Output",
      CellTags->"S1.4.4"],
    Cell[232731, 11626, 389, 9, 59, "Text",
      CellTags->{"S1.4.4", "4.50"}],
    Cell[233123, 11637, 137, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.51"}],
    Cell[233285, 11645, 157, 5, 51, "Input",
      CellTags->"S1.4.4"],
    Cell[233445, 11652, 118, 3, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[233578, 11658, 83, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.52"}],
    Cell[233686, 11663, 105, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[233794, 11667, 151, 4, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[233960, 11674, 133, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.53"}],
    Cell[234118, 11682, 81, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[234202, 11686, 84, 3, 23, "Output",
      CellTags->"S1.4.4"],
    Cell[234301, 11692, 59, 1, 25, "Text",
      CellTags->{"S1.4.4", "4.54"}],
    Cell[234363, 11695, 236, 10, 25, "Text",
      CellTags->{"S1.4.4", "4.55"}],
    Cell[234602, 11707, 1253, 33, 135, "Text",
      CellTags->{"S1.4.4", "4.56"}],
    Cell[235858, 11742, 115, 2, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.57"}],
    Cell[235998, 11748, 215, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[236216, 11756, 16762, 1105, 186, 16689, 1102, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[252993, 12864, 103, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.58"}],
    Cell[253121, 12869, 207, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[253331, 12877, 16698, 1087, 186, 16625, 1084, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[270044, 13967, 103, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.59"}],
    Cell[270172, 13972, 100, 2, 31, "Input",
      CellTags->"S1.4.4"],
    Cell[270275, 13976, 1093, 22, 156, "Output",
      CellTags->"S1.4.4"],
    Cell[271383, 14001, 96, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.60"}],
    Cell[271504, 14006, 217, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[271724, 14014, 14264, 927, 186, 14191, 924, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"],
    Cell[286003, 14944, 75, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.61"}],
    Cell[286103, 14949, 209, 6, 71, "Input",
      CellTags->"S1.4.4"],
    Cell[286315, 14957, 13811, 900, 186, 13738, 897, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.4"]},
  "4.1"->{
    Cell[175128, 8899, 95, 1, 39, "Subsection",
      CellTags->{"S1.4.4", "4.1"}]},
  "4.2"->{
    Cell[175226, 8902, 2468, 61, 238, "Text",
      CellTags->{"S1.4.4", "4.2"}]},
  "4.3"->{
    Cell[177697, 8965, 330, 6, 44, "DisplayFormula",
      CellTags->{"S1.4.4", "4.3"}]},
  "4.4"->{
    Cell[178030, 8973, 186, 7, 25, "Text",
      CellTags->{"S1.4.4", "4.4"}]},
  "4.5"->{
    Cell[178219, 8982, 331, 6, 44, "DisplayFormula",
      CellTags->{"S1.4.4", "4.5"}]},
  "4.6"->{
    Cell[178553, 8990, 2905, 80, 249, "Text",
      CellTags->{"S1.4.4", "4.6"}]},
  "4.7"->{
    Cell[181461, 9072, 430, 8, 36, "DisplayFormula",
      CellTags->{"S1.4.4", "4.7"}]},
  "4.8"->{
    Cell[181894, 9082, 120, 4, 25, "Text",
      CellTags->{"S1.4.4", "4.8"}]},
  "4.9"->{
    Cell[182017, 9088, 364, 7, 59, "DisplayFormula",
      CellTags->{"S1.4.4", "4.9"}]},
  "4.10"->{
    Cell[182384, 9097, 332, 11, 26, "Text",
      CellTags->{"S1.4.4", "4.10"}]},
  "4.11"->{
    Cell[182719, 9110, 237, 5, 34, "DisplayFormula",
      CellTags->{"S1.4.4", "4.11"}]},
  "4.12"->{
    Cell[182959, 9117, 127, 4, 25, "Text",
      CellTags->{"S1.4.4", "4.12"}]},
  "4.13"->{
    Cell[183089, 9123, 300, 7, 53, "DisplayFormula",
      CellTags->{"S1.4.4", "4.13"}]},
  "4.14"->{
    Cell[183392, 9132, 679, 20, 61, "Text",
      CellTags->{"S1.4.4", "4.14"}]},
  "4.15"->{
    Cell[184074, 9154, 1008, 25, 99, "DisplayFormula",
      CellTags->{"S1.4.4", "4.15"}]},
  "4.16"->{
    Cell[185085, 9181, 179, 7, 26, "Text",
      CellTags->{"S1.4.4", "4.16"}]},
  "4.17"->{
    Cell[185267, 9190, 285, 6, 33, "DisplayFormula",
      CellTags->{"S1.4.4", "4.17"}]},
  "4.18"->{
    Cell[185555, 9198, 1002, 31, 61, "Text",
      CellTags->{"S1.4.4", "4.18"}]},
  "4.19"->{
    Cell[186560, 9231, 276, 6, 47, "DisplayFormula",
      CellTags->{"S1.4.4", "4.19"}]},
  "4.20"->{
    Cell[186839, 9239, 127, 4, 35, "Subsubsection",
      CellTags->{"S1.4.4", "4.20"}]},
  "4.21"->{
    Cell[186969, 9245, 1021, 23, 95, "Text",
      CellTags->{"S1.4.4", "4.21"}]},
  "4.22"->{
    Cell[187993, 9270, 391, 8, 47, "DisplayFormula",
      CellTags->{"S1.4.4", "4.22"}]},
  "4.23"->{
    Cell[188387, 9280, 1781, 52, 137, "Text",
      CellTags->{"S1.4.4", "4.23"}]},
  "4.24"->{
    Cell[190171, 9334, 353, 11, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.24"}]},
  "4.25"->{
    Cell[190799, 9356, 130, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.25"}]},
  "4.26"->{
    Cell[191086, 9370, 171, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.26"}]},
  "4.27"->{
    Cell[195113, 9651, 231, 5, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.27"}]},
  "4.28"->{
    Cell[195757, 9672, 312, 7, 59, "Text",
      CellTags->{"S1.4.4", "4.28"}]},
  "4.29"->{
    Cell[196072, 9681, 153, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.29"}]},
  "4.30"->{
    Cell[201236, 10034, 154, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.30"}]},
  "4.31"->{
    Cell[207521, 10464, 678, 15, 93, "Text",
      CellTags->{"S1.4.4", "4.31"}]},
  "4.32"->{
    Cell[208202, 10481, 237, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.32"}]},
  "4.33"->{
    Cell[208773, 10506, 139, 5, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.33"}]},
  "4.34"->{
    Cell[209010, 10517, 108, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.34"}]},
  "4.35"->{
    Cell[219816, 11232, 408, 11, 59, "Text",
      CellTags->{"S1.4.4", "4.35"}]},
  "4.36"->{
    Cell[220227, 11245, 245, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.36"}]},
  "4.37"->{
    Cell[220682, 11266, 245, 7, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.37"}]},
  "4.38"->{
    Cell[221142, 11287, 1449, 32, 169, "Text",
      CellTags->{"S1.4.4", "4.38"}]},
  "4.39"->{
    Cell[222594, 11321, 145, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.39"}]},
  "4.40"->{
    Cell[223308, 11343, 271, 8, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.40"}]},
  "4.41"->{
    Cell[224226, 11374, 1072, 28, 93, "Text",
      CellTags->{"S1.4.4", "4.41"}]},
  "4.42"->{
    Cell[225301, 11404, 180, 7, 25, "Text",
      CellTags->{"S1.4.4", "4.42"}]},
  "4.43"->{
    Cell[225484, 11413, 502, 14, 59, "Text",
      CellTags->{"S1.4.4", "4.43"}]},
  "4.44"->{
    Cell[225989, 11429, 105, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.44"}]},
  "4.45"->{
    Cell[226729, 11450, 821, 24, 63, "Text",
      CellTags->{"S1.4.4", "4.45"}]},
  "4.46"->{
    Cell[227553, 11476, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.46"}]},
  "4.47"->{
    Cell[229902, 11541, 1021, 25, 110, "Text",
      CellTags->{"S1.4.4", "4.47"}]},
  "4.48"->{
    Cell[230926, 11568, 354, 11, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.48"}]},
  "4.49"->{
    Cell[231605, 11597, 166, 4, 48, "MathCaption",
      CellTags->{"S1.4.4", "4.49"}]},
  "4.50"->{
    Cell[232731, 11626, 389, 9, 59, "Text",
      CellTags->{"S1.4.4", "4.50"}]},
  "4.51"->{
    Cell[233123, 11637, 137, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.51"}]},
  "4.52"->{
    Cell[233578, 11658, 83, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.52"}]},
  "4.53"->{
    Cell[233960, 11674, 133, 4, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.53"}]},
  "4.54"->{
    Cell[234301, 11692, 59, 1, 25, "Text",
      CellTags->{"S1.4.4", "4.54"}]},
  "4.55"->{
    Cell[234363, 11695, 236, 10, 25, "Text",
      CellTags->{"S1.4.4", "4.55"}]},
  "4.56"->{
    Cell[234602, 11707, 1253, 33, 135, "Text",
      CellTags->{"S1.4.4", "4.56"}]},
  "4.57"->{
    Cell[235858, 11742, 115, 2, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.57"}]},
  "4.58"->{
    Cell[252993, 12864, 103, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.58"}]},
  "4.59"->{
    Cell[270044, 13967, 103, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.59"}]},
  "4.60"->{
    Cell[271383, 14001, 96, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.60"}]},
  "4.61"->{
    Cell[286003, 14944, 75, 1, 31, "MathCaption",
      CellTags->{"S1.4.4", "4.61"}]},
  "S1.4.5"->{
    Cell[300141, 15860, 67, 1, 39, "Subsection",
      CellTags->{"S1.4.5", "5.1"}],
    Cell[300211, 15863, 953, 26, 76, "Text",
      CellTags->{"S1.4.5", "5.2"}],
    Cell[301167, 15891, 361, 9, 43, "DisplayFormula",
      CellTags->{"S1.4.5", "5.3"}],
    Cell[301531, 15902, 51, 1, 25, "Text",
      CellTags->{"S1.4.5", "5.4"}],
    Cell[301585, 15905, 511, 13, 43, "DisplayFormula",
      CellTags->{"S1.4.5", "5.5"}],
    Cell[302099, 15920, 253, 7, 25, "Text",
      CellTags->{"S1.4.5", "5.6"}],
    Cell[302355, 15929, 287, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.5", "5.7"}],
    Cell[302645, 15937, 51, 1, 25, "Text",
      CellTags->{"S1.4.5", "5.8"}],
    Cell[302699, 15940, 312, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.5", "5.9"}],
    Cell[303014, 15948, 483, 15, 42, "Text",
      CellTags->{"S1.4.5", "5.10"}],
    Cell[303500, 15965, 962, 23, 56, "DisplayFormula",
      CellTags->{"S1.4.5", "5.11"}],
    Cell[304465, 15990, 304, 11, 25, "Text",
      CellTags->{"S1.4.5", "5.12"}],
    Cell[304772, 16003, 287, 6, 56, "DisplayFormula",
      CellTags->{"S1.4.5", "5.13"}],
    Cell[305062, 16011, 581, 16, 67, "Text",
      CellTags->{"S1.4.5", "5.14"}],
    Cell[305646, 16029, 172, 7, 25, "Text",
      CellTags->{"S1.4.5", "5.15"}],
    Cell[305821, 16038, 1354, 42, 93, "Text",
      CellTags->{"S1.4.5", "5.16"}],
    Cell[307178, 16082, 106, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.17"}],
    Cell[307309, 16087, 90, 2, 31, "Input",
      CellTags->"S1.4.5"],
    Cell[307402, 16091, 401, 8, 61, "Output",
      CellTags->"S1.4.5"],
    Cell[307818, 16102, 161, 5, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.18"}],
    Cell[308004, 16111, 194, 6, 71, "Input",
      CellTags->"S1.4.5"],
    Cell[308201, 16119, 5586, 381, 186, 5513, 378, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.5"],
    Cell[313802, 16503, 177, 4, 48, "MathCaption",
      CellTags->{"S1.4.5", "5.19"}],
    Cell[314004, 16511, 186, 6, 71, "Input",
      CellTags->"S1.4.5"],
    Cell[314193, 16519, 6439, 441, 186, 6366, 438, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.5"],
    Cell[320647, 16963, 94, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.20"}],
    Cell[320766, 16968, 92, 2, 31, "Input",
      CellTags->"S1.4.5"],
    Cell[320861, 16972, 1878, 38, 270, "Output",
      CellTags->"S1.4.5"],
    Cell[322754, 17013, 84, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.21"}],
    Cell[322863, 17018, 227, 7, 91, "Input",
      CellTags->"S1.4.5"],
    Cell[323093, 17027, 11125, 809, 186, 11052, 806, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.5"],
    Cell[334233, 17839, 75, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.22"}],
    Cell[334333, 17844, 219, 7, 91, "Input",
      CellTags->"S1.4.5"],
    Cell[334555, 17853, 10626, 776, 186, 10553, 773, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.5"]},
  "5.1"->{
    Cell[300141, 15860, 67, 1, 39, "Subsection",
      CellTags->{"S1.4.5", "5.1"}]},
  "5.2"->{
    Cell[300211, 15863, 953, 26, 76, "Text",
      CellTags->{"S1.4.5", "5.2"}]},
  "5.3"->{
    Cell[301167, 15891, 361, 9, 43, "DisplayFormula",
      CellTags->{"S1.4.5", "5.3"}]},
  "5.4"->{
    Cell[301531, 15902, 51, 1, 25, "Text",
      CellTags->{"S1.4.5", "5.4"}]},
  "5.5"->{
    Cell[301585, 15905, 511, 13, 43, "DisplayFormula",
      CellTags->{"S1.4.5", "5.5"}]},
  "5.6"->{
    Cell[302099, 15920, 253, 7, 25, "Text",
      CellTags->{"S1.4.5", "5.6"}]},
  "5.7"->{
    Cell[302355, 15929, 287, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.5", "5.7"}]},
  "5.8"->{
    Cell[302645, 15937, 51, 1, 25, "Text",
      CellTags->{"S1.4.5", "5.8"}]},
  "5.9"->{
    Cell[302699, 15940, 312, 6, 34, "DisplayFormula",
      CellTags->{"S1.4.5", "5.9"}]},
  "5.10"->{
    Cell[303014, 15948, 483, 15, 42, "Text",
      CellTags->{"S1.4.5", "5.10"}]},
  "5.11"->{
    Cell[303500, 15965, 962, 23, 56, "DisplayFormula",
      CellTags->{"S1.4.5", "5.11"}]},
  "5.12"->{
    Cell[304465, 15990, 304, 11, 25, "Text",
      CellTags->{"S1.4.5", "5.12"}]},
  "5.13"->{
    Cell[304772, 16003, 287, 6, 56, "DisplayFormula",
      CellTags->{"S1.4.5", "5.13"}]},
  "5.14"->{
    Cell[305062, 16011, 581, 16, 67, "Text",
      CellTags->{"S1.4.5", "5.14"}]},
  "5.15"->{
    Cell[305646, 16029, 172, 7, 25, "Text",
      CellTags->{"S1.4.5", "5.15"}]},
  "5.16"->{
    Cell[305821, 16038, 1354, 42, 93, "Text",
      CellTags->{"S1.4.5", "5.16"}]},
  "5.17"->{
    Cell[307178, 16082, 106, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.17"}]},
  "5.18"->{
    Cell[307818, 16102, 161, 5, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.18"}]},
  "5.19"->{
    Cell[313802, 16503, 177, 4, 48, "MathCaption",
      CellTags->{"S1.4.5", "5.19"}]},
  "5.20"->{
    Cell[320647, 16963, 94, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.20"}]},
  "5.21"->{
    Cell[322754, 17013, 84, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.21"}]},
  "5.22"->{
    Cell[334233, 17839, 75, 1, 31, "MathCaption",
      CellTags->{"S1.4.5", "5.22"}]},
  "S1.4.6"->{
    Cell[345196, 18632, 520, 18, 39, "Subsection",
      CellTags->{"S1.4.6", "6.1"}],
    Cell[345719, 18652, 1228, 37, 89, "Text",
      CellTags->{"S1.4.6", "6.2"}],
    Cell[346950, 18691, 89, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.3"}],
    Cell[347042, 18694, 162, 5, 51, "Input",
      CellTags->"S1.4.6"],
    Cell[347207, 18701, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.4"}],
    Cell[347308, 18704, 90, 2, 31, "Input",
      CellTags->"S1.4.6"],
    Cell[347401, 18708, 156, 4, 48, "MathCaption",
      CellTags->{"S1.4.6", "6.5"}],
    Cell[347582, 18716, 157, 5, 51, "Input",
      CellTags->"S1.4.6"],
    Cell[347742, 18723, 5363, 370, 186, 5290, 367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[353120, 19096, 548, 16, 65, "MathCaption",
      CellTags->{"S1.4.6", "6.6"}],
    Cell[353693, 19116, 228, 6, 71, "Input",
      CellTags->"S1.4.6"],
    Cell[353924, 19124, 11713, 773, 186, 11640, 770, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[365652, 19900, 1586, 51, 76, "Text",
      CellTags->{"S1.4.6", "6.7"}],
    Cell[367241, 19953, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.8"}],
    Cell[367376, 19958, 189, 6, 71, "Input",
      CellTags->"S1.4.6"],
    Cell[367568, 19966, 5366, 369, 186, 5293, 366, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[372949, 20338, 365, 12, 42, "Text",
      CellTags->{"S1.4.6", "6.9"}],
    Cell[373317, 20352, 285, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.6", "6.10"}],
    Cell[373605, 20360, 52, 1, 25, "Text",
      CellTags->{"S1.4.6", "6.11"}],
    Cell[373660, 20363, 314, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.6", "6.12"}],
    Cell[373977, 20371, 204, 6, 42, "Text",
      CellTags->{"S1.4.6", "6.13"}],
    Cell[374184, 20379, 137, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.14"}],
    Cell[374346, 20387, 228, 6, 71, "Input",
      CellTags->"S1.4.6"],
    Cell[374577, 20395, 9503, 633, 186, 9430, 630, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[384095, 21031, 141, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.15"}],
    Cell[384261, 21039, 266, 7, 91, "Input",
      CellTags->"S1.4.6"],
    Cell[384530, 21048, 11941, 716, 186, 11868, 713, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[396486, 21767, 281, 9, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.16"}],
    Cell[396792, 21780, 225, 6, 71, "Input",
      CellTags->"S1.4.6"],
    Cell[397020, 21788, 13932, 914, 186, 13859, 911, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[410967, 22705, 281, 9, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.17"}],
    Cell[411273, 22718, 262, 7, 91, "Input",
      CellTags->"S1.4.6"],
    Cell[411538, 22727, 14481, 948, 186, 14408, 945, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[426034, 23678, 475, 12, 42, "Text",
      CellTags->{"S1.4.6", "6.18"}],
    Cell[426512, 23692, 573, 11, 64, "DisplayFormula",
      CellTags->{"S1.4.6", "6.19"}],
    Cell[427088, 23705, 127, 4, 25, "Text",
      CellTags->{"S1.4.6", "6.20"}],
    Cell[427218, 23711, 289, 13, 25, "Text",
      CellTags->{"S1.4.6", "6.21"}],
    Cell[427510, 23726, 506, 17, 42, "Text",
      CellTags->{"S1.4.6", "6.22"}],
    Cell[428019, 23745, 143, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.23"}],
    Cell[428165, 23751, 129, 5, 51, "Input",
      CellTags->"S1.4.6"],
    Cell[428297, 23758, 218, 7, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.24"}],
    Cell[428540, 23769, 157, 5, 51, "Input",
      CellTags->"S1.4.6"],
    Cell[428700, 23776, 8148, 544, 186, 8075, 541, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[436863, 24323, 1576, 53, 93, "Text",
      CellTags->{"S1.4.6", "6.25"}],
    Cell[438442, 24378, 285, 8, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.26"}],
    Cell[438730, 24388, 109, 2, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[438842, 24392, 327, 8, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.27"}],
    Cell[439194, 24404, 163, 5, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[439360, 24411, 9722, 648, 70, 9649, 645, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[449097, 25062, 232, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.28"}],
    Cell[449354, 25073, 187, 6, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[449544, 25081, 27430, 1776, 70, 27357, 1773, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[476989, 26860, 96, 1, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.29"}],
    Cell[477088, 26863, 87, 2, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[477178, 26867, 269, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.30"}],
    Cell[477472, 26878, 332, 9, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[477807, 26889, 20426, 1370, 70, 20353, 1367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"],
    Cell[498248, 28262, 350, 11, 70, "Text",
      CellTags->{"S1.4.6", "6.31"}],
    Cell[498601, 28275, 281, 13, 70, "Text",
      CellTags->{"S1.4.6", "6.32"}],
    Cell[498885, 28290, 497, 17, 70, "Text",
      CellTags->{"S1.4.6", "6.33"}],
    Cell[499385, 28309, 232, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.34"}],
    Cell[499642, 28320, 176, 6, 70, "Input",
      CellTags->"S1.4.6"],
    Cell[499821, 28328, 8852, 589, 70, 8779, 586, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.4.6"]},
  "6.1"->{
    Cell[345196, 18632, 520, 18, 39, "Subsection",
      CellTags->{"S1.4.6", "6.1"}]},
  "6.2"->{
    Cell[345719, 18652, 1228, 37, 89, "Text",
      CellTags->{"S1.4.6", "6.2"}]},
  "6.3"->{
    Cell[346950, 18691, 89, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.3"}]},
  "6.4"->{
    Cell[347207, 18701, 98, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.4"}]},
  "6.5"->{
    Cell[347401, 18708, 156, 4, 48, "MathCaption",
      CellTags->{"S1.4.6", "6.5"}]},
  "6.6"->{
    Cell[353120, 19096, 548, 16, 65, "MathCaption",
      CellTags->{"S1.4.6", "6.6"}]},
  "6.7"->{
    Cell[365652, 19900, 1586, 51, 76, "Text",
      CellTags->{"S1.4.6", "6.7"}]},
  "6.8"->{
    Cell[367241, 19953, 110, 1, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.8"}]},
  "6.9"->{
    Cell[372949, 20338, 365, 12, 42, "Text",
      CellTags->{"S1.4.6", "6.9"}]},
  "6.10"->{
    Cell[373317, 20352, 285, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.6", "6.10"}]},
  "6.11"->{
    Cell[373605, 20360, 52, 1, 25, "Text",
      CellTags->{"S1.4.6", "6.11"}]},
  "6.12"->{
    Cell[373660, 20363, 314, 6, 55, "DisplayFormula",
      CellTags->{"S1.4.6", "6.12"}]},
  "6.13"->{
    Cell[373977, 20371, 204, 6, 42, "Text",
      CellTags->{"S1.4.6", "6.13"}]},
  "6.14"->{
    Cell[374184, 20379, 137, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.14"}]},
  "6.15"->{
    Cell[384095, 21031, 141, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.15"}]},
  "6.16"->{
    Cell[396486, 21767, 281, 9, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.16"}]},
  "6.17"->{
    Cell[410967, 22705, 281, 9, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.17"}]},
  "6.18"->{
    Cell[426034, 23678, 475, 12, 42, "Text",
      CellTags->{"S1.4.6", "6.18"}]},
  "6.19"->{
    Cell[426512, 23692, 573, 11, 64, "DisplayFormula",
      CellTags->{"S1.4.6", "6.19"}]},
  "6.20"->{
    Cell[427088, 23705, 127, 4, 25, "Text",
      CellTags->{"S1.4.6", "6.20"}]},
  "6.21"->{
    Cell[427218, 23711, 289, 13, 25, "Text",
      CellTags->{"S1.4.6", "6.21"}]},
  "6.22"->{
    Cell[427510, 23726, 506, 17, 42, "Text",
      CellTags->{"S1.4.6", "6.22"}]},
  "6.23"->{
    Cell[428019, 23745, 143, 4, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.23"}]},
  "6.24"->{
    Cell[428297, 23758, 218, 7, 31, "MathCaption",
      CellTags->{"S1.4.6", "6.24"}]},
  "6.25"->{
    Cell[436863, 24323, 1576, 53, 93, "Text",
      CellTags->{"S1.4.6", "6.25"}]},
  "6.26"->{
    Cell[438442, 24378, 285, 8, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.26"}]},
  "6.27"->{
    Cell[438842, 24392, 327, 8, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.27"}]},
  "6.28"->{
    Cell[449097, 25062, 232, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.28"}]},
  "6.29"->{
    Cell[476989, 26860, 96, 1, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.29"}]},
  "6.30"->{
    Cell[477178, 26867, 269, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.30"}]},
  "6.31"->{
    Cell[498248, 28262, 350, 11, 70, "Text",
      CellTags->{"S1.4.6", "6.31"}]},
  "6.32"->{
    Cell[498601, 28275, 281, 13, 70, "Text",
      CellTags->{"S1.4.6", "6.32"}]},
  "6.33"->{
    Cell[498885, 28290, 497, 17, 70, "Text",
      CellTags->{"S1.4.6", "6.33"}]},
  "6.34"->{
    Cell[499385, 28309, 232, 7, 70, "MathCaption",
      CellTags->{"S1.4.6", "6.34"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 509347, 28938},
  {"S1.4.0", 509507, 28943},
  {"0.1", 509676, 28948},
  {"0.2", 509766, 28951},
  {"S1.4.1", 509860, 28954},
  {"1.1", 513030, 29031},
  {"1.2", 513124, 29034},
  {"1.3", 513212, 29037},
  {"1.4", 513310, 29040},
  {"1.5", 513397, 29043},
  {"1.6", 513495, 29046},
  {"1.7", 513586, 29049},
  {"1.8", 513685, 29052},
  {"1.9", 513775, 29055},
  {"1.10", 513876, 29058},
  {"1.11", 513969, 29061},
  {"1.12", 514070, 29064},
  {"1.13", 514160, 29067},
  {"1.14", 514261, 29070},
  {"1.15", 514353, 29073},
  {"1.16", 514454, 29076},
  {"1.17", 514546, 29079},
  {"1.18", 514647, 29082},
  {"1.19", 514740, 29085},
  {"1.20", 514841, 29088},
  {"1.21", 514931, 29091},
  {"1.22", 515032, 29094},
  {"1.23", 515124, 29097},
  {"1.24", 515226, 29100},
  {"1.25", 515318, 29103},
  {"1.26", 515419, 29106},
  {"1.27", 515511, 29109},
  {"1.28", 515610, 29112},
  {"1.29", 515703, 29115},
  {"1.30", 515804, 29118},
  {"1.31", 515897, 29121},
  {"1.32", 515998, 29124},
  {"1.33", 516091, 29127},
  {"1.34", 516195, 29130},
  {"1.35", 516287, 29133},
  {"1.36", 516389, 29136},
  {"1.37", 516480, 29139},
  {"1.38", 516582, 29142},
  {"S1.4.2", 516676, 29145},
  {"2.1", 520616, 29246},
  {"2.2", 520710, 29249},
  {"2.3", 520800, 29252},
  {"2.4", 520899, 29255},
  {"2.5", 520989, 29258},
  {"2.6", 521088, 29261},
  {"2.7", 521178, 29264},
  {"2.8", 521277, 29267},
  {"2.9", 521368, 29270},
  {"2.10", 521468, 29273},
  {"2.11", 521561, 29276},
  {"2.12", 521662, 29279},
  {"2.13", 521755, 29282},
  {"2.14", 521858, 29285},
  {"2.15", 521956, 29288},
  {"2.16", 522056, 29291},
  {"2.17", 522149, 29294},
  {"2.18", 522249, 29297},
  {"2.19", 522348, 29300},
  {"2.20", 522447, 29303},
  {"2.21", 522547, 29306},
  {"2.22", 522641, 29309},
  {"2.23", 522739, 29312},
  {"2.24", 522831, 29315},
  {"2.25", 522923, 29318},
  {"2.26", 523016, 29321},
  {"2.27", 523115, 29324},
  {"2.28", 523208, 29327},
  {"2.29", 523301, 29330},
  {"2.30", 523394, 29333},
  {"2.31", 523493, 29336},
  {"S1.4.3", 523594, 29339},
  {"3.1", 529664, 29494},
  {"3.2", 529759, 29497},
  {"3.3", 529852, 29500},
  {"3.4", 529953, 29503},
  {"3.5", 530047, 29506},
  {"3.6", 530147, 29509},
  {"3.7", 530241, 29512},
  {"3.8", 530342, 29515},
  {"3.9", 530431, 29518},
  {"3.10", 530532, 29521},
  {"3.11", 530625, 29524},
  {"3.12", 530731, 29527},
  {"3.13", 530826, 29530},
  {"3.14", 530919, 29533},
  {"3.15", 531014, 29536},
  {"3.16", 531113, 29539},
  {"3.17", 531212, 29542},
  {"3.18", 531311, 29545},
  {"3.19", 531410, 29548},
  {"3.20", 531503, 29551},
  {"3.21", 531602, 29554},
  {"3.22", 531701, 29557},
  {"3.23", 531793, 29560},
  {"3.24", 531886, 29563},
  {"3.25", 531980, 29566},
  {"3.26", 532079, 29569},
  {"3.27", 532172, 29572},
  {"3.28", 532271, 29575},
  {"3.29", 532370, 29578},
  {"3.30", 532469, 29581},
  {"3.31", 532568, 29584},
  {"3.32", 532661, 29587},
  {"3.33", 532755, 29590},
  {"3.34", 532849, 29593},
  {"3.35", 532949, 29596},
  {"3.36", 533049, 29599},
  {"3.37", 533149, 29602},
  {"3.38", 533250, 29605},
  {"3.39", 533350, 29608},
  {"S1.4.4", 533451, 29611},
  {"4.1", 542753, 29844},
  {"4.2", 542849, 29847},
  {"4.3", 542943, 29850},
  {"4.4", 543044, 29853},
  {"4.5", 543135, 29856},
  {"4.6", 543236, 29859},
  {"4.7", 543330, 29862},
  {"4.8", 543431, 29865},
  {"4.9", 543522, 29868},
  {"4.10", 543624, 29871},
  {"4.11", 543718, 29874},
  {"4.12", 543821, 29877},
  {"4.13", 543914, 29880},
  {"4.14", 544017, 29883},
  {"4.15", 544111, 29886},
  {"4.16", 544216, 29889},
  {"4.17", 544309, 29892},
  {"4.18", 544412, 29895},
  {"4.19", 544507, 29898},
  {"4.20", 544610, 29901},
  {"4.21", 544712, 29904},
  {"4.22", 544807, 29907},
  {"4.23", 544910, 29910},
  {"4.24", 545006, 29913},
  {"4.25", 545107, 29916},
  {"4.26", 545207, 29919},
  {"4.27", 545307, 29922},
  {"4.28", 545407, 29925},
  {"4.29", 545500, 29928},
  {"4.30", 545600, 29931},
  {"4.31", 545701, 29934},
  {"4.32", 545796, 29937},
  {"4.33", 545897, 29940},
  {"4.34", 545998, 29943},
  {"4.35", 546099, 29946},
  {"4.36", 546194, 29949},
  {"4.37", 546295, 29952},
  {"4.38", 546396, 29955},
  {"4.39", 546493, 29958},
  {"4.40", 546594, 29961},
  {"4.41", 546695, 29964},
  {"4.42", 546791, 29967},
  {"4.43", 546885, 29970},
  {"4.44", 546980, 29973},
  {"4.45", 547081, 29976},
  {"4.46", 547176, 29979},
  {"4.47", 547276, 29982},
  {"4.48", 547373, 29985},
  {"4.49", 547475, 29988},
  {"4.50", 547576, 29991},
  {"4.51", 547670, 29994},
  {"4.52", 547771, 29997},
  {"4.53", 547871, 30000},
  {"4.54", 547972, 30003},
  {"4.55", 548065, 30006},
  {"4.56", 548160, 30009},
  {"4.57", 548257, 30012},
  {"4.58", 548358, 30015},
  {"4.59", 548459, 30018},
  {"4.60", 548560, 30021},
  {"4.61", 548660, 30024},
  {"S1.4.5", 548762, 30027},
  {"5.1", 551860, 30104},
  {"5.2", 551957, 30107},
  {"5.3", 552050, 30110},
  {"5.4", 552152, 30113},
  {"5.5", 552243, 30116},
  {"5.6", 552346, 30119},
  {"5.7", 552438, 30122},
  {"5.8", 552540, 30125},
  {"5.9", 552631, 30128},
  {"5.10", 552734, 30131},
  {"5.11", 552829, 30134},
  {"5.12", 552934, 30137},
  {"5.13", 553029, 30140},
  {"5.14", 553133, 30143},
  {"5.15", 553228, 30146},
  {"5.16", 553322, 30149},
  {"5.17", 553418, 30152},
  {"5.18", 553519, 30155},
  {"5.19", 553620, 30158},
  {"5.20", 553721, 30161},
  {"5.21", 553821, 30164},
  {"5.22", 553921, 30167},
  {"S1.4.6", 554023, 30170},
  {"6.1", 560041, 30321},
  {"6.2", 560140, 30324},
  {"6.3", 560234, 30327},
  {"6.4", 560332, 30330},
  {"6.5", 560430, 30333},
  {"6.6", 560529, 30336},
  {"6.7", 560629, 30339},
  {"6.8", 560723, 30342},
  {"6.9", 560822, 30345},
  {"6.10", 560916, 30348},
  {"6.11", 561020, 30351},
  {"6.12", 561113, 30354},
  {"6.13", 561217, 30357},
  {"6.14", 561311, 30360},
  {"6.15", 561412, 30363},
  {"6.16", 561513, 30366},
  {"6.17", 561614, 30369},
  {"6.18", 561715, 30372},
  {"6.19", 561810, 30375},
  {"6.20", 561915, 30378},
  {"6.21", 562009, 30381},
  {"6.22", 562104, 30384},
  {"6.23", 562199, 30387},
  {"6.24", 562300, 30390},
  {"6.25", 562401, 30393},
  {"6.26", 562497, 30396},
  {"6.27", 562598, 30399},
  {"6.28", 562699, 30402},
  {"6.29", 562800, 30405},
  {"6.30", 562900, 30408},
  {"6.31", 563001, 30411},
  {"6.32", 563096, 30414},
  {"6.33", 563191, 30417},
  {"6.34", 563286, 30420}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 90, 1, 56, "Section",
  CellTags->"Contents"],
Cell[1810, 52, 1566, 51, 144, "Contents",
  CellTags->"Contents"],
Cell[3379, 105, 97, 1, 56, "Section",
  CellTags->{"S1.4.0", "0.1"}],
Cell[3479, 108, 2478, 56, 305, "Text",
  CellTags->{"S1.4.0", "0.2"}],
Cell[5960, 166, 101, 1, 39, "Subsection",
  CellTags->{"S1.4.1", "1.1"}],
Cell[6064, 169, 168, 4, 42, "Text",
  CellTags->{"S1.4.1", "1.2"}],
Cell[6235, 175, 363, 8, 46, "DisplayFormula",
  CellTags->{"S1.4.1", "1.3"}],
Cell[6601, 185, 72, 1, 25, "Text",
  CellTags->{"S1.4.1", "1.4"}],
Cell[6676, 188, 368, 8, 46, "DisplayFormula",
  CellTags->{"S1.4.1", "1.5"}],
Cell[7047, 198, 3034, 87, 206, "Text",
  CellTags->{"S1.4.1", "1.6"}],
Cell[10084, 287, 367, 7, 32, "DisplayFormula",
  CellTags->{"S1.4.1", "1.7"}],
Cell[10454, 296, 309, 11, 25, "Text",
  CellTags->{"S1.4.1", "1.8"}],
Cell[10766, 309, 464, 11, 43, "DisplayFormula",
  CellTags->{"S1.4.1", "1.9"}],
Cell[11233, 322, 1140, 35, 60, "Text",
  CellTags->{"S1.4.1", "1.10"}],
Cell[12376, 359, 284, 6, 55, "DisplayFormula",
  CellTags->{"S1.4.1", "1.11"}],
Cell[12663, 367, 61, 1, 25, "Text",
  CellTags->{"S1.4.1", "1.12"}],
Cell[12727, 370, 205, 5, 32, "DisplayFormula",
  CellTags->{"S1.4.1", "1.13"}],
Cell[12935, 377, 363, 11, 25, "Text",
  CellTags->{"S1.4.1", "1.14"}],
Cell[13301, 390, 261, 6, 34, "DisplayFormula",
  CellTags->{"S1.4.1", "1.15"}],
Cell[13565, 398, 349, 11, 25, "Text",
  CellTags->{"S1.4.1", "1.16"}],
Cell[13917, 411, 263, 6, 31, "DisplayFormula",
  CellTags->{"S1.4.1", "1.17"}],
Cell[14183, 419, 1271, 41, 59, "Text",
  CellTags->{"S1.4.1", "1.18"}],
Cell[15457, 462, 260, 6, 32, "DisplayFormula",
  CellTags->{"S1.4.1", "1.19"}],
Cell[15720, 470, 51, 1, 25, "Text",
  CellTags->{"S1.4.1", "1.20"}],
Cell[15774, 473, 274, 6, 33, "DisplayFormula",
  CellTags->{"S1.4.1", "1.21"}],
Cell[16051, 481, 991, 31, 59, "Text",
  CellTags->{"S1.4.1", "1.22"}],
Cell[17045, 514, 705, 19, 56, "DisplayFormula",
  CellTags->{"S1.4.1", "1.23"}],
Cell[17753, 535, 417, 12, 50, "Text",
  CellTags->{"S1.4.1", "1.24"}],
Cell[18173, 549, 272, 5, 34, "DisplayFormula",
  CellTags->{"S1.4.1", "1.25"}],
Cell[18448, 556, 767, 25, 42, "Text",
  CellTags->{"S1.4.1", "1.26"}],
Cell[19218, 583, 79, 1, 35, "Subsubsection",
  CellTags->{"S1.4.1", "1.27"}],
Cell[19300, 586, 1109, 32, 84, "Text",
  CellTags->{"S1.4.1", "1.28"}],
Cell[20412, 620, 326, 8, 68, "DisplayFormula",
  CellTags->{"S1.4.1", "1.29"}],
Cell[20741, 630, 1195, 37, 85, "Text",
  CellTags->{"S1.4.1", "1.30"}],
Cell[21939, 669, 490, 9, 68, "DisplayFormula",
  CellTags->{"S1.4.1", "1.31"}],
Cell[22432, 680, 1464, 51, 46, "Text",
  CellTags->{"S1.4.1", "1.32"}],
Cell[23899, 733, 1369, 33, 105, "DisplayFormula",
  CellTags->{"S1.4.1", "1.33"}],
Cell[25271, 768, 500, 12, 70, "Text",
  CellTags->{"S1.4.1", "1.34"}],
Cell[25774, 782, 711, 14, 47, "DisplayFormula",
  CellTags->{"S1.4.1", "1.35"}],
Cell[26488, 798, 238, 7, 25, "Text",
  CellTags->{"S1.4.1", "1.36"}],
Cell[26729, 807, 483, 11, 47, "DisplayFormula",
  CellTags->{"S1.4.1", "1.37"}],
Cell[27215, 820, 733, 23, 44, "Text",
  CellTags->{"S1.4.1", "1.38"}],
Cell[27951, 845, 93, 1, 39, "Subsection",
  CellTags->{"S1.4.2", "2.1"}],
Cell[28047, 848, 482, 13, 59, "Text",
  CellTags->{"S1.4.2", "2.2"}],
Cell[28532, 863, 273, 6, 57, "DisplayFormula",
  CellTags->{"S1.4.2", "2.3"}],
Cell[28808, 871, 582, 19, 42, "Text",
  CellTags->{"S1.4.2", "2.4"}],
Cell[29393, 892, 256, 5, 34, "DisplayFormula",
  CellTags->{"S1.4.2", "2.5"}],
Cell[29652, 899, 469, 15, 42, "Text",
  CellTags->{"S1.4.2", "2.6"}],
Cell[30124, 916, 260, 6, 71, "DisplayFormula",
  CellTags->{"S1.4.2", "2.7"}],
Cell[30387, 924, 949, 20, 112, "Text",
  CellTags->{"S1.4.2", "2.8"}],
Cell[31339, 946, 322, 8, 68, "DisplayFormula",
  CellTags->{"S1.4.2", "2.9"}],
Cell[31664, 956, 1710, 52, 99, "Text",
  CellTags->{"S1.4.2", "2.10"}],
Cell[33377, 1010, 127, 4, 35, "Subsubsection",
  CellTags->{"S1.4.2", "2.11"}],
Cell[33507, 1016, 657, 21, 42, "Text",
  CellTags->{"S1.4.2", "2.12"}],
Cell[34167, 1039, 557, 16, 67, "DisplayFormula",
  CellTags->{"S1.4.2", "2.13"}],
Cell[34727, 1057, 78, 1, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.14"}],
Cell[34808, 1060, 93, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[34904, 1064, 334, 11, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.15"}],
Cell[35241, 1077, 141, 5, 51, "Input",
  CellTags->"S1.4.2"],
Cell[35385, 1084, 674, 16, 76, "Text",
  CellTags->{"S1.4.2", "2.16"}],
Cell[36062, 1102, 657, 19, 65, "MathCaption",
  CellTags->{"S1.4.2", "2.17"}],

Cell[CellGroupData[{
Cell[36744, 1125, 135, 6, 71, "Input",
  CellTags->"S1.4.2"],
Cell[36882, 1133, 441, 8, 42, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[37338, 1144, 291, 6, 65, "MathCaption",
  CellTags->{"S1.4.2", "2.18"}],

Cell[CellGroupData[{
Cell[37654, 1154, 234, 8, 111, "Input",
  CellTags->"S1.4.2"],
Cell[37891, 1164, 3680, 262, 186, 3607, 259, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[41586, 1429, 110, 1, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.19"}],

Cell[CellGroupData[{
Cell[41721, 1434, 96, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[41820, 1438, 260, 5, 23, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[42095, 1446, 303, 10, 32, "MathCaption",
  CellTags->{"S1.4.2", "2.20"}],

Cell[CellGroupData[{
Cell[42423, 1460, 85, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[42511, 1464, 282, 6, 42, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[42808, 1473, 1075, 33, 83, "Text",
  CellTags->{"S1.4.2", "2.21"}],
Cell[43886, 1508, 98, 1, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.22"}],

Cell[CellGroupData[{
Cell[44009, 1513, 161, 5, 51, "Input",
  CellTags->"S1.4.2"],
Cell[44173, 1520, 305, 6, 42, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[44493, 1529, 182, 5, 25, "Text",
  CellTags->{"S1.4.2", "2.23"}],
Cell[44678, 1536, 175, 7, 25, "Text",
  CellTags->{"S1.4.2", "2.24"}],
Cell[44856, 1545, 603, 16, 59, "Text",
  CellTags->{"S1.4.2", "2.25"}],
Cell[45462, 1563, 239, 7, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.26"}],

Cell[CellGroupData[{
Cell[45726, 1574, 88, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[45817, 1578, 254, 5, 42, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[46086, 1586, 392, 11, 59, "Text",
  CellTags->{"S1.4.2", "2.27"}],
Cell[46481, 1599, 232, 10, 25, "Text",
  CellTags->{"S1.4.2", "2.28"}],
Cell[46716, 1611, 862, 24, 76, "Text",
  CellTags->{"S1.4.2", "2.29"}],
Cell[47581, 1637, 141, 4, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.30"}],

Cell[CellGroupData[{
Cell[47747, 1645, 88, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[47838, 1649, 1261, 24, 213, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[49114, 1676, 128, 4, 31, "MathCaption",
  CellTags->{"S1.4.2", "2.31"}],

Cell[CellGroupData[{
Cell[49267, 1684, 77, 2, 31, "Input",
  CellTags->"S1.4.2"],
Cell[49347, 1688, 84, 3, 23, "Output",
  CellTags->"S1.4.2"]
}, Open  ]],
Cell[49446, 1694, 94, 1, 39, "Subsection",
  CellTags->{"S1.4.3", "3.1"}],
Cell[49543, 1697, 1414, 30, 194, "Text",
  CellTags->{"S1.4.3", "3.2"}],
Cell[50960, 1729, 519, 11, 54, "DisplayFormula",
  CellTags->{"S1.4.3", "3.3"}],
Cell[51482, 1742, 3269, 100, 170, "Text",
  CellTags->{"S1.4.3", "3.4"}],
Cell[54754, 1844, 289, 6, 55, "DisplayFormula",
  CellTags->{"S1.4.3", "3.5"}],
Cell[55046, 1852, 3699, 107, 228, "Text",
  CellTags->{"S1.4.3", "3.6"}],
Cell[58748, 1961, 600, 12, 48, "DisplayFormula",
  CellTags->{"S1.4.3", "3.7"}],
Cell[59351, 1975, 78, 1, 25, "Text",
  CellTags->{"S1.4.3", "3.8"}],
Cell[59432, 1978, 160, 4, 32, "DisplayFormula",
  CellTags->{"S1.4.3", "3.9"}],
Cell[59595, 1984, 818, 27, 43, "Text",
  CellTags->{"S1.4.3", "3.10"}],
Cell[60416, 2013, 6303, 167, 155, "DisplayFormula",
  CellTags->{"S1.4.3", "3.11"}],
Cell[66722, 2182, 1990, 56, 143, "Text",
  CellTags->{"S1.4.3", "3.12"}],
Cell[68715, 2240, 235, 10, 25, "Text",
  CellTags->{"S1.4.3", "3.13"}],
Cell[68953, 2252, 1706, 52, 101, "Text",
  CellTags->{"S1.4.3", "3.14"}],
Cell[70662, 2306, 100, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.15"}],

Cell[CellGroupData[{
Cell[70787, 2311, 89, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[70879, 2315, 193, 4, 23, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[71087, 2322, 221, 7, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.16"}],
Cell[71311, 2331, 98, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[71412, 2335, 184, 5, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.17"}],

Cell[CellGroupData[{
Cell[71621, 2344, 79, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[71703, 2348, 211, 6, 50, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[71929, 2357, 143, 5, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.18"}],

Cell[CellGroupData[{
Cell[72097, 2366, 144, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[72244, 2373, 5570, 390, 186, 5497, 387, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[77829, 2766, 853, 22, 76, "Text",
  CellTags->{"S1.4.3", "3.19"}],
Cell[78685, 2790, 264, 8, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.20"}],

Cell[CellGroupData[{
Cell[78974, 2802, 155, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[79132, 2809, 174, 5, 23, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[79321, 2817, 240, 7, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.21"}],

Cell[CellGroupData[{
Cell[79586, 2828, 155, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[79744, 2835, 6790, 462, 186, 6717, 459, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[86549, 3300, 274, 9, 42, "Text",
  CellTags->{"S1.4.3", "3.22"}],
Cell[86826, 3311, 342, 16, 25, "Text",
  CellTags->{"S1.4.3", "3.23"}],
Cell[87171, 3329, 1111, 36, 76, "Text",
  CellTags->{"S1.4.3", "3.24"}],
Cell[88285, 3367, 109, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.25"}],

Cell[CellGroupData[{
Cell[88419, 3372, 143, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[88565, 3379, 176, 5, 23, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[88756, 3387, 865, 26, 76, "Text",
  CellTags->{"S1.4.3", "3.26"}],
Cell[89624, 3415, 208, 7, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.27"}],

Cell[CellGroupData[{
Cell[89857, 3426, 75, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[89935, 3430, 108, 3, 23, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[90058, 3436, 142, 4, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.28"}],

Cell[CellGroupData[{
Cell[90225, 3444, 235, 7, 91, "Input",
  CellTags->"S1.4.3"],
Cell[90463, 3453, 8729, 578, 186, 8656, 575, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[99207, 4034, 105, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.29"}],
Cell[99315, 4037, 92, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[99410, 4041, 107, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.30"}],

Cell[CellGroupData[{
Cell[99542, 4046, 181, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[99726, 4053, 27047, 1746, 186, 26974, 1743, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[126788, 5802, 341, 9, 42, "Text",
  CellTags->{"S1.4.3", "3.31"}],
Cell[127132, 5813, 227, 10, 25, "Text",
  CellTags->{"S1.4.3", "3.32"}],
Cell[127362, 5825, 880, 31, 42, "Text",
  CellTags->{"S1.4.3", "3.33"}],
Cell[128245, 5858, 226, 7, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.34"}],
Cell[128474, 5867, 87, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[128564, 5871, 124, 4, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.35"}],

Cell[CellGroupData[{
Cell[128713, 5879, 76, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[128792, 5883, 169, 4, 37, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[128976, 5890, 110, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.36"}],

Cell[CellGroupData[{
Cell[129111, 5895, 161, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[129275, 5902, 6895, 473, 186, 6822, 470, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[136185, 6378, 342, 11, 48, "MathCaption",
  CellTags->{"S1.4.3", "3.37"}],

Cell[CellGroupData[{
Cell[136552, 6393, 109, 2, 31, "Input",
  CellTags->"S1.4.3"],
Cell[136664, 6397, 176, 5, 23, "Output",
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[136855, 6405, 108, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.38"}],

Cell[CellGroupData[{
Cell[136988, 6410, 181, 6, 71, "Input",
  CellTags->"S1.4.3"],
Cell[137172, 6418, 10415, 693, 186, 10342, 690, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[147602, 7114, 94, 1, 31, "MathCaption",
  CellTags->{"S1.4.3", "3.39"}],

Cell[CellGroupData[{
Cell[147721, 7119, 173, 5, 51, "Input",
  CellTags->"S1.4.3"],
Cell[147897, 7126, 27216, 1770, 186, 27143, 1767, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.3"]
}, Open  ]],
Cell[175128, 8899, 95, 1, 39, "Subsection",
  CellTags->{"S1.4.4", "4.1"}],
Cell[175226, 8902, 2468, 61, 238, "Text",
  CellTags->{"S1.4.4", "4.2"}],
Cell[177697, 8965, 330, 6, 44, "DisplayFormula",
  CellTags->{"S1.4.4", "4.3"}],
Cell[178030, 8973, 186, 7, 25, "Text",
  CellTags->{"S1.4.4", "4.4"}],
Cell[178219, 8982, 331, 6, 44, "DisplayFormula",
  CellTags->{"S1.4.4", "4.5"}],
Cell[178553, 8990, 2905, 80, 249, "Text",
  CellTags->{"S1.4.4", "4.6"}],
Cell[181461, 9072, 430, 8, 36, "DisplayFormula",
  CellTags->{"S1.4.4", "4.7"}],
Cell[181894, 9082, 120, 4, 25, "Text",
  CellTags->{"S1.4.4", "4.8"}],
Cell[182017, 9088, 364, 7, 59, "DisplayFormula",
  CellTags->{"S1.4.4", "4.9"}],
Cell[182384, 9097, 332, 11, 26, "Text",
  CellTags->{"S1.4.4", "4.10"}],
Cell[182719, 9110, 237, 5, 34, "DisplayFormula",
  CellTags->{"S1.4.4", "4.11"}],
Cell[182959, 9117, 127, 4, 25, "Text",
  CellTags->{"S1.4.4", "4.12"}],
Cell[183089, 9123, 300, 7, 53, "DisplayFormula",
  CellTags->{"S1.4.4", "4.13"}],
Cell[183392, 9132, 679, 20, 61, "Text",
  CellTags->{"S1.4.4", "4.14"}],
Cell[184074, 9154, 1008, 25, 99, "DisplayFormula",
  CellTags->{"S1.4.4", "4.15"}],
Cell[185085, 9181, 179, 7, 26, "Text",
  CellTags->{"S1.4.4", "4.16"}],
Cell[185267, 9190, 285, 6, 33, "DisplayFormula",
  CellTags->{"S1.4.4", "4.17"}],
Cell[185555, 9198, 1002, 31, 61, "Text",
  CellTags->{"S1.4.4", "4.18"}],
Cell[186560, 9231, 276, 6, 47, "DisplayFormula",
  CellTags->{"S1.4.4", "4.19"}],
Cell[186839, 9239, 127, 4, 35, "Subsubsection",
  CellTags->{"S1.4.4", "4.20"}],
Cell[186969, 9245, 1021, 23, 95, "Text",
  CellTags->{"S1.4.4", "4.21"}],
Cell[187993, 9270, 391, 8, 47, "DisplayFormula",
  CellTags->{"S1.4.4", "4.22"}],
Cell[188387, 9280, 1781, 52, 137, "Text",
  CellTags->{"S1.4.4", "4.23"}],
Cell[190171, 9334, 353, 11, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.24"}],
Cell[190527, 9347, 269, 7, 91, "Input",
  CellTags->"S1.4.4"],
Cell[190799, 9356, 130, 4, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.25"}],
Cell[190932, 9362, 151, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[191086, 9370, 171, 4, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.26"}],

Cell[CellGroupData[{
Cell[191282, 9378, 235, 8, 111, "Input",
  CellTags->"S1.4.4"],
Cell[191520, 9388, 3578, 260, 186, 3505, 257, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[195113, 9651, 231, 5, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.27"}],

Cell[CellGroupData[{
Cell[195369, 9660, 109, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[195481, 9664, 261, 5, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[195757, 9672, 312, 7, 59, "Text",
  CellTags->{"S1.4.4", "4.28"}],
Cell[196072, 9681, 153, 4, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.29"}],

Cell[CellGroupData[{
Cell[196250, 9689, 144, 5, 51, "Input",
  CellTags->"S1.4.4"],
Cell[196397, 9696, 4824, 335, 186, 4751, 332, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[201236, 10034, 154, 4, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.30"}],

Cell[CellGroupData[{
Cell[201415, 10042, 176, 5, 51, "Input",
  CellTags->"S1.4.4"],
Cell[201594, 10049, 5912, 412, 186, 5839, 409, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[207521, 10464, 678, 15, 93, "Text",
  CellTags->{"S1.4.4", "4.31"}],
Cell[208202, 10481, 237, 7, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.32"}],

Cell[CellGroupData[{
Cell[208464, 10492, 142, 5, 51, "Input",
  CellTags->"S1.4.4"],
Cell[208609, 10499, 149, 4, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[208773, 10506, 139, 5, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.33"}],
Cell[208915, 10513, 92, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[209010, 10517, 108, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.34"}],

Cell[CellGroupData[{
Cell[209143, 10522, 320, 8, 111, "Input",
  CellTags->"S1.4.4"],
Cell[209466, 10532, 10335, 697, 186, 10262, 694, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[219816, 11232, 408, 11, 59, "Text",
  CellTags->{"S1.4.4", "4.35"}],
Cell[220227, 11245, 245, 7, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.36"}],

Cell[CellGroupData[{
Cell[220497, 11256, 76, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[220576, 11260, 91, 3, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[220682, 11266, 245, 7, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.37"}],

Cell[CellGroupData[{
Cell[220952, 11277, 76, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[221031, 11281, 96, 3, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[221142, 11287, 1449, 32, 169, "Text",
  CellTags->{"S1.4.4", "4.38"}],
Cell[222594, 11321, 145, 4, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.39"}],

Cell[CellGroupData[{
Cell[222764, 11329, 113, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[222880, 11333, 413, 7, 42, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[223308, 11343, 271, 8, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.40"}],

Cell[CellGroupData[{
Cell[223604, 11355, 178, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[223785, 11363, 426, 8, 61, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[224226, 11374, 1072, 28, 93, "Text",
  CellTags->{"S1.4.4", "4.41"}],
Cell[225301, 11404, 180, 7, 25, "Text",
  CellTags->{"S1.4.4", "4.42"}],
Cell[225484, 11413, 502, 14, 59, "Text",
  CellTags->{"S1.4.4", "4.43"}],
Cell[225989, 11429, 105, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.44"}],

Cell[CellGroupData[{
Cell[226119, 11434, 94, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[226216, 11438, 498, 9, 61, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[226729, 11450, 821, 24, 63, "Text",
  CellTags->{"S1.4.4", "4.45"}],
Cell[227553, 11476, 98, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.46"}],

Cell[CellGroupData[{
Cell[227676, 11481, 82, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[227761, 11485, 2126, 53, 99, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[229902, 11541, 1021, 25, 110, "Text",
  CellTags->{"S1.4.4", "4.47"}],
Cell[230926, 11568, 354, 11, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.48"}],

Cell[CellGroupData[{
Cell[231305, 11583, 163, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[231471, 11591, 119, 3, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[231605, 11597, 166, 4, 48, "MathCaption",
  CellTags->{"S1.4.4", "4.49"}],

Cell[CellGroupData[{
Cell[231796, 11605, 111, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[231910, 11609, 806, 14, 118, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[232731, 11626, 389, 9, 59, "Text",
  CellTags->{"S1.4.4", "4.50"}],
Cell[233123, 11637, 137, 4, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.51"}],

Cell[CellGroupData[{
Cell[233285, 11645, 157, 5, 51, "Input",
  CellTags->"S1.4.4"],
Cell[233445, 11652, 118, 3, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[233578, 11658, 83, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.52"}],

Cell[CellGroupData[{
Cell[233686, 11663, 105, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[233794, 11667, 151, 4, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[233960, 11674, 133, 4, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.53"}],

Cell[CellGroupData[{
Cell[234118, 11682, 81, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[234202, 11686, 84, 3, 23, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[234301, 11692, 59, 1, 25, "Text",
  CellTags->{"S1.4.4", "4.54"}],
Cell[234363, 11695, 236, 10, 25, "Text",
  CellTags->{"S1.4.4", "4.55"}],
Cell[234602, 11707, 1253, 33, 135, "Text",
  CellTags->{"S1.4.4", "4.56"}],
Cell[235858, 11742, 115, 2, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.57"}],

Cell[CellGroupData[{
Cell[235998, 11748, 215, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[236216, 11756, 16762, 1105, 186, 16689, 1102, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[252993, 12864, 103, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.58"}],

Cell[CellGroupData[{
Cell[253121, 12869, 207, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[253331, 12877, 16698, 1087, 186, 16625, 1084, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[270044, 13967, 103, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.59"}],

Cell[CellGroupData[{
Cell[270172, 13972, 100, 2, 31, "Input",
  CellTags->"S1.4.4"],
Cell[270275, 13976, 1093, 22, 156, "Output",
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[271383, 14001, 96, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.60"}],

Cell[CellGroupData[{
Cell[271504, 14006, 217, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[271724, 14014, 14264, 927, 186, 14191, 924, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[286003, 14944, 75, 1, 31, "MathCaption",
  CellTags->{"S1.4.4", "4.61"}],

Cell[CellGroupData[{
Cell[286103, 14949, 209, 6, 71, "Input",
  CellTags->"S1.4.4"],
Cell[286315, 14957, 13811, 900, 186, 13738, 897, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.4"]
}, Open  ]],
Cell[300141, 15860, 67, 1, 39, "Subsection",
  CellTags->{"S1.4.5", "5.1"}],
Cell[300211, 15863, 953, 26, 76, "Text",
  CellTags->{"S1.4.5", "5.2"}],
Cell[301167, 15891, 361, 9, 43, "DisplayFormula",
  CellTags->{"S1.4.5", "5.3"}],
Cell[301531, 15902, 51, 1, 25, "Text",
  CellTags->{"S1.4.5", "5.4"}],
Cell[301585, 15905, 511, 13, 43, "DisplayFormula",
  CellTags->{"S1.4.5", "5.5"}],
Cell[302099, 15920, 253, 7, 25, "Text",
  CellTags->{"S1.4.5", "5.6"}],
Cell[302355, 15929, 287, 6, 34, "DisplayFormula",
  CellTags->{"S1.4.5", "5.7"}],
Cell[302645, 15937, 51, 1, 25, "Text",
  CellTags->{"S1.4.5", "5.8"}],
Cell[302699, 15940, 312, 6, 34, "DisplayFormula",
  CellTags->{"S1.4.5", "5.9"}],
Cell[303014, 15948, 483, 15, 42, "Text",
  CellTags->{"S1.4.5", "5.10"}],
Cell[303500, 15965, 962, 23, 56, "DisplayFormula",
  CellTags->{"S1.4.5", "5.11"}],
Cell[304465, 15990, 304, 11, 25, "Text",
  CellTags->{"S1.4.5", "5.12"}],
Cell[304772, 16003, 287, 6, 56, "DisplayFormula",
  CellTags->{"S1.4.5", "5.13"}],
Cell[305062, 16011, 581, 16, 67, "Text",
  CellTags->{"S1.4.5", "5.14"}],
Cell[305646, 16029, 172, 7, 25, "Text",
  CellTags->{"S1.4.5", "5.15"}],
Cell[305821, 16038, 1354, 42, 93, "Text",
  CellTags->{"S1.4.5", "5.16"}],
Cell[307178, 16082, 106, 1, 31, "MathCaption",
  CellTags->{"S1.4.5", "5.17"}],

Cell[CellGroupData[{
Cell[307309, 16087, 90, 2, 31, "Input",
  CellTags->"S1.4.5"],
Cell[307402, 16091, 401, 8, 61, "Output",
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[307818, 16102, 161, 5, 31, "MathCaption",
  CellTags->{"S1.4.5", "5.18"}],

Cell[CellGroupData[{
Cell[308004, 16111, 194, 6, 71, "Input",
  CellTags->"S1.4.5"],
Cell[308201, 16119, 5586, 381, 186, 5513, 378, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[313802, 16503, 177, 4, 48, "MathCaption",
  CellTags->{"S1.4.5", "5.19"}],

Cell[CellGroupData[{
Cell[314004, 16511, 186, 6, 71, "Input",
  CellTags->"S1.4.5"],
Cell[314193, 16519, 6439, 441, 186, 6366, 438, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[320647, 16963, 94, 1, 31, "MathCaption",
  CellTags->{"S1.4.5", "5.20"}],

Cell[CellGroupData[{
Cell[320766, 16968, 92, 2, 31, "Input",
  CellTags->"S1.4.5"],
Cell[320861, 16972, 1878, 38, 270, "Output",
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[322754, 17013, 84, 1, 31, "MathCaption",
  CellTags->{"S1.4.5", "5.21"}],

Cell[CellGroupData[{
Cell[322863, 17018, 227, 7, 91, "Input",
  CellTags->"S1.4.5"],
Cell[323093, 17027, 11125, 809, 186, 11052, 806, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[334233, 17839, 75, 1, 31, "MathCaption",
  CellTags->{"S1.4.5", "5.22"}],

Cell[CellGroupData[{
Cell[334333, 17844, 219, 7, 91, "Input",
  CellTags->"S1.4.5"],
Cell[334555, 17853, 10626, 776, 186, 10553, 773, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.5"]
}, Open  ]],
Cell[345196, 18632, 520, 18, 39, "Subsection",
  CellTags->{"S1.4.6", "6.1"}],
Cell[345719, 18652, 1228, 37, 89, "Text",
  CellTags->{"S1.4.6", "6.2"}],
Cell[346950, 18691, 89, 1, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.3"}],
Cell[347042, 18694, 162, 5, 51, "Input",
  CellTags->"S1.4.6"],
Cell[347207, 18701, 98, 1, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.4"}],
Cell[347308, 18704, 90, 2, 31, "Input",
  CellTags->"S1.4.6"],
Cell[347401, 18708, 156, 4, 48, "MathCaption",
  CellTags->{"S1.4.6", "6.5"}],

Cell[CellGroupData[{
Cell[347582, 18716, 157, 5, 51, "Input",
  CellTags->"S1.4.6"],
Cell[347742, 18723, 5363, 370, 186, 5290, 367, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[353120, 19096, 548, 16, 65, "MathCaption",
  CellTags->{"S1.4.6", "6.6"}],

Cell[CellGroupData[{
Cell[353693, 19116, 228, 6, 71, "Input",
  CellTags->"S1.4.6"],
Cell[353924, 19124, 11713, 773, 186, 11640, 770, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[365652, 19900, 1586, 51, 76, "Text",
  CellTags->{"S1.4.6", "6.7"}],
Cell[367241, 19953, 110, 1, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.8"}],

Cell[CellGroupData[{
Cell[367376, 19958, 189, 6, 71, "Input",
  CellTags->"S1.4.6"],
Cell[367568, 19966, 5366, 369, 186, 5293, 366, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[372949, 20338, 365, 12, 42, "Text",
  CellTags->{"S1.4.6", "6.9"}],
Cell[373317, 20352, 285, 6, 55, "DisplayFormula",
  CellTags->{"S1.4.6", "6.10"}],
Cell[373605, 20360, 52, 1, 25, "Text",
  CellTags->{"S1.4.6", "6.11"}],
Cell[373660, 20363, 314, 6, 55, "DisplayFormula",
  CellTags->{"S1.4.6", "6.12"}],
Cell[373977, 20371, 204, 6, 42, "Text",
  CellTags->{"S1.4.6", "6.13"}],
Cell[374184, 20379, 137, 4, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.14"}],

Cell[CellGroupData[{
Cell[374346, 20387, 228, 6, 71, "Input",
  CellTags->"S1.4.6"],
Cell[374577, 20395, 9503, 633, 186, 9430, 630, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[384095, 21031, 141, 4, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.15"}],

Cell[CellGroupData[{
Cell[384261, 21039, 266, 7, 91, "Input",
  CellTags->"S1.4.6"],
Cell[384530, 21048, 11941, 716, 186, 11868, 713, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[396486, 21767, 281, 9, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.16"}],

Cell[CellGroupData[{
Cell[396792, 21780, 225, 6, 71, "Input",
  CellTags->"S1.4.6"],
Cell[397020, 21788, 13932, 914, 186, 13859, 911, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[410967, 22705, 281, 9, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.17"}],

Cell[CellGroupData[{
Cell[411273, 22718, 262, 7, 91, "Input",
  CellTags->"S1.4.6"],
Cell[411538, 22727, 14481, 948, 186, 14408, 945, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[426034, 23678, 475, 12, 42, "Text",
  CellTags->{"S1.4.6", "6.18"}],
Cell[426512, 23692, 573, 11, 64, "DisplayFormula",
  CellTags->{"S1.4.6", "6.19"}],
Cell[427088, 23705, 127, 4, 25, "Text",
  CellTags->{"S1.4.6", "6.20"}],
Cell[427218, 23711, 289, 13, 25, "Text",
  CellTags->{"S1.4.6", "6.21"}],
Cell[427510, 23726, 506, 17, 42, "Text",
  CellTags->{"S1.4.6", "6.22"}],
Cell[428019, 23745, 143, 4, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.23"}],
Cell[428165, 23751, 129, 5, 51, "Input",
  CellTags->"S1.4.6"],
Cell[428297, 23758, 218, 7, 31, "MathCaption",
  CellTags->{"S1.4.6", "6.24"}],

Cell[CellGroupData[{
Cell[428540, 23769, 157, 5, 51, "Input",
  CellTags->"S1.4.6"],
Cell[428700, 23776, 8148, 544, 186, 8075, 541, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[436863, 24323, 1576, 53, 93, "Text",
  CellTags->{"S1.4.6", "6.25"}],
Cell[438442, 24378, 285, 8, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.26"}],
Cell[438730, 24388, 109, 2, 70, "Input",
  CellTags->"S1.4.6"],
Cell[438842, 24392, 327, 8, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.27"}],

Cell[CellGroupData[{
Cell[439194, 24404, 163, 5, 70, "Input",
  CellTags->"S1.4.6"],
Cell[439360, 24411, 9722, 648, 70, 9649, 645, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[449097, 25062, 232, 7, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.28"}],

Cell[CellGroupData[{
Cell[449354, 25073, 187, 6, 70, "Input",
  CellTags->"S1.4.6"],
Cell[449544, 25081, 27430, 1776, 70, 27357, 1773, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[476989, 26860, 96, 1, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.29"}],
Cell[477088, 26863, 87, 2, 70, "Input",
  CellTags->"S1.4.6"],
Cell[477178, 26867, 269, 7, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.30"}],

Cell[CellGroupData[{
Cell[477472, 26878, 332, 9, 70, "Input",
  CellTags->"S1.4.6"],
Cell[477807, 26889, 20426, 1370, 70, 20353, 1367, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]],
Cell[498248, 28262, 350, 11, 70, "Text",
  CellTags->{"S1.4.6", "6.31"}],
Cell[498601, 28275, 281, 13, 70, "Text",
  CellTags->{"S1.4.6", "6.32"}],
Cell[498885, 28290, 497, 17, 70, "Text",
  CellTags->{"S1.4.6", "6.33"}],
Cell[499385, 28309, 232, 7, 70, "MathCaption",
  CellTags->{"S1.4.6", "6.34"}],

Cell[CellGroupData[{
Cell[499642, 28320, 176, 6, 70, "Input",
  CellTags->"S1.4.6"],
Cell[499821, 28328, 8852, 589, 70, 8779, 586, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.4.6"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

