(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1005373,      33434]*)
(*NotebookOutlinePosition[   1061617,      35043]*)
(*  CellTagsIndexPosition[   1055154,      34807]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
1.5 Discrete Wavelet Transforms and Wavelet Packet Transforms\
\>", 
  "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 1.5.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.1 Wavelet Transforms",
    ButtonData:>{"Wavelets 1.5.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.2 Inverse Wavelet Transforms",
    ButtonData:>{"Wavelets 1.5.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.3 Connection to Subband Filtering",
    ButtonData:>{"Wavelets 1.5.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.4 Wavelets and Wavelet Transforms in Two Dimensions",
    ButtonData:>{"Wavelets 1.5.4"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.5 Mathematica Functions for Doing Wavelet Transforms",
    ButtonData:>{"Wavelets 1.5.5"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.6 Wavelet Packets and Wavelet Packet Transforms",
    ButtonData:>{"Wavelets 1.5.6"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.7 Generating Wavelet Packets",
    ButtonData:>{"Wavelets 1.5.7"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.5.8 Zooming in on Details of ",
    ButtonData:>{"Wavelets 1.5.8"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Phi]",
    ButtonData:>{"Wavelets 1.5.8"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[", ",
    ButtonData:>{"Wavelets 1.5.8"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Psi]",
    ButtonData:>{"Wavelets 1.5.8"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[", and w",
    ButtonData:>{"Wavelets 1.5.8"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["\<\
1.5 Discrete Wavelet Transforms and Wavelet Packet Transforms\
\>", 
  "Section",
  CellTags->{"S1.5.0", "0.1"}],

Cell[TextData[{
  "In Section ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2"},
    ButtonStyle->"AddOnsLink"],
  " on multiresolution analysis we saw that the space of \
square\[Hyphen]integrable functions, ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.5.0"],
  ", can be decomposed into a direct sum of orthogonal subspaces; in \
particular, any function in ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.5.0"],
  " can be expanded in terms of ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(2\^\(j\_0/2\)\) \[Phi] \((\(2\^j\_0\) t - k)\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(2\^\(j/2\)\) \[Psi] \((\(2\^j\) t - k)\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.0"],
  ", the orthonormal bases of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j\_0\)\)], "InlineFormula",
    CellTags->"S1.5.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{W\_j}\)], "InlineFormula",
    CellTags->"S1.5.0"],
  ", respectively. Recall that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.0"],
  " is the scaling function and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.0"],
  " mother wavelet. Different ways of decomposing the space naturally lead to \
different choices for the basis functions and discrete wavelet transforms in \
fact correspond to transformations between different orthogonal bases. \nIn \
this section we first discuss wavelet transforms. We derive the formulas that \
enable us to go from the decomposition of a function in one basis to that in \
another. The connection between the wavelet transform and subband filtering \
is made. After that, we discuss wavelet packet transforms. The ",
  StyleBox["Mathematica", "TI"],
  " programs and function for doing these transforms are introduced. "
}], "Text",
  CellTags->{"S1.5.0", "0.2"}],

Cell["1.5.1 Wavelet Transforms", "Subsection",
  CellTags->{"S1.5.1", "1.1"}],

Cell[TextData[{
  "We begin with a discussion of discrete wavelet transforms. Consider a \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and let us suppose that we only know the function to a certain resolution \
level, say, ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and the information containing details on scales smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is assumed to be unknown or is ignored.We use ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " to denote this approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". Using the language of multiresolution analysis, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is in ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_j\), \((t)\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(f\_k\%j\), \(\[Phi]\_\(j  k\)\), \((t)
          \)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.1"],
  ", where the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\%j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " of the expansion is given by the inner product ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "\[LeftAngleBracket]", \(\[Phi]\_\(j  k\)\), \(, \ \), "f", 
          "\[RightAngleBracket]", "=", "\[LeftAngleBracket]", 
          \(\[Phi]\_\(j  k\)\), \(, \ \), \(f\_j\), "\[RightAngleBracket]", 
          "=", "\[Integral]", \(f\_j\), \((t)\), \(\[Phi]\_\(j  k\)\), \((t)
          \), " ", 
          StyleBox[\("dt"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.1"],
  ". Given the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi]\_\(j  k\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is uniquely represented by the set of coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". On the other hand, we can also separate ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " into a smooth part or trend ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_\(j - 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " on a coarser scale ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(j - 1\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and details or fluctuations ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(j - 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". The part containing fluctuations ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(j - 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(d\_\(j - 1\)\), \((t)\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(d\_k\%\(j - 1\)\), 
          \(\[Psi]\_\(j - 1, k\)\), \((t)\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.1"],
  ", where the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`d\_k\%\(j - 1\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm
      \`d\_k\%\(j - 1\) = \[LeftAngleBracket]\(\[Psi]\_\(j - 1, k\)\) \(, \ 
        \) f\[RightAngleBracket]\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". The decomposition "
}], "Text",
  CellTags->{"S1.5.1", "1.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_j\), \((t)\), "=", \(f\_\(j - 1\)\), \((t)\), "+", 
        \(d\_\(j - 1\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%\(j - 1\)\), 
        \(\[Phi]\_\(j - 1, k\)\), \((t)\), "+", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(d\_k\%\(j - 1\)\), 
        \(\[Psi]\_\(j - 1, k\)\), \((t)\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.1", "1.3"}],

Cell[TextData[{
  "corresponds to the decomposition of the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " into ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j - 1\)\[CirclePlus]W\_\(j - 1\)\)], 
    "InlineFormula",
    CellTags->"S1.5.1"],
  ". We will now derive the wavelet decomposition formula connecting ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". \nSince ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j - 1\) \[Subset] V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_\(j - 1\) \[Subset] V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ", the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(j - 1, k\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(j - 1, k\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " can be written as a superposition of the basis functions of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ": "
}], "Text",
  CellTags->{"S1.5.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\_\(j - 1, k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\[Phi]\_\(j  l\)\), \(, \ \), \(\[Phi]\_\(j - 1, k\)\), 
        "\[RightAngleBracket]", \(\[Phi]\_\(j  l\)\), \((t)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.1", "1.5"}],

Cell["where the coefficients are given by ", "Text",
  CellTags->{"S1.5.1", "1.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "\[LeftAngleBracket]", \(\[Phi]\_\(j  l\)\), \(, \ \), 
        \(\[Phi]\_\(j - 1, k\)\), "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((
        \(2\^\(j - 1\)\) t - k)\), \(\[Phi] \((\(2\^j\) t - l)\)\), 
        \(2\^\(j - 1\)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(\@2\), \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\),
         "\[Phi]", \((u)\), \(\[Phi] \((2  u - \((l - 2  k)\))\)\), " ", 
        StyleBox[\("du"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.1", "1.7"}],

Cell[TextData[{
  "We observe that this is precisely the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`h\_\(l - 2  k\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " appearing in the dilation equation (see (",
  ButtonBox["2.4",
    ButtonData:>{"Wavelets 1.2.3", "3.5"},
    ButtonStyle->"AddOnsLink"],
  ")). Therefore, "
}], "Text",
  CellTags->{"S1.5.1", "1.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\(\[Phi]\_\(j  l\)\) , \  
      \[Phi]\_\(j - 1, k\)\[RightAngleBracket] = h\_\(l - 2  k\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.1", "1.9"}],

Cell["Similarly we have, ", "Text",
  CellTags->{"S1.5.1", "1.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\_\(j - 1, k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\[Phi]\_\(j  l\)\), \(, \ \), \(\[Psi]\_\(j - 1, k\)\), 
        "\[RightAngleBracket]", \(\[Phi]\_\(j  l\)\), \((t)\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.1", "1.11"}],

Cell[TextData[{
  "where the coefficient can be identified using (",
  ButtonBox["2.6",
    ButtonData:>{"Wavelets 1.2.4", "4.9"},
    ButtonStyle->"AddOnsLink"],
  ") as "
}], "Text",
  CellTags->{"S1.5.1", "1.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\(\[Phi]\_\(j  l\)\) , \  
      \[Psi]\_\(j - 1, k\)\[RightAngleBracket] = g\_\(l - 2  k\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.1", "1.13"}],

Cell["Thus, we obtain the relations ", "Text",
  CellTags->{"S1.5.1", "1.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\_\(j - 1, k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(l - 2  k\)\), \(\[Phi]\_\(j, l\)\),
         \((t)\), \("and"\), \(\[Psi]\_\(j - 1, k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(l - 2  k\)\), \(\[Phi]\_\(j, l\)\),
         \((t)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.1", "1.15"}],

Cell[TextData[{
  "Using these relations, we can easily derive explicit expressions for ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ": "
}], "Text",
  CellTags->{"S1.5.1", "1.16"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_k\%\(j - 1\)\), "=", "\[LeftAngleBracket]", 
        \(\[Phi]\_\(j - 1, k\)\), \(, \ \), "f", "\[RightAngleBracket]", "=", 
        
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(l - 2  k\)\), 
        "\[LeftAngleBracket]", \(\[Phi]\_\(j  l\)\), \(, \ \), "f", 
        "\[RightAngleBracket]", "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(l - 2  k\)\), \(f\_l\%j\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.1", "1.17"}],

Cell["and ", "Text",
  CellTags->{"S1.5.1", "1.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(d\_k\%\(j - 1\)\), "=", "\[LeftAngleBracket]", 
        \(\[Psi]\_\(j - 1, k\)\), \(, \ \), "f", "\[RightAngleBracket]", "=", 
        
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(l - 2  k\)\), 
        "\[LeftAngleBracket]", \(\[Phi]\_\(j  l\)\), \(, \ \), "f", 
        "\[RightAngleBracket]", "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(l - 2  k\)\), \(f\_l\%j\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.1", "1.19"}],

Cell[TextData[{
  "So in the new basis, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " can be expressed in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " where the former set represents the trend and the latter, the details. \
This decomposition can be repeated again, that is, we can decompose ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%\(j - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " into its trend and fluctuations on the scale ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-\((j - 2)\)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ", and this process continued until we reach the coarsest level, say, ",
  Cell[BoxData[
      \(TraditionalForm\`j\_0\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " where we have "
}], "Text",
  CellTags->{"S1.5.1", "1.20"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_j\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%j\), \(\[Phi]\_\(j  k\)\), \((t)
        \), "=", 
        UnderoverscriptBox["\[Sum]", \(l = j\_0\), \(j - 1\),
          LimitsPositioning->True], 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(d\_k\%l\), \(\[Psi]\_\(l  k\)\), \((t)
        \), "+", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%j\_0\), 
        \(\[Phi]\_\(\(j\_0\) k\)\), \((t)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.1", "1.21"}],

Cell[TextData[{
  "Here, the details at various levels along with a residual trend are said \
to be the representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " in the wavelet basis. \nA couple of points are worth noticing. The first \
concerns the number of operations required to do a wavelet transform. Since \
the above decomposition amounts to changing from one orthogonal basis to \
another, the coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " in the wavelet basis can be obtained simply by multiplying the original \
data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " by an orthogonal matrix. We might, therefore, expect that the \
transformation needs ",
  Cell[BoxData[
      \(TraditionalForm\`O \((N\^2)\)\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " operations where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is the length of the data (",
  StyleBox["i.e.", "TI"],
  ", the number of coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ", which in practice is invariably finite). However, from (",
  ButtonBox["5.3",
    ButtonData:>{"Wavelets 1.5.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  ") we see that after one decomposition, we have ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " coefficients that represent the trend and the other ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " represent details. The next decomposition is only performed on the set of \
trend coefficients whose length is half that of the original data. So as the \
decomposition goes deeper and deeper, fewer and fewer operations are needed. \
If the filter length is ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ", the number of operations is of the order "
}], "Text",
  CellTags->{"S1.5.1", "1.22"}],

Cell[BoxData[
    \(TraditionalForm\`L  N \((1 + 1\/2 + 1\/2\^2 + ...)\) < 2  L  N.\)], 
  "DisplayFormula",
  CellTags->{"S1.5.1", "1.23"}],

Cell[TextData[{
  "Thus, the number of operations for a wavelet transform of data of length ",
  
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " is of the order of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " not ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)], "InlineFormula",
    CellTags->"S1.5.1"],
  ". (This means that the orthogonal transformation matrix is relatively \
sparse.) This makes it a rather fast algorithm and, as in the case of \
discrete Fourier transform, it is often referred to as fast wavelet \
transform. Since each successive decomposition cuts the number of operations \
by half, the algorithm for doing fast wavelet transforms using the \
convolutions (",
  ButtonBox["5.3",
    ButtonData:>{"Wavelets 1.5.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["5.4",
    ButtonData:>{"Wavelets 1.5.1", "1.19"},
    ButtonStyle->"AddOnsLink"],
  ") is called the \"pyramid algorithm\". The second point worth noticing is \
that the wavelets themselves never enter the above wavelet transform. All we \
need to know are the filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S1.5.1"],
  " in order to do wavelet transforms."
}], "Text",
  CellTags->{"S1.5.1", "1.24"}],

Cell["1.5.2 Inverse Wavelet Transforms", "Subsection",
  CellTags->{"S1.5.2", "2.1"}],

Cell[TextData[{
  "The inverse of the above transform can similarly be worked out easily and \
we do so next. Theoretically, we can simply invert the orthogonal matrix that \
transforms the original coefficients into the coefficients in the wavelet \
basis. In practice, the inverse wavelet transform is done starting from the \
coarsest level and combining the trend and the details into the trend at the \
next finer level, and so on. This corresponds to changing the combined basis \
of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_\(j - 1\)\)], "InlineFormula",
    CellTags->"S1.5.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_\(j - 1\)\)], "InlineFormula",
    CellTags->"S1.5.2"],
  " to that of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.2"],
  ". So we expand ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_\(j, k\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.2"],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(j - 1, l\)\) \((t)\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j - 1, l\)\) \((t)\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.2"],
  ":"
}], "Text",
  CellTags->{"S1.5.2", "2.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\_\(j, k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\[Phi]\_\(j - 1, l\)\), \(, \ \ \), \(\[Phi]\_\(j, k\)\), 
        "\[RightAngleBracket]", \(\[Phi]\_\(j - 1, l\)\), \((t)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\[Psi]\_\(j - 1, l\)\), \(, \ \ \), \(\[Phi]\_\(j, k\)\), 
        "\[RightAngleBracket]", \(\[Psi]\_\(j - 1, l\)\), \((t)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.2", "2.3"}],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Phi]\_\(j - 1, l\)\) , \ \  
        \[Phi]\_\(j, k\)\[RightAngleBracket] = h\_\(k - 2  l\)\)], 
    "InlineFormula",
    CellTags->"S1.5.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Psi]\_\(j - 1, l\)\) , \ \  
        \[Phi]\_\(j, k\)\[RightAngleBracket] = g\_\(k - 2  l\)\)], 
    "InlineFormula",
    CellTags->"S1.5.2"],
  " (see (",
  ButtonBox["5.1",
    ButtonData:>{"Wavelets 1.5.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["5.2",
    ButtonData:>{"Wavelets 1.5.1", "1.13"},
    ButtonStyle->"AddOnsLink"],
  ")), the basis functions of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.5.2"],
  " can be expressed as "
}], "Text",
  CellTags->{"S1.5.2", "2.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\_\(j  k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(k - 2  l\)\), 
        \(\[Phi]\_\(j - 1, l\)\), \((t)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(k - 2  l\)\), 
        \(\[Psi]\_\(j - 1, l\)\), \((t)\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.2", "2.5"}],

Cell[TextData[{
  "and the trend coefficients at level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.2"],
  " can be reconstructed from the lower level trend and detail coefficients: \
"
}], "Text",
  CellTags->{"S1.5.2", "2.6"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(f\_k\%j\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              "\[LeftAngleBracket]", \(\[Phi]\_\(j k\)\), \(, \ \ \), "f", 
                "\[RightAngleBracket]", "=", 
                UnderscriptBox["\[Sum]", "l",
                  LimitsPositioning->True], \(h\_\(k - 2 l\)\), 
                "\[LeftAngleBracket]", \(\[Phi]\_\(j - 1, l\)\), \(, \ \ \), 
                "f", "\[RightAngleBracket]", "+", 
                UnderscriptBox["\[Sum]", "l",
                  LimitsPositioning->True], \(g\_\(k - 2 l\)\), 
                "\[LeftAngleBracket]", \(\[Psi]\_\(j - 1, l\)\), \(, \ \ \), 
                "f", "\[RightAngleBracket]"}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                UnderscriptBox["\[Sum]", "l",
                  LimitsPositioning->True], \(h\_\(k - 2 l\)\), " ", 
                \(f\_l\%\(j - 1\)\), "+", 
                UnderscriptBox["\[Sum]", "l",
                  LimitsPositioning->True], \(g\_\(k - 2 l\)\), " ", 
                \(d\_l\%\(j - 1\)\), "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\n(5.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.2", "2.7"}],

Cell["\<\
The inverse wavelet transform iterates this reconstruction process \
until the finest level is reached where the original data are recovered. \
\
\>", "Text",
  CellTags->{"S1.5.2", "2.8"}],

Cell["1.5.3 Connection to Subband Filtering", "Subsection",
  CellTags->{"S1.5.3", "3.1"}],

Cell[TextData[{
  "So far we have been more or less exclusively using the language of \
wavelets. In fact, the fast wavelet transform is intimately connected with \
what is called subband filtering in signal processing. For completeness, we \
devote this section to exploring this connection briefly and relating the \
corresponding terminology. \nWe first define subband filtering and show that \
wavelet decomposition simply amounts to subband filtering with a pair of \
lowpass and highpass filters. In signal processing an incoming signal is \
often decomposed or separated into different frequency bands or channels \
after which they can then be coded and transmitted separately and \
efficiently. This decomposition of signal into different frequency channels \
is usually done using a collection of filters called a filter bank. A filter \
is usually a linear transformation that transforms an input signal to another \
signal. For example, the discrete input signal ",
  Cell[BoxData[
      \(TraditionalForm\`{x\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", after filtering by a linear filter ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", becomes the output signal ",
  Cell[BoxData[
      \(TraditionalForm\`{y\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " given by"
}], "Text",
  CellTags->{"S1.5.3", "3.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(y\_n\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(c\_m\), \(x\_\(n - m\)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.3"}],

Cell[TextData[{
  "(Or, for a continuous signal, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "y", \((t)\), "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
          "c", \((\[Tau])\), "x", \((t - \[Tau])\), 
          RowBox[{
            StyleBox[\("d"\),
              "TI"], "\[Tau]"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.3"],
  ".) \nThe coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " are referred to as filter coefficients or, simply, a filter. The filter ",
  
  Cell[BoxData[
      \(TraditionalForm\`{c\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is also called an impulse response since it is the output signal when the \
input signal is a unit impulse. (That is, if ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = 1\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n = 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", the output signal ",
  Cell[BoxData[
      \(TraditionalForm\`{y\_n} = {c\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ".) If a filter has a finite number of nonzero filter coefficients, it is \
called a ",
  StyleBox["finite impulse response (FIR) filter", "TI"],
  "; otherwise it is called an ",
  StyleBox["infinite impulse response (IIR) filter", "TI"],
  ". The Fourier transform of the filter coefficients ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "n",
            LimitsPositioning->True], \(c\_n\), \(e\^\(-i  \[Omega]  n\)\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.3"],
  " is called the frequency response function or transfer function. (Note \
that the response function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " defined earlier includes an extra factor of ",
  Cell[BoxData[
      \(TraditionalForm\`1/\@2\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ".) \nThe separation of the signals into different frequency channels \
through filtering can be seen easily in frequency space. If we do Fourier \
transform on both sides of (",
  ButtonBox["5.6",
    ButtonData:>{"Wavelets 1.5.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "), the convolution becomes a simple multiplication and we have "
}], "Text",
  CellTags->{"S1.5.3", "3.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`y \((\[Omega])\) = C \((\[Omega])\) x \((\[Omega])\).\)], 
  "DisplayFormula",
  CellTags->{"S1.5.3", "3.5"}],

Cell[TextData[{
  "Suppose the filter is such that ",
  Cell[BoxData[
      \(TraditionalForm\`C \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is mostly concentrated at low frequencies and vanishes at high \
frequencies (",
  StyleBox["i.e.", "TI"],
  ", around ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  "); then the high\[Hyphen]frequency components of the input signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " will be suppressed by the filtering. Such a filter ",
  Cell[BoxData[
      \(TraditionalForm\`C \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is called a ",
  StyleBox["lowpass filter", "TI"],
  " since it blocks out the high\[Hyphen]frequency components of the signal \
and allows only the low frequency part of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " to \"pass\". Similarly, if a filter is zero at low frequencies and \
nonzero at high frequencies, it is called a ",
  StyleBox["highpass filter", "TI"],
  ".\nA signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " can be separated or decomposed into components belonging to different \
frequency channels using a collection of filters, this is referred to as \
subband filtering or subband decomposition. For example, in a \
two\[Hyphen]channel subband filtering scheme, a pair of half\[Hyphen]band \
filters ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " (called an analysis filter bank), one lowpass and one highpass, is used \
to separate the incoming signal into two sets of data,"
}], "Text",
  CellTags->{"S1.5.3", "3.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(y\_n\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(c\_m\), \(x\_\(n - m\)\), "   ", 
        \(" and "\), "   ", \(z\_n\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(d\_m\), \(x\_\(n - m\)\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.3", "3.7"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is the low\[Hyphen]frequency part of the original signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is the high\[Hyphen]frequency part. (In the \"ideal\" half\[Hyphen]band \
filter case, ",
  Cell[BoxData[
      \(TraditionalForm\`y \((\[Omega])\) = 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Pi]/2 < 
        \( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) < 
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z \((\[Omega])\) = 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm
      \`0 < \( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) < 
        \[Pi]/2\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ".) We notice that the amount of data is doubled after filtering. On the \
other hand, the amount of information clearly cannot have doubled due to \
filtering and we certainly do not want to represent the same amount of \
information using a data set twice as long. This redundancy of the data can \
be removed by deleting every other data point in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and keeping only those data with even indices, ",
  Cell[BoxData[
      \(TraditionalForm\`y\_n\%\[Prime] = y\_\(2  n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_n\%\[Prime] = z\_\(2  n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". This operation is called ",
  StyleBox["down\[Hyphen]sampling", "TI"],
  " or \"",
  StyleBox["decimation", "TI"],
  "\" by 2. \nThe justification for the decimation is the Shannon sampling \
theorem, which we first encountered in Section ",
  ButtonBox["1.3",
    ButtonData:>{"Wavelets 1.3"},
    ButtonStyle->"AddOnsLink"],
  ". From the sampling theorem, any series (with some technical requirements) \
",
  Cell[BoxData[
      \(TraditionalForm\`{y\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " can always be thought of as the sample points of a band\[Hyphen]limited \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". That is,"
}], "Text",
  CellTags->{"S1.5.3", "3.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(y\_n\), 
        \(\(sin  \[Pi] \((t - n)\)\)\/\(\[Pi] \((t - n)\)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.3", "3.9"}],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`y\_n = f \((n)\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\&^\), \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "n",
            LimitsPositioning->True], \(y\_n\), \(e\^\(-i  \[Omega]  n\)\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) < 
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega])\) = 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) > 
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". Now if the series ",
  Cell[BoxData[
      \(TraditionalForm\`{y\_n}\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is such that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderscriptBox["\[Sum]", "n",
            LimitsPositioning->True], \(y\_n\), \(e\^\(-i  \[Omega]  n\)\), 
          "=", "0"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Pi]/2 < 
        \( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) < 
        \[Pi]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " (",
  StyleBox["i.e.", "TI"],
  ", it results from ideal half\[Hyphen]band filtering), the function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is band\[Hyphen]limited within the band ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] \(\[Omega] \[VerticalSeparator] \)\) < \[Pi]/2
        \)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and it can be expressed as (see (",
  ButtonBox["3.11",
    ButtonData:>{"Wavelets 1.3.2", "2.9"},
    ButtonStyle->"AddOnsLink"],
  ")) "
}], "Text",
  CellTags->{"S1.5.3", "3.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(y\_\(2  n\)\), 
        \(\(sin  \[Pi] \((t/2 - n)\)\)\/\(\[Pi] \((t/2 - n)\)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.3", "3.11"}],

Cell["and ", "Text",
  CellTags->{"S1.5.3", "3.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\&^\), \((\[Omega])\), "=", "2", 
        UnderscriptBox["\[Sum]", "n",
          LimitsPositioning->True], \(y\_\(2  n\)\), 
        \(e\^\(-i  2  n  \[Omega]\)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.3", "3.13"}],

Cell[TextData[{
  "We see that only even\[Hyphen]numbered points are needed to represent the \
same function. Intuitively, the absence of high\[Hyphen]frequency components \
in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " implies slower variation of the signal in time, and the sampling points \
can be less dense without losing any information. By appropriate \
transformation, we can similarly show that the redundancy of data filtered by \
the highpass filter can again be removed by keeping only those data with even \
indices (see Daubechies (1992)). So after decimation, we have "
}], "Text",
  CellTags->{"S1.5.3", "3.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(y\_n\%\[Prime]\), "=", \(y\_\(2  n\)\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(c\_m\), \(x\_\(2  n - m\)\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(c\_\(2  n - m\)\), \(x\_m\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.15"}],

Cell["and ", "Text",
  CellTags->{"S1.5.3", "3.16"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(z\_n\%\[Prime]\), "=", \(z\_\(2  n\)\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(d\_m\), \(z\_\(2  n - m\)\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], \(d\_\(2  n - m\)\), \(x\_m\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.17"}],

Cell[TextData[{
  "Comparing these with the expressions for wavelet decomposition (",
  ButtonBox["5.3",
    ButtonData:>{"Wavelets 1.5.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["5.4",
    ButtonData:>{"Wavelets 1.5.1", "1.19"},
    ButtonStyle->"AddOnsLink"],
  "), we see that the wavelet decomposition is in fact identical to subband \
filtering with a pair of lowpass and highpass filters ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n = h\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_n = g\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", respectively. \nIn the subband coding scheme, after filtering and \
decimation, the subband signals are coded and transmitted separately. Then at \
the receiver end, they are combined to try to recover the original signal. \
This reconstruction process is done by reversing the above procedure. First, \
the subband signals go through the expander, that is, \"upsampling\" by 2 \
that produces ",
  Cell[BoxData[
      \(TraditionalForm\`0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  "s at odd indices.Then a pair of filters (called a synthesis filter bank)",
  Cell[BoxData[
      \(TraditionalForm\`\(c\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " are used to perform the convolutions with the two sets of upsampled data \
respectively and the results are combined. Denoting the two data sets \
obtained after undergoing upsampling by ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)\_\(2  n\) = y\_n\%\[Prime]\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\&~\)\_\(2  n\) = z\_n\%\[Prime]\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(y\&~\)\_\(2  n + 1\) = \(z\&~\)\_\(2  n + 1\) = 0\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", the signal produced from the synthesis process using the filters ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\&~\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is "
}], "Text",
  CellTags->{"S1.5.3", "3.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(v\_n\), "=", 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], 
        \((\(\(c\&~\)\_m\) \(y\&~\)\_\(n - m\) + \(\(d\&~\)\_m\) 
            \(z\&~\)\_\(n - m\))\), "."}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.5.3", "3.19"}],

Cell[TextData[{
  "Separating even and odd terms and using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)\_m = \(z\&~\)\_m = 0\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " is odd, we have "
}], "Text",
  CellTags->{"S1.5.3", "3.20"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(v\_\(2 n\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                UnderscriptBox["\[Sum]", "m",
                  LimitsPositioning->True], 
                \((\(\(c\&~\)\_m\) \(y\&~\)\_\(2 n - m\) + \(\(d\&~\)\_m\) 
                    \(z\&~\)\_\(2 n - m\))\), "=", 
                UnderscriptBox["\[Sum]", "m",
                  LimitsPositioning->True], 
                \((\(\(c\&~\)\_\(2 m\)\) \(y\&~\)\_\(2 n - 2 m\) + 
                    \(\(d\&~\)\_\(2 m\)\) \(z\&~\)\_\(2 n - 2 m\))\)}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                UnderscriptBox["\[Sum]", "m",
                  LimitsPositioning->True], 
                \((\(\(c\&~\)\_\(2 m\)\) y\_\(n - m\)\%\[Prime] + 
                    \(\(d\&~\)\_\(2 m\)\) z\_\(n - m\)\%\[Prime])\), "=", 
                UnderscriptBox["\[Sum]", "l",
                  LimitsPositioning->True], 
                \((\(\(c\&~\)\_\(2 n - 2 l\)\) y\_l\%\[Prime] + 
                    \(\(d\&~\)\_\(2 n - 2 l\)\) z\_l\%\[Prime])\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.3", "3.21"}],

Cell["\<\
for the even terms. Similarly we can show that for the odd terms \
\
\>", "Text",
  CellTags->{"S1.5.3", "3.22"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(v\_\(2  n + 1\)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        \((\(\(c\&~\)\_\(2  n + 1 - 2  l\)\) y\_l\%\[Prime] + 
            \(\(d\&~\)\_\(2  n + 1 - 2  l\)\) z\_l\%\[Prime])\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.3", "3.23"}],

Cell["Combining the two together, we have ", "Text",
  CellTags->{"S1.5.3", "3.24"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(v\_n\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        \((\(\(c\&~\)\_\(n - 2  l\)\) y\_l\%\[Prime] + 
            \(\(d\&~\)\_\(n - 2  l\)\) z\_l\%\[Prime])\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.25"}],

Cell[TextData[{
  "Comparing (",
  ButtonBox["5.9",
    ButtonData:>{"Wavelets 1.5.3", "3.25"},
    ButtonStyle->"AddOnsLink"],
  ") and the reconstruction formula (",
  ButtonBox["5.5",
    ButtonData:>{"Wavelets 1.5.2", "2.7"},
    ButtonStyle->"AddOnsLink"],
  "), we see that the reconstruction in an inverse wavelet transform is \
exactly the synthesis part of a subband filtering scheme with ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\&~\)\_n = h\_n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\&~\)\_n = g\_n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". \nNow we proceed to see under what conditions the subband filtering \
scheme reproduces the original signal exactly. From the expressions (",
  ButtonBox["5.7",
    ButtonData:>{"Wavelets 1.5.3", "3.15"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["5.8",
    ButtonData:>{"Wavelets 1.5.3", "3.17"},
    ButtonStyle->"AddOnsLink"],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`y\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\^\[Prime]\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", we have an explicit expression for the reconstructed signal ",
  Cell[BoxData[
      \(TraditionalForm\`v\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " in terms the initial signal ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ": "
}], "Text",
  CellTags->{"S1.5.3", "3.26"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(v\_n\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        UnderscriptBox["\[Sum]", "m",
          LimitsPositioning->True], 
        \((\(\(c\&~\)\_\(n - 2  l\)\) c\_\(2  l - m\) + 
            \(\(d\&~\)\_\(n - 2  l\)\) d\_\(2  l - m\))\), \(x\_m\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.3", "3.27"}],

Cell[TextData[{
  "To ensure perfect reconstruction, that is, ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n = x\_n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", we must have,"
}], "Text",
  CellTags->{"S1.5.3", "3.28"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], 
        \((\(\(c\&~\)\_\(n - 2  l\)\) c\_\(2  l - m\) + 
            \(\(d\&~\)\_\(n - 2  l\)\) d\_\(2  l - m\))\), "=", 
        \(\[Delta]\_\(n  m\)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.10) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.29"}],

Cell[TextData[{
  "Note that this has to be true for all ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". This set of equations for perfect reconstruction can be \
re\[Hyphen]expressed in terms of frequency response functions and they yield \
the following two conditions in frequency space: "
}], "Text",
  CellTags->{"S1.5.3", "3.30"}],

Cell[BoxData[
    \(TraditionalForm
    \`C \((\[Omega])\) \(C\&~\) \((\[Omega])\) + D \((\[Omega])\) \(D\&~\) \((
      \[Omega])\) = 2 "and" C \((\[Omega])\) \(C\&~\) \((\[Omega] + \[Pi])
      \) + D \((\[Omega])\) \(D\&~\) \((\[Omega] + \[Pi])\) = 0.\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.11) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.3", "3.31"}],

Cell[TextData[{
  "Now let us go back to wavelet transforms. We noted the following \
identifications previously: ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n = h\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`d\_n = g\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\&~\)\_n = h\_n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\&~\)\_n = g\_n\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ". In frequency space, these relationships are (recall that there is a ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " in the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ") ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\ H \((\[Omega])\) = \(C\&~\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\ \(H \((\[Omega])\)\)\&_ = C \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\ G \((\[Omega])\) = \(D\&~\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\ \(G \((\[Omega])\)\)\&_ = D \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S1.5.3"],
  ". We can easily check that the filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.5.3"],
  " associated with orthonormal wavelets satisfy the above perfect \
reconstruction conditions. This is because such filters satisfy ",
  Cell[BoxData[
      \(TraditionalForm
      \`G \((\[Omega])\) = -\(e\^\(-i  \[Omega]\)\) 
        \(H \((\[Omega] + \[Pi])\)\)\&_\)], "InlineFormula",
    CellTags->"S1.5.3"],
  ", and "
}], "Text",
  CellTags->{"S1.5.3", "3.32"}],

Cell[BoxData[
    \(TraditionalForm
    \`\( \[VerticalSeparator] H \((\[Omega])\)\( \[VerticalSeparator] \^2\)+ 
      \[VerticalSeparator] H \((\[Omega] + \[Pi])
      \)\( \[VerticalSeparator] \^2\) = 1.\)\)], "DisplayFormula",
  CellTags->{"S1.5.3", "3.33"}],

Cell[TextData[{
  "So orthogonal wavelet transforms are, in fact, subband filtering schemes \
that give perfect reconstruction. However, there are many other filters that \
lead to perfect reconstruction without being orthogonal. We will see in \
Section ",
  ButtonBox["1.6",
    ButtonData:>{"Wavelets 1.6"},
    ButtonStyle->"AddOnsLink"],
  " that biorthogonal wavelets constitute one such example. "
}], "Text",
  CellTags->{"S1.5.3", "3.34"}],

Cell["1.5.4 Wavelets and Wavelet Transforms in Two Dimensions", "Subsection",
  CellTags->{"S1.5.4", "4.1"}],

Cell["\<\
The theories of multiresolution analysis and wavelets can be \
generalized to higher dimensions. In practice the usual choice for a two\
\[Hyphen]dimensional scaling function or wavelet is a product of two one\
\[Hyphen]dimensional functions. For example, \
\>", "Text",
  CellTags->{"S1.5.4", "4.2"}],

Cell[BoxData[
    \(TraditionalForm\`\[Phi] \((x, y)\) = \[Phi] \((x)\) \[Phi] \((y)\), \)],
   "DisplayFormula",
  CellTags->{"S1.5.4", "4.3"}],

Cell["and the dilation equation assumes the form", "Text",
  CellTags->{"S1.5.4", "4.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((x, y)\), "=", "2", 
        UnderscriptBox["\[Sum]", \(k, l\),
          LimitsPositioning->True], \(h\_\(k  l\)\), "\[Phi]", \((
        2  x - k, 2  y - l)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.4", "4.5"}],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((x)\)\)], "InlineFormula",
    CellTags->"S1.5.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((y)\)\)], "InlineFormula",
    CellTags->"S1.5.4"],
  " both satisfy the dilation equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", \((x)\), "=", \(\@2\), 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  x - k)\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.4"],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`h\_\(k  l\) = \(h\_k\) h\_l\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ". That is, the two\[Hyphen]dimensional dilation equation is the product of \
two one\[Hyphen]dimensional dilation equations. We can proceed analogously to \
construct wavelets using products of one\[Hyphen]dimensional functions. \
However, unlike the one\[Hyphen]dimensional case, we now have three rather \
than one basic wavelet. They are defined to be"
}], "Text",
  CellTags->{"S1.5.4", "4.6"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(\(\[Psi]\^\((I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[\(\[Phi] \((x)\) \[Psi] \((y)\), \),
              "DisplayFormula"]},
          {
            StyleBox[\(\(\[Psi]\^\((I I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[\(\[Psi] \((x)\) \[Phi] \((y)\), \),
              "DisplayFormula"]},
          {
            StyleBox[\(\(\[Psi]\^\((I I I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[\(\[Psi] \((x)\) \[Psi] \((y)\).\),
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.4", "4.7"}],

Cell["\<\
The generalization of the one\[Hyphen]dimensional wavelet equation \
leads to
the following relations: \
\>", "Text",
  CellTags->{"S1.5.4", "4.8"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(\(\[Psi]\^\((I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"2", 
                UnderscriptBox["\[Sum]", \(k, l\),
                  LimitsPositioning->True], \(g\_\(k l\)\%\((I)\)\), "\[Phi]",
                 \((2 x - k, 2 y - l)\), ","}],
              "DisplayFormula"]},
          {
            StyleBox[\(\(\[Psi]\^\((I I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"2", 
                UnderscriptBox["\[Sum]", \(k, l\),
                  LimitsPositioning->True], \(g\_\(k l\)\%\((I I)\)\), 
                "\[Phi]", \((2 x - k, 2 y - l)\), ","}],
              "DisplayFormula"]},
          {
            StyleBox[\(\(\[Psi]\^\((I I I)\)\) \((x, y)\)\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"2", 
                UnderscriptBox["\[Sum]", \(k, l\),
                  LimitsPositioning->True], \(g\_\(k l\)\%\((I I I)\)\), 
                "\[Phi]", \((2 x - k, 2 y - l)\), ","}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.4", "4.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`g\_\(k  l\)\%\((I)\) = \(h\_k\) g\_l\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`g\_\(k  l\)\%\((I  I)\) = \(g\_k\) h\_l\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`g\_\(k  l\)\%\((I  I  I)\) = \(g\_k\) g\_l\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  ". \nWe can generate two\[Hyphen]dimensional scaling functions and wavelets \
using the functions ",
  StyleBox["ScalingFunction", "MR"],
  " and ",
  StyleBox["Wavelet", "MR"],
  " then taking the product. For example, here we plot the Haar wavelets in \
two dimensions. Various translated and dilated versions of the wavelets can \
be plotted similarly. "
}], "Text",
  CellTags->{"S1.5.4", "4.10"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S1.5.4", "4.11"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.5.4"],

Cell["\<\
We first generate the one\[Hyphen]dimensional scaling function and \
mother wavelet.\
\>", "MathCaption",
  CellTags->{"S1.5.4", "4.12"}],

Cell["\<\
(h1 = DaubechiesFilter[1];
 phi = ScalingFunction[h1, 6, Interpolation -> True];
 psi = Wavelet[h1, 6, Interpolation -> True];)\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.5.4"],

Cell["This is the two\[Hyphen]dimensional Haar scaling function.", 
  "MathCaption",
  CellTags->{"S1.5.4", "4.13"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[phi[x] phi[y]], {x, -0.1, 1},
{y, -0.1, 1}, PlotPoints -> 30, PlotRange -> All,
Boxed -> False, Axes -> False];\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.27971e-18 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.664 .741 .908 r
.39457 .59389 .40512 .60371 .42281 .59841 .41233 .58852 Metetra
.664 .741 .908 r
.41233 .58852 .42281 .59841 .44061 .59307 .43021 .58311 Metetra
.946 .659 .462 r
.43021 .58311 .44061 .59307 .45853 .58769 .44361 .78163 Metetra
.561 .336 .531 r
.44361 .78163 .45853 .58769 .47657 .58228 .4628 .77654 Metetra
.561 .336 .531 r
.4628 .77654 .47657 .58228 .49473 .57683 .48213 .77142 Metetra
.561 .336 .531 r
.48213 .77142 .49473 .57683 .51301 .57135 .50159 .76626 Metetra
.561 .336 .531 r
.50159 .76626 .51301 .57135 .53142 .56582 .5212 .76107 Metetra
.561 .336 .531 r
.5212 .76107 .53142 .56582 .54995 .56027 .54094 .75583 Metetra
.561 .336 .531 r
.54094 .75583 .54995 .56027 .5686 .55467 .56083 .75056 Metetra
.561 .336 .531 r
.56083 .75056 .5686 .55467 .58738 .54904 .58086 .74525 Metetra
.561 .336 .531 r
.58086 .74525 .58738 .54904 .60629 .54336 .60104 .7399 Metetra
.561 .336 .531 r
.60104 .7399 .60629 .54336 .62532 .53765 .62136 .73452 Metetra
.561 .336 .531 r
.62136 .73452 .62532 .53765 .64449 .5319 .64184 .72909 Metetra
.561 .336 .531 r
.64184 .72909 .64449 .5319 .66379 .52611 .66246 .72363 Metetra
.561 .336 .531 r
.66246 .72363 .66379 .52611 .68322 .52028 .68324 .71812 Metetra
.561 .336 .531 r
.68324 .71812 .68322 .52028 .70279 .51441 .70416 .71257 Metetra
.561 .336 .531 r
.70416 .71257 .70279 .51441 .72249 .5085 .72525 .70698 Metetra
.561 .336 .531 r
.72525 .70698 .72249 .5085 .74233 .50255 .74649 .70136 Metetra
.561 .336 .531 r
.74649 .70136 .74233 .50255 .7623 .49656 .76789 .69568 Metetra
.561 .336 .531 r
.76789 .69568 .7623 .49656 .78242 .49052 .78945 .68997 Metetra
.561 .336 .531 r
.78945 .68997 .78242 .49052 .80268 .48445 .81118 .68421 Metetra
.561 .336 .531 r
.81118 .68421 .80268 .48445 .82308 .47833 .83307 .67841 Metetra
.561 .336 .531 r
.83307 .67841 .82308 .47833 .84363 .47216 .85512 .67256 Metetra
.561 .336 .531 r
.85512 .67256 .84363 .47216 .86432 .46595 .87734 .66668 Metetra
.561 .336 .531 r
.87734 .66668 .86432 .46595 .88516 .4597 .89974 .66074 Metetra
.561 .336 .531 r
.89974 .66074 .88516 .4597 .90615 .45341 .9223 .65476 Metetra
.561 .336 .531 r
.9223 .65476 .90615 .45341 .92729 .44706 .94504 .64873 Metetra
.561 .336 .531 r
.94504 .64873 .92729 .44706 .94858 .44068 .96795 .64266 Metetra
.155 .05 .473 r
.96795 .64266 .94858 .44068 .97003 .43424 .96217 .42224 Metetra
.664 .741 .908 r
.38389 .58395 .39457 .59389 .41233 .58852 .40173 .57851 Metetra
.664 .741 .908 r
.40173 .57851 .41233 .58852 .43021 .58311 .41968 .57304 Metetra
.946 .659 .462 r
.41968 .57304 .43021 .58311 .44361 .78163 .43249 .77221 Metetra
.646 .762 .934 r
.43249 .77221 .44361 .78163 .4628 .77654 .45177 .76706 Metetra
.646 .762 .934 r
.45177 .76706 .4628 .77654 .48213 .77142 .47118 .76187 Metetra
.646 .762 .934 r
.47118 .76187 .48213 .77142 .50159 .76626 .49074 .75664 Metetra
.646 .762 .934 r
.49074 .75664 .50159 .76626 .5212 .76107 .51044 .75138 Metetra
.646 .762 .934 r
.51044 .75138 .5212 .76107 .54094 .75583 .53027 .74607 Metetra
.646 .762 .934 r
.53027 .74607 .54094 .75583 .56083 .75056 .55026 .74073 Metetra
.646 .762 .934 r
.55026 .74073 .56083 .75056 .58086 .74525 .57038 .73535 Metetra
.646 .762 .934 r
.57038 .73535 .58086 .74525 .60104 .7399 .59066 .72993 Metetra
.646 .762 .934 r
.59066 .72993 .60104 .7399 .62136 .73452 .61108 .72447 Metetra
.646 .762 .934 r
.61108 .72447 .62136 .73452 .64184 .72909 .63166 .71897 Metetra
.646 .762 .934 r
.63166 .71897 .64184 .72909 .66246 .72363 .65239 .71343 Metetra
.646 .762 .934 r
.65239 .71343 .66246 .72363 .68324 .71812 .67327 .70785 Metetra
.646 .762 .934 r
.67327 .70785 .68324 .71812 .70416 .71257 .6943 .70222 Metetra
.646 .762 .934 r
.6943 .70222 .70416 .71257 .72525 .70698 .7155 .69656 Metetra
.646 .762 .934 r
.7155 .69656 .72525 .70698 .74649 .70136 .73685 .69085 Metetra
.646 .762 .934 r
.73685 .69085 .74649 .70136 .76789 .69568 .75836 .6851 Metetra
.646 .762 .934 r
.75836 .6851 .76789 .69568 .78945 .68997 .78004 .67931 Metetra
.646 .762 .934 r
.78004 .67931 .78945 .68997 .81118 .68421 .80188 .67347 Metetra
.646 .762 .934 r
.80188 .67347 .81118 .68421 .83307 .67841 .82388 .66758 Metetra
.646 .762 .934 r
.82388 .66758 .83307 .67841 .85512 .67256 .84606 .66166 Metetra
.646 .762 .934 r
.84606 .66166 .85512 .67256 .87734 .66668 .86841 .65568 Metetra
.646 .762 .934 r
.86841 .65568 .87734 .66668 .89974 .66074 .89092 .64966 Metetra
.646 .762 .934 r
.89092 .64966 .89974 .66074 .9223 .65476 .91361 .6436 Metetra
.646 .762 .934 r
.91361 .6436 .9223 .65476 .94504 .64873 .93648 .63748 Metetra
.646 .762 .934 r
.93648 .63748 .94504 .64873 .96795 .64266 .95953 .63132 Metetra
.986 .716 .415 r
.95953 .63132 .96795 .64266 .96217 .42224 .9542 .41007 Metetra
.664 .741 .908 r
.37308 .57388 .38389 .58395 .40173 .57851 .39099 .56838 Metetra
.664 .741 .908 r
.39099 .56838 .40173 .57851 .41968 .57304 .40902 .56284 Metetra
.946 .659 .462 r
.40902 .56284 .41968 .57304 .43249 .77221 .42123 .76267 Metetra
.646 .762 .934 r
.42123 .76267 .43249 .77221 .45177 .76706 .44059 .75745 Metetra
.646 .762 .934 r
.44059 .75745 .45177 .76706 .47118 .76187 .4601 .75219 Metetra
.646 .762 .934 r
.4601 .75219 .47118 .76187 .49074 .75664 .47974 .74689 Metetra
.646 .762 .934 r
.47974 .74689 .49074 .75664 .51044 .75138 .49953 .74155 Metetra
.646 .762 .934 r
.49953 .74155 .51044 .75138 .53027 .74607 .51946 .73618 Metetra
.646 .762 .934 r
.51946 .73618 .53027 .74607 .55026 .74073 .53954 .73077 Metetra
.646 .762 .934 r
.53954 .73077 .55026 .74073 .57038 .73535 .55977 .72531 Metetra
.646 .762 .934 r
.55977 .72531 .57038 .73535 .59066 .72993 .58014 .71982 Metetra
.646 .762 .934 r
.58014 .71982 .59066 .72993 .61108 .72447 .60067 .71428 Metetra
.646 .762 .934 r
.60067 .71428 .61108 .72447 .63166 .71897 .62134 .70871 Metetra
.646 .762 .934 r
.62134 .70871 .63166 .71897 .65239 .71343 .64217 .70309 Metetra
.646 .762 .934 r
.64217 .70309 .65239 .71343 .67327 .70785 .66316 .69743 Metetra
.646 .762 .934 r
.66316 .69743 .67327 .70785 .6943 .70222 .6843 .69173 Metetra
.646 .762 .934 r
.6843 .69173 .6943 .70222 .7155 .69656 .70561 .68599 Metetra
.646 .762 .934 r
.70561 .68599 .7155 .69656 .73685 .69085 .72707 .6802 Metetra
.646 .762 .934 r
.72707 .6802 .73685 .69085 .75836 .6851 .7487 .67437 Metetra
.646 .762 .934 r
.7487 .67437 .75836 .6851 .78004 .67931 .77049 .66849 Metetra
.646 .762 .934 r
.77049 .66849 .78004 .67931 .80188 .67347 .79245 .66257 Metetra
.646 .762 .934 r
.79245 .66257 .80188 .67347 .82388 .66758 .81457 .6566 Metetra
.646 .762 .934 r
.81457 .6566 .82388 .66758 .84606 .66166 .83687 .65059 Metetra
.646 .762 .934 r
.83687 .65059 .84606 .66166 .86841 .65568 .85934 .64453 Metetra
.646 .762 .934 r
.85934 .64453 .86841 .65568 .89092 .64966 .88198 .63843 Metetra
.646 .762 .934 r
.88198 .63843 .89092 .64966 .91361 .6436 .9048 .63227 Metetra
.646 .762 .934 r
.9048 .63227 .91361 .6436 .93648 .63748 .9278 .62607 Metetra
.646 .762 .934 r
.9278 .62607 .93648 .63748 .95953 .63132 .95098 .61982 Metetra
.986 .716 .415 r
.95098 .61982 .95953 .63132 .9542 .41007 .94612 .39774 Metetra
.664 .741 .908 r
.36214 .56369 .37308 .57388 .39099 .56838 .38012 .55812 Metetra
.664 .741 .908 r
.38012 .55812 .39099 .56838 .40902 .56284 .39822 .55251 Metetra
.946 .659 .462 r
.39822 .55251 .40902 .56284 .42123 .76267 .40982 .753 Metetra
.646 .762 .934 r
.40982 .753 .42123 .76267 .44059 .75745 .42927 .74771 Metetra
.646 .762 .934 r
.42927 .74771 .44059 .75745 .4601 .75219 .44886 .74238 Metetra
.646 .762 .934 r
.44886 .74238 .4601 .75219 .47974 .74689 .4686 .73701 Metetra
.646 .762 .934 r
.4686 .73701 .47974 .74689 .49953 .74155 .48848 .7316 Metetra
.646 .762 .934 r
.48848 .7316 .49953 .74155 .51946 .73618 .50851 .72615 Metetra
.646 .762 .934 r
.50851 .72615 .51946 .73618 .53954 .73077 .52868 .72067 Metetra
.646 .762 .934 r
.52868 .72067 .53954 .73077 .55977 .72531 .549 .71514 Metetra
.646 .762 .934 r
.549 .71514 .55977 .72531 .58014 .71982 .56948 .70957 Metetra
.646 .762 .934 r
.56948 .70957 .58014 .71982 .60067 .71428 .5901 .70396 Metetra
.646 .762 .934 r
.5901 .70396 .60067 .71428 .62134 .70871 .61088 .69831 Metetra
.646 .762 .934 r
.61088 .69831 .62134 .70871 .64217 .70309 .63182 .69261 Metetra
.646 .762 .934 r
.63182 .69261 .64217 .70309 .66316 .69743 .65291 .68687 Metetra
.646 .762 .934 r
.65291 .68687 .66316 .69743 .6843 .69173 .67416 .68109 Metetra
.646 .762 .934 r
.67416 .68109 .6843 .69173 .70561 .68599 .69558 .67527 Metetra
.646 .762 .934 r
.69558 .67527 .70561 .68599 .72707 .6802 .71716 .6694 Metetra
.646 .762 .934 r
.71716 .6694 .72707 .6802 .7487 .67437 .7389 .66348 Metetra
.646 .762 .934 r
.7389 .66348 .7487 .67437 .77049 .66849 .7608 .65753 Metetra
.646 .762 .934 r
.7608 .65753 .77049 .66849 .79245 .66257 .78288 .65152 Metetra
.646 .762 .934 r
.78288 .65152 .79245 .66257 .81457 .6566 .80513 .64547 Metetra
.646 .762 .934 r
.80513 .64547 .81457 .6566 .83687 .65059 .82755 .63937 Metetra
.646 .762 .934 r
.82755 .63937 .83687 .65059 .85934 .64453 .85014 .63322 Metetra
.646 .762 .934 r
.85014 .63322 .85934 .64453 .88198 .63843 .87291 .62703 Metetra
.646 .762 .934 r
.87291 .62703 .88198 .63843 .9048 .63227 .89586 .62079 Metetra
.646 .762 .934 r
.89586 .62079 .9048 .63227 .9278 .62607 .919 .6145 Metetra
.646 .762 .934 r
.919 .6145 .9278 .62607 .95098 .61982 .94231 .60815 Metetra
.986 .716 .415 r
.94231 .60815 .95098 .61982 .94612 .39774 .93793 .38524 Metetra
.664 .741 .908 r
.35106 .55337 .36214 .56369 .38012 .55812 .36911 .54773 Metetra
.664 .741 .908 r
.36911 .54773 .38012 .55812 .39822 .55251 .38729 .54205 Metetra
.946 .659 .462 r
.38729 .54205 .39822 .55251 .40982 .753 .39825 .7432 Metetra
.646 .762 .934 r
.39825 .7432 .40982 .753 .42927 .74771 .41779 .73784 Metetra
.646 .762 .934 r
.41779 .73784 .42927 .74771 .44886 .74238 .43748 .73244 Metetra
.646 .762 .934 r
.43748 .73244 .44886 .74238 .4686 .73701 .4573 .72699 Metetra
.646 .762 .934 r
.4573 .72699 .4686 .73701 .48848 .7316 .47728 .72151 Metetra
.646 .762 .934 r
.47728 .72151 .48848 .7316 .50851 .72615 .4974 .71599 Metetra
.646 .762 .934 r
.4974 .71599 .50851 .72615 .52868 .72067 .51767 .71043 Metetra
.646 .762 .934 r
.51767 .71043 .52868 .72067 .549 .71514 .53809 .70482 Metetra
.646 .762 .934 r
.53809 .70482 .549 .71514 .56948 .70957 .55867 .69918 Metetra
.646 .762 .934 r
.55867 .69918 .56948 .70957 .5901 .70396 .5794 .69349 Metetra
.646 .762 .934 r
.5794 .69349 .5901 .70396 .61088 .69831 .60028 .68776 Metetra
.646 .762 .934 r
.60028 .68776 .61088 .69831 .63182 .69261 .62132 .68199 Metetra
.646 .762 .934 r
.62132 .68199 .63182 .69261 .65291 .68687 .64252 .67617 Metetra
.646 .762 .934 r
.64252 .67617 .65291 .68687 .67416 .68109 .66388 .6703 Metetra
.646 .762 .934 r
.66388 .6703 .67416 .68109 .69558 .67527 .68541 .6644 Metetra
.646 .762 .934 r
.68541 .6644 .69558 .67527 .71716 .6694 .7071 .65845 Metetra
.646 .762 .934 r
.7071 .65845 .71716 .6694 .7389 .66348 .72896 .65245 Metetra
.646 .762 .934 r
.72896 .65245 .7389 .66348 .7608 .65753 .75098 .6464 Metetra
.646 .762 .934 r
.75098 .6464 .7608 .65753 .78288 .65152 .77318 .64031 Metetra
.646 .762 .934 r
.77318 .64031 .78288 .65152 .80513 .64547 .79555 .63417 Metetra
.646 .762 .934 r
.79555 .63417 .80513 .64547 .82755 .63937 .81809 .62799 Metetra
.646 .762 .934 r
.81809 .62799 .82755 .63937 .85014 .63322 .84081 .62175 Metetra
.646 .762 .934 r
.84081 .62175 .85014 .63322 .87291 .62703 .86371 .61547 Metetra
.646 .762 .934 r
.86371 .61547 .87291 .62703 .89586 .62079 .8868 .60913 Metetra
.646 .762 .934 r
.8868 .60913 .89586 .62079 .919 .6145 .91006 .60275 Metetra
.646 .762 .934 r
.91006 .60275 .919 .6145 .94231 .60815 .93351 .59631 Metetra
.986 .716 .415 r
.93351 .59631 .94231 .60815 .93793 .38524 .92963 .37257 Metetra
.664 .741 .908 r
.33984 .54293 .35106 .55337 .36911 .54773 .35797 .53721 Metetra
.664 .741 .908 r
.35797 .53721 .36911 .54773 .38729 .54205 .37623 .53146 Metetra
.946 .659 .462 r
.37623 .53146 .38729 .54205 .39825 .7432 .38653 .73327 Metetra
.646 .762 .934 r
.38653 .73327 .39825 .7432 .41779 .73784 .40616 .72783 Metetra
.646 .762 .934 r
.40616 .72783 .41779 .73784 .43748 .73244 .42594 .72236 Metetra
.646 .762 .934 r
.42594 .72236 .43748 .73244 .4573 .72699 .44586 .71684 Metetra
.646 .762 .934 r
.44586 .71684 .4573 .72699 .47728 .72151 .46592 .71129 Metetra
.646 .762 .934 r
.46592 .71129 .47728 .72151 .4974 .71599 .48614 .70569 Metetra
.646 .762 .934 r
.48614 .70569 .4974 .71599 .51767 .71043 .50651 .70005 Metetra
.646 .762 .934 r
.50651 .70005 .51767 .71043 .53809 .70482 .52703 .69437 Metetra
.646 .762 .934 r
.52703 .69437 .53809 .70482 .55867 .69918 .54771 .68864 Metetra
.646 .762 .934 r
.54771 .68864 .55867 .69918 .5794 .69349 .56854 .68288 Metetra
.646 .762 .934 r
.56854 .68288 .5794 .69349 .60028 .68776 .58953 .67707 Metetra
.646 .762 .934 r
.58953 .67707 .60028 .68776 .62132 .68199 .61067 .67121 Metetra
.646 .762 .934 r
.61067 .67121 .62132 .68199 .64252 .67617 .63198 .66531 Metetra
.646 .762 .934 r
.63198 .66531 .64252 .67617 .66388 .6703 .65346 .65936 Metetra
.646 .762 .934 r
.65346 .65936 .66388 .6703 .68541 .6644 .6751 .65337 Metetra
.646 .762 .934 r
.6751 .65337 .68541 .6644 .7071 .65845 .6969 .64734 Metetra
.646 .762 .934 r
.6969 .64734 .7071 .65845 .72896 .65245 .71887 .64125 Metetra
.646 .762 .934 r
.71887 .64125 .72896 .65245 .75098 .6464 .74102 .63512 Metetra
.646 .762 .934 r
.74102 .63512 .75098 .6464 .77318 .64031 .76334 .62894 Metetra
.646 .762 .934 r
.76334 .62894 .77318 .64031 .79555 .63417 .78583 .62271 Metetra
.646 .762 .934 r
.78583 .62271 .79555 .63417 .81809 .62799 .8085 .61644 Metetra
.646 .762 .934 r
.8085 .61644 .81809 .62799 .84081 .62175 .83135 .61011 Metetra
.646 .762 .934 r
.83135 .61011 .84081 .62175 .86371 .61547 .85438 .60373 Metetra
.646 .762 .934 r
.85438 .60373 .86371 .61547 .8868 .60913 .87759 .59731 Metetra
.646 .762 .934 r
.87759 .59731 .8868 .60913 .91006 .60275 .90099 .59083 Metetra
.646 .762 .934 r
.90099 .59083 .91006 .60275 .93351 .59631 .92458 .5843 Metetra
.986 .716 .415 r
.92458 .5843 .93351 .59631 .92963 .37257 .92121 .35972 Metetra
.664 .741 .908 r
.32848 .53235 .33984 .54293 .35797 .53721 .34668 .52656 Metetra
.664 .741 .908 r
.34668 .52656 .35797 .53721 .37623 .53146 .36502 .52073 Metetra
.946 .659 .462 r
.36502 .52073 .37623 .53146 .38653 .73327 .37465 .7232 Metetra
.646 .762 .934 r
.37465 .7232 .38653 .73327 .40616 .72783 .39437 .71769 Metetra
.646 .762 .934 r
.39437 .71769 .40616 .72783 .42594 .72236 .41424 .71214 Metetra
.646 .762 .934 r
.41424 .71214 .42594 .72236 .44586 .71684 .43425 .70655 Metetra
.646 .762 .934 r
.43425 .70655 .44586 .71684 .46592 .71129 .45441 .70092 Metetra
.646 .762 .934 r
.45441 .70092 .46592 .71129 .48614 .70569 .47473 .69525 Metetra
.646 .762 .934 r
.47473 .69525 .48614 .70569 .50651 .70005 .4952 .68953 Metetra
.646 .762 .934 r
.4952 .68953 .50651 .70005 .52703 .69437 .51582 .68377 Metetra
.646 .762 .934 r
.51582 .68377 .52703 .69437 .54771 .68864 .53659 .67796 Metetra
.646 .762 .934 r
.53659 .67796 .54771 .68864 .56854 .68288 .55753 .67211 Metetra
.646 .762 .934 r
.55753 .67211 .56854 .68288 .58953 .67707 .57862 .66622 Metetra
.646 .762 .934 r
.57862 .66622 .58953 .67707 .61067 .67121 .59988 .66028 Metetra
.646 .762 .934 r
.59988 .66028 .61067 .67121 .63198 .66531 .6213 .6543 Metetra
.646 .762 .934 r
.6213 .6543 .63198 .66531 .65346 .65936 .64288 .64827 Metetra
.646 .762 .934 r
.64288 .64827 .65346 .65936 .6751 .65337 .66463 .64219 Metetra
.646 .762 .934 r
.66463 .64219 .6751 .65337 .6969 .64734 .68656 .63607 Metetra
.646 .762 .934 r
.68656 .63607 .6969 .64734 .71887 .64125 .70865 .6299 Metetra
.646 .762 .934 r
.70865 .6299 .71887 .64125 .74102 .63512 .73091 .62367 Metetra
.646 .762 .934 r
.73091 .62367 .74102 .63512 .76334 .62894 .75335 .61741 Metetra
.646 .762 .934 r
.75335 .61741 .76334 .62894 .78583 .62271 .77597 .61109 Metetra
.646 .762 .934 r
.77597 .61109 .78583 .62271 .8085 .61644 .79877 .60472 Metetra
.646 .762 .934 r
.79877 .60472 .8085 .61644 .83135 .61011 .82174 .5983 Metetra
.646 .762 .934 r
.82174 .5983 .83135 .61011 .85438 .60373 .84491 .59183 Metetra
.646 .762 .934 r
.84491 .59183 .85438 .60373 .87759 .59731 .86825 .58531 Metetra
.646 .762 .934 r
.86825 .58531 .87759 .59731 .90099 .59083 .89179 .57873 Metetra
.646 .762 .934 r
.89179 .57873 .90099 .59083 .92458 .5843 .91552 .5721 Metetra
.986 .716 .415 r
.91552 .5721 .92458 .5843 .92121 .35972 .91267 .34669 Metetra
.664 .741 .908 r
.31697 .52163 .32848 .53235 .34668 .52656 .33525 .51577 Metetra
.664 .741 .908 r
.33525 .51577 .34668 .52656 .36502 .52073 .35366 .50987 Metetra
.946 .659 .462 r
.35366 .50987 .36502 .52073 .37465 .7232 .36261 .713 Metetra
.646 .762 .934 r
.36261 .713 .37465 .7232 .39437 .71769 .38242 .70742 Metetra
.646 .762 .934 r
.38242 .70742 .39437 .71769 .41424 .71214 .40238 .70179 Metetra
.646 .762 .934 r
.40238 .70179 .41424 .71214 .43425 .70655 .42249 .69612 Metetra
.646 .762 .934 r
.42249 .69612 .43425 .70655 .45441 .70092 .44274 .69041 Metetra
.646 .762 .934 r
.44274 .69041 .45441 .70092 .47473 .69525 .46316 .68466 Metetra
.646 .762 .934 r
.46316 .68466 .47473 .69525 .4952 .68953 .48372 .67886 Metetra
.646 .762 .934 r
.48372 .67886 .4952 .68953 .51582 .68377 .50444 .67302 Metetra
.646 .762 .934 r
.50444 .67302 .51582 .68377 .53659 .67796 .52532 .66713 Metetra
.646 .762 .934 r
.52532 .66713 .53659 .67796 .55753 .67211 .54636 .6612 Metetra
.646 .762 .934 r
.54636 .6612 .55753 .67211 .57862 .66622 .56756 .65522 Metetra
.646 .762 .934 r
.56756 .65522 .57862 .66622 .59988 .66028 .58893 .6492 Metetra
.646 .762 .934 r
.58893 .6492 .59988 .66028 .6213 .6543 .61046 .64313 Metetra
.646 .762 .934 r
.61046 .64313 .6213 .6543 .64288 .64827 .63216 .63701 Metetra
.646 .762 .934 r
.63216 .63701 .64288 .64827 .66463 .64219 .65402 .63085 Metetra
.646 .762 .934 r
.65402 .63085 .66463 .64219 .68656 .63607 .67606 .62463 Metetra
.646 .762 .934 r
.67606 .62463 .68656 .63607 .70865 .6299 .69827 .61837 Metetra
.646 .762 .934 r
.69827 .61837 .70865 .6299 .73091 .62367 .72066 .61206 Metetra
.646 .762 .934 r
.72066 .61206 .73091 .62367 .75335 .61741 .74322 .6057 Metetra
.646 .762 .934 r
.74322 .6057 .75335 .61741 .77597 .61109 .76596 .59929 Metetra
.646 .762 .934 r
.76596 .59929 .77597 .61109 .79877 .60472 .78889 .59283 Metetra
.646 .762 .934 r
.78889 .59283 .79877 .60472 .82174 .5983 .812 .58631 Metetra
.646 .762 .934 r
.812 .58631 .82174 .5983 .84491 .59183 .83529 .57975 Metetra
.646 .762 .934 r
.83529 .57975 .84491 .59183 .86825 .58531 .85878 .57313 Metetra
.646 .762 .934 r
.85878 .57313 .86825 .58531 .89179 .57873 .88245 .56645 Metetra
.646 .762 .934 r
.88245 .56645 .89179 .57873 .91552 .5721 .90632 .55972 Metetra
.986 .716 .415 r
.90632 .55972 .91552 .5721 .91267 .34669 .90401 .33348 Metetra
.664 .741 .908 r
.30532 .51078 .31697 .52163 .33525 .51577 .32368 .50485 Metetra
.664 .741 .908 r
.32368 .50485 .33525 .51577 .35366 .50987 .34217 .49887 Metetra
.946 .659 .462 r
.34217 .49887 .35366 .50987 .36261 .713 .3504 .70266 Metetra
.646 .762 .934 r
.3504 .70266 .36261 .713 .38242 .70742 .3703 .697 Metetra
.646 .762 .934 r
.3703 .697 .38242 .70742 .40238 .70179 .39035 .69129 Metetra
.646 .762 .934 r
.39035 .69129 .40238 .70179 .42249 .69612 .41056 .68554 Metetra
.646 .762 .934 r
.41056 .68554 .42249 .69612 .44274 .69041 .43091 .67975 Metetra
.646 .762 .934 r
.43091 .67975 .44274 .69041 .46316 .68466 .45142 .67392 Metetra
.646 .762 .934 r
.45142 .67392 .46316 .68466 .48372 .67886 .47209 .66804 Metetra
.646 .762 .934 r
.47209 .66804 .48372 .67886 .50444 .67302 .49291 .66211 Metetra
.646 .762 .934 r
.49291 .66211 .50444 .67302 .52532 .66713 .51389 .65614 Metetra
.646 .762 .934 r
.51389 .65614 .52532 .66713 .54636 .6612 .53504 .65013 Metetra
.646 .762 .934 r
.53504 .65013 .54636 .6612 .56756 .65522 .55635 .64407 Metetra
.646 .762 .934 r
.55635 .64407 .56756 .65522 .58893 .6492 .57782 .63796 Metetra
.646 .762 .934 r
.57782 .63796 .58893 .6492 .61046 .64313 .59946 .6318 Metetra
.646 .762 .934 r
.59946 .6318 .61046 .64313 .63216 .63701 .62128 .62559 Metetra
.646 .762 .934 r
.62128 .62559 .63216 .63701 .65402 .63085 .64326 .61934 Metetra
.646 .762 .934 r
.64326 .61934 .65402 .63085 .67606 .62463 .66541 .61304 Metetra
.646 .762 .934 r
.66541 .61304 .67606 .62463 .69827 .61837 .68774 .60668 Metetra
.646 .762 .934 r
.68774 .60668 .69827 .61837 .72066 .61206 .71025 .60028 Metetra
.646 .762 .934 r
.71025 .60028 .72066 .61206 .74322 .6057 .73294 .59382 Metetra
.646 .762 .934 r
.73294 .59382 .74322 .6057 .76596 .59929 .75581 .58732 Metetra
.646 .762 .934 r
.75581 .58732 .76596 .59929 .78889 .59283 .77887 .58076 Metetra
.646 .762 .934 r
.77887 .58076 .78889 .59283 .812 .58631 .80211 .57415 Metetra
.646 .762 .934 r
.80211 .57415 .812 .58631 .83529 .57975 .82554 .56748 Metetra
.646 .762 .934 r
.82554 .56748 .83529 .57975 .85878 .57313 .84915 .56076 Metetra
.646 .762 .934 r
.84915 .56076 .85878 .57313 .88245 .56645 .87297 .55399 Metetra
.646 .762 .934 r
.87297 .55399 .88245 .56645 .90632 .55972 .89698 .54716 Metetra
.986 .716 .415 r
.89698 .54716 .90632 .55972 .90401 .33348 .89523 .32008 Metetra
.664 .741 .908 r
.29351 .49979 .30532 .51078 .32368 .50485 .31195 .49378 Metetra
.664 .741 .908 r
.31195 .49378 .32368 .50485 .34217 .49887 .33052 .48772 Metetra
.946 .659 .462 r
.33052 .48772 .34217 .49887 .3504 .70266 .33802 .69217 Metetra
.646 .762 .934 r
.33802 .69217 .3504 .70266 .3703 .697 .35802 .68643 Metetra
.646 .762 .934 r
.35802 .68643 .3703 .697 .39035 .69129 .37816 .68065 Metetra
.646 .762 .934 r
.37816 .68065 .39035 .69129 .41056 .68554 .39846 .67482 Metetra
.646 .762 .934 r
.39846 .67482 .41056 .68554 .43091 .67975 .41891 .66895 Metetra
.646 .762 .934 r
.41891 .66895 .43091 .67975 .45142 .67392 .43952 .66303 Metetra
.646 .762 .934 r
.43952 .66303 .45142 .67392 .47209 .66804 .46029 .65707 Metetra
.646 .762 .934 r
.46029 .65707 .47209 .66804 .49291 .66211 .48121 .65106 Metetra
.646 .762 .934 r
.48121 .65106 .49291 .66211 .51389 .65614 .5023 .645 Metetra
.646 .762 .934 r
.5023 .645 .51389 .65614 .53504 .65013 .52355 .6389 Metetra
.646 .762 .934 r
.52355 .6389 .53504 .65013 .55635 .64407 .54497 .63275 Metetra
.646 .762 .934 r
.54497 .63275 .55635 .64407 .57782 .63796 .56656 .62655 Metetra
.646 .762 .934 r
.56656 .62655 .57782 .63796 .59946 .6318 .58831 .62031 Metetra
.646 .762 .934 r
.58831 .62031 .59946 .6318 .62128 .62559 .61024 .61401 Metetra
.646 .762 .934 r
.61024 .61401 .62128 .62559 .64326 .61934 .63233 .60766 Metetra
.646 .762 .934 r
.63233 .60766 .64326 .61934 .66541 .61304 .65461 .60127 Metetra
.646 .762 .934 r
.65461 .60127 .66541 .61304 .68774 .60668 .67706 .59482 Metetra
.646 .762 .934 r
.67706 .59482 .68774 .60668 .71025 .60028 .69969 .58832 Metetra
.646 .762 .934 r
.69969 .58832 .71025 .60028 .73294 .59382 .72251 .58177 Metetra
.646 .762 .934 r
.72251 .58177 .73294 .59382 .75581 .58732 .74551 .57517 Metetra
.646 .762 .934 r
.74551 .57517 .75581 .58732 .77887 .58076 .76869 .56851 Metetra
.646 .762 .934 r
.76869 .56851 .77887 .58076 .80211 .57415 .79207 .5618 Metetra
.646 .762 .934 r
.79207 .5618 .80211 .57415 .82554 .56748 .81563 .55503 Metetra
.646 .762 .934 r
.81563 .55503 .82554 .56748 .84915 .56076 .83939 .54821 Metetra
.646 .762 .934 r
.83939 .54821 .84915 .56076 .87297 .55399 .86334 .54133 Metetra
.646 .762 .934 r
.86334 .54133 .87297 .55399 .89698 .54716 .88749 .5344 Metetra
.986 .716 .415 r
.88749 .5344 .89698 .54716 .89523 .32008 .88633 .30649 Metetra
.664 .741 .908 r
.28155 .48866 .29351 .49979 .31195 .49378 .30007 .48257 Metetra
.664 .741 .908 r
.30007 .48257 .31195 .49378 .33052 .48772 .31872 .47643 Metetra
.946 .659 .462 r
.31872 .47643 .33052 .48772 .33802 .69217 .32547 .68154 Metetra
.646 .762 .934 r
.32547 .68154 .33802 .69217 .35802 .68643 .34556 .67572 Metetra
.646 .762 .934 r
.34556 .67572 .35802 .68643 .37816 .68065 .3658 .66985 Metetra
.646 .762 .934 r
.3658 .66985 .37816 .68065 .39846 .67482 .38619 .66394 Metetra
.646 .762 .934 r
.38619 .66394 .39846 .67482 .41891 .66895 .40674 .65799 Metetra
.646 .762 .934 r
.40674 .65799 .41891 .66895 .43952 .66303 .42745 .65198 Metetra
.646 .762 .934 r
.42745 .65198 .43952 .66303 .46029 .65707 .44832 .64594 Metetra
.646 .762 .934 r
.44832 .64594 .46029 .65707 .48121 .65106 .46935 .63984 Metetra
.646 .762 .934 r
.46935 .63984 .48121 .65106 .5023 .645 .49054 .6337 Metetra
.646 .762 .934 r
.49054 .6337 .5023 .645 .52355 .6389 .5119 .62751 Metetra
.646 .762 .934 r
.5119 .62751 .52355 .6389 .54497 .63275 .53343 .62127 Metetra
.646 .762 .934 r
.53343 .62127 .54497 .63275 .56656 .62655 .55512 .61498 Metetra
.646 .762 .934 r
.55512 .61498 .56656 .62655 .58831 .62031 .57699 .60864 Metetra
.646 .762 .934 r
.57699 .60864 .58831 .62031 .61024 .61401 .59903 .60226 Metetra
.646 .762 .934 r
.59903 .60226 .61024 .61401 .63233 .60766 .62125 .59582 Metetra
.646 .762 .934 r
.62125 .59582 .63233 .60766 .65461 .60127 .64365 .58933 Metetra
.646 .762 .934 r
.64365 .58933 .65461 .60127 .67706 .59482 .66622 .58278 Metetra
.646 .762 .934 r
.66622 .58278 .67706 .59482 .69969 .58832 .68898 .57619 Metetra
.646 .762 .934 r
.68898 .57619 .69969 .58832 .72251 .58177 .71192 .56954 Metetra
.646 .762 .934 r
.71192 .56954 .72251 .58177 .74551 .57517 .73505 .56284 Metetra
.646 .762 .934 r
.73505 .56284 .74551 .57517 .76869 .56851 .75836 .55608 Metetra
.646 .762 .934 r
.75836 .55608 .76869 .56851 .79207 .5618 .78187 .54926 Metetra
.646 .762 .934 r
.78187 .54926 .79207 .5618 .81563 .55503 .80557 .5424 Metetra
.646 .762 .934 r
.80557 .5424 .81563 .55503 .83939 .54821 .82947 .53547 Metetra
.646 .762 .934 r
.82947 .53547 .83939 .54821 .86334 .54133 .85357 .52849 Metetra
.646 .762 .934 r
.85357 .52849 .86334 .54133 .88749 .5344 .87787 .52144 Metetra
.986 .716 .415 r
.87787 .52144 .88749 .5344 .88633 .30649 .87729 .2927 Metetra
.664 .741 .908 r
.26944 .47738 .28155 .48866 .30007 .48257 .28804 .47121 Metetra
.664 .741 .908 r
.28804 .47121 .30007 .48257 .31872 .47643 .30676 .465 Metetra
.946 .659 .462 r
.30676 .465 .31872 .47643 .32547 .68154 .31275 .67076 Metetra
.646 .762 .934 r
.31275 .67076 .32547 .68154 .34556 .67572 .33293 .66485 Metetra
.646 .762 .934 r
.33293 .66485 .34556 .67572 .3658 .66985 .35326 .6589 Metetra
.646 .762 .934 r
.35326 .6589 .3658 .66985 .38619 .66394 .37375 .65291 Metetra
.646 .762 .934 r
.37375 .65291 .38619 .66394 .40674 .65799 .3944 .64687 Metetra
.646 .762 .934 r
.3944 .64687 .40674 .65799 .42745 .65198 .41521 .64078 Metetra
.646 .762 .934 r
.41521 .64078 .42745 .65198 .44832 .64594 .43618 .63465 Metetra
.646 .762 .934 r
.43618 .63465 .44832 .64594 .46935 .63984 .45731 .62846 Metetra
.646 .762 .934 r
.45731 .62846 .46935 .63984 .49054 .6337 .47861 .62223 Metetra
.646 .762 .934 r
.47861 .62223 .49054 .6337 .5119 .62751 .50008 .61595 Metetra
.646 .762 .934 r
.50008 .61595 .5119 .62751 .53343 .62127 .52172 .60962 Metetra
.646 .762 .934 r
.52172 .60962 .53343 .62127 .55512 .61498 .54353 .60324 Metetra
.646 .762 .934 r
.54353 .60324 .55512 .61498 .57699 .60864 .56551 .59681 Metetra
.646 .762 .934 r
.56551 .59681 .57699 .60864 .59903 .60226 .58767 .59033 Metetra
.646 .762 .934 r
.58767 .59033 .59903 .60226 .62125 .59582 .61 .58379 Metetra
.646 .762 .934 r
.61 .58379 .62125 .59582 .64365 .58933 .63252 .57721 Metetra
.646 .762 .934 r
.63252 .57721 .64365 .58933 .66622 .58278 .65522 .57056 Metetra
.646 .762 .934 r
.65522 .57056 .66622 .58278 .68898 .57619 .6781 .56387 Metetra
.646 .762 .934 r
.6781 .56387 .68898 .57619 .71192 .56954 .70117 .55712 Metetra
.646 .762 .934 r
.70117 .55712 .71192 .56954 .73505 .56284 .72443 .55032 Metetra
.646 .762 .934 r
.72443 .55032 .73505 .56284 .75836 .55608 .74788 .54346 Metetra
.646 .762 .934 r
.74788 .54346 .75836 .55608 .78187 .54926 .77152 .53654 Metetra
.646 .762 .934 r
.77152 .53654 .78187 .54926 .80557 .5424 .79537 .52956 Metetra
.646 .762 .934 r
.79537 .52956 .80557 .5424 .82947 .53547 .8194 .52253 Metetra
.646 .762 .934 r
.8194 .52253 .82947 .53547 .85357 .52849 .84364 .51544 Metetra
.646 .762 .934 r
.84364 .51544 .85357 .52849 .87787 .52144 .86809 .50829 Metetra
.986 .716 .415 r
.86809 .50829 .87787 .52144 .87729 .2927 .86813 .27871 Metetra
.664 .741 .908 r
.25717 .46595 .26944 .47738 .28804 .47121 .27584 .4597 Metetra
.664 .741 .908 r
.27584 .4597 .28804 .47121 .30676 .465 .29465 .45341 Metetra
.946 .659 .462 r
.29465 .45341 .30676 .465 .31275 .67076 .29984 .65982 Metetra
.646 .762 .934 r
.29984 .65982 .31275 .67076 .33293 .66485 .32012 .65384 Metetra
.646 .762 .934 r
.32012 .65384 .33293 .66485 .35326 .6589 .34055 .6478 Metetra
.646 .762 .934 r
.34055 .6478 .35326 .6589 .37375 .65291 .36113 .64172 Metetra
.646 .762 .934 r
.36113 .64172 .37375 .65291 .3944 .64687 .38188 .63559 Metetra
.646 .762 .934 r
.38188 .63559 .3944 .64687 .41521 .64078 .40279 .62942 Metetra
.646 .762 .934 r
.40279 .62942 .41521 .64078 .43618 .63465 .42386 .62319 Metetra
.646 .762 .934 r
.42386 .62319 .43618 .63465 .45731 .62846 .4451 .61692 Metetra
.646 .762 .934 r
.4451 .61692 .45731 .62846 .47861 .62223 .46651 .6106 Metetra
.646 .762 .934 r
.46651 .6106 .47861 .62223 .50008 .61595 .48809 .60423 Metetra
.646 .762 .934 r
.48809 .60423 .50008 .61595 .52172 .60962 .50983 .5978 Metetra
.646 .762 .934 r
.50983 .5978 .52172 .60962 .54353 .60324 .53176 .59133 Metetra
.646 .762 .934 r
.53176 .59133 .54353 .60324 .56551 .59681 .55385 .5848 Metetra
.646 .762 .934 r
.55385 .5848 .56551 .59681 .58767 .59033 .57613 .57822 Metetra
.646 .762 .934 r
.57613 .57822 .58767 .59033 .61 .58379 .59859 .57159 Metetra
.646 .762 .934 r
.59859 .57159 .61 .58379 .63252 .57721 .62123 .5649 Metetra
.646 .762 .934 r
.62123 .5649 .63252 .57721 .65522 .57056 .64405 .55816 Metetra
.646 .762 .934 r
.64405 .55816 .65522 .57056 .6781 .56387 .66706 .55137 Metetra
.646 .762 .934 r
.66706 .55137 .6781 .56387 .70117 .55712 .69026 .54451 Metetra
.646 .762 .934 r
.69026 .54451 .70117 .55712 .72443 .55032 .71365 .53761 Metetra
.646 .762 .934 r
.71365 .53761 .72443 .55032 .74788 .54346 .73724 .53064 Metetra
.646 .762 .934 r
.73724 .53064 .74788 .54346 .77152 .53654 .76102 .52362 Metetra
.646 .762 .934 r
.76102 .52362 .77152 .53654 .79537 .52956 .785 .51653 Metetra
.646 .762 .934 r
.785 .51653 .79537 .52956 .8194 .52253 .80918 .50939 Metetra
.646 .762 .934 r
.80918 .50939 .8194 .52253 .84364 .51544 .83357 .50219 Metetra
.646 .762 .934 r
.83357 .50219 .84364 .51544 .86809 .50829 .85816 .49493 Metetra
.986 .716 .415 r
.85816 .49493 .86809 .50829 .86813 .27871 .85883 .26451 Metetra
.664 .741 .908 r
.24474 .45438 .25717 .46595 .27584 .4597 .26349 .44804 Metetra
.664 .741 .908 r
.26349 .44804 .27584 .4597 .29465 .45341 .28238 .44166 Metetra
.946 .659 .462 r
.28238 .44166 .29465 .45341 .29984 .65982 .28676 .64873 Metetra
.646 .762 .934 r
.28676 .64873 .29984 .65982 .32012 .65384 .30712 .64266 Metetra
.646 .762 .934 r
.30712 .64266 .32012 .65384 .34055 .6478 .32765 .63654 Metetra
.646 .762 .934 r
.32765 .63654 .34055 .6478 .36113 .64172 .34833 .63037 Metetra
.646 .762 .934 r
.34833 .63037 .36113 .64172 .38188 .63559 .36918 .62416 Metetra
.646 .762 .934 r
.36918 .62416 .38188 .63559 .40279 .62942 .39019 .61789 Metetra
.646 .762 .934 r
.39019 .61789 .40279 .62942 .42386 .62319 .41137 .61157 Metetra
.646 .762 .934 r
.41137 .61157 .42386 .62319 .4451 .61692 .43271 .60521 Metetra
.646 .762 .934 r
.43271 .60521 .4451 .61692 .46651 .6106 .45423 .59879 Metetra
.646 .762 .934 r
.45423 .59879 .46651 .6106 .48809 .60423 .47591 .59233 Metetra
.646 .762 .934 r
.47591 .59233 .48809 .60423 .50983 .5978 .49778 .58581 Metetra
.646 .762 .934 r
.49778 .58581 .50983 .5978 .53176 .59133 .51981 .57924 Metetra
.646 .762 .934 r
.51981 .57924 .53176 .59133 .55385 .5848 .54203 .57261 Metetra
.646 .762 .934 r
.54203 .57261 .55385 .5848 .57613 .57822 .56442 .56594 Metetra
.646 .762 .934 r
.56442 .56594 .57613 .57822 .59859 .57159 .587 .5592 Metetra
.646 .762 .934 r
.587 .5592 .59859 .57159 .62123 .5649 .60976 .55242 Metetra
.646 .762 .934 r
.60976 .55242 .62123 .5649 .64405 .55816 .63271 .54557 Metetra
.646 .762 .934 r
.63271 .54557 .64405 .55816 .66706 .55137 .65585 .53867 Metetra
.646 .762 .934 r
.65585 .53867 .66706 .55137 .69026 .54451 .67918 .53172 Metetra
.646 .762 .934 r
.67918 .53172 .69026 .54451 .71365 .53761 .70271 .5247 Metetra
.646 .762 .934 r
.70271 .5247 .71365 .53761 .73724 .53064 .72643 .51763 Metetra
.646 .762 .934 r
.72643 .51763 .73724 .53064 .76102 .52362 .75035 .51049 Metetra
.646 .762 .934 r
.75035 .51049 .76102 .52362 .785 .51653 .77447 .5033 Metetra
.646 .762 .934 r
.77447 .5033 .785 .51653 .80918 .50939 .7988 .49605 Metetra
.646 .762 .934 r
.7988 .49605 .80918 .50939 .83357 .50219 .82333 .48873 Metetra
.646 .762 .934 r
.82333 .48873 .83357 .50219 .85816 .49493 .84807 .48135 Metetra
.986 .716 .415 r
.84807 .48135 .85816 .49493 .85883 .26451 .84939 .25011 Metetra
.664 .741 .908 r
.23214 .44265 .24474 .45438 .26349 .44804 .25097 .43623 Metetra
.664 .741 .908 r
.25097 .43623 .26349 .44804 .28238 .44166 .26994 .42976 Metetra
.946 .659 .462 r
.26994 .42976 .28238 .44166 .28676 .64873 .27348 .63748 Metetra
.646 .762 .934 r
.27348 .63748 .28676 .64873 .30712 .64266 .29394 .63132 Metetra
.646 .762 .934 r
.29394 .63132 .30712 .64266 .32765 .63654 .31456 .62511 Metetra
.646 .762 .934 r
.31456 .62511 .32765 .63654 .34833 .63037 .33535 .61886 Metetra
.646 .762 .934 r
.33535 .61886 .34833 .63037 .36918 .62416 .35629 .61255 Metetra
.646 .762 .934 r
.35629 .61255 .36918 .62416 .39019 .61789 .37741 .60619 Metetra
.646 .762 .934 r
.37741 .60619 .39019 .61789 .41137 .61157 .39869 .59978 Metetra
.646 .762 .934 r
.39869 .59978 .41137 .61157 .43271 .60521 .42014 .59333 Metetra
.646 .762 .934 r
.42014 .59333 .43271 .60521 .45423 .59879 .44177 .58682 Metetra
.646 .762 .934 r
.44177 .58682 .45423 .59879 .47591 .59233 .46356 .58025 Metetra
.646 .762 .934 r
.46356 .58025 .47591 .59233 .49778 .58581 .48554 .57364 Metetra
.646 .762 .934 r
.48554 .57364 .49778 .58581 .51981 .57924 .50769 .56697 Metetra
.646 .762 .934 r
.50769 .56697 .51981 .57924 .54203 .57261 .53002 .56024 Metetra
.646 .762 .934 r
.53002 .56024 .54203 .57261 .56442 .56594 .55254 .55346 Metetra
.646 .762 .934 r
.55254 .55346 .56442 .56594 .587 .5592 .57524 .54663 Metetra
.646 .762 .934 r
.57524 .54663 .587 .5592 .60976 .55242 .59812 .53974 Metetra
.646 .762 .934 r
.59812 .53974 .60976 .55242 .63271 .54557 .6212 .53279 Metetra
.646 .762 .934 r
.6212 .53279 .63271 .54557 .65585 .53867 .64447 .52578 Metetra
.646 .762 .934 r
.64447 .52578 .65585 .53867 .67918 .53172 .66793 .51872 Metetra
.646 .762 .934 r
.66793 .51872 .67918 .53172 .70271 .5247 .69159 .5116 Metetra
.646 .762 .934 r
.69159 .5116 .70271 .5247 .72643 .51763 .71545 .50441 Metetra
.646 .762 .934 r
.71545 .50441 .72643 .51763 .75035 .51049 .73951 .49717 Metetra
.646 .762 .934 r
.73951 .49717 .75035 .51049 .77447 .5033 .76378 .48986 Metetra
.646 .762 .934 r
.76378 .48986 .77447 .5033 .7988 .49605 .78825 .48249 Metetra
.646 .762 .934 r
.78825 .48249 .7988 .49605 .82333 .48873 .81293 .47506 Metetra
.646 .762 .934 r
.81293 .47506 .82333 .48873 .84807 .48135 .83782 .46757 Metetra
.986 .716 .415 r
.83782 .46757 .84807 .48135 .84939 .25011 .83981 .23549 Metetra
.664 .741 .908 r
.21937 .43076 .23214 .44265 .25097 .43623 .23828 .42425 Metetra
.664 .741 .908 r
.23828 .42425 .25097 .43623 .26994 .42976 .25733 .4177 Metetra
.946 .659 .462 r
.25733 .4177 .26994 .42976 .27348 .63748 .26001 .62607 Metetra
.646 .762 .934 r
.26001 .62607 .27348 .63748 .29394 .63132 .28057 .61982 Metetra
.646 .762 .934 r
.28057 .61982 .29394 .63132 .31456 .62511 .30129 .61352 Metetra
.646 .762 .934 r
.30129 .61352 .31456 .62511 .33535 .61886 .32217 .60717 Metetra
.646 .762 .934 r
.32217 .60717 .33535 .61886 .35629 .61255 .34322 .60077 Metetra
.646 .762 .934 r
.34322 .60077 .35629 .61255 .37741 .60619 .36444 .59432 Metetra
.646 .762 .934 r
.36444 .59432 .37741 .60619 .39869 .59978 .38582 .58782 Metetra
.646 .762 .934 r
.38582 .58782 .39869 .59978 .42014 .59333 .40738 .58127 Metetra
.646 .762 .934 r
.40738 .58127 .42014 .59333 .44177 .58682 .42912 .57466 Metetra
.646 .762 .934 r
.42912 .57466 .44177 .58682 .46356 .58025 .45103 .568 Metetra
.646 .762 .934 r
.45103 .568 .46356 .58025 .48554 .57364 .47311 .56128 Metetra
.646 .762 .934 r
.47311 .56128 .48554 .57364 .50769 .56697 .49538 .55451 Metetra
.646 .762 .934 r
.49538 .55451 .50769 .56697 .53002 .56024 .51783 .54768 Metetra
.646 .762 .934 r
.51783 .54768 .53002 .56024 .55254 .55346 .54047 .5408 Metetra
.646 .762 .934 r
.54047 .5408 .55254 .55346 .57524 .54663 .56329 .53386 Metetra
.646 .762 .934 r
.56329 .53386 .57524 .54663 .59812 .53974 .58631 .52687 Metetra
.646 .762 .934 r
.58631 .52687 .59812 .53974 .6212 .53279 .60951 .51981 Metetra
.646 .762 .934 r
.60951 .51981 .6212 .53279 .64447 .52578 .63291 .5127 Metetra
.646 .762 .934 r
.63291 .5127 .64447 .52578 .66793 .51872 .65651 .50552 Metetra
.646 .762 .934 r
.65651 .50552 .66793 .51872 .69159 .5116 .6803 .49829 Metetra
.646 .762 .934 r
.6803 .49829 .69159 .5116 .71545 .50441 .7043 .49099 Metetra
.646 .762 .934 r
.7043 .49099 .71545 .50441 .73951 .49717 .7285 .48363 Metetra
.646 .762 .934 r
.7285 .48363 .73951 .49717 .76378 .48986 .75291 .47621 Metetra
.646 .762 .934 r
.75291 .47621 .76378 .48986 .78825 .48249 .77753 .46872 Metetra
.646 .762 .934 r
.77753 .46872 .78825 .48249 .81293 .47506 .80237 .46117 Metetra
.646 .762 .934 r
.80237 .46117 .81293 .47506 .83782 .46757 .82741 .45356 Metetra
.986 .716 .415 r
.82741 .45356 .83782 .46757 .83981 .23549 .83009 .22065 Metetra
.664 .741 .908 r
.20643 .41871 .21937 .43076 .23828 .42425 .22542 .41211 Metetra
.664 .741 .908 r
.22542 .41211 .23828 .42425 .25733 .4177 .24455 .40547 Metetra
.946 .659 .462 r
.24455 .40547 .25733 .4177 .26001 .62607 .24635 .6145 Metetra
.646 .762 .934 r
.24635 .6145 .26001 .62607 .28057 .61982 .267 .60815 Metetra
.646 .762 .934 r
.267 .60815 .28057 .61982 .30129 .61352 .28782 .60176 Metetra
.646 .762 .934 r
.28782 .60176 .30129 .61352 .32217 .60717 .3088 .59532 Metetra
.646 .762 .934 r
.3088 .59532 .32217 .60717 .34322 .60077 .32995 .58882 Metetra
.646 .762 .934 r
.32995 .58882 .34322 .60077 .36444 .59432 .35127 .58228 Metetra
.646 .762 .934 r
.35127 .58228 .36444 .59432 .38582 .58782 .37277 .57568 Metetra
.646 .762 .934 r
.37277 .57568 .38582 .58782 .40738 .58127 .39443 .56902 Metetra
.646 .762 .934 r
.39443 .56902 .40738 .58127 .42912 .57466 .41628 .56232 Metetra
.646 .762 .934 r
.41628 .56232 .42912 .57466 .45103 .568 .4383 .55556 Metetra
.646 .762 .934 r
.4383 .55556 .45103 .568 .47311 .56128 .4605 .54874 Metetra
.646 .762 .934 r
.4605 .54874 .47311 .56128 .49538 .55451 .48289 .54186 Metetra
.646 .762 .934 r
.48289 .54186 .49538 .55451 .51783 .54768 .50546 .53493 Metetra
.646 .762 .934 r
.50546 .53493 .51783 .54768 .54047 .5408 .52822 .52795 Metetra
.646 .762 .934 r
.52822 .52795 .54047 .5408 .56329 .53386 .55117 .5209 Metetra
.646 .762 .934 r
.55117 .5209 .56329 .53386 .58631 .52687 .57431 .51379 Metetra
.646 .762 .934 r
.57431 .51379 .58631 .52687 .60951 .51981 .59764 .50663 Metetra
.646 .762 .934 r
.59764 .50663 .60951 .51981 .63291 .5127 .62117 .4994 Metetra
.646 .762 .934 r
.62117 .4994 .63291 .5127 .65651 .50552 .6449 .49212 Metetra
.646 .762 .934 r
.6449 .49212 .65651 .50552 .6803 .49829 .66884 .48477 Metetra
.646 .762 .934 r
.66884 .48477 .6803 .49829 .7043 .49099 .69298 .47736 Metetra
.646 .762 .934 r
.69298 .47736 .7043 .49099 .7285 .48363 .71732 .46988 Metetra
.646 .762 .934 r
.71732 .46988 .7285 .48363 .75291 .47621 .74188 .46234 Metetra
.646 .762 .934 r
.74188 .46234 .75291 .47621 .77753 .46872 .76665 .45473 Metetra
.646 .762 .934 r
.76665 .45473 .77753 .46872 .80237 .46117 .79163 .44706 Metetra
.646 .762 .934 r
.79163 .44706 .80237 .46117 .82741 .45356 .81683 .43932 Metetra
.986 .716 .415 r
.81683 .43932 .82741 .45356 .83009 .22065 .82022 .20559 Metetra
.664 .741 .908 r
.19331 .4065 .20643 .41871 .22542 .41211 .21239 .39981 Metetra
.664 .741 .908 r
.21239 .39981 .22542 .41211 .24455 .40547 .2316 .39308 Metetra
.946 .659 .462 r
.2316 .39308 .24455 .40547 .24635 .6145 .23248 .60275 Metetra
.646 .762 .934 r
.23248 .60275 .24635 .6145 .267 .60815 .25323 .59631 Metetra
.646 .762 .934 r
.25323 .59631 .267 .60815 .28782 .60176 .27415 .58983 Metetra
.646 .762 .934 r
.27415 .58983 .28782 .60176 .3088 .59532 .29523 .58329 Metetra
.646 .762 .934 r
.29523 .58329 .3088 .59532 .32995 .58882 .31649 .5767 Metetra
.646 .762 .934 r
.31649 .5767 .32995 .58882 .35127 .58228 .33791 .57005 Metetra
.646 .762 .934 r
.33791 .57005 .35127 .58228 .37277 .57568 .35951 .56335 Metetra
.646 .762 .934 r
.35951 .56335 .37277 .57568 .39443 .56902 .38129 .5566 Metetra
.646 .762 .934 r
.38129 .5566 .39443 .56902 .41628 .56232 .40324 .54979 Metetra
.646 .762 .934 r
.40324 .54979 .41628 .56232 .4383 .55556 .42538 .54293 Metetra
.646 .762 .934 r
.42538 .54293 .4383 .55556 .4605 .54874 .4477 .536 Metetra
.646 .762 .934 r
.4477 .536 .4605 .54874 .48289 .54186 .4702 .52902 Metetra
.646 .762 .934 r
.4702 .52902 .48289 .54186 .50546 .53493 .49289 .52199 Metetra
.646 .762 .934 r
.49289 .52199 .50546 .53493 .52822 .52795 .51578 .51489 Metetra
.646 .762 .934 r
.51578 .51489 .52822 .52795 .55117 .5209 .53885 .50774 Metetra
.646 .762 .934 r
.53885 .50774 .55117 .5209 .57431 .51379 .56212 .50052 Metetra
.646 .762 .934 r
.56212 .50052 .57431 .51379 .59764 .50663 .58559 .49324 Metetra
.646 .762 .934 r
.58559 .49324 .59764 .50663 .62117 .4994 .60925 .4859 Metetra
.646 .762 .934 r
.60925 .4859 .62117 .4994 .6449 .49212 .63312 .4785 Metetra
.646 .762 .934 r
.63312 .4785 .6449 .49212 .66884 .48477 .65719 .47103 Metetra
.646 .762 .934 r
.65719 .47103 .66884 .48477 .69298 .47736 .68147 .4635 Metetra
.646 .762 .934 r
.68147 .4635 .69298 .47736 .71732 .46988 .70596 .45591 Metetra
.646 .762 .934 r
.70596 .45591 .71732 .46988 .74188 .46234 .73067 .44825 Metetra
.646 .762 .934 r
.73067 .44825 .74188 .46234 .76665 .45473 .75559 .44052 Metetra
.646 .762 .934 r
.75559 .44052 .76665 .45473 .79163 .44706 .78072 .43272 Metetra
.646 .762 .934 r
.78072 .43272 .79163 .44706 .81683 .43932 .80608 .42486 Metetra
.986 .716 .415 r
.80608 .42486 .81683 .43932 .82022 .20559 .81021 .1903 Metetra
.664 .741 .908 r
.18002 .39412 .19331 .4065 .21239 .39981 .19917 .38734 Metetra
.664 .741 .908 r
.19917 .38734 .21239 .39981 .2316 .39308 .21847 .38051 Metetra
.946 .659 .462 r
.21847 .38051 .2316 .39308 .23248 .60275 .21841 .59083 Metetra
.646 .762 .934 r
.21841 .59083 .23248 .60275 .25323 .59631 .23926 .5843 Metetra
.646 .762 .934 r
.23926 .5843 .25323 .59631 .27415 .58983 .26028 .57771 Metetra
.646 .762 .934 r
.26028 .57771 .27415 .58983 .29523 .58329 .28146 .57108 Metetra
.646 .762 .934 r
.28146 .57108 .29523 .58329 .31649 .5767 .30282 .56439 Metetra
.646 .762 .934 r
.30282 .56439 .31649 .5767 .33791 .57005 .32435 .55764 Metetra
.646 .762 .934 r
.32435 .55764 .33791 .57005 .35951 .56335 .34606 .55084 Metetra
.646 .762 .934 r
.34606 .55084 .35951 .56335 .38129 .5566 .36795 .54399 Metetra
.646 .762 .934 r
.36795 .54399 .38129 .5566 .40324 .54979 .39001 .53707 Metetra
.646 .762 .934 r
.39001 .53707 .40324 .54979 .42538 .54293 .41226 .5301 Metetra
.646 .762 .934 r
.41226 .5301 .42538 .54293 .4477 .536 .4347 .52307 Metetra
.646 .762 .934 r
.4347 .52307 .4477 .536 .4702 .52902 .45732 .51599 Metetra
.646 .762 .934 r
.45732 .51599 .4702 .52902 .49289 .52199 .48014 .50884 Metetra
.646 .762 .934 r
.48014 .50884 .49289 .52199 .51578 .51489 .50314 .50163 Metetra
.646 .762 .934 r
.50314 .50163 .51578 .51489 .53885 .50774 .52634 .49436 Metetra
.646 .762 .934 r
.52634 .49436 .53885 .50774 .56212 .50052 .54974 .48704 Metetra
.646 .762 .934 r
.54974 .48704 .56212 .50052 .58559 .49324 .57334 .47964 Metetra
.646 .762 .934 r
.57334 .47964 .58559 .49324 .60925 .4859 .59714 .47219 Metetra
.646 .762 .934 r
.59714 .47219 .60925 .4859 .63312 .4785 .62114 .46467 Metetra
.646 .762 .934 r
.62114 .46467 .63312 .4785 .65719 .47103 .64536 .45708 Metetra
.646 .762 .934 r
.64536 .45708 .65719 .47103 .68147 .4635 .66978 .44943 Metetra
.646 .762 .934 r
.66978 .44943 .68147 .4635 .70596 .45591 .69442 .44171 Metetra
.646 .762 .934 r
.69442 .44171 .70596 .45591 .73067 .44825 .71927 .43393 Metetra
.646 .762 .934 r
.71927 .43393 .73067 .44825 .75559 .44052 .74434 .42607 Metetra
.646 .762 .934 r
.74434 .42607 .75559 .44052 .78072 .43272 .76964 .41815 Metetra
.646 .762 .934 r
.76964 .41815 .78072 .43272 .80608 .42486 .79516 .41016 Metetra
.986 .716 .415 r
.79516 .41016 .80608 .42486 .81021 .1903 .80004 .17478 Metetra
.664 .741 .908 r
.16654 .38157 .18002 .39412 .19917 .38734 .18578 .3747 Metetra
.664 .741 .908 r
.18578 .3747 .19917 .38734 .21847 .38051 .20516 .36777 Metetra
.946 .659 .462 r
.20516 .36777 .21847 .38051 .21841 .59083 .20414 .57873 Metetra
.646 .762 .934 r
.20414 .57873 .21841 .59083 .23926 .5843 .22508 .5721 Metetra
.646 .762 .934 r
.22508 .5721 .23926 .5843 .26028 .57771 .2462 .56542 Metetra
.646 .762 .934 r
.2462 .56542 .26028 .57771 .28146 .57108 .26748 .55868 Metetra
.646 .762 .934 r
.26748 .55868 .28146 .57108 .30282 .56439 .28894 .55189 Metetra
.646 .762 .934 r
.28894 .55189 .30282 .56439 .32435 .55764 .31058 .54504 Metetra
.646 .762 .934 r
.31058 .54504 .32435 .55764 .34606 .55084 .3324 .53814 Metetra
.646 .762 .934 r
.3324 .53814 .34606 .55084 .36795 .54399 .3544 .53118 Metetra
.646 .762 .934 r
.3544 .53118 .36795 .54399 .39001 .53707 .37658 .52416 Metetra
.646 .762 .934 r
.37658 .52416 .39001 .53707 .41226 .5301 .39894 .51708 Metetra
.646 .762 .934 r
.39894 .51708 .41226 .5301 .4347 .52307 .4215 .50994 Metetra
.646 .762 .934 r
.4215 .50994 .4347 .52307 .45732 .51599 .44424 .50275 Metetra
.646 .762 .934 r
.44424 .50275 .45732 .51599 .48014 .50884 .46718 .49549 Metetra
.646 .762 .934 r
.46718 .49549 .48014 .50884 .50314 .50163 .49031 .48817 Metetra
.646 .762 .934 r
.49031 .48817 .50314 .50163 .52634 .49436 .51364 .48078 Metetra
.646 .762 .934 r
.51364 .48078 .52634 .49436 .54974 .48704 .53717 .47334 Metetra
.646 .762 .934 r
.53717 .47334 .54974 .48704 .57334 .47964 .5609 .46583 Metetra
.646 .762 .934 r
.5609 .46583 .57334 .47964 .59714 .47219 .58483 .45825 Metetra
.646 .762 .934 r
.58483 .45825 .59714 .47219 .62114 .46467 .60898 .45061 Metetra
.646 .762 .934 r
.60898 .45061 .62114 .46467 .64536 .45708 .63333 .4429 Metetra
.646 .762 .934 r
.63333 .4429 .64536 .45708 .66978 .44943 .6579 .43513 Metetra
.646 .762 .934 r
.6579 .43513 .66978 .44943 .69442 .44171 .68269 .42729 Metetra
.646 .762 .934 r
.68269 .42729 .69442 .44171 .71927 .43393 .70769 .41937 Metetra
.646 .762 .934 r
.70769 .41937 .71927 .43393 .74434 .42607 .73292 .41139 Metetra
.646 .762 .934 r
.73292 .41139 .74434 .42607 .76964 .41815 .75837 .40334 Metetra
.646 .762 .934 r
.75837 .40334 .76964 .41815 .79516 .41016 .78405 .39521 Metetra
.986 .716 .415 r
.78405 .39521 .79516 .41016 .80004 .17478 .78971 .15902 Metetra
.664 .741 .908 r
.15287 .36884 .16654 .38157 .18578 .3747 .17219 .36188 Metetra
.664 .741 .908 r
.17219 .36188 .18578 .3747 .20516 .36777 .19166 .35486 Metetra
.946 .659 .462 r
.19166 .35486 .20516 .36777 .20414 .57873 .18964 .56645 Metetra
.646 .762 .934 r
.18964 .56645 .20414 .57873 .22508 .5721 .21069 .55972 Metetra
.646 .762 .934 r
.21069 .55972 .22508 .5721 .2462 .56542 .2319 .55294 Metetra
.646 .762 .934 r
.2319 .55294 .2462 .56542 .26748 .55868 .25329 .5461 Metetra
.646 .762 .934 r
.25329 .5461 .26748 .55868 .28894 .55189 .27486 .53921 Metetra
.646 .762 .934 r
.27486 .53921 .28894 .55189 .31058 .54504 .2966 .53225 Metetra
.646 .762 .934 r
.2966 .53225 .31058 .54504 .3324 .53814 .31853 .52524 Metetra
.646 .762 .934 r
.31853 .52524 .3324 .53814 .3544 .53118 .34064 .51817 Metetra
.646 .762 .934 r
.34064 .51817 .3544 .53118 .37658 .52416 .36293 .51105 Metetra
.646 .762 .934 r
.36293 .51105 .37658 .52416 .39894 .51708 .38542 .50386 Metetra
.646 .762 .934 r
.38542 .50386 .39894 .51708 .4215 .50994 .40809 .49661 Metetra
.646 .762 .934 r
.40809 .49661 .4215 .50994 .44424 .50275 .43095 .4893 Metetra
.646 .762 .934 r
.43095 .4893 .44424 .50275 .46718 .49549 .45401 .48192 Metetra
.646 .762 .934 r
.45401 .48192 .46718 .49549 .49031 .48817 .47727 .47449 Metetra
.646 .762 .934 r
.47727 .47449 .49031 .48817 .51364 .48078 .50073 .46699 Metetra
.646 .762 .934 r
.50073 .46699 .51364 .48078 .53717 .47334 .52439 .45942 Metetra
.646 .762 .934 r
.52439 .45942 .53717 .47334 .5609 .46583 .54826 .45179 Metetra
.646 .762 .934 r
.54826 .45179 .5609 .46583 .58483 .45825 .57233 .44409 Metetra
.646 .762 .934 r
.57233 .44409 .58483 .45825 .60898 .45061 .59662 .43633 Metetra
.646 .762 .934 r
.59662 .43633 .60898 .45061 .63333 .4429 .62112 .4285 Metetra
.646 .762 .934 r
.62112 .4285 .63333 .4429 .6579 .43513 .64583 .42059 Metetra
.646 .762 .934 r
.64583 .42059 .6579 .43513 .68269 .42729 .67076 .41262 Metetra
.646 .762 .934 r
.67076 .41262 .68269 .42729 .70769 .41937 .69592 .40458 Metetra
.646 .762 .934 r
.69592 .40458 .70769 .41937 .73292 .41139 .7213 .39646 Metetra
.646 .762 .934 r
.7213 .39646 .73292 .41139 .75837 .40334 .74691 .38828 Metetra
.646 .762 .934 r
.74691 .38828 .75837 .40334 .78405 .39521 .77275 .38001 Metetra
.986 .716 .415 r
.77275 .38001 .78405 .39521 .78971 .15902 .77922 .14301 Metetra
.664 .741 .908 r
.13902 .35594 .15287 .36884 .17219 .36188 .15842 .34888 Metetra
.664 .741 .908 r
.15842 .34888 .17219 .36188 .19166 .35486 .17797 .34176 Metetra
.946 .659 .462 r
.17797 .34176 .19166 .35486 .18964 .56645 .17493 .55399 Metetra
.646 .762 .934 r
.17493 .55399 .18964 .56645 .21069 .55972 .19607 .54716 Metetra
.646 .762 .934 r
.19607 .54716 .21069 .55972 .2319 .55294 .21739 .54027 Metetra
.646 .762 .934 r
.21739 .54027 .2319 .55294 .25329 .5461 .23889 .53333 Metetra
.646 .762 .934 r
.23889 .53333 .25329 .5461 .27486 .53921 .26056 .52632 Metetra
.646 .762 .934 r
.26056 .52632 .27486 .53921 .2966 .53225 .28241 .51926 Metetra
.646 .762 .934 r
.28241 .51926 .2966 .53225 .31853 .52524 .30445 .51215 Metetra
.646 .762 .934 r
.30445 .51215 .31853 .52524 .34064 .51817 .32667 .50497 Metetra
.646 .762 .934 r
.32667 .50497 .34064 .51817 .36293 .51105 .34908 .49773 Metetra
.646 .762 .934 r
.34908 .49773 .36293 .51105 .38542 .50386 .37168 .49043 Metetra
.646 .762 .934 r
.37168 .49043 .38542 .50386 .40809 .49661 .39447 .48306 Metetra
.646 .762 .934 r
.39447 .48306 .40809 .49661 .43095 .4893 .41746 .47564 Metetra
.646 .762 .934 r
.41746 .47564 .43095 .4893 .45401 .48192 .44064 .46815 Metetra
.646 .762 .934 r
.44064 .46815 .45401 .48192 .47727 .47449 .46403 .46059 Metetra
.646 .762 .934 r
.46403 .46059 .47727 .47449 .50073 .46699 .48762 .45297 Metetra
.646 .762 .934 r
.48762 .45297 .50073 .46699 .52439 .45942 .51141 .44528 Metetra
.646 .762 .934 r
.51141 .44528 .52439 .45942 .54826 .45179 .53541 .43753 Metetra
.646 .762 .934 r
.53541 .43753 .54826 .45179 .57233 .44409 .55963 .42971 Metetra
.646 .762 .934 r
.55963 .42971 .57233 .44409 .59662 .43633 .58405 .42182 Metetra
.646 .762 .934 r
.58405 .42182 .59662 .43633 .62112 .4285 .6087 .41385 Metetra
.646 .762 .934 r
.6087 .41385 .62112 .4285 .64583 .42059 .63356 .40582 Metetra
.646 .762 .934 r
.63356 .40582 .64583 .42059 .67076 .41262 .65864 .39772 Metetra
.646 .762 .934 r
.65864 .39772 .67076 .41262 .69592 .40458 .68396 .38954 Metetra
.646 .762 .934 r
.68396 .38954 .69592 .40458 .7213 .39646 .70949 .38129 Metetra
.646 .762 .934 r
.70949 .38129 .7213 .39646 .74691 .38828 .73527 .37296 Metetra
.646 .762 .934 r
.73527 .37296 .74691 .38828 .77275 .38001 .76127 .36456 Metetra
.986 .716 .415 r
.76127 .36456 .77275 .38001 .77922 .14301 .76857 .12675 Metetra
.664 .741 .908 r
.12497 .34286 .13902 .35594 .15842 .34888 .14445 .3357 Metetra
.664 .741 .908 r
.14445 .3357 .15842 .34888 .17797 .34176 .16409 .32848 Metetra
.946 .659 .462 r
.16409 .32848 .17797 .34176 .17493 .55399 .16 .54133 Metetra
.646 .762 .934 r
.16 .54133 .17493 .55399 .19607 .54716 .18124 .5344 Metetra
.646 .762 .934 r
.18124 .5344 .19607 .54716 .21739 .54027 .20266 .52741 Metetra
.646 .762 .934 r
.20266 .52741 .21739 .54027 .23889 .53333 .22426 .52035 Metetra
.646 .762 .934 r
.22426 .52035 .23889 .53333 .26056 .52632 .24603 .51324 Metetra
.646 .762 .934 r
.24603 .51324 .26056 .52632 .28241 .51926 .268 .50608 Metetra
.646 .762 .934 r
.268 .50608 .28241 .51926 .30445 .51215 .29014 .49884 Metetra
.646 .762 .934 r
.29014 .49884 .30445 .51215 .32667 .50497 .31248 .49155 Metetra
.646 .762 .934 r
.31248 .49155 .32667 .50497 .34908 .49773 .335 .4842 Metetra
.646 .762 .934 r
.335 .4842 .34908 .49773 .37168 .49043 .35772 .47678 Metetra
.646 .762 .934 r
.35772 .47678 .37168 .49043 .39447 .48306 .38064 .4693 Metetra
.646 .762 .934 r
.38064 .4693 .39447 .48306 .41746 .47564 .40375 .46176 Metetra
.646 .762 .934 r
.40375 .46176 .41746 .47564 .44064 .46815 .42706 .45415 Metetra
.646 .762 .934 r
.42706 .45415 .44064 .46815 .46403 .46059 .45057 .44647 Metetra
.646 .762 .934 r
.45057 .44647 .46403 .46059 .48762 .45297 .47429 .43873 Metetra
.646 .762 .934 r
.47429 .43873 .48762 .45297 .51141 .44528 .49822 .43091 Metetra
.646 .762 .934 r
.49822 .43091 .51141 .44528 .53541 .43753 .52236 .42303 Metetra
.646 .762 .934 r
.52236 .42303 .53541 .43753 .55963 .42971 .54671 .41508 Metetra
.646 .762 .934 r
.54671 .41508 .55963 .42971 .58405 .42182 .57128 .40706 Metetra
.646 .762 .934 r
.57128 .40706 .58405 .42182 .6087 .41385 .59607 .39897 Metetra
.646 .762 .934 r
.59607 .39897 .6087 .41385 .63356 .40582 .62109 .3908 Metetra
.646 .762 .934 r
.62109 .3908 .63356 .40582 .65864 .39772 .64632 .38256 Metetra
.646 .762 .934 r
.64632 .38256 .65864 .39772 .68396 .38954 .67179 .37425 Metetra
.646 .762 .934 r
.67179 .37425 .68396 .38954 .70949 .38129 .69749 .36586 Metetra
.646 .762 .934 r
.69749 .36586 .70949 .38129 .73527 .37296 .72342 .35739 Metetra
.646 .762 .934 r
.72342 .35739 .73527 .37296 .76127 .36456 .74959 .34885 Metetra
.986 .716 .415 r
.74959 .34885 .76127 .36456 .76857 .12675 .75774 .11023 Metetra
.664 .741 .908 r
.11072 .32959 .12497 .34286 .14445 .3357 .13029 .32233 Metetra
.664 .741 .908 r
.13029 .32233 .14445 .3357 .16409 .32848 .15001 .31501 Metetra
.946 .659 .462 r
.15001 .31501 .16409 .32848 .16 .54133 .14483 .52849 Metetra
.646 .762 .934 r
.14483 .52849 .16 .54133 .18124 .5344 .16618 .52144 Metetra
.646 .762 .934 r
.16618 .52144 .18124 .5344 .20266 .52741 .1877 .51434 Metetra
.646 .762 .934 r
.1877 .51434 .20266 .52741 .22426 .52035 .2094 .50718 Metetra
.646 .762 .934 r
.2094 .50718 .22426 .52035 .24603 .51324 .23129 .49996 Metetra
.646 .762 .934 r
.23129 .49996 .24603 .51324 .268 .50608 .25336 .49268 Metetra
.646 .762 .934 r
.25336 .49268 .268 .50608 .29014 .49884 .27562 .48533 Metetra
.646 .762 .934 r
.27562 .48533 .29014 .49884 .31248 .49155 .29806 .47793 Metetra
.646 .762 .934 r
.29806 .47793 .31248 .49155 .335 .4842 .32071 .47046 Metetra
.646 .762 .934 r
.32071 .47046 .335 .4842 .35772 .47678 .34354 .46292 Metetra
.646 .762 .934 r
.34354 .46292 .35772 .47678 .38064 .4693 .36658 .45532 Metetra
.646 .762 .934 r
.36658 .45532 .38064 .4693 .40375 .46176 .38981 .44766 Metetra
.646 .762 .934 r
.38981 .44766 .40375 .46176 .42706 .45415 .41325 .43992 Metetra
.646 .762 .934 r
.41325 .43992 .42706 .45415 .45057 .44647 .4369 .43212 Metetra
.646 .762 .934 r
.4369 .43212 .45057 .44647 .47429 .43873 .46075 .42425 Metetra
.646 .762 .934 r
.46075 .42425 .47429 .43873 .49822 .43091 .48481 .41631 Metetra
.646 .762 .934 r
.48481 .41631 .49822 .43091 .52236 .42303 .50909 .4083 Metetra
.646 .762 .934 r
.50909 .4083 .52236 .42303 .54671 .41508 .53359 .40022 Metetra
.646 .762 .934 r
.53359 .40022 .54671 .41508 .57128 .40706 .5583 .39206 Metetra
.646 .762 .934 r
.5583 .39206 .57128 .40706 .59607 .39897 .58324 .38384 Metetra
.646 .762 .934 r
.58324 .38384 .59607 .39897 .62109 .3908 .6084 .37553 Metetra
.646 .762 .934 r
.6084 .37553 .62109 .3908 .64632 .38256 .63379 .36716 Metetra
.646 .762 .934 r
.63379 .36716 .64632 .38256 .67179 .37425 .65942 .3587 Metetra
.646 .762 .934 r
.65942 .3587 .67179 .37425 .69749 .36586 .68528 .35017 Metetra
.646 .762 .934 r
.68528 .35017 .69749 .36586 .72342 .35739 .71138 .34156 Metetra
.646 .762 .934 r
.71138 .34156 .72342 .35739 .74959 .34885 .73771 .33287 Metetra
.986 .716 .415 r
.73771 .33287 .74959 .34885 .75774 .11023 .74675 .09346 Metetra
.664 .741 .908 r
.09627 .31614 .11072 .32959 .13029 .32233 .11592 .30877 Metetra
.664 .741 .908 r
.11592 .30877 .13029 .32233 .15001 .31501 .13573 .30134 Metetra
.946 .659 .462 r
.13573 .30134 .15001 .31501 .14483 .52849 .12944 .51544 Metetra
.646 .762 .934 r
.12944 .51544 .14483 .52849 .16618 .52144 .15088 .50829 Metetra
.646 .762 .934 r
.15088 .50829 .16618 .52144 .1877 .51434 .1725 .50108 Metetra
.646 .762 .934 r
.1725 .50108 .1877 .51434 .2094 .50718 .19431 .4938 Metetra
.646 .762 .934 r
.19431 .4938 .2094 .50718 .23129 .49996 .2163 .48647 Metetra
.646 .762 .934 r
.2163 .48647 .23129 .49996 .25336 .49268 .23849 .47907 Metetra
.646 .762 .934 r
.23849 .47907 .25336 .49268 .27562 .48533 .26086 .47161 Metetra
.646 .762 .934 r
.26086 .47161 .27562 .48533 .29806 .47793 .28342 .46409 Metetra
.646 .762 .934 r
.28342 .46409 .29806 .47793 .32071 .47046 .30618 .4565 Metetra
.646 .762 .934 r
.30618 .4565 .32071 .47046 .34354 .46292 .32914 .44884 Metetra
.646 .762 .934 r
.32914 .44884 .34354 .46292 .36658 .45532 .3523 .44112 Metetra
.646 .762 .934 r
.3523 .44112 .36658 .45532 .38981 .44766 .37566 .43333 Metetra
.646 .762 .934 r
.37566 .43333 .38981 .44766 .41325 .43992 .39922 .42547 Metetra
.646 .762 .934 r
.39922 .42547 .41325 .43992 .4369 .43212 .423 .41754 Metetra
.646 .762 .934 r
.423 .41754 .4369 .43212 .46075 .42425 .44699 .40954 Metetra
.646 .762 .934 r
.44699 .40954 .46075 .42425 .48481 .41631 .47119 .40147 Metetra
.646 .762 .934 r
.47119 .40147 .48481 .41631 .50909 .4083 .4956 .39332 Metetra
.646 .762 .934 r
.4956 .39332 .50909 .4083 .53359 .40022 .52024 .38511 Metetra
.646 .762 .934 r
.52024 .38511 .53359 .40022 .5583 .39206 .5451 .37682 Metetra
.646 .762 .934 r
.5451 .37682 .5583 .39206 .58324 .38384 .57019 .36845 Metetra
.646 .762 .934 r
.57019 .36845 .58324 .38384 .6084 .37553 .59551 .36001 Metetra
.646 .762 .934 r
.59551 .36001 .6084 .37553 .63379 .36716 .62105 .35149 Metetra
.646 .762 .934 r
.62105 .35149 .63379 .36716 .65942 .3587 .64684 .34289 Metetra
.646 .762 .934 r
.64684 .34289 .65942 .3587 .68528 .35017 .67286 .33421 Metetra
.646 .762 .934 r
.67286 .33421 .68528 .35017 .71138 .34156 .69912 .32545 Metetra
.646 .762 .934 r
.69912 .32545 .71138 .34156 .73771 .33287 .72563 .31661 Metetra
.986 .716 .415 r
.72563 .31661 .73771 .33287 .74675 .09346 .73558 .07641 Metetra
.664 .741 .908 r
.08161 .30249 .09627 .31614 .11592 .30877 .10134 .29501 Metetra
.664 .741 .908 r
.10134 .29501 .11592 .30877 .13573 .30134 .12124 .28747 Metetra
.946 .659 .462 r
.12124 .28747 .13573 .30134 .12944 .51544 .1138 .50219 Metetra
.646 .762 .934 r
.1138 .50219 .12944 .51544 .15088 .50829 .13534 .49493 Metetra
.646 .762 .934 r
.13534 .49493 .15088 .50829 .1725 .50108 .15707 .4876 Metetra
.646 .762 .934 r
.15707 .4876 .1725 .50108 .19431 .4938 .17898 .48021 Metetra
.646 .762 .934 r
.17898 .48021 .19431 .4938 .2163 .48647 .20109 .47276 Metetra
.646 .762 .934 r
.20109 .47276 .2163 .48647 .23849 .47907 .22338 .46525 Metetra
.646 .762 .934 r
.22338 .46525 .23849 .47907 .26086 .47161 .24586 .45767 Metetra
.646 .762 .934 r
.24586 .45767 .26086 .47161 .28342 .46409 .26854 .45002 Metetra
.646 .762 .934 r
.26854 .45002 .28342 .46409 .30618 .4565 .29142 .44231 Metetra
.646 .762 .934 r
.29142 .44231 .30618 .4565 .32914 .44884 .3145 .43453 Metetra
.646 .762 .934 r
.3145 .43453 .32914 .44884 .3523 .44112 .33778 .42668 Metetra
.646 .762 .934 r
.33778 .42668 .3523 .44112 .37566 .43333 .36127 .41876 Metetra
.646 .762 .934 r
.36127 .41876 .37566 .43333 .39922 .42547 .38497 .41077 Metetra
.646 .762 .934 r
.38497 .41077 .39922 .42547 .423 .41754 .40887 .40271 Metetra
.646 .762 .934 r
.40887 .40271 .423 .41754 .44699 .40954 .43299 .39458 Metetra
.646 .762 .934 r
.43299 .39458 .44699 .40954 .47119 .40147 .45733 .38638 Metetra
.646 .762 .934 r
.45733 .38638 .47119 .40147 .4956 .39332 .48189 .3781 Metetra
.646 .762 .934 r
.48189 .3781 .4956 .39332 .52024 .38511 .50667 .36974 Metetra
.646 .762 .934 r
.50667 .36974 .52024 .38511 .5451 .37682 .53168 .36131 Metetra
.646 .762 .934 r
.53168 .36131 .5451 .37682 .57019 .36845 .55692 .3528 Metetra
.646 .762 .934 r
.55692 .3528 .57019 .36845 .59551 .36001 .58239 .34422 Metetra
.646 .762 .934 r
.58239 .34422 .59551 .36001 .62105 .35149 .60809 .33555 Metetra
.646 .762 .934 r
.60809 .33555 .62105 .35149 .64684 .34289 .63404 .3268 Metetra
.646 .762 .934 r
.63404 .3268 .64684 .34289 .67286 .33421 .66023 .31798 Metetra
.646 .762 .934 r
.66023 .31798 .67286 .33421 .69912 .32545 .68666 .30907 Metetra
.646 .762 .934 r
.68666 .30907 .69912 .32545 .72563 .31661 .71334 .30007 Metetra
.986 .716 .415 r
.71334 .30007 .72563 .31661 .73558 .07641 .72423 .05908 Metetra
.664 .741 .908 r
.06673 .28864 .08161 .30249 .10134 .29501 .08656 .28105 Metetra
.664 .741 .908 r
.08656 .28105 .10134 .29501 .12124 .28747 .10654 .27341 Metetra
.664 .741 .908 r
.10654 .27341 .12124 .28747 .1138 .50219 .12667 .2657 Metetra
.528 .317 .537 r
.12667 .2657 .1138 .50219 .13534 .49493 .14697 .25794 Metetra
.528 .317 .537 r
.14697 .25794 .13534 .49493 .15707 .4876 .16743 .25011 Metetra
.528 .317 .537 r
.16743 .25011 .15707 .4876 .17898 .48021 .18805 .24222 Metetra
.528 .317 .537 r
.18805 .24222 .17898 .48021 .20109 .47276 .20884 .23426 Metetra
.528 .317 .537 r
.20884 .23426 .20109 .47276 .22338 .46525 .2298 .22624 Metetra
.528 .317 .537 r
.2298 .22624 .22338 .46525 .24586 .45767 .25093 .21816 Metetra
.528 .317 .537 r
.25093 .21816 .24586 .45767 .26854 .45002 .27223 .21001 Metetra
.528 .317 .537 r
.27223 .21001 .26854 .45002 .29142 .44231 .2937 .20179 Metetra
.528 .317 .537 r
.2937 .20179 .29142 .44231 .3145 .43453 .31536 .19351 Metetra
.528 .317 .537 r
.31536 .19351 .3145 .43453 .33778 .42668 .33719 .18516 Metetra
.528 .317 .537 r
.33719 .18516 .33778 .42668 .36127 .41876 .3592 .17673 Metetra
.528 .317 .537 r
.3592 .17673 .36127 .41876 .38497 .41077 .38139 .16824 Metetra
.528 .317 .537 r
.38139 .16824 .38497 .41077 .40887 .40271 .40377 .15968 Metetra
.528 .317 .537 r
.40377 .15968 .40887 .40271 .43299 .39458 .42634 .15104 Metetra
.528 .317 .537 r
.42634 .15104 .43299 .39458 .45733 .38638 .44909 .14234 Metetra
.528 .317 .537 r
.44909 .14234 .45733 .38638 .48189 .3781 .47204 .13356 Metetra
.528 .317 .537 r
.47204 .13356 .48189 .3781 .50667 .36974 .49519 .1247 Metetra
.528 .317 .537 r
.49519 .1247 .50667 .36974 .53168 .36131 .51853 .11577 Metetra
.528 .317 .537 r
.51853 .11577 .53168 .36131 .55692 .3528 .54207 .10676 Metetra
.528 .317 .537 r
.54207 .10676 .55692 .3528 .58239 .34422 .56582 .09768 Metetra
.528 .317 .537 r
.56582 .09768 .58239 .34422 .60809 .33555 .58977 .08851 Metetra
.528 .317 .537 r
.58977 .08851 .60809 .33555 .63404 .3268 .61393 .07927 Metetra
.528 .317 .537 r
.61393 .07927 .63404 .3268 .66023 .31798 .6383 .06994 Metetra
.528 .317 .537 r
.6383 .06994 .66023 .31798 .68666 .30907 .66288 .06054 Metetra
.528 .317 .537 r
.66288 .06054 .68666 .30907 .71334 .30007 .68768 .05105 Metetra
.528 .317 .537 r
.68768 .05105 .71334 .30007 .72423 .05908 .71269 .04148 Metetra
.664 .741 .908 r
.05165 .27459 .06673 .28864 .08656 .28105 .07155 .26689 Metetra
.664 .741 .908 r
.07155 .26689 .08656 .28105 .10654 .27341 .09162 .25914 Metetra
.664 .741 .908 r
.09162 .25914 .10654 .27341 .12667 .2657 .11185 .25132 Metetra
.664 .741 .908 r
.11185 .25132 .12667 .2657 .14697 .25794 .13223 .24344 Metetra
.664 .741 .908 r
.13223 .24344 .14697 .25794 .16743 .25011 .15279 .23549 Metetra
.664 .741 .908 r
.15279 .23549 .16743 .25011 .18805 .24222 .1735 .22748 Metetra
.664 .741 .908 r
.1735 .22748 .18805 .24222 .20884 .23426 .19439 .21941 Metetra
.664 .741 .908 r
.19439 .21941 .20884 .23426 .2298 .22624 .21545 .21127 Metetra
.664 .741 .908 r
.21545 .21127 .2298 .22624 .25093 .21816 .23668 .20306 Metetra
.664 .741 .908 r
.23668 .20306 .25093 .21816 .27223 .21001 .25808 .19479 Metetra
.664 .741 .908 r
.25808 .19479 .27223 .21001 .2937 .20179 .27966 .18645 Metetra
.664 .741 .908 r
.27966 .18645 .2937 .20179 .31536 .19351 .30142 .17803 Metetra
.664 .741 .908 r
.30142 .17803 .31536 .19351 .33719 .18516 .32336 .16955 Metetra
.664 .741 .908 r
.32336 .16955 .33719 .18516 .3592 .17673 .34548 .161 Metetra
.664 .741 .908 r
.34548 .161 .3592 .17673 .38139 .16824 .36779 .15238 Metetra
.664 .741 .908 r
.36779 .15238 .38139 .16824 .40377 .15968 .39028 .14368 Metetra
.664 .741 .908 r
.39028 .14368 .40377 .15968 .42634 .15104 .41297 .13491 Metetra
.664 .741 .908 r
.41297 .13491 .42634 .15104 .44909 .14234 .43585 .12607 Metetra
.664 .741 .908 r
.43585 .12607 .44909 .14234 .47204 .13356 .45892 .11715 Metetra
.664 .741 .908 r
.45892 .11715 .47204 .13356 .49519 .1247 .48219 .10815 Metetra
.664 .741 .908 r
.48219 .10815 .49519 .1247 .51853 .11577 .50567 .09908 Metetra
.664 .741 .908 r
.50567 .09908 .51853 .11577 .54207 .10676 .52934 .08993 Metetra
.664 .741 .908 r
.52934 .08993 .54207 .10676 .56582 .09768 .55322 .08069 Metetra
.664 .741 .908 r
.55322 .08069 .56582 .09768 .58977 .08851 .57731 .07138 Metetra
.664 .741 .908 r
.57731 .07138 .58977 .08851 .61393 .07927 .60161 .06199 Metetra
.664 .741 .908 r
.60161 .06199 .61393 .07927 .6383 .06994 .62612 .05251 Metetra
.664 .741 .908 r
.62612 .05251 .6383 .06994 .66288 .06054 .65085 .04295 Metetra
.664 .741 .908 r
.65085 .04295 .66288 .06054 .68768 .05105 .6758 .03331 Metetra
.664 .741 .908 r
.6758 .03331 .68768 .05105 .71269 .04148 .70097 .02358 Metetra
.664 .741 .908 r
.03634 .26033 .05165 .27459 .07155 .26689 .05633 .25252 Metetra
.664 .741 .908 r
.05633 .25252 .07155 .26689 .09162 .25914 .07648 .24465 Metetra
.664 .741 .908 r
.07648 .24465 .09162 .25914 .11185 .25132 .0968 .23672 Metetra
.664 .741 .908 r
.0968 .23672 .11185 .25132 .13223 .24344 .11728 .22872 Metetra
.664 .741 .908 r
.11728 .22872 .13223 .24344 .15279 .23549 .13792 .22065 Metetra
.664 .741 .908 r
.13792 .22065 .15279 .23549 .1735 .22748 .15874 .21252 Metetra
.664 .741 .908 r
.15874 .21252 .1735 .22748 .19439 .21941 .17972 .20433 Metetra
.664 .741 .908 r
.17972 .20433 .19439 .21941 .21545 .21127 .20088 .19607 Metetra
.664 .741 .908 r
.20088 .19607 .21545 .21127 .23668 .20306 .22221 .18773 Metetra
.664 .741 .908 r
.22221 .18773 .23668 .20306 .25808 .19479 .24371 .17933 Metetra
.664 .741 .908 r
.24371 .17933 .25808 .19479 .27966 .18645 .2654 .17086 Metetra
.664 .741 .908 r
.2654 .17086 .27966 .18645 .30142 .17803 .28727 .16232 Metetra
.664 .741 .908 r
.28727 .16232 .30142 .17803 .32336 .16955 .30932 .15371 Metetra
.664 .741 .908 r
.30932 .15371 .32336 .16955 .34548 .161 .33155 .14502 Metetra
.664 .741 .908 r
.33155 .14502 .34548 .161 .36779 .15238 .35397 .13627 Metetra
.664 .741 .908 r
.35397 .13627 .36779 .15238 .39028 .14368 .37659 .12743 Metetra
.664 .741 .908 r
.37659 .12743 .39028 .14368 .41297 .13491 .39939 .11852 Metetra
.664 .741 .908 r
.39939 .11852 .41297 .13491 .43585 .12607 .4224 .10954 Metetra
.664 .741 .908 r
.4224 .10954 .43585 .12607 .45892 .11715 .44559 .10048 Metetra
.664 .741 .908 r
.44559 .10048 .45892 .11715 .48219 .10815 .46899 .09134 Metetra
.664 .741 .908 r
.46899 .09134 .48219 .10815 .50567 .09908 .4926 .08212 Metetra
.664 .741 .908 r
.4926 .08212 .50567 .09908 .52934 .08993 .51641 .07282 Metetra
.664 .741 .908 r
.51641 .07282 .52934 .08993 .55322 .08069 .54042 .06344 Metetra
.664 .741 .908 r
.54042 .06344 .55322 .08069 .57731 .07138 .56465 .05398 Metetra
.664 .741 .908 r
.56465 .05398 .57731 .07138 .60161 .06199 .58909 .04443 Metetra
.664 .741 .908 r
.58909 .04443 .60161 .06199 .62612 .05251 .61375 .0348 Metetra
.664 .741 .908 r
.61375 .0348 .62612 .05251 .65085 .04295 .63862 .02508 Metetra
.664 .741 .908 r
.63862 .02508 .65085 .04295 .6758 .03331 .66372 .01528 Metetra
.664 .741 .908 r
.66372 .01528 .6758 .03331 .70097 .02358 .68905 .00539 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],

Cell[TextData[{
  "We plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((I)\)\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S1.5.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.4", "4.14"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[phi[x] psi[y]], {x, -0.1, 1},
{y, -0.1, 1}, PlotPoints -> 30, PlotRange -> All,
Boxed -> False, Axes -> False];\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
8.83083e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.656 .751 .92 r
.39082 .69236 .40169 .70185 .41987 .69673 .40908 .68717 Metetra
.656 .751 .92 r
.40908 .68717 .41987 .69673 .43818 .69156 .42746 .68194 Metetra
.924 .72 .609 r
.42746 .68194 .43818 .69156 .45661 .68637 .44821 .57767 Metetra
.594 .42 .616 r
.44821 .57767 .45661 .68637 .47517 .68114 .46632 .57219 Metetra
.594 .42 .616 r
.46632 .57219 .47517 .68114 .49385 .67587 .48456 .56668 Metetra
.594 .42 .616 r
.48456 .56668 .49385 .67587 .51267 .67056 .50292 .56112 Metetra
.594 .42 .616 r
.50292 .56112 .51267 .67056 .53161 .66522 .52141 .55553 Metetra
.594 .42 .616 r
.52141 .55553 .53161 .66522 .55068 .65984 .54002 .5499 Metetra
.594 .42 .616 r
.54002 .5499 .55068 .65984 .56989 .65443 .55875 .54424 Metetra
.594 .42 .616 r
.55875 .54424 .56989 .65443 .58923 .64898 .57762 .53853 Metetra
.594 .42 .616 r
.57762 .53853 .58923 .64898 .60871 .64349 .59661 .53279 Metetra
.594 .42 .616 r
.59661 .53279 .60871 .64349 .62832 .63796 .61573 .52701 Metetra
.594 .42 .616 r
.61573 .52701 .62832 .63796 .64807 .63239 .63499 .52118 Metetra
.594 .42 .616 r
.63499 .52118 .64807 .63239 .66796 .62678 .65438 .51532 Metetra
.594 .42 .616 r
.65438 .51532 .66796 .62678 .688 .62113 .6739 .50942 Metetra
.594 .42 .616 r
.6739 .50942 .688 .62113 .70817 .61544 .69356 .50347 Metetra
.594 .42 .616 r
.69356 .50347 .70817 .61544 .72849 .60972 .71336 .49748 Metetra
.594 .42 .616 r
.71336 .49748 .72849 .60972 .74896 .60395 .73329 .49146 Metetra
.594 .42 .616 r
.73329 .49146 .74896 .60395 .76957 .59813 .75337 .48538 Metetra
.594 .42 .616 r
.75337 .48538 .76957 .59813 .79033 .59228 .77358 .47927 Metetra
.594 .42 .616 r
.77358 .47927 .79033 .59228 .81124 .58638 .79394 .47311 Metetra
.594 .42 .616 r
.79394 .47311 .81124 .58638 .83231 .58045 .81445 .46691 Metetra
.594 .42 .616 r
.81445 .46691 .83231 .58045 .85352 .57446 .8351 .46067 Metetra
.594 .42 .616 r
.8351 .46067 .85352 .57446 .8749 .56844 .8559 .45438 Metetra
.594 .42 .616 r
.8559 .45438 .8749 .56844 .89643 .56237 .87685 .44804 Metetra
.594 .42 .616 r
.87685 .44804 .89643 .56237 .91812 .55625 .89795 .44166 Metetra
.594 .42 .616 r
.89795 .44166 .91812 .55625 .93997 .55009 .9192 .43523 Metetra
.594 .42 .616 r
.9192 .43523 .93997 .55009 .96198 .54388 .94061 .42876 Metetra
.272 .203 .594 r
.94061 .42876 .96198 .54388 .98416 .53763 .97615 .52596 Metetra
.656 .751 .92 r
.3798 .68275 .39082 .69236 .40908 .68717 .39814 .67749 Metetra
.656 .751 .92 r
.39814 .67749 .40908 .68717 .42746 .68194 .41661 .6722 Metetra
.924 .72 .609 r
.41661 .6722 .42746 .68194 .44821 .57767 .43775 .56753 Metetra
.664 .741 .908 r
.43775 .56753 .44821 .57767 .46632 .57219 .45595 .56198 Metetra
.664 .741 .908 r
.45595 .56198 .46632 .57219 .48456 .56668 .47426 .5564 Metetra
.664 .741 .908 r
.47426 .5564 .48456 .56668 .50292 .56112 .4927 .55077 Metetra
.664 .741 .908 r
.4927 .55077 .50292 .56112 .52141 .55553 .51127 .54511 Metetra
.664 .741 .908 r
.51127 .54511 .52141 .55553 .54002 .5499 .52996 .53941 Metetra
.664 .741 .908 r
.52996 .53941 .54002 .5499 .55875 .54424 .54878 .53368 Metetra
.664 .741 .908 r
.54878 .53368 .55875 .54424 .57762 .53853 .56773 .5279 Metetra
.664 .741 .908 r
.56773 .5279 .57762 .53853 .59661 .53279 .58681 .52208 Metetra
.664 .741 .908 r
.58681 .52208 .59661 .53279 .61573 .52701 .60602 .51622 Metetra
.664 .741 .908 r
.60602 .51622 .61573 .52701 .63499 .52118 .62537 .51033 Metetra
.664 .741 .908 r
.62537 .51033 .63499 .52118 .65438 .51532 .64485 .50439 Metetra
.664 .741 .908 r
.64485 .50439 .65438 .51532 .6739 .50942 .66446 .49841 Metetra
.664 .741 .908 r
.66446 .49841 .6739 .50942 .69356 .50347 .68422 .49239 Metetra
.664 .741 .908 r
.68422 .49239 .69356 .50347 .71336 .49748 .70411 .48632 Metetra
.664 .741 .908 r
.70411 .48632 .71336 .49748 .73329 .49146 .72414 .48021 Metetra
.664 .741 .908 r
.72414 .48021 .73329 .49146 .75337 .48538 .74431 .47406 Metetra
.664 .741 .908 r
.74431 .47406 .75337 .48538 .77358 .47927 .76463 .46787 Metetra
.664 .741 .908 r
.76463 .46787 .77358 .47927 .79394 .47311 .78509 .46163 Metetra
.664 .741 .908 r
.78509 .46163 .79394 .47311 .81445 .46691 .8057 .45535 Metetra
.664 .741 .908 r
.8057 .45535 .81445 .46691 .8351 .46067 .82646 .44902 Metetra
.664 .741 .908 r
.82646 .44902 .8351 .46067 .8559 .45438 .84737 .44265 Metetra
.664 .741 .908 r
.84737 .44265 .8559 .45438 .87685 .44804 .86842 .43623 Metetra
.664 .741 .908 r
.86842 .43623 .87685 .44804 .89795 .44166 .88963 .42976 Metetra
.664 .741 .908 r
.88963 .42976 .89795 .44166 .9192 .43523 .911 .42325 Metetra
.664 .741 .908 r
.911 .42325 .9192 .43523 .94061 .42876 .93252 .41668 Metetra
.869 .479 .007 r
.93252 .41668 .94061 .42876 .97615 .52596 .96802 .51413 Metetra
.656 .751 .92 r
.36865 .67302 .3798 .68275 .39814 .67749 .38707 .66769 Metetra
.656 .751 .92 r
.38707 .66769 .39814 .67749 .41661 .6722 .40561 .66233 Metetra
.924 .72 .609 r
.40561 .66233 .41661 .6722 .43775 .56753 .42717 .55726 Metetra
.664 .741 .908 r
.42717 .55726 .43775 .56753 .45595 .56198 .44544 .55164 Metetra
.664 .741 .908 r
.44544 .55164 .45595 .56198 .47426 .5564 .46383 .54599 Metetra
.664 .741 .908 r
.46383 .54599 .47426 .5564 .4927 .55077 .48236 .54029 Metetra
.664 .741 .908 r
.48236 .54029 .4927 .55077 .51127 .54511 .501 .53456 Metetra
.664 .741 .908 r
.501 .53456 .51127 .54511 .52996 .53941 .51978 .52879 Metetra
.664 .741 .908 r
.51978 .52879 .52996 .53941 .54878 .53368 .53868 .52298 Metetra
.664 .741 .908 r
.53868 .52298 .54878 .53368 .56773 .5279 .55772 .51713 Metetra
.664 .741 .908 r
.55772 .51713 .56773 .5279 .58681 .52208 .57689 .51124 Metetra
.664 .741 .908 r
.57689 .51124 .58681 .52208 .60602 .51622 .59619 .5053 Metetra
.664 .741 .908 r
.59619 .5053 .60602 .51622 .62537 .51033 .61562 .49933 Metetra
.664 .741 .908 r
.61562 .49933 .62537 .51033 .64485 .50439 .63519 .49331 Metetra
.664 .741 .908 r
.63519 .49331 .64485 .50439 .66446 .49841 .6549 .48726 Metetra
.664 .741 .908 r
.6549 .48726 .66446 .49841 .68422 .49239 .67475 .48116 Metetra
.664 .741 .908 r
.67475 .48116 .68422 .49239 .70411 .48632 .69474 .47501 Metetra
.664 .741 .908 r
.69474 .47501 .70411 .48632 .72414 .48021 .71487 .46882 Metetra
.664 .741 .908 r
.71487 .46882 .72414 .48021 .74431 .47406 .73514 .46259 Metetra
.664 .741 .908 r
.73514 .46259 .74431 .47406 .76463 .46787 .75556 .45632 Metetra
.664 .741 .908 r
.75556 .45632 .76463 .46787 .78509 .46163 .77613 .45 Metetra
.664 .741 .908 r
.77613 .45 .78509 .46163 .8057 .45535 .79684 .44363 Metetra
.664 .741 .908 r
.79684 .44363 .8057 .45535 .82646 .44902 .8177 .43722 Metetra
.664 .741 .908 r
.8177 .43722 .82646 .44902 .84737 .44265 .83872 .43076 Metetra
.664 .741 .908 r
.83872 .43076 .84737 .44265 .86842 .43623 .85989 .42425 Metetra
.664 .741 .908 r
.85989 .42425 .86842 .43623 .88963 .42976 .88121 .4177 Metetra
.664 .741 .908 r
.88121 .4177 .88963 .42976 .911 .42325 .90269 .41109 Metetra
.664 .741 .908 r
.90269 .41109 .911 .42325 .93252 .41668 .92432 .40444 Metetra
.869 .479 .007 r
.92432 .40444 .93252 .41668 .96802 .51413 .95977 .50214 Metetra
.656 .751 .92 r
.35736 .66316 .36865 .67302 .38707 .66769 .37585 .65777 Metetra
.656 .751 .92 r
.37585 .65777 .38707 .66769 .40561 .66233 .39448 .65234 Metetra
.924 .72 .609 r
.39448 .65234 .40561 .66233 .42717 .55726 .41645 .54686 Metetra
.664 .741 .908 r
.41645 .54686 .42717 .55726 .44544 .55164 .4348 .54117 Metetra
.664 .741 .908 r
.4348 .54117 .44544 .55164 .46383 .54599 .45328 .53545 Metetra
.664 .741 .908 r
.45328 .53545 .46383 .54599 .48236 .54029 .47188 .52968 Metetra
.664 .741 .908 r
.47188 .52968 .48236 .54029 .501 .53456 .49061 .52388 Metetra
.664 .741 .908 r
.49061 .52388 .501 .53456 .51978 .52879 .50947 .51803 Metetra
.664 .741 .908 r
.50947 .51803 .51978 .52879 .53868 .52298 .52846 .51215 Metetra
.664 .741 .908 r
.52846 .51215 .53868 .52298 .55772 .51713 .54758 .50622 Metetra
.664 .741 .908 r
.54758 .50622 .55772 .51713 .57689 .51124 .56683 .50025 Metetra
.664 .741 .908 r
.56683 .50025 .57689 .51124 .59619 .5053 .58622 .49424 Metetra
.664 .741 .908 r
.58622 .49424 .59619 .5053 .61562 .49933 .60575 .48819 Metetra
.664 .741 .908 r
.60575 .48819 .61562 .49933 .63519 .49331 .62542 .4821 Metetra
.664 .741 .908 r
.62542 .4821 .63519 .49331 .6549 .48726 .64522 .47596 Metetra
.664 .741 .908 r
.64522 .47596 .6549 .48726 .67475 .48116 .66516 .46978 Metetra
.664 .741 .908 r
.66516 .46978 .67475 .48116 .69474 .47501 .68525 .46355 Metetra
.664 .741 .908 r
.68525 .46355 .69474 .47501 .71487 .46882 .70548 .45729 Metetra
.664 .741 .908 r
.70548 .45729 .71487 .46882 .73514 .46259 .72585 .45097 Metetra
.664 .741 .908 r
.72585 .45097 .73514 .46259 .75556 .45632 .74637 .44461 Metetra
.664 .741 .908 r
.74637 .44461 .75556 .45632 .77613 .45 .76704 .43821 Metetra
.664 .741 .908 r
.76704 .43821 .77613 .45 .79684 .44363 .78786 .43175 Metetra
.664 .741 .908 r
.78786 .43175 .79684 .44363 .8177 .43722 .80883 .42525 Metetra
.664 .741 .908 r
.80883 .42525 .8177 .43722 .83872 .43076 .82995 .41871 Metetra
.664 .741 .908 r
.82995 .41871 .83872 .43076 .85989 .42425 .85123 .41211 Metetra
.664 .741 .908 r
.85123 .41211 .85989 .42425 .88121 .4177 .87267 .40547 Metetra
.664 .741 .908 r
.87267 .40547 .88121 .4177 .90269 .41109 .89426 .39878 Metetra
.664 .741 .908 r
.89426 .39878 .90269 .41109 .92432 .40444 .91601 .39204 Metetra
.869 .479 .007 r
.91601 .39204 .92432 .40444 .95977 .50214 .95141 .48997 Metetra
.656 .751 .92 r
.34592 .65317 .35736 .66316 .37585 .65777 .36449 .64771 Metetra
.656 .751 .92 r
.36449 .64771 .37585 .65777 .39448 .65234 .3832 .64221 Metetra
.924 .72 .609 r
.3832 .64221 .39448 .65234 .41645 .54686 .4056 .53633 Metetra
.664 .741 .908 r
.4056 .53633 .41645 .54686 .4348 .54117 .42403 .53057 Metetra
.664 .741 .908 r
.42403 .53057 .4348 .54117 .45328 .53545 .44258 .52477 Metetra
.664 .741 .908 r
.44258 .52477 .45328 .53545 .47188 .52968 .46127 .51893 Metetra
.664 .741 .908 r
.46127 .51893 .47188 .52968 .49061 .52388 .48008 .51305 Metetra
.664 .741 .908 r
.48008 .51305 .49061 .52388 .50947 .51803 .49902 .50713 Metetra
.664 .741 .908 r
.49902 .50713 .50947 .51803 .52846 .51215 .5181 .50117 Metetra
.664 .741 .908 r
.5181 .50117 .52846 .51215 .54758 .50622 .53731 .49517 Metetra
.664 .741 .908 r
.53731 .49517 .54758 .50622 .56683 .50025 .55665 .48913 Metetra
.664 .741 .908 r
.55665 .48913 .56683 .50025 .58622 .49424 .57613 .48304 Metetra
.664 .741 .908 r
.57613 .48304 .58622 .49424 .60575 .48819 .59575 .47691 Metetra
.664 .741 .908 r
.59575 .47691 .60575 .48819 .62542 .4821 .61551 .47073 Metetra
.664 .741 .908 r
.61551 .47073 .62542 .4821 .64522 .47596 .63541 .46452 Metetra
.664 .741 .908 r
.63541 .46452 .64522 .47596 .66516 .46978 .65545 .45825 Metetra
.664 .741 .908 r
.65545 .45825 .66516 .46978 .68525 .46355 .67563 .45195 Metetra
.664 .741 .908 r
.67563 .45195 .68525 .46355 .70548 .45729 .69596 .44559 Metetra
.664 .741 .908 r
.69596 .44559 .70548 .45729 .72585 .45097 .71643 .43919 Metetra
.664 .741 .908 r
.71643 .43919 .72585 .45097 .74637 .44461 .73706 .43275 Metetra
.664 .741 .908 r
.73706 .43275 .74637 .44461 .76704 .43821 .75783 .42626 Metetra
.664 .741 .908 r
.75783 .42626 .76704 .43821 .78786 .43175 .77876 .41972 Metetra
.664 .741 .908 r
.77876 .41972 .78786 .43175 .80883 .42525 .79984 .41313 Metetra
.664 .741 .908 r
.79984 .41313 .80883 .42525 .82995 .41871 .82107 .4065 Metetra
.664 .741 .908 r
.82107 .4065 .82995 .41871 .85123 .41211 .84246 .39981 Metetra
.664 .741 .908 r
.84246 .39981 .85123 .41211 .87267 .40547 .86401 .39308 Metetra
.664 .741 .908 r
.86401 .39308 .87267 .40547 .89426 .39878 .88572 .38629 Metetra
.664 .741 .908 r
.88572 .38629 .89426 .39878 .91601 .39204 .90759 .37946 Metetra
.869 .479 .007 r
.90759 .37946 .91601 .39204 .95141 .48997 .94293 .47763 Metetra
.656 .751 .92 r
.33433 .64306 .34592 .65317 .36449 .64771 .35299 .63753 Metetra
.656 .751 .92 r
.35299 .63753 .36449 .64771 .3832 .64221 .37177 .63196 Metetra
.924 .72 .609 r
.37177 .63196 .3832 .64221 .4056 .53633 .39461 .52567 Metetra
.664 .741 .908 r
.39461 .52567 .4056 .53633 .42403 .53057 .41312 .51983 Metetra
.664 .741 .908 r
.41312 .51983 .42403 .53057 .44258 .52477 .43175 .51396 Metetra
.664 .741 .908 r
.43175 .51396 .44258 .52477 .46127 .51893 .45052 .50805 Metetra
.664 .741 .908 r
.45052 .50805 .46127 .51893 .48008 .51305 .46942 .50209 Metetra
.664 .741 .908 r
.46942 .50209 .48008 .51305 .49902 .50713 .48844 .4961 Metetra
.664 .741 .908 r
.48844 .4961 .49902 .50713 .5181 .50117 .50761 .49006 Metetra
.664 .741 .908 r
.50761 .49006 .5181 .50117 .53731 .49517 .5269 .48398 Metetra
.664 .741 .908 r
.5269 .48398 .53731 .49517 .55665 .48913 .54634 .47785 Metetra
.664 .741 .908 r
.54634 .47785 .55665 .48913 .57613 .48304 .56591 .47169 Metetra
.664 .741 .908 r
.56591 .47169 .57613 .48304 .59575 .47691 .58562 .46547 Metetra
.664 .741 .908 r
.58562 .46547 .59575 .47691 .61551 .47073 .60547 .45922 Metetra
.664 .741 .908 r
.60547 .45922 .61551 .47073 .63541 .46452 .62546 .45292 Metetra
.664 .741 .908 r
.62546 .45292 .63541 .46452 .65545 .45825 .6456 .44657 Metetra
.664 .741 .908 r
.6456 .44657 .65545 .45825 .67563 .45195 .66588 .44018 Metetra
.664 .741 .908 r
.66588 .44018 .67563 .45195 .69596 .44559 .68631 .43374 Metetra
.664 .741 .908 r
.68631 .43374 .69596 .44559 .71643 .43919 .70689 .42726 Metetra
.664 .741 .908 r
.70689 .42726 .71643 .43919 .73706 .43275 .72762 .42073 Metetra
.664 .741 .908 r
.72762 .42073 .73706 .43275 .75783 .42626 .7485 .41415 Metetra
.664 .741 .908 r
.7485 .41415 .75783 .42626 .77876 .41972 .76953 .40752 Metetra
.664 .741 .908 r
.76953 .40752 .77876 .41972 .79984 .41313 .79072 .40084 Metetra
.664 .741 .908 r
.79072 .40084 .79984 .41313 .82107 .4065 .81207 .39412 Metetra
.664 .741 .908 r
.81207 .39412 .82107 .4065 .84246 .39981 .83357 .38734 Metetra
.664 .741 .908 r
.83357 .38734 .84246 .39981 .86401 .39308 .85523 .38051 Metetra
.664 .741 .908 r
.85523 .38051 .86401 .39308 .88572 .38629 .87706 .37364 Metetra
.664 .741 .908 r
.87706 .37364 .88572 .38629 .90759 .37946 .89905 .36671 Metetra
.869 .479 .007 r
.89905 .36671 .90759 .37946 .94293 .47763 .93433 .46511 Metetra
.656 .751 .92 r
.32259 .63282 .33433 .64306 .35299 .63753 .34133 .62721 Metetra
.656 .751 .92 r
.34133 .62721 .35299 .63753 .37177 .63196 .3602 .62157 Metetra
.924 .72 .609 r
.3602 .62157 .37177 .63196 .39461 .52567 .38348 .51487 Metetra
.664 .741 .908 r
.38348 .51487 .39461 .52567 .41312 .51983 .40207 .50896 Metetra
.664 .741 .908 r
.40207 .50896 .41312 .51983 .43175 .51396 .42078 .50301 Metetra
.664 .741 .908 r
.42078 .50301 .43175 .51396 .45052 .50805 .43963 .49702 Metetra
.664 .741 .908 r
.43963 .49702 .45052 .50805 .46942 .50209 .45861 .49099 Metetra
.664 .741 .908 r
.45861 .49099 .46942 .50209 .48844 .4961 .47773 .48492 Metetra
.664 .741 .908 r
.47773 .48492 .48844 .4961 .50761 .49006 .49698 .4788 Metetra
.664 .741 .908 r
.49698 .4788 .50761 .49006 .5269 .48398 .51636 .47264 Metetra
.664 .741 .908 r
.51636 .47264 .5269 .48398 .54634 .47785 .53589 .46643 Metetra
.664 .741 .908 r
.53589 .46643 .54634 .47785 .56591 .47169 .55555 .46018 Metetra
.664 .741 .908 r
.55555 .46018 .56591 .47169 .58562 .46547 .57535 .45389 Metetra
.664 .741 .908 r
.57535 .45389 .58562 .46547 .60547 .45922 .5953 .44755 Metetra
.664 .741 .908 r
.5953 .44755 .60547 .45922 .62546 .45292 .61539 .44117 Metetra
.664 .741 .908 r
.61539 .44117 .62546 .45292 .6456 .44657 .63562 .43474 Metetra
.664 .741 .908 r
.63562 .43474 .6456 .44657 .66588 .44018 .65601 .42826 Metetra
.664 .741 .908 r
.65601 .42826 .66588 .44018 .68631 .43374 .67654 .42174 Metetra
.664 .741 .908 r
.67654 .42174 .68631 .43374 .70689 .42726 .69722 .41516 Metetra
.664 .741 .908 r
.69722 .41516 .70689 .42726 .72762 .42073 .71805 .40854 Metetra
.664 .741 .908 r
.71805 .40854 .72762 .42073 .7485 .41415 .73904 .40187 Metetra
.664 .741 .908 r
.73904 .40187 .7485 .41415 .76953 .40752 .76018 .39515 Metetra
.664 .741 .908 r
.76018 .39515 .76953 .40752 .79072 .40084 .78148 .38839 Metetra
.664 .741 .908 r
.78148 .38839 .79072 .40084 .81207 .39412 .80294 .38157 Metetra
.664 .741 .908 r
.80294 .38157 .81207 .39412 .83357 .38734 .82456 .3747 Metetra
.664 .741 .908 r
.82456 .3747 .83357 .38734 .85523 .38051 .84634 .36777 Metetra
.664 .741 .908 r
.84634 .36777 .85523 .38051 .87706 .37364 .86828 .3608 Metetra
.664 .741 .908 r
.86828 .3608 .87706 .37364 .89905 .36671 .89039 .35377 Metetra
.869 .479 .007 r
.89039 .35377 .89905 .36671 .93433 .46511 .92561 .45241 Metetra
.656 .751 .92 r
.3107 .62244 .32259 .63282 .34133 .62721 .32952 .61676 Metetra
.656 .751 .92 r
.32952 .61676 .34133 .62721 .3602 .62157 .34847 .61104 Metetra
.924 .72 .609 r
.34847 .61104 .3602 .62157 .38348 .51487 .3722 .50393 Metetra
.664 .741 .908 r
.3722 .50393 .38348 .51487 .40207 .50896 .39087 .49795 Metetra
.664 .741 .908 r
.39087 .49795 .40207 .50896 .42078 .50301 .40967 .49192 Metetra
.664 .741 .908 r
.40967 .49192 .42078 .50301 .43963 .49702 .4286 .48585 Metetra
.664 .741 .908 r
.4286 .48585 .43963 .49702 .45861 .49099 .44767 .47974 Metetra
.664 .741 .908 r
.44767 .47974 .45861 .49099 .47773 .48492 .46687 .47359 Metetra
.664 .741 .908 r
.46687 .47359 .47773 .48492 .49698 .4788 .48621 .46739 Metetra
.664 .741 .908 r
.48621 .46739 .49698 .4788 .51636 .47264 .50568 .46115 Metetra
.664 .741 .908 r
.50568 .46115 .51636 .47264 .53589 .46643 .5253 .45486 Metetra
.664 .741 .908 r
.5253 .45486 .53589 .46643 .55555 .46018 .54505 .44853 Metetra
.664 .741 .908 r
.54505 .44853 .55555 .46018 .57535 .45389 .56495 .44215 Metetra
.664 .741 .908 r
.56495 .44215 .57535 .45389 .5953 .44755 .58499 .43573 Metetra
.664 .741 .908 r
.58499 .43573 .5953 .44755 .61539 .44117 .60518 .42926 Metetra
.664 .741 .908 r
.60518 .42926 .61539 .44117 .63562 .43474 .62551 .42274 Metetra
.664 .741 .908 r
.62551 .42274 .63562 .43474 .65601 .42826 .646 .41618 Metetra
.664 .741 .908 r
.646 .41618 .65601 .42826 .67654 .42174 .66663 .40956 Metetra
.664 .741 .908 r
.66663 .40956 .67654 .42174 .69722 .41516 .68741 .4029 Metetra
.664 .741 .908 r
.68741 .4029 .69722 .41516 .71805 .40854 .70835 .39619 Metetra
.664 .741 .908 r
.70835 .39619 .71805 .40854 .73904 .40187 .72945 .38943 Metetra
.664 .741 .908 r
.72945 .38943 .73904 .40187 .76018 .39515 .7507 .38262 Metetra
.664 .741 .908 r
.7507 .38262 .76018 .39515 .78148 .38839 .77211 .37576 Metetra
.664 .741 .908 r
.77211 .37576 .78148 .38839 .80294 .38157 .79368 .36884 Metetra
.664 .741 .908 r
.79368 .36884 .80294 .38157 .82456 .3747 .81542 .36188 Metetra
.664 .741 .908 r
.81542 .36188 .82456 .3747 .84634 .36777 .83731 .35486 Metetra
.664 .741 .908 r
.83731 .35486 .84634 .36777 .86828 .3608 .85938 .34779 Metetra
.664 .741 .908 r
.85938 .34779 .86828 .3608 .89039 .35377 .88161 .34066 Metetra
.869 .479 .007 r
.88161 .34066 .89039 .35377 .92561 .45241 .91675 .43952 Metetra
.656 .751 .92 r
.29865 .61192 .3107 .62244 .32952 .61676 .31755 .60617 Metetra
.656 .751 .92 r
.31755 .60617 .32952 .61676 .34847 .61104 .33658 .60037 Metetra
.924 .72 .609 r
.33658 .60037 .34847 .61104 .3722 .50393 .36079 .49285 Metetra
.664 .741 .908 r
.36079 .49285 .3722 .50393 .39087 .49795 .37954 .48679 Metetra
.664 .741 .908 r
.37954 .48679 .39087 .49795 .40967 .49192 .39842 .48068 Metetra
.664 .741 .908 r
.39842 .48068 .40967 .49192 .4286 .48585 .41743 .47454 Metetra
.664 .741 .908 r
.41743 .47454 .4286 .48585 .44767 .47974 .43658 .46835 Metetra
.664 .741 .908 r
.43658 .46835 .44767 .47974 .46687 .47359 .45587 .46211 Metetra
.664 .741 .908 r
.45587 .46211 .46687 .47359 .48621 .46739 .4753 .45583 Metetra
.664 .741 .908 r
.4753 .45583 .48621 .46739 .50568 .46115 .49486 .44951 Metetra
.664 .741 .908 r
.49486 .44951 .50568 .46115 .5253 .45486 .51457 .44314 Metetra
.664 .741 .908 r
.51457 .44314 .5253 .45486 .54505 .44853 .53442 .43672 Metetra
.664 .741 .908 r
.53442 .43672 .54505 .44853 .56495 .44215 .55441 .43026 Metetra
.664 .741 .908 r
.55441 .43026 .56495 .44215 .58499 .43573 .57455 .42375 Metetra
.664 .741 .908 r
.57455 .42375 .58499 .43573 .60518 .42926 .59483 .41719 Metetra
.664 .741 .908 r
.59483 .41719 .60518 .42926 .62551 .42274 .61526 .41059 Metetra
.664 .741 .908 r
.61526 .41059 .62551 .42274 .646 .41618 .63585 .40393 Metetra
.664 .741 .908 r
.63585 .40393 .646 .41618 .66663 .40956 .65659 .39723 Metetra
.664 .741 .908 r
.65659 .39723 .66663 .40956 .68741 .4029 .67748 .39047 Metetra
.664 .741 .908 r
.67748 .39047 .68741 .4029 .70835 .39619 .69852 .38367 Metetra
.664 .741 .908 r
.69852 .38367 .70835 .39619 .72945 .38943 .71973 .37682 Metetra
.664 .741 .908 r
.71973 .37682 .72945 .38943 .7507 .38262 .74109 .36991 Metetra
.664 .741 .908 r
.74109 .36991 .7507 .38262 .77211 .37576 .76261 .36295 Metetra
.664 .741 .908 r
.76261 .36295 .77211 .37576 .79368 .36884 .7843 .35594 Metetra
.664 .741 .908 r
.7843 .35594 .79368 .36884 .81542 .36188 .80615 .34888 Metetra
.664 .741 .908 r
.80615 .34888 .81542 .36188 .83731 .35486 .82817 .34176 Metetra
.664 .741 .908 r
.82817 .34176 .83731 .35486 .85938 .34779 .85035 .33459 Metetra
.664 .741 .908 r
.85035 .33459 .85938 .34779 .88161 .34066 .87271 .32736 Metetra
.869 .479 .007 r
.87271 .32736 .88161 .34066 .91675 .43952 .90777 .42645 Metetra
.656 .751 .92 r
.28644 .60127 .29865 .61192 .31755 .60617 .30542 .59544 Metetra
.656 .751 .92 r
.30542 .59544 .31755 .60617 .33658 .60037 .32454 .58956 Metetra
.924 .72 .609 r
.32454 .58956 .33658 .60037 .36079 .49285 .34922 .48163 Metetra
.664 .741 .908 r
.34922 .48163 .36079 .49285 .37954 .48679 .36805 .47549 Metetra
.664 .741 .908 r
.36805 .47549 .37954 .48679 .39842 .48068 .38701 .4693 Metetra
.664 .741 .908 r
.38701 .4693 .39842 .48068 .41743 .47454 .40611 .46307 Metetra
.664 .741 .908 r
.40611 .46307 .41743 .47454 .43658 .46835 .42535 .4568 Metetra
.664 .741 .908 r
.42535 .4568 .43658 .46835 .45587 .46211 .44473 .45048 Metetra
.664 .741 .908 r
.44473 .45048 .45587 .46211 .4753 .45583 .46424 .44412 Metetra
.664 .741 .908 r
.46424 .44412 .4753 .45583 .49486 .44951 .4839 .43771 Metetra
.664 .741 .908 r
.4839 .43771 .49486 .44951 .51457 .44314 .50369 .43126 Metetra
.664 .741 .908 r
.50369 .43126 .51457 .44314 .53442 .43672 .52364 .42475 Metetra
.664 .741 .908 r
.52364 .42475 .53442 .43672 .55441 .43026 .54372 .4182 Metetra
.664 .741 .908 r
.54372 .4182 .55441 .43026 .57455 .42375 .56396 .4116 Metetra
.664 .741 .908 r
.56396 .4116 .57455 .42375 .59483 .41719 .58434 .40496 Metetra
.664 .741 .908 r
.58434 .40496 .59483 .41719 .61526 .41059 .60488 .39826 Metetra
.664 .741 .908 r
.60488 .39826 .61526 .41059 .63585 .40393 .62556 .39152 Metetra
.664 .741 .908 r
.62556 .39152 .63585 .40393 .65659 .39723 .6464 .38472 Metetra
.664 .741 .908 r
.6464 .38472 .65659 .39723 .67748 .39047 .6674 .37787 Metetra
.664 .741 .908 r
.6674 .37787 .67748 .39047 .69852 .38367 .68856 .37098 Metetra
.664 .741 .908 r
.68856 .37098 .69852 .38367 .71973 .37682 .70987 .36403 Metetra
.664 .741 .908 r
.70987 .36403 .71973 .37682 .74109 .36991 .73134 .35702 Metetra
.664 .741 .908 r
.73134 .35702 .74109 .36991 .76261 .36295 .75298 .34997 Metetra
.664 .741 .908 r
.75298 .34997 .76261 .36295 .7843 .35594 .77478 .34286 Metetra
.664 .741 .908 r
.77478 .34286 .7843 .35594 .80615 .34888 .79675 .3357 Metetra
.664 .741 .908 r
.79675 .3357 .80615 .34888 .82817 .34176 .81889 .32848 Metetra
.664 .741 .908 r
.81889 .32848 .82817 .34176 .85035 .33459 .84119 .3212 Metetra
.664 .741 .908 r
.84119 .3212 .85035 .33459 .87271 .32736 .86367 .31387 Metetra
.869 .479 .007 r
.86367 .31387 .87271 .32736 .90777 .42645 .89865 .41318 Metetra
.656 .751 .92 r
.27407 .59047 .28644 .60127 .30542 .59544 .29313 .58456 Metetra
.656 .751 .92 r
.29313 .58456 .30542 .59544 .32454 .58956 .31233 .57861 Metetra
.924 .72 .609 r
.31233 .57861 .32454 .58956 .34922 .48163 .3375 .47026 Metetra
.664 .741 .908 r
.3375 .47026 .34922 .48163 .36805 .47549 .35641 .46404 Metetra
.664 .741 .908 r
.35641 .46404 .36805 .47549 .38701 .4693 .37546 .45777 Metetra
.664 .741 .908 r
.37546 .45777 .38701 .4693 .40611 .46307 .39465 .45146 Metetra
.664 .741 .908 r
.39465 .45146 .40611 .46307 .42535 .4568 .41397 .4451 Metetra
.664 .741 .908 r
.41397 .4451 .42535 .4568 .44473 .45048 .43343 .4387 Metetra
.664 .741 .908 r
.43343 .4387 .44473 .45048 .46424 .44412 .45304 .43225 Metetra
.664 .741 .908 r
.45304 .43225 .46424 .44412 .4839 .43771 .47278 .42576 Metetra
.664 .741 .908 r
.47278 .42576 .4839 .43771 .50369 .43126 .49267 .41921 Metetra
.664 .741 .908 r
.49267 .41921 .50369 .43126 .52364 .42475 .51271 .41262 Metetra
.664 .741 .908 r
.51271 .41262 .52364 .42475 .54372 .4182 .53289 .40598 Metetra
.664 .741 .908 r
.53289 .40598 .54372 .4182 .56396 .4116 .55323 .3993 Metetra
.664 .741 .908 r
.55323 .3993 .56396 .4116 .58434 .40496 .57371 .39256 Metetra
.664 .741 .908 r
.57371 .39256 .58434 .40496 .60488 .39826 .59435 .38577 Metetra
.664 .741 .908 r
.59435 .38577 .60488 .39826 .62556 .39152 .61514 .37893 Metetra
.664 .741 .908 r
.61514 .37893 .62556 .39152 .6464 .38472 .63608 .37204 Metetra
.664 .741 .908 r
.63608 .37204 .6464 .38472 .6674 .37787 .65719 .3651 Metetra
.664 .741 .908 r
.65719 .3651 .6674 .37787 .68856 .37098 .67845 .3581 Metetra
.664 .741 .908 r
.67845 .3581 .68856 .37098 .70987 .36403 .69987 .35106 Metetra
.664 .741 .908 r
.69987 .35106 .70987 .36403 .73134 .35702 .72146 .34396 Metetra
.664 .741 .908 r
.72146 .34396 .73134 .35702 .75298 .34997 .74321 .3368 Metetra
.664 .741 .908 r
.74321 .3368 .75298 .34997 .77478 .34286 .76513 .32959 Metetra
.664 .741 .908 r
.76513 .32959 .77478 .34286 .79675 .3357 .78722 .32233 Metetra
.664 .741 .908 r
.78722 .32233 .79675 .3357 .81889 .32848 .80948 .31501 Metetra
.664 .741 .908 r
.80948 .31501 .81889 .32848 .84119 .3212 .83191 .30763 Metetra
.664 .741 .908 r
.83191 .30763 .84119 .3212 .86367 .31387 .85451 .30019 Metetra
.869 .479 .007 r
.85451 .30019 .86367 .31387 .89865 .41318 .8894 .39971 Metetra
.656 .751 .92 r
.26154 .57953 .27407 .59047 .29313 .58456 .28068 .57354 Metetra
.656 .751 .92 r
.28068 .57354 .29313 .58456 .31233 .57861 .29996 .56751 Metetra
.924 .72 .609 r
.29996 .56751 .31233 .57861 .3375 .47026 .32563 .45874 Metetra
.664 .741 .908 r
.32563 .45874 .3375 .47026 .35641 .46404 .34462 .45243 Metetra
.664 .741 .908 r
.34462 .45243 .35641 .46404 .37546 .45777 .36375 .44608 Metetra
.664 .741 .908 r
.36375 .44608 .37546 .45777 .39465 .45146 .38302 .43969 Metetra
.664 .741 .908 r
.38302 .43969 .39465 .45146 .41397 .4451 .40244 .43325 Metetra
.664 .741 .908 r
.40244 .43325 .41397 .4451 .43343 .4387 .42199 .42676 Metetra
.664 .741 .908 r
.42199 .42676 .43343 .4387 .45304 .43225 .44168 .42022 Metetra
.664 .741 .908 r
.44168 .42022 .45304 .43225 .47278 .42576 .46152 .41364 Metetra
.664 .741 .908 r
.46152 .41364 .47278 .42576 .49267 .41921 .4815 .40701 Metetra
.664 .741 .908 r
.4815 .40701 .49267 .41921 .51271 .41262 .50164 .40033 Metetra
.664 .741 .908 r
.50164 .40033 .51271 .41262 .53289 .40598 .52192 .3936 Metetra
.664 .741 .908 r
.52192 .3936 .53289 .40598 .55323 .3993 .54235 .38682 Metetra
.664 .741 .908 r
.54235 .38682 .55323 .3993 .57371 .39256 .56293 .37999 Metetra
.664 .741 .908 r
.56293 .37999 .57371 .39256 .59435 .38577 .58367 .3731 Metetra
.664 .741 .908 r
.58367 .3731 .59435 .38577 .61514 .37893 .60457 .36617 Metetra
.664 .741 .908 r
.60457 .36617 .61514 .37893 .63608 .37204 .62562 .35918 Metetra
.664 .741 .908 r
.62562 .35918 .63608 .37204 .65719 .3651 .64683 .35215 Metetra
.664 .741 .908 r
.64683 .35215 .65719 .3651 .67845 .3581 .6682 .34505 Metetra
.664 .741 .908 r
.6682 .34505 .67845 .3581 .69987 .35106 .68974 .33791 Metetra
.664 .741 .908 r
.68974 .33791 .69987 .35106 .72146 .34396 .71144 .3307 Metetra
.664 .741 .908 r
.71144 .3307 .72146 .34396 .74321 .3368 .73331 .32345 Metetra
.664 .741 .908 r
.73331 .32345 .74321 .3368 .76513 .32959 .75534 .31614 Metetra
.664 .741 .908 r
.75534 .31614 .76513 .32959 .78722 .32233 .77755 .30877 Metetra
.664 .741 .908 r
.77755 .30877 .78722 .32233 .80948 .31501 .79993 .30134 Metetra
.664 .741 .908 r
.79993 .30134 .80948 .31501 .83191 .30763 .82248 .29385 Metetra
.664 .741 .908 r
.82248 .29385 .83191 .30763 .85451 .30019 .84522 .28631 Metetra
.869 .479 .007 r
.84522 .28631 .85451 .30019 .8894 .39971 .88001 .38604 Metetra
.656 .751 .92 r
.24883 .56844 .26154 .57953 .28068 .57354 .26805 .56237 Metetra
.656 .751 .92 r
.26805 .56237 .28068 .57354 .29996 .56751 .28742 .55625 Metetra
.924 .72 .609 r
.28742 .55625 .29996 .56751 .32563 .45874 .31359 .44706 Metetra
.664 .741 .908 r
.31359 .44706 .32563 .45874 .34462 .45243 .33267 .44068 Metetra
.664 .741 .908 r
.33267 .44068 .34462 .45243 .36375 .44608 .35189 .43424 Metetra
.664 .741 .908 r
.35189 .43424 .36375 .44608 .38302 .43969 .37125 .42776 Metetra
.664 .741 .908 r
.37125 .42776 .38302 .43969 .40244 .43325 .39075 .42123 Metetra
.664 .741 .908 r
.39075 .42123 .40244 .43325 .42199 .42676 .41039 .41466 Metetra
.664 .741 .908 r
.41039 .41466 .42199 .42676 .44168 .42022 .43017 .40803 Metetra
.664 .741 .908 r
.43017 .40803 .44168 .42022 .46152 .41364 .4501 .40136 Metetra
.664 .741 .908 r
.4501 .40136 .46152 .41364 .4815 .40701 .47018 .39464 Metetra
.664 .741 .908 r
.47018 .39464 .4815 .40701 .50164 .40033 .49041 .38786 Metetra
.664 .741 .908 r
.49041 .38786 .50164 .40033 .52192 .3936 .51079 .38104 Metetra
.664 .741 .908 r
.51079 .38104 .52192 .3936 .54235 .38682 .53132 .37417 Metetra
.664 .741 .908 r
.53132 .37417 .54235 .38682 .56293 .37999 .552 .36724 Metetra
.664 .741 .908 r
.552 .36724 .56293 .37999 .58367 .3731 .57285 .36026 Metetra
.664 .741 .908 r
.57285 .36026 .58367 .3731 .60457 .36617 .59385 .35323 Metetra
.664 .741 .908 r
.59385 .35323 .60457 .36617 .62562 .35918 .615 .34615 Metetra
.664 .741 .908 r
.615 .34615 .62562 .35918 .64683 .35215 .63632 .33901 Metetra
.664 .741 .908 r
.63632 .33901 .64683 .35215 .6682 .34505 .65781 .33182 Metetra
.664 .741 .908 r
.65781 .33182 .6682 .34505 .68974 .33791 .67946 .32457 Metetra
.664 .741 .908 r
.67946 .32457 .68974 .33791 .71144 .3307 .70127 .31726 Metetra
.664 .741 .908 r
.70127 .31726 .71144 .3307 .73331 .32345 .72326 .3099 Metetra
.664 .741 .908 r
.72326 .3099 .73331 .32345 .75534 .31614 .74541 .30249 Metetra
.664 .741 .908 r
.74541 .30249 .75534 .31614 .77755 .30877 .76774 .29501 Metetra
.664 .741 .908 r
.76774 .29501 .77755 .30877 .79993 .30134 .79025 .28747 Metetra
.664 .741 .908 r
.79025 .28747 .79993 .30134 .82248 .29385 .81293 .27988 Metetra
.664 .741 .908 r
.81293 .27988 .82248 .29385 .84522 .28631 .83579 .27223 Metetra
.869 .479 .007 r
.83579 .27223 .84522 .28631 .88001 .38604 .87047 .37217 Metetra
.656 .751 .92 r
.23595 .5572 .24883 .56844 .26805 .56237 .25526 .55104 Metetra
.656 .751 .92 r
.25526 .55104 .26805 .56237 .28742 .55625 .27471 .54484 Metetra
.945 .625 .396 r
.27471 .54484 .28742 .55625 .31359 .44706 .28676 .64873 Metetra
.528 .288 .494 r
.28676 .64873 .31359 .44706 .33267 .44068 .30712 .64266 Metetra
.528 .288 .494 r
.30712 .64266 .33267 .44068 .35189 .43424 .32765 .63654 Metetra
.528 .288 .494 r
.32765 .63654 .35189 .43424 .37125 .42776 .34833 .63037 Metetra
.528 .288 .494 r
.34833 .63037 .37125 .42776 .39075 .42123 .36918 .62416 Metetra
.528 .288 .494 r
.36918 .62416 .39075 .42123 .41039 .41466 .39019 .61789 Metetra
.528 .288 .494 r
.39019 .61789 .41039 .41466 .43017 .40803 .41137 .61157 Metetra
.528 .288 .494 r
.41137 .61157 .43017 .40803 .4501 .40136 .43271 .60521 Metetra
.528 .288 .494 r
.43271 .60521 .4501 .40136 .47018 .39464 .45423 .59879 Metetra
.528 .288 .494 r
.45423 .59879 .47018 .39464 .49041 .38786 .47591 .59233 Metetra
.528 .288 .494 r
.47591 .59233 .49041 .38786 .51079 .38104 .49778 .58581 Metetra
.528 .288 .494 r
.49778 .58581 .51079 .38104 .53132 .37417 .51981 .57924 Metetra
.528 .288 .494 r
.51981 .57924 .53132 .37417 .552 .36724 .54203 .57261 Metetra
.528 .288 .494 r
.54203 .57261 .552 .36724 .57285 .36026 .56442 .56594 Metetra
.528 .288 .494 r
.56442 .56594 .57285 .36026 .59385 .35323 .587 .5592 Metetra
.528 .288 .494 r
.587 .5592 .59385 .35323 .615 .34615 .60976 .55242 Metetra
.528 .288 .494 r
.60976 .55242 .615 .34615 .63632 .33901 .63271 .54557 Metetra
.528 .288 .494 r
.63271 .54557 .63632 .33901 .65781 .33182 .65585 .53867 Metetra
.528 .288 .494 r
.65585 .53867 .65781 .33182 .67946 .32457 .67918 .53172 Metetra
.528 .288 .494 r
.67918 .53172 .67946 .32457 .70127 .31726 .70271 .5247 Metetra
.528 .288 .494 r
.70271 .5247 .70127 .31726 .72326 .3099 .72643 .51763 Metetra
.528 .288 .494 r
.72643 .51763 .72326 .3099 .74541 .30249 .75035 .51049 Metetra
.528 .288 .494 r
.75035 .51049 .74541 .30249 .76774 .29501 .77447 .5033 Metetra
.528 .288 .494 r
.77447 .5033 .76774 .29501 .79025 .28747 .7988 .49605 Metetra
.528 .288 .494 r
.7988 .49605 .79025 .28747 .81293 .27988 .82333 .48873 Metetra
.528 .288 .494 r
.82333 .48873 .81293 .27988 .83579 .27223 .84807 .48135 Metetra
.31 .129 .466 r
.84807 .48135 .83579 .27223 .87047 .37217 .86079 .35808 Metetra
.656 .751 .92 r
.22289 .5458 .23595 .5572 .25526 .55104 .24228 .53956 Metetra
.656 .751 .92 r
.24228 .53956 .25526 .55104 .27471 .54484 .26182 .53328 Metetra
.945 .625 .396 r
.26182 .53328 .27471 .54484 .28676 .64873 .27348 .63748 Metetra
.646 .762 .934 r
.27348 .63748 .28676 .64873 .30712 .64266 .29394 .63132 Metetra
.646 .762 .934 r
.29394 .63132 .30712 .64266 .32765 .63654 .31456 .62511 Metetra
.646 .762 .934 r
.31456 .62511 .32765 .63654 .34833 .63037 .33535 .61886 Metetra
.646 .762 .934 r
.33535 .61886 .34833 .63037 .36918 .62416 .35629 .61255 Metetra
.646 .762 .934 r
.35629 .61255 .36918 .62416 .39019 .61789 .37741 .60619 Metetra
.646 .762 .934 r
.37741 .60619 .39019 .61789 .41137 .61157 .39869 .59978 Metetra
.646 .762 .934 r
.39869 .59978 .41137 .61157 .43271 .60521 .42014 .59333 Metetra
.646 .762 .934 r
.42014 .59333 .43271 .60521 .45423 .59879 .44177 .58682 Metetra
.646 .762 .934 r
.44177 .58682 .45423 .59879 .47591 .59233 .46356 .58025 Metetra
.646 .762 .934 r
.46356 .58025 .47591 .59233 .49778 .58581 .48554 .57364 Metetra
.646 .762 .934 r
.48554 .57364 .49778 .58581 .51981 .57924 .50769 .56697 Metetra
.646 .762 .934 r
.50769 .56697 .51981 .57924 .54203 .57261 .53002 .56024 Metetra
.646 .762 .934 r
.53002 .56024 .54203 .57261 .56442 .56594 .55254 .55346 Metetra
.646 .762 .934 r
.55254 .55346 .56442 .56594 .587 .5592 .57524 .54663 Metetra
.646 .762 .934 r
.57524 .54663 .587 .5592 .60976 .55242 .59812 .53974 Metetra
.646 .762 .934 r
.59812 .53974 .60976 .55242 .63271 .54557 .6212 .53279 Metetra
.646 .762 .934 r
.6212 .53279 .63271 .54557 .65585 .53867 .64447 .52578 Metetra
.646 .762 .934 r
.64447 .52578 .65585 .53867 .67918 .53172 .66793 .51872 Metetra
.646 .762 .934 r
.66793 .51872 .67918 .53172 .70271 .5247 .69159 .5116 Metetra
.646 .762 .934 r
.69159 .5116 .70271 .5247 .72643 .51763 .71545 .50441 Metetra
.646 .762 .934 r
.71545 .50441 .72643 .51763 .75035 .51049 .73951 .49717 Metetra
.646 .762 .934 r
.73951 .49717 .75035 .51049 .77447 .5033 .76378 .48986 Metetra
.646 .762 .934 r
.76378 .48986 .77447 .5033 .7988 .49605 .78825 .48249 Metetra
.646 .762 .934 r
.78825 .48249 .7988 .49605 .82333 .48873 .81293 .47506 Metetra
.646 .762 .934 r
.81293 .47506 .82333 .48873 .84807 .48135 .83782 .46757 Metetra
.986 .752 .496 r
.83782 .46757 .84807 .48135 .86079 .35808 .85096 .34377 Metetra
.656 .751 .92 r
.20965 .53425 .22289 .5458 .24228 .53956 .22913 .52792 Metetra
.656 .751 .92 r
.22913 .52792 .24228 .53956 .26182 .53328 .24876 .52155 Metetra
.945 .625 .396 r
.24876 .52155 .26182 .53328 .27348 .63748 .26001 .62607 Metetra
.646 .762 .934 r
.26001 .62607 .27348 .63748 .29394 .63132 .28057 .61982 Metetra
.646 .762 .934 r
.28057 .61982 .29394 .63132 .31456 .62511 .30129 .61352 Metetra
.646 .762 .934 r
.30129 .61352 .31456 .62511 .33535 .61886 .32217 .60717 Metetra
.646 .762 .934 r
.32217 .60717 .33535 .61886 .35629 .61255 .34322 .60077 Metetra
.646 .762 .934 r
.34322 .60077 .35629 .61255 .37741 .60619 .36444 .59432 Metetra
.646 .762 .934 r
.36444 .59432 .37741 .60619 .39869 .59978 .38582 .58782 Metetra
.646 .762 .934 r
.38582 .58782 .39869 .59978 .42014 .59333 .40738 .58127 Metetra
.646 .762 .934 r
.40738 .58127 .42014 .59333 .44177 .58682 .42912 .57466 Metetra
.646 .762 .934 r
.42912 .57466 .44177 .58682 .46356 .58025 .45103 .568 Metetra
.646 .762 .934 r
.45103 .568 .46356 .58025 .48554 .57364 .47311 .56128 Metetra
.646 .762 .934 r
.47311 .56128 .48554 .57364 .50769 .56697 .49538 .55451 Metetra
.646 .762 .934 r
.49538 .55451 .50769 .56697 .53002 .56024 .51783 .54768 Metetra
.646 .762 .934 r
.51783 .54768 .53002 .56024 .55254 .55346 .54047 .5408 Metetra
.646 .762 .934 r
.54047 .5408 .55254 .55346 .57524 .54663 .56329 .53386 Metetra
.646 .762 .934 r
.56329 .53386 .57524 .54663 .59812 .53974 .58631 .52687 Metetra
.646 .762 .934 r
.58631 .52687 .59812 .53974 .6212 .53279 .60951 .51981 Metetra
.646 .762 .934 r
.60951 .51981 .6212 .53279 .64447 .52578 .63291 .5127 Metetra
.646 .762 .934 r
.63291 .5127 .64447 .52578 .66793 .51872 .65651 .50552 Metetra
.646 .762 .934 r
.65651 .50552 .66793 .51872 .69159 .5116 .6803 .49829 Metetra
.646 .762 .934 r
.6803 .49829 .69159 .5116 .71545 .50441 .7043 .49099 Metetra
.646 .762 .934 r
.7043 .49099 .71545 .50441 .73951 .49717 .7285 .48363 Metetra
.646 .762 .934 r
.7285 .48363 .73951 .49717 .76378 .48986 .75291 .47621 Metetra
.646 .762 .934 r
.75291 .47621 .76378 .48986 .78825 .48249 .77753 .46872 Metetra
.646 .762 .934 r
.77753 .46872 .78825 .48249 .81293 .47506 .80237 .46117 Metetra
.646 .762 .934 r
.80237 .46117 .81293 .47506 .83782 .46757 .82741 .45356 Metetra
.986 .752 .496 r
.82741 .45356 .83782 .46757 .85096 .34377 .84098 .32925 Metetra
.656 .751 .92 r
.19623 .52253 .20965 .53425 .22913 .52792 .21579 .51612 Metetra
.656 .751 .92 r
.21579 .51612 .22913 .52792 .24876 .52155 .23551 .50965 Metetra
.945 .625 .396 r
.23551 .50965 .24876 .52155 .26001 .62607 .24635 .6145 Metetra
.646 .762 .934 r
.24635 .6145 .26001 .62607 .28057 .61982 .267 .60815 Metetra
.646 .762 .934 r
.267 .60815 .28057 .61982 .30129 .61352 .28782 .60176 Metetra
.646 .762 .934 r
.28782 .60176 .30129 .61352 .32217 .60717 .3088 .59532 Metetra
.646 .762 .934 r
.3088 .59532 .32217 .60717 .34322 .60077 .32995 .58882 Metetra
.646 .762 .934 r
.32995 .58882 .34322 .60077 .36444 .59432 .35127 .58228 Metetra
.646 .762 .934 r
.35127 .58228 .36444 .59432 .38582 .58782 .37277 .57568 Metetra
.646 .762 .934 r
.37277 .57568 .38582 .58782 .40738 .58127 .39443 .56902 Metetra
.646 .762 .934 r
.39443 .56902 .40738 .58127 .42912 .57466 .41628 .56232 Metetra
.646 .762 .934 r
.41628 .56232 .42912 .57466 .45103 .568 .4383 .55556 Metetra
.646 .762 .934 r
.4383 .55556 .45103 .568 .47311 .56128 .4605 .54874 Metetra
.646 .762 .934 r
.4605 .54874 .47311 .56128 .49538 .55451 .48289 .54186 Metetra
.646 .762 .934 r
.48289 .54186 .49538 .55451 .51783 .54768 .50546 .53493 Metetra
.646 .762 .934 r
.50546 .53493 .51783 .54768 .54047 .5408 .52822 .52795 Metetra
.646 .762 .934 r
.52822 .52795 .54047 .5408 .56329 .53386 .55117 .5209 Metetra
.646 .762 .934 r
.55117 .5209 .56329 .53386 .58631 .52687 .57431 .51379 Metetra
.646 .762 .934 r
.57431 .51379 .58631 .52687 .60951 .51981 .59764 .50663 Metetra
.646 .762 .934 r
.59764 .50663 .60951 .51981 .63291 .5127 .62117 .4994 Metetra
.646 .762 .934 r
.62117 .4994 .63291 .5127 .65651 .50552 .6449 .49212 Metetra
.646 .762 .934 r
.6449 .49212 .65651 .50552 .6803 .49829 .66884 .48477 Metetra
.646 .762 .934 r
.66884 .48477 .6803 .49829 .7043 .49099 .69298 .47736 Metetra
.646 .762 .934 r
.69298 .47736 .7043 .49099 .7285 .48363 .71732 .46988 Metetra
.646 .762 .934 r
.71732 .46988 .7285 .48363 .75291 .47621 .74188 .46234 Metetra
.646 .762 .934 r
.74188 .46234 .75291 .47621 .77753 .46872 .76665 .45473 Metetra
.646 .762 .934 r
.76665 .45473 .77753 .46872 .80237 .46117 .79163 .44706 Metetra
.646 .762 .934 r
.79163 .44706 .80237 .46117 .82741 .45356 .81683 .43932 Metetra
.986 .752 .496 r
.81683 .43932 .82741 .45356 .84098 .32925 .83084 .31449 Metetra
.656 .751 .92 r
.18262 .51065 .19623 .52253 .21579 .51612 .20227 .50415 Metetra
.656 .751 .92 r
.20227 .50415 .21579 .51612 .23551 .50965 .22207 .49759 Metetra
.945 .625 .396 r
.22207 .49759 .23551 .50965 .24635 .6145 .23248 .60275 Metetra
.646 .762 .934 r
.23248 .60275 .24635 .6145 .267 .60815 .25323 .59631 Metetra
.646 .762 .934 r
.25323 .59631 .267 .60815 .28782 .60176 .27415 .58983 Metetra
.646 .762 .934 r
.27415 .58983 .28782 .60176 .3088 .59532 .29523 .58329 Metetra
.646 .762 .934 r
.29523 .58329 .3088 .59532 .32995 .58882 .31649 .5767 Metetra
.646 .762 .934 r
.31649 .5767 .32995 .58882 .35127 .58228 .33791 .57005 Metetra
.646 .762 .934 r
.33791 .57005 .35127 .58228 .37277 .57568 .35951 .56335 Metetra
.646 .762 .934 r
.35951 .56335 .37277 .57568 .39443 .56902 .38129 .5566 Metetra
.646 .762 .934 r
.38129 .5566 .39443 .56902 .41628 .56232 .40324 .54979 Metetra
.646 .762 .934 r
.40324 .54979 .41628 .56232 .4383 .55556 .42538 .54293 Metetra
.646 .762 .934 r
.42538 .54293 .4383 .55556 .4605 .54874 .4477 .536 Metetra
.646 .762 .934 r
.4477 .536 .4605 .54874 .48289 .54186 .4702 .52902 Metetra
.646 .762 .934 r
.4702 .52902 .48289 .54186 .50546 .53493 .49289 .52199 Metetra
.646 .762 .934 r
.49289 .52199 .50546 .53493 .52822 .52795 .51578 .51489 Metetra
.646 .762 .934 r
.51578 .51489 .52822 .52795 .55117 .5209 .53885 .50774 Metetra
.646 .762 .934 r
.53885 .50774 .55117 .5209 .57431 .51379 .56212 .50052 Metetra
.646 .762 .934 r
.56212 .50052 .57431 .51379 .59764 .50663 .58559 .49324 Metetra
.646 .762 .934 r
.58559 .49324 .59764 .50663 .62117 .4994 .60925 .4859 Metetra
.646 .762 .934 r
.60925 .4859 .62117 .4994 .6449 .49212 .63312 .4785 Metetra
.646 .762 .934 r
.63312 .4785 .6449 .49212 .66884 .48477 .65719 .47103 Metetra
.646 .762 .934 r
.65719 .47103 .66884 .48477 .69298 .47736 .68147 .4635 Metetra
.646 .762 .934 r
.68147 .4635 .69298 .47736 .71732 .46988 .70596 .45591 Metetra
.646 .762 .934 r
.70596 .45591 .71732 .46988 .74188 .46234 .73067 .44825 Metetra
.646 .762 .934 r
.73067 .44825 .74188 .46234 .76665 .45473 .75559 .44052 Metetra
.646 .762 .934 r
.75559 .44052 .76665 .45473 .79163 .44706 .78072 .43272 Metetra
.646 .762 .934 r
.78072 .43272 .79163 .44706 .81683 .43932 .80608 .42486 Metetra
.986 .752 .496 r
.80608 .42486 .81683 .43932 .83084 .31449 .82055 .29951 Metetra
.656 .751 .92 r
.16882 .49861 .18262 .51065 .20227 .50415 .18855 .49201 Metetra
.656 .751 .92 r
.18855 .49201 .20227 .50415 .22207 .49759 .20844 .48536 Metetra
.945 .625 .396 r
.20844 .48536 .22207 .49759 .23248 .60275 .21841 .59083 Metetra
.646 .762 .934 r
.21841 .59083 .23248 .60275 .25323 .59631 .23926 .5843 Metetra
.646 .762 .934 r
.23926 .5843 .25323 .59631 .27415 .58983 .26028 .57771 Metetra
.646 .762 .934 r
.26028 .57771 .27415 .58983 .29523 .58329 .28146 .57108 Metetra
.646 .762 .934 r
.28146 .57108 .29523 .58329 .31649 .5767 .30282 .56439 Metetra
.646 .762 .934 r
.30282 .56439 .31649 .5767 .33791 .57005 .32435 .55764 Metetra
.646 .762 .934 r
.32435 .55764 .33791 .57005 .35951 .56335 .34606 .55084 Metetra
.646 .762 .934 r
.34606 .55084 .35951 .56335 .38129 .5566 .36795 .54399 Metetra
.646 .762 .934 r
.36795 .54399 .38129 .5566 .40324 .54979 .39001 .53707 Metetra
.646 .762 .934 r
.39001 .53707 .40324 .54979 .42538 .54293 .41226 .5301 Metetra
.646 .762 .934 r
.41226 .5301 .42538 .54293 .4477 .536 .4347 .52307 Metetra
.646 .762 .934 r
.4347 .52307 .4477 .536 .4702 .52902 .45732 .51599 Metetra
.646 .762 .934 r
.45732 .51599 .4702 .52902 .49289 .52199 .48014 .50884 Metetra
.646 .762 .934 r
.48014 .50884 .49289 .52199 .51578 .51489 .50314 .50163 Metetra
.646 .762 .934 r
.50314 .50163 .51578 .51489 .53885 .50774 .52634 .49436 Metetra
.646 .762 .934 r
.52634 .49436 .53885 .50774 .56212 .50052 .54974 .48704 Metetra
.646 .762 .934 r
.54974 .48704 .56212 .50052 .58559 .49324 .57334 .47964 Metetra
.646 .762 .934 r
.57334 .47964 .58559 .49324 .60925 .4859 .59714 .47219 Metetra
.646 .762 .934 r
.59714 .47219 .60925 .4859 .63312 .4785 .62114 .46467 Metetra
.646 .762 .934 r
.62114 .46467 .63312 .4785 .65719 .47103 .64536 .45708 Metetra
.646 .762 .934 r
.64536 .45708 .65719 .47103 .68147 .4635 .66978 .44943 Metetra
.646 .762 .934 r
.66978 .44943 .68147 .4635 .70596 .45591 .69442 .44171 Metetra
.646 .762 .934 r
.69442 .44171 .70596 .45591 .73067 .44825 .71927 .43393 Metetra
.646 .762 .934 r
.71927 .43393 .73067 .44825 .75559 .44052 .74434 .42607 Metetra
.646 .762 .934 r
.74434 .42607 .75559 .44052 .78072 .43272 .76964 .41815 Metetra
.646 .762 .934 r
.76964 .41815 .78072 .43272 .80608 .42486 .79516 .41016 Metetra
.986 .752 .496 r
.79516 .41016 .80608 .42486 .82055 .29951 .81009 .28428 Metetra
.656 .751 .92 r
.15482 .48639 .16882 .49861 .18855 .49201 .17464 .4797 Metetra
.656 .751 .92 r
.17464 .4797 .18855 .49201 .20844 .48536 .19462 .47295 Metetra
.945 .625 .396 r
.19462 .47295 .20844 .48536 .21841 .59083 .20414 .57873 Metetra
.646 .762 .934 r
.20414 .57873 .21841 .59083 .23926 .5843 .22508 .5721 Metetra
.646 .762 .934 r
.22508 .5721 .23926 .5843 .26028 .57771 .2462 .56542 Metetra
.646 .762 .934 r
.2462 .56542 .26028 .57771 .28146 .57108 .26748 .55868 Metetra
.646 .762 .934 r
.26748 .55868 .28146 .57108 .30282 .56439 .28894 .55189 Metetra
.646 .762 .934 r
.28894 .55189 .30282 .56439 .32435 .55764 .31058 .54504 Metetra
.646 .762 .934 r
.31058 .54504 .32435 .55764 .34606 .55084 .3324 .53814 Metetra
.646 .762 .934 r
.3324 .53814 .34606 .55084 .36795 .54399 .3544 .53118 Metetra
.646 .762 .934 r
.3544 .53118 .36795 .54399 .39001 .53707 .37658 .52416 Metetra
.646 .762 .934 r
.37658 .52416 .39001 .53707 .41226 .5301 .39894 .51708 Metetra
.646 .762 .934 r
.39894 .51708 .41226 .5301 .4347 .52307 .4215 .50994 Metetra
.646 .762 .934 r
.4215 .50994 .4347 .52307 .45732 .51599 .44424 .50275 Metetra
.646 .762 .934 r
.44424 .50275 .45732 .51599 .48014 .50884 .46718 .49549 Metetra
.646 .762 .934 r
.46718 .49549 .48014 .50884 .50314 .50163 .49031 .48817 Metetra
.646 .762 .934 r
.49031 .48817 .50314 .50163 .52634 .49436 .51364 .48078 Metetra
.646 .762 .934 r
.51364 .48078 .52634 .49436 .54974 .48704 .53717 .47334 Metetra
.646 .762 .934 r
.53717 .47334 .54974 .48704 .57334 .47964 .5609 .46583 Metetra
.646 .762 .934 r
.5609 .46583 .57334 .47964 .59714 .47219 .58483 .45825 Metetra
.646 .762 .934 r
.58483 .45825 .59714 .47219 .62114 .46467 .60898 .45061 Metetra
.646 .762 .934 r
.60898 .45061 .62114 .46467 .64536 .45708 .63333 .4429 Metetra
.646 .762 .934 r
.63333 .4429 .64536 .45708 .66978 .44943 .6579 .43513 Metetra
.646 .762 .934 r
.6579 .43513 .66978 .44943 .69442 .44171 .68269 .42729 Metetra
.646 .762 .934 r
.68269 .42729 .69442 .44171 .71927 .43393 .70769 .41937 Metetra
.646 .762 .934 r
.70769 .41937 .71927 .43393 .74434 .42607 .73292 .41139 Metetra
.646 .762 .934 r
.73292 .41139 .74434 .42607 .76964 .41815 .75837 .40334 Metetra
.646 .762 .934 r
.75837 .40334 .76964 .41815 .79516 .41016 .78405 .39521 Metetra
.986 .752 .496 r
.78405 .39521 .79516 .41016 .81009 .28428 .79946 .26882 Metetra
.656 .751 .92 r
.14062 .474 .15482 .48639 .17464 .4797 .16053 .46721 Metetra
.656 .751 .92 r
.16053 .46721 .17464 .4797 .19462 .47295 .18059 .46037 Metetra
.945 .625 .396 r
.18059 .46037 .19462 .47295 .20414 .57873 .18964 .56645 Metetra
.646 .762 .934 r
.18964 .56645 .20414 .57873 .22508 .5721 .21069 .55972 Metetra
.646 .762 .934 r
.21069 .55972 .22508 .5721 .2462 .56542 .2319 .55294 Metetra
.646 .762 .934 r
.2319 .55294 .2462 .56542 .26748 .55868 .25329 .5461 Metetra
.646 .762 .934 r
.25329 .5461 .26748 .55868 .28894 .55189 .27486 .53921 Metetra
.646 .762 .934 r
.27486 .53921 .28894 .55189 .31058 .54504 .2966 .53225 Metetra
.646 .762 .934 r
.2966 .53225 .31058 .54504 .3324 .53814 .31853 .52524 Metetra
.646 .762 .934 r
.31853 .52524 .3324 .53814 .3544 .53118 .34064 .51817 Metetra
.646 .762 .934 r
.34064 .51817 .3544 .53118 .37658 .52416 .36293 .51105 Metetra
.646 .762 .934 r
.36293 .51105 .37658 .52416 .39894 .51708 .38542 .50386 Metetra
.646 .762 .934 r
.38542 .50386 .39894 .51708 .4215 .50994 .40809 .49661 Metetra
.646 .762 .934 r
.40809 .49661 .4215 .50994 .44424 .50275 .43095 .4893 Metetra
.646 .762 .934 r
.43095 .4893 .44424 .50275 .46718 .49549 .45401 .48192 Metetra
.646 .762 .934 r
.45401 .48192 .46718 .49549 .49031 .48817 .47727 .47449 Metetra
.646 .762 .934 r
.47727 .47449 .49031 .48817 .51364 .48078 .50073 .46699 Metetra
.646 .762 .934 r
.50073 .46699 .51364 .48078 .53717 .47334 .52439 .45942 Metetra
.646 .762 .934 r
.52439 .45942 .53717 .47334 .5609 .46583 .54826 .45179 Metetra
.646 .762 .934 r
.54826 .45179 .5609 .46583 .58483 .45825 .57233 .44409 Metetra
.646 .762 .934 r
.57233 .44409 .58483 .45825 .60898 .45061 .59662 .43633 Metetra
.646 .762 .934 r
.59662 .43633 .60898 .45061 .63333 .4429 .62112 .4285 Metetra
.646 .762 .934 r
.62112 .4285 .63333 .4429 .6579 .43513 .64583 .42059 Metetra
.646 .762 .934 r
.64583 .42059 .6579 .43513 .68269 .42729 .67076 .41262 Metetra
.646 .762 .934 r
.67076 .41262 .68269 .42729 .70769 .41937 .69592 .40458 Metetra
.646 .762 .934 r
.69592 .40458 .70769 .41937 .73292 .41139 .7213 .39646 Metetra
.646 .762 .934 r
.7213 .39646 .73292 .41139 .75837 .40334 .74691 .38828 Metetra
.646 .762 .934 r
.74691 .38828 .75837 .40334 .78405 .39521 .77275 .38001 Metetra
.986 .752 .496 r
.77275 .38001 .78405 .39521 .79946 .26882 .78866 .2531 Metetra
.656 .751 .92 r
.12621 .46142 .14062 .474 .16053 .46721 .14621 .45454 Metetra
.656 .751 .92 r
.14621 .45454 .16053 .46721 .18059 .46037 .16637 .4476 Metetra
.945 .625 .396 r
.16637 .4476 .18059 .46037 .18964 .56645 .17493 .55399 Metetra
.646 .762 .934 r
.17493 .55399 .18964 .56645 .21069 .55972 .19607 .54716 Metetra
.646 .762 .934 r
.19607 .54716 .21069 .55972 .2319 .55294 .21739 .54027 Metetra
.646 .762 .934 r
.21739 .54027 .2319 .55294 .25329 .5461 .23889 .53333 Metetra
.646 .762 .934 r
.23889 .53333 .25329 .5461 .27486 .53921 .26056 .52632 Metetra
.646 .762 .934 r
.26056 .52632 .27486 .53921 .2966 .53225 .28241 .51926 Metetra
.646 .762 .934 r
.28241 .51926 .2966 .53225 .31853 .52524 .30445 .51215 Metetra
.646 .762 .934 r
.30445 .51215 .31853 .52524 .34064 .51817 .32667 .50497 Metetra
.646 .762 .934 r
.32667 .50497 .34064 .51817 .36293 .51105 .34908 .49773 Metetra
.646 .762 .934 r
.34908 .49773 .36293 .51105 .38542 .50386 .37168 .49043 Metetra
.646 .762 .934 r
.37168 .49043 .38542 .50386 .40809 .49661 .39447 .48306 Metetra
.646 .762 .934 r
.39447 .48306 .40809 .49661 .43095 .4893 .41746 .47564 Metetra
.646 .762 .934 r
.41746 .47564 .43095 .4893 .45401 .48192 .44064 .46815 Metetra
.646 .762 .934 r
.44064 .46815 .45401 .48192 .47727 .47449 .46403 .46059 Metetra
.646 .762 .934 r
.46403 .46059 .47727 .47449 .50073 .46699 .48762 .45297 Metetra
.646 .762 .934 r
.48762 .45297 .50073 .46699 .52439 .45942 .51141 .44528 Metetra
.646 .762 .934 r
.51141 .44528 .52439 .45942 .54826 .45179 .53541 .43753 Metetra
.646 .762 .934 r
.53541 .43753 .54826 .45179 .57233 .44409 .55963 .42971 Metetra
.646 .762 .934 r
.55963 .42971 .57233 .44409 .59662 .43633 .58405 .42182 Metetra
.646 .762 .934 r
.58405 .42182 .59662 .43633 .62112 .4285 .6087 .41385 Metetra
.646 .762 .934 r
.6087 .41385 .62112 .4285 .64583 .42059 .63356 .40582 Metetra
.646 .762 .934 r
.63356 .40582 .64583 .42059 .67076 .41262 .65864 .39772 Metetra
.646 .762 .934 r
.65864 .39772 .67076 .41262 .69592 .40458 .68396 .38954 Metetra
.646 .762 .934 r
.68396 .38954 .69592 .40458 .7213 .39646 .70949 .38129 Metetra
.646 .762 .934 r
.70949 .38129 .7213 .39646 .74691 .38828 .73527 .37296 Metetra
.646 .762 .934 r
.73527 .37296 .74691 .38828 .77275 .38001 .76127 .36456 Metetra
.986 .752 .496 r
.76127 .36456 .77275 .38001 .78866 .2531 .77769 .23713 Metetra
.656 .751 .92 r
.1116 .44867 .12621 .46142 .14621 .45454 .13169 .44168 Metetra
.656 .751 .92 r
.13169 .44168 .14621 .45454 .16637 .4476 .15193 .43464 Metetra
.945 .625 .396 r
.15193 .43464 .16637 .4476 .17493 .55399 .16 .54133 Metetra
.646 .762 .934 r
.16 .54133 .17493 .55399 .19607 .54716 .18124 .5344 Metetra
.646 .762 .934 r
.18124 .5344 .19607 .54716 .21739 .54027 .20266 .52741 Metetra
.646 .762 .934 r
.20266 .52741 .21739 .54027 .23889 .53333 .22426 .52035 Metetra
.646 .762 .934 r
.22426 .52035 .23889 .53333 .26056 .52632 .24603 .51324 Metetra
.646 .762 .934 r
.24603 .51324 .26056 .52632 .28241 .51926 .268 .50608 Metetra
.646 .762 .934 r
.268 .50608 .28241 .51926 .30445 .51215 .29014 .49884 Metetra
.646 .762 .934 r
.29014 .49884 .30445 .51215 .32667 .50497 .31248 .49155 Metetra
.646 .762 .934 r
.31248 .49155 .32667 .50497 .34908 .49773 .335 .4842 Metetra
.646 .762 .934 r
.335 .4842 .34908 .49773 .37168 .49043 .35772 .47678 Metetra
.646 .762 .934 r
.35772 .47678 .37168 .49043 .39447 .48306 .38064 .4693 Metetra
.646 .762 .934 r
.38064 .4693 .39447 .48306 .41746 .47564 .40375 .46176 Metetra
.646 .762 .934 r
.40375 .46176 .41746 .47564 .44064 .46815 .42706 .45415 Metetra
.646 .762 .934 r
.42706 .45415 .44064 .46815 .46403 .46059 .45057 .44647 Metetra
.646 .762 .934 r
.45057 .44647 .46403 .46059 .48762 .45297 .47429 .43873 Metetra
.646 .762 .934 r
.47429 .43873 .48762 .45297 .51141 .44528 .49822 .43091 Metetra
.646 .762 .934 r
.49822 .43091 .51141 .44528 .53541 .43753 .52236 .42303 Metetra
.646 .762 .934 r
.52236 .42303 .53541 .43753 .55963 .42971 .54671 .41508 Metetra
.646 .762 .934 r
.54671 .41508 .55963 .42971 .58405 .42182 .57128 .40706 Metetra
.646 .762 .934 r
.57128 .40706 .58405 .42182 .6087 .41385 .59607 .39897 Metetra
.646 .762 .934 r
.59607 .39897 .6087 .41385 .63356 .40582 .62109 .3908 Metetra
.646 .762 .934 r
.62109 .3908 .63356 .40582 .65864 .39772 .64632 .38256 Metetra
.646 .762 .934 r
.64632 .38256 .65864 .39772 .68396 .38954 .67179 .37425 Metetra
.646 .762 .934 r
.67179 .37425 .68396 .38954 .70949 .38129 .69749 .36586 Metetra
.646 .762 .934 r
.69749 .36586 .70949 .38129 .73527 .37296 .72342 .35739 Metetra
.646 .762 .934 r
.72342 .35739 .73527 .37296 .76127 .36456 .74959 .34885 Metetra
.986 .752 .496 r
.74959 .34885 .76127 .36456 .77769 .23713 .76653 .22089 Metetra
.656 .751 .92 r
.09677 .43573 .1116 .44867 .13169 .44168 .11695 .42864 Metetra
.656 .751 .92 r
.11695 .42864 .13169 .44168 .15193 .43464 .13729 .4215 Metetra
.945 .625 .396 r
.13729 .4215 .15193 .43464 .16 .54133 .14483 .52849 Metetra
.646 .762 .934 r
.14483 .52849 .16 .54133 .18124 .5344 .16618 .52144 Metetra
.646 .762 .934 r
.16618 .52144 .18124 .5344 .20266 .52741 .1877 .51434 Metetra
.646 .762 .934 r
.1877 .51434 .20266 .52741 .22426 .52035 .2094 .50718 Metetra
.646 .762 .934 r
.2094 .50718 .22426 .52035 .24603 .51324 .23129 .49996 Metetra
.646 .762 .934 r
.23129 .49996 .24603 .51324 .268 .50608 .25336 .49268 Metetra
.646 .762 .934 r
.25336 .49268 .268 .50608 .29014 .49884 .27562 .48533 Metetra
.646 .762 .934 r
.27562 .48533 .29014 .49884 .31248 .49155 .29806 .47793 Metetra
.646 .762 .934 r
.29806 .47793 .31248 .49155 .335 .4842 .32071 .47046 Metetra
.646 .762 .934 r
.32071 .47046 .335 .4842 .35772 .47678 .34354 .46292 Metetra
.646 .762 .934 r
.34354 .46292 .35772 .47678 .38064 .4693 .36658 .45532 Metetra
.646 .762 .934 r
.36658 .45532 .38064 .4693 .40375 .46176 .38981 .44766 Metetra
.646 .762 .934 r
.38981 .44766 .40375 .46176 .42706 .45415 .41325 .43992 Metetra
.646 .762 .934 r
.41325 .43992 .42706 .45415 .45057 .44647 .4369 .43212 Metetra
.646 .762 .934 r
.4369 .43212 .45057 .44647 .47429 .43873 .46075 .42425 Metetra
.646 .762 .934 r
.46075 .42425 .47429 .43873 .49822 .43091 .48481 .41631 Metetra
.646 .762 .934 r
.48481 .41631 .49822 .43091 .52236 .42303 .50909 .4083 Metetra
.646 .762 .934 r
.50909 .4083 .52236 .42303 .54671 .41508 .53359 .40022 Metetra
.646 .762 .934 r
.53359 .40022 .54671 .41508 .57128 .40706 .5583 .39206 Metetra
.646 .762 .934 r
.5583 .39206 .57128 .40706 .59607 .39897 .58324 .38384 Metetra
.646 .762 .934 r
.58324 .38384 .59607 .39897 .62109 .3908 .6084 .37553 Metetra
.646 .762 .934 r
.6084 .37553 .62109 .3908 .64632 .38256 .63379 .36716 Metetra
.646 .762 .934 r
.63379 .36716 .64632 .38256 .67179 .37425 .65942 .3587 Metetra
.646 .762 .934 r
.65942 .3587 .67179 .37425 .69749 .36586 .68528 .35017 Metetra
.646 .762 .934 r
.68528 .35017 .69749 .36586 .72342 .35739 .71138 .34156 Metetra
.646 .762 .934 r
.71138 .34156 .72342 .35739 .74959 .34885 .73771 .33287 Metetra
.986 .752 .496 r
.73771 .33287 .74959 .34885 .76653 .22089 .75519 .20439 Metetra
.656 .751 .92 r
.08173 .4226 .09677 .43573 .11695 .42864 .10199 .4154 Metetra
.656 .751 .92 r
.10199 .4154 .11695 .42864 .13729 .4215 .12242 .40815 Metetra
.945 .625 .396 r
.12242 .40815 .13729 .4215 .14483 .52849 .12944 .51544 Metetra
.646 .762 .934 r
.12944 .51544 .14483 .52849 .16618 .52144 .15088 .50829 Metetra
.646 .762 .934 r
.15088 .50829 .16618 .52144 .1877 .51434 .1725 .50108 Metetra
.646 .762 .934 r
.1725 .50108 .1877 .51434 .2094 .50718 .19431 .4938 Metetra
.646 .762 .934 r
.19431 .4938 .2094 .50718 .23129 .49996 .2163 .48647 Metetra
.646 .762 .934 r
.2163 .48647 .23129 .49996 .25336 .49268 .23849 .47907 Metetra
.646 .762 .934 r
.23849 .47907 .25336 .49268 .27562 .48533 .26086 .47161 Metetra
.646 .762 .934 r
.26086 .47161 .27562 .48533 .29806 .47793 .28342 .46409 Metetra
.646 .762 .934 r
.28342 .46409 .29806 .47793 .32071 .47046 .30618 .4565 Metetra
.646 .762 .934 r
.30618 .4565 .32071 .47046 .34354 .46292 .32914 .44884 Metetra
.646 .762 .934 r
.32914 .44884 .34354 .46292 .36658 .45532 .3523 .44112 Metetra
.646 .762 .934 r
.3523 .44112 .36658 .45532 .38981 .44766 .37566 .43333 Metetra
.646 .762 .934 r
.37566 .43333 .38981 .44766 .41325 .43992 .39922 .42547 Metetra
.646 .762 .934 r
.39922 .42547 .41325 .43992 .4369 .43212 .423 .41754 Metetra
.646 .762 .934 r
.423 .41754 .4369 .43212 .46075 .42425 .44699 .40954 Metetra
.646 .762 .934 r
.44699 .40954 .46075 .42425 .48481 .41631 .47119 .40147 Metetra
.646 .762 .934 r
.47119 .40147 .48481 .41631 .50909 .4083 .4956 .39332 Metetra
.646 .762 .934 r
.4956 .39332 .50909 .4083 .53359 .40022 .52024 .38511 Metetra
.646 .762 .934 r
.52024 .38511 .53359 .40022 .5583 .39206 .5451 .37682 Metetra
.646 .762 .934 r
.5451 .37682 .5583 .39206 .58324 .38384 .57019 .36845 Metetra
.646 .762 .934 r
.57019 .36845 .58324 .38384 .6084 .37553 .59551 .36001 Metetra
.646 .762 .934 r
.59551 .36001 .6084 .37553 .63379 .36716 .62105 .35149 Metetra
.646 .762 .934 r
.62105 .35149 .63379 .36716 .65942 .3587 .64684 .34289 Metetra
.646 .762 .934 r
.64684 .34289 .65942 .3587 .68528 .35017 .67286 .33421 Metetra
.646 .762 .934 r
.67286 .33421 .68528 .35017 .71138 .34156 .69912 .32545 Metetra
.646 .762 .934 r
.69912 .32545 .71138 .34156 .73771 .33287 .72563 .31661 Metetra
.986 .752 .496 r
.72563 .31661 .73771 .33287 .75519 .20439 .74366 .18761 Metetra
.656 .751 .92 r
.06646 .40927 .08173 .4226 .10199 .4154 .08681 .40197 Metetra
.656 .751 .92 r
.08681 .40197 .10199 .4154 .12242 .40815 .10733 .39461 Metetra
.945 .625 .396 r
.10733 .39461 .12242 .40815 .12944 .51544 .1138 .50219 Metetra
.646 .762 .934 r
.1138 .50219 .12944 .51544 .15088 .50829 .13534 .49493 Metetra
.646 .762 .934 r
.13534 .49493 .15088 .50829 .1725 .50108 .15707 .4876 Metetra
.646 .762 .934 r
.15707 .4876 .1725 .50108 .19431 .4938 .17898 .48021 Metetra
.646 .762 .934 r
.17898 .48021 .19431 .4938 .2163 .48647 .20109 .47276 Metetra
.646 .762 .934 r
.20109 .47276 .2163 .48647 .23849 .47907 .22338 .46525 Metetra
.646 .762 .934 r
.22338 .46525 .23849 .47907 .26086 .47161 .24586 .45767 Metetra
.646 .762 .934 r
.24586 .45767 .26086 .47161 .28342 .46409 .26854 .45002 Metetra
.646 .762 .934 r
.26854 .45002 .28342 .46409 .30618 .4565 .29142 .44231 Metetra
.646 .762 .934 r
.29142 .44231 .30618 .4565 .32914 .44884 .3145 .43453 Metetra
.646 .762 .934 r
.3145 .43453 .32914 .44884 .3523 .44112 .33778 .42668 Metetra
.646 .762 .934 r
.33778 .42668 .3523 .44112 .37566 .43333 .36127 .41876 Metetra
.646 .762 .934 r
.36127 .41876 .37566 .43333 .39922 .42547 .38497 .41077 Metetra
.646 .762 .934 r
.38497 .41077 .39922 .42547 .423 .41754 .40887 .40271 Metetra
.646 .762 .934 r
.40887 .40271 .423 .41754 .44699 .40954 .43299 .39458 Metetra
.646 .762 .934 r
.43299 .39458 .44699 .40954 .47119 .40147 .45733 .38638 Metetra
.646 .762 .934 r
.45733 .38638 .47119 .40147 .4956 .39332 .48189 .3781 Metetra
.646 .762 .934 r
.48189 .3781 .4956 .39332 .52024 .38511 .50667 .36974 Metetra
.646 .762 .934 r
.50667 .36974 .52024 .38511 .5451 .37682 .53168 .36131 Metetra
.646 .762 .934 r
.53168 .36131 .5451 .37682 .57019 .36845 .55692 .3528 Metetra
.646 .762 .934 r
.55692 .3528 .57019 .36845 .59551 .36001 .58239 .34422 Metetra
.646 .762 .934 r
.58239 .34422 .59551 .36001 .62105 .35149 .60809 .33555 Metetra
.646 .762 .934 r
.60809 .33555 .62105 .35149 .64684 .34289 .63404 .3268 Metetra
.646 .762 .934 r
.63404 .3268 .64684 .34289 .67286 .33421 .66023 .31798 Metetra
.646 .762 .934 r
.66023 .31798 .67286 .33421 .69912 .32545 .68666 .30907 Metetra
.646 .762 .934 r
.68666 .30907 .69912 .32545 .72563 .31661 .71334 .30007 Metetra
.986 .752 .496 r
.71334 .30007 .72563 .31661 .74366 .18761 .73194 .17055 Metetra
.656 .751 .92 r
.05096 .39575 .06646 .40927 .08681 .40197 .07141 .38834 Metetra
.656 .751 .92 r
.07141 .38834 .08681 .40197 .10733 .39461 .09202 .38086 Metetra
.656 .751 .92 r
.09202 .38086 .10733 .39461 .1138 .50219 .1128 .37333 Metetra
.545 .355 .575 r
.1128 .37333 .1138 .50219 .13534 .49493 .13375 .36574 Metetra
.545 .355 .575 r
.13375 .36574 .13534 .49493 .15707 .4876 .15487 .35808 Metetra
.545 .355 .575 r
.15487 .35808 .15707 .4876 .17898 .48021 .17617 .35036 Metetra
.545 .355 .575 r
.17617 .35036 .17898 .48021 .20109 .47276 .19765 .34257 Metetra
.545 .355 .575 r
.19765 .34257 .20109 .47276 .22338 .46525 .2193 .33472 Metetra
.545 .355 .575 r
.2193 .33472 .22338 .46525 .24586 .45767 .24114 .3268 Metetra
.545 .355 .575 r
.24114 .3268 .24586 .45767 .26854 .45002 .26316 .31882 Metetra
.545 .355 .575 r
.26316 .31882 .26854 .45002 .29142 .44231 .28537 .31077 Metetra
.545 .355 .575 r
.28537 .31077 .29142 .44231 .3145 .43453 .30777 .30265 Metetra
.545 .355 .575 r
.30777 .30265 .3145 .43453 .33778 .42668 .33036 .29446 Metetra
.545 .355 .575 r
.33036 .29446 .33778 .42668 .36127 .41876 .35315 .2862 Metetra
.545 .355 .575 r
.35315 .2862 .36127 .41876 .38497 .41077 .37613 .27787 Metetra
.545 .355 .575 r
.37613 .27787 .38497 .41077 .40887 .40271 .39931 .26947 Metetra
.545 .355 .575 r
.39931 .26947 .40887 .40271 .43299 .39458 .42269 .26099 Metetra
.545 .355 .575 r
.42269 .26099 .43299 .39458 .45733 .38638 .44628 .25244 Metetra
.545 .355 .575 r
.44628 .25244 .45733 .38638 .48189 .3781 .47007 .24381 Metetra
.545 .355 .575 r
.47007 .24381 .48189 .3781 .50667 .36974 .49408 .23511 Metetra
.545 .355 .575 r
.49408 .23511 .50667 .36974 .53168 .36131 .51829 .22633 Metetra
.545 .355 .575 r
.51829 .22633 .53168 .36131 .55692 .3528 .54272 .21748 Metetra
.545 .355 .575 r
.54272 .21748 .55692 .3528 .58239 .34422 .56737 .20854 Metetra
.545 .355 .575 r
.56737 .20854 .58239 .34422 .60809 .33555 .59224 .19952 Metetra
.545 .355 .575 r
.59224 .19952 .60809 .33555 .63404 .3268 .61734 .19043 Metetra
.545 .355 .575 r
.61734 .19043 .63404 .3268 .66023 .31798 .64266 .18125 Metetra
.545 .355 .575 r
.64266 .18125 .66023 .31798 .68666 .30907 .66821 .17198 Metetra
.545 .355 .575 r
.66821 .17198 .68666 .30907 .71334 .30007 .694 .16264 Metetra
.545 .355 .575 r
.694 .16264 .71334 .30007 .73194 .17055 .72002 .1532 Metetra
.656 .751 .92 r
.03523 .38202 .05096 .39575 .07141 .38834 .05577 .37449 Metetra
.656 .751 .92 r
.05577 .37449 .07141 .38834 .09202 .38086 .07647 .36691 Metetra
.656 .751 .92 r
.07647 .36691 .09202 .38086 .1128 .37333 .09734 .35926 Metetra
.656 .751 .92 r
.09734 .35926 .1128 .37333 .13375 .36574 .11839 .35155 Metetra
.656 .751 .92 r
.11839 .35155 .13375 .36574 .15487 .35808 .13961 .34377 Metetra
.656 .751 .92 r
.13961 .34377 .15487 .35808 .17617 .35036 .16101 .33593 Metetra
.656 .751 .92 r
.16101 .33593 .17617 .35036 .19765 .34257 .18259 .32803 Metetra
.656 .751 .92 r
.18259 .32803 .19765 .34257 .2193 .33472 .20435 .32005 Metetra
.656 .751 .92 r
.20435 .32005 .2193 .33472 .24114 .3268 .2263 .31201 Metetra
.656 .751 .92 r
.2263 .31201 .24114 .3268 .26316 .31882 .24843 .3039 Metetra
.656 .751 .92 r
.24843 .3039 .26316 .31882 .28537 .31077 .27075 .29572 Metetra
.656 .751 .92 r
.27075 .29572 .28537 .31077 .30777 .30265 .29327 .28747 Metetra
.656 .751 .92 r
.29327 .28747 .30777 .30265 .33036 .29446 .31598 .27915 Metetra
.656 .751 .92 r
.31598 .27915 .33036 .29446 .35315 .2862 .33888 .27076 Metetra
.656 .751 .92 r
.33888 .27076 .35315 .2862 .37613 .27787 .36198 .2623 Metetra
.656 .751 .92 r
.36198 .2623 .37613 .27787 .39931 .26947 .38529 .25376 Metetra
.656 .751 .92 r
.38529 .25376 .39931 .26947 .42269 .26099 .4088 .24514 Metetra
.656 .751 .92 r
.4088 .24514 .42269 .26099 .44628 .25244 .43252 .23645 Metetra
.656 .751 .92 r
.43252 .23645 .44628 .25244 .47007 .24381 .45644 .22769 Metetra
.656 .751 .92 r
.45644 .22769 .47007 .24381 .49408 .23511 .48058 .21884 Metetra
.656 .751 .92 r
.48058 .21884 .49408 .23511 .51829 .22633 .50494 .20992 Metetra
.656 .751 .92 r
.50494 .20992 .51829 .22633 .54272 .21748 .52951 .20092 Metetra
.656 .751 .92 r
.52951 .20092 .54272 .21748 .56737 .20854 .55431 .19183 Metetra
.656 .751 .92 r
.55431 .19183 .56737 .20854 .59224 .19952 .57933 .18266 Metetra
.656 .751 .92 r
.57933 .18266 .59224 .19952 .61734 .19043 .60457 .17341 Metetra
.656 .751 .92 r
.60457 .17341 .61734 .19043 .64266 .18125 .63005 .16408 Metetra
.656 .751 .92 r
.63005 .16408 .64266 .18125 .66821 .17198 .65576 .15466 Metetra
.656 .751 .92 r
.65576 .15466 .66821 .17198 .694 .16264 .68171 .14515 Metetra
.656 .751 .92 r
.68171 .14515 .694 .16264 .72002 .1532 .7079 .13556 Metetra
.656 .751 .92 r
.01926 .36808 .03523 .38202 .05577 .37449 .03989 .36044 Metetra
.656 .751 .92 r
.03989 .36044 .05577 .37449 .07647 .36691 .06068 .35274 Metetra
.656 .751 .92 r
.06068 .35274 .07647 .36691 .09734 .35926 .08165 .34497 Metetra
.656 .751 .92 r
.08165 .34497 .09734 .35926 .11839 .35155 .10279 .33714 Metetra
.656 .751 .92 r
.10279 .33714 .11839 .35155 .13961 .34377 .12411 .32925 Metetra
.656 .751 .92 r
.12411 .32925 .13961 .34377 .16101 .33593 .14562 .32128 Metetra
.656 .751 .92 r
.14562 .32128 .16101 .33593 .18259 .32803 .1673 .31325 Metetra
.656 .751 .92 r
.1673 .31325 .18259 .32803 .20435 .32005 .18917 .30515 Metetra
.656 .751 .92 r
.18917 .30515 .20435 .32005 .2263 .31201 .21122 .29699 Metetra
.656 .751 .92 r
.21122 .29699 .2263 .31201 .24843 .3039 .23347 .28875 Metetra
.656 .751 .92 r
.23347 .28875 .24843 .3039 .27075 .29572 .2559 .28044 Metetra
.656 .751 .92 r
.2559 .28044 .27075 .29572 .29327 .28747 .27853 .27206 Metetra
.656 .751 .92 r
.27853 .27206 .29327 .28747 .31598 .27915 .30136 .2636 Metetra
.656 .751 .92 r
.30136 .2636 .31598 .27915 .33888 .27076 .32438 .25508 Metetra
.656 .751 .92 r
.32438 .25508 .33888 .27076 .36198 .2623 .34761 .24647 Metetra
.656 .751 .92 r
.34761 .24647 .36198 .2623 .38529 .25376 .37104 .2378 Metetra
.656 .751 .92 r
.37104 .2378 .38529 .25376 .4088 .24514 .39468 .22904 Metetra
.656 .751 .92 r
.39468 .22904 .4088 .24514 .43252 .23645 .41853 .22021 Metetra
.656 .751 .92 r
.41853 .22021 .43252 .23645 .45644 .22769 .44259 .2113 Metetra
.656 .751 .92 r
.44259 .2113 .45644 .22769 .48058 .21884 .46687 .20231 Metetra
.656 .751 .92 r
.46687 .20231 .48058 .21884 .50494 .20992 .49136 .19323 Metetra
.656 .751 .92 r
.49136 .19323 .50494 .20992 .52951 .20092 .51608 .18408 Metetra
.656 .751 .92 r
.51608 .18408 .52951 .20092 .55431 .19183 .54102 .17484 Metetra
.656 .751 .92 r
.54102 .17484 .55431 .19183 .57933 .18266 .56619 .16552 Metetra
.656 .751 .92 r
.56619 .16552 .57933 .18266 .60457 .17341 .59159 .15611 Metetra
.656 .751 .92 r
.59159 .15611 .60457 .17341 .63005 .16408 .61722 .14662 Metetra
.656 .751 .92 r
.61722 .14662 .63005 .16408 .65576 .15466 .6431 .13704 Metetra
.656 .751 .92 r
.6431 .13704 .65576 .15466 .68171 .14515 .66921 .12737 Metetra
.656 .751 .92 r
.66921 .12737 .68171 .14515 .7079 .13556 .69556 .11761 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((I  I)\)\) \((x, y)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  ", which is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((I)\)\) \((y, x)\)\)], "InlineFormula",
    CellTags->"S1.5.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.4", "4.15"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[psi[x] phi[y]], {x, -0.1, 1},
{y, -0.1, 1}, PlotPoints -> 30, PlotRange -> All,
Boxed -> False, Axes -> False];\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
8.83083e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.656 .751 .92 r
.39082 .69236 .40169 .70185 .41987 .69673 .40908 .68717 Metetra
.656 .751 .92 r
.40908 .68717 .41987 .69673 .43818 .69156 .42746 .68194 Metetra
.945 .625 .396 r
.42746 .68194 .43818 .69156 .45661 .68637 .44361 .78163 Metetra
.547 .302 .496 r
.44361 .78163 .45661 .68637 .47517 .68114 .4628 .77654 Metetra
.547 .302 .496 r
.4628 .77654 .47517 .68114 .49385 .67587 .48213 .77142 Metetra
.547 .302 .496 r
.48213 .77142 .49385 .67587 .51267 .67056 .50159 .76626 Metetra
.547 .302 .496 r
.50159 .76626 .51267 .67056 .53161 .66522 .5212 .76107 Metetra
.547 .302 .496 r
.5212 .76107 .53161 .66522 .55068 .65984 .54094 .75583 Metetra
.547 .302 .496 r
.54094 .75583 .55068 .65984 .56989 .65443 .56083 .75056 Metetra
.547 .302 .496 r
.56083 .75056 .56989 .65443 .58923 .64898 .58086 .74525 Metetra
.547 .302 .496 r
.58086 .74525 .58923 .64898 .60871 .64349 .60104 .7399 Metetra
.547 .302 .496 r
.60104 .7399 .60871 .64349 .62832 .63796 .62136 .73452 Metetra
.547 .302 .496 r
.62136 .73452 .62832 .63796 .64807 .63239 .64184 .72909 Metetra
.547 .302 .496 r
.64184 .72909 .64807 .63239 .66796 .62678 .66246 .72363 Metetra
.547 .302 .496 r
.66246 .72363 .66796 .62678 .688 .62113 .68324 .71812 Metetra
.715 .61 .041 r
.68324 .71812 .688 .62113 .70817 .61544 .69356 .50347 Metetra
.594 .42 .616 r
.69356 .50347 .70817 .61544 .72849 .60972 .71336 .49748 Metetra
.594 .42 .616 r
.71336 .49748 .72849 .60972 .74896 .60395 .73329 .49146 Metetra
.594 .42 .616 r
.73329 .49146 .74896 .60395 .76957 .59813 .75337 .48538 Metetra
.594 .42 .616 r
.75337 .48538 .76957 .59813 .79033 .59228 .77358 .47927 Metetra
.594 .42 .616 r
.77358 .47927 .79033 .59228 .81124 .58638 .79394 .47311 Metetra
.594 .42 .616 r
.79394 .47311 .81124 .58638 .83231 .58045 .81445 .46691 Metetra
.594 .42 .616 r
.81445 .46691 .83231 .58045 .85352 .57446 .8351 .46067 Metetra
.594 .42 .616 r
.8351 .46067 .85352 .57446 .8749 .56844 .8559 .45438 Metetra
.594 .42 .616 r
.8559 .45438 .8749 .56844 .89643 .56237 .87685 .44804 Metetra
.594 .42 .616 r
.87685 .44804 .89643 .56237 .91812 .55625 .89795 .44166 Metetra
.594 .42 .616 r
.89795 .44166 .91812 .55625 .93997 .55009 .9192 .43523 Metetra
.594 .42 .616 r
.9192 .43523 .93997 .55009 .96198 .54388 .94061 .42876 Metetra
.272 .203 .594 r
.94061 .42876 .96198 .54388 .98416 .53763 .97615 .52596 Metetra
.656 .751 .92 r
.3798 .68275 .39082 .69236 .40908 .68717 .39814 .67749 Metetra
.656 .751 .92 r
.39814 .67749 .40908 .68717 .42746 .68194 .41661 .6722 Metetra
.945 .625 .396 r
.41661 .6722 .42746 .68194 .44361 .78163 .43249 .77221 Metetra
.646 .762 .934 r
.43249 .77221 .44361 .78163 .4628 .77654 .45177 .76706 Metetra
.646 .762 .934 r
.45177 .76706 .4628 .77654 .48213 .77142 .47118 .76187 Metetra
.646 .762 .934 r
.47118 .76187 .48213 .77142 .50159 .76626 .49074 .75664 Metetra
.646 .762 .934 r
.49074 .75664 .50159 .76626 .5212 .76107 .51044 .75138 Metetra
.646 .762 .934 r
.51044 .75138 .5212 .76107 .54094 .75583 .53027 .74607 Metetra
.646 .762 .934 r
.53027 .74607 .54094 .75583 .56083 .75056 .55026 .74073 Metetra
.646 .762 .934 r
.55026 .74073 .56083 .75056 .58086 .74525 .57038 .73535 Metetra
.646 .762 .934 r
.57038 .73535 .58086 .74525 .60104 .7399 .59066 .72993 Metetra
.646 .762 .934 r
.59066 .72993 .60104 .7399 .62136 .73452 .61108 .72447 Metetra
.646 .762 .934 r
.61108 .72447 .62136 .73452 .64184 .72909 .63166 .71897 Metetra
.646 .762 .934 r
.63166 .71897 .64184 .72909 .66246 .72363 .65239 .71343 Metetra
.646 .762 .934 r
.65239 .71343 .66246 .72363 .68324 .71812 .67327 .70785 Metetra
.964 .717 .513 r
.67327 .70785 .68324 .71812 .69356 .50347 .68422 .49239 Metetra
.664 .741 .908 r
.68422 .49239 .69356 .50347 .71336 .49748 .70411 .48632 Metetra
.664 .741 .908 r
.70411 .48632 .71336 .49748 .73329 .49146 .72414 .48021 Metetra
.664 .741 .908 r
.72414 .48021 .73329 .49146 .75337 .48538 .74431 .47406 Metetra
.664 .741 .908 r
.74431 .47406 .75337 .48538 .77358 .47927 .76463 .46787 Metetra
.664 .741 .908 r
.76463 .46787 .77358 .47927 .79394 .47311 .78509 .46163 Metetra
.664 .741 .908 r
.78509 .46163 .79394 .47311 .81445 .46691 .8057 .45535 Metetra
.664 .741 .908 r
.8057 .45535 .81445 .46691 .8351 .46067 .82646 .44902 Metetra
.664 .741 .908 r
.82646 .44902 .8351 .46067 .8559 .45438 .84737 .44265 Metetra
.664 .741 .908 r
.84737 .44265 .8559 .45438 .87685 .44804 .86842 .43623 Metetra
.664 .741 .908 r
.86842 .43623 .87685 .44804 .89795 .44166 .88963 .42976 Metetra
.664 .741 .908 r
.88963 .42976 .89795 .44166 .9192 .43523 .911 .42325 Metetra
.664 .741 .908 r
.911 .42325 .9192 .43523 .94061 .42876 .93252 .41668 Metetra
.869 .479 .007 r
.93252 .41668 .94061 .42876 .97615 .52596 .96802 .51413 Metetra
.656 .751 .92 r
.36865 .67302 .3798 .68275 .39814 .67749 .38707 .66769 Metetra
.656 .751 .92 r
.38707 .66769 .39814 .67749 .41661 .6722 .40561 .66233 Metetra
.945 .625 .396 r
.40561 .66233 .41661 .6722 .43249 .77221 .42123 .76267 Metetra
.646 .762 .934 r
.42123 .76267 .43249 .77221 .45177 .76706 .44059 .75745 Metetra
.646 .762 .934 r
.44059 .75745 .45177 .76706 .47118 .76187 .4601 .75219 Metetra
.646 .762 .934 r
.4601 .75219 .47118 .76187 .49074 .75664 .47974 .74689 Metetra
.646 .762 .934 r
.47974 .74689 .49074 .75664 .51044 .75138 .49953 .74155 Metetra
.646 .762 .934 r
.49953 .74155 .51044 .75138 .53027 .74607 .51946 .73618 Metetra
.646 .762 .934 r
.51946 .73618 .53027 .74607 .55026 .74073 .53954 .73077 Metetra
.646 .762 .934 r
.53954 .73077 .55026 .74073 .57038 .73535 .55977 .72531 Metetra
.646 .762 .934 r
.55977 .72531 .57038 .73535 .59066 .72993 .58014 .71982 Metetra
.646 .762 .934 r
.58014 .71982 .59066 .72993 .61108 .72447 .60067 .71428 Metetra
.646 .762 .934 r
.60067 .71428 .61108 .72447 .63166 .71897 .62134 .70871 Metetra
.646 .762 .934 r
.62134 .70871 .63166 .71897 .65239 .71343 .64217 .70309 Metetra
.646 .762 .934 r
.64217 .70309 .65239 .71343 .67327 .70785 .66316 .69743 Metetra
.964 .717 .513 r
.66316 .69743 .67327 .70785 .68422 .49239 .67475 .48116 Metetra
.664 .741 .908 r
.67475 .48116 .68422 .49239 .70411 .48632 .69474 .47501 Metetra
.664 .741 .908 r
.69474 .47501 .70411 .48632 .72414 .48021 .71487 .46882 Metetra
.664 .741 .908 r
.71487 .46882 .72414 .48021 .74431 .47406 .73514 .46259 Metetra
.664 .741 .908 r
.73514 .46259 .74431 .47406 .76463 .46787 .75556 .45632 Metetra
.664 .741 .908 r
.75556 .45632 .76463 .46787 .78509 .46163 .77613 .45 Metetra
.664 .741 .908 r
.77613 .45 .78509 .46163 .8057 .45535 .79684 .44363 Metetra
.664 .741 .908 r
.79684 .44363 .8057 .45535 .82646 .44902 .8177 .43722 Metetra
.664 .741 .908 r
.8177 .43722 .82646 .44902 .84737 .44265 .83872 .43076 Metetra
.664 .741 .908 r
.83872 .43076 .84737 .44265 .86842 .43623 .85989 .42425 Metetra
.664 .741 .908 r
.85989 .42425 .86842 .43623 .88963 .42976 .88121 .4177 Metetra
.664 .741 .908 r
.88121 .4177 .88963 .42976 .911 .42325 .90269 .41109 Metetra
.664 .741 .908 r
.90269 .41109 .911 .42325 .93252 .41668 .92432 .40444 Metetra
.869 .479 .007 r
.92432 .40444 .93252 .41668 .96802 .51413 .95977 .50214 Metetra
.656 .751 .92 r
.35736 .66316 .36865 .67302 .38707 .66769 .37585 .65777 Metetra
.656 .751 .92 r
.37585 .65777 .38707 .66769 .40561 .66233 .39448 .65234 Metetra
.945 .625 .396 r
.39448 .65234 .40561 .66233 .42123 .76267 .40982 .753 Metetra
.646 .762 .934 r
.40982 .753 .42123 .76267 .44059 .75745 .42927 .74771 Metetra
.646 .762 .934 r
.42927 .74771 .44059 .75745 .4601 .75219 .44886 .74238 Metetra
.646 .762 .934 r
.44886 .74238 .4601 .75219 .47974 .74689 .4686 .73701 Metetra
.646 .762 .934 r
.4686 .73701 .47974 .74689 .49953 .74155 .48848 .7316 Metetra
.646 .762 .934 r
.48848 .7316 .49953 .74155 .51946 .73618 .50851 .72615 Metetra
.646 .762 .934 r
.50851 .72615 .51946 .73618 .53954 .73077 .52868 .72067 Metetra
.646 .762 .934 r
.52868 .72067 .53954 .73077 .55977 .72531 .549 .71514 Metetra
.646 .762 .934 r
.549 .71514 .55977 .72531 .58014 .71982 .56948 .70957 Metetra
.646 .762 .934 r
.56948 .70957 .58014 .71982 .60067 .71428 .5901 .70396 Metetra
.646 .762 .934 r
.5901 .70396 .60067 .71428 .62134 .70871 .61088 .69831 Metetra
.646 .762 .934 r
.61088 .69831 .62134 .70871 .64217 .70309 .63182 .69261 Metetra
.646 .762 .934 r
.63182 .69261 .64217 .70309 .66316 .69743 .65291 .68687 Metetra
.964 .717 .513 r
.65291 .68687 .66316 .69743 .67475 .48116 .66516 .46978 Metetra
.664 .741 .908 r
.66516 .46978 .67475 .48116 .69474 .47501 .68525 .46355 Metetra
.664 .741 .908 r
.68525 .46355 .69474 .47501 .71487 .46882 .70548 .45729 Metetra
.664 .741 .908 r
.70548 .45729 .71487 .46882 .73514 .46259 .72585 .45097 Metetra
.664 .741 .908 r
.72585 .45097 .73514 .46259 .75556 .45632 .74637 .44461 Metetra
.664 .741 .908 r
.74637 .44461 .75556 .45632 .77613 .45 .76704 .43821 Metetra
.664 .741 .908 r
.76704 .43821 .77613 .45 .79684 .44363 .78786 .43175 Metetra
.664 .741 .908 r
.78786 .43175 .79684 .44363 .8177 .43722 .80883 .42525 Metetra
.664 .741 .908 r
.80883 .42525 .8177 .43722 .83872 .43076 .82995 .41871 Metetra
.664 .741 .908 r
.82995 .41871 .83872 .43076 .85989 .42425 .85123 .41211 Metetra
.664 .741 .908 r
.85123 .41211 .85989 .42425 .88121 .4177 .87267 .40547 Metetra
.664 .741 .908 r
.87267 .40547 .88121 .4177 .90269 .41109 .89426 .39878 Metetra
.664 .741 .908 r
.89426 .39878 .90269 .41109 .92432 .40444 .91601 .39204 Metetra
.869 .479 .007 r
.91601 .39204 .92432 .40444 .95977 .50214 .95141 .48997 Metetra
.656 .751 .92 r
.34592 .65317 .35736 .66316 .37585 .65777 .36449 .64771 Metetra
.656 .751 .92 r
.36449 .64771 .37585 .65777 .39448 .65234 .3832 .64221 Metetra
.945 .625 .396 r
.3832 .64221 .39448 .65234 .40982 .753 .39825 .7432 Metetra
.646 .762 .934 r
.39825 .7432 .40982 .753 .42927 .74771 .41779 .73784 Metetra
.646 .762 .934 r
.41779 .73784 .42927 .74771 .44886 .74238 .43748 .73244 Metetra
.646 .762 .934 r
.43748 .73244 .44886 .74238 .4686 .73701 .4573 .72699 Metetra
.646 .762 .934 r
.4573 .72699 .4686 .73701 .48848 .7316 .47728 .72151 Metetra
.646 .762 .934 r
.47728 .72151 .48848 .7316 .50851 .72615 .4974 .71599 Metetra
.646 .762 .934 r
.4974 .71599 .50851 .72615 .52868 .72067 .51767 .71043 Metetra
.646 .762 .934 r
.51767 .71043 .52868 .72067 .549 .71514 .53809 .70482 Metetra
.646 .762 .934 r
.53809 .70482 .549 .71514 .56948 .70957 .55867 .69918 Metetra
.646 .762 .934 r
.55867 .69918 .56948 .70957 .5901 .70396 .5794 .69349 Metetra
.646 .762 .934 r
.5794 .69349 .5901 .70396 .61088 .69831 .60028 .68776 Metetra
.646 .762 .934 r
.60028 .68776 .61088 .69831 .63182 .69261 .62132 .68199 Metetra
.646 .762 .934 r
.62132 .68199 .63182 .69261 .65291 .68687 .64252 .67617 Metetra
.964 .717 .513 r
.64252 .67617 .65291 .68687 .66516 .46978 .65545 .45825 Metetra
.664 .741 .908 r
.65545 .45825 .66516 .46978 .68525 .46355 .67563 .45195 Metetra
.664 .741 .908 r
.67563 .45195 .68525 .46355 .70548 .45729 .69596 .44559 Metetra
.664 .741 .908 r
.69596 .44559 .70548 .45729 .72585 .45097 .71643 .43919 Metetra
.664 .741 .908 r
.71643 .43919 .72585 .45097 .74637 .44461 .73706 .43275 Metetra
.664 .741 .908 r
.73706 .43275 .74637 .44461 .76704 .43821 .75783 .42626 Metetra
.664 .741 .908 r
.75783 .42626 .76704 .43821 .78786 .43175 .77876 .41972 Metetra
.664 .741 .908 r
.77876 .41972 .78786 .43175 .80883 .42525 .79984 .41313 Metetra
.664 .741 .908 r
.79984 .41313 .80883 .42525 .82995 .41871 .82107 .4065 Metetra
.664 .741 .908 r
.82107 .4065 .82995 .41871 .85123 .41211 .84246 .39981 Metetra
.664 .741 .908 r
.84246 .39981 .85123 .41211 .87267 .40547 .86401 .39308 Metetra
.664 .741 .908 r
.86401 .39308 .87267 .40547 .89426 .39878 .88572 .38629 Metetra
.664 .741 .908 r
.88572 .38629 .89426 .39878 .91601 .39204 .90759 .37946 Metetra
.869 .479 .007 r
.90759 .37946 .91601 .39204 .95141 .48997 .94293 .47763 Metetra
.656 .751 .92 r
.33433 .64306 .34592 .65317 .36449 .64771 .35299 .63753 Metetra
.656 .751 .92 r
.35299 .63753 .36449 .64771 .3832 .64221 .37177 .63196 Metetra
.945 .625 .396 r
.37177 .63196 .3832 .64221 .39825 .7432 .38653 .73327 Metetra
.646 .762 .934 r
.38653 .73327 .39825 .7432 .41779 .73784 .40616 .72783 Metetra
.646 .762 .934 r
.40616 .72783 .41779 .73784 .43748 .73244 .42594 .72236 Metetra
.646 .762 .934 r
.42594 .72236 .43748 .73244 .4573 .72699 .44586 .71684 Metetra
.646 .762 .934 r
.44586 .71684 .4573 .72699 .47728 .72151 .46592 .71129 Metetra
.646 .762 .934 r
.46592 .71129 .47728 .72151 .4974 .71599 .48614 .70569 Metetra
.646 .762 .934 r
.48614 .70569 .4974 .71599 .51767 .71043 .50651 .70005 Metetra
.646 .762 .934 r
.50651 .70005 .51767 .71043 .53809 .70482 .52703 .69437 Metetra
.646 .762 .934 r
.52703 .69437 .53809 .70482 .55867 .69918 .54771 .68864 Metetra
.646 .762 .934 r
.54771 .68864 .55867 .69918 .5794 .69349 .56854 .68288 Metetra
.646 .762 .934 r
.56854 .68288 .5794 .69349 .60028 .68776 .58953 .67707 Metetra
.646 .762 .934 r
.58953 .67707 .60028 .68776 .62132 .68199 .61067 .67121 Metetra
.646 .762 .934 r
.61067 .67121 .62132 .68199 .64252 .67617 .63198 .66531 Metetra
.964 .717 .513 r
.63198 .66531 .64252 .67617 .65545 .45825 .6456 .44657 Metetra
.664 .741 .908 r
.6456 .44657 .65545 .45825 .67563 .45195 .66588 .44018 Metetra
.664 .741 .908 r
.66588 .44018 .67563 .45195 .69596 .44559 .68631 .43374 Metetra
.664 .741 .908 r
.68631 .43374 .69596 .44559 .71643 .43919 .70689 .42726 Metetra
.664 .741 .908 r
.70689 .42726 .71643 .43919 .73706 .43275 .72762 .42073 Metetra
.664 .741 .908 r
.72762 .42073 .73706 .43275 .75783 .42626 .7485 .41415 Metetra
.664 .741 .908 r
.7485 .41415 .75783 .42626 .77876 .41972 .76953 .40752 Metetra
.664 .741 .908 r
.76953 .40752 .77876 .41972 .79984 .41313 .79072 .40084 Metetra
.664 .741 .908 r
.79072 .40084 .79984 .41313 .82107 .4065 .81207 .39412 Metetra
.664 .741 .908 r
.81207 .39412 .82107 .4065 .84246 .39981 .83357 .38734 Metetra
.664 .741 .908 r
.83357 .38734 .84246 .39981 .86401 .39308 .85523 .38051 Metetra
.664 .741 .908 r
.85523 .38051 .86401 .39308 .88572 .38629 .87706 .37364 Metetra
.664 .741 .908 r
.87706 .37364 .88572 .38629 .90759 .37946 .89905 .36671 Metetra
.869 .479 .007 r
.89905 .36671 .90759 .37946 .94293 .47763 .93433 .46511 Metetra
.656 .751 .92 r
.32259 .63282 .33433 .64306 .35299 .63753 .34133 .62721 Metetra
.656 .751 .92 r
.34133 .62721 .35299 .63753 .37177 .63196 .3602 .62157 Metetra
.945 .625 .396 r
.3602 .62157 .37177 .63196 .38653 .73327 .37465 .7232 Metetra
.646 .762 .934 r
.37465 .7232 .38653 .73327 .40616 .72783 .39437 .71769 Metetra
.646 .762 .934 r
.39437 .71769 .40616 .72783 .42594 .72236 .41424 .71214 Metetra
.646 .762 .934 r
.41424 .71214 .42594 .72236 .44586 .71684 .43425 .70655 Metetra
.646 .762 .934 r
.43425 .70655 .44586 .71684 .46592 .71129 .45441 .70092 Metetra
.646 .762 .934 r
.45441 .70092 .46592 .71129 .48614 .70569 .47473 .69525 Metetra
.646 .762 .934 r
.47473 .69525 .48614 .70569 .50651 .70005 .4952 .68953 Metetra
.646 .762 .934 r
.4952 .68953 .50651 .70005 .52703 .69437 .51582 .68377 Metetra
.646 .762 .934 r
.51582 .68377 .52703 .69437 .54771 .68864 .53659 .67796 Metetra
.646 .762 .934 r
.53659 .67796 .54771 .68864 .56854 .68288 .55753 .67211 Metetra
.646 .762 .934 r
.55753 .67211 .56854 .68288 .58953 .67707 .57862 .66622 Metetra
.646 .762 .934 r
.57862 .66622 .58953 .67707 .61067 .67121 .59988 .66028 Metetra
.646 .762 .934 r
.59988 .66028 .61067 .67121 .63198 .66531 .6213 .6543 Metetra
.964 .717 .513 r
.6213 .6543 .63198 .66531 .6456 .44657 .63562 .43474 Metetra
.664 .741 .908 r
.63562 .43474 .6456 .44657 .66588 .44018 .65601 .42826 Metetra
.664 .741 .908 r
.65601 .42826 .66588 .44018 .68631 .43374 .67654 .42174 Metetra
.664 .741 .908 r
.67654 .42174 .68631 .43374 .70689 .42726 .69722 .41516 Metetra
.664 .741 .908 r
.69722 .41516 .70689 .42726 .72762 .42073 .71805 .40854 Metetra
.664 .741 .908 r
.71805 .40854 .72762 .42073 .7485 .41415 .73904 .40187 Metetra
.664 .741 .908 r
.73904 .40187 .7485 .41415 .76953 .40752 .76018 .39515 Metetra
.664 .741 .908 r
.76018 .39515 .76953 .40752 .79072 .40084 .78148 .38839 Metetra
.664 .741 .908 r
.78148 .38839 .79072 .40084 .81207 .39412 .80294 .38157 Metetra
.664 .741 .908 r
.80294 .38157 .81207 .39412 .83357 .38734 .82456 .3747 Metetra
.664 .741 .908 r
.82456 .3747 .83357 .38734 .85523 .38051 .84634 .36777 Metetra
.664 .741 .908 r
.84634 .36777 .85523 .38051 .87706 .37364 .86828 .3608 Metetra
.664 .741 .908 r
.86828 .3608 .87706 .37364 .89905 .36671 .89039 .35377 Metetra
.869 .479 .007 r
.89039 .35377 .89905 .36671 .93433 .46511 .92561 .45241 Metetra
.656 .751 .92 r
.3107 .62244 .32259 .63282 .34133 .62721 .32952 .61676 Metetra
.656 .751 .92 r
.32952 .61676 .34133 .62721 .3602 .62157 .34847 .61104 Metetra
.945 .625 .396 r
.34847 .61104 .3602 .62157 .37465 .7232 .36261 .713 Metetra
.646 .762 .934 r
.36261 .713 .37465 .7232 .39437 .71769 .38242 .70742 Metetra
.646 .762 .934 r
.38242 .70742 .39437 .71769 .41424 .71214 .40238 .70179 Metetra
.646 .762 .934 r
.40238 .70179 .41424 .71214 .43425 .70655 .42249 .69612 Metetra
.646 .762 .934 r
.42249 .69612 .43425 .70655 .45441 .70092 .44274 .69041 Metetra
.646 .762 .934 r
.44274 .69041 .45441 .70092 .47473 .69525 .46316 .68466 Metetra
.646 .762 .934 r
.46316 .68466 .47473 .69525 .4952 .68953 .48372 .67886 Metetra
.646 .762 .934 r
.48372 .67886 .4952 .68953 .51582 .68377 .50444 .67302 Metetra
.646 .762 .934 r
.50444 .67302 .51582 .68377 .53659 .67796 .52532 .66713 Metetra
.646 .762 .934 r
.52532 .66713 .53659 .67796 .55753 .67211 .54636 .6612 Metetra
.646 .762 .934 r
.54636 .6612 .55753 .67211 .57862 .66622 .56756 .65522 Metetra
.646 .762 .934 r
.56756 .65522 .57862 .66622 .59988 .66028 .58893 .6492 Metetra
.646 .762 .934 r
.58893 .6492 .59988 .66028 .6213 .6543 .61046 .64313 Metetra
.964 .717 .513 r
.61046 .64313 .6213 .6543 .63562 .43474 .62551 .42274 Metetra
.664 .741 .908 r
.62551 .42274 .63562 .43474 .65601 .42826 .646 .41618 Metetra
.664 .741 .908 r
.646 .41618 .65601 .42826 .67654 .42174 .66663 .40956 Metetra
.664 .741 .908 r
.66663 .40956 .67654 .42174 .69722 .41516 .68741 .4029 Metetra
.664 .741 .908 r
.68741 .4029 .69722 .41516 .71805 .40854 .70835 .39619 Metetra
.664 .741 .908 r
.70835 .39619 .71805 .40854 .73904 .40187 .72945 .38943 Metetra
.664 .741 .908 r
.72945 .38943 .73904 .40187 .76018 .39515 .7507 .38262 Metetra
.664 .741 .908 r
.7507 .38262 .76018 .39515 .78148 .38839 .77211 .37576 Metetra
.664 .741 .908 r
.77211 .37576 .78148 .38839 .80294 .38157 .79368 .36884 Metetra
.664 .741 .908 r
.79368 .36884 .80294 .38157 .82456 .3747 .81542 .36188 Metetra
.664 .741 .908 r
.81542 .36188 .82456 .3747 .84634 .36777 .83731 .35486 Metetra
.664 .741 .908 r
.83731 .35486 .84634 .36777 .86828 .3608 .85938 .34779 Metetra
.664 .741 .908 r
.85938 .34779 .86828 .3608 .89039 .35377 .88161 .34066 Metetra
.869 .479 .007 r
.88161 .34066 .89039 .35377 .92561 .45241 .91675 .43952 Metetra
.656 .751 .92 r
.29865 .61192 .3107 .62244 .32952 .61676 .31755 .60617 Metetra
.656 .751 .92 r
.31755 .60617 .32952 .61676 .34847 .61104 .33658 .60037 Metetra
.945 .625 .396 r
.33658 .60037 .34847 .61104 .36261 .713 .3504 .70266 Metetra
.646 .762 .934 r
.3504 .70266 .36261 .713 .38242 .70742 .3703 .697 Metetra
.646 .762 .934 r
.3703 .697 .38242 .70742 .40238 .70179 .39035 .69129 Metetra
.646 .762 .934 r
.39035 .69129 .40238 .70179 .42249 .69612 .41056 .68554 Metetra
.646 .762 .934 r
.41056 .68554 .42249 .69612 .44274 .69041 .43091 .67975 Metetra
.646 .762 .934 r
.43091 .67975 .44274 .69041 .46316 .68466 .45142 .67392 Metetra
.646 .762 .934 r
.45142 .67392 .46316 .68466 .48372 .67886 .47209 .66804 Metetra
.646 .762 .934 r
.47209 .66804 .48372 .67886 .50444 .67302 .49291 .66211 Metetra
.646 .762 .934 r
.49291 .66211 .50444 .67302 .52532 .66713 .51389 .65614 Metetra
.646 .762 .934 r
.51389 .65614 .52532 .66713 .54636 .6612 .53504 .65013 Metetra
.646 .762 .934 r
.53504 .65013 .54636 .6612 .56756 .65522 .55635 .64407 Metetra
.646 .762 .934 r
.55635 .64407 .56756 .65522 .58893 .6492 .57782 .63796 Metetra
.646 .762 .934 r
.57782 .63796 .58893 .6492 .61046 .64313 .59946 .6318 Metetra
.964 .717 .513 r
.59946 .6318 .61046 .64313 .62551 .42274 .61526 .41059 Metetra
.664 .741 .908 r
.61526 .41059 .62551 .42274 .646 .41618 .63585 .40393 Metetra
.664 .741 .908 r
.63585 .40393 .646 .41618 .66663 .40956 .65659 .39723 Metetra
.664 .741 .908 r
.65659 .39723 .66663 .40956 .68741 .4029 .67748 .39047 Metetra
.664 .741 .908 r
.67748 .39047 .68741 .4029 .70835 .39619 .69852 .38367 Metetra
.664 .741 .908 r
.69852 .38367 .70835 .39619 .72945 .38943 .71973 .37682 Metetra
.664 .741 .908 r
.71973 .37682 .72945 .38943 .7507 .38262 .74109 .36991 Metetra
.664 .741 .908 r
.74109 .36991 .7507 .38262 .77211 .37576 .76261 .36295 Metetra
.664 .741 .908 r
.76261 .36295 .77211 .37576 .79368 .36884 .7843 .35594 Metetra
.664 .741 .908 r
.7843 .35594 .79368 .36884 .81542 .36188 .80615 .34888 Metetra
.664 .741 .908 r
.80615 .34888 .81542 .36188 .83731 .35486 .82817 .34176 Metetra
.664 .741 .908 r
.82817 .34176 .83731 .35486 .85938 .34779 .85035 .33459 Metetra
.664 .741 .908 r
.85035 .33459 .85938 .34779 .88161 .34066 .87271 .32736 Metetra
.869 .479 .007 r
.87271 .32736 .88161 .34066 .91675 .43952 .90777 .42645 Metetra
.656 .751 .92 r
.28644 .60127 .29865 .61192 .31755 .60617 .30542 .59544 Metetra
.656 .751 .92 r
.30542 .59544 .31755 .60617 .33658 .60037 .32454 .58956 Metetra
.945 .625 .396 r
.32454 .58956 .33658 .60037 .3504 .70266 .33802 .69217 Metetra
.646 .762 .934 r
.33802 .69217 .3504 .70266 .3703 .697 .35802 .68643 Metetra
.646 .762 .934 r
.35802 .68643 .3703 .697 .39035 .69129 .37816 .68065 Metetra
.646 .762 .934 r
.37816 .68065 .39035 .69129 .41056 .68554 .39846 .67482 Metetra
.646 .762 .934 r
.39846 .67482 .41056 .68554 .43091 .67975 .41891 .66895 Metetra
.646 .762 .934 r
.41891 .66895 .43091 .67975 .45142 .67392 .43952 .66303 Metetra
.646 .762 .934 r
.43952 .66303 .45142 .67392 .47209 .66804 .46029 .65707 Metetra
.646 .762 .934 r
.46029 .65707 .47209 .66804 .49291 .66211 .48121 .65106 Metetra
.646 .762 .934 r
.48121 .65106 .49291 .66211 .51389 .65614 .5023 .645 Metetra
.646 .762 .934 r
.5023 .645 .51389 .65614 .53504 .65013 .52355 .6389 Metetra
.646 .762 .934 r
.52355 .6389 .53504 .65013 .55635 .64407 .54497 .63275 Metetra
.646 .762 .934 r
.54497 .63275 .55635 .64407 .57782 .63796 .56656 .62655 Metetra
.646 .762 .934 r
.56656 .62655 .57782 .63796 .59946 .6318 .58831 .62031 Metetra
.964 .717 .513 r
.58831 .62031 .59946 .6318 .61526 .41059 .60488 .39826 Metetra
.664 .741 .908 r
.60488 .39826 .61526 .41059 .63585 .40393 .62556 .39152 Metetra
.664 .741 .908 r
.62556 .39152 .63585 .40393 .65659 .39723 .6464 .38472 Metetra
.664 .741 .908 r
.6464 .38472 .65659 .39723 .67748 .39047 .6674 .37787 Metetra
.664 .741 .908 r
.6674 .37787 .67748 .39047 .69852 .38367 .68856 .37098 Metetra
.664 .741 .908 r
.68856 .37098 .69852 .38367 .71973 .37682 .70987 .36403 Metetra
.664 .741 .908 r
.70987 .36403 .71973 .37682 .74109 .36991 .73134 .35702 Metetra
.664 .741 .908 r
.73134 .35702 .74109 .36991 .76261 .36295 .75298 .34997 Metetra
.664 .741 .908 r
.75298 .34997 .76261 .36295 .7843 .35594 .77478 .34286 Metetra
.664 .741 .908 r
.77478 .34286 .7843 .35594 .80615 .34888 .79675 .3357 Metetra
.664 .741 .908 r
.79675 .3357 .80615 .34888 .82817 .34176 .81889 .32848 Metetra
.664 .741 .908 r
.81889 .32848 .82817 .34176 .85035 .33459 .84119 .3212 Metetra
.664 .741 .908 r
.84119 .3212 .85035 .33459 .87271 .32736 .86367 .31387 Metetra
.869 .479 .007 r
.86367 .31387 .87271 .32736 .90777 .42645 .89865 .41318 Metetra
.656 .751 .92 r
.27407 .59047 .28644 .60127 .30542 .59544 .29313 .58456 Metetra
.656 .751 .92 r
.29313 .58456 .30542 .59544 .32454 .58956 .31233 .57861 Metetra
.945 .625 .396 r
.31233 .57861 .32454 .58956 .33802 .69217 .32547 .68154 Metetra
.646 .762 .934 r
.32547 .68154 .33802 .69217 .35802 .68643 .34556 .67572 Metetra
.646 .762 .934 r
.34556 .67572 .35802 .68643 .37816 .68065 .3658 .66985 Metetra
.646 .762 .934 r
.3658 .66985 .37816 .68065 .39846 .67482 .38619 .66394 Metetra
.646 .762 .934 r
.38619 .66394 .39846 .67482 .41891 .66895 .40674 .65799 Metetra
.646 .762 .934 r
.40674 .65799 .41891 .66895 .43952 .66303 .42745 .65198 Metetra
.646 .762 .934 r
.42745 .65198 .43952 .66303 .46029 .65707 .44832 .64594 Metetra
.646 .762 .934 r
.44832 .64594 .46029 .65707 .48121 .65106 .46935 .63984 Metetra
.646 .762 .934 r
.46935 .63984 .48121 .65106 .5023 .645 .49054 .6337 Metetra
.646 .762 .934 r
.49054 .6337 .5023 .645 .52355 .6389 .5119 .62751 Metetra
.646 .762 .934 r
.5119 .62751 .52355 .6389 .54497 .63275 .53343 .62127 Metetra
.646 .762 .934 r
.53343 .62127 .54497 .63275 .56656 .62655 .55512 .61498 Metetra
.646 .762 .934 r
.55512 .61498 .56656 .62655 .58831 .62031 .57699 .60864 Metetra
.964 .717 .513 r
.57699 .60864 .58831 .62031 .60488 .39826 .59435 .38577 Metetra
.664 .741 .908 r
.59435 .38577 .60488 .39826 .62556 .39152 .61514 .37893 Metetra
.664 .741 .908 r
.61514 .37893 .62556 .39152 .6464 .38472 .63608 .37204 Metetra
.664 .741 .908 r
.63608 .37204 .6464 .38472 .6674 .37787 .65719 .3651 Metetra
.664 .741 .908 r
.65719 .3651 .6674 .37787 .68856 .37098 .67845 .3581 Metetra
.664 .741 .908 r
.67845 .3581 .68856 .37098 .70987 .36403 .69987 .35106 Metetra
.664 .741 .908 r
.69987 .35106 .70987 .36403 .73134 .35702 .72146 .34396 Metetra
.664 .741 .908 r
.72146 .34396 .73134 .35702 .75298 .34997 .74321 .3368 Metetra
.664 .741 .908 r
.74321 .3368 .75298 .34997 .77478 .34286 .76513 .32959 Metetra
.664 .741 .908 r
.76513 .32959 .77478 .34286 .79675 .3357 .78722 .32233 Metetra
.664 .741 .908 r
.78722 .32233 .79675 .3357 .81889 .32848 .80948 .31501 Metetra
.664 .741 .908 r
.80948 .31501 .81889 .32848 .84119 .3212 .83191 .30763 Metetra
.664 .741 .908 r
.83191 .30763 .84119 .3212 .86367 .31387 .85451 .30019 Metetra
.869 .479 .007 r
.85451 .30019 .86367 .31387 .89865 .41318 .8894 .39971 Metetra
.656 .751 .92 r
.26154 .57953 .27407 .59047 .29313 .58456 .28068 .57354 Metetra
.656 .751 .92 r
.28068 .57354 .29313 .58456 .31233 .57861 .29996 .56751 Metetra
.945 .625 .396 r
.29996 .56751 .31233 .57861 .32547 .68154 .31275 .67076 Metetra
.646 .762 .934 r
.31275 .67076 .32547 .68154 .34556 .67572 .33293 .66485 Metetra
.646 .762 .934 r
.33293 .66485 .34556 .67572 .3658 .66985 .35326 .6589 Metetra
.646 .762 .934 r
.35326 .6589 .3658 .66985 .38619 .66394 .37375 .65291 Metetra
.646 .762 .934 r
.37375 .65291 .38619 .66394 .40674 .65799 .3944 .64687 Metetra
.646 .762 .934 r
.3944 .64687 .40674 .65799 .42745 .65198 .41521 .64078 Metetra
.646 .762 .934 r
.41521 .64078 .42745 .65198 .44832 .64594 .43618 .63465 Metetra
.646 .762 .934 r
.43618 .63465 .44832 .64594 .46935 .63984 .45731 .62846 Metetra
.646 .762 .934 r
.45731 .62846 .46935 .63984 .49054 .6337 .47861 .62223 Metetra
.646 .762 .934 r
.47861 .62223 .49054 .6337 .5119 .62751 .50008 .61595 Metetra
.646 .762 .934 r
.50008 .61595 .5119 .62751 .53343 .62127 .52172 .60962 Metetra
.646 .762 .934 r
.52172 .60962 .53343 .62127 .55512 .61498 .54353 .60324 Metetra
.646 .762 .934 r
.54353 .60324 .55512 .61498 .57699 .60864 .56551 .59681 Metetra
.964 .717 .513 r
.56551 .59681 .57699 .60864 .59435 .38577 .58367 .3731 Metetra
.664 .741 .908 r
.58367 .3731 .59435 .38577 .61514 .37893 .60457 .36617 Metetra
.664 .741 .908 r
.60457 .36617 .61514 .37893 .63608 .37204 .62562 .35918 Metetra
.664 .741 .908 r
.62562 .35918 .63608 .37204 .65719 .3651 .64683 .35215 Metetra
.664 .741 .908 r
.64683 .35215 .65719 .3651 .67845 .3581 .6682 .34505 Metetra
.664 .741 .908 r
.6682 .34505 .67845 .3581 .69987 .35106 .68974 .33791 Metetra
.664 .741 .908 r
.68974 .33791 .69987 .35106 .72146 .34396 .71144 .3307 Metetra
.664 .741 .908 r
.71144 .3307 .72146 .34396 .74321 .3368 .73331 .32345 Metetra
.664 .741 .908 r
.73331 .32345 .74321 .3368 .76513 .32959 .75534 .31614 Metetra
.664 .741 .908 r
.75534 .31614 .76513 .32959 .78722 .32233 .77755 .30877 Metetra
.664 .741 .908 r
.77755 .30877 .78722 .32233 .80948 .31501 .79993 .30134 Metetra
.664 .741 .908 r
.79993 .30134 .80948 .31501 .83191 .30763 .82248 .29385 Metetra
.664 .741 .908 r
.82248 .29385 .83191 .30763 .85451 .30019 .84522 .28631 Metetra
.869 .479 .007 r
.84522 .28631 .85451 .30019 .8894 .39971 .88001 .38604 Metetra
.656 .751 .92 r
.24883 .56844 .26154 .57953 .28068 .57354 .26805 .56237 Metetra
.656 .751 .92 r
.26805 .56237 .28068 .57354 .29996 .56751 .28742 .55625 Metetra
.945 .625 .396 r
.28742 .55625 .29996 .56751 .31275 .67076 .29984 .65982 Metetra
.646 .762 .934 r
.29984 .65982 .31275 .67076 .33293 .66485 .32012 .65384 Metetra
.646 .762 .934 r
.32012 .65384 .33293 .66485 .35326 .6589 .34055 .6478 Metetra
.646 .762 .934 r
.34055 .6478 .35326 .6589 .37375 .65291 .36113 .64172 Metetra
.646 .762 .934 r
.36113 .64172 .37375 .65291 .3944 .64687 .38188 .63559 Metetra
.646 .762 .934 r
.38188 .63559 .3944 .64687 .41521 .64078 .40279 .62942 Metetra
.646 .762 .934 r
.40279 .62942 .41521 .64078 .43618 .63465 .42386 .62319 Metetra
.646 .762 .934 r
.42386 .62319 .43618 .63465 .45731 .62846 .4451 .61692 Metetra
.646 .762 .934 r
.4451 .61692 .45731 .62846 .47861 .62223 .46651 .6106 Metetra
.646 .762 .934 r
.46651 .6106 .47861 .62223 .50008 .61595 .48809 .60423 Metetra
.646 .762 .934 r
.48809 .60423 .50008 .61595 .52172 .60962 .50983 .5978 Metetra
.646 .762 .934 r
.50983 .5978 .52172 .60962 .54353 .60324 .53176 .59133 Metetra
.646 .762 .934 r
.53176 .59133 .54353 .60324 .56551 .59681 .55385 .5848 Metetra
.964 .717 .513 r
.55385 .5848 .56551 .59681 .58367 .3731 .57285 .36026 Metetra
.664 .741 .908 r
.57285 .36026 .58367 .3731 .60457 .36617 .59385 .35323 Metetra
.664 .741 .908 r
.59385 .35323 .60457 .36617 .62562 .35918 .615 .34615 Metetra
.664 .741 .908 r
.615 .34615 .62562 .35918 .64683 .35215 .63632 .33901 Metetra
.664 .741 .908 r
.63632 .33901 .64683 .35215 .6682 .34505 .65781 .33182 Metetra
.664 .741 .908 r
.65781 .33182 .6682 .34505 .68974 .33791 .67946 .32457 Metetra
.664 .741 .908 r
.67946 .32457 .68974 .33791 .71144 .3307 .70127 .31726 Metetra
.664 .741 .908 r
.70127 .31726 .71144 .3307 .73331 .32345 .72326 .3099 Metetra
.664 .741 .908 r
.72326 .3099 .73331 .32345 .75534 .31614 .74541 .30249 Metetra
.664 .741 .908 r
.74541 .30249 .75534 .31614 .77755 .30877 .76774 .29501 Metetra
.664 .741 .908 r
.76774 .29501 .77755 .30877 .79993 .30134 .79025 .28747 Metetra
.664 .741 .908 r
.79025 .28747 .79993 .30134 .82248 .29385 .81293 .27988 Metetra
.664 .741 .908 r
.81293 .27988 .82248 .29385 .84522 .28631 .83579 .27223 Metetra
.869 .479 .007 r
.83579 .27223 .84522 .28631 .88001 .38604 .87047 .37217 Metetra
.656 .751 .92 r
.23595 .5572 .24883 .56844 .26805 .56237 .25526 .55104 Metetra
.656 .751 .92 r
.25526 .55104 .26805 .56237 .28742 .55625 .27471 .54484 Metetra
.945 .625 .396 r
.27471 .54484 .28742 .55625 .29984 .65982 .28676 .64873 Metetra
.646 .762 .934 r
.28676 .64873 .29984 .65982 .32012 .65384 .30712 .64266 Metetra
.646 .762 .934 r
.30712 .64266 .32012 .65384 .34055 .6478 .32765 .63654 Metetra
.646 .762 .934 r
.32765 .63654 .34055 .6478 .36113 .64172 .34833 .63037 Metetra
.646 .762 .934 r
.34833 .63037 .36113 .64172 .38188 .63559 .36918 .62416 Metetra
.646 .762 .934 r
.36918 .62416 .38188 .63559 .40279 .62942 .39019 .61789 Metetra
.646 .762 .934 r
.39019 .61789 .40279 .62942 .42386 .62319 .41137 .61157 Metetra
.646 .762 .934 r
.41137 .61157 .42386 .62319 .4451 .61692 .43271 .60521 Metetra
.646 .762 .934 r
.43271 .60521 .4451 .61692 .46651 .6106 .45423 .59879 Metetra
.646 .762 .934 r
.45423 .59879 .46651 .6106 .48809 .60423 .47591 .59233 Metetra
.646 .762 .934 r
.47591 .59233 .48809 .60423 .50983 .5978 .49778 .58581 Metetra
.646 .762 .934 r
.49778 .58581 .50983 .5978 .53176 .59133 .51981 .57924 Metetra
.646 .762 .934 r
.51981 .57924 .53176 .59133 .55385 .5848 .54203 .57261 Metetra
.964 .717 .513 r
.54203 .57261 .55385 .5848 .57285 .36026 .56187 .34724 Metetra
.664 .741 .908 r
.56187 .34724 .57285 .36026 .59385 .35323 .58298 .34011 Metetra
.664 .741 .908 r
.58298 .34011 .59385 .35323 .615 .34615 .60424 .33293 Metetra
.664 .741 .908 r
.60424 .33293 .615 .34615 .63632 .33901 .62567 .32569 Metetra
.664 .741 .908 r
.62567 .32569 .63632 .33901 .65781 .33182 .64727 .31839 Metetra
.664 .741 .908 r
.64727 .31839 .65781 .33182 .67946 .32457 .66903 .31104 Metetra
.664 .741 .908 r
.66903 .31104 .67946 .32457 .70127 .31726 .69096 .30363 Metetra
.664 .741 .908 r
.69096 .30363 .70127 .31726 .72326 .3099 .71306 .29616 Metetra
.664 .741 .908 r
.71306 .29616 .72326 .3099 .74541 .30249 .73534 .28864 Metetra
.664 .741 .908 r
.73534 .28864 .74541 .30249 .76774 .29501 .75779 .28105 Metetra
.664 .741 .908 r
.75779 .28105 .76774 .29501 .79025 .28747 .78042 .27341 Metetra
.664 .741 .908 r
.78042 .27341 .79025 .28747 .81293 .27988 .80323 .2657 Metetra
.664 .741 .908 r
.80323 .2657 .81293 .27988 .83579 .27223 .82622 .25794 Metetra
.869 .479 .007 r
.82622 .25794 .83579 .27223 .87047 .37217 .86079 .35808 Metetra
.656 .751 .92 r
.22289 .5458 .23595 .5572 .25526 .55104 .24228 .53956 Metetra
.656 .751 .92 r
.24228 .53956 .25526 .55104 .27471 .54484 .26182 .53328 Metetra
.945 .625 .396 r
.26182 .53328 .27471 .54484 .28676 .64873 .27348 .63748 Metetra
.646 .762 .934 r
.27348 .63748 .28676 .64873 .30712 .64266 .29394 .63132 Metetra
.646 .762 .934 r
.29394 .63132 .30712 .64266 .32765 .63654 .31456 .62511 Metetra
.646 .762 .934 r
.31456 .62511 .32765 .63654 .34833 .63037 .33535 .61886 Metetra
.646 .762 .934 r
.33535 .61886 .34833 .63037 .36918 .62416 .35629 .61255 Metetra
.646 .762 .934 r
.35629 .61255 .36918 .62416 .39019 .61789 .37741 .60619 Metetra
.646 .762 .934 r
.37741 .60619 .39019 .61789 .41137 .61157 .39869 .59978 Metetra
.646 .762 .934 r
.39869 .59978 .41137 .61157 .43271 .60521 .42014 .59333 Metetra
.646 .762 .934 r
.42014 .59333 .43271 .60521 .45423 .59879 .44177 .58682 Metetra
.646 .762 .934 r
.44177 .58682 .45423 .59879 .47591 .59233 .46356 .58025 Metetra
.646 .762 .934 r
.46356 .58025 .47591 .59233 .49778 .58581 .48554 .57364 Metetra
.646 .762 .934 r
.48554 .57364 .49778 .58581 .51981 .57924 .50769 .56697 Metetra
.646 .762 .934 r
.50769 .56697 .51981 .57924 .54203 .57261 .53002 .56024 Metetra
.964 .717 .513 r
.53002 .56024 .54203 .57261 .56187 .34724 .55074 .33404 Metetra
.664 .741 .908 r
.55074 .33404 .56187 .34724 .58298 .34011 .57195 .3268 Metetra
.664 .741 .908 r
.57195 .3268 .58298 .34011 .60424 .33293 .59333 .31952 Metetra
.664 .741 .908 r
.59333 .31952 .60424 .33293 .62567 .32569 .61487 .31217 Metetra
.664 .741 .908 r
.61487 .31217 .62567 .32569 .64727 .31839 .63658 .30477 Metetra
.664 .741 .908 r
.63658 .30477 .64727 .31839 .66903 .31104 .65845 .29732 Metetra
.664 .741 .908 r
.65845 .29732 .66903 .31104 .69096 .30363 .6805 .2898 Metetra
.664 .741 .908 r
.6805 .2898 .69096 .30363 .71306 .29616 .70272 .28222 Metetra
.664 .741 .908 r
.70272 .28222 .71306 .29616 .73534 .28864 .72512 .27459 Metetra
.664 .741 .908 r
.72512 .27459 .73534 .28864 .75779 .28105 .7477 .26689 Metetra
.664 .741 .908 r
.7477 .26689 .75779 .28105 .78042 .27341 .77045 .25914 Metetra
.664 .741 .908 r
.77045 .25914 .78042 .27341 .80323 .2657 .79339 .25132 Metetra
.664 .741 .908 r
.79339 .25132 .80323 .2657 .82622 .25794 .81651 .24344 Metetra
.869 .479 .007 r
.81651 .24344 .82622 .25794 .86079 .35808 .85096 .34377 Metetra
.656 .751 .92 r
.20965 .53425 .22289 .5458 .24228 .53956 .22913 .52792 Metetra
.656 .751 .92 r
.22913 .52792 .24228 .53956 .26182 .53328 .24876 .52155 Metetra
.945 .625 .396 r
.24876 .52155 .26182 .53328 .27348 .63748 .26001 .62607 Metetra
.646 .762 .934 r
.26001 .62607 .27348 .63748 .29394 .63132 .28057 .61982 Metetra
.646 .762 .934 r
.28057 .61982 .29394 .63132 .31456 .62511 .30129 .61352 Metetra
.646 .762 .934 r
.30129 .61352 .31456 .62511 .33535 .61886 .32217 .60717 Metetra
.646 .762 .934 r
.32217 .60717 .33535 .61886 .35629 .61255 .34322 .60077 Metetra
.646 .762 .934 r
.34322 .60077 .35629 .61255 .37741 .60619 .36444 .59432 Metetra
.646 .762 .934 r
.36444 .59432 .37741 .60619 .39869 .59978 .38582 .58782 Metetra
.646 .762 .934 r
.38582 .58782 .39869 .59978 .42014 .59333 .40738 .58127 Metetra
.646 .762 .934 r
.40738 .58127 .42014 .59333 .44177 .58682 .42912 .57466 Metetra
.646 .762 .934 r
.42912 .57466 .44177 .58682 .46356 .58025 .45103 .568 Metetra
.646 .762 .934 r
.45103 .568 .46356 .58025 .48554 .57364 .47311 .56128 Metetra
.646 .762 .934 r
.47311 .56128 .48554 .57364 .50769 .56697 .49538 .55451 Metetra
.646 .762 .934 r
.49538 .55451 .50769 .56697 .53002 .56024 .51783 .54768 Metetra
.964 .717 .513 r
.51783 .54768 .53002 .56024 .55074 .33404 .53945 .32064 Metetra
.664 .741 .908 r
.53945 .32064 .55074 .33404 .57195 .3268 .56077 .31331 Metetra
.664 .741 .908 r
.56077 .31331 .57195 .3268 .59333 .31952 .58225 .30592 Metetra
.664 .741 .908 r
.58225 .30592 .59333 .31952 .61487 .31217 .60391 .29847 Metetra
.664 .741 .908 r
.60391 .29847 .61487 .31217 .63658 .30477 .62573 .29096 Metetra
.664 .741 .908 r
.62573 .29096 .63658 .30477 .65845 .29732 .64772 .28339 Metetra
.664 .741 .908 r
.64772 .28339 .65845 .29732 .6805 .2898 .66989 .27577 Metetra
.664 .741 .908 r
.66989 .27577 .6805 .2898 .70272 .28222 .69223 .26808 Metetra
.664 .741 .908 r
.69223 .26808 .70272 .28222 .72512 .27459 .71475 .26033 Metetra
.664 .741 .908 r
.71475 .26033 .72512 .27459 .7477 .26689 .73745 .25252 Metetra
.664 .741 .908 r
.73745 .25252 .7477 .26689 .77045 .25914 .76033 .24465 Metetra
.664 .741 .908 r
.76033 .24465 .77045 .25914 .79339 .25132 .7834 .23672 Metetra
.664 .741 .908 r
.7834 .23672 .79339 .25132 .81651 .24344 .80665 .22872 Metetra
.869 .479 .007 r
.80665 .22872 .81651 .24344 .85096 .34377 .84098 .32925 Metetra
.656 .751 .92 r
.19623 .52253 .20965 .53425 .22913 .52792 .21579 .51612 Metetra
.656 .751 .92 r
.21579 .51612 .22913 .52792 .24876 .52155 .23551 .50965 Metetra
.945 .625 .396 r
.23551 .50965 .24876 .52155 .26001 .62607 .24635 .6145 Metetra
.646 .762 .934 r
.24635 .6145 .26001 .62607 .28057 .61982 .267 .60815 Metetra
.646 .762 .934 r
.267 .60815 .28057 .61982 .30129 .61352 .28782 .60176 Metetra
.646 .762 .934 r
.28782 .60176 .30129 .61352 .32217 .60717 .3088 .59532 Metetra
.646 .762 .934 r
.3088 .59532 .32217 .60717 .34322 .60077 .32995 .58882 Metetra
.646 .762 .934 r
.32995 .58882 .34322 .60077 .36444 .59432 .35127 .58228 Metetra
.646 .762 .934 r
.35127 .58228 .36444 .59432 .38582 .58782 .37277 .57568 Metetra
.646 .762 .934 r
.37277 .57568 .38582 .58782 .40738 .58127 .39443 .56902 Metetra
.646 .762 .934 r
.39443 .56902 .40738 .58127 .42912 .57466 .41628 .56232 Metetra
.646 .762 .934 r
.41628 .56232 .42912 .57466 .45103 .568 .4383 .55556 Metetra
.646 .762 .934 r
.4383 .55556 .45103 .568 .47311 .56128 .4605 .54874 Metetra
.646 .762 .934 r
.4605 .54874 .47311 .56128 .49538 .55451 .48289 .54186 Metetra
.646 .762 .934 r
.48289 .54186 .49538 .55451 .51783 .54768 .50546 .53493 Metetra
.964 .717 .513 r
.50546 .53493 .51783 .54768 .53945 .32064 .528 .30706 Metetra
.664 .741 .908 r
.528 .30706 .53945 .32064 .56077 .31331 .54943 .29962 Metetra
.664 .741 .908 r
.54943 .29962 .56077 .31331 .58225 .30592 .57102 .29212 Metetra
.664 .741 .908 r
.57102 .29212 .58225 .30592 .60391 .29847 .59279 .28456 Metetra
.664 .741 .908 r
.59279 .28456 .60391 .29847 .62573 .29096 .61473 .27694 Metetra
.664 .741 .908 r
.61473 .27694 .62573 .29096 .64772 .28339 .63684 .26927 Metetra
.664 .741 .908 r
.63684 .26927 .64772 .28339 .66989 .27577 .65912 .26153 Metetra
.664 .741 .908 r
.65912 .26153 .66989 .27577 .69223 .26808 .68159 .25373 Metetra
.664 .741 .908 r
.68159 .25373 .69223 .26808 .71475 .26033 .70423 .24587 Metetra
.664 .741 .908 r
.70423 .24587 .71475 .26033 .73745 .25252 .72706 .23794 Metetra
.664 .741 .908 r
.72706 .23794 .73745 .25252 .76033 .24465 .75007 .22995 Metetra
.664 .741 .908 r
.75007 .22995 .76033 .24465 .7834 .23672 .77326 .2219 Metetra
.664 .741 .908 r
.77326 .2219 .7834 .23672 .80665 .22872 .79665 .21378 Metetra
.869 .479 .007 r
.79665 .21378 .80665 .22872 .84098 .32925 .83084 .31449 Metetra
.656 .751 .92 r
.18262 .51065 .19623 .52253 .21579 .51612 .20227 .50415 Metetra
.656 .751 .92 r
.20227 .50415 .21579 .51612 .23551 .50965 .22207 .49759 Metetra
.945 .625 .396 r
.22207 .49759 .23551 .50965 .24635 .6145 .23248 .60275 Metetra
.646 .762 .934 r
.23248 .60275 .24635 .6145 .267 .60815 .25323 .59631 Metetra
.646 .762 .934 r
.25323 .59631 .267 .60815 .28782 .60176 .27415 .58983 Metetra
.646 .762 .934 r
.27415 .58983 .28782 .60176 .3088 .59532 .29523 .58329 Metetra
.646 .762 .934 r
.29523 .58329 .3088 .59532 .32995 .58882 .31649 .5767 Metetra
.646 .762 .934 r
.31649 .5767 .32995 .58882 .35127 .58228 .33791 .57005 Metetra
.646 .762 .934 r
.33791 .57005 .35127 .58228 .37277 .57568 .35951 .56335 Metetra
.646 .762 .934 r
.35951 .56335 .37277 .57568 .39443 .56902 .38129 .5566 Metetra
.646 .762 .934 r
.38129 .5566 .39443 .56902 .41628 .56232 .40324 .54979 Metetra
.646 .762 .934 r
.40324 .54979 .41628 .56232 .4383 .55556 .42538 .54293 Metetra
.646 .762 .934 r
.42538 .54293 .4383 .55556 .4605 .54874 .4477 .536 Metetra
.646 .762 .934 r
.4477 .536 .4605 .54874 .48289 .54186 .4702 .52902 Metetra
.646 .762 .934 r
.4702 .52902 .48289 .54186 .50546 .53493 .49289 .52199 Metetra
.964 .717 .513 r
.49289 .52199 .50546 .53493 .528 .30706 .51638 .29328 Metetra
.664 .741 .908 r
.51638 .29328 .528 .30706 .54943 .29962 .53792 .28573 Metetra
.664 .741 .908 r
.53792 .28573 .54943 .29962 .57102 .29212 .55963 .27812 Metetra
.664 .741 .908 r
.55963 .27812 .57102 .29212 .59279 .28456 .58151 .27045 Metetra
.664 .741 .908 r
.58151 .27045 .59279 .28456 .61473 .27694 .60356 .26272 Metetra
.664 .741 .908 r
.60356 .26272 .61473 .27694 .63684 .26927 .62579 .25493 Metetra
.664 .741 .908 r
.62579 .25493 .63684 .26927 .65912 .26153 .6482 .24708 Metetra
.664 .741 .908 r
.6482 .24708 .65912 .26153 .68159 .25373 .67078 .23917 Metetra
.664 .741 .908 r
.67078 .23917 .68159 .25373 .70423 .24587 .69355 .23119 Metetra
.664 .741 .908 r
.69355 .23119 .70423 .24587 .72706 .23794 .7165 .22314 Metetra
.664 .741 .908 r
.7165 .22314 .72706 .23794 .75007 .22995 .73964 .21503 Metetra
.664 .741 .908 r
.73964 .21503 .75007 .22995 .77326 .2219 .76297 .20686 Metetra
.664 .741 .908 r
.76297 .20686 .77326 .2219 .79665 .21378 .78649 .19861 Metetra
.869 .479 .007 r
.78649 .19861 .79665 .21378 .83084 .31449 .82055 .29951 Metetra
.656 .751 .92 r
.16882 .49861 .18262 .51065 .20227 .50415 .18855 .49201 Metetra
.656 .751 .92 r
.18855 .49201 .20227 .50415 .22207 .49759 .20844 .48536 Metetra
.945 .625 .396 r
.20844 .48536 .22207 .49759 .23248 .60275 .21841 .59083 Metetra
.646 .762 .934 r
.21841 .59083 .23248 .60275 .25323 .59631 .23926 .5843 Metetra
.646 .762 .934 r
.23926 .5843 .25323 .59631 .27415 .58983 .26028 .57771 Metetra
.646 .762 .934 r
.26028 .57771 .27415 .58983 .29523 .58329 .28146 .57108 Metetra
.646 .762 .934 r
.28146 .57108 .29523 .58329 .31649 .5767 .30282 .56439 Metetra
.646 .762 .934 r
.30282 .56439 .31649 .5767 .33791 .57005 .32435 .55764 Metetra
.646 .762 .934 r
.32435 .55764 .33791 .57005 .35951 .56335 .34606 .55084 Metetra
.646 .762 .934 r
.34606 .55084 .35951 .56335 .38129 .5566 .36795 .54399 Metetra
.646 .762 .934 r
.36795 .54399 .38129 .5566 .40324 .54979 .39001 .53707 Metetra
.646 .762 .934 r
.39001 .53707 .40324 .54979 .42538 .54293 .41226 .5301 Metetra
.646 .762 .934 r
.41226 .5301 .42538 .54293 .4477 .536 .4347 .52307 Metetra
.646 .762 .934 r
.4347 .52307 .4477 .536 .4702 .52902 .45732 .51599 Metetra
.646 .762 .934 r
.45732 .51599 .4702 .52902 .49289 .52199 .48014 .50884 Metetra
.964 .717 .513 r
.48014 .50884 .49289 .52199 .51638 .29328 .5046 .27929 Metetra
.664 .741 .908 r
.5046 .27929 .51638 .29328 .53792 .28573 .52624 .27164 Metetra
.664 .741 .908 r
.52624 .27164 .53792 .28573 .55963 .27812 .54807 .26392 Metetra
.664 .741 .908 r
.54807 .26392 .55963 .27812 .58151 .27045 .57006 .25614 Metetra
.664 .741 .908 r
.57006 .25614 .58151 .27045 .60356 .26272 .59223 .24829 Metetra
.664 .741 .908 r
.59223 .24829 .60356 .26272 .62579 .25493 .61458 .24039 Metetra
.664 .741 .908 r
.61458 .24039 .62579 .25493 .6482 .24708 .63711 .23242 Metetra
.664 .741 .908 r
.63711 .23242 .6482 .24708 .67078 .23917 .65982 .22438 Metetra
.664 .741 .908 r
.65982 .22438 .67078 .23917 .69355 .23119 .68271 .21629 Metetra
.664 .741 .908 r
.68271 .21629 .69355 .23119 .7165 .22314 .70579 .20812 Metetra
.664 .741 .908 r
.70579 .20812 .7165 .22314 .73964 .21503 .72906 .19989 Metetra
.664 .741 .908 r
.72906 .19989 .73964 .21503 .76297 .20686 .75253 .19159 Metetra
.664 .741 .908 r
.75253 .19159 .76297 .20686 .78649 .19861 .77618 .18322 Metetra
.869 .479 .007 r
.77618 .18322 .78649 .19861 .82055 .29951 .81009 .28428 Metetra
.656 .751 .92 r
.15482 .48639 .16882 .49861 .18855 .49201 .17464 .4797 Metetra
.656 .751 .92 r
.17464 .4797 .18855 .49201 .20844 .48536 .19462 .47295 Metetra
.945 .625 .396 r
.19462 .47295 .20844 .48536 .21841 .59083 .20414 .57873 Metetra
.646 .762 .934 r
.20414 .57873 .21841 .59083 .23926 .5843 .22508 .5721 Metetra
.646 .762 .934 r
.22508 .5721 .23926 .5843 .26028 .57771 .2462 .56542 Metetra
.646 .762 .934 r
.2462 .56542 .26028 .57771 .28146 .57108 .26748 .55868 Metetra
.646 .762 .934 r
.26748 .55868 .28146 .57108 .30282 .56439 .28894 .55189 Metetra
.646 .762 .934 r
.28894 .55189 .30282 .56439 .32435 .55764 .31058 .54504 Metetra
.646 .762 .934 r
.31058 .54504 .32435 .55764 .34606 .55084 .3324 .53814 Metetra
.646 .762 .934 r
.3324 .53814 .34606 .55084 .36795 .54399 .3544 .53118 Metetra
.646 .762 .934 r
.3544 .53118 .36795 .54399 .39001 .53707 .37658 .52416 Metetra
.646 .762 .934 r
.37658 .52416 .39001 .53707 .41226 .5301 .39894 .51708 Metetra
.646 .762 .934 r
.39894 .51708 .41226 .5301 .4347 .52307 .4215 .50994 Metetra
.646 .762 .934 r
.4215 .50994 .4347 .52307 .45732 .51599 .44424 .50275 Metetra
.646 .762 .934 r
.44424 .50275 .45732 .51599 .48014 .50884 .46718 .49549 Metetra
.964 .717 .513 r
.46718 .49549 .48014 .50884 .5046 .27929 .49264 .26511 Metetra
.664 .741 .908 r
.49264 .26511 .5046 .27929 .52624 .27164 .5144 .25734 Metetra
.664 .741 .908 r
.5144 .25734 .52624 .27164 .54807 .26392 .53633 .2495 Metetra
.664 .741 .908 r
.53633 .2495 .54807 .26392 .57006 .25614 .55844 .24161 Metetra
.664 .741 .908 r
.55844 .24161 .57006 .25614 .59223 .24829 .58073 .23365 Metetra
.664 .741 .908 r
.58073 .23365 .59223 .24829 .61458 .24039 .6032 .22562 Metetra
.664 .741 .908 r
.6032 .22562 .61458 .24039 .63711 .23242 .62585 .21754 Metetra
.664 .741 .908 r
.62585 .21754 .63711 .23242 .65982 .22438 .64869 .20938 Metetra
.664 .741 .908 r
.64869 .20938 .65982 .22438 .68271 .21629 .67171 .20116 Metetra
.664 .741 .908 r
.67171 .20116 .68271 .21629 .70579 .20812 .69492 .19287 Metetra
.664 .741 .908 r
.69492 .19287 .70579 .20812 .72906 .19989 .71832 .18451 Metetra
.664 .741 .908 r
.71832 .18451 .72906 .19989 .75253 .19159 .74192 .17608 Metetra
.664 .741 .908 r
.74192 .17608 .75253 .19159 .77618 .18322 .76571 .16759 Metetra
.869 .479 .007 r
.76571 .16759 .77618 .18322 .81009 .28428 .79946 .26882 Metetra
.656 .751 .92 r
.14062 .474 .15482 .48639 .17464 .4797 .16053 .46721 Metetra
.656 .751 .92 r
.16053 .46721 .17464 .4797 .19462 .47295 .18059 .46037 Metetra
.945 .625 .396 r
.18059 .46037 .19462 .47295 .20414 .57873 .18964 .56645 Metetra
.646 .762 .934 r
.18964 .56645 .20414 .57873 .22508 .5721 .21069 .55972 Metetra
.646 .762 .934 r
.21069 .55972 .22508 .5721 .2462 .56542 .2319 .55294 Metetra
.646 .762 .934 r
.2319 .55294 .2462 .56542 .26748 .55868 .25329 .5461 Metetra
.646 .762 .934 r
.25329 .5461 .26748 .55868 .28894 .55189 .27486 .53921 Metetra
.646 .762 .934 r
.27486 .53921 .28894 .55189 .31058 .54504 .2966 .53225 Metetra
.646 .762 .934 r
.2966 .53225 .31058 .54504 .3324 .53814 .31853 .52524 Metetra
.646 .762 .934 r
.31853 .52524 .3324 .53814 .3544 .53118 .34064 .51817 Metetra
.646 .762 .934 r
.34064 .51817 .3544 .53118 .37658 .52416 .36293 .51105 Metetra
.646 .762 .934 r
.36293 .51105 .37658 .52416 .39894 .51708 .38542 .50386 Metetra
.646 .762 .934 r
.38542 .50386 .39894 .51708 .4215 .50994 .40809 .49661 Metetra
.646 .762 .934 r
.40809 .49661 .4215 .50994 .44424 .50275 .43095 .4893 Metetra
.646 .762 .934 r
.43095 .4893 .44424 .50275 .46718 .49549 .45401 .48192 Metetra
.964 .717 .513 r
.45401 .48192 .46718 .49549 .49264 .26511 .4805 .25071 Metetra
.664 .741 .908 r
.4805 .25071 .49264 .26511 .5144 .25734 .50238 .24283 Metetra
.664 .741 .908 r
.50238 .24283 .5144 .25734 .53633 .2495 .52443 .23488 Metetra
.664 .741 .908 r
.52443 .23488 .53633 .2495 .55844 .24161 .54665 .22686 Metetra
.664 .741 .908 r
.54665 .22686 .55844 .24161 .58073 .23365 .56906 .21878 Metetra
.664 .741 .908 r
.56906 .21878 .58073 .23365 .6032 .22562 .59165 .21064 Metetra
.664 .741 .908 r
.59165 .21064 .6032 .22562 .62585 .21754 .61442 .20243 Metetra
.664 .741 .908 r
.61442 .20243 .62585 .21754 .64869 .20938 .63739 .19415 Metetra
.664 .741 .908 r
.63739 .19415 .64869 .20938 .67171 .20116 .66054 .1858 Metetra
.664 .741 .908 r
.66054 .1858 .67171 .20116 .69492 .19287 .68388 .17738 Metetra
.664 .741 .908 r
.68388 .17738 .69492 .19287 .71832 .18451 .70742 .1689 Metetra
.664 .741 .908 r
.70742 .1689 .71832 .18451 .74192 .17608 .73115 .16034 Metetra
.664 .741 .908 r
.73115 .16034 .74192 .17608 .76571 .16759 .75508 .15171 Metetra
.869 .479 .007 r
.75508 .15171 .76571 .16759 .79946 .26882 .78866 .2531 Metetra
.656 .751 .92 r
.12621 .46142 .14062 .474 .16053 .46721 .14621 .45454 Metetra
.656 .751 .92 r
.14621 .45454 .16053 .46721 .18059 .46037 .16637 .4476 Metetra
.945 .625 .396 r
.16637 .4476 .18059 .46037 .18964 .56645 .17493 .55399 Metetra
.646 .762 .934 r
.17493 .55399 .18964 .56645 .21069 .55972 .19607 .54716 Metetra
.646 .762 .934 r
.19607 .54716 .21069 .55972 .2319 .55294 .21739 .54027 Metetra
.646 .762 .934 r
.21739 .54027 .2319 .55294 .25329 .5461 .23889 .53333 Metetra
.646 .762 .934 r
.23889 .53333 .25329 .5461 .27486 .53921 .26056 .52632 Metetra
.646 .762 .934 r
.26056 .52632 .27486 .53921 .2966 .53225 .28241 .51926 Metetra
.646 .762 .934 r
.28241 .51926 .2966 .53225 .31853 .52524 .30445 .51215 Metetra
.646 .762 .934 r
.30445 .51215 .31853 .52524 .34064 .51817 .32667 .50497 Metetra
.646 .762 .934 r
.32667 .50497 .34064 .51817 .36293 .51105 .34908 .49773 Metetra
.646 .762 .934 r
.34908 .49773 .36293 .51105 .38542 .50386 .37168 .49043 Metetra
.646 .762 .934 r
.37168 .49043 .38542 .50386 .40809 .49661 .39447 .48306 Metetra
.646 .762 .934 r
.39447 .48306 .40809 .49661 .43095 .4893 .41746 .47564 Metetra
.646 .762 .934 r
.41746 .47564 .43095 .4893 .45401 .48192 .44064 .46815 Metetra
.964 .717 .513 r
.44064 .46815 .45401 .48192 .4805 .25071 .46819 .2361 Metetra
.664 .741 .908 r
.46819 .2361 .4805 .25071 .50238 .24283 .49018 .2281 Metetra
.664 .741 .908 r
.49018 .2281 .50238 .24283 .52443 .23488 .51234 .22003 Metetra
.664 .741 .908 r
.51234 .22003 .52443 .23488 .54665 .22686 .53469 .2119 Metetra
.664 .741 .908 r
.53469 .2119 .54665 .22686 .56906 .21878 .55721 .2037 Metetra
.664 .741 .908 r
.55721 .2037 .56906 .21878 .59165 .21064 .57992 .19543 Metetra
.664 .741 .908 r
.57992 .19543 .59165 .21064 .61442 .20243 .60282 .18709 Metetra
.664 .741 .908 r
.60282 .18709 .61442 .20243 .63739 .19415 .62591 .17868 Metetra
.664 .741 .908 r
.62591 .17868 .63739 .19415 .66054 .1858 .6492 .17021 Metetra
.664 .741 .908 r
.6492 .17021 .66054 .1858 .68388 .17738 .67267 .16166 Metetra
.664 .741 .908 r
.67267 .16166 .68388 .17738 .70742 .1689 .69634 .15304 Metetra
.664 .741 .908 r
.69634 .15304 .70742 .1689 .73115 .16034 .72021 .14435 Metetra
.664 .741 .908 r
.72021 .14435 .73115 .16034 .75508 .15171 .74429 .13559 Metetra
.869 .479 .007 r
.74429 .13559 .75508 .15171 .78866 .2531 .77769 .23713 Metetra
.656 .751 .92 r
.1116 .44867 .12621 .46142 .14621 .45454 .13169 .44168 Metetra
.656 .751 .92 r
.13169 .44168 .14621 .45454 .16637 .4476 .15193 .43464 Metetra
.945 .625 .396 r
.15193 .43464 .16637 .4476 .17493 .55399 .16 .54133 Metetra
.646 .762 .934 r
.16 .54133 .17493 .55399 .19607 .54716 .18124 .5344 Metetra
.646 .762 .934 r
.18124 .5344 .19607 .54716 .21739 .54027 .20266 .52741 Metetra
.646 .762 .934 r
.20266 .52741 .21739 .54027 .23889 .53333 .22426 .52035 Metetra
.646 .762 .934 r
.22426 .52035 .23889 .53333 .26056 .52632 .24603 .51324 Metetra
.646 .762 .934 r
.24603 .51324 .26056 .52632 .28241 .51926 .268 .50608 Metetra
.646 .762 .934 r
.268 .50608 .28241 .51926 .30445 .51215 .29014 .49884 Metetra
.646 .762 .934 r
.29014 .49884 .30445 .51215 .32667 .50497 .31248 .49155 Metetra
.646 .762 .934 r
.31248 .49155 .32667 .50497 .34908 .49773 .335 .4842 Metetra
.646 .762 .934 r
.335 .4842 .34908 .49773 .37168 .49043 .35772 .47678 Metetra
.646 .762 .934 r
.35772 .47678 .37168 .49043 .39447 .48306 .38064 .4693 Metetra
.646 .762 .934 r
.38064 .4693 .39447 .48306 .41746 .47564 .40375 .46176 Metetra
.646 .762 .934 r
.40375 .46176 .41746 .47564 .44064 .46815 .42706 .45415 Metetra
.964 .717 .513 r
.42706 .45415 .44064 .46815 .46819 .2361 .45569 .22128 Metetra
.664 .741 .908 r
.45569 .22128 .46819 .2361 .49018 .2281 .47779 .21315 Metetra
.664 .741 .908 r
.47779 .21315 .49018 .2281 .51234 .22003 .50007 .20496 Metetra
.664 .741 .908 r
.50007 .20496 .51234 .22003 .53469 .2119 .52254 .1967 Metetra
.664 .741 .908 r
.52254 .1967 .53469 .2119 .55721 .2037 .54519 .18838 Metetra
.664 .741 .908 r
.54519 .18838 .55721 .2037 .57992 .19543 .56802 .17998 Metetra
.664 .741 .908 r
.56802 .17998 .57992 .19543 .60282 .18709 .59105 .17152 Metetra
.664 .741 .908 r
.59105 .17152 .60282 .18709 .62591 .17868 .61426 .16298 Metetra
.664 .741 .908 r
.61426 .16298 .62591 .17868 .6492 .17021 .63768 .15437 Metetra
.664 .741 .908 r
.63768 .15437 .6492 .17021 .67267 .16166 .66129 .14569 Metetra
.664 .741 .908 r
.66129 .14569 .67267 .16166 .69634 .15304 .6851 .13694 Metetra
.664 .741 .908 r
.6851 .13694 .69634 .15304 .72021 .14435 .70911 .12812 Metetra
.664 .741 .908 r
.70911 .12812 .72021 .14435 .74429 .13559 .73332 .11921 Metetra
.869 .479 .007 r
.73332 .11921 .74429 .13559 .77769 .23713 .76653 .22089 Metetra
.656 .751 .92 r
.09677 .43573 .1116 .44867 .13169 .44168 .11695 .42864 Metetra
.656 .751 .92 r
.11695 .42864 .13169 .44168 .15193 .43464 .13729 .4215 Metetra
.945 .625 .396 r
.13729 .4215 .15193 .43464 .16 .54133 .14483 .52849 Metetra
.646 .762 .934 r
.14483 .52849 .16 .54133 .18124 .5344 .16618 .52144 Metetra
.646 .762 .934 r
.16618 .52144 .18124 .5344 .20266 .52741 .1877 .51434 Metetra
.646 .762 .934 r
.1877 .51434 .20266 .52741 .22426 .52035 .2094 .50718 Metetra
.646 .762 .934 r
.2094 .50718 .22426 .52035 .24603 .51324 .23129 .49996 Metetra
.646 .762 .934 r
.23129 .49996 .24603 .51324 .268 .50608 .25336 .49268 Metetra
.646 .762 .934 r
.25336 .49268 .268 .50608 .29014 .49884 .27562 .48533 Metetra
.646 .762 .934 r
.27562 .48533 .29014 .49884 .31248 .49155 .29806 .47793 Metetra
.646 .762 .934 r
.29806 .47793 .31248 .49155 .335 .4842 .32071 .47046 Metetra
.646 .762 .934 r
.32071 .47046 .335 .4842 .35772 .47678 .34354 .46292 Metetra
.646 .762 .934 r
.34354 .46292 .35772 .47678 .38064 .4693 .36658 .45532 Metetra
.646 .762 .934 r
.36658 .45532 .38064 .4693 .40375 .46176 .38981 .44766 Metetra
.646 .762 .934 r
.38981 .44766 .40375 .46176 .42706 .45415 .41325 .43992 Metetra
.964 .717 .513 r
.41325 .43992 .42706 .45415 .45569 .22128 .443 .20623 Metetra
.664 .741 .908 r
.443 .20623 .45569 .22128 .47779 .21315 .46522 .19798 Metetra
.664 .741 .908 r
.46522 .19798 .47779 .21315 .50007 .20496 .48762 .18966 Metetra
.664 .741 .908 r
.48762 .18966 .50007 .20496 .52254 .1967 .5102 .18128 Metetra
.664 .741 .908 r
.5102 .18128 .52254 .1967 .54519 .18838 .53297 .17282 Metetra
.664 .741 .908 r
.53297 .17282 .54519 .18838 .56802 .17998 .55593 .1643 Metetra
.664 .741 .908 r
.55593 .1643 .56802 .17998 .59105 .17152 .57909 .1557 Metetra
.664 .741 .908 r
.57909 .1557 .59105 .17152 .61426 .16298 .60244 .14703 Metetra
.664 .741 .908 r
.60244 .14703 .61426 .16298 .63768 .15437 .62598 .13829 Metetra
.664 .741 .908 r
.62598 .13829 .63768 .15437 .66129 .14569 .64972 .12948 Metetra
.664 .741 .908 r
.64972 .12948 .66129 .14569 .6851 .13694 .67367 .12059 Metetra
.664 .741 .908 r
.67367 .12059 .6851 .13694 .70911 .12812 .69782 .11162 Metetra
.664 .741 .908 r
.69782 .11162 .70911 .12812 .73332 .11921 .72218 .10258 Metetra
.869 .479 .007 r
.72218 .10258 .73332 .11921 .76653 .22089 .75519 .20439 Metetra
.656 .751 .92 r
.08173 .4226 .09677 .43573 .11695 .42864 .10199 .4154 Metetra
.656 .751 .92 r
.10199 .4154 .11695 .42864 .13729 .4215 .12242 .40815 Metetra
.945 .625 .396 r
.12242 .40815 .13729 .4215 .14483 .52849 .12944 .51544 Metetra
.646 .762 .934 r
.12944 .51544 .14483 .52849 .16618 .52144 .15088 .50829 Metetra
.646 .762 .934 r
.15088 .50829 .16618 .52144 .1877 .51434 .1725 .50108 Metetra
.646 .762 .934 r
.1725 .50108 .1877 .51434 .2094 .50718 .19431 .4938 Metetra
.646 .762 .934 r
.19431 .4938 .2094 .50718 .23129 .49996 .2163 .48647 Metetra
.646 .762 .934 r
.2163 .48647 .23129 .49996 .25336 .49268 .23849 .47907 Metetra
.646 .762 .934 r
.23849 .47907 .25336 .49268 .27562 .48533 .26086 .47161 Metetra
.646 .762 .934 r
.26086 .47161 .27562 .48533 .29806 .47793 .28342 .46409 Metetra
.646 .762 .934 r
.28342 .46409 .29806 .47793 .32071 .47046 .30618 .4565 Metetra
.646 .762 .934 r
.30618 .4565 .32071 .47046 .34354 .46292 .32914 .44884 Metetra
.646 .762 .934 r
.32914 .44884 .34354 .46292 .36658 .45532 .3523 .44112 Metetra
.646 .762 .934 r
.3523 .44112 .36658 .45532 .38981 .44766 .37566 .43333 Metetra
.646 .762 .934 r
.37566 .43333 .38981 .44766 .41325 .43992 .39922 .42547 Metetra
.964 .717 .513 r
.39922 .42547 .41325 .43992 .443 .20623 .43012 .19095 Metetra
.664 .741 .908 r
.43012 .19095 .443 .20623 .46522 .19798 .45246 .18257 Metetra
.664 .741 .908 r
.45246 .18257 .46522 .19798 .48762 .18966 .47497 .17413 Metetra
.664 .741 .908 r
.47497 .17413 .48762 .18966 .5102 .18128 .49768 .16562 Metetra
.664 .741 .908 r
.49768 .16562 .5102 .18128 .53297 .17282 .52057 .15703 Metetra
.664 .741 .908 r
.52057 .15703 .53297 .17282 .55593 .1643 .54366 .14837 Metetra
.664 .741 .908 r
.54366 .14837 .55593 .1643 .57909 .1557 .56694 .13964 Metetra
.664 .741 .908 r
.56694 .13964 .57909 .1557 .60244 .14703 .59042 .13084 Metetra
.664 .741 .908 r
.59042 .13084 .60244 .14703 .62598 .13829 .6141 .12196 Metetra
.664 .741 .908 r
.6141 .12196 .62598 .13829 .64972 .12948 .63798 .11301 Metetra
.664 .741 .908 r
.63798 .11301 .64972 .12948 .67367 .12059 .66207 .10397 Metetra
.664 .741 .908 r
.66207 .10397 .67367 .12059 .69782 .11162 .68636 .09486 Metetra
.664 .741 .908 r
.68636 .09486 .69782 .11162 .72218 .10258 .71086 .08568 Metetra
.869 .479 .007 r
.71086 .08568 .72218 .10258 .75519 .20439 .74366 .18761 Metetra
.656 .751 .92 r
.06646 .40927 .08173 .4226 .10199 .4154 .08681 .40197 Metetra
.656 .751 .92 r
.08681 .40197 .10199 .4154 .12242 .40815 .10733 .39461 Metetra
.945 .625 .396 r
.10733 .39461 .12242 .40815 .12944 .51544 .1138 .50219 Metetra
.646 .762 .934 r
.1138 .50219 .12944 .51544 .15088 .50829 .13534 .49493 Metetra
.646 .762 .934 r
.13534 .49493 .15088 .50829 .1725 .50108 .15707 .4876 Metetra
.646 .762 .934 r
.15707 .4876 .1725 .50108 .19431 .4938 .17898 .48021 Metetra
.646 .762 .934 r
.17898 .48021 .19431 .4938 .2163 .48647 .20109 .47276 Metetra
.646 .762 .934 r
.20109 .47276 .2163 .48647 .23849 .47907 .22338 .46525 Metetra
.646 .762 .934 r
.22338 .46525 .23849 .47907 .26086 .47161 .24586 .45767 Metetra
.646 .762 .934 r
.24586 .45767 .26086 .47161 .28342 .46409 .26854 .45002 Metetra
.646 .762 .934 r
.26854 .45002 .28342 .46409 .30618 .4565 .29142 .44231 Metetra
.646 .762 .934 r
.29142 .44231 .30618 .4565 .32914 .44884 .3145 .43453 Metetra
.646 .762 .934 r
.3145 .43453 .32914 .44884 .3523 .44112 .33778 .42668 Metetra
.646 .762 .934 r
.33778 .42668 .3523 .44112 .37566 .43333 .36127 .41876 Metetra
.646 .762 .934 r
.36127 .41876 .37566 .43333 .39922 .42547 .38497 .41077 Metetra
.964 .717 .513 r
.38497 .41077 .39922 .42547 .43012 .19095 .41705 .17543 Metetra
.664 .741 .908 r
.41705 .17543 .43012 .19095 .45246 .18257 .4395 .16693 Metetra
.664 .741 .908 r
.4395 .16693 .45246 .18257 .47497 .17413 .46213 .15836 Metetra
.664 .741 .908 r
.46213 .15836 .47497 .17413 .49768 .16562 .48496 .14971 Metetra
.664 .741 .908 r
.48496 .14971 .49768 .16562 .52057 .15703 .50798 .14099 Metetra
.664 .741 .908 r
.50798 .14099 .52057 .15703 .54366 .14837 .53119 .1322 Metetra
.664 .741 .908 r
.53119 .1322 .54366 .14837 .56694 .13964 .5546 .12333 Metetra
.664 .741 .908 r
.5546 .12333 .56694 .13964 .59042 .13084 .57822 .11439 Metetra
.664 .741 .908 r
.57822 .11439 .59042 .13084 .6141 .12196 .60203 .10537 Metetra
.664 .741 .908 r
.60203 .10537 .6141 .12196 .63798 .11301 .62605 .09627 Metetra
.664 .741 .908 r
.62605 .09627 .63798 .11301 .66207 .10397 .65028 .08709 Metetra
.664 .741 .908 r
.65028 .08709 .66207 .10397 .68636 .09486 .67471 .07784 Metetra
.664 .741 .908 r
.67471 .07784 .68636 .09486 .71086 .08568 .69936 .0685 Metetra
.869 .479 .007 r
.69936 .0685 .71086 .08568 .74366 .18761 .73194 .17055 Metetra
.656 .751 .92 r
.05096 .39575 .06646 .40927 .08681 .40197 .07141 .38834 Metetra
.656 .751 .92 r
.07141 .38834 .08681 .40197 .10733 .39461 .09202 .38086 Metetra
.656 .751 .92 r
.09202 .38086 .10733 .39461 .1138 .50219 .1128 .37333 Metetra
.545 .355 .575 r
.1128 .37333 .1138 .50219 .13534 .49493 .13375 .36574 Metetra
.545 .355 .575 r
.13375 .36574 .13534 .49493 .15707 .4876 .15487 .35808 Metetra
.545 .355 .575 r
.15487 .35808 .15707 .4876 .17898 .48021 .17617 .35036 Metetra
.545 .355 .575 r
.17617 .35036 .17898 .48021 .20109 .47276 .19765 .34257 Metetra
.545 .355 .575 r
.19765 .34257 .20109 .47276 .22338 .46525 .2193 .33472 Metetra
.545 .355 .575 r
.2193 .33472 .22338 .46525 .24586 .45767 .24114 .3268 Metetra
.545 .355 .575 r
.24114 .3268 .24586 .45767 .26854 .45002 .26316 .31882 Metetra
.545 .355 .575 r
.26316 .31882 .26854 .45002 .29142 .44231 .28537 .31077 Metetra
.545 .355 .575 r
.28537 .31077 .29142 .44231 .3145 .43453 .30777 .30265 Metetra
.545 .355 .575 r
.30777 .30265 .3145 .43453 .33778 .42668 .33036 .29446 Metetra
.545 .355 .575 r
.33036 .29446 .33778 .42668 .36127 .41876 .35315 .2862 Metetra
.545 .355 .575 r
.35315 .2862 .36127 .41876 .38497 .41077 .37613 .27787 Metetra
.545 .355 .575 r
.37613 .27787 .38497 .41077 .41705 .17543 .39931 .26947 Metetra
.443 .149 .369 r
.39931 .26947 .41705 .17543 .4395 .16693 .42269 .26099 Metetra
.443 .149 .369 r
.42269 .26099 .4395 .16693 .46213 .15836 .44628 .25244 Metetra
.443 .149 .369 r
.44628 .25244 .46213 .15836 .48496 .14971 .47007 .24381 Metetra
.443 .149 .369 r
.47007 .24381 .48496 .14971 .50798 .14099 .49408 .23511 Metetra
.443 .149 .369 r
.49408 .23511 .50798 .14099 .53119 .1322 .51829 .22633 Metetra
.443 .149 .369 r
.51829 .22633 .53119 .1322 .5546 .12333 .54272 .21748 Metetra
.443 .149 .369 r
.54272 .21748 .5546 .12333 .57822 .11439 .56737 .20854 Metetra
.443 .149 .369 r
.56737 .20854 .57822 .11439 .60203 .10537 .59224 .19952 Metetra
.443 .149 .369 r
.59224 .19952 .60203 .10537 .62605 .09627 .61734 .19043 Metetra
.443 .149 .369 r
.61734 .19043 .62605 .09627 .65028 .08709 .64266 .18125 Metetra
.443 .149 .369 r
.64266 .18125 .65028 .08709 .67471 .07784 .66821 .17198 Metetra
.443 .149 .369 r
.66821 .17198 .67471 .07784 .69936 .0685 .694 .16264 Metetra
.443 .149 .369 r
.694 .16264 .69936 .0685 .73194 .17055 .72002 .1532 Metetra
.656 .751 .92 r
.03523 .38202 .05096 .39575 .07141 .38834 .05577 .37449 Metetra
.656 .751 .92 r
.05577 .37449 .07141 .38834 .09202 .38086 .07647 .36691 Metetra
.656 .751 .92 r
.07647 .36691 .09202 .38086 .1128 .37333 .09734 .35926 Metetra
.656 .751 .92 r
.09734 .35926 .1128 .37333 .13375 .36574 .11839 .35155 Metetra
.656 .751 .92 r
.11839 .35155 .13375 .36574 .15487 .35808 .13961 .34377 Metetra
.656 .751 .92 r
.13961 .34377 .15487 .35808 .17617 .35036 .16101 .33593 Metetra
.656 .751 .92 r
.16101 .33593 .17617 .35036 .19765 .34257 .18259 .32803 Metetra
.656 .751 .92 r
.18259 .32803 .19765 .34257 .2193 .33472 .20435 .32005 Metetra
.656 .751 .92 r
.20435 .32005 .2193 .33472 .24114 .3268 .2263 .31201 Metetra
.656 .751 .92 r
.2263 .31201 .24114 .3268 .26316 .31882 .24843 .3039 Metetra
.656 .751 .92 r
.24843 .3039 .26316 .31882 .28537 .31077 .27075 .29572 Metetra
.656 .751 .92 r
.27075 .29572 .28537 .31077 .30777 .30265 .29327 .28747 Metetra
.656 .751 .92 r
.29327 .28747 .30777 .30265 .33036 .29446 .31598 .27915 Metetra
.656 .751 .92 r
.31598 .27915 .33036 .29446 .35315 .2862 .33888 .27076 Metetra
.656 .751 .92 r
.33888 .27076 .35315 .2862 .37613 .27787 .36198 .2623 Metetra
.656 .751 .92 r
.36198 .2623 .37613 .27787 .39931 .26947 .38529 .25376 Metetra
.656 .751 .92 r
.38529 .25376 .39931 .26947 .42269 .26099 .4088 .24514 Metetra
.656 .751 .92 r
.4088 .24514 .42269 .26099 .44628 .25244 .43252 .23645 Metetra
.656 .751 .92 r
.43252 .23645 .44628 .25244 .47007 .24381 .45644 .22769 Metetra
.656 .751 .92 r
.45644 .22769 .47007 .24381 .49408 .23511 .48058 .21884 Metetra
.656 .751 .92 r
.48058 .21884 .49408 .23511 .51829 .22633 .50494 .20992 Metetra
.656 .751 .92 r
.50494 .20992 .51829 .22633 .54272 .21748 .52951 .20092 Metetra
.656 .751 .92 r
.52951 .20092 .54272 .21748 .56737 .20854 .55431 .19183 Metetra
.656 .751 .92 r
.55431 .19183 .56737 .20854 .59224 .19952 .57933 .18266 Metetra
.656 .751 .92 r
.57933 .18266 .59224 .19952 .61734 .19043 .60457 .17341 Metetra
.656 .751 .92 r
.60457 .17341 .61734 .19043 .64266 .18125 .63005 .16408 Metetra
.656 .751 .92 r
.63005 .16408 .64266 .18125 .66821 .17198 .65576 .15466 Metetra
.656 .751 .92 r
.65576 .15466 .66821 .17198 .694 .16264 .68171 .14515 Metetra
.656 .751 .92 r
.68171 .14515 .694 .16264 .72002 .1532 .7079 .13556 Metetra
.656 .751 .92 r
.01926 .36808 .03523 .38202 .05577 .37449 .03989 .36044 Metetra
.656 .751 .92 r
.03989 .36044 .05577 .37449 .07647 .36691 .06068 .35274 Metetra
.656 .751 .92 r
.06068 .35274 .07647 .36691 .09734 .35926 .08165 .34497 Metetra
.656 .751 .92 r
.08165 .34497 .09734 .35926 .11839 .35155 .10279 .33714 Metetra
.656 .751 .92 r
.10279 .33714 .11839 .35155 .13961 .34377 .12411 .32925 Metetra
.656 .751 .92 r
.12411 .32925 .13961 .34377 .16101 .33593 .14562 .32128 Metetra
.656 .751 .92 r
.14562 .32128 .16101 .33593 .18259 .32803 .1673 .31325 Metetra
.656 .751 .92 r
.1673 .31325 .18259 .32803 .20435 .32005 .18917 .30515 Metetra
.656 .751 .92 r
.18917 .30515 .20435 .32005 .2263 .31201 .21122 .29699 Metetra
.656 .751 .92 r
.21122 .29699 .2263 .31201 .24843 .3039 .23347 .28875 Metetra
.656 .751 .92 r
.23347 .28875 .24843 .3039 .27075 .29572 .2559 .28044 Metetra
.656 .751 .92 r
.2559 .28044 .27075 .29572 .29327 .28747 .27853 .27206 Metetra
.656 .751 .92 r
.27853 .27206 .29327 .28747 .31598 .27915 .30136 .2636 Metetra
.656 .751 .92 r
.30136 .2636 .31598 .27915 .33888 .27076 .32438 .25508 Metetra
.656 .751 .92 r
.32438 .25508 .33888 .27076 .36198 .2623 .34761 .24647 Metetra
.656 .751 .92 r
.34761 .24647 .36198 .2623 .38529 .25376 .37104 .2378 Metetra
.656 .751 .92 r
.37104 .2378 .38529 .25376 .4088 .24514 .39468 .22904 Metetra
.656 .751 .92 r
.39468 .22904 .4088 .24514 .43252 .23645 .41853 .22021 Metetra
.656 .751 .92 r
.41853 .22021 .43252 .23645 .45644 .22769 .44259 .2113 Metetra
.656 .751 .92 r
.44259 .2113 .45644 .22769 .48058 .21884 .46687 .20231 Metetra
.656 .751 .92 r
.46687 .20231 .48058 .21884 .50494 .20992 .49136 .19323 Metetra
.656 .751 .92 r
.49136 .19323 .50494 .20992 .52951 .20092 .51608 .18408 Metetra
.656 .751 .92 r
.51608 .18408 .52951 .20092 .55431 .19183 .54102 .17484 Metetra
.656 .751 .92 r
.54102 .17484 .55431 .19183 .57933 .18266 .56619 .16552 Metetra
.656 .751 .92 r
.56619 .16552 .57933 .18266 .60457 .17341 .59159 .15611 Metetra
.656 .751 .92 r
.59159 .15611 .60457 .17341 .63005 .16408 .61722 .14662 Metetra
.656 .751 .92 r
.61722 .14662 .63005 .16408 .65576 .15466 .6431 .13704 Metetra
.656 .751 .92 r
.6431 .13704 .65576 .15466 .68171 .14515 .66921 .12737 Metetra
.656 .751 .92 r
.66921 .12737 .68171 .14515 .7079 .13556 .69556 .11761 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((I  I  I)\)\) \((x, y)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.4", "4.16"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[psi[x] psi[y]], {x, -0.1, 1},
{y, -0.1, 1}, PlotPoints -> 30, PlotRange -> All,
Boxed -> False, Axes -> False];\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
8.83083e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.656 .751 .92 r
.39082 .69236 .40169 .70185 .41987 .69673 .40908 .68717 Metetra
.656 .751 .92 r
.40908 .68717 .41987 .69673 .43818 .69156 .42746 .68194 Metetra
.924 .72 .609 r
.42746 .68194 .43818 .69156 .45661 .68637 .44821 .57767 Metetra
.594 .42 .616 r
.44821 .57767 .45661 .68637 .47517 .68114 .46632 .57219 Metetra
.594 .42 .616 r
.46632 .57219 .47517 .68114 .49385 .67587 .48456 .56668 Metetra
.594 .42 .616 r
.48456 .56668 .49385 .67587 .51267 .67056 .50292 .56112 Metetra
.594 .42 .616 r
.50292 .56112 .51267 .67056 .53161 .66522 .52141 .55553 Metetra
.594 .42 .616 r
.52141 .55553 .53161 .66522 .55068 .65984 .54002 .5499 Metetra
.594 .42 .616 r
.54002 .5499 .55068 .65984 .56989 .65443 .55875 .54424 Metetra
.594 .42 .616 r
.55875 .54424 .56989 .65443 .58923 .64898 .57762 .53853 Metetra
.594 .42 .616 r
.57762 .53853 .58923 .64898 .60871 .64349 .59661 .53279 Metetra
.594 .42 .616 r
.59661 .53279 .60871 .64349 .62832 .63796 .61573 .52701 Metetra
.594 .42 .616 r
.61573 .52701 .62832 .63796 .64807 .63239 .63499 .52118 Metetra
.594 .42 .616 r
.63499 .52118 .64807 .63239 .66796 .62678 .65438 .51532 Metetra
.594 .42 .616 r
.65438 .51532 .66796 .62678 .688 .62113 .6739 .50942 Metetra
0 0 .267 r
.6739 .50942 .688 .62113 .70817 .61544 .70416 .71257 Metetra
.547 .302 .496 r
.70416 .71257 .70817 .61544 .72849 .60972 .72525 .70698 Metetra
.547 .302 .496 r
.72525 .70698 .72849 .60972 .74896 .60395 .74649 .70136 Metetra
.547 .302 .496 r
.74649 .70136 .74896 .60395 .76957 .59813 .76789 .69568 Metetra
.547 .302 .496 r
.76789 .69568 .76957 .59813 .79033 .59228 .78945 .68997 Metetra
.547 .302 .496 r
.78945 .68997 .79033 .59228 .81124 .58638 .81118 .68421 Metetra
.547 .302 .496 r
.81118 .68421 .81124 .58638 .83231 .58045 .83307 .67841 Metetra
.547 .302 .496 r
.83307 .67841 .83231 .58045 .85352 .57446 .85512 .67256 Metetra
.547 .302 .496 r
.85512 .67256 .85352 .57446 .8749 .56844 .87734 .66668 Metetra
.547 .302 .496 r
.87734 .66668 .8749 .56844 .89643 .56237 .89974 .66074 Metetra
.547 .302 .496 r
.89974 .66074 .89643 .56237 .91812 .55625 .9223 .65476 Metetra
.547 .302 .496 r
.9223 .65476 .91812 .55625 .93997 .55009 .94504 .64873 Metetra
.547 .302 .496 r
.94504 .64873 .93997 .55009 .96198 .54388 .96795 .64266 Metetra
.111 0 .422 r
.96795 .64266 .96198 .54388 .98416 .53763 .97615 .52596 Metetra
.656 .751 .92 r
.3798 .68275 .39082 .69236 .40908 .68717 .39814 .67749 Metetra
.656 .751 .92 r
.39814 .67749 .40908 .68717 .42746 .68194 .41661 .6722 Metetra
.924 .72 .609 r
.41661 .6722 .42746 .68194 .44821 .57767 .43775 .56753 Metetra
.664 .741 .908 r
.43775 .56753 .44821 .57767 .46632 .57219 .45595 .56198 Metetra
.664 .741 .908 r
.45595 .56198 .46632 .57219 .48456 .56668 .47426 .5564 Metetra
.664 .741 .908 r
.47426 .5564 .48456 .56668 .50292 .56112 .4927 .55077 Metetra
.664 .741 .908 r
.4927 .55077 .50292 .56112 .52141 .55553 .51127 .54511 Metetra
.664 .741 .908 r
.51127 .54511 .52141 .55553 .54002 .5499 .52996 .53941 Metetra
.664 .741 .908 r
.52996 .53941 .54002 .5499 .55875 .54424 .54878 .53368 Metetra
.664 .741 .908 r
.54878 .53368 .55875 .54424 .57762 .53853 .56773 .5279 Metetra
.664 .741 .908 r
.56773 .5279 .57762 .53853 .59661 .53279 .58681 .52208 Metetra
.664 .741 .908 r
.58681 .52208 .59661 .53279 .61573 .52701 .60602 .51622 Metetra
.664 .741 .908 r
.60602 .51622 .61573 .52701 .63499 .52118 .62537 .51033 Metetra
.664 .741 .908 r
.62537 .51033 .63499 .52118 .65438 .51532 .64485 .50439 Metetra
.664 .741 .908 r
.64485 .50439 .65438 .51532 .6739 .50942 .66446 .49841 Metetra
.964 .645 .358 r
.66446 .49841 .6739 .50942 .70416 .71257 .6943 .70222 Metetra
.646 .762 .934 r
.6943 .70222 .70416 .71257 .72525 .70698 .7155 .69656 Metetra
.646 .762 .934 r
.7155 .69656 .72525 .70698 .74649 .70136 .73685 .69085 Metetra
.646 .762 .934 r
.73685 .69085 .74649 .70136 .76789 .69568 .75836 .6851 Metetra
.646 .762 .934 r
.75836 .6851 .76789 .69568 .78945 .68997 .78004 .67931 Metetra
.646 .762 .934 r
.78004 .67931 .78945 .68997 .81118 .68421 .80188 .67347 Metetra
.646 .762 .934 r
.80188 .67347 .81118 .68421 .83307 .67841 .82388 .66758 Metetra
.646 .762 .934 r
.82388 .66758 .83307 .67841 .85512 .67256 .84606 .66166 Metetra
.646 .762 .934 r
.84606 .66166 .85512 .67256 .87734 .66668 .86841 .65568 Metetra
.646 .762 .934 r
.86841 .65568 .87734 .66668 .89974 .66074 .89092 .64966 Metetra
.646 .762 .934 r
.89092 .64966 .89974 .66074 .9223 .65476 .91361 .6436 Metetra
.646 .762 .934 r
.91361 .6436 .9223 .65476 .94504 .64873 .93648 .63748 Metetra
.646 .762 .934 r
.93648 .63748 .94504 .64873 .96795 .64266 .95953 .63132 Metetra
.986 .752 .496 r
.95953 .63132 .96795 .64266 .97615 .52596 .96802 .51413 Metetra
.656 .751 .92 r
.36865 .67302 .3798 .68275 .39814 .67749 .38707 .66769 Metetra
.656 .751 .92 r
.38707 .66769 .39814 .67749 .41661 .6722 .40561 .66233 Metetra
.924 .72 .609 r
.40561 .66233 .41661 .6722 .43775 .56753 .42717 .55726 Metetra
.664 .741 .908 r
.42717 .55726 .43775 .56753 .45595 .56198 .44544 .55164 Metetra
.664 .741 .908 r
.44544 .55164 .45595 .56198 .47426 .5564 .46383 .54599 Metetra
.664 .741 .908 r
.46383 .54599 .47426 .5564 .4927 .55077 .48236 .54029 Metetra
.664 .741 .908 r
.48236 .54029 .4927 .55077 .51127 .54511 .501 .53456 Metetra
.664 .741 .908 r
.501 .53456 .51127 .54511 .52996 .53941 .51978 .52879 Metetra
.664 .741 .908 r
.51978 .52879 .52996 .53941 .54878 .53368 .53868 .52298 Metetra
.664 .741 .908 r
.53868 .52298 .54878 .53368 .56773 .5279 .55772 .51713 Metetra
.664 .741 .908 r
.55772 .51713 .56773 .5279 .58681 .52208 .57689 .51124 Metetra
.664 .741 .908 r
.57689 .51124 .58681 .52208 .60602 .51622 .59619 .5053 Metetra
.664 .741 .908 r
.59619 .5053 .60602 .51622 .62537 .51033 .61562 .49933 Metetra
.664 .741 .908 r
.61562 .49933 .62537 .51033 .64485 .50439 .63519 .49331 Metetra
.664 .741 .908 r
.63519 .49331 .64485 .50439 .66446 .49841 .6549 .48726 Metetra
.964 .645 .358 r
.6549 .48726 .66446 .49841 .6943 .70222 .6843 .69173 Metetra
.646 .762 .934 r
.6843 .69173 .6943 .70222 .7155 .69656 .70561 .68599 Metetra
.646 .762 .934 r
.70561 .68599 .7155 .69656 .73685 .69085 .72707 .6802 Metetra
.646 .762 .934 r
.72707 .6802 .73685 .69085 .75836 .6851 .7487 .67437 Metetra
.646 .762 .934 r
.7487 .67437 .75836 .6851 .78004 .67931 .77049 .66849 Metetra
.646 .762 .934 r
.77049 .66849 .78004 .67931 .80188 .67347 .79245 .66257 Metetra
.646 .762 .934 r
.79245 .66257 .80188 .67347 .82388 .66758 .81457 .6566 Metetra
.646 .762 .934 r
.81457 .6566 .82388 .66758 .84606 .66166 .83687 .65059 Metetra
.646 .762 .934 r
.83687 .65059 .84606 .66166 .86841 .65568 .85934 .64453 Metetra
.646 .762 .934 r
.85934 .64453 .86841 .65568 .89092 .64966 .88198 .63843 Metetra
.646 .762 .934 r
.88198 .63843 .89092 .64966 .91361 .6436 .9048 .63227 Metetra
.646 .762 .934 r
.9048 .63227 .91361 .6436 .93648 .63748 .9278 .62607 Metetra
.646 .762 .934 r
.9278 .62607 .93648 .63748 .95953 .63132 .95098 .61982 Metetra
.986 .752 .496 r
.95098 .61982 .95953 .63132 .96802 .51413 .95977 .50214 Metetra
.656 .751 .92 r
.35736 .66316 .36865 .67302 .38707 .66769 .37585 .65777 Metetra
.656 .751 .92 r
.37585 .65777 .38707 .66769 .40561 .66233 .39448 .65234 Metetra
.924 .72 .609 r
.39448 .65234 .40561 .66233 .42717 .55726 .41645 .54686 Metetra
.664 .741 .908 r
.41645 .54686 .42717 .55726 .44544 .55164 .4348 .54117 Metetra
.664 .741 .908 r
.4348 .54117 .44544 .55164 .46383 .54599 .45328 .53545 Metetra
.664 .741 .908 r
.45328 .53545 .46383 .54599 .48236 .54029 .47188 .52968 Metetra
.664 .741 .908 r
.47188 .52968 .48236 .54029 .501 .53456 .49061 .52388 Metetra
.664 .741 .908 r
.49061 .52388 .501 .53456 .51978 .52879 .50947 .51803 Metetra
.664 .741 .908 r
.50947 .51803 .51978 .52879 .53868 .52298 .52846 .51215 Metetra
.664 .741 .908 r
.52846 .51215 .53868 .52298 .55772 .51713 .54758 .50622 Metetra
.664 .741 .908 r
.54758 .50622 .55772 .51713 .57689 .51124 .56683 .50025 Metetra
.664 .741 .908 r
.56683 .50025 .57689 .51124 .59619 .5053 .58622 .49424 Metetra
.664 .741 .908 r
.58622 .49424 .59619 .5053 .61562 .49933 .60575 .48819 Metetra
.664 .741 .908 r
.60575 .48819 .61562 .49933 .63519 .49331 .62542 .4821 Metetra
.664 .741 .908 r
.62542 .4821 .63519 .49331 .6549 .48726 .64522 .47596 Metetra
.964 .645 .358 r
.64522 .47596 .6549 .48726 .6843 .69173 .67416 .68109 Metetra
.646 .762 .934 r
.67416 .68109 .6843 .69173 .70561 .68599 .69558 .67527 Metetra
.646 .762 .934 r
.69558 .67527 .70561 .68599 .72707 .6802 .71716 .6694 Metetra
.646 .762 .934 r
.71716 .6694 .72707 .6802 .7487 .67437 .7389 .66348 Metetra
.646 .762 .934 r
.7389 .66348 .7487 .67437 .77049 .66849 .7608 .65753 Metetra
.646 .762 .934 r
.7608 .65753 .77049 .66849 .79245 .66257 .78288 .65152 Metetra
.646 .762 .934 r
.78288 .65152 .79245 .66257 .81457 .6566 .80513 .64547 Metetra
.646 .762 .934 r
.80513 .64547 .81457 .6566 .83687 .65059 .82755 .63937 Metetra
.646 .762 .934 r
.82755 .63937 .83687 .65059 .85934 .64453 .85014 .63322 Metetra
.646 .762 .934 r
.85014 .63322 .85934 .64453 .88198 .63843 .87291 .62703 Metetra
.646 .762 .934 r
.87291 .62703 .88198 .63843 .9048 .63227 .89586 .62079 Metetra
.646 .762 .934 r
.89586 .62079 .9048 .63227 .9278 .62607 .919 .6145 Metetra
.646 .762 .934 r
.919 .6145 .9278 .62607 .95098 .61982 .94231 .60815 Metetra
.986 .752 .496 r
.94231 .60815 .95098 .61982 .95977 .50214 .95141 .48997 Metetra
.656 .751 .92 r
.34592 .65317 .35736 .66316 .37585 .65777 .36449 .64771 Metetra
.656 .751 .92 r
.36449 .64771 .37585 .65777 .39448 .65234 .3832 .64221 Metetra
.924 .72 .609 r
.3832 .64221 .39448 .65234 .41645 .54686 .4056 .53633 Metetra
.664 .741 .908 r
.4056 .53633 .41645 .54686 .4348 .54117 .42403 .53057 Metetra
.664 .741 .908 r
.42403 .53057 .4348 .54117 .45328 .53545 .44258 .52477 Metetra
.664 .741 .908 r
.44258 .52477 .45328 .53545 .47188 .52968 .46127 .51893 Metetra
.664 .741 .908 r
.46127 .51893 .47188 .52968 .49061 .52388 .48008 .51305 Metetra
.664 .741 .908 r
.48008 .51305 .49061 .52388 .50947 .51803 .49902 .50713 Metetra
.664 .741 .908 r
.49902 .50713 .50947 .51803 .52846 .51215 .5181 .50117 Metetra
.664 .741 .908 r
.5181 .50117 .52846 .51215 .54758 .50622 .53731 .49517 Metetra
.664 .741 .908 r
.53731 .49517 .54758 .50622 .56683 .50025 .55665 .48913 Metetra
.664 .741 .908 r
.55665 .48913 .56683 .50025 .58622 .49424 .57613 .48304 Metetra
.664 .741 .908 r
.57613 .48304 .58622 .49424 .60575 .48819 .59575 .47691 Metetra
.664 .741 .908 r
.59575 .47691 .60575 .48819 .62542 .4821 .61551 .47073 Metetra
.664 .741 .908 r
.61551 .47073 .62542 .4821 .64522 .47596 .63541 .46452 Metetra
.964 .645 .358 r
.63541 .46452 .64522 .47596 .67416 .68109 .66388 .6703 Metetra
.646 .762 .934 r
.66388 .6703 .67416 .68109 .69558 .67527 .68541 .6644 Metetra
.646 .762 .934 r
.68541 .6644 .69558 .67527 .71716 .6694 .7071 .65845 Metetra
.646 .762 .934 r
.7071 .65845 .71716 .6694 .7389 .66348 .72896 .65245 Metetra
.646 .762 .934 r
.72896 .65245 .7389 .66348 .7608 .65753 .75098 .6464 Metetra
.646 .762 .934 r
.75098 .6464 .7608 .65753 .78288 .65152 .77318 .64031 Metetra
.646 .762 .934 r
.77318 .64031 .78288 .65152 .80513 .64547 .79555 .63417 Metetra
.646 .762 .934 r
.79555 .63417 .80513 .64547 .82755 .63937 .81809 .62799 Metetra
.646 .762 .934 r
.81809 .62799 .82755 .63937 .85014 .63322 .84081 .62175 Metetra
.646 .762 .934 r
.84081 .62175 .85014 .63322 .87291 .62703 .86371 .61547 Metetra
.646 .762 .934 r
.86371 .61547 .87291 .62703 .89586 .62079 .8868 .60913 Metetra
.646 .762 .934 r
.8868 .60913 .89586 .62079 .919 .6145 .91006 .60275 Metetra
.646 .762 .934 r
.91006 .60275 .919 .6145 .94231 .60815 .93351 .59631 Metetra
.986 .752 .496 r
.93351 .59631 .94231 .60815 .95141 .48997 .94293 .47763 Metetra
.656 .751 .92 r
.33433 .64306 .34592 .65317 .36449 .64771 .35299 .63753 Metetra
.656 .751 .92 r
.35299 .63753 .36449 .64771 .3832 .64221 .37177 .63196 Metetra
.924 .72 .609 r
.37177 .63196 .3832 .64221 .4056 .53633 .39461 .52567 Metetra
.664 .741 .908 r
.39461 .52567 .4056 .53633 .42403 .53057 .41312 .51983 Metetra
.664 .741 .908 r
.41312 .51983 .42403 .53057 .44258 .52477 .43175 .51396 Metetra
.664 .741 .908 r
.43175 .51396 .44258 .52477 .46127 .51893 .45052 .50805 Metetra
.664 .741 .908 r
.45052 .50805 .46127 .51893 .48008 .51305 .46942 .50209 Metetra
.664 .741 .908 r
.46942 .50209 .48008 .51305 .49902 .50713 .48844 .4961 Metetra
.664 .741 .908 r
.48844 .4961 .49902 .50713 .5181 .50117 .50761 .49006 Metetra
.664 .741 .908 r
.50761 .49006 .5181 .50117 .53731 .49517 .5269 .48398 Metetra
.664 .741 .908 r
.5269 .48398 .53731 .49517 .55665 .48913 .54634 .47785 Metetra
.664 .741 .908 r
.54634 .47785 .55665 .48913 .57613 .48304 .56591 .47169 Metetra
.664 .741 .908 r
.56591 .47169 .57613 .48304 .59575 .47691 .58562 .46547 Metetra
.664 .741 .908 r
.58562 .46547 .59575 .47691 .61551 .47073 .60547 .45922 Metetra
.664 .741 .908 r
.60547 .45922 .61551 .47073 .63541 .46452 .62546 .45292 Metetra
.964 .645 .358 r
.62546 .45292 .63541 .46452 .66388 .6703 .65346 .65936 Metetra
.646 .762 .934 r
.65346 .65936 .66388 .6703 .68541 .6644 .6751 .65337 Metetra
.646 .762 .934 r
.6751 .65337 .68541 .6644 .7071 .65845 .6969 .64734 Metetra
.646 .762 .934 r
.6969 .64734 .7071 .65845 .72896 .65245 .71887 .64125 Metetra
.646 .762 .934 r
.71887 .64125 .72896 .65245 .75098 .6464 .74102 .63512 Metetra
.646 .762 .934 r
.74102 .63512 .75098 .6464 .77318 .64031 .76334 .62894 Metetra
.646 .762 .934 r
.76334 .62894 .77318 .64031 .79555 .63417 .78583 .62271 Metetra
.646 .762 .934 r
.78583 .62271 .79555 .63417 .81809 .62799 .8085 .61644 Metetra
.646 .762 .934 r
.8085 .61644 .81809 .62799 .84081 .62175 .83135 .61011 Metetra
.646 .762 .934 r
.83135 .61011 .84081 .62175 .86371 .61547 .85438 .60373 Metetra
.646 .762 .934 r
.85438 .60373 .86371 .61547 .8868 .60913 .87759 .59731 Metetra
.646 .762 .934 r
.87759 .59731 .8868 .60913 .91006 .60275 .90099 .59083 Metetra
.646 .762 .934 r
.90099 .59083 .91006 .60275 .93351 .59631 .92458 .5843 Metetra
.986 .752 .496 r
.92458 .5843 .93351 .59631 .94293 .47763 .93433 .46511 Metetra
.656 .751 .92 r
.32259 .63282 .33433 .64306 .35299 .63753 .34133 .62721 Metetra
.656 .751 .92 r
.34133 .62721 .35299 .63753 .37177 .63196 .3602 .62157 Metetra
.924 .72 .609 r
.3602 .62157 .37177 .63196 .39461 .52567 .38348 .51487 Metetra
.664 .741 .908 r
.38348 .51487 .39461 .52567 .41312 .51983 .40207 .50896 Metetra
.664 .741 .908 r
.40207 .50896 .41312 .51983 .43175 .51396 .42078 .50301 Metetra
.664 .741 .908 r
.42078 .50301 .43175 .51396 .45052 .50805 .43963 .49702 Metetra
.664 .741 .908 r
.43963 .49702 .45052 .50805 .46942 .50209 .45861 .49099 Metetra
.664 .741 .908 r
.45861 .49099 .46942 .50209 .48844 .4961 .47773 .48492 Metetra
.664 .741 .908 r
.47773 .48492 .48844 .4961 .50761 .49006 .49698 .4788 Metetra
.664 .741 .908 r
.49698 .4788 .50761 .49006 .5269 .48398 .51636 .47264 Metetra
.664 .741 .908 r
.51636 .47264 .5269 .48398 .54634 .47785 .53589 .46643 Metetra
.664 .741 .908 r
.53589 .46643 .54634 .47785 .56591 .47169 .55555 .46018 Metetra
.664 .741 .908 r
.55555 .46018 .56591 .47169 .58562 .46547 .57535 .45389 Metetra
.664 .741 .908 r
.57535 .45389 .58562 .46547 .60547 .45922 .5953 .44755 Metetra
.664 .741 .908 r
.5953 .44755 .60547 .45922 .62546 .45292 .61539 .44117 Metetra
.964 .645 .358 r
.61539 .44117 .62546 .45292 .65346 .65936 .64288 .64827 Metetra
.646 .762 .934 r
.64288 .64827 .65346 .65936 .6751 .65337 .66463 .64219 Metetra
.646 .762 .934 r
.66463 .64219 .6751 .65337 .6969 .64734 .68656 .63607 Metetra
.646 .762 .934 r
.68656 .63607 .6969 .64734 .71887 .64125 .70865 .6299 Metetra
.646 .762 .934 r
.70865 .6299 .71887 .64125 .74102 .63512 .73091 .62367 Metetra
.646 .762 .934 r
.73091 .62367 .74102 .63512 .76334 .62894 .75335 .61741 Metetra
.646 .762 .934 r
.75335 .61741 .76334 .62894 .78583 .62271 .77597 .61109 Metetra
.646 .762 .934 r
.77597 .61109 .78583 .62271 .8085 .61644 .79877 .60472 Metetra
.646 .762 .934 r
.79877 .60472 .8085 .61644 .83135 .61011 .82174 .5983 Metetra
.646 .762 .934 r
.82174 .5983 .83135 .61011 .85438 .60373 .84491 .59183 Metetra
.646 .762 .934 r
.84491 .59183 .85438 .60373 .87759 .59731 .86825 .58531 Metetra
.646 .762 .934 r
.86825 .58531 .87759 .59731 .90099 .59083 .89179 .57873 Metetra
.646 .762 .934 r
.89179 .57873 .90099 .59083 .92458 .5843 .91552 .5721 Metetra
.986 .752 .496 r
.91552 .5721 .92458 .5843 .93433 .46511 .92561 .45241 Metetra
.656 .751 .92 r
.3107 .62244 .32259 .63282 .34133 .62721 .32952 .61676 Metetra
.656 .751 .92 r
.32952 .61676 .34133 .62721 .3602 .62157 .34847 .61104 Metetra
.924 .72 .609 r
.34847 .61104 .3602 .62157 .38348 .51487 .3722 .50393 Metetra
.664 .741 .908 r
.3722 .50393 .38348 .51487 .40207 .50896 .39087 .49795 Metetra
.664 .741 .908 r
.39087 .49795 .40207 .50896 .42078 .50301 .40967 .49192 Metetra
.664 .741 .908 r
.40967 .49192 .42078 .50301 .43963 .49702 .4286 .48585 Metetra
.664 .741 .908 r
.4286 .48585 .43963 .49702 .45861 .49099 .44767 .47974 Metetra
.664 .741 .908 r
.44767 .47974 .45861 .49099 .47773 .48492 .46687 .47359 Metetra
.664 .741 .908 r
.46687 .47359 .47773 .48492 .49698 .4788 .48621 .46739 Metetra
.664 .741 .908 r
.48621 .46739 .49698 .4788 .51636 .47264 .50568 .46115 Metetra
.664 .741 .908 r
.50568 .46115 .51636 .47264 .53589 .46643 .5253 .45486 Metetra
.664 .741 .908 r
.5253 .45486 .53589 .46643 .55555 .46018 .54505 .44853 Metetra
.664 .741 .908 r
.54505 .44853 .55555 .46018 .57535 .45389 .56495 .44215 Metetra
.664 .741 .908 r
.56495 .44215 .57535 .45389 .5953 .44755 .58499 .43573 Metetra
.664 .741 .908 r
.58499 .43573 .5953 .44755 .61539 .44117 .60518 .42926 Metetra
.964 .645 .358 r
.60518 .42926 .61539 .44117 .64288 .64827 .63216 .63701 Metetra
.646 .762 .934 r
.63216 .63701 .64288 .64827 .66463 .64219 .65402 .63085 Metetra
.646 .762 .934 r
.65402 .63085 .66463 .64219 .68656 .63607 .67606 .62463 Metetra
.646 .762 .934 r
.67606 .62463 .68656 .63607 .70865 .6299 .69827 .61837 Metetra
.646 .762 .934 r
.69827 .61837 .70865 .6299 .73091 .62367 .72066 .61206 Metetra
.646 .762 .934 r
.72066 .61206 .73091 .62367 .75335 .61741 .74322 .6057 Metetra
.646 .762 .934 r
.74322 .6057 .75335 .61741 .77597 .61109 .76596 .59929 Metetra
.646 .762 .934 r
.76596 .59929 .77597 .61109 .79877 .60472 .78889 .59283 Metetra
.646 .762 .934 r
.78889 .59283 .79877 .60472 .82174 .5983 .812 .58631 Metetra
.646 .762 .934 r
.812 .58631 .82174 .5983 .84491 .59183 .83529 .57975 Metetra
.646 .762 .934 r
.83529 .57975 .84491 .59183 .86825 .58531 .85878 .57313 Metetra
.646 .762 .934 r
.85878 .57313 .86825 .58531 .89179 .57873 .88245 .56645 Metetra
.646 .762 .934 r
.88245 .56645 .89179 .57873 .91552 .5721 .90632 .55972 Metetra
.986 .752 .496 r
.90632 .55972 .91552 .5721 .92561 .45241 .91675 .43952 Metetra
.656 .751 .92 r
.29865 .61192 .3107 .62244 .32952 .61676 .31755 .60617 Metetra
.656 .751 .92 r
.31755 .60617 .32952 .61676 .34847 .61104 .33658 .60037 Metetra
.924 .72 .609 r
.33658 .60037 .34847 .61104 .3722 .50393 .36079 .49285 Metetra
.664 .741 .908 r
.36079 .49285 .3722 .50393 .39087 .49795 .37954 .48679 Metetra
.664 .741 .908 r
.37954 .48679 .39087 .49795 .40967 .49192 .39842 .48068 Metetra
.664 .741 .908 r
.39842 .48068 .40967 .49192 .4286 .48585 .41743 .47454 Metetra
.664 .741 .908 r
.41743 .47454 .4286 .48585 .44767 .47974 .43658 .46835 Metetra
.664 .741 .908 r
.43658 .46835 .44767 .47974 .46687 .47359 .45587 .46211 Metetra
.664 .741 .908 r
.45587 .46211 .46687 .47359 .48621 .46739 .4753 .45583 Metetra
.664 .741 .908 r
.4753 .45583 .48621 .46739 .50568 .46115 .49486 .44951 Metetra
.664 .741 .908 r
.49486 .44951 .50568 .46115 .5253 .45486 .51457 .44314 Metetra
.664 .741 .908 r
.51457 .44314 .5253 .45486 .54505 .44853 .53442 .43672 Metetra
.664 .741 .908 r
.53442 .43672 .54505 .44853 .56495 .44215 .55441 .43026 Metetra
.664 .741 .908 r
.55441 .43026 .56495 .44215 .58499 .43573 .57455 .42375 Metetra
.664 .741 .908 r
.57455 .42375 .58499 .43573 .60518 .42926 .59483 .41719 Metetra
.964 .645 .358 r
.59483 .41719 .60518 .42926 .63216 .63701 .62128 .62559 Metetra
.646 .762 .934 r
.62128 .62559 .63216 .63701 .65402 .63085 .64326 .61934 Metetra
.646 .762 .934 r
.64326 .61934 .65402 .63085 .67606 .62463 .66541 .61304 Metetra
.646 .762 .934 r
.66541 .61304 .67606 .62463 .69827 .61837 .68774 .60668 Metetra
.646 .762 .934 r
.68774 .60668 .69827 .61837 .72066 .61206 .71025 .60028 Metetra
.646 .762 .934 r
.71025 .60028 .72066 .61206 .74322 .6057 .73294 .59382 Metetra
.646 .762 .934 r
.73294 .59382 .74322 .6057 .76596 .59929 .75581 .58732 Metetra
.646 .762 .934 r
.75581 .58732 .76596 .59929 .78889 .59283 .77887 .58076 Metetra
.646 .762 .934 r
.77887 .58076 .78889 .59283 .812 .58631 .80211 .57415 Metetra
.646 .762 .934 r
.80211 .57415 .812 .58631 .83529 .57975 .82554 .56748 Metetra
.646 .762 .934 r
.82554 .56748 .83529 .57975 .85878 .57313 .84915 .56076 Metetra
.646 .762 .934 r
.84915 .56076 .85878 .57313 .88245 .56645 .87297 .55399 Metetra
.646 .762 .934 r
.87297 .55399 .88245 .56645 .90632 .55972 .89698 .54716 Metetra
.986 .752 .496 r
.89698 .54716 .90632 .55972 .91675 .43952 .90777 .42645 Metetra
.656 .751 .92 r
.28644 .60127 .29865 .61192 .31755 .60617 .30542 .59544 Metetra
.656 .751 .92 r
.30542 .59544 .31755 .60617 .33658 .60037 .32454 .58956 Metetra
.924 .72 .609 r
.32454 .58956 .33658 .60037 .36079 .49285 .34922 .48163 Metetra
.664 .741 .908 r
.34922 .48163 .36079 .49285 .37954 .48679 .36805 .47549 Metetra
.664 .741 .908 r
.36805 .47549 .37954 .48679 .39842 .48068 .38701 .4693 Metetra
.664 .741 .908 r
.38701 .4693 .39842 .48068 .41743 .47454 .40611 .46307 Metetra
.664 .741 .908 r
.40611 .46307 .41743 .47454 .43658 .46835 .42535 .4568 Metetra
.664 .741 .908 r
.42535 .4568 .43658 .46835 .45587 .46211 .44473 .45048 Metetra
.664 .741 .908 r
.44473 .45048 .45587 .46211 .4753 .45583 .46424 .44412 Metetra
.664 .741 .908 r
.46424 .44412 .4753 .45583 .49486 .44951 .4839 .43771 Metetra
.664 .741 .908 r
.4839 .43771 .49486 .44951 .51457 .44314 .50369 .43126 Metetra
.664 .741 .908 r
.50369 .43126 .51457 .44314 .53442 .43672 .52364 .42475 Metetra
.664 .741 .908 r
.52364 .42475 .53442 .43672 .55441 .43026 .54372 .4182 Metetra
.664 .741 .908 r
.54372 .4182 .55441 .43026 .57455 .42375 .56396 .4116 Metetra
.664 .741 .908 r
.56396 .4116 .57455 .42375 .59483 .41719 .58434 .40496 Metetra
.964 .645 .358 r
.58434 .40496 .59483 .41719 .62128 .62559 .61024 .61401 Metetra
.646 .762 .934 r
.61024 .61401 .62128 .62559 .64326 .61934 .63233 .60766 Metetra
.646 .762 .934 r
.63233 .60766 .64326 .61934 .66541 .61304 .65461 .60127 Metetra
.646 .762 .934 r
.65461 .60127 .66541 .61304 .68774 .60668 .67706 .59482 Metetra
.646 .762 .934 r
.67706 .59482 .68774 .60668 .71025 .60028 .69969 .58832 Metetra
.646 .762 .934 r
.69969 .58832 .71025 .60028 .73294 .59382 .72251 .58177 Metetra
.646 .762 .934 r
.72251 .58177 .73294 .59382 .75581 .58732 .74551 .57517 Metetra
.646 .762 .934 r
.74551 .57517 .75581 .58732 .77887 .58076 .76869 .56851 Metetra
.646 .762 .934 r
.76869 .56851 .77887 .58076 .80211 .57415 .79207 .5618 Metetra
.646 .762 .934 r
.79207 .5618 .80211 .57415 .82554 .56748 .81563 .55503 Metetra
.646 .762 .934 r
.81563 .55503 .82554 .56748 .84915 .56076 .83939 .54821 Metetra
.646 .762 .934 r
.83939 .54821 .84915 .56076 .87297 .55399 .86334 .54133 Metetra
.646 .762 .934 r
.86334 .54133 .87297 .55399 .89698 .54716 .88749 .5344 Metetra
.986 .752 .496 r
.88749 .5344 .89698 .54716 .90777 .42645 .89865 .41318 Metetra
.656 .751 .92 r
.27407 .59047 .28644 .60127 .30542 .59544 .29313 .58456 Metetra
.656 .751 .92 r
.29313 .58456 .30542 .59544 .32454 .58956 .31233 .57861 Metetra
.924 .72 .609 r
.31233 .57861 .32454 .58956 .34922 .48163 .3375 .47026 Metetra
.664 .741 .908 r
.3375 .47026 .34922 .48163 .36805 .47549 .35641 .46404 Metetra
.664 .741 .908 r
.35641 .46404 .36805 .47549 .38701 .4693 .37546 .45777 Metetra
.664 .741 .908 r
.37546 .45777 .38701 .4693 .40611 .46307 .39465 .45146 Metetra
.664 .741 .908 r
.39465 .45146 .40611 .46307 .42535 .4568 .41397 .4451 Metetra
.664 .741 .908 r
.41397 .4451 .42535 .4568 .44473 .45048 .43343 .4387 Metetra
.664 .741 .908 r
.43343 .4387 .44473 .45048 .46424 .44412 .45304 .43225 Metetra
.664 .741 .908 r
.45304 .43225 .46424 .44412 .4839 .43771 .47278 .42576 Metetra
.664 .741 .908 r
.47278 .42576 .4839 .43771 .50369 .43126 .49267 .41921 Metetra
.664 .741 .908 r
.49267 .41921 .50369 .43126 .52364 .42475 .51271 .41262 Metetra
.664 .741 .908 r
.51271 .41262 .52364 .42475 .54372 .4182 .53289 .40598 Metetra
.664 .741 .908 r
.53289 .40598 .54372 .4182 .56396 .4116 .55323 .3993 Metetra
.664 .741 .908 r
.55323 .3993 .56396 .4116 .58434 .40496 .57371 .39256 Metetra
.964 .645 .358 r
.57371 .39256 .58434 .40496 .61024 .61401 .59903 .60226 Metetra
.646 .762 .934 r
.59903 .60226 .61024 .61401 .63233 .60766 .62125 .59582 Metetra
.646 .762 .934 r
.62125 .59582 .63233 .60766 .65461 .60127 .64365 .58933 Metetra
.646 .762 .934 r
.64365 .58933 .65461 .60127 .67706 .59482 .66622 .58278 Metetra
.646 .762 .934 r
.66622 .58278 .67706 .59482 .69969 .58832 .68898 .57619 Metetra
.646 .762 .934 r
.68898 .57619 .69969 .58832 .72251 .58177 .71192 .56954 Metetra
.646 .762 .934 r
.71192 .56954 .72251 .58177 .74551 .57517 .73505 .56284 Metetra
.646 .762 .934 r
.73505 .56284 .74551 .57517 .76869 .56851 .75836 .55608 Metetra
.646 .762 .934 r
.75836 .55608 .76869 .56851 .79207 .5618 .78187 .54926 Metetra
.646 .762 .934 r
.78187 .54926 .79207 .5618 .81563 .55503 .80557 .5424 Metetra
.646 .762 .934 r
.80557 .5424 .81563 .55503 .83939 .54821 .82947 .53547 Metetra
.646 .762 .934 r
.82947 .53547 .83939 .54821 .86334 .54133 .85357 .52849 Metetra
.646 .762 .934 r
.85357 .52849 .86334 .54133 .88749 .5344 .87787 .52144 Metetra
.986 .752 .496 r
.87787 .52144 .88749 .5344 .89865 .41318 .8894 .39971 Metetra
.656 .751 .92 r
.26154 .57953 .27407 .59047 .29313 .58456 .28068 .57354 Metetra
.656 .751 .92 r
.28068 .57354 .29313 .58456 .31233 .57861 .29996 .56751 Metetra
.924 .72 .609 r
.29996 .56751 .31233 .57861 .3375 .47026 .32563 .45874 Metetra
.664 .741 .908 r
.32563 .45874 .3375 .47026 .35641 .46404 .34462 .45243 Metetra
.664 .741 .908 r
.34462 .45243 .35641 .46404 .37546 .45777 .36375 .44608 Metetra
.664 .741 .908 r
.36375 .44608 .37546 .45777 .39465 .45146 .38302 .43969 Metetra
.664 .741 .908 r
.38302 .43969 .39465 .45146 .41397 .4451 .40244 .43325 Metetra
.664 .741 .908 r
.40244 .43325 .41397 .4451 .43343 .4387 .42199 .42676 Metetra
.664 .741 .908 r
.42199 .42676 .43343 .4387 .45304 .43225 .44168 .42022 Metetra
.664 .741 .908 r
.44168 .42022 .45304 .43225 .47278 .42576 .46152 .41364 Metetra
.664 .741 .908 r
.46152 .41364 .47278 .42576 .49267 .41921 .4815 .40701 Metetra
.664 .741 .908 r
.4815 .40701 .49267 .41921 .51271 .41262 .50164 .40033 Metetra
.664 .741 .908 r
.50164 .40033 .51271 .41262 .53289 .40598 .52192 .3936 Metetra
.664 .741 .908 r
.52192 .3936 .53289 .40598 .55323 .3993 .54235 .38682 Metetra
.664 .741 .908 r
.54235 .38682 .55323 .3993 .57371 .39256 .56293 .37999 Metetra
.964 .645 .358 r
.56293 .37999 .57371 .39256 .59903 .60226 .58767 .59033 Metetra
.646 .762 .934 r
.58767 .59033 .59903 .60226 .62125 .59582 .61 .58379 Metetra
.646 .762 .934 r
.61 .58379 .62125 .59582 .64365 .58933 .63252 .57721 Metetra
.646 .762 .934 r
.63252 .57721 .64365 .58933 .66622 .58278 .65522 .57056 Metetra
.646 .762 .934 r
.65522 .57056 .66622 .58278 .68898 .57619 .6781 .56387 Metetra
.646 .762 .934 r
.6781 .56387 .68898 .57619 .71192 .56954 .70117 .55712 Metetra
.646 .762 .934 r
.70117 .55712 .71192 .56954 .73505 .56284 .72443 .55032 Metetra
.646 .762 .934 r
.72443 .55032 .73505 .56284 .75836 .55608 .74788 .54346 Metetra
.646 .762 .934 r
.74788 .54346 .75836 .55608 .78187 .54926 .77152 .53654 Metetra
.646 .762 .934 r
.77152 .53654 .78187 .54926 .80557 .5424 .79537 .52956 Metetra
.646 .762 .934 r
.79537 .52956 .80557 .5424 .82947 .53547 .8194 .52253 Metetra
.646 .762 .934 r
.8194 .52253 .82947 .53547 .85357 .52849 .84364 .51544 Metetra
.646 .762 .934 r
.84364 .51544 .85357 .52849 .87787 .52144 .86809 .50829 Metetra
.986 .752 .496 r
.86809 .50829 .87787 .52144 .8894 .39971 .88001 .38604 Metetra
.656 .751 .92 r
.24883 .56844 .26154 .57953 .28068 .57354 .26805 .56237 Metetra
.656 .751 .92 r
.26805 .56237 .28068 .57354 .29996 .56751 .28742 .55625 Metetra
.924 .72 .609 r
.28742 .55625 .29996 .56751 .32563 .45874 .31359 .44706 Metetra
.664 .741 .908 r
.31359 .44706 .32563 .45874 .34462 .45243 .33267 .44068 Metetra
.664 .741 .908 r
.33267 .44068 .34462 .45243 .36375 .44608 .35189 .43424 Metetra
.664 .741 .908 r
.35189 .43424 .36375 .44608 .38302 .43969 .37125 .42776 Metetra
.664 .741 .908 r
.37125 .42776 .38302 .43969 .40244 .43325 .39075 .42123 Metetra
.664 .741 .908 r
.39075 .42123 .40244 .43325 .42199 .42676 .41039 .41466 Metetra
.664 .741 .908 r
.41039 .41466 .42199 .42676 .44168 .42022 .43017 .40803 Metetra
.664 .741 .908 r
.43017 .40803 .44168 .42022 .46152 .41364 .4501 .40136 Metetra
.664 .741 .908 r
.4501 .40136 .46152 .41364 .4815 .40701 .47018 .39464 Metetra
.664 .741 .908 r
.47018 .39464 .4815 .40701 .50164 .40033 .49041 .38786 Metetra
.664 .741 .908 r
.49041 .38786 .50164 .40033 .52192 .3936 .51079 .38104 Metetra
.664 .741 .908 r
.51079 .38104 .52192 .3936 .54235 .38682 .53132 .37417 Metetra
.664 .741 .908 r
.53132 .37417 .54235 .38682 .56293 .37999 .552 .36724 Metetra
.964 .645 .358 r
.552 .36724 .56293 .37999 .58767 .59033 .57613 .57822 Metetra
.646 .762 .934 r
.57613 .57822 .58767 .59033 .61 .58379 .59859 .57159 Metetra
.646 .762 .934 r
.59859 .57159 .61 .58379 .63252 .57721 .62123 .5649 Metetra
.646 .762 .934 r
.62123 .5649 .63252 .57721 .65522 .57056 .64405 .55816 Metetra
.646 .762 .934 r
.64405 .55816 .65522 .57056 .6781 .56387 .66706 .55137 Metetra
.646 .762 .934 r
.66706 .55137 .6781 .56387 .70117 .55712 .69026 .54451 Metetra
.646 .762 .934 r
.69026 .54451 .70117 .55712 .72443 .55032 .71365 .53761 Metetra
.646 .762 .934 r
.71365 .53761 .72443 .55032 .74788 .54346 .73724 .53064 Metetra
.646 .762 .934 r
.73724 .53064 .74788 .54346 .77152 .53654 .76102 .52362 Metetra
.646 .762 .934 r
.76102 .52362 .77152 .53654 .79537 .52956 .785 .51653 Metetra
.646 .762 .934 r
.785 .51653 .79537 .52956 .8194 .52253 .80918 .50939 Metetra
.646 .762 .934 r
.80918 .50939 .8194 .52253 .84364 .51544 .83357 .50219 Metetra
.646 .762 .934 r
.83357 .50219 .84364 .51544 .86809 .50829 .85816 .49493 Metetra
.986 .752 .496 r
.85816 .49493 .86809 .50829 .88001 .38604 .87047 .37217 Metetra
.656 .751 .92 r
.23595 .5572 .24883 .56844 .26805 .56237 .25526 .55104 Metetra
.656 .751 .92 r
.25526 .55104 .26805 .56237 .28742 .55625 .27471 .54484 Metetra
.945 .625 .396 r
.27471 .54484 .28742 .55625 .31359 .44706 .28676 .64873 Metetra
.528 .288 .494 r
.28676 .64873 .31359 .44706 .33267 .44068 .30712 .64266 Metetra
.528 .288 .494 r
.30712 .64266 .33267 .44068 .35189 .43424 .32765 .63654 Metetra
.528 .288 .494 r
.32765 .63654 .35189 .43424 .37125 .42776 .34833 .63037 Metetra
.528 .288 .494 r
.34833 .63037 .37125 .42776 .39075 .42123 .36918 .62416 Metetra
.528 .288 .494 r
.36918 .62416 .39075 .42123 .41039 .41466 .39019 .61789 Metetra
.528 .288 .494 r
.39019 .61789 .41039 .41466 .43017 .40803 .41137 .61157 Metetra
.528 .288 .494 r
.41137 .61157 .43017 .40803 .4501 .40136 .43271 .60521 Metetra
.528 .288 .494 r
.43271 .60521 .4501 .40136 .47018 .39464 .45423 .59879 Metetra
.528 .288 .494 r
.45423 .59879 .47018 .39464 .49041 .38786 .47591 .59233 Metetra
.528 .288 .494 r
.47591 .59233 .49041 .38786 .51079 .38104 .49778 .58581 Metetra
.528 .288 .494 r
.49778 .58581 .51079 .38104 .53132 .37417 .51981 .57924 Metetra
.528 .288 .494 r
.51981 .57924 .53132 .37417 .552 .36724 .54203 .57261 Metetra
0 0 .275 r
.54203 .57261 .552 .36724 .57613 .57822 .56187 .34724 Metetra
.561 .362 .569 r
.56187 .34724 .57613 .57822 .59859 .57159 .58298 .34011 Metetra
.561 .362 .569 r
.58298 .34011 .59859 .57159 .62123 .5649 .60424 .33293 Metetra
.561 .362 .569 r
.60424 .33293 .62123 .5649 .64405 .55816 .62567 .32569 Metetra
.561 .362 .569 r
.62567 .32569 .64405 .55816 .66706 .55137 .64727 .31839 Metetra
.561 .362 .569 r
.64727 .31839 .66706 .55137 .69026 .54451 .66903 .31104 Metetra
.561 .362 .569 r
.66903 .31104 .69026 .54451 .71365 .53761 .69096 .30363 Metetra
.561 .362 .569 r
.69096 .30363 .71365 .53761 .73724 .53064 .71306 .29616 Metetra
.561 .362 .569 r
.71306 .29616 .73724 .53064 .76102 .52362 .73534 .28864 Metetra
.561 .362 .569 r
.73534 .28864 .76102 .52362 .785 .51653 .75779 .28105 Metetra
.561 .362 .569 r
.75779 .28105 .785 .51653 .80918 .50939 .78042 .27341 Metetra
.561 .362 .569 r
.78042 .27341 .80918 .50939 .83357 .50219 .80323 .2657 Metetra
.561 .362 .569 r
.80323 .2657 .83357 .50219 .85816 .49493 .82622 .25794 Metetra
.378 .235 .557 r
.82622 .25794 .85816 .49493 .87047 .37217 .86079 .35808 Metetra
.656 .751 .92 r
.22289 .5458 .23595 .5572 .25526 .55104 .24228 .53956 Metetra
.656 .751 .92 r
.24228 .53956 .25526 .55104 .27471 .54484 .26182 .53328 Metetra
.945 .625 .396 r
.26182 .53328 .27471 .54484 .28676 .64873 .27348 .63748 Metetra
.646 .762 .934 r
.27348 .63748 .28676 .64873 .30712 .64266 .29394 .63132 Metetra
.646 .762 .934 r
.29394 .63132 .30712 .64266 .32765 .63654 .31456 .62511 Metetra
.646 .762 .934 r
.31456 .62511 .32765 .63654 .34833 .63037 .33535 .61886 Metetra
.646 .762 .934 r
.33535 .61886 .34833 .63037 .36918 .62416 .35629 .61255 Metetra
.646 .762 .934 r
.35629 .61255 .36918 .62416 .39019 .61789 .37741 .60619 Metetra
.646 .762 .934 r
.37741 .60619 .39019 .61789 .41137 .61157 .39869 .59978 Metetra
.646 .762 .934 r
.39869 .59978 .41137 .61157 .43271 .60521 .42014 .59333 Metetra
.646 .762 .934 r
.42014 .59333 .43271 .60521 .45423 .59879 .44177 .58682 Metetra
.646 .762 .934 r
.44177 .58682 .45423 .59879 .47591 .59233 .46356 .58025 Metetra
.646 .762 .934 r
.46356 .58025 .47591 .59233 .49778 .58581 .48554 .57364 Metetra
.646 .762 .934 r
.48554 .57364 .49778 .58581 .51981 .57924 .50769 .56697 Metetra
.646 .762 .934 r
.50769 .56697 .51981 .57924 .54203 .57261 .53002 .56024 Metetra
.964 .717 .513 r
.53002 .56024 .54203 .57261 .56187 .34724 .55074 .33404 Metetra
.664 .741 .908 r
.55074 .33404 .56187 .34724 .58298 .34011 .57195 .3268 Metetra
.664 .741 .908 r
.57195 .3268 .58298 .34011 .60424 .33293 .59333 .31952 Metetra
.664 .741 .908 r
.59333 .31952 .60424 .33293 .62567 .32569 .61487 .31217 Metetra
.664 .741 .908 r
.61487 .31217 .62567 .32569 .64727 .31839 .63658 .30477 Metetra
.664 .741 .908 r
.63658 .30477 .64727 .31839 .66903 .31104 .65845 .29732 Metetra
.664 .741 .908 r
.65845 .29732 .66903 .31104 .69096 .30363 .6805 .2898 Metetra
.664 .741 .908 r
.6805 .2898 .69096 .30363 .71306 .29616 .70272 .28222 Metetra
.664 .741 .908 r
.70272 .28222 .71306 .29616 .73534 .28864 .72512 .27459 Metetra
.664 .741 .908 r
.72512 .27459 .73534 .28864 .75779 .28105 .7477 .26689 Metetra
.664 .741 .908 r
.7477 .26689 .75779 .28105 .78042 .27341 .77045 .25914 Metetra
.664 .741 .908 r
.77045 .25914 .78042 .27341 .80323 .2657 .79339 .25132 Metetra
.664 .741 .908 r
.79339 .25132 .80323 .2657 .82622 .25794 .81651 .24344 Metetra
.869 .479 .007 r
.81651 .24344 .82622 .25794 .86079 .35808 .85096 .34377 Metetra
.656 .751 .92 r
.20965 .53425 .22289 .5458 .24228 .53956 .22913 .52792 Metetra
.656 .751 .92 r
.22913 .52792 .24228 .53956 .26182 .53328 .24876 .52155 Metetra
.945 .625 .396 r
.24876 .52155 .26182 .53328 .27348 .63748 .26001 .62607 Metetra
.646 .762 .934 r
.26001 .62607 .27348 .63748 .29394 .63132 .28057 .61982 Metetra
.646 .762 .934 r
.28057 .61982 .29394 .63132 .31456 .62511 .30129 .61352 Metetra
.646 .762 .934 r
.30129 .61352 .31456 .62511 .33535 .61886 .32217 .60717 Metetra
.646 .762 .934 r
.32217 .60717 .33535 .61886 .35629 .61255 .34322 .60077 Metetra
.646 .762 .934 r
.34322 .60077 .35629 .61255 .37741 .60619 .36444 .59432 Metetra
.646 .762 .934 r
.36444 .59432 .37741 .60619 .39869 .59978 .38582 .58782 Metetra
.646 .762 .934 r
.38582 .58782 .39869 .59978 .42014 .59333 .40738 .58127 Metetra
.646 .762 .934 r
.40738 .58127 .42014 .59333 .44177 .58682 .42912 .57466 Metetra
.646 .762 .934 r
.42912 .57466 .44177 .58682 .46356 .58025 .45103 .568 Metetra
.646 .762 .934 r
.45103 .568 .46356 .58025 .48554 .57364 .47311 .56128 Metetra
.646 .762 .934 r
.47311 .56128 .48554 .57364 .50769 .56697 .49538 .55451 Metetra
.646 .762 .934 r
.49538 .55451 .50769 .56697 .53002 .56024 .51783 .54768 Metetra
.964 .717 .513 r
.51783 .54768 .53002 .56024 .55074 .33404 .53945 .32064 Metetra
.664 .741 .908 r
.53945 .32064 .55074 .33404 .57195 .3268 .56077 .31331 Metetra
.664 .741 .908 r
.56077 .31331 .57195 .3268 .59333 .31952 .58225 .30592 Metetra
.664 .741 .908 r
.58225 .30592 .59333 .31952 .61487 .31217 .60391 .29847 Metetra
.664 .741 .908 r
.60391 .29847 .61487 .31217 .63658 .30477 .62573 .29096 Metetra
.664 .741 .908 r
.62573 .29096 .63658 .30477 .65845 .29732 .64772 .28339 Metetra
.664 .741 .908 r
.64772 .28339 .65845 .29732 .6805 .2898 .66989 .27577 Metetra
.664 .741 .908 r
.66989 .27577 .6805 .2898 .70272 .28222 .69223 .26808 Metetra
.664 .741 .908 r
.69223 .26808 .70272 .28222 .72512 .27459 .71475 .26033 Metetra
.664 .741 .908 r
.71475 .26033 .72512 .27459 .7477 .26689 .73745 .25252 Metetra
.664 .741 .908 r
.73745 .25252 .7477 .26689 .77045 .25914 .76033 .24465 Metetra
.664 .741 .908 r
.76033 .24465 .77045 .25914 .79339 .25132 .7834 .23672 Metetra
.664 .741 .908 r
.7834 .23672 .79339 .25132 .81651 .24344 .80665 .22872 Metetra
.869 .479 .007 r
.80665 .22872 .81651 .24344 .85096 .34377 .84098 .32925 Metetra
.656 .751 .92 r
.19623 .52253 .20965 .53425 .22913 .52792 .21579 .51612 Metetra
.656 .751 .92 r
.21579 .51612 .22913 .52792 .24876 .52155 .23551 .50965 Metetra
.945 .625 .396 r
.23551 .50965 .24876 .52155 .26001 .62607 .24635 .6145 Metetra
.646 .762 .934 r
.24635 .6145 .26001 .62607 .28057 .61982 .267 .60815 Metetra
.646 .762 .934 r
.267 .60815 .28057 .61982 .30129 .61352 .28782 .60176 Metetra
.646 .762 .934 r
.28782 .60176 .30129 .61352 .32217 .60717 .3088 .59532 Metetra
.646 .762 .934 r
.3088 .59532 .32217 .60717 .34322 .60077 .32995 .58882 Metetra
.646 .762 .934 r
.32995 .58882 .34322 .60077 .36444 .59432 .35127 .58228 Metetra
.646 .762 .934 r
.35127 .58228 .36444 .59432 .38582 .58782 .37277 .57568 Metetra
.646 .762 .934 r
.37277 .57568 .38582 .58782 .40738 .58127 .39443 .56902 Metetra
.646 .762 .934 r
.39443 .56902 .40738 .58127 .42912 .57466 .41628 .56232 Metetra
.646 .762 .934 r
.41628 .56232 .42912 .57466 .45103 .568 .4383 .55556 Metetra
.646 .762 .934 r
.4383 .55556 .45103 .568 .47311 .56128 .4605 .54874 Metetra
.646 .762 .934 r
.4605 .54874 .47311 .56128 .49538 .55451 .48289 .54186 Metetra
.646 .762 .934 r
.48289 .54186 .49538 .55451 .51783 .54768 .50546 .53493 Metetra
.964 .717 .513 r
.50546 .53493 .51783 .54768 .53945 .32064 .528 .30706 Metetra
.664 .741 .908 r
.528 .30706 .53945 .32064 .56077 .31331 .54943 .29962 Metetra
.664 .741 .908 r
.54943 .29962 .56077 .31331 .58225 .30592 .57102 .29212 Metetra
.664 .741 .908 r
.57102 .29212 .58225 .30592 .60391 .29847 .59279 .28456 Metetra
.664 .741 .908 r
.59279 .28456 .60391 .29847 .62573 .29096 .61473 .27694 Metetra
.664 .741 .908 r
.61473 .27694 .62573 .29096 .64772 .28339 .63684 .26927 Metetra
.664 .741 .908 r
.63684 .26927 .64772 .28339 .66989 .27577 .65912 .26153 Metetra
.664 .741 .908 r
.65912 .26153 .66989 .27577 .69223 .26808 .68159 .25373 Metetra
.664 .741 .908 r
.68159 .25373 .69223 .26808 .71475 .26033 .70423 .24587 Metetra
.664 .741 .908 r
.70423 .24587 .71475 .26033 .73745 .25252 .72706 .23794 Metetra
.664 .741 .908 r
.72706 .23794 .73745 .25252 .76033 .24465 .75007 .22995 Metetra
.664 .741 .908 r
.75007 .22995 .76033 .24465 .7834 .23672 .77326 .2219 Metetra
.664 .741 .908 r
.77326 .2219 .7834 .23672 .80665 .22872 .79665 .21378 Metetra
.869 .479 .007 r
.79665 .21378 .80665 .22872 .84098 .32925 .83084 .31449 Metetra
.656 .751 .92 r
.18262 .51065 .19623 .52253 .21579 .51612 .20227 .50415 Metetra
.656 .751 .92 r
.20227 .50415 .21579 .51612 .23551 .50965 .22207 .49759 Metetra
.945 .625 .396 r
.22207 .49759 .23551 .50965 .24635 .6145 .23248 .60275 Metetra
.646 .762 .934 r
.23248 .60275 .24635 .6145 .267 .60815 .25323 .59631 Metetra
.646 .762 .934 r
.25323 .59631 .267 .60815 .28782 .60176 .27415 .58983 Metetra
.646 .762 .934 r
.27415 .58983 .28782 .60176 .3088 .59532 .29523 .58329 Metetra
.646 .762 .934 r
.29523 .58329 .3088 .59532 .32995 .58882 .31649 .5767 Metetra
.646 .762 .934 r
.31649 .5767 .32995 .58882 .35127 .58228 .33791 .57005 Metetra
.646 .762 .934 r
.33791 .57005 .35127 .58228 .37277 .57568 .35951 .56335 Metetra
.646 .762 .934 r
.35951 .56335 .37277 .57568 .39443 .56902 .38129 .5566 Metetra
.646 .762 .934 r
.38129 .5566 .39443 .56902 .41628 .56232 .40324 .54979 Metetra
.646 .762 .934 r
.40324 .54979 .41628 .56232 .4383 .55556 .42538 .54293 Metetra
.646 .762 .934 r
.42538 .54293 .4383 .55556 .4605 .54874 .4477 .536 Metetra
.646 .762 .934 r
.4477 .536 .4605 .54874 .48289 .54186 .4702 .52902 Metetra
.646 .762 .934 r
.4702 .52902 .48289 .54186 .50546 .53493 .49289 .52199 Metetra
.964 .717 .513 r
.49289 .52199 .50546 .53493 .528 .30706 .51638 .29328 Metetra
.664 .741 .908 r
.51638 .29328 .528 .30706 .54943 .29962 .53792 .28573 Metetra
.664 .741 .908 r
.53792 .28573 .54943 .29962 .57102 .29212 .55963 .27812 Metetra
.664 .741 .908 r
.55963 .27812 .57102 .29212 .59279 .28456 .58151 .27045 Metetra
.664 .741 .908 r
.58151 .27045 .59279 .28456 .61473 .27694 .60356 .26272 Metetra
.664 .741 .908 r
.60356 .26272 .61473 .27694 .63684 .26927 .62579 .25493 Metetra
.664 .741 .908 r
.62579 .25493 .63684 .26927 .65912 .26153 .6482 .24708 Metetra
.664 .741 .908 r
.6482 .24708 .65912 .26153 .68159 .25373 .67078 .23917 Metetra
.664 .741 .908 r
.67078 .23917 .68159 .25373 .70423 .24587 .69355 .23119 Metetra
.664 .741 .908 r
.69355 .23119 .70423 .24587 .72706 .23794 .7165 .22314 Metetra
.664 .741 .908 r
.7165 .22314 .72706 .23794 .75007 .22995 .73964 .21503 Metetra
.664 .741 .908 r
.73964 .21503 .75007 .22995 .77326 .2219 .76297 .20686 Metetra
.664 .741 .908 r
.76297 .20686 .77326 .2219 .79665 .21378 .78649 .19861 Metetra
.869 .479 .007 r
.78649 .19861 .79665 .21378 .83084 .31449 .82055 .29951 Metetra
.656 .751 .92 r
.16882 .49861 .18262 .51065 .20227 .50415 .18855 .49201 Metetra
.656 .751 .92 r
.18855 .49201 .20227 .50415 .22207 .49759 .20844 .48536 Metetra
.945 .625 .396 r
.20844 .48536 .22207 .49759 .23248 .60275 .21841 .59083 Metetra
.646 .762 .934 r
.21841 .59083 .23248 .60275 .25323 .59631 .23926 .5843 Metetra
.646 .762 .934 r
.23926 .5843 .25323 .59631 .27415 .58983 .26028 .57771 Metetra
.646 .762 .934 r
.26028 .57771 .27415 .58983 .29523 .58329 .28146 .57108 Metetra
.646 .762 .934 r
.28146 .57108 .29523 .58329 .31649 .5767 .30282 .56439 Metetra
.646 .762 .934 r
.30282 .56439 .31649 .5767 .33791 .57005 .32435 .55764 Metetra
.646 .762 .934 r
.32435 .55764 .33791 .57005 .35951 .56335 .34606 .55084 Metetra
.646 .762 .934 r
.34606 .55084 .35951 .56335 .38129 .5566 .36795 .54399 Metetra
.646 .762 .934 r
.36795 .54399 .38129 .5566 .40324 .54979 .39001 .53707 Metetra
.646 .762 .934 r
.39001 .53707 .40324 .54979 .42538 .54293 .41226 .5301 Metetra
.646 .762 .934 r
.41226 .5301 .42538 .54293 .4477 .536 .4347 .52307 Metetra
.646 .762 .934 r
.4347 .52307 .4477 .536 .4702 .52902 .45732 .51599 Metetra
.646 .762 .934 r
.45732 .51599 .4702 .52902 .49289 .52199 .48014 .50884 Metetra
.964 .717 .513 r
.48014 .50884 .49289 .52199 .51638 .29328 .5046 .27929 Metetra
.664 .741 .908 r
.5046 .27929 .51638 .29328 .53792 .28573 .52624 .27164 Metetra
.664 .741 .908 r
.52624 .27164 .53792 .28573 .55963 .27812 .54807 .26392 Metetra
.664 .741 .908 r
.54807 .26392 .55963 .27812 .58151 .27045 .57006 .25614 Metetra
.664 .741 .908 r
.57006 .25614 .58151 .27045 .60356 .26272 .59223 .24829 Metetra
.664 .741 .908 r
.59223 .24829 .60356 .26272 .62579 .25493 .61458 .24039 Metetra
.664 .741 .908 r
.61458 .24039 .62579 .25493 .6482 .24708 .63711 .23242 Metetra
.664 .741 .908 r
.63711 .23242 .6482 .24708 .67078 .23917 .65982 .22438 Metetra
.664 .741 .908 r
.65982 .22438 .67078 .23917 .69355 .23119 .68271 .21629 Metetra
.664 .741 .908 r
.68271 .21629 .69355 .23119 .7165 .22314 .70579 .20812 Metetra
.664 .741 .908 r
.70579 .20812 .7165 .22314 .73964 .21503 .72906 .19989 Metetra
.664 .741 .908 r
.72906 .19989 .73964 .21503 .76297 .20686 .75253 .19159 Metetra
.664 .741 .908 r
.75253 .19159 .76297 .20686 .78649 .19861 .77618 .18322 Metetra
.869 .479 .007 r
.77618 .18322 .78649 .19861 .82055 .29951 .81009 .28428 Metetra
.656 .751 .92 r
.15482 .48639 .16882 .49861 .18855 .49201 .17464 .4797 Metetra
.656 .751 .92 r
.17464 .4797 .18855 .49201 .20844 .48536 .19462 .47295 Metetra
.945 .625 .396 r
.19462 .47295 .20844 .48536 .21841 .59083 .20414 .57873 Metetra
.646 .762 .934 r
.20414 .57873 .21841 .59083 .23926 .5843 .22508 .5721 Metetra
.646 .762 .934 r
.22508 .5721 .23926 .5843 .26028 .57771 .2462 .56542 Metetra
.646 .762 .934 r
.2462 .56542 .26028 .57771 .28146 .57108 .26748 .55868 Metetra
.646 .762 .934 r
.26748 .55868 .28146 .57108 .30282 .56439 .28894 .55189 Metetra
.646 .762 .934 r
.28894 .55189 .30282 .56439 .32435 .55764 .31058 .54504 Metetra
.646 .762 .934 r
.31058 .54504 .32435 .55764 .34606 .55084 .3324 .53814 Metetra
.646 .762 .934 r
.3324 .53814 .34606 .55084 .36795 .54399 .3544 .53118 Metetra
.646 .762 .934 r
.3544 .53118 .36795 .54399 .39001 .53707 .37658 .52416 Metetra
.646 .762 .934 r
.37658 .52416 .39001 .53707 .41226 .5301 .39894 .51708 Metetra
.646 .762 .934 r
.39894 .51708 .41226 .5301 .4347 .52307 .4215 .50994 Metetra
.646 .762 .934 r
.4215 .50994 .4347 .52307 .45732 .51599 .44424 .50275 Metetra
.646 .762 .934 r
.44424 .50275 .45732 .51599 .48014 .50884 .46718 .49549 Metetra
.964 .717 .513 r
.46718 .49549 .48014 .50884 .5046 .27929 .49264 .26511 Metetra
.664 .741 .908 r
.49264 .26511 .5046 .27929 .52624 .27164 .5144 .25734 Metetra
.664 .741 .908 r
.5144 .25734 .52624 .27164 .54807 .26392 .53633 .2495 Metetra
.664 .741 .908 r
.53633 .2495 .54807 .26392 .57006 .25614 .55844 .24161 Metetra
.664 .741 .908 r
.55844 .24161 .57006 .25614 .59223 .24829 .58073 .23365 Metetra
.664 .741 .908 r
.58073 .23365 .59223 .24829 .61458 .24039 .6032 .22562 Metetra
.664 .741 .908 r
.6032 .22562 .61458 .24039 .63711 .23242 .62585 .21754 Metetra
.664 .741 .908 r
.62585 .21754 .63711 .23242 .65982 .22438 .64869 .20938 Metetra
.664 .741 .908 r
.64869 .20938 .65982 .22438 .68271 .21629 .67171 .20116 Metetra
.664 .741 .908 r
.67171 .20116 .68271 .21629 .70579 .20812 .69492 .19287 Metetra
.664 .741 .908 r
.69492 .19287 .70579 .20812 .72906 .19989 .71832 .18451 Metetra
.664 .741 .908 r
.71832 .18451 .72906 .19989 .75253 .19159 .74192 .17608 Metetra
.664 .741 .908 r
.74192 .17608 .75253 .19159 .77618 .18322 .76571 .16759 Metetra
.869 .479 .007 r
.76571 .16759 .77618 .18322 .81009 .28428 .79946 .26882 Metetra
.656 .751 .92 r
.14062 .474 .15482 .48639 .17464 .4797 .16053 .46721 Metetra
.656 .751 .92 r
.16053 .46721 .17464 .4797 .19462 .47295 .18059 .46037 Metetra
.945 .625 .396 r
.18059 .46037 .19462 .47295 .20414 .57873 .18964 .56645 Metetra
.646 .762 .934 r
.18964 .56645 .20414 .57873 .22508 .5721 .21069 .55972 Metetra
.646 .762 .934 r
.21069 .55972 .22508 .5721 .2462 .56542 .2319 .55294 Metetra
.646 .762 .934 r
.2319 .55294 .2462 .56542 .26748 .55868 .25329 .5461 Metetra
.646 .762 .934 r
.25329 .5461 .26748 .55868 .28894 .55189 .27486 .53921 Metetra
.646 .762 .934 r
.27486 .53921 .28894 .55189 .31058 .54504 .2966 .53225 Metetra
.646 .762 .934 r
.2966 .53225 .31058 .54504 .3324 .53814 .31853 .52524 Metetra
.646 .762 .934 r
.31853 .52524 .3324 .53814 .3544 .53118 .34064 .51817 Metetra
.646 .762 .934 r
.34064 .51817 .3544 .53118 .37658 .52416 .36293 .51105 Metetra
.646 .762 .934 r
.36293 .51105 .37658 .52416 .39894 .51708 .38542 .50386 Metetra
.646 .762 .934 r
.38542 .50386 .39894 .51708 .4215 .50994 .40809 .49661 Metetra
.646 .762 .934 r
.40809 .49661 .4215 .50994 .44424 .50275 .43095 .4893 Metetra
.646 .762 .934 r
.43095 .4893 .44424 .50275 .46718 .49549 .45401 .48192 Metetra
.964 .717 .513 r
.45401 .48192 .46718 .49549 .49264 .26511 .4805 .25071 Metetra
.664 .741 .908 r
.4805 .25071 .49264 .26511 .5144 .25734 .50238 .24283 Metetra
.664 .741 .908 r
.50238 .24283 .5144 .25734 .53633 .2495 .52443 .23488 Metetra
.664 .741 .908 r
.52443 .23488 .53633 .2495 .55844 .24161 .54665 .22686 Metetra
.664 .741 .908 r
.54665 .22686 .55844 .24161 .58073 .23365 .56906 .21878 Metetra
.664 .741 .908 r
.56906 .21878 .58073 .23365 .6032 .22562 .59165 .21064 Metetra
.664 .741 .908 r
.59165 .21064 .6032 .22562 .62585 .21754 .61442 .20243 Metetra
.664 .741 .908 r
.61442 .20243 .62585 .21754 .64869 .20938 .63739 .19415 Metetra
.664 .741 .908 r
.63739 .19415 .64869 .20938 .67171 .20116 .66054 .1858 Metetra
.664 .741 .908 r
.66054 .1858 .67171 .20116 .69492 .19287 .68388 .17738 Metetra
.664 .741 .908 r
.68388 .17738 .69492 .19287 .71832 .18451 .70742 .1689 Metetra
.664 .741 .908 r
.70742 .1689 .71832 .18451 .74192 .17608 .73115 .16034 Metetra
.664 .741 .908 r
.73115 .16034 .74192 .17608 .76571 .16759 .75508 .15171 Metetra
.869 .479 .007 r
.75508 .15171 .76571 .16759 .79946 .26882 .78866 .2531 Metetra
.656 .751 .92 r
.12621 .46142 .14062 .474 .16053 .46721 .14621 .45454 Metetra
.656 .751 .92 r
.14621 .45454 .16053 .46721 .18059 .46037 .16637 .4476 Metetra
.945 .625 .396 r
.16637 .4476 .18059 .46037 .18964 .56645 .17493 .55399 Metetra
.646 .762 .934 r
.17493 .55399 .18964 .56645 .21069 .55972 .19607 .54716 Metetra
.646 .762 .934 r
.19607 .54716 .21069 .55972 .2319 .55294 .21739 .54027 Metetra
.646 .762 .934 r
.21739 .54027 .2319 .55294 .25329 .5461 .23889 .53333 Metetra
.646 .762 .934 r
.23889 .53333 .25329 .5461 .27486 .53921 .26056 .52632 Metetra
.646 .762 .934 r
.26056 .52632 .27486 .53921 .2966 .53225 .28241 .51926 Metetra
.646 .762 .934 r
.28241 .51926 .2966 .53225 .31853 .52524 .30445 .51215 Metetra
.646 .762 .934 r
.30445 .51215 .31853 .52524 .34064 .51817 .32667 .50497 Metetra
.646 .762 .934 r
.32667 .50497 .34064 .51817 .36293 .51105 .34908 .49773 Metetra
.646 .762 .934 r
.34908 .49773 .36293 .51105 .38542 .50386 .37168 .49043 Metetra
.646 .762 .934 r
.37168 .49043 .38542 .50386 .40809 .49661 .39447 .48306 Metetra
.646 .762 .934 r
.39447 .48306 .40809 .49661 .43095 .4893 .41746 .47564 Metetra
.646 .762 .934 r
.41746 .47564 .43095 .4893 .45401 .48192 .44064 .46815 Metetra
.964 .717 .513 r
.44064 .46815 .45401 .48192 .4805 .25071 .46819 .2361 Metetra
.664 .741 .908 r
.46819 .2361 .4805 .25071 .50238 .24283 .49018 .2281 Metetra
.664 .741 .908 r
.49018 .2281 .50238 .24283 .52443 .23488 .51234 .22003 Metetra
.664 .741 .908 r
.51234 .22003 .52443 .23488 .54665 .22686 .53469 .2119 Metetra
.664 .741 .908 r
.53469 .2119 .54665 .22686 .56906 .21878 .55721 .2037 Metetra
.664 .741 .908 r
.55721 .2037 .56906 .21878 .59165 .21064 .57992 .19543 Metetra
.664 .741 .908 r
.57992 .19543 .59165 .21064 .61442 .20243 .60282 .18709 Metetra
.664 .741 .908 r
.60282 .18709 .61442 .20243 .63739 .19415 .62591 .17868 Metetra
.664 .741 .908 r
.62591 .17868 .63739 .19415 .66054 .1858 .6492 .17021 Metetra
.664 .741 .908 r
.6492 .17021 .66054 .1858 .68388 .17738 .67267 .16166 Metetra
.664 .741 .908 r
.67267 .16166 .68388 .17738 .70742 .1689 .69634 .15304 Metetra
.664 .741 .908 r
.69634 .15304 .70742 .1689 .73115 .16034 .72021 .14435 Metetra
.664 .741 .908 r
.72021 .14435 .73115 .16034 .75508 .15171 .74429 .13559 Metetra
.869 .479 .007 r
.74429 .13559 .75508 .15171 .78866 .2531 .77769 .23713 Metetra
.656 .751 .92 r
.1116 .44867 .12621 .46142 .14621 .45454 .13169 .44168 Metetra
.656 .751 .92 r
.13169 .44168 .14621 .45454 .16637 .4476 .15193 .43464 Metetra
.945 .625 .396 r
.15193 .43464 .16637 .4476 .17493 .55399 .16 .54133 Metetra
.646 .762 .934 r
.16 .54133 .17493 .55399 .19607 .54716 .18124 .5344 Metetra
.646 .762 .934 r
.18124 .5344 .19607 .54716 .21739 .54027 .20266 .52741 Metetra
.646 .762 .934 r
.20266 .52741 .21739 .54027 .23889 .53333 .22426 .52035 Metetra
.646 .762 .934 r
.22426 .52035 .23889 .53333 .26056 .52632 .24603 .51324 Metetra
.646 .762 .934 r
.24603 .51324 .26056 .52632 .28241 .51926 .268 .50608 Metetra
.646 .762 .934 r
.268 .50608 .28241 .51926 .30445 .51215 .29014 .49884 Metetra
.646 .762 .934 r
.29014 .49884 .30445 .51215 .32667 .50497 .31248 .49155 Metetra
.646 .762 .934 r
.31248 .49155 .32667 .50497 .34908 .49773 .335 .4842 Metetra
.646 .762 .934 r
.335 .4842 .34908 .49773 .37168 .49043 .35772 .47678 Metetra
.646 .762 .934 r
.35772 .47678 .37168 .49043 .39447 .48306 .38064 .4693 Metetra
.646 .762 .934 r
.38064 .4693 .39447 .48306 .41746 .47564 .40375 .46176 Metetra
.646 .762 .934 r
.40375 .46176 .41746 .47564 .44064 .46815 .42706 .45415 Metetra
.964 .717 .513 r
.42706 .45415 .44064 .46815 .46819 .2361 .45569 .22128 Metetra
.664 .741 .908 r
.45569 .22128 .46819 .2361 .49018 .2281 .47779 .21315 Metetra
.664 .741 .908 r
.47779 .21315 .49018 .2281 .51234 .22003 .50007 .20496 Metetra
.664 .741 .908 r
.50007 .20496 .51234 .22003 .53469 .2119 .52254 .1967 Metetra
.664 .741 .908 r
.52254 .1967 .53469 .2119 .55721 .2037 .54519 .18838 Metetra
.664 .741 .908 r
.54519 .18838 .55721 .2037 .57992 .19543 .56802 .17998 Metetra
.664 .741 .908 r
.56802 .17998 .57992 .19543 .60282 .18709 .59105 .17152 Metetra
.664 .741 .908 r
.59105 .17152 .60282 .18709 .62591 .17868 .61426 .16298 Metetra
.664 .741 .908 r
.61426 .16298 .62591 .17868 .6492 .17021 .63768 .15437 Metetra
.664 .741 .908 r
.63768 .15437 .6492 .17021 .67267 .16166 .66129 .14569 Metetra
.664 .741 .908 r
.66129 .14569 .67267 .16166 .69634 .15304 .6851 .13694 Metetra
.664 .741 .908 r
.6851 .13694 .69634 .15304 .72021 .14435 .70911 .12812 Metetra
.664 .741 .908 r
.70911 .12812 .72021 .14435 .74429 .13559 .73332 .11921 Metetra
.869 .479 .007 r
.73332 .11921 .74429 .13559 .77769 .23713 .76653 .22089 Metetra
.656 .751 .92 r
.09677 .43573 .1116 .44867 .13169 .44168 .11695 .42864 Metetra
.656 .751 .92 r
.11695 .42864 .13169 .44168 .15193 .43464 .13729 .4215 Metetra
.945 .625 .396 r
.13729 .4215 .15193 .43464 .16 .54133 .14483 .52849 Metetra
.646 .762 .934 r
.14483 .52849 .16 .54133 .18124 .5344 .16618 .52144 Metetra
.646 .762 .934 r
.16618 .52144 .18124 .5344 .20266 .52741 .1877 .51434 Metetra
.646 .762 .934 r
.1877 .51434 .20266 .52741 .22426 .52035 .2094 .50718 Metetra
.646 .762 .934 r
.2094 .50718 .22426 .52035 .24603 .51324 .23129 .49996 Metetra
.646 .762 .934 r
.23129 .49996 .24603 .51324 .268 .50608 .25336 .49268 Metetra
.646 .762 .934 r
.25336 .49268 .268 .50608 .29014 .49884 .27562 .48533 Metetra
.646 .762 .934 r
.27562 .48533 .29014 .49884 .31248 .49155 .29806 .47793 Metetra
.646 .762 .934 r
.29806 .47793 .31248 .49155 .335 .4842 .32071 .47046 Metetra
.646 .762 .934 r
.32071 .47046 .335 .4842 .35772 .47678 .34354 .46292 Metetra
.646 .762 .934 r
.34354 .46292 .35772 .47678 .38064 .4693 .36658 .45532 Metetra
.646 .762 .934 r
.36658 .45532 .38064 .4693 .40375 .46176 .38981 .44766 Metetra
.646 .762 .934 r
.38981 .44766 .40375 .46176 .42706 .45415 .41325 .43992 Metetra
.964 .717 .513 r
.41325 .43992 .42706 .45415 .45569 .22128 .443 .20623 Metetra
.664 .741 .908 r
.443 .20623 .45569 .22128 .47779 .21315 .46522 .19798 Metetra
.664 .741 .908 r
.46522 .19798 .47779 .21315 .50007 .20496 .48762 .18966 Metetra
.664 .741 .908 r
.48762 .18966 .50007 .20496 .52254 .1967 .5102 .18128 Metetra
.664 .741 .908 r
.5102 .18128 .52254 .1967 .54519 .18838 .53297 .17282 Metetra
.664 .741 .908 r
.53297 .17282 .54519 .18838 .56802 .17998 .55593 .1643 Metetra
.664 .741 .908 r
.55593 .1643 .56802 .17998 .59105 .17152 .57909 .1557 Metetra
.664 .741 .908 r
.57909 .1557 .59105 .17152 .61426 .16298 .60244 .14703 Metetra
.664 .741 .908 r
.60244 .14703 .61426 .16298 .63768 .15437 .62598 .13829 Metetra
.664 .741 .908 r
.62598 .13829 .63768 .15437 .66129 .14569 .64972 .12948 Metetra
.664 .741 .908 r
.64972 .12948 .66129 .14569 .6851 .13694 .67367 .12059 Metetra
.664 .741 .908 r
.67367 .12059 .6851 .13694 .70911 .12812 .69782 .11162 Metetra
.664 .741 .908 r
.69782 .11162 .70911 .12812 .73332 .11921 .72218 .10258 Metetra
.869 .479 .007 r
.72218 .10258 .73332 .11921 .76653 .22089 .75519 .20439 Metetra
.656 .751 .92 r
.08173 .4226 .09677 .43573 .11695 .42864 .10199 .4154 Metetra
.656 .751 .92 r
.10199 .4154 .11695 .42864 .13729 .4215 .12242 .40815 Metetra
.945 .625 .396 r
.12242 .40815 .13729 .4215 .14483 .52849 .12944 .51544 Metetra
.646 .762 .934 r
.12944 .51544 .14483 .52849 .16618 .52144 .15088 .50829 Metetra
.646 .762 .934 r
.15088 .50829 .16618 .52144 .1877 .51434 .1725 .50108 Metetra
.646 .762 .934 r
.1725 .50108 .1877 .51434 .2094 .50718 .19431 .4938 Metetra
.646 .762 .934 r
.19431 .4938 .2094 .50718 .23129 .49996 .2163 .48647 Metetra
.646 .762 .934 r
.2163 .48647 .23129 .49996 .25336 .49268 .23849 .47907 Metetra
.646 .762 .934 r
.23849 .47907 .25336 .49268 .27562 .48533 .26086 .47161 Metetra
.646 .762 .934 r
.26086 .47161 .27562 .48533 .29806 .47793 .28342 .46409 Metetra
.646 .762 .934 r
.28342 .46409 .29806 .47793 .32071 .47046 .30618 .4565 Metetra
.646 .762 .934 r
.30618 .4565 .32071 .47046 .34354 .46292 .32914 .44884 Metetra
.646 .762 .934 r
.32914 .44884 .34354 .46292 .36658 .45532 .3523 .44112 Metetra
.646 .762 .934 r
.3523 .44112 .36658 .45532 .38981 .44766 .37566 .43333 Metetra
.646 .762 .934 r
.37566 .43333 .38981 .44766 .41325 .43992 .39922 .42547 Metetra
.964 .717 .513 r
.39922 .42547 .41325 .43992 .443 .20623 .43012 .19095 Metetra
.664 .741 .908 r
.43012 .19095 .443 .20623 .46522 .19798 .45246 .18257 Metetra
.664 .741 .908 r
.45246 .18257 .46522 .19798 .48762 .18966 .47497 .17413 Metetra
.664 .741 .908 r
.47497 .17413 .48762 .18966 .5102 .18128 .49768 .16562 Metetra
.664 .741 .908 r
.49768 .16562 .5102 .18128 .53297 .17282 .52057 .15703 Metetra
.664 .741 .908 r
.52057 .15703 .53297 .17282 .55593 .1643 .54366 .14837 Metetra
.664 .741 .908 r
.54366 .14837 .55593 .1643 .57909 .1557 .56694 .13964 Metetra
.664 .741 .908 r
.56694 .13964 .57909 .1557 .60244 .14703 .59042 .13084 Metetra
.664 .741 .908 r
.59042 .13084 .60244 .14703 .62598 .13829 .6141 .12196 Metetra
.664 .741 .908 r
.6141 .12196 .62598 .13829 .64972 .12948 .63798 .11301 Metetra
.664 .741 .908 r
.63798 .11301 .64972 .12948 .67367 .12059 .66207 .10397 Metetra
.664 .741 .908 r
.66207 .10397 .67367 .12059 .69782 .11162 .68636 .09486 Metetra
.664 .741 .908 r
.68636 .09486 .69782 .11162 .72218 .10258 .71086 .08568 Metetra
.869 .479 .007 r
.71086 .08568 .72218 .10258 .75519 .20439 .74366 .18761 Metetra
.656 .751 .92 r
.06646 .40927 .08173 .4226 .10199 .4154 .08681 .40197 Metetra
.656 .751 .92 r
.08681 .40197 .10199 .4154 .12242 .40815 .10733 .39461 Metetra
.945 .625 .396 r
.10733 .39461 .12242 .40815 .12944 .51544 .1138 .50219 Metetra
.646 .762 .934 r
.1138 .50219 .12944 .51544 .15088 .50829 .13534 .49493 Metetra
.646 .762 .934 r
.13534 .49493 .15088 .50829 .1725 .50108 .15707 .4876 Metetra
.646 .762 .934 r
.15707 .4876 .1725 .50108 .19431 .4938 .17898 .48021 Metetra
.646 .762 .934 r
.17898 .48021 .19431 .4938 .2163 .48647 .20109 .47276 Metetra
.646 .762 .934 r
.20109 .47276 .2163 .48647 .23849 .47907 .22338 .46525 Metetra
.646 .762 .934 r
.22338 .46525 .23849 .47907 .26086 .47161 .24586 .45767 Metetra
.646 .762 .934 r
.24586 .45767 .26086 .47161 .28342 .46409 .26854 .45002 Metetra
.646 .762 .934 r
.26854 .45002 .28342 .46409 .30618 .4565 .29142 .44231 Metetra
.646 .762 .934 r
.29142 .44231 .30618 .4565 .32914 .44884 .3145 .43453 Metetra
.646 .762 .934 r
.3145 .43453 .32914 .44884 .3523 .44112 .33778 .42668 Metetra
.646 .762 .934 r
.33778 .42668 .3523 .44112 .37566 .43333 .36127 .41876 Metetra
.646 .762 .934 r
.36127 .41876 .37566 .43333 .39922 .42547 .38497 .41077 Metetra
.964 .717 .513 r
.38497 .41077 .39922 .42547 .43012 .19095 .41705 .17543 Metetra
.664 .741 .908 r
.41705 .17543 .43012 .19095 .45246 .18257 .4395 .16693 Metetra
.664 .741 .908 r
.4395 .16693 .45246 .18257 .47497 .17413 .46213 .15836 Metetra
.664 .741 .908 r
.46213 .15836 .47497 .17413 .49768 .16562 .48496 .14971 Metetra
.664 .741 .908 r
.48496 .14971 .49768 .16562 .52057 .15703 .50798 .14099 Metetra
.664 .741 .908 r
.50798 .14099 .52057 .15703 .54366 .14837 .53119 .1322 Metetra
.664 .741 .908 r
.53119 .1322 .54366 .14837 .56694 .13964 .5546 .12333 Metetra
.664 .741 .908 r
.5546 .12333 .56694 .13964 .59042 .13084 .57822 .11439 Metetra
.664 .741 .908 r
.57822 .11439 .59042 .13084 .6141 .12196 .60203 .10537 Metetra
.664 .741 .908 r
.60203 .10537 .6141 .12196 .63798 .11301 .62605 .09627 Metetra
.664 .741 .908 r
.62605 .09627 .63798 .11301 .66207 .10397 .65028 .08709 Metetra
.664 .741 .908 r
.65028 .08709 .66207 .10397 .68636 .09486 .67471 .07784 Metetra
.664 .741 .908 r
.67471 .07784 .68636 .09486 .71086 .08568 .69936 .0685 Metetra
.869 .479 .007 r
.69936 .0685 .71086 .08568 .74366 .18761 .73194 .17055 Metetra
.656 .751 .92 r
.05096 .39575 .06646 .40927 .08681 .40197 .07141 .38834 Metetra
.656 .751 .92 r
.07141 .38834 .08681 .40197 .10733 .39461 .09202 .38086 Metetra
.656 .751 .92 r
.09202 .38086 .10733 .39461 .1138 .50219 .1128 .37333 Metetra
.545 .355 .575 r
.1128 .37333 .1138 .50219 .13534 .49493 .13375 .36574 Metetra
.545 .355 .575 r
.13375 .36574 .13534 .49493 .15707 .4876 .15487 .35808 Metetra
.545 .355 .575 r
.15487 .35808 .15707 .4876 .17898 .48021 .17617 .35036 Metetra
.545 .355 .575 r
.17617 .35036 .17898 .48021 .20109 .47276 .19765 .34257 Metetra
.545 .355 .575 r
.19765 .34257 .20109 .47276 .22338 .46525 .2193 .33472 Metetra
.545 .355 .575 r
.2193 .33472 .22338 .46525 .24586 .45767 .24114 .3268 Metetra
.545 .355 .575 r
.24114 .3268 .24586 .45767 .26854 .45002 .26316 .31882 Metetra
.545 .355 .575 r
.26316 .31882 .26854 .45002 .29142 .44231 .28537 .31077 Metetra
.545 .355 .575 r
.28537 .31077 .29142 .44231 .3145 .43453 .30777 .30265 Metetra
.545 .355 .575 r
.30777 .30265 .3145 .43453 .33778 .42668 .33036 .29446 Metetra
.545 .355 .575 r
.33036 .29446 .33778 .42668 .36127 .41876 .35315 .2862 Metetra
.545 .355 .575 r
.35315 .2862 .36127 .41876 .38497 .41077 .37613 .27787 Metetra
.545 .355 .575 r
.37613 .27787 .38497 .41077 .41705 .17543 .39931 .26947 Metetra
.443 .149 .369 r
.39931 .26947 .41705 .17543 .4395 .16693 .42269 .26099 Metetra
.443 .149 .369 r
.42269 .26099 .4395 .16693 .46213 .15836 .44628 .25244 Metetra
.443 .149 .369 r
.44628 .25244 .46213 .15836 .48496 .14971 .47007 .24381 Metetra
.443 .149 .369 r
.47007 .24381 .48496 .14971 .50798 .14099 .49408 .23511 Metetra
.443 .149 .369 r
.49408 .23511 .50798 .14099 .53119 .1322 .51829 .22633 Metetra
.443 .149 .369 r
.51829 .22633 .53119 .1322 .5546 .12333 .54272 .21748 Metetra
.443 .149 .369 r
.54272 .21748 .5546 .12333 .57822 .11439 .56737 .20854 Metetra
.443 .149 .369 r
.56737 .20854 .57822 .11439 .60203 .10537 .59224 .19952 Metetra
.443 .149 .369 r
.59224 .19952 .60203 .10537 .62605 .09627 .61734 .19043 Metetra
.443 .149 .369 r
.61734 .19043 .62605 .09627 .65028 .08709 .64266 .18125 Metetra
.443 .149 .369 r
.64266 .18125 .65028 .08709 .67471 .07784 .66821 .17198 Metetra
.443 .149 .369 r
.66821 .17198 .67471 .07784 .69936 .0685 .694 .16264 Metetra
.443 .149 .369 r
.694 .16264 .69936 .0685 .73194 .17055 .72002 .1532 Metetra
.656 .751 .92 r
.03523 .38202 .05096 .39575 .07141 .38834 .05577 .37449 Metetra
.656 .751 .92 r
.05577 .37449 .07141 .38834 .09202 .38086 .07647 .36691 Metetra
.656 .751 .92 r
.07647 .36691 .09202 .38086 .1128 .37333 .09734 .35926 Metetra
.656 .751 .92 r
.09734 .35926 .1128 .37333 .13375 .36574 .11839 .35155 Metetra
.656 .751 .92 r
.11839 .35155 .13375 .36574 .15487 .35808 .13961 .34377 Metetra
.656 .751 .92 r
.13961 .34377 .15487 .35808 .17617 .35036 .16101 .33593 Metetra
.656 .751 .92 r
.16101 .33593 .17617 .35036 .19765 .34257 .18259 .32803 Metetra
.656 .751 .92 r
.18259 .32803 .19765 .34257 .2193 .33472 .20435 .32005 Metetra
.656 .751 .92 r
.20435 .32005 .2193 .33472 .24114 .3268 .2263 .31201 Metetra
.656 .751 .92 r
.2263 .31201 .24114 .3268 .26316 .31882 .24843 .3039 Metetra
.656 .751 .92 r
.24843 .3039 .26316 .31882 .28537 .31077 .27075 .29572 Metetra
.656 .751 .92 r
.27075 .29572 .28537 .31077 .30777 .30265 .29327 .28747 Metetra
.656 .751 .92 r
.29327 .28747 .30777 .30265 .33036 .29446 .31598 .27915 Metetra
.656 .751 .92 r
.31598 .27915 .33036 .29446 .35315 .2862 .33888 .27076 Metetra
.656 .751 .92 r
.33888 .27076 .35315 .2862 .37613 .27787 .36198 .2623 Metetra
.656 .751 .92 r
.36198 .2623 .37613 .27787 .39931 .26947 .38529 .25376 Metetra
.656 .751 .92 r
.38529 .25376 .39931 .26947 .42269 .26099 .4088 .24514 Metetra
.656 .751 .92 r
.4088 .24514 .42269 .26099 .44628 .25244 .43252 .23645 Metetra
.656 .751 .92 r
.43252 .23645 .44628 .25244 .47007 .24381 .45644 .22769 Metetra
.656 .751 .92 r
.45644 .22769 .47007 .24381 .49408 .23511 .48058 .21884 Metetra
.656 .751 .92 r
.48058 .21884 .49408 .23511 .51829 .22633 .50494 .20992 Metetra
.656 .751 .92 r
.50494 .20992 .51829 .22633 .54272 .21748 .52951 .20092 Metetra
.656 .751 .92 r
.52951 .20092 .54272 .21748 .56737 .20854 .55431 .19183 Metetra
.656 .751 .92 r
.55431 .19183 .56737 .20854 .59224 .19952 .57933 .18266 Metetra
.656 .751 .92 r
.57933 .18266 .59224 .19952 .61734 .19043 .60457 .17341 Metetra
.656 .751 .92 r
.60457 .17341 .61734 .19043 .64266 .18125 .63005 .16408 Metetra
.656 .751 .92 r
.63005 .16408 .64266 .18125 .66821 .17198 .65576 .15466 Metetra
.656 .751 .92 r
.65576 .15466 .66821 .17198 .694 .16264 .68171 .14515 Metetra
.656 .751 .92 r
.68171 .14515 .694 .16264 .72002 .1532 .7079 .13556 Metetra
.656 .751 .92 r
.01926 .36808 .03523 .38202 .05577 .37449 .03989 .36044 Metetra
.656 .751 .92 r
.03989 .36044 .05577 .37449 .07647 .36691 .06068 .35274 Metetra
.656 .751 .92 r
.06068 .35274 .07647 .36691 .09734 .35926 .08165 .34497 Metetra
.656 .751 .92 r
.08165 .34497 .09734 .35926 .11839 .35155 .10279 .33714 Metetra
.656 .751 .92 r
.10279 .33714 .11839 .35155 .13961 .34377 .12411 .32925 Metetra
.656 .751 .92 r
.12411 .32925 .13961 .34377 .16101 .33593 .14562 .32128 Metetra
.656 .751 .92 r
.14562 .32128 .16101 .33593 .18259 .32803 .1673 .31325 Metetra
.656 .751 .92 r
.1673 .31325 .18259 .32803 .20435 .32005 .18917 .30515 Metetra
.656 .751 .92 r
.18917 .30515 .20435 .32005 .2263 .31201 .21122 .29699 Metetra
.656 .751 .92 r
.21122 .29699 .2263 .31201 .24843 .3039 .23347 .28875 Metetra
.656 .751 .92 r
.23347 .28875 .24843 .3039 .27075 .29572 .2559 .28044 Metetra
.656 .751 .92 r
.2559 .28044 .27075 .29572 .29327 .28747 .27853 .27206 Metetra
.656 .751 .92 r
.27853 .27206 .29327 .28747 .31598 .27915 .30136 .2636 Metetra
.656 .751 .92 r
.30136 .2636 .31598 .27915 .33888 .27076 .32438 .25508 Metetra
.656 .751 .92 r
.32438 .25508 .33888 .27076 .36198 .2623 .34761 .24647 Metetra
.656 .751 .92 r
.34761 .24647 .36198 .2623 .38529 .25376 .37104 .2378 Metetra
.656 .751 .92 r
.37104 .2378 .38529 .25376 .4088 .24514 .39468 .22904 Metetra
.656 .751 .92 r
.39468 .22904 .4088 .24514 .43252 .23645 .41853 .22021 Metetra
.656 .751 .92 r
.41853 .22021 .43252 .23645 .45644 .22769 .44259 .2113 Metetra
.656 .751 .92 r
.44259 .2113 .45644 .22769 .48058 .21884 .46687 .20231 Metetra
.656 .751 .92 r
.46687 .20231 .48058 .21884 .50494 .20992 .49136 .19323 Metetra
.656 .751 .92 r
.49136 .19323 .50494 .20992 .52951 .20092 .51608 .18408 Metetra
.656 .751 .92 r
.51608 .18408 .52951 .20092 .55431 .19183 .54102 .17484 Metetra
.656 .751 .92 r
.54102 .17484 .55431 .19183 .57933 .18266 .56619 .16552 Metetra
.656 .751 .92 r
.56619 .16552 .57933 .18266 .60457 .17341 .59159 .15611 Metetra
.656 .751 .92 r
.59159 .15611 .60457 .17341 .63005 .16408 .61722 .14662 Metetra
.656 .751 .92 r
.61722 .14662 .63005 .16408 .65576 .15466 .6431 .13704 Metetra
.656 .751 .92 r
.6431 .13704 .65576 .15466 .68171 .14515 .66921 .12737 Metetra
.656 .751 .92 r
.66921 .12737 .68171 .14515 .7079 .13556 .69556 .11761 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],

Cell["\<\
Here is the least asymmetric wavelet of order 8 in two dimensions. \
\
\>", "Text",
  CellTags->{"S1.5.4", "4.17"}],

Cell[TextData[{
  "We generate the one\[Hyphen]dimensional wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.5.4"],
  " first."
}], "MathCaption",
  CellTags->{"S1.5.4", "4.18"}],

Cell["\<\
(s8 = LeastAsymmetricFilter[8];
psi = Wavelet[s8, 7, Interpolation -> True];)\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.5.4"],

Cell[TextData[{
  "This gives the least asymmetric wavelet of order 8 ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((I  I  I)\)\) \((x, y)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  " in two dimensions."
}], "MathCaption",
  CellTags->{"S1.5.4", "4.19"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[psi[x] psi[y]],{x, -2, 3}, {y, -2, 3},
PlotPoints -> 70, PlotRange -> All,
Boxed -> False, Axes -> False];\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.278e-16 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.659 .749 .917 r
.39794 .67576 .40246 .67977 .41004 .67758 .40553 .67356 Metetra
.659 .75 .917 r
.40553 .67356 .41004 .67758 .41765 .67537 .41315 .67134 Metetra
.66 .75 .917 r
.41315 .67134 .41765 .67537 .42527 .67315 .42079 .66911 Metetra
.66 .75 .917 r
.42079 .66911 .42527 .67315 .43292 .67093 .42845 .66687 Metetra
.66 .75 .917 r
.42845 .66687 .43292 .67093 .44059 .6687 .43613 .66463 Metetra
.659 .749 .917 r
.43613 .66463 .44059 .6687 .44827 .66647 .44383 .66239 Metetra
.658 .749 .917 r
.44383 .66239 .44827 .66647 .45598 .66425 .45156 .66016 Metetra
.658 .749 .917 r
.45156 .66016 .45598 .66425 .46372 .66204 .4593 .65794 Metetra
.657 .749 .918 r
.4593 .65794 .46372 .66204 .47147 .65983 .46707 .65572 Metetra
.657 .749 .918 r
.46707 .65572 .47147 .65983 .47925 .65763 .47486 .65351 Metetra
.656 .748 .918 r
.47486 .65351 .47925 .65763 .48704 .65544 .48267 .6513 Metetra
.656 .749 .918 r
.48267 .6513 .48704 .65544 .49486 .65324 .49051 .64909 Metetra
.657 .749 .918 r
.49051 .64909 .49486 .65324 .50271 .65101 .49836 .64685 Metetra
.659 .749 .917 r
.49836 .64685 .50271 .65101 .51057 .64874 .50625 .64457 Metetra
.661 .75 .916 r
.50625 .64457 .51057 .64874 .51846 .64641 .51415 .64223 Metetra
.662 .75 .916 r
.51415 .64223 .51846 .64641 .52637 .64407 .52207 .63988 Metetra
.661 .75 .916 r
.52207 .63988 .52637 .64407 .53431 .64173 .53002 .63752 Metetra
.661 .75 .916 r
.53002 .63752 .53431 .64173 .54226 .63938 .53799 .63516 Metetra
.659 .749 .917 r
.53799 .63516 .54226 .63938 .55024 .63708 .54599 .63285 Metetra
.653 .748 .919 r
.54599 .63285 .55024 .63708 .55824 .63488 .55401 .63064 Metetra
.644 .745 .922 r
.55401 .63064 .55824 .63488 .56627 .63285 .56205 .6286 Metetra
.635 .742 .926 r
.56205 .6286 .56627 .63285 .57433 .63099 .57012 .62673 Metetra
.631 .741 .927 r
.57012 .62673 .57433 .63099 .58241 .62918 .57822 .62492 Metetra
.632 .742 .927 r
.57822 .62492 .58241 .62918 .59052 .62737 .58634 .62309 Metetra
.634 .743 .926 r
.58634 .62309 .59052 .62737 .59865 .6255 .59449 .62121 Metetra
.643 .746 .924 r
.59449 .62121 .59865 .6255 .60681 .62345 .60266 .61916 Metetra
.657 .75 .919 r
.60266 .61916 .60681 .62345 .61498 .62113 .61085 .61683 Metetra
.676 .756 .911 r
.61085 .61683 .61498 .62113 .62317 .61839 .61905 .61406 Metetra
.694 .761 .903 r
.61905 .61406 .62317 .61839 .63136 .61522 .62727 .61088 Metetra
.702 .762 .899 r
.62727 .61088 .63136 .61522 .63957 .61186 .63549 .60749 Metetra
.704 .763 .897 r
.63549 .60749 .63957 .61186 .6478 .60842 .64373 .60403 Metetra
.702 .761 .898 r
.64373 .60403 .6478 .60842 .65604 .60505 .652 .60062 Metetra
.693 .759 .902 r
.652 .60062 .65604 .60505 .66432 .60187 .66029 .59742 Metetra
.679 .754 .908 r
.66029 .59742 .66432 .60187 .67263 .59902 .66862 .59456 Metetra
.654 .746 .917 r
.66862 .59456 .67263 .59902 .68099 .59672 .67699 .59225 Metetra
.627 .736 .926 r
.67699 .59225 .68099 .59672 .68939 .59494 .68542 .59046 Metetra
.61 .731 .931 r
.68542 .59046 .68939 .59494 .69785 .59345 .69389 .58897 Metetra
.602 .728 .933 r
.69389 .58897 .69785 .59345 .70633 .59209 .70239 .58761 Metetra
.604 .729 .933 r
.70239 .58761 .70633 .59209 .71485 .59069 .71093 .58621 Metetra
.611 .732 .932 r
.71093 .58621 .71485 .59069 .72339 .58917 .71948 .58468 Metetra
.623 .737 .929 r
.71948 .58468 .72339 .58917 .73195 .58743 .72806 .58294 Metetra
.644 .745 .923 r
.72806 .58294 .73195 .58743 .74051 .58527 .73664 .58077 Metetra
.662 .752 .917 r
.73664 .58077 .74051 .58527 .74907 .58272 .74522 .57821 Metetra
.672 .755 .913 r
.74522 .57821 .74907 .58272 .75765 .57994 .75381 .57541 Metetra
.677 .757 .911 r
.75381 .57541 .75765 .57994 .76624 .57705 .76242 .5725 Metetra
.676 .756 .911 r
.76242 .5725 .76624 .57705 .77485 .57417 .77105 .56959 Metetra
.676 .756 .911 r
.77105 .56959 .77485 .57417 .78349 .57128 .77971 .56669 Metetra
.674 .755 .912 r
.77971 .56669 .78349 .57128 .79216 .56844 .78839 .56383 Metetra
.668 .753 .914 r
.78839 .56383 .79216 .56844 .80086 .56572 .79711 .56109 Metetra
.663 .751 .916 r
.79711 .56109 .80086 .56572 .80959 .5631 .80587 .55846 Metetra
.66 .75 .917 r
.80587 .55846 .80959 .5631 .81836 .56054 .81466 .55589 Metetra
.659 .75 .917 r
.81466 .55589 .81836 .56054 .82716 .55799 .82347 .55333 Metetra
.661 .75 .916 r
.82347 .55333 .82716 .55799 .83598 .55541 .83231 .55072 Metetra
.66 .75 .916 r
.83231 .55072 .83598 .55541 .84483 .55282 .84118 .54812 Metetra
.659 .749 .917 r
.84118 .54812 .84483 .55282 .8537 .55025 .85007 .54554 Metetra
.658 .749 .917 r
.85007 .54554 .8537 .55025 .86261 .5477 .859 .54297 Metetra
.657 .749 .917 r
.859 .54297 .86261 .5477 .87154 .54516 .86795 .54041 Metetra
.656 .748 .918 r
.86795 .54041 .87154 .54516 .88051 .54262 .87694 .53786 Metetra
.655 .748 .918 r
.87694 .53786 .88051 .54262 .8895 .5401 .88595 .53533 Metetra
.654 .747 .918 r
.88595 .53533 .8895 .5401 .89853 .53761 .895 .53282 Metetra
.654 .747 .919 r
.895 .53282 .89853 .53761 .90758 .53511 .90407 .53031 Metetra
.654 .747 .919 r
.90407 .53031 .90758 .53511 .91666 .5326 .91317 .52779 Metetra
.655 .748 .918 r
.91317 .52779 .91666 .5326 .92577 .53006 .9223 .52523 Metetra
.656 .748 .918 r
.9223 .52523 .92577 .53006 .9349 .52748 .93146 .52264 Metetra
.656 .749 .918 r
.93146 .52264 .9349 .52748 .94406 .52489 .94064 .52004 Metetra
.657 .749 .918 r
.94064 .52004 .94406 .52489 .95325 .52228 .94985 .51741 Metetra
.657 .749 .918 r
.94985 .51741 .95325 .52228 .96247 .51966 .95908 .51478 Metetra
.657 .749 .918 r
.95908 .51478 .96247 .51966 .97171 .51702 .96835 .51212 Metetra
.658 .749 .917 r
.96835 .51212 .97171 .51702 .98098 .51437 .97764 .50945 Metetra
.659 .749 .917 r
.39339 .67173 .39794 .67576 .40553 .67356 .401 .66952 Metetra
.659 .749 .917 r
.401 .66952 .40553 .67356 .41315 .67134 .40863 .66729 Metetra
.659 .75 .917 r
.40863 .66729 .41315 .67134 .42079 .66911 .41628 .66505 Metetra
.66 .75 .917 r
.41628 .66505 .42079 .66911 .42845 .66687 .42396 .6628 Metetra
.659 .75 .917 r
.42396 .6628 .42845 .66687 .43613 .66463 .43165 .66055 Metetra
.659 .75 .917 r
.43165 .66055 .43613 .66463 .44383 .66239 .43937 .6583 Metetra
.658 .75 .917 r
.43937 .6583 .44383 .66239 .45156 .66016 .44711 .65606 Metetra
.658 .749 .918 r
.44711 .65606 .45156 .66016 .4593 .65794 .45487 .65382 Metetra
.657 .749 .918 r
.45487 .65382 .4593 .65794 .46707 .65572 .46265 .65159 Metetra
.657 .749 .918 r
.46265 .65159 .46707 .65572 .47486 .65351 .47045 .64937 Metetra
.656 .749 .918 r
.47045 .64937 .47486 .65351 .48267 .6513 .47828 .64715 Metetra
.656 .749 .918 r
.47828 .64715 .48267 .6513 .49051 .64909 .48613 .64493 Metetra
.657 .749 .918 r
.48613 .64493 .49051 .64909 .49836 .64685 .494 .64267 Metetra
.659 .749 .917 r
.494 .64267 .49836 .64685 .50625 .64457 .50189 .64038 Metetra
.661 .75 .916 r
.50189 .64038 .50625 .64457 .51415 .64223 .50981 .63803 Metetra
.661 .75 .916 r
.50981 .63803 .51415 .64223 .52207 .63988 .51775 .63567 Metetra
.661 .751 .916 r
.51775 .63567 .52207 .63988 .53002 .63752 .52572 .63331 Metetra
.661 .751 .917 r
.52572 .63331 .53002 .63752 .53799 .63516 .5337 .63094 Metetra
.659 .75 .918 r
.5337 .63094 .53799 .63516 .54599 .63285 .54171 .62861 Metetra
.653 .749 .92 r
.54171 .62861 .54599 .63285 .55401 .63064 .54975 .62638 Metetra
.645 .746 .923 r
.54975 .62638 .55401 .63064 .56205 .6286 .55781 .62432 Metetra
.636 .742 .925 r
.55781 .62432 .56205 .6286 .57012 .62673 .56589 .62242 Metetra
.633 .741 .926 r
.56589 .62242 .57012 .62673 .57822 .62492 .574 .62057 Metetra
.633 .739 .925 r
.574 .62057 .57822 .62492 .58634 .62309 .58214 .61871 Metetra
.636 .739 .923 r
.58214 .61871 .58634 .62309 .59449 .62121 .59031 .61679 Metetra
.644 .741 .919 r
.59031 .61679 .59449 .62121 .60266 .61916 .59849 .61471 Metetra
.657 .744 .914 r
.59849 .61471 .60266 .61916 .61085 .61683 .6067 .61237 Metetra
.676 .75 .907 r
.6067 .61237 .61085 .61683 .61905 .61406 .61492 .60961 Metetra
.692 .755 .9 r
.61492 .60961 .61905 .61406 .62727 .61088 .62315 .60645 Metetra
.7 .759 .898 r
.62315 .60645 .62727 .61088 .63549 .60749 .63139 .6031 Metetra
.702 .762 .898 r
.63139 .6031 .63549 .60749 .64373 .60403 .63965 .59968 Metetra
.7 .764 .901 r
.63965 .59968 .64373 .60403 .652 .60062 .64794 .59631 Metetra
.692 .764 .907 r
.64794 .59631 .652 .60062 .66029 .59742 .65625 .59314 Metetra
.678 .762 .914 r
.65625 .59314 .66029 .59742 .66862 .59456 .6646 .59028 Metetra
.653 .755 .925 r
.6646 .59028 .66862 .59456 .67699 .59225 .67299 .58795 Metetra
.626 .746 .933 r
.67299 .58795 .67699 .59225 .68542 .59046 .68143 .58612 Metetra
.611 .739 .936 r
.68143 .58612 .68542 .59046 .69389 .58897 .68991 .58457 Metetra
.604 .734 .936 r
.68991 .58457 .69389 .58897 .70239 .58761 .69843 .58315 Metetra
.607 .732 .934 r
.69843 .58315 .70239 .58761 .71093 .58621 .70698 .58168 Metetra
.614 .732 .93 r
.70698 .58168 .71093 .58621 .71948 .58468 .71555 .5801 Metetra
.625 .735 .926 r
.71555 .5801 .71948 .58468 .72806 .58294 .72414 .5783 Metetra
.645 .74 .919 r
.72414 .5783 .72806 .58294 .73664 .58077 .73274 .57611 Metetra
.662 .746 .912 r
.73274 .57611 .73664 .58077 .74522 .57821 .74133 .57354 Metetra
.672 .749 .909 r
.74133 .57354 .74522 .57821 .75381 .57541 .74995 .57074 Metetra
.676 .752 .908 r
.74995 .57074 .75381 .57541 .76242 .5725 .75857 .56784 Metetra
.675 .752 .909 r
.75857 .56784 .76242 .5725 .77105 .56959 .76723 .56494 Metetra
.675 .753 .91 r
.76723 .56494 .77105 .56959 .77971 .56669 .7759 .56205 Metetra
.673 .753 .911 r
.7759 .56205 .77971 .56669 .78839 .56383 .78461 .55919 Metetra
.668 .752 .914 r
.78461 .55919 .78839 .56383 .79711 .56109 .79335 .55644 Metetra
.663 .751 .916 r
.79335 .55644 .79711 .56109 .80587 .55846 .80212 .5538 Metetra
.66 .75 .917 r
.80212 .5538 .80587 .55846 .81466 .55589 .81093 .55122 Metetra
.659 .75 .917 r
.81093 .55122 .81466 .55589 .82347 .55333 .81976 .54865 Metetra
.66 .751 .917 r
.81976 .54865 .82347 .55333 .83231 .55072 .82862 .54603 Metetra
.66 .751 .917 r
.82862 .54603 .83231 .55072 .84118 .54812 .83751 .54342 Metetra
.659 .75 .918 r
.83751 .54342 .84118 .54812 .85007 .54554 .84642 .54082 Metetra
.658 .75 .918 r
.84642 .54082 .85007 .54554 .859 .54297 .85537 .53824 Metetra
.657 .75 .918 r
.85537 .53824 .859 .54297 .86795 .54041 .86434 .53567 Metetra
.656 .749 .918 r
.86434 .53567 .86795 .54041 .87694 .53786 .87335 .5331 Metetra
.655 .749 .919 r
.87335 .5331 .87694 .53786 .88595 .53533 .88238 .53055 Metetra
.654 .748 .919 r
.88238 .53055 .88595 .53533 .895 .53282 .89145 .52803 Metetra
.654 .748 .919 r
.89145 .52803 .895 .53282 .90407 .53031 .90054 .5255 Metetra
.654 .748 .919 r
.90054 .5255 .90407 .53031 .91317 .52779 .90966 .52295 Metetra
.655 .748 .918 r
.90966 .52295 .91317 .52779 .9223 .52523 .91881 .52038 Metetra
.656 .748 .918 r
.91881 .52038 .9223 .52523 .93146 .52264 .92799 .51777 Metetra
.656 .749 .918 r
.92799 .51777 .93146 .52264 .94064 .52004 .93719 .51515 Metetra
.657 .749 .918 r
.93719 .51515 .94064 .52004 .94985 .51741 .94642 .51251 Metetra
.657 .749 .917 r
.94642 .51251 .94985 .51741 .95908 .51478 .95568 .50986 Metetra
.657 .749 .917 r
.95568 .50986 .95908 .51478 .96835 .51212 .96497 .50719 Metetra
.658 .749 .917 r
.96497 .50719 .96835 .51212 .97764 .50945 .97428 .5045 Metetra
.659 .749 .917 r
.38882 .66768 .39339 .67173 .401 .66952 .39644 .66546 Metetra
.659 .749 .917 r
.39644 .66546 .401 .66952 .40863 .66729 .40409 .66322 Metetra
.659 .75 .917 r
.40409 .66322 .40863 .66729 .41628 .66505 .41175 .66098 Metetra
.659 .75 .917 r
.41175 .66098 .41628 .66505 .42396 .6628 .41944 .65872 Metetra
.659 .75 .917 r
.41944 .65872 .42396 .6628 .43165 .66055 .42715 .65646 Metetra
.659 .75 .918 r
.42715 .65646 .43165 .66055 .43937 .6583 .43488 .65421 Metetra
.658 .75 .918 r
.43488 .65421 .43937 .6583 .44711 .65606 .44263 .65195 Metetra
.658 .75 .918 r
.44263 .65195 .44711 .65606 .45487 .65382 .4504 .64971 Metetra
.657 .75 .919 r
.4504 .64971 .45487 .65382 .46265 .65159 .4582 .64746 Metetra
.657 .75 .919 r
.4582 .64746 .46265 .65159 .47045 .64937 .46602 .64522 Metetra
.656 .75 .919 r
.46602 .64522 .47045 .64937 .47828 .64715 .47386 .64299 Metetra
.656 .749 .919 r
.47386 .64299 .47828 .64715 .48613 .64493 .48172 .64074 Metetra
.657 .749 .918 r
.48172 .64074 .48613 .64493 .494 .64267 .48961 .63848 Metetra
.659 .75 .917 r
.48961 .63848 .494 .64267 .50189 .64038 .49752 .63617 Metetra
.66 .75 .917 r
.49752 .63617 .50189 .64038 .50981 .63803 .50545 .63383 Metetra
.661 .751 .917 r
.50545 .63383 .50981 .63803 .51775 .63567 .51341 .63146 Metetra
.66 .751 .917 r
.51341 .63146 .51775 .63567 .52572 .63331 .52139 .6291 Metetra
.661 .752 .918 r
.52139 .6291 .52572 .63331 .5337 .63094 .52939 .62672 Metetra
.658 .752 .919 r
.52939 .62672 .5337 .63094 .54171 .62861 .53742 .62439 Metetra
.654 .751 .921 r
.53742 .62439 .54171 .62861 .54975 .62638 .54546 .62214 Metetra
.647 .748 .923 r
.54546 .62214 .54975 .62638 .55781 .62432 .55354 .62002 Metetra
.639 .744 .924 r
.55354 .62002 .55781 .62432 .56589 .62242 .56164 .61805 Metetra
.637 .74 .923 r
.56164 .61805 .56589 .62242 .574 .62057 .56976 .61611 Metetra
.638 .737 .92 r
.56976 .61611 .574 .62057 .58214 .61871 .57792 .61416 Metetra
.64 .734 .917 r
.57792 .61416 .58214 .61871 .59031 .61679 .58609 .61217 Metetra
.647 .734 .912 r
.58609 .61217 .59031 .61679 .59849 .61471 .59429 .61004 Metetra
.658 .735 .907 r
.59429 .61004 .59849 .61471 .6067 .61237 .60251 .60768 Metetra
.673 .74 .901 r
.60251 .60768 .6067 .61237 .61492 .60961 .61075 .60497 Metetra
.687 .747 .897 r
.61075 .60497 .61492 .60961 .62315 .60645 .619 .60191 Metetra
.694 .754 .898 r
.619 .60191 .62315 .60645 .63139 .6031 .62727 .59869 Metetra
.696 .761 .902 r
.62727 .59869 .63139 .6031 .63965 .59968 .63555 .59541 Metetra
.695 .767 .908 r
.63555 .59541 .63965 .59968 .64794 .59631 .64386 .59217 Metetra
.687 .772 .916 r
.64386 .59217 .64794 .59631 .65625 .59314 .65219 .5891 Metetra
.674 .774 .925 r
.65219 .5891 .65625 .59314 .6646 .59028 .66056 .58629 Metetra
.651 .77 .936 r
.66056 .58629 .6646 .59028 .67299 .58795 .66897 .58394 Metetra
.628 .762 .943 r
.66897 .58394 .67299 .58795 .68143 .58612 .67743 .58201 Metetra
.615 .753 .944 r
.67743 .58201 .68143 .58612 .68991 .58457 .68592 .58031 Metetra
.61 .744 .94 r
.68592 .58031 .68991 .58457 .69843 .58315 .69445 .57873 Metetra
.614 .738 .934 r
.69445 .57873 .69843 .58315 .70698 .58168 .70301 .5771 Metetra
.621 .734 .927 r
.70301 .5771 .70698 .58168 .71555 .5801 .71159 .57538 Metetra
.631 .732 .92 r
.71159 .57538 .71555 .5801 .72414 .5783 .72019 .57347 Metetra
.648 .733 .912 r
.72019 .57347 .72414 .5783 .73274 .57611 .7288 .57122 Metetra
.662 .737 .905 r
.7288 .57122 .73274 .57611 .74133 .57354 .73742 .56865 Metetra
.67 .74 .903 r
.73742 .56865 .74133 .57354 .74995 .57074 .74605 .56589 Metetra
.674 .743 .903 r
.74605 .56589 .74995 .57074 .75857 .56784 .7547 .56303 Metetra
.673 .746 .906 r
.7547 .56303 .75857 .56784 .76723 .56494 .76337 .56018 Metetra
.672 .748 .908 r
.76337 .56018 .76723 .56494 .7759 .56205 .77207 .55733 Metetra
.671 .75 .91 r
.77207 .55733 .7759 .56205 .78461 .55919 .7808 .5545 Metetra
.666 .751 .914 r
.7808 .5545 .78461 .55919 .79335 .55644 .78956 .55178 Metetra
.662 .751 .916 r
.78956 .55178 .79335 .55644 .80212 .5538 .79836 .54914 Metetra
.659 .751 .918 r
.79836 .54914 .80212 .5538 .81093 .55122 .80718 .54655 Metetra
.659 .751 .918 r
.80718 .54655 .81093 .55122 .81976 .54865 .81604 .54396 Metetra
.66 .752 .918 r
.81604 .54396 .81976 .54865 .82862 .54603 .82492 .54134 Metetra
.659 .752 .918 r
.82492 .54134 .82862 .54603 .83751 .54342 .83382 .53872 Metetra
.659 .752 .919 r
.83382 .53872 .83751 .54342 .84642 .54082 .84276 .53612 Metetra
.658 .752 .919 r
.84276 .53612 .84642 .54082 .85537 .53824 .85172 .53352 Metetra
.657 .752 .92 r
.85172 .53352 .85537 .53824 .86434 .53567 .86072 .53093 Metetra
.656 .751 .92 r
.86072 .53093 .86434 .53567 .87335 .5331 .86974 .52835 Metetra
.655 .751 .92 r
.86974 .52835 .87335 .5331 .88238 .53055 .8788 .52578 Metetra
.654 .75 .92 r
.8788 .52578 .88238 .53055 .89145 .52803 .88788 .52322 Metetra
.654 .749 .92 r
.88788 .52322 .89145 .52803 .90054 .5255 .89699 .52067 Metetra
.655 .749 .919 r
.89699 .52067 .90054 .5255 .90966 .52295 .90614 .51809 Metetra
.656 .749 .918 r
.90614 .51809 .90966 .52295 .91881 .52038 .9153 .51549 Metetra
.656 .749 .918 r
.9153 .51549 .91881 .52038 .92799 .51777 .9245 .51287 Metetra
.657 .748 .918 r
.9245 .51287 .92799 .51777 .93719 .51515 .93372 .51023 Metetra
.657 .748 .917 r
.93372 .51023 .93719 .51515 .94642 .51251 .94297 .50757 Metetra
.657 .748 .917 r
.94297 .50757 .94642 .51251 .95568 .50986 .95225 .5049 Metetra
.658 .748 .917 r
.95225 .5049 .95568 .50986 .96497 .50719 .96156 .50221 Metetra
.658 .749 .917 r
.96156 .50221 .96497 .50719 .97428 .5045 .9709 .49952 Metetra
.659 .749 .917 r
.38423 .6636 .38882 .66768 .39644 .66546 .39186 .66137 Metetra
.659 .749 .917 r
.39186 .66137 .39644 .66546 .40409 .66322 .39952 .65913 Metetra
.659 .75 .917 r
.39952 .65913 .40409 .66322 .41175 .66098 .4072 .65688 Metetra
.659 .75 .917 r
.4072 .65688 .41175 .66098 .41944 .65872 .4149 .65462 Metetra
.659 .75 .918 r
.4149 .65462 .41944 .65872 .42715 .65646 .42262 .65236 Metetra
.658 .751 .918 r
.42262 .65236 .42715 .65646 .43488 .65421 .43036 .6501 Metetra
.658 .751 .918 r
.43036 .6501 .43488 .65421 .44263 .65195 .43813 .64784 Metetra
.657 .751 .919 r
.43813 .64784 .44263 .65195 .4504 .64971 .44592 .64558 Metetra
.657 .751 .919 r
.44592 .64558 .4504 .64971 .4582 .64746 .45373 .64332 Metetra
.657 .75 .919 r
.45373 .64332 .4582 .64746 .46602 .64522 .46156 .64106 Metetra
.656 .75 .919 r
.46156 .64106 .46602 .64522 .47386 .64299 .46942 .63881 Metetra
.656 .75 .919 r
.46942 .63881 .47386 .64299 .48172 .64074 .4773 .63655 Metetra
.657 .75 .918 r
.4773 .63655 .48172 .64074 .48961 .63848 .4852 .63426 Metetra
.658 .75 .918 r
.4852 .63426 .48961 .63848 .49752 .63617 .49312 .63195 Metetra
.66 .75 .917 r
.49312 .63195 .49752 .63617 .50545 .63383 .50107 .6296 Metetra
.66 .751 .918 r
.50107 .6296 .50545 .63383 .51341 .63146 .50904 .62725 Metetra
.66 .752 .918 r
.50904 .62725 .51341 .63146 .52139 .6291 .51704 .62488 Metetra
.66 .752 .919 r
.51704 .62488 .52139 .6291 .52939 .62672 .52505 .62251 Metetra
.658 .753 .92 r
.52505 .62251 .52939 .62672 .53742 .62439 .53309 .62017 Metetra
.655 .752 .921 r
.53309 .62017 .53742 .62439 .54546 .62214 .54116 .61789 Metetra
.649 .749 .923 r
.54116 .61789 .54546 .62214 .55354 .62002 .54925 .6157 Metetra
.644 .745 .923 r
.54925 .6157 .55354 .62002 .56164 .61805 .55736 .61362 Metetra
.643 .741 .92 r
.55736 .61362 .56164 .61805 .56976 .61611 .5655 .61157 Metetra
.643 .736 .916 r
.5655 .61157 .56976 .61611 .57792 .61416 .57367 .60951 Metetra
.645 .732 .912 r
.57367 .60951 .57792 .61416 .58609 .61217 .58186 .60742 Metetra
.65 .73 .907 r
.58186 .60742 .58609 .61217 .59429 .61004 .59007 .60521 Metetra
.658 .73 .902 r
.59007 .60521 .59429 .61004 .60251 .60768 .59831 .60284 Metetra
.669 .733 .898 r
.59831 .60284 .60251 .60768 .61075 .60497 .60656 .60019 Metetra
.68 .74 .896 r
.60656 .60019 .61075 .60497 .619 .60191 .61483 .59729 Metetra
.685 .749 .9 r
.61483 .59729 .619 .60191 .62727 .59869 .62312 .59426 Metetra
.687 .759 .906 r
.62312 .59426 .62727 .59869 .63555 .59541 .63143 .59118 Metetra
.686 .768 .914 r
.63143 .59118 .63555 .59541 .64386 .59217 .63976 .58814 Metetra
.68 .776 .924 r
.63976 .58814 .64386 .59217 .65219 .5891 .64812 .58522 Metetra
.669 .781 .933 r
.64812 .58522 .65219 .5891 .66056 .58629 .65651 .58249 Metetra
.65 .781 .943 r
.65651 .58249 .66056 .58629 .66897 .58394 .66494 .58011 Metetra
.632 .774 .948 r
.66494 .58011 .66897 .58394 .67743 .58201 .67341 .57804 Metetra
.623 .764 .947 r
.67341 .57804 .67743 .58201 .68592 .58031 .68191 .57614 Metetra
.621 .754 .941 r
.68191 .57614 .68592 .58031 .69445 .57873 .69045 .57432 Metetra
.625 .744 .933 r
.69045 .57432 .69445 .57873 .70301 .5771 .69901 .57248 Metetra
.631 .737 .924 r
.69901 .57248 .70301 .5771 .71159 .57538 .7076 .57056 Metetra
.639 .731 .915 r
.7076 .57056 .71159 .57538 .72019 .57347 .71621 .56849 Metetra
.651 .73 .907 r
.71621 .56849 .72019 .57347 .7288 .57122 .72483 .56617 Metetra
.661 .731 .901 r
.72483 .56617 .7288 .57122 .73742 .56865 .73347 .56361 Metetra
.667 .734 .9 r
.73347 .56361 .73742 .56865 .74605 .56589 .74212 .5609 Metetra
.67 .738 .901 r
.74212 .5609 .74605 .56589 .7547 .56303 .75079 .55811 Metetra
.669 .741 .904 r
.75079 .55811 .7547 .56303 .76337 .56018 .75949 .55533 Metetra
.669 .745 .907 r
.75949 .55533 .76337 .56018 .77207 .55733 .76822 .55255 Metetra
.668 .748 .91 r
.76822 .55255 .77207 .55733 .7808 .5545 .77697 .54978 Metetra
.664 .75 .914 r
.77697 .54978 .7808 .5545 .78956 .55178 .78576 .54709 Metetra
.661 .751 .917 r
.78576 .54709 .78956 .55178 .79836 .54914 .79457 .54446 Metetra
.659 .751 .918 r
.79457 .54446 .79836 .54914 .80718 .54655 .80342 .54187 Metetra
.658 .752 .919 r
.80342 .54187 .80718 .54655 .81604 .54396 .81229 .53927 Metetra
.659 .752 .919 r
.81229 .53927 .81604 .54396 .82492 .54134 .82119 .53665 Metetra
.659 .753 .919 r
.82119 .53665 .82492 .54134 .83382 .53872 .83012 .53403 Metetra
.658 .753 .92 r
.83012 .53403 .83382 .53872 .84276 .53612 .83908 .53141 Metetra
.658 .753 .92 r
.83908 .53141 .84276 .53612 .85172 .53352 .84806 .5288 Metetra
.657 .753 .921 r
.84806 .5288 .85172 .53352 .86072 .53093 .85708 .5262 Metetra
.657 .752 .921 r
.85708 .5262 .86072 .53093 .86974 .52835 .86612 .52359 Metetra
.656 .752 .921 r
.86612 .52359 .86974 .52835 .8788 .52578 .87519 .52099 Metetra
.655 .751 .92 r
.87519 .52099 .8788 .52578 .88788 .52322 .8843 .51841 Metetra
.655 .75 .92 r
.8843 .51841 .88788 .52322 .89699 .52067 .89343 .51582 Metetra
.655 .749 .919 r
.89343 .51582 .89699 .52067 .90614 .51809 .90259 .51321 Metetra
.656 .749 .918 r
.90259 .51321 .90614 .51809 .9153 .51549 .91178 .51059 Metetra
.657 .749 .918 r
.91178 .51059 .9153 .51549 .9245 .51287 .92099 .50794 Metetra
.657 .749 .917 r
.92099 .50794 .9245 .51287 .93372 .51023 .93023 .50527 Metetra
.657 .748 .917 r
.93023 .50527 .93372 .51023 .94297 .50757 .93951 .5026 Metetra
.657 .748 .917 r
.93951 .5026 .94297 .50757 .95225 .5049 .94881 .49991 Metetra
.658 .748 .917 r
.94881 .49991 .95225 .5049 .96156 .50221 .95814 .49721 Metetra
.658 .748 .917 r
.95814 .49721 .96156 .50221 .9709 .49952 .9675 .49449 Metetra
.658 .749 .917 r
.37961 .6595 .38423 .6636 .39186 .66137 .38726 .65726 Metetra
.658 .749 .917 r
.38726 .65726 .39186 .66137 .39952 .65913 .39493 .65502 Metetra
.658 .75 .917 r
.39493 .65502 .39952 .65913 .4072 .65688 .40262 .65277 Metetra
.658 .75 .918 r
.40262 .65277 .4072 .65688 .4149 .65462 .41033 .65051 Metetra
.658 .751 .918 r
.41033 .65051 .4149 .65462 .42262 .65236 .41807 .64825 Metetra
.658 .751 .919 r
.41807 .64825 .42262 .65236 .43036 .6501 .42583 .64598 Metetra
.658 .751 .919 r
.42583 .64598 .43036 .6501 .43813 .64784 .43361 .64371 Metetra
.657 .751 .919 r
.43361 .64371 .43813 .64784 .44592 .64558 .44141 .64144 Metetra
.657 .751 .919 r
.44141 .64144 .44592 .64558 .45373 .64332 .44924 .63917 Metetra
.657 .751 .919 r
.44924 .63917 .45373 .64332 .46156 .64106 .45708 .63689 Metetra
.657 .751 .919 r
.45708 .63689 .46156 .64106 .46942 .63881 .46495 .63461 Metetra
.657 .75 .919 r
.46495 .63461 .46942 .63881 .4773 .63655 .47285 .63233 Metetra
.657 .75 .918 r
.47285 .63233 .4773 .63655 .4852 .63426 .48076 .63003 Metetra
.658 .75 .918 r
.48076 .63003 .4852 .63426 .49312 .63195 .4887 .62771 Metetra
.659 .75 .918 r
.4887 .62771 .49312 .63195 .50107 .6296 .49667 .62537 Metetra
.659 .751 .918 r
.49667 .62537 .50107 .6296 .50904 .62725 .50465 .62302 Metetra
.659 .752 .919 r
.50465 .62302 .50904 .62725 .51704 .62488 .51266 .62067 Metetra
.659 .753 .92 r
.51266 .62067 .51704 .62488 .52505 .62251 .52069 .61831 Metetra
.658 .754 .921 r
.52069 .61831 .52505 .62251 .53309 .62017 .52875 .61596 Metetra
.656 .754 .922 r
.52875 .61596 .53309 .62017 .54116 .61789 .53683 .61364 Metetra
.653 .752 .922 r
.53683 .61364 .54116 .61789 .54925 .6157 .54493 .61136 Metetra
.65 .747 .92 r
.54493 .61136 .54925 .6157 .55736 .61362 .55306 .60914 Metetra
.65 .741 .916 r
.55306 .60914 .55736 .61362 .5655 .61157 .56122 .60693 Metetra
.651 .735 .911 r
.56122 .60693 .5655 .61157 .57367 .60951 .56939 .60472 Metetra
.652 .729 .906 r
.56939 .60472 .57367 .60951 .58186 .60742 .5776 .60248 Metetra
.655 .724 .9 r
.5776 .60248 .58186 .60742 .59007 .60521 .58583 .60018 Metetra
.658 .722 .896 r
.58583 .60018 .59007 .60521 .59831 .60284 .59408 .59778 Metetra
.664 .724 .894 r
.59408 .59778 .59831 .60284 .60656 .60019 .60235 .59524 Metetra
.67 .731 .895 r
.60235 .59524 .60656 .60019 .61483 .59729 .61064 .59256 Metetra
.673 .742 .902 r
.61064 .59256 .61483 .59729 .62312 .59426 .61895 .58981 Metetra
.674 .755 .912 r
.61895 .58981 .62312 .59426 .63143 .59118 .62729 .58703 Metetra
.672 .769 .923 r
.62729 .58703 .63143 .59118 .63976 .58814 .63565 .58427 Metetra
.668 .782 .935 r
.63565 .58427 .63976 .58814 .64812 .58522 .64404 .58157 Metetra
.66 .792 .945 r
.64404 .58157 .64812 .58522 .65651 .58249 .65245 .57896 Metetra
.648 .796 .953 r
.65245 .57896 .65651 .58249 .66494 .58011 .6609 .57654 Metetra
.639 .791 .955 r
.6609 .57654 .66494 .58011 .67341 .57804 .66938 .57427 Metetra
.636 .78 .951 r
.66938 .57427 .67341 .57804 .68191 .57614 .67789 .5721 Metetra
.637 .767 .942 r
.67789 .5721 .68191 .57614 .69045 .57432 .68643 .56996 Metetra
.64 .753 .93 r
.68643 .56996 .69045 .57432 .69901 .57248 .69499 .5678 Metetra
.644 .74 .919 r
.69499 .5678 .69901 .57248 .7076 .57056 .70358 .5656 Metetra
.648 .73 .909 r
.70358 .5656 .7076 .57056 .71621 .56849 .7122 .56332 Metetra
.655 .724 .9 r
.7122 .56332 .71621 .56849 .72483 .56617 .72083 .56091 Metetra
.66 .723 .895 r
.72083 .56091 .72483 .56617 .73347 .56361 .72949 .55836 Metetra
.663 .725 .895 r
.72949 .55836 .73347 .56361 .74212 .5609 .73816 .55573 Metetra
.664 .729 .898 r
.73816 .55573 .74212 .5609 .75079 .55811 .74686 .55305 Metetra
.664 .735 .902 r
.74686 .55305 .75079 .55811 .75949 .55533 .75559 .55038 Metetra
.664 .74 .906 r
.75559 .55038 .75949 .55533 .76822 .55255 .76434 .5477 Metetra
.663 .744 .91 r
.76434 .5477 .76822 .55255 .77697 .54978 .77312 .54502 Metetra
.661 .748 .915 r
.77312 .54502 .77697 .54978 .78576 .54709 .78193 .54238 Metetra
.659 .751 .918 r
.78193 .54238 .78576 .54709 .79457 .54446 .79077 .53977 Metetra
.658 .752 .919 r
.79077 .53977 .79457 .54446 .80342 .54187 .79963 .53718 Metetra
.658 .752 .92 r
.79963 .53718 .80342 .54187 .81229 .53927 .80853 .53458 Metetra
.658 .753 .92 r
.80853 .53458 .81229 .53927 .82119 .53665 .81745 .53196 Metetra
.658 .754 .921 r
.81745 .53196 .82119 .53665 .83012 .53403 .8264 .52934 Metetra
.658 .754 .921 r
.8264 .52934 .83012 .53403 .83908 .53141 .83537 .52671 Metetra
.657 .754 .922 r
.83537 .52671 .83908 .53141 .84806 .5288 .84438 .52409 Metetra
.657 .754 .922 r
.84438 .52409 .84806 .5288 .85708 .5262 .85341 .52147 Metetra
.657 .754 .922 r
.85341 .52147 .85708 .5262 .86612 .52359 .86248 .51884 Metetra
.656 .754 .921 r
.86248 .51884 .86612 .52359 .87519 .52099 .87157 .51621 Metetra
.656 .753 .921 r
.87157 .51621 .87519 .52099 .8843 .51841 .88069 .51358 Metetra
.656 .752 .92 r
.88069 .51358 .8843 .51841 .89343 .51582 .88984 .51095 Metetra
.656 .75 .919 r
.88984 .51095 .89343 .51582 .90259 .51321 .89902 .50831 Metetra
.657 .75 .918 r
.89902 .50831 .90259 .51321 .91178 .51059 .90823 .50565 Metetra
.657 .749 .918 r
.90823 .50565 .91178 .51059 .92099 .50794 .91746 .50297 Metetra
.657 .749 .917 r
.91746 .50297 .92099 .50794 .93023 .50527 .92673 .50029 Metetra
.657 .748 .917 r
.92673 .50029 .93023 .50527 .93951 .5026 .93602 .49759 Metetra
.658 .748 .917 r
.93602 .49759 .93951 .5026 .94881 .49991 .94534 .49488 Metetra
.658 .748 .917 r
.94534 .49488 .94881 .49991 .95814 .49721 .95469 .49216 Metetra
.658 .748 .916 r
.95469 .49216 .95814 .49721 .9675 .49449 .96407 .48943 Metetra
.658 .748 .917 r
.37497 .65537 .37961 .6595 .38726 .65726 .38263 .65313 Metetra
.658 .749 .917 r
.38263 .65313 .38726 .65726 .39493 .65502 .39031 .65089 Metetra
.657 .749 .918 r
.39031 .65089 .39493 .65502 .40262 .65277 .39801 .64864 Metetra
.657 .75 .918 r
.39801 .64864 .40262 .65277 .41033 .65051 .40574 .64639 Metetra
.657 .751 .919 r
.40574 .64639 .41033 .65051 .41807 .64825 .41349 .64413 Metetra
.657 .752 .919 r
.41349 .64413 .41807 .64825 .42583 .64598 .42126 .64186 Metetra
.657 .752 .92 r
.42126 .64186 .42583 .64598 .43361 .64371 .42906 .63959 Metetra
.657 .752 .92 r
.42906 .63959 .43361 .64371 .44141 .64144 .43688 .6373 Metetra
.657 .752 .92 r
.43688 .6373 .44141 .64144 .44924 .63917 .44472 .63501 Metetra
.657 .752 .92 r
.44472 .63501 .44924 .63917 .45708 .63689 .45258 .63272 Metetra
.658 .752 .919 r
.45258 .63272 .45708 .63689 .46495 .63461 .46046 .63041 Metetra
.658 .751 .919 r
.46046 .63041 .46495 .63461 .47285 .63233 .46837 .6281 Metetra
.658 .75 .918 r
.46837 .6281 .47285 .63233 .48076 .63003 .4763 .62578 Metetra
.657 .75 .918 r
.4763 .62578 .48076 .63003 .4887 .62771 .48426 .62346 Metetra
.657 .75 .919 r
.48426 .62346 .4887 .62771 .49667 .62537 .49224 .62114 Metetra
.657 .752 .92 r
.49224 .62114 .49667 .62537 .50465 .62302 .50024 .6188 Metetra
.657 .753 .921 r
.50024 .6188 .50465 .62302 .51266 .62067 .50826 .61647 Metetra
.657 .754 .922 r
.50826 .61647 .51266 .62067 .52069 .61831 .51631 .61412 Metetra
.657 .756 .923 r
.51631 .61412 .52069 .61831 .52875 .61596 .52438 .61177 Metetra
.657 .756 .923 r
.52438 .61177 .52875 .61596 .53683 .61364 .53248 .60939 Metetra
.658 .755 .921 r
.53248 .60939 .53683 .61364 .54493 .61136 .5406 .607 Metetra
.659 .75 .917 r
.5406 .607 .54493 .61136 .55306 .60914 .54874 .60459 Metetra
.66 .742 .911 r
.54874 .60459 .55306 .60914 .56122 .60693 .55691 .60217 Metetra
.66 .734 .904 r
.55691 .60217 .56122 .60693 .56939 .60472 .5651 .59974 Metetra
.66 .725 .897 r
.5651 .59974 .56939 .60472 .5776 .60248 .57331 .59731 Metetra
.66 .718 .892 r
.57331 .59731 .5776 .60248 .58583 .60018 .58155 .59488 Metetra
.659 .713 .888 r
.58155 .59488 .58583 .60018 .59408 .59778 .58982 .59246 Metetra
.657 .712 .888 r
.58982 .59246 .59408 .59778 .60235 .59524 .59811 .59007 Metetra
.656 .718 .894 r
.59811 .59007 .60235 .59524 .61064 .59256 .60642 .58771 Metetra
.655 .731 .906 r
.60642 .58771 .61064 .59256 .61895 .58981 .61476 .58535 Metetra
.654 .749 .92 r
.61476 .58535 .61895 .58981 .62729 .58703 .62313 .58299 Metetra
.651 .769 .935 r
.62313 .58299 .62729 .58703 .63565 .58427 .63152 .58061 Metetra
.648 .788 .949 r
.63152 .58061 .63565 .58427 .64404 .58157 .63994 .57822 Metetra
.645 .805 .96 r
.63994 .57822 .64404 .58157 .65245 .57896 .64838 .57579 Metetra
.645 .815 .965 r
.64838 .57579 .65245 .57896 .6609 .57654 .65685 .57331 Metetra
.648 .814 .963 r
.65685 .57331 .6609 .57654 .66938 .57427 .66533 .57078 Metetra
.653 .802 .954 r
.66533 .57078 .66938 .57427 .67789 .5721 .67385 .56822 Metetra
.658 .784 .941 r
.67385 .56822 .67789 .5721 .68643 .56996 .68239 .56565 Metetra
.66 .763 .926 r
.68239 .56565 .68643 .56996 .69499 .5678 .69095 .56307 Metetra
.661 .745 .912 r
.69095 .56307 .69499 .5678 .70358 .5656 .69954 .56049 Metetra
.661 .729 .9 r
.69954 .56049 .70358 .5656 .7122 .56332 .70816 .55792 Metetra
.659 .718 .891 r
.70816 .55792 .7122 .56332 .72083 .56091 .7168 .55538 Metetra
.658 .713 .888 r
.7168 .55538 .72083 .56091 .72949 .55836 .72547 .55285 Metetra
.658 .714 .89 r
.72547 .55285 .72949 .55836 .73816 .55573 .73417 .55033 Metetra
.657 .719 .894 r
.73417 .55033 .73816 .55573 .74686 .55305 .7429 .54782 Metetra
.657 .726 .9 r
.7429 .54782 .74686 .55305 .75559 .55038 .75166 .54529 Metetra
.657 .733 .905 r
.75166 .54529 .75559 .55038 .76434 .5477 .76044 .54276 Metetra
.657 .74 .911 r
.76044 .54276 .76434 .5477 .77312 .54502 .76924 .54022 Metetra
.657 .746 .916 r
.76924 .54022 .77312 .54502 .78193 .54238 .77808 .53765 Metetra
.657 .75 .919 r
.77808 .53765 .78193 .54238 .79077 .53977 .78694 .53508 Metetra
.657 .752 .92 r
.78694 .53508 .79077 .53977 .79963 .53718 .79583 .53248 Metetra
.657 .753 .921 r
.79583 .53248 .79963 .53718 .80853 .53458 .80474 .52988 Metetra
.657 .754 .921 r
.80474 .52988 .80853 .53458 .81745 .53196 .81369 .52728 Metetra
.657 .755 .922 r
.81369 .52728 .81745 .53196 .8264 .52934 .82266 .52466 Metetra
.657 .756 .923 r
.82266 .52466 .8264 .52934 .83537 .52671 .83166 .52203 Metetra
.657 .756 .923 r
.83166 .52203 .83537 .52671 .84438 .52409 .84068 .5194 Metetra
.657 .757 .923 r
.84068 .5194 .84438 .52409 .85341 .52147 .84974 .51675 Metetra
.657 .756 .923 r
.84974 .51675 .85341 .52147 .86248 .51884 .85882 .5141 Metetra
.657 .756 .923 r
.85882 .5141 .86248 .51884 .87157 .51621 .86793 .51143 Metetra
.657 .755 .922 r
.86793 .51143 .87157 .51621 .88069 .51358 .87707 .50876 Metetra
.658 .753 .921 r
.87707 .50876 .88069 .51358 .88984 .51095 .88624 .50607 Metetra
.658 .752 .919 r
.88624 .50607 .88984 .51095 .89902 .50831 .89543 .50338 Metetra
.658 .75 .918 r
.89543 .50338 .89902 .50831 .90823 .50565 .90466 .50068 Metetra
.658 .749 .918 r
.90466 .50068 .90823 .50565 .91746 .50297 .91391 .49798 Metetra
.658 .749 .917 r
.91391 .49798 .91746 .50297 .92673 .50029 .9232 .49527 Metetra
.658 .748 .917 r
.9232 .49527 .92673 .50029 .93602 .49759 .93251 .49254 Metetra
.658 .748 .916 r
.93251 .49254 .93602 .49759 .94534 .49488 .94185 .48981 Metetra
.658 .748 .916 r
.94185 .48981 .94534 .49488 .95469 .49216 .95122 .48708 Metetra
.658 .747 .916 r
.95122 .48708 .95469 .49216 .96407 .48943 .96063 .48433 Metetra
.657 .748 .917 r
.3703 .65121 .37497 .65537 .38263 .65313 .37797 .64898 Metetra
.657 .748 .918 r
.37797 .64898 .38263 .65313 .39031 .65089 .38567 .64675 Metetra
.656 .749 .918 r
.38567 .64675 .39031 .65089 .39801 .64864 .39339 .64451 Metetra
.656 .75 .919 r
.39339 .64451 .39801 .64864 .40574 .64639 .40113 .64227 Metetra
.656 .751 .92 r
.40113 .64227 .40574 .64639 .41349 .64413 .40889 .64002 Metetra
.656 .753 .921 r
.40889 .64002 .41349 .64413 .42126 .64186 .41668 .63775 Metetra
.657 .753 .921 r
.41668 .63775 .42126 .64186 .42906 .63959 .42448 .63548 Metetra
.657 .754 .921 r
.42448 .63548 .42906 .63959 .43688 .6373 .43232 .63318 Metetra
.658 .754 .921 r
.43232 .63318 .43688 .6373 .44472 .63501 .44017 .63087 Metetra
.658 .754 .921 r
.44017 .63087 .44472 .63501 .45258 .63272 .44805 .62855 Metetra
.659 .753 .92 r
.44805 .62855 .45258 .63272 .46046 .63041 .45595 .62621 Metetra
.659 .752 .919 r
.45595 .62621 .46046 .63041 .46837 .6281 .46387 .62386 Metetra
.658 .751 .919 r
.46387 .62386 .46837 .6281 .4763 .62578 .47182 .62152 Metetra
.657 .75 .919 r
.47182 .62152 .4763 .62578 .48426 .62346 .47979 .6192 Metetra
.655 .751 .92 r
.47979 .6192 .48426 .62346 .49224 .62114 .48778 .6169 Metetra
.655 .752 .922 r
.48778 .6169 .49224 .62114 .50024 .6188 .4958 .61461 Metetra
.655 .755 .923 r
.4958 .61461 .50024 .6188 .50826 .61647 .50384 .6123 Metetra
.654 .757 .925 r
.50384 .6123 .50826 .61647 .51631 .61412 .5119 .60999 Metetra
.656 .759 .926 r
.5119 .60999 .51631 .61412 .52438 .61177 .51999 .60763 Metetra
.66 .761 .925 r
.51999 .60763 .52438 .61177 .53248 .60939 .5281 .60519 Metetra
.666 .76 .92 r
.5281 .60519 .53248 .60939 .5406 .607 .53624 .60263 Metetra
.672 .754 .912 r
.53624 .60263 .5406 .607 .54874 .60459 .54439 .59993 Metetra
.674 .743 .902 r
.54439 .59993 .54874 .60459 .55691 .60217 .55257 .59719 Metetra
.673 .73 .892 r
.55257 .59719 .55691 .60217 .5651 .59974 .56078 .59444 Metetra
.671 .717 .883 r
.56078 .59444 .5651 .59974 .57331 .59731 .569 .59172 Metetra
.666 .705 .876 r
.569 .59172 .57331 .59731 .58155 .59488 .57725 .58911 Metetra
.658 .696 .874 r
.57725 .58911 .58155 .59488 .58982 .59246 .58553 .58667 Metetra
.647 .692 .878 r
.58553 .58667 .58982 .59246 .59811 .59007 .59384 .58451 Metetra
.635 .696 .89 r
.59384 .58451 .59811 .59007 .60642 .58771 .60218 .58263 Metetra
.627 .713 .908 r
.60218 .58263 .60642 .58771 .61476 .58535 .61055 .58087 Metetra
.62 .738 .931 r
.61055 .58087 .61476 .58535 .62313 .58299 .61895 .57915 Metetra
.613 .768 .954 r
.61895 .57915 .62313 .58299 .63152 .58061 .62738 .57738 Metetra
.609 .8 .973 r
.62738 .57738 .63152 .58061 .63994 .57822 .63583 .57545 Metetra
.611 .829 .983 r
.63583 .57545 .63994 .57822 .64838 .57579 .64431 .57329 Metetra
.63 .85 .984 r
.64431 .57329 .64838 .57579 .65685 .57331 .65279 .57075 Metetra
.657 .855 .975 r
.65279 .57075 .65685 .57331 .66533 .57078 .66129 .56783 Metetra
.677 .839 .961 r
.66129 .56783 .66533 .57078 .67385 .56822 .6698 .5647 Metetra
.688 .811 .941 r
.6698 .5647 .67385 .56822 .68239 .56565 .67833 .56146 Metetra
.689 .779 .92 r
.67833 .56146 .68239 .56565 .69095 .56307 .68688 .55825 Metetra
.685 .75 .901 r
.68688 .55825 .69095 .56307 .69954 .56049 .69546 .5551 Metetra
.677 .725 .886 r
.69546 .5551 .69954 .56049 .70816 .55792 .70407 .5521 Metetra
.666 .705 .877 r
.70407 .5521 .70816 .55792 .7168 .55538 .71272 .54937 Metetra
.655 .695 .875 r
.71272 .54937 .7168 .55538 .72547 .55285 .72141 .54688 Metetra
.649 .695 .879 r
.72141 .54688 .72547 .55285 .73417 .55033 .73014 .54455 Metetra
.647 .701 .886 r
.73014 .54455 .73417 .55033 .7429 .54782 .7389 .54228 Metetra
.647 .711 .894 r
.7389 .54228 .7429 .54782 .75166 .54529 .74769 .53999 Metetra
.647 .721 .902 r
.74769 .53999 .75166 .54529 .76044 .54276 .7565 .53769 Metetra
.648 .731 .91 r
.7565 .53769 .76044 .54276 .76924 .54022 .76535 .53535 Metetra
.651 .742 .916 r
.76535 .53535 .76924 .54022 .77808 .53765 .77421 .53291 Metetra
.654 .75 .92 r
.77421 .53291 .77808 .53765 .78694 .53508 .7831 .53039 Metetra
.656 .754 .922 r
.7831 .53039 .78694 .53508 .79583 .53248 .79201 .52781 Metetra
.656 .755 .923 r
.79201 .52781 .79583 .53248 .80474 .52988 .80094 .52522 Metetra
.655 .755 .924 r
.80094 .52522 .80474 .52988 .81369 .52728 .80991 .52263 Metetra
.655 .757 .925 r
.80991 .52263 .81369 .52728 .82266 .52466 .8189 .52004 Metetra
.656 .759 .926 r
.8189 .52004 .82266 .52466 .83166 .52203 .82792 .51741 Metetra
.656 .76 .926 r
.82792 .51741 .83166 .52203 .84068 .5194 .83697 .51477 Metetra
.657 .761 .926 r
.83697 .51477 .84068 .5194 .84974 .51675 .84605 .5121 Metetra
.658 .76 .926 r
.84605 .5121 .84974 .51675 .85882 .5141 .85515 .50941 Metetra
.658 .76 .925 r
.85515 .50941 .85882 .5141 .86793 .51143 .86428 .5067 Metetra
.659 .759 .923 r
.86428 .5067 .86793 .51143 .87707 .50876 .87343 .50396 Metetra
.66 .757 .922 r
.87343 .50396 .87707 .50876 .88624 .50607 .88261 .5012 Metetra
.66 .754 .92 r
.88261 .5012 .88624 .50607 .89543 .50338 .89183 .49844 Metetra
.659 .752 .918 r
.89183 .49844 .89543 .50338 .90466 .50068 .90107 .49569 Metetra
.659 .75 .917 r
.90107 .49569 .90466 .50068 .91391 .49798 .91034 .49295 Metetra
.659 .749 .917 r
.91034 .49295 .91391 .49798 .9232 .49527 .91964 .4902 Metetra
.658 .748 .916 r
.91964 .4902 .9232 .49527 .93251 .49254 .92898 .48745 Metetra
.658 .747 .916 r
.92898 .48745 .93251 .49254 .94185 .48981 .93834 .4847 Metetra
.658 .747 .916 r
.93834 .4847 .94185 .48981 .95122 .48708 .94773 .48194 Metetra
.658 .747 .915 r
.94773 .48194 .95122 .48708 .96063 .48433 .95716 .47918 Metetra
.656 .747 .917 r
.36561 .64702 .3703 .65121 .37797 .64898 .37329 .6448 Metetra
.655 .748 .918 r
.37329 .6448 .37797 .64898 .38567 .64675 .381 .64258 Metetra
.655 .749 .919 r
.381 .64258 .38567 .64675 .39339 .64451 .38873 .64036 Metetra
.654 .751 .921 r
.38873 .64036 .39339 .64451 .40113 .64227 .39649 .63815 Metetra
.654 .752 .922 r
.39649 .63815 .40113 .64227 .40889 .64002 .40426 .63592 Metetra
.655 .754 .923 r
.40426 .63592 .40889 .64002 .41668 .63775 .41206 .63367 Metetra
.656 .755 .923 r
.41206 .63367 .41668 .63775 .42448 .63548 .41988 .63139 Metetra
.657 .756 .923 r
.41988 .63139 .42448 .63548 .43232 .63318 .42773 .62908 Metetra
.658 .757 .923 r
.42773 .62908 .43232 .63318 .44017 .63087 .4356 .62675 Metetra
.659 .756 .922 r
.4356 .62675 .44017 .63087 .44805 .62855 .44349 .6244 Metetra
.66 .756 .921 r
.44349 .6244 .44805 .62855 .45595 .62621 .45141 .62201 Metetra
.66 .754 .92 r
.45141 .62201 .45595 .62621 .46387 .62386 .45935 .61962 Metetra
.659 .752 .919 r
.45935 .61962 .46387 .62386 .47182 .62152 .46731 .61725 Metetra
.656 .751 .92 r
.46731 .61725 .47182 .62152 .47979 .6192 .4753 .61494 Metetra
.652 .751 .922 r
.4753 .61494 .47979 .6192 .48778 .6169 .4833 .61269 Metetra
.651 .753 .924 r
.4833 .61269 .48778 .6169 .4958 .61461 .49133 .61045 Metetra
.651 .756 .927 r
.49133 .61045 .4958 .61461 .50384 .6123 .49939 .60819 Metetra
.65 .759 .929 r
.49939 .60819 .50384 .6123 .5119 .60999 .50747 .60593 Metetra
.655 .764 .93 r
.50747 .60593 .5119 .60999 .51999 .60763 .51557 .60358 Metetra
.663 .767 .927 r
.51557 .60358 .51999 .60763 .5281 .60519 .5237 .60105 Metetra
.677 .767 .918 r
.5237 .60105 .5281 .60519 .53624 .60263 .53185 .59823 Metetra
.689 .759 .905 r
.53185 .59823 .53624 .60263 .54439 .59993 .54002 .59513 Metetra
.692 .743 .89 r
.54002 .59513 .54439 .59993 .55257 .59719 .54822 .59193 Metetra
.689 .725 .877 r
.54822 .59193 .55257 .59719 .56078 .59444 .55643 .58873 Metetra
.684 .707 .865 r
.55643 .58873 .56078 .59444 .569 .59172 .56466 .58559 Metetra
.673 .69 .858 r
.56466 .58559 .569 .59172 .57725 .58911 .57292 .58271 Metetra
.657 .676 .856 r
.57292 .58271 .57725 .58911 .58553 .58667 .58121 .58025 Metetra
.632 .665 .864 r
.58121 .58025 .58553 .58667 .59384 .58451 .58954 .57843 Metetra
.604 .666 .883 r
.58954 .57843 .59384 .58451 .60218 .58263 .59791 .57726 Metetra
.583 .685 .911 r
.59791 .57726 .60218 .58263 .61055 .58087 .60631 .57638 Metetra
.561 .717 .945 r
.60631 .57638 .61055 .58087 .61895 .57915 .61476 .5756 Metetra
.54 .758 .977 r
.61476 .5756 .61895 .57915 .62738 .57738 .62323 .57472 Metetra
.527 .804 .997 r
.62323 .57472 .62738 .57738 .63583 .57545 .63173 .5735 Metetra
.533 .847 .998 r
.63173 .5735 .63583 .57545 .64431 .57329 .64024 .57174 Metetra
.591 .89 .99 r
.64024 .57174 .64431 .57329 .65279 .57075 .64874 .56909 Metetra
.665 .907 .978 r
.64874 .56909 .65279 .57075 .66129 .56783 .65725 .5656 Metetra
.711 .888 .961 r
.65725 .5656 .66129 .56783 .6698 .5647 .66575 .56165 Metetra
.73 .847 .936 r
.66575 .56165 .6698 .5647 .67833 .56146 .67426 .55745 Metetra
.726 .798 .909 r
.67426 .55745 .67833 .56146 .68688 .55825 .68279 .55331 Metetra
.714 .755 .885 r
.68279 .55331 .68688 .55825 .69546 .5551 .69135 .54935 Metetra
.697 .72 .867 r
.69135 .54935 .69546 .5551 .70407 .5521 .69994 .54572 Metetra
.672 .69 .858 r
.69994 .54572 .70407 .5521 .71272 .54937 .70859 .54272 Metetra
.651 .673 .858 r
.70859 .54272 .71272 .54937 .72141 .54688 .7173 .54031 Metetra
.638 .67 .864 r
.7173 .54031 .72141 .54688 .73014 .54455 .72606 .53825 Metetra
.631 .677 .875 r
.72606 .53825 .73014 .54455 .7389 .54228 .73486 .53635 Metetra
.632 .691 .887 r
.73486 .53635 .7389 .54228 .74769 .53999 .74368 .53441 Metetra
.632 .705 .898 r
.74368 .53441 .74769 .53999 .7565 .53769 .75254 .53245 Metetra
.634 .72 .91 r
.75254 .53245 .7565 .53769 .76535 .53535 .76142 .53041 Metetra
.642 .737 .918 r
.76142 .53041 .76535 .53535 .77421 .53291 .77032 .52817 Metetra
.649 .749 .922 r
.77032 .52817 .77421 .53291 .7831 .53039 .77923 .52574 Metetra
.654 .755 .924 r
.77923 .52574 .7831 .53039 .79201 .52781 .78816 .52318 Metetra
.654 .757 .925 r
.78816 .52318 .79201 .52781 .80094 .52522 .79712 .5206 Metetra
.652 .758 .927 r
.79712 .5206 .80094 .52522 .80991 .52263 .80612 .51806 Metetra
.652 .761 .929 r
.80612 .51806 .80991 .52263 .8189 .52004 .81513 .51549 Metetra
.654 .763 .93 r
.81513 .51549 .8189 .52004 .82792 .51741 .82418 .51288 Metetra
.656 .765 .93 r
.82418 .51288 .82792 .51741 .83697 .51477 .83325 .51022 Metetra
.657 .766 .93 r
.83325 .51022 .83697 .51477 .84605 .5121 .84234 .50753 Metetra
.658 .766 .929 r
.84234 .50753 .84605 .5121 .85515 .50941 .85146 .5048 Metetra
.66 .766 .928 r
.85146 .5048 .85515 .50941 .86428 .5067 .86061 .50202 Metetra
.662 .764 .925 r
.86061 .50202 .86428 .5067 .87343 .50396 .86978 .49919 Metetra
.663 .761 .923 r
.86978 .49919 .87343 .50396 .88261 .5012 .87897 .49634 Metetra
.663 .757 .92 r
.87897 .49634 .88261 .5012 .89183 .49844 .8882 .49349 Metetra
.661 .753 .918 r
.8882 .49349 .89183 .49844 .90107 .49569 .89746 .49067 Metetra
.66 .75 .917 r
.89746 .49067 .90107 .49569 .91034 .49295 .90675 .48788 Metetra
.66 .749 .916 r
.90675 .48788 .91034 .49295 .91964 .4902 .91607 .48509 Metetra
.659 .747 .915 r
.91607 .48509 .91964 .4902 .92898 .48745 .92542 .48231 Metetra
.659 .746 .915 r
.92542 .48231 .92898 .48745 .93834 .4847 .93481 .47953 Metetra
.658 .746 .915 r
.93481 .47953 .93834 .4847 .94773 .48194 .94422 .47675 Metetra
.658 .745 .915 r
.94422 .47675 .94773 .48194 .95716 .47918 .95367 .47397 Metetra
.654 .747 .918 r
.36089 .6428 .36561 .64702 .37329 .6448 .36859 .6406 Metetra
.653 .748 .919 r
.36859 .6406 .37329 .6448 .381 .64258 .37631 .6384 Metetra
.653 .749 .92 r
.37631 .6384 .381 .64258 .38873 .64036 .38405 .6362 Metetra
.652 .75 .922 r
.38405 .6362 .38873 .64036 .39649 .63815 .39182 .63401 Metetra
.652 .752 .923 r
.39182 .63401 .39649 .63815 .40426 .63592 .39961 .63181 Metetra
.653 .754 .924 r
.39961 .63181 .40426 .63592 .41206 .63367 .40742 .62958 Metetra
.655 .756 .924 r
.40742 .62958 .41206 .63367 .41988 .63139 .41526 .6273 Metetra
.657 .757 .924 r
.41526 .6273 .41988 .63139 .42773 .62908 .42312 .62498 Metetra
.659 .757 .923 r
.42312 .62498 .42773 .62908 .4356 .62675 .431 .62262 Metetra
.66 .757 .922 r
.431 .62262 .4356 .62675 .44349 .6244 .43891 .62024 Metetra
.662 .757 .92 r
.43891 .62024 .44349 .6244 .45141 .62201 .44685 .6178 Metetra
.662 .755 .919 r
.44685 .6178 .45141 .62201 .45935 .61962 .4548 .61535 Metetra
.659 .753 .919 r
.4548 .61535 .45935 .61962 .46731 .61725 .46278 .61296 Metetra
.655 .751 .92 r
.46278 .61296 .46731 .61725 .4753 .61494 .47078 .61066 Metetra
.649 .75 .923 r
.47078 .61066 .4753 .61494 .4833 .61269 .4788 .60846 Metetra
.647 .753 .926 r
.4788 .60846 .4833 .61269 .49133 .61045 .48684 .60628 Metetra
.647 .756 .929 r
.48684 .60628 .49133 .61045 .49939 .60819 .49491 .60409 Metetra
.646 .759 .931 r
.49491 .60409 .49939 .60819 .50747 .60593 .50301 .60189 Metetra
.653 .765 .931 r
.50301 .60189 .50747 .60593 .51557 .60358 .51113 .59954 Metetra
.668 .77 .926 r
.51113 .59954 .51557 .60358 .5237 .60105 .51927 .59691 Metetra
.689 .771 .914 r
.51927 .59691 .5237 .60105 .53185 .59823 .52744 .59382 Metetra
.707 .763 .896 r
.52744 .59382 .53185 .59823 .54002 .59513 .53563 .59027 Metetra
.709 .746 .88 r
.53563 .59027 .54002 .59513 .54822 .59193 .54383 .58657 Metetra
.705 .726 .866 r
.54383 .58657 .54822 .59193 .55643 .58873 .55206 .58287 Metetra
.698 .707 .855 r
.55206 .58287 .55643 .58873 .56466 .58559 .5603 .57928 Metetra
.681 .688 .849 r
.5603 .57928 .56466 .58559 .57292 .58271 .56857 .5761 Metetra
.657 .67 .851 r
.56857 .5761 .57292 .58271 .58121 .58025 .57687 .57361 Metetra
.617 .653 .863 r
.57687 .57361 .58121 .58025 .58954 .57843 .58522 .57217 Metetra
.566 .644 .887 r
.58522 .57217 .58954 .57843 .59791 .57726 .59361 .57178 Metetra
.525 .657 .918 r
.59361 .57178 .59791 .57726 .60631 .57638 .60205 .57187 Metetra
.483 .683 .954 r
.60205 .57187 .60631 .57638 .61476 .5756 .61054 .57213 Metetra
.445 .722 .984 r
.61054 .57213 .61476 .5756 .62323 .57472 .61906 .57223 Metetra
.43 .772 .997 r
.61906 .57223 .62323 .57472 .63173 .5735 .6276 .57178 Metetra
.46 .829 .993 r
.6276 .57178 .63173 .5735 .64024 .57174 .63615 .57047 Metetra
.578 .899 .984 r
.63615 .57047 .64024 .57174 .64874 .56909 .64468 .56772 Metetra
.697 .929 .967 r
.64468 .56772 .64874 .56909 .65725 .5656 .65318 .5636 Metetra
.755 .906 .944 r
.65318 .5636 .65725 .5656 .66575 .56165 .66167 .55873 Metetra
.772 .86 .915 r
.66167 .55873 .66575 .56165 .67426 .55745 .67016 .55348 Metetra
.762 .808 .89 r
.67016 .55348 .67426 .55745 .68279 .55331 .67867 .54833 Metetra
.742 .762 .869 r
.67867 .54833 .68279 .55331 .69135 .54935 .68721 .54347 Metetra
.717 .723 .854 r
.68721 .54347 .69135 .54935 .69994 .54572 .69578 .53915 Metetra
.68 .688 .85 r
.69578 .53915 .69994 .54572 .70859 .54272 .70443 .53586 Metetra
.647 .666 .854 r
.70443 .53586 .70859 .54272 .7173 .54031 .71316 .53352 Metetra
.626 .659 .863 r
.71316 .53352 .7173 .54031 .72606 .53825 .72195 .53176 Metetra
.615 .664 .875 r
.72195 .53176 .72606 .53825 .73486 .53635 .73079 .53027 Metetra
.615 .679 .888 r
.73079 .53027 .73486 .53635 .74368 .53441 .73965 .52872 Metetra
.615 .694 .9 r
.73965 .52872 .74368 .53441 .75254 .53245 .74855 .52714 Metetra
.617 .711 .913 r
.74855 .52714 .75254 .53245 .76142 .53041 .75747 .52544 Metetra
.631 .732 .92 r
.75747 .52544 .76142 .53041 .77032 .52817 .76641 .5234 Metetra
.643 .747 .924 r
.76641 .5234 .77032 .52817 .77923 .52574 .77535 .52107 Metetra
.652 .755 .925 r
.77535 .52107 .77923 .52574 .78816 .52318 .7843 .51854 Metetra
.653 .758 .927 r
.7843 .51854 .78816 .52318 .79712 .5206 .79329 .51597 Metetra
.649 .758 .929 r
.79329 .51597 .79712 .5206 .80612 .51806 .8023 .51348 Metetra
.65 .761 .931 r
.8023 .51348 .80612 .51806 .81513 .51549 .81135 .51095 Metetra
.652 .764 .932 r
.81135 .51095 .81513 .51549 .82418 .51288 .82042 .50836 Metetra
.655 .767 .932 r
.82042 .50836 .82418 .51288 .83325 .51022 .82951 .50569 Metetra
.658 .768 .931 r
.82951 .50569 .83325 .51022 .84234 .50753 .83862 .50296 Metetra
.659 .768 .93 r
.83862 .50296 .84234 .50753 .85146 .5048 .84776 .50019 Metetra
.663 .768 .928 r
.84776 .50019 .85146 .5048 .86061 .50202 .85692 .49735 Metetra
.666 .767 .925 r
.85692 .49735 .86061 .50202 .86978 .49919 .86611 .49442 Metetra
.667 .763 .922 r
.86611 .49442 .86978 .49919 .87897 .49634 .87531 .49146 Metetra
.667 .759 .919 r
.87531 .49146 .87897 .49634 .8882 .49349 .88455 .48851 Metetra
.664 .754 .918 r
.88455 .48851 .8882 .49349 .89746 .49067 .89383 .48563 Metetra
.662 .751 .916 r
.89383 .48563 .89746 .49067 .90675 .48788 .90313 .48278 Metetra
.661 .749 .916 r
.90313 .48278 .90675 .48788 .91607 .48509 .91247 .47995 Metetra
.66 .748 .915 r
.91247 .47995 .91607 .48509 .92542 .48231 .92185 .47713 Metetra
.659 .746 .914 r
.92185 .47713 .92542 .48231 .93481 .47953 .93125 .47432 Metetra
.658 .745 .914 r
.93125 .47432 .93481 .47953 .94422 .47675 .94069 .47152 Metetra
.658 .745 .914 r
.94069 .47152 .94422 .47675 .95367 .47397 .95015 .46873 Metetra
.653 .746 .918 r
.35615 .63857 .36089 .6428 .36859 .6406 .36386 .63637 Metetra
.652 .747 .919 r
.36386 .63637 .36859 .6406 .37631 .6384 .37159 .63419 Metetra
.651 .748 .921 r
.37159 .63419 .37631 .6384 .38405 .6362 .37935 .63202 Metetra
.65 .75 .922 r
.37935 .63202 .38405 .6362 .39182 .63401 .38713 .62985 Metetra
.651 .751 .923 r
.38713 .62985 .39182 .63401 .39961 .63181 .39493 .62767 Metetra
.652 .753 .924 r
.39493 .62767 .39961 .63181 .40742 .62958 .40276 .62545 Metetra
.654 .755 .924 r
.40276 .62545 .40742 .62958 .41526 .6273 .41061 .62318 Metetra
.657 .756 .923 r
.41061 .62318 .41526 .6273 .42312 .62498 .41848 .62084 Metetra
.659 .757 .922 r
.41848 .62084 .42312 .62498 .431 .62262 .42638 .61846 Metetra
.661 .757 .921 r
.42638 .61846 .431 .62262 .43891 .62024 .43431 .61604 Metetra
.664 .757 .919 r
.43431 .61604 .43891 .62024 .44685 .6178 .44226 .61356 Metetra
.664 .755 .918 r
.44226 .61356 .44685 .6178 .4548 .61535 .45023 .61106 Metetra
.66 .753 .919 r
.45023 .61106 .4548 .61535 .46278 .61296 .45822 .60864 Metetra
.654 .75 .921 r
.45822 .60864 .46278 .61296 .47078 .61066 .46623 .60635 Metetra
.645 .749 .924 r
.46623 .60635 .47078 .61066 .4788 .60846 .47427 .6042 Metetra
.643 .751 .927 r
.47427 .6042 .4788 .60846 .48684 .60628 .48233 .60208 Metetra
.644 .754 .929 r
.48233 .60208 .48684 .60628 .49491 .60409 .49041 .59994 Metetra
.643 .757 .932 r
.49041 .59994 .49491 .60409 .50301 .60189 .49852 .59779 Metetra
.653 .763 .93 r
.49852 .59779 .50301 .60189 .51113 .59954 .50666 .59545 Metetra
.672 .769 .923 r
.50666 .59545 .51113 .59954 .51927 .59691 .51482 .59271 Metetra
.699 .772 .908 r
.51482 .59271 .51927 .59691 .52744 .59382 .52301 .58938 Metetra
.721 .766 .888 r
.52301 .58938 .52744 .59382 .53563 .59027 .53121 .58542 Metetra
.724 .751 .873 r
.53121 .58542 .53563 .59027 .54383 .58657 .53943 .58125 Metetra
.72 .733 .861 r
.53943 .58125 .54383 .58657 .55206 .58287 .54767 .5771 Metetra
.711 .715 .852 r
.54767 .5771 .55206 .58287 .5603 .57928 .55592 .57309 Metetra
.69 .696 .85 r
.55592 .57309 .5603 .57928 .56857 .5761 .5642 .56965 Metetra
.658 .676 .856 r
.5642 .56965 .56857 .5761 .57687 .57361 .57252 .56712 Metetra
.601 .652 .873 r
.57252 .56712 .57687 .57361 .58522 .57217 .58088 .56603 Metetra
.523 .63 .898 r
.58088 .56603 .58522 .57217 .59361 .57178 .58929 .56635 Metetra
.46 .629 .926 r
.58929 .56635 .59361 .57178 .60205 .57187 .59777 .56733 Metetra
.399 .642 .954 r
.59777 .56733 .60205 .57187 .61054 .57213 .60629 .56855 Metetra
.355 .671 .975 r
.60629 .56855 .61054 .57213 .61906 .57223 .61485 .56954 Metetra
.361 .726 .988 r
.61485 .56954 .61906 .57223 .6276 .57178 .62343 .5698 Metetra
.435 .804 .994 r
.62343 .5698 .6276 .57178 .63615 .57047 .63202 .5689 Metetra
.607 .895 .988 r
.63202 .5689 .63615 .57047 .64468 .56772 .64057 .56605 Metetra
.74 .921 .953 r
.64057 .56605 .64468 .56772 .65318 .5636 .64908 .56136 Metetra
.79 .896 .918 r
.64908 .56136 .65318 .5636 .66167 .55873 .65757 .55564 Metetra
.801 .854 .889 r
.65757 .55564 .66167 .55873 .67016 .55348 .66604 .54943 Metetra
.787 .809 .87 r
.66604 .54943 .67016 .55348 .67867 .54833 .67453 .54334 Metetra
.765 .768 .855 r
.67453 .54334 .67867 .54833 .68721 .54347 .68305 .53765 Metetra
.736 .732 .847 r
.68305 .53765 .68721 .54347 .69578 .53915 .69161 .5327 Metetra
.689 .696 .851 r
.69161 .5327 .69578 .53915 .70443 .53586 .70026 .52915 Metetra
.645 .67 .86 r
.70026 .52915 .70443 .53586 .71316 .53352 .70901 .52688 Metetra
.614 .66 .871 r
.70901 .52688 .71316 .53352 .72195 .53176 .71783 .52539 Metetra
.597 .662 .883 r
.71783 .52539 .72195 .53176 .73079 .53027 .7267 .52427 Metetra
.598 .676 .895 r
.7267 .52427 .73079 .53027 .73965 .52872 .73561 .52307 Metetra
.597 .69 .907 r
.73561 .52307 .73965 .52872 .74855 .52714 .74454 .52184 Metetra
.601 .706 .918 r
.74454 .52184 .74855 .52714 .75747 .52544 .7535 .52044 Metetra
.621 .728 .924 r
.7535 .52044 .75747 .52544 .76641 .5234 .76247 .5186 Metetra
.638 .745 .926 r
.76247 .5186 .76641 .5234 .77535 .52107 .77144 .51636 Metetra
.65 .754 .926 r
.77144 .51636 .77535 .52107 .7843 .51854 .78042 .51385 Metetra
.652 .756 .926 r
.78042 .51385 .7843 .51854 .79329 .51597 .78942 .5113 Metetra
.646 .756 .929 r
.78942 .5113 .79329 .51597 .8023 .51348 .79847 .50885 Metetra
.648 .759 .93 r
.79847 .50885 .8023 .51348 .81135 .51095 .80753 .50635 Metetra
.651 .762 .931 r
.80753 .50635 .81135 .51095 .82042 .50836 .81663 .50377 Metetra
.655 .765 .93 r
.81663 .50377 .82042 .50836 .82951 .50569 .82574 .50109 Metetra
.659 .767 .93 r
.82574 .50109 .82951 .50569 .83862 .50296 .83487 .49834 Metetra
.66 .767 .928 r
.83487 .49834 .83862 .50296 .84776 .50019 .84403 .49553 Metetra
.665 .767 .926 r
.84403 .49553 .84776 .50019 .85692 .49735 .85321 .49261 Metetra
.669 .767 .923 r
.85321 .49261 .85692 .49735 .86611 .49442 .86241 .48959 Metetra
.671 .764 .92 r
.86241 .48959 .86611 .49442 .87531 .49146 .87163 .48654 Metetra
.67 .76 .918 r
.87163 .48654 .87531 .49146 .88455 .48851 .88088 .4835 Metetra
.666 .755 .917 r
.88088 .4835 .88455 .48851 .89383 .48563 .89017 .48055 Metetra
.663 .752 .916 r
.89017 .48055 .89383 .48563 .90313 .48278 .8995 .47765 Metetra
.662 .75 .915 r
.8995 .47765 .90313 .48278 .91247 .47995 .90886 .47478 Metetra
.661 .748 .915 r
.90886 .47478 .91247 .47995 .92185 .47713 .91825 .47193 Metetra
.66 .747 .914 r
.91825 .47193 .92185 .47713 .93125 .47432 .92767 .46909 Metetra
.659 .746 .914 r
.92767 .46909 .93125 .47432 .94069 .47152 .93713 .46627 Metetra
.658 .745 .915 r
.93713 .46627 .94069 .47152 .95015 .46873 .94662 .46346 Metetra
.652 .747 .919 r
.35138 .63432 .35615 .63857 .36386 .63637 .35911 .63213 Metetra
.651 .747 .92 r
.35911 .63213 .36386 .63637 .37159 .63419 .36685 .62995 Metetra
.65 .748 .921 r
.36685 .62995 .37159 .63419 .37935 .63202 .37462 .62779 Metetra
.649 .749 .922 r
.37462 .62779 .37935 .63202 .38713 .62985 .38241 .62563 Metetra
.65 .75 .923 r
.38241 .62563 .38713 .62985 .39493 .62767 .39023 .62346 Metetra
.651 .751 .923 r
.39023 .62346 .39493 .62767 .40276 .62545 .39807 .62125 Metetra
.654 .753 .922 r
.39807 .62125 .40276 .62545 .41061 .62318 .40593 .61897 Metetra
.657 .754 .921 r
.40593 .61897 .41061 .62318 .41848 .62084 .41382 .61662 Metetra
.66 .755 .92 r
.41382 .61662 .41848 .62084 .42638 .61846 .42174 .61422 Metetra
.662 .755 .919 r
.42174 .61422 .42638 .61846 .43431 .61604 .42968 .61178 Metetra
.665 .755 .917 r
.42968 .61178 .43431 .61604 .44226 .61356 .43764 .60926 Metetra
.665 .754 .917 r
.43764 .60926 .44226 .61356 .45023 .61106 .44563 .60673 Metetra
.661 .752 .918 r
.44563 .60673 .45023 .61106 .45822 .60864 .45364 .60429 Metetra
.653 .749 .92 r
.45364 .60429 .45822 .60864 .46623 .60635 .46167 .60199 Metetra
.643 .747 .924 r
.46167 .60199 .46623 .60635 .47427 .6042 .46972 .59987 Metetra
.641 .748 .927 r
.46972 .59987 .47427 .6042 .48233 .60208 .47779 .59779 Metetra
.642 .751 .928 r
.47779 .59779 .48233 .60208 .49041 .59994 .48589 .59567 Metetra
.641 .753 .93 r
.48589 .59567 .49041 .59994 .49852 .59779 .49402 .59356 Metetra
.653 .758 .927 r
.49402 .59356 .49852 .59779 .50666 .59545 .50217 .59121 Metetra
.675 .764 .918 r
.50217 .59121 .50666 .59545 .51482 .59271 .51035 .58841 Metetra
.705 .769 .902 r
.51035 .58841 .51482 .59271 .52301 .58938 .51855 .5849 Metetra
.73 .768 .883 r
.51855 .5849 .52301 .58938 .53121 .58542 .52677 .58066 Metetra
.735 .758 .871 r
.52677 .58066 .53121 .58542 .53943 .58125 .53501 .57619 Metetra
.732 .746 .863 r
.53501 .57619 .53943 .58125 .54767 .5771 .54326 .57172 Metetra
.723 .733 .859 r
.54326 .57172 .54767 .5771 .55592 .57309 .55153 .56743 Metetra
.7 .717 .862 r
.55153 .56743 .55592 .57309 .5642 .56965 .55982 .5638 Metetra
.661 .698 .874 r
.55982 .5638 .5642 .56965 .57252 .56712 .56815 .56125 Metetra
.585 .668 .896 r
.56815 .56125 .57252 .56712 .58088 .56603 .57652 .56039 Metetra
.479 .63 .919 r
.57652 .56039 .58088 .56603 .58929 .56635 .58496 .56118 Metetra
.399 .611 .935 r
.58496 .56118 .58929 .56635 .59777 .56733 .59346 .56275 Metetra
.336 .608 .948 r
.59346 .56275 .59777 .56733 .60629 .56855 .60201 .5646 Metetra
.315 .63 .962 r
.60201 .5646 .60629 .56855 .61485 .56954 .6106 .56619 Metetra
.362 .69 .981 r
.6106 .56619 .61485 .56954 .62343 .5698 .61921 .56692 Metetra
.475 .773 .996 r
.61921 .56692 .62343 .5698 .63202 .5689 .62782 .56629 Metetra
.654 .854 .977 r
.62782 .56629 .63202 .5689 .64057 .56605 .6364 .56337 Metetra
.766 .872 .925 r
.6364 .56337 .64057 .56605 .64908 .56136 .64492 .55828 Metetra
.803 .855 .888 r
.64492 .55828 .64908 .56136 .65757 .55564 .65341 .552 Metetra
.812 .829 .864 r
.65341 .552 .65757 .55564 .66604 .54943 .66189 .54513 Metetra
.799 .801 .853 r
.66189 .54513 .66604 .54943 .67453 .54334 .67038 .53841 Metetra
.78 .774 .848 r
.67038 .53841 .67453 .54334 .68305 .53765 .67889 .53217 Metetra
.751 .748 .85 r
.67889 .53217 .68305 .53765 .69161 .5327 .68745 .5268 Metetra
.699 .718 .864 r
.68745 .5268 .69161 .5327 .70026 .52915 .69611 .52306 Metetra
.643 .691 .88 r
.69611 .52306 .70026 .52915 .70901 .52688 .70487 .52083 Metetra
.603 .676 .892 r
.70487 .52083 .70901 .52688 .71783 .52539 .71372 .51952 Metetra
.581 .674 .903 r
.71372 .51952 .71783 .52539 .7267 .52427 .72262 .51864 Metetra
.582 .684 .911 r
.72262 .51864 .7267 .52427 .73561 .52307 .73155 .51767 Metetra
.582 .694 .919 r
.73155 .51767 .73561 .52307 .74454 .52184 .74052 .51666 Metetra
.588 .707 .926 r
.74052 .51666 .74454 .52184 .7535 .52044 .74952 .51547 Metetra
.613 .728 .927 r
.74952 .51547 .7535 .52044 .76247 .5186 .75851 .51374 Metetra
.635 .742 .926 r
.75851 .51374 .76247 .5186 .77144 .51636 .7675 .51156 Metetra
.649 .751 .924 r
.7675 .51156 .77144 .51636 .78042 .51385 .7765 .50907 Metetra
.651 .753 .924 r
.7765 .50907 .78042 .51385 .78942 .5113 .78553 .50652 Metetra
.645 .751 .927 r
.78553 .50652 .78942 .5113 .79847 .50885 .7946 .50409 Metetra
.647 .754 .927 r
.7946 .50409 .79847 .50885 .80753 .50635 .80369 .50161 Metetra
.651 .757 .927 r
.80369 .50161 .80753 .50635 .81663 .50377 .8128 .49903 Metetra
.655 .76 .926 r
.8128 .49903 .81663 .50377 .82574 .50109 .82194 .49634 Metetra
.66 .761 .925 r
.82194 .49634 .82574 .50109 .83487 .49834 .83109 .49356 Metetra
.662 .762 .924 r
.83109 .49356 .83487 .49834 .84403 .49553 .84027 .49072 Metetra
.667 .763 .922 r
.84027 .49072 .84403 .49553 .85321 .49261 .84947 .48776 Metetra
.672 .763 .919 r
.84947 .48776 .85321 .49261 .86241 .48959 .85868 .48467 Metetra
.673 .762 .917 r
.85868 .48467 .86241 .48959 .87163 .48654 .86792 .48155 Metetra
.672 .759 .916 r
.86792 .48155 .87163 .48654 .88088 .4835 .87719 .47844 Metetra
.668 .755 .916 r
.87719 .47844 .88088 .4835 .89017 .48055 .8865 .47544 Metetra
.664 .752 .916 r
.8865 .47544 .89017 .48055 .8995 .47765 .89584 .4725 Metetra
.663 .75 .915 r
.89584 .4725 .8995 .47765 .90886 .47478 .90522 .4696 Metetra
.661 .749 .915 r
.90522 .4696 .90886 .47478 .91825 .47193 .91463 .46672 Metetra
.66 .748 .915 r
.91463 .46672 .91825 .47193 .92767 .46909 .92408 .46385 Metetra
.659 .747 .915 r
.92408 .46385 .92767 .46909 .93713 .46627 .93356 .46101 Metetra
.658 .747 .916 r
.93356 .46101 .93713 .46627 .94662 .46346 .94307 .45819 Metetra
.652 .747 .92 r
.34659 .63006 .35138 .63432 .35911 .63213 .35433 .62786 Metetra
.65 .747 .92 r
.35433 .62786 .35911 .63213 .36685 .62995 .36209 .62569 Metetra
.65 .747 .921 r
.36209 .62569 .36685 .62995 .37462 .62779 .36987 .62352 Metetra
.649 .748 .922 r
.36987 .62352 .37462 .62779 .38241 .62563 .37767 .62136 Metetra
.649 .748 .922 r
.37767 .62136 .38241 .62563 .39023 .62346 .3855 .61919 Metetra
.651 .749 .922 r
.3855 .61919 .39023 .62346 .39807 .62125 .39335 .61697 Metetra
.654 .75 .921 r
.39335 .61697 .39807 .62125 .40593 .61897 .40123 .61469 Metetra
.658 .752 .919 r
.40123 .61469 .40593 .61897 .41382 .61662 .40914 .61233 Metetra
.66 .752 .918 r
.40914 .61233 .41382 .61662 .42174 .61422 .41707 .60991 Metetra
.662 .753 .917 r
.41707 .60991 .42174 .61422 .42968 .61178 .42502 .60745 Metetra
.666 .753 .916 r
.42502 .60745 .42968 .61178 .43764 .60926 .433 .6049 Metetra
.666 .753 .915 r
.433 .6049 .43764 .60926 .44563 .60673 .44101 .60235 Metetra
.661 .751 .917 r
.44101 .60235 .44563 .60673 .45364 .60429 .44903 .59989 Metetra
.653 .748 .92 r
.44903 .59989 .45364 .60429 .46167 .60199 .45707 .59759 Metetra
.643 .746 .924 r
.45707 .59759 .46167 .60199 .46972 .59987 .46514 .59548 Metetra
.64 .746 .925 r
.46514 .59548 .46972 .59987 .47779 .59779 .47323 .5934 Metetra
.641 .747 .926 r
.47323 .5934 .47779 .59779 .48589 .59567 .48134 .59129 Metetra
.641 .748 .927 r
.48134 .59129 .48589 .59567 .49402 .59356 .48948 .58919 Metetra
.653 .753 .923 r
.48948 .58919 .49402 .59356 .50217 .59121 .49765 .58684 Metetra
.676 .759 .914 r
.49765 .58684 .50217 .59121 .51035 .58841 .50585 .58399 Metetra
.707 .766 .898 r
.50585 .58399 .51035 .58841 .51855 .5849 .51407 .58039 Metetra
.734 .768 .88 r
.51407 .58039 .51855 .5849 .52677 .58066 .52231 .57601 Metetra
.741 .764 .872 r
.52231 .57601 .52677 .58066 .53501 .57619 .53056 .57137 Metetra
.739 .758 .868 r
.53056 .57137 .53501 .57619 .54326 .57172 .53883 .56674 Metetra
.731 .751 .868 r
.53883 .56674 .54326 .57172 .55153 .56743 .54712 .5623 Metetra
.707 .74 .877 r
.54712 .5623 .55153 .56743 .55982 .5638 .55543 .55858 Metetra
.662 .723 .894 r
.55543 .55858 .55982 .5638 .56815 .56125 .56377 .55601 Metetra
.57 .689 .921 r
.56377 .55601 .56815 .56125 .57652 .56039 .57216 .55525 Metetra
.442 .635 .938 r
.57216 .55525 .57652 .56039 .58496 .56118 .58061 .55627 Metetra
.355 .602 .941 r
.58061 .55627 .58496 .56118 .59346 .56275 .58913 .55813 Metetra
.304 .589 .943 r
.58913 .55813 .59346 .56275 .60201 .5646 .59769 .56028 Metetra
.311 .609 .953 r
.59769 .56028 .60201 .5646 .6106 .56619 .6063 .56216 Metetra
.387 .666 .97 r
.6063 .56216 .6106 .56619 .61921 .56692 .61494 .56312 Metetra
.511 .738 .976 r
.61494 .56312 .61921 .56692 .62782 .56629 .62357 .56261 Metetra
.672 .803 .945 r
.62357 .56261 .62782 .56629 .6364 .56337 .63217 .55965 Metetra
.767 .821 .895 r
.63217 .55965 .6364 .56337 .64492 .55828 .64071 .55436 Metetra
.801 .816 .864 r
.64071 .55436 .64492 .55828 .65341 .552 .64921 .54778 Metetra
.811 .806 .846 r
.64921 .54778 .65341 .552 .66189 .54513 .6577 .54059 Metetra
.803 .793 .843 r
.6577 .54059 .66189 .54513 .67038 .53841 .6662 .53355 Metetra
.787 .779 .846 r
.6662 .53355 .67038 .53841 .67889 .53217 .67472 .52703 Metetra
.76 .764 .856 r
.67472 .52703 .67889 .53217 .68745 .5268 .6833 .52143 Metetra
.705 .741 .879 r
.6833 .52143 .68745 .5268 .69611 .52306 .69197 .5176 Metetra
.642 .715 .901 r
.69197 .5176 .69611 .52306 .70487 .52083 .70075 .51538 Metetra
.594 .697 .915 r
.70075 .51538 .70487 .52083 .71372 .51952 .70961 .51415 Metetra
.567 .689 .923 r
.70961 .51415 .71372 .51952 .72262 .51864 .71854 .51339 Metetra
.57 .696 .926 r
.71854 .51339 .72262 .51864 .73155 .51767 .7275 .51253 Metetra
.571 .702 .93 r
.7275 .51253 .73155 .51767 .74052 .51666 .73649 .51162 Metetra
.58 .711 .932 r
.73649 .51162 .74052 .51666 .74952 .51547 .74551 .51051 Metetra
.609 .728 .93 r
.74551 .51051 .74952 .51547 .75851 .51374 .75452 .50884 Metetra
.633 .741 .926 r
.75452 .50884 .75851 .51374 .7675 .51156 .76354 .50668 Metetra
.649 .748 .922 r
.76354 .50668 .7675 .51156 .7765 .50907 .77256 .50418 Metetra
.651 .75 .922 r
.77256 .50418 .7765 .50907 .78553 .50652 .78161 .50163 Metetra
.644 .748 .924 r
.78161 .50163 .78553 .50652 .7946 .50409 .7907 .49921 Metetra
.647 .749 .924 r
.7907 .49921 .7946 .50409 .80369 .50161 .79981 .49673 Metetra
.651 .752 .923 r
.79981 .49673 .80369 .50161 .8128 .49903 .80895 .49414 Metetra
.656 .754 .922 r
.80895 .49414 .8128 .49903 .82194 .49634 .8181 .49144 Metetra
.66 .756 .921 r
.8181 .49144 .82194 .49634 .83109 .49356 .82728 .48863 Metetra
.662 .756 .92 r
.82728 .48863 .83109 .49356 .84027 .49072 .83648 .48577 Metetra
.668 .758 .918 r
.83648 .48577 .84027 .49072 .84947 .48776 .8457 .48277 Metetra
.673 .759 .916 r
.8457 .48277 .84947 .48776 .85868 .48467 .85493 .47965 Metetra
.675 .759 .914 r
.85493 .47965 .85868 .48467 .86792 .48155 .86418 .47648 Metetra
.673 .757 .914 r
.86418 .47648 .86792 .48155 .87719 .47844 .87347 .47333 Metetra
.668 .754 .915 r
.87347 .47333 .87719 .47844 .8865 .47544 .8828 .47029 Metetra
.665 .752 .915 r
.8828 .47029 .8865 .47544 .89584 .4725 .89217 .46733 Metetra
.663 .751 .916 r
.89217 .46733 .89584 .4725 .90522 .4696 .90157 .4644 Metetra
.661 .75 .916 r
.90157 .4644 .90522 .4696 .91463 .46672 .911 .4615 Metetra
.66 .749 .916 r
.911 .4615 .91463 .46672 .92408 .46385 .92047 .45861 Metetra
.659 .748 .916 r
.92047 .45861 .92408 .46385 .93356 .46101 .92997 .45576 Metetra
.658 .748 .917 r
.92997 .45576 .93356 .46101 .94307 .45819 .9395 .45292 Metetra
.652 .747 .92 r
.34177 .62578 .34659 .63006 .35433 .62786 .34952 .62358 Metetra
.65 .747 .921 r
.34952 .62358 .35433 .62786 .36209 .62569 .35729 .6214 Metetra
.649 .747 .921 r
.35729 .6214 .36209 .62569 .36987 .62352 .36509 .61922 Metetra
.648 .747 .922 r
.36509 .61922 .36987 .62352 .37767 .62136 .37291 .61706 Metetra
.649 .748 .922 r
.37291 .61706 .37767 .62136 .3855 .61919 .38075 .61488 Metetra
.651 .748 .921 r
.38075 .61488 .3855 .61919 .39335 .61697 .38862 .61266 Metetra
.654 .749 .92 r
.38862 .61266 .39335 .61697 .40123 .61469 .39651 .61036 Metetra
.658 .751 .918 r
.39651 .61036 .40123 .61469 .40914 .61233 .40443 .60799 Metetra
.66 .751 .917 r
.40443 .60799 .40914 .61233 .41707 .60991 .41238 .60556 Metetra
.662 .752 .916 r
.41238 .60556 .41707 .60991 .42502 .60745 .42035 .60307 Metetra
.666 .752 .915 r
.42035 .60307 .42502 .60745 .433 .6049 .42834 .60051 Metetra
.666 .752 .915 r
.42834 .60051 .433 .6049 .44101 .60235 .43636 .59794 Metetra
.661 .751 .916 r
.43636 .59794 .44101 .60235 .44903 .59989 .4444 .59546 Metetra
.653 .748 .92 r
.4444 .59546 .44903 .59989 .45707 .59759 .45246 .59315 Metetra
.642 .745 .924 r
.45246 .59315 .45707 .59759 .46514 .59548 .46053 .59104 Metetra
.64 .745 .925 r
.46053 .59104 .46514 .59548 .47323 .5934 .46864 .58896 Metetra
.641 .746 .925 r
.46864 .58896 .47323 .5934 .48134 .59129 .47677 .58686 Metetra
.64 .746 .926 r
.47677 .58686 .48134 .59129 .48948 .58919 .48492 .58475 Metetra
.653 .751 .921 r
.48492 .58475 .48948 .58919 .49765 .58684 .49311 .58239 Metetra
.677 .757 .912 r
.49311 .58239 .49765 .58684 .50585 .58399 .50132 .57952 Metetra
.709 .765 .896 r
.50132 .57952 .50585 .58399 .51407 .58039 .50956 .57586 Metetra
.736 .768 .879 r
.50956 .57586 .51407 .58039 .52231 .57601 .51782 .57138 Metetra
.744 .767 .872 r
.51782 .57138 .52231 .57601 .53056 .57137 .52609 .56664 Metetra
.742 .763 .87 r
.52609 .56664 .53056 .57137 .53883 .56674 .53438 .56191 Metetra
.735 .758 .871 r
.53438 .56191 .53883 .56674 .54712 .5623 .54269 .55738 Metetra
.71 .75 .883 r
.54269 .55738 .54712 .5623 .55543 .55858 .55101 .5536 Metetra
.662 .734 .903 r
.55101 .5536 .55543 .55858 .56377 .55601 .55937 .55101 Metetra
.562 .697 .931 r
.55937 .55101 .56377 .55601 .57216 .55525 .56777 .55031 Metetra
.42 .635 .944 r
.56777 .55031 .57216 .55525 .58061 .55627 .57624 .55145 Metetra
.33 .594 .942 r
.57624 .55145 .58061 .55627 .58913 .55813 .58477 .55347 Metetra
.285 .578 .94 r
.58477 .55347 .58913 .55813 .59769 .56028 .59335 .55579 Metetra
.303 .597 .948 r
.59335 .55579 .59769 .56028 .6063 .56216 .60198 .55783 Metetra
.391 .654 .963 r
.60198 .55783 .6063 .56216 .61494 .56312 .61063 .55892 Metetra
.519 .722 .965 r
.61063 .55892 .61494 .56312 .62357 .56261 .61928 .55848 Metetra
.675 .783 .931 r
.61928 .55848 .62357 .56261 .63217 .55965 .6279 .55549 Metetra
.766 .803 .882 r
.6279 .55549 .63217 .55965 .64071 .55436 .63646 .55008 Metetra
.8 .802 .854 r
.63646 .55008 .64071 .55436 .64921 .54778 .64498 .54333 Metetra
.811 .797 .839 r
.64498 .54333 .64921 .54778 .6577 .54059 .65349 .53593 Metetra
.805 .789 .838 r
.65349 .53593 .6577 .54059 .6662 .53355 .662 .5287 Metetra
.791 .781 .844 r
.662 .5287 .6662 .53355 .67472 .52703 .67054 .522 Metetra
.765 .771 .857 r
.67054 .522 .67472 .52703 .6833 .52143 .67913 .51628 Metetra
.708 .751 .886 r
.67913 .51628 .6833 .52143 .69197 .5176 .68782 .51238 Metetra
.64 .726 .91 r
.68782 .51238 .69197 .5176 .70075 .51538 .69662 .51016 Metetra
.588 .705 .924 r
.69662 .51016 .70075 .51538 .70961 .51415 .7055 .50897 Metetra
.56 .695 .931 r
.7055 .50897 .70961 .51415 .71854 .51339 .71445 .50826 Metetra
.564 .701 .933 r
.71445 .50826 .71854 .51339 .7275 .51253 .72343 .50746 Metetra
.565 .704 .935 r
.72343 .50746 .7275 .51253 .73649 .51162 .73244 .50661 Metetra
.576 .712 .935 r
.73244 .50661 .73649 .51162 .74551 .51051 .74148 .50555 Metetra
.607 .728 .931 r
.74148 .50555 .74551 .51051 .75452 .50884 .75052 .50391 Metetra
.632 .74 .926 r
.75052 .50391 .75452 .50884 .76354 .50668 .75955 .50175 Metetra
.649 .747 .921 r
.75955 .50175 .76354 .50668 .77256 .50418 .76859 .49924 Metetra
.651 .748 .921 r
.76859 .49924 .77256 .50418 .78161 .50163 .77766 .49668 Metetra
.644 .746 .923 r
.77766 .49668 .78161 .50163 .7907 .49921 .78677 .49425 Metetra
.646 .747 .923 r
.78677 .49425 .7907 .49921 .79981 .49673 .79591 .49176 Metetra
.651 .75 .922 r
.79591 .49176 .79981 .49673 .80895 .49414 .80506 .48916 Metetra
.656 .752 .92 r
.80506 .48916 .80895 .49414 .8181 .49144 .81424 .48645 Metetra
.66 .754 .919 r
.81424 .48645 .8181 .49144 .82728 .48863 .82344 .48363 Metetra
.663 .754 .918 r
.82344 .48363 .82728 .48863 .83648 .48577 .83266 .48074 Metetra
.668 .756 .916 r
.83266 .48074 .83648 .48577 .8457 .48277 .84189 .47772 Metetra
.674 .758 .914 r
.84189 .47772 .8457 .48277 .85493 .47965 .85115 .47456 Metetra
.675 .758 .913 r
.85115 .47456 .85493 .47965 .86418 .47648 .86042 .47136 Metetra
.674 .757 .913 r
.86042 .47136 .86418 .47648 .87347 .47333 .86973 .46819 Metetra
.669 .754 .914 r
.86973 .46819 .87347 .47333 .8828 .47029 .87908 .46512 Metetra
.665 .752 .915 r
.87908 .46512 .8828 .47029 .89217 .46733 .88847 .46213 Metetra
.663 .751 .916 r
.88847 .46213 .89217 .46733 .90157 .4644 .89789 .45918 Metetra
.661 .75 .916 r
.89789 .45918 .90157 .4644 .911 .4615 .90735 .45626 Metetra
.66 .75 .916 r
.90735 .45626 .911 .4615 .92047 .45861 .91683 .45336 Metetra
.659 .749 .917 r
.91683 .45336 .92047 .45861 .92997 .45576 .92636 .45048 Metetra
.658 .748 .917 r
.92636 .45048 .92997 .45576 .9395 .45292 .93592 .44762 Metetra
.652 .748 .92 r
.33692 .62149 .34177 .62578 .34952 .62358 .34469 .61928 Metetra
.65 .747 .921 r
.34469 .61928 .34952 .62358 .35729 .6214 .35248 .61708 Metetra
.649 .747 .921 r
.35248 .61708 .35729 .6214 .36509 .61922 .36028 .61489 Metetra
.649 .747 .921 r
.36028 .61489 .36509 .61922 .37291 .61706 .36812 .61271 Metetra
.649 .747 .921 r
.36812 .61271 .37291 .61706 .38075 .61488 .37597 .61052 Metetra
.651 .747 .92 r
.37597 .61052 .38075 .61488 .38862 .61266 .38386 .60828 Metetra
.654 .748 .919 r
.38386 .60828 .38862 .61266 .39651 .61036 .39176 .60597 Metetra
.658 .749 .917 r
.39176 .60597 .39651 .61036 .40443 .60799 .3997 .60358 Metetra
.66 .749 .916 r
.3997 .60358 .40443 .60799 .41238 .60556 .40766 .60114 Metetra
.662 .75 .915 r
.40766 .60114 .41238 .60556 .42035 .60307 .41564 .59864 Metetra
.666 .751 .914 r
.41564 .59864 .42035 .60307 .42834 .60051 .42365 .59607 Metetra
.666 .751 .914 r
.42365 .59607 .42834 .60051 .43636 .59794 .43169 .59349 Metetra
.661 .75 .916 r
.43169 .59349 .43636 .59794 .4444 .59546 .43974 .591 Metetra
.653 .748 .919 r
.43974 .591 .4444 .59546 .45246 .59315 .44781 .58868 Metetra
.642 .745 .923 r
.44781 .58868 .45246 .59315 .46053 .59104 .45591 .58654 Metetra
.64 .744 .924 r
.45591 .58654 .46053 .59104 .46864 .58896 .46403 .58445 Metetra
.641 .744 .923 r
.46403 .58445 .46864 .58896 .47677 .58686 .47217 .58232 Metetra
.641 .743 .923 r
.47217 .58232 .47677 .58686 .48492 .58475 .48034 .5802 Metetra
.654 .747 .918 r
.48034 .5802 .48492 .58475 .49311 .58239 .48854 .57782 Metetra
.676 .753 .909 r
.48854 .57782 .49311 .58239 .50132 .57952 .49677 .57494 Metetra
.708 .761 .894 r
.49677 .57494 .50132 .57952 .50956 .57586 .50503 .57129 Metetra
.735 .768 .879 r
.50503 .57129 .50956 .57586 .51782 .57138 .51331 .56682 Metetra
.744 .771 .875 r
.51331 .56682 .51782 .57138 .52609 .56664 .5216 .5621 Metetra
.743 .772 .876 r
.5216 .5621 .52609 .56664 .53438 .56191 .52991 .55739 Metetra
.737 .772 .881 r
.52991 .55739 .53438 .56191 .54269 .55738 .53823 .55287 Metetra
.712 .768 .897 r
.53823 .55287 .54269 .55738 .55101 .5536 .54657 .54909 Metetra
.661 .755 .92 r
.54657 .54909 .55101 .5536 .55937 .55101 .55495 .54649 Metetra
.553 .717 .949 r
.55495 .54649 .55937 .55101 .56777 .55031 .56337 .54575 Metetra
.403 .647 .956 r
.56337 .54575 .56777 .55031 .57624 .55145 .57185 .54683 Metetra
.321 .6 .947 r
.57185 .54683 .57624 .55145 .58477 .55347 .58038 .54877 Metetra
.294 .582 .941 r
.58038 .54877 .58477 .55347 .59335 .55579 .58898 .55102 Metetra
.331 .599 .944 r
.58898 .55102 .59335 .55579 .60198 .55783 .59761 .55298 Metetra
.424 .645 .949 r
.59761 .55298 .60198 .55783 .61063 .55892 .60628 .55401 Metetra
.541 .697 .941 r
.60628 .55401 .61063 .55892 .61928 .55848 .61495 .55352 Metetra
.676 .747 .904 r
.61495 .55352 .61928 .55848 .6279 .55549 .62358 .55052 Metetra
.756 .769 .863 r
.62358 .55052 .6279 .55549 .63646 .55008 .63216 .54513 Metetra
.789 .776 .841 r
.63216 .54513 .63646 .55008 .64498 .54333 .64071 .53842 Metetra
.803 .78 .832 r
.64071 .53842 .64498 .54333 .65349 .53593 .64924 .53108 Metetra
.801 .783 .836 r
.64924 .53108 .65349 .53593 .662 .5287 .65778 .52389 Metetra
.791 .784 .846 r
.65778 .52389 .662 .5287 .67054 .522 .66634 .51724 Metetra
.768 .782 .865 r
.66634 .51724 .67054 .522 .67913 .51628 .67496 .51153 Metetra
.71 .77 .899 r
.67496 .51153 .67913 .51628 .68782 .51238 .68367 .50764 Metetra
.638 .747 .928 r
.68367 .50764 .68782 .51238 .69662 .51016 .69249 .5054 Metetra
.582 .725 .941 r
.69249 .5054 .69662 .51016 .7055 .50897 .70138 .50418 Metetra
.553 .712 .945 r
.70138 .50418 .7055 .50897 .71445 .50826 .71035 .50343 Metetra
.559 .713 .944 r
.71035 .50343 .71445 .50826 .72343 .50746 .71934 .50258 Metetra
.563 .713 .942 r
.71934 .50258 .72343 .50746 .73244 .50661 .72837 .50169 Metetra
.575 .717 .939 r
.72837 .50169 .73244 .50661 .74148 .50555 .73743 .5006 Metetra
.607 .73 .932 r
.73743 .5006 .74148 .50555 .75052 .50391 .74648 .49892 Metetra
.633 .74 .925 r
.74648 .49892 .75052 .50391 .75955 .50175 .75554 .49674 Metetra
.649 .745 .92 r
.75554 .49674 .75955 .50175 .76859 .49924 .7646 .49422 Metetra
.651 .746 .919 r
.7646 .49422 .76859 .49924 .77766 .49668 .77369 .49163 Metetra
.645 .743 .921 r
.77369 .49163 .77766 .49668 .78677 .49425 .78282 .48919 Metetra
.647 .744 .92 r
.78282 .48919 .78677 .49425 .79591 .49176 .79197 .48668 Metetra
.652 .746 .919 r
.79197 .48668 .79591 .49176 .80506 .48916 .80115 .48407 Metetra
.656 .748 .917 r
.80115 .48407 .80506 .48916 .81424 .48645 .81034 .48133 Metetra
.661 .749 .916 r
.81034 .48133 .81424 .48645 .82344 .48363 .81956 .47849 Metetra
.663 .75 .915 r
.81956 .47849 .82344 .48363 .83266 .48074 .8288 .4756 Metetra
.668 .752 .913 r
.8288 .4756 .83266 .48074 .84189 .47772 .83806 .47256 Metetra
.673 .755 .912 r
.83806 .47256 .84189 .47772 .85115 .47456 .84734 .46939 Metetra
.675 .755 .911 r
.84734 .46939 .85115 .47456 .86042 .47136 .85664 .46618 Metetra
.673 .755 .912 r
.85664 .46618 .86042 .47136 .86973 .46819 .86597 .46299 Metetra
.669 .753 .914 r
.86597 .46299 .86973 .46819 .87908 .46512 .87534 .45991 Metetra
.665 .752 .915 r
.87534 .45991 .87908 .46512 .88847 .46213 .88475 .45691 Metetra
.663 .751 .916 r
.88475 .45691 .88847 .46213 .89789 .45918 .89419 .45395 Metetra
.661 .751 .916 r
.89419 .45395 .89789 .45918 .90735 .45626 .90367 .45101 Metetra
.66 .75 .917 r
.90367 .45101 .90735 .45626 .91683 .45336 .91318 .44809 Metetra
.659 .75 .917 r
.91318 .44809 .91683 .45336 .92636 .45048 .92273 .4452 Metetra
.657 .749 .918 r
.92273 .4452 .92636 .45048 .93592 .44762 .93231 .44232 Metetra
.652 .748 .92 r
.33205 .61719 .33692 .62149 .34469 .61928 .33983 .61495 Metetra
.651 .748 .92 r
.33983 .61495 .34469 .61928 .35248 .61708 .34763 .61273 Metetra
.65 .747 .92 r
.34763 .61273 .35248 .61708 .36028 .61489 .35545 .61052 Metetra
.649 .746 .92 r
.35545 .61052 .36028 .61489 .36812 .61271 .3633 .60831 Metetra
.65 .746 .92 r
.3633 .60831 .36812 .61271 .37597 .61052 .37117 .60609 Metetra
.652 .746 .918 r
.37117 .60609 .37597 .61052 .38386 .60828 .37907 .60383 Metetra
.654 .746 .917 r
.37907 .60383 .38386 .60828 .39176 .60597 .38699 .60151 Metetra
.658 .747 .915 r
.38699 .60151 .39176 .60597 .3997 .60358 .39494 .59911 Metetra
.66 .747 .915 r
.39494 .59911 .3997 .60358 .40766 .60114 .40292 .59665 Metetra
.662 .748 .914 r
.40292 .59665 .40766 .60114 .41564 .59864 .41092 .59415 Metetra
.665 .749 .913 r
.41092 .59415 .41564 .59864 .42365 .59607 .41894 .59158 Metetra
.665 .75 .913 r
.41894 .59158 .42365 .59607 .43169 .59349 .42699 .589 Metetra
.661 .749 .915 r
.42699 .589 .43169 .59349 .43974 .591 .43506 .5865 Metetra
.653 .747 .919 r
.43506 .5865 .43974 .591 .44781 .58868 .44315 .58415 Metetra
.644 .744 .922 r
.44315 .58415 .44781 .58868 .45591 .58654 .45125 .58199 Metetra
.642 .742 .922 r
.45125 .58199 .45591 .58654 .46403 .58445 .45939 .57985 Metetra
.643 .742 .921 r
.45939 .57985 .46403 .58445 .47217 .58232 .46755 .57769 Metetra
.643 .741 .92 r
.46755 .57769 .47217 .58232 .48034 .5802 .47574 .57553 Metetra
.654 .743 .915 r
.47574 .57553 .48034 .5802 .48854 .57782 .48395 .57313 Metetra
.675 .749 .906 r
.48395 .57313 .48854 .57782 .49677 .57494 .4922 .57027 Metetra
.704 .757 .893 r
.4922 .57027 .49677 .57494 .50503 .57129 .50047 .56668 Metetra
.731 .767 .882 r
.50047 .56668 .50503 .57129 .51331 .56682 .50877 .56235 Metetra
.74 .774 .881 r
.50877 .56235 .51331 .56682 .5216 .5621 .51708 .55777 Metetra
.74 .781 .886 r
.51708 .55777 .5216 .5621 .52991 .55739 .52541 .5532 Metetra
.735 .787 .894 r
.52541 .5532 .52991 .55739 .53823 .55287 .53375 .54881 Metetra
.71 .789 .913 r
.53375 .54881 .53823 .55287 .54657 .54909 .54212 .54511 Metetra
.658 .781 .939 r
.54212 .54511 .54657 .54909 .55495 .54649 .55051 .5425 Metetra
.547 .743 .967 r
.55051 .5425 .55495 .54649 .56337 .54575 .55894 .54161 Metetra
.402 .67 .969 r
.55894 .54161 .56337 .54575 .57185 .54683 .56743 .54243 Metetra
.338 .623 .956 r
.56743 .54243 .57185 .54683 .58038 .54877 .57598 .54403 Metetra
.333 .603 .946 r
.57598 .54403 .58038 .54877 .58898 .55102 .58457 .54592 Metetra
.381 .611 .941 r
.58457 .54592 .58898 .55102 .59761 .55298 .59321 .54754 Metetra
.468 .641 .932 r
.59321 .54754 .59761 .55298 .60628 .55401 .60188 .5483 Metetra
.565 .674 .913 r
.60188 .5483 .60628 .55401 .61495 .55352 .61056 .54765 Metetra
.672 .711 .878 r
.61056 .54765 .61495 .55352 .62358 .55052 .61921 .54466 Metetra
.741 .734 .845 r
.61921 .54466 .62358 .55052 .63216 .54513 .62782 .53946 Metetra
.773 .749 .831 r
.62782 .53946 .63216 .54513 .64071 .53842 .6364 .53303 Metetra
.789 .762 .828 r
.6364 .53303 .64071 .53842 .64924 .53108 .64496 .52601 Metetra
.791 .774 .838 r
.64496 .52601 .64924 .53108 .65778 .52389 .65354 .51914 Metetra
.785 .786 .853 r
.65354 .51914 .65778 .52389 .66634 .51724 .66214 .51275 Metetra
.765 .794 .877 r
.66214 .51275 .66634 .51724 .67496 .51153 .67078 .50725 Metetra
.708 .791 .916 r
.67078 .50725 .67496 .51153 .68367 .50764 .67952 .50343 Metetra
.634 .773 .946 r
.67952 .50343 .68367 .50764 .69249 .5054 .68836 .50115 Metetra
.578 .75 .959 r
.68836 .50115 .69249 .5054 .70138 .50418 .69727 .49981 Metetra
.551 .733 .96 r
.69727 .49981 .70138 .50418 .71035 .50343 .70624 .49891 Metetra
.56 .73 .954 r
.70624 .49891 .71035 .50343 .71934 .50258 .71525 .49792 Metetra
.566 .726 .949 r
.71525 .49792 .71934 .50258 .72837 .50169 .72429 .49688 Metetra
.579 .725 .943 r
.72429 .49688 .72837 .50169 .73743 .5006 .73336 .49566 Metetra
.611 .733 .932 r
.73336 .49566 .73743 .5006 .74648 .49892 .74243 .49389 Metetra
.635 .739 .924 r
.74243 .49389 .74648 .49892 .75554 .49674 .7515 .49165 Metetra
.65 .744 .918 r
.7515 .49165 .75554 .49674 .7646 .49422 .76058 .4891 Metetra
.652 .744 .917 r
.76058 .4891 .7646 .49422 .77369 .49163 .76968 .48649 Metetra
.646 .741 .918 r
.76968 .48649 .77369 .49163 .78282 .48919 .77883 .48401 Metetra
.648 .741 .917 r
.77883 .48401 .78282 .48919 .79197 .48668 .788 .48147 Metetra
.652 .742 .915 r
.788 .48147 .79197 .48668 .80115 .48407 .7972 .47883 Metetra
.657 .743 .914 r
.7972 .47883 .80115 .48407 .81034 .48133 .80642 .47608 Metetra
.661 .745 .912 r
.80642 .47608 .81034 .48133 .81956 .47849 .81566 .47323 Metetra
.663 .746 .912 r
.81566 .47323 .81956 .47849 .8288 .4756 .82492 .47032 Metetra
.668 .748 .91 r
.82492 .47032 .8288 .4756 .83806 .47256 .8342 .46729 Metetra
.672 .751 .909 r
.8342 .46729 .83806 .47256 .84734 .46939 .8435 .46413 Metetra
.674 .752 .91 r
.8435 .46413 .84734 .46939 .85664 .46618 .85283 .46093 Metetra
.672 .753 .911 r
.85283 .46093 .85664 .46618 .86597 .46299 .86218 .45775 Metetra
.668 .752 .914 r
.86218 .45775 .86597 .46299 .87534 .45991 .87158 .45467 Metetra
.664 .752 .915 r
.87158 .45467 .87534 .45991 .88475 .45691 .88101 .45167 Metetra
.663 .752 .916 r
.88101 .45167 .88475 .45691 .89419 .45395 .89048 .4487 Metetra
.661 .751 .917 r
.89048 .4487 .89419 .45395 .90367 .45101 .89998 .44575 Metetra
.66 .751 .918 r
.89998 .44575 .90367 .45101 .91318 .44809 .90951 .44281 Metetra
.658 .751 .918 r
.90951 .44281 .91318 .44809 .92273 .4452 .91908 .4399 Metetra
.657 .75 .918 r
.91908 .4399 .92273 .4452 .93231 .44232 .92869 .43701 Metetra
.653 .749 .92 r
.32715 .61287 .33205 .61719 .33983 .61495 .33495 .6106 Metetra
.652 .748 .92 r
.33495 .6106 .33983 .61495 .34763 .61273 .34276 .60835 Metetra
.651 .747 .92 r
.34276 .60835 .34763 .61273 .35545 .61052 .3506 .60611 Metetra
.651 .746 .919 r
.3506 .60611 .35545 .61052 .3633 .60831 .35846 .60387 Metetra
.651 .745 .918 r
.35846 .60387 .3633 .60831 .37117 .60609 .36635 .60161 Metetra
.653 .744 .917 r
.36635 .60161 .37117 .60609 .37907 .60383 .37426 .59932 Metetra
.655 .744 .915 r
.37426 .59932 .37907 .60383 .38699 .60151 .3822 .59698 Metetra
.658 .745 .914 r
.3822 .59698 .38699 .60151 .39494 .59911 .39016 .59456 Metetra
.66 .745 .913 r
.39016 .59456 .39494 .59911 .40292 .59665 .39815 .5921 Metetra
.662 .746 .913 r
.39815 .5921 .40292 .59665 .41092 .59415 .40616 .5896 Metetra
.664 .747 .912 r
.40616 .5896 .41092 .59415 .41894 .59158 .4142 .58703 Metetra
.664 .748 .913 r
.4142 .58703 .41894 .59158 .42699 .589 .42226 .58446 Metetra
.66 .748 .915 r
.42226 .58446 .42699 .589 .43506 .5865 .43035 .58196 Metetra
.654 .747 .918 r
.43035 .58196 .43506 .5865 .44315 .58415 .43845 .57959 Metetra
.646 .744 .921 r
.43845 .57959 .44315 .58415 .45125 .58199 .44658 .57737 Metetra
.644 .742 .92 r
.44658 .57737 .45125 .58199 .45939 .57985 .45473 .57518 Metetra
.645 .74 .918 r
.45473 .57518 .45939 .57985 .46755 .57769 .4629 .57296 Metetra
.645 .738 .917 r
.4629 .57296 .46755 .57769 .47574 .57553 .47111 .57074 Metetra
.655 .739 .912 r
.47111 .57074 .47574 .57553 .48395 .57313 .47934 .56832 Metetra
.673 .744 .904 r
.47934 .56832 .48395 .57313 .4922 .57027 .4876 .5655 Metetra
.698 .753 .894 r
.4876 .5655 .4922 .57027 .50047 .56668 .49589 .56204 Metetra
.722 .765 .886 r
.49589 .56204 .50047 .56668 .50877 .56235 .5042 .55795 Metetra
.731 .777 .89 r
.5042 .55795 .50877 .56235 .51708 .55777 .51253 .55364 Metetra
.733 .79 .898 r
.51253 .55364 .51708 .55777 .52541 .5532 .52088 .54934 Metetra
.728 .802 .91 r
.52088 .54934 .52541 .5532 .53375 .54881 .52925 .54519 Metetra
.703 .81 .931 r
.52925 .54519 .53375 .54881 .54212 .54511 .53763 .54164 Metetra
.653 .806 .957 r
.53763 .54164 .54212 .54511 .55051 .5425 .54604 .53902 Metetra
.548 .772 .981 r
.54604 .53902 .55051 .5425 .55894 .54161 .55449 .5379 Metetra
.423 .704 .981 r
.55449 .5379 .55894 .54161 .56743 .54243 .56299 .53823 Metetra
.383 .659 .967 r
.56299 .53823 .56743 .54243 .57598 .54403 .57154 .53925 Metetra
.395 .635 .952 r
.57154 .53925 .57598 .54403 .58457 .54592 .58014 .54051 Metetra
.444 .631 .934 r
.58014 .54051 .58457 .54592 .59321 .54754 .58878 .54154 Metetra
.514 .64 .911 r
.58878 .54154 .59321 .54754 .60188 .5483 .59745 .54181 Metetra
.586 .656 .885 r
.59745 .54181 .60188 .5483 .61056 .54765 .60613 .54088 Metetra
.667 .681 .854 r
.60613 .54088 .61056 .54765 .61921 .54466 .6148 .53793 Metetra
.723 .703 .831 r
.6148 .53793 .61921 .54466 .62782 .53946 .62343 .53308 Metetra
.752 .723 .825 r
.62343 .53308 .62782 .53946 .6364 .53303 .63205 .52716 Metetra
.77 .744 .829 r
.63205 .52716 .6364 .53303 .64496 .52601 .64065 .52073 Metetra
.776 .765 .844 r
.64065 .52073 .64496 .52601 .65354 .51914 .64927 .51443 Metetra
.773 .787 .864 r
.64927 .51443 .65354 .51914 .66214 .51275 .65792 .50854 Metetra
.756 .806 .893 r
.65792 .50854 .66214 .51275 .67078 .50725 .66661 .50342 Metetra
.701 .812 .934 r
.66661 .50342 .67078 .50725 .67952 .50343 .67537 .49974 Metetra
.63 .799 .964 r
.67537 .49974 .67952 .50343 .68836 .50115 .68423 .49739 Metetra
.577 .777 .974 r
.68423 .49739 .68836 .50115 .69727 .49981 .69315 .49585 Metetra
.556 .758 .972 r
.69315 .49585 .69727 .49981 .70624 .49891 .70213 .49469 Metetra
.568 .75 .963 r
.70213 .49469 .70624 .49891 .71525 .49792 .71114 .49345 Metetra
.575 .741 .955 r
.71114 .49345 .71525 .49792 .72429 .49688 .72019 .49217 Metetra
.589 .736 .945 r
.72019 .49217 .72429 .49688 .73336 .49566 .72926 .49072 Metetra
.617 .738 .932 r
.72926 .49072 .73336 .49566 .74243 .49389 .73834 .48881 Metetra
.638 .74 .922 r
.73834 .48881 .74243 .49389 .7515 .49165 .74743 .48649 Metetra
.651 .742 .916 r
.74743 .48649 .7515 .49165 .76058 .4891 .75653 .4839 Metetra
.653 .742 .915 r
.75653 .4839 .76058 .4891 .76968 .48649 .76565 .48126 Metetra
.648 .739 .916 r
.76565 .48126 .76968 .48649 .77883 .48401 .77482 .47872 Metetra
.65 .738 .914 r
.77482 .47872 .77883 .48401 .788 .48147 .78401 .47613 Metetra
.653 .738 .912 r
.78401 .47613 .788 .48147 .7972 .47883 .79322 .47346 Metetra
.657 .739 .91 r
.79322 .47346 .7972 .47883 .80642 .47608 .80246 .47069 Metetra
.66 .74 .909 r
.80246 .47069 .80642 .47608 .81566 .47323 .81172 .46783 Metetra
.662 .741 .909 r
.81172 .46783 .81566 .47323 .82492 .47032 .82101 .46492 Metetra
.666 .743 .908 r
.82101 .46492 .82492 .47032 .8342 .46729 .83031 .4619 Metetra
.67 .746 .908 r
.83031 .4619 .8342 .46729 .8435 .46413 .83964 .45878 Metetra
.672 .749 .909 r
.83964 .45878 .8435 .46413 .85283 .46093 .84899 .45561 Metetra
.67 .751 .911 r
.84899 .45561 .85283 .46093 .86218 .45775 .85837 .45246 Metetra
.666 .751 .914 r
.85837 .45246 .86218 .45775 .87158 .45467 .86779 .4494 Metetra
.663 .751 .916 r
.86779 .4494 .87158 .45467 .88101 .45167 .87725 .4464 Metetra
.662 .752 .917 r
.87725 .4464 .88101 .45167 .89048 .4487 .88674 .44343 Metetra
.661 .752 .918 r
.88674 .44343 .89048 .4487 .89998 .44575 .89626 .44047 Metetra
.66 .752 .918 r
.89626 .44047 .89998 .44575 .90951 .44281 .90582 .43753 Metetra
.658 .752 .919 r
.90582 .43753 .90951 .44281 .91908 .4399 .91542 .43461 Metetra
.657 .751 .919 r
.91542 .43461 .91908 .4399 .92869 .43701 .92504 .4317 Metetra
.654 .749 .92 r
.32223 .60853 .32715 .61287 .33495 .6106 .33003 .60624 Metetra
.653 .748 .92 r
.33003 .60624 .33495 .6106 .34276 .60835 .33786 .60395 Metetra
.652 .747 .919 r
.33786 .60395 .34276 .60835 .3506 .60611 .34572 .60167 Metetra
.652 .746 .918 r
.34572 .60167 .3506 .60611 .35846 .60387 .3536 .59939 Metetra
.652 .745 .917 r
.3536 .59939 .35846 .60387 .36635 .60161 .3615 .59709 Metetra
.654 .744 .916 r
.3615 .59709 .36635 .60161 .37426 .59932 .36942 .59477 Metetra
.656 .744 .915 r
.36942 .59477 .37426 .59932 .3822 .59698 .37738 .5924 Metetra
.658 .744 .913 r
.37738 .5924 .3822 .59698 .39016 .59456 .38535 .58997 Metetra
.66 .744 .913 r
.38535 .58997 .39016 .59456 .39815 .5921 .39336 .58751 Metetra
.661 .745 .912 r
.39336 .58751 .39815 .5921 .40616 .5896 .40138 .58501 Metetra
.663 .746 .912 r
.40138 .58501 .40616 .5896 .4142 .58703 .40944 .58245 Metetra
.663 .747 .913 r
.40944 .58245 .4142 .58703 .42226 .58446 .41751 .57989 Metetra
.66 .748 .915 r
.41751 .57989 .42226 .58446 .43035 .58196 .42561 .57739 Metetra
.655 .747 .917 r
.42561 .57739 .43035 .58196 .43845 .57959 .43373 .57499 Metetra
.648 .744 .919 r
.43373 .57499 .43845 .57959 .44658 .57737 .44187 .57271 Metetra
.647 .742 .918 r
.44187 .57271 .44658 .57737 .45473 .57518 .45004 .57045 Metetra
.648 .74 .916 r
.45004 .57045 .45473 .57518 .4629 .57296 .45823 .56817 Metetra
.648 .737 .915 r
.45823 .56817 .4629 .57296 .47111 .57074 .46645 .56588 Metetra
.656 .738 .91 r
.46645 .56588 .47111 .57074 .47934 .56832 .4747 .56343 Metetra
.67 .741 .904 r
.4747 .56343 .47934 .56832 .4876 .5655 .48297 .56066 Metetra
.691 .75 .897 r
.48297 .56066 .4876 .5655 .49589 .56204 .49128 .55738 Metetra
.711 .762 .892 r
.49128 .55738 .49589 .56204 .5042 .55795 .49961 .55357 Metetra
.719 .777 .898 r
.49961 .55357 .5042 .55795 .51253 .55364 .50796 .5496 Metetra
.72 .793 .909 r
.50796 .5496 .51253 .55364 .52088 .54934 .51633 .54563 Metetra
.716 .808 .922 r
.51633 .54563 .52088 .54934 .52925 .54519 .52471 .54178 Metetra
.693 .819 .942 r
.52471 .54178 .52925 .54519 .53763 .54164 .53312 .5384 Metetra
.648 .818 .965 r
.53312 .5384 .53763 .54164 .54604 .53902 .54155 .53578 Metetra
.561 .791 .985 r
.54155 .53578 .54604 .53902 .55449 .5379 .55002 .53437 Metetra
.467 .737 .986 r
.55002 .53437 .55449 .5379 .56299 .53823 .55853 .53413 Metetra
.445 .696 .973 r
.55853 .53413 .56299 .53823 .57154 .53925 .56708 .53443 Metetra
.461 .668 .952 r
.56708 .53443 .57154 .53925 .58014 .54051 .57568 .53493 Metetra
.5 .652 .926 r
.57568 .53493 .58014 .54051 .58878 .54154 .58432 .53524 Metetra
.551 .647 .898 r
.58432 .53524 .58878 .54154 .59745 .54181 .59299 .53494 Metetra
.602 .651 .871 r
.59299 .53494 .59745 .54181 .60613 .54088 .60168 .53367 Metetra
.662 .667 .844 r
.60168 .53367 .60613 .54088 .6148 .53793 .61036 .53077 Metetra
.708 .687 .828 r
.61036 .53077 .6148 .53793 .62343 .53308 .61902 .52633 Metetra
.733 .708 .827 r
.61902 .52633 .62343 .53308 .63205 .52716 .62767 .52104 Metetra
.751 .732 .835 r
.62767 .52104 .63205 .52716 .64065 .52073 .63632 .51533 Metetra
.757 .758 .853 r
.63632 .51533 .64065 .52073 .64927 .51443 .64499 .50972 Metetra
.756 .785 .877 r
.64499 .50972 .64927 .51443 .65792 .50854 .65368 .50445 Metetra
.74 .809 .906 r
.65368 .50445 .65792 .50854 .66661 .50342 .66241 .49978 Metetra
.691 .821 .945 r
.66241 .49978 .66661 .50342 .67537 .49974 .67121 .49629 Metetra
.629 .812 .971 r
.67121 .49629 .67537 .49974 .68423 .49739 .68008 .49386 Metetra
.586 .793 .978 r
.68008 .49386 .68423 .49739 .69315 .49585 .68902 .49208 Metetra
.571 .775 .975 r
.68902 .49208 .69315 .49585 .70213 .49469 .698 .4906 Metetra
.583 .764 .965 r
.698 .4906 .70213 .49469 .71114 .49345 .70702 .48907 Metetra
.591 .753 .955 r
.70702 .48907 .71114 .49345 .72019 .49217 .71607 .48749 Metetra
.603 .744 .944 r
.71607 .48749 .72019 .49217 .72926 .49072 .72515 .48578 Metetra
.626 .742 .931 r
.72515 .48578 .72926 .49072 .73834 .48881 .73424 .4837 Metetra
.642 .741 .921 r
.73424 .4837 .73834 .48881 .74743 .48649 .74334 .48128 Metetra
.652 .742 .915 r
.74334 .48128 .74743 .48649 .75653 .4839 .75245 .47864 Metetra
.654 .741 .914 r
.75245 .47864 .75653 .4839 .76565 .48126 .7616 .47596 Metetra
.65 .738 .914 r
.7616 .47596 .76565 .48126 .77482 .47872 .77078 .47336 Metetra
.651 .737 .912 r
.77078 .47336 .77482 .47872 .78401 .47613 .77998 .47072 Metetra
.654 .737 .91 r
.77998 .47072 .78401 .47613 .79322 .47346 .78922 .46801 Metetra
.657 .737 .908 r
.78922 .46801 .79322 .47346 .80246 .47069 .79847 .46522 Metetra
.66 .738 .908 r
.79847 .46522 .80246 .47069 .81172 .46783 .80776 .46235 Metetra
.661 .739 .907 r
.80776 .46235 .81172 .46783 .82101 .46492 .81706 .45945 Metetra
.665 .741 .907 r
.81706 .45945 .82101 .46492 .83031 .4619 .82639 .45645 Metetra
.668 .744 .907 r
.82639 .45645 .83031 .4619 .83964 .45878 .83575 .45336 Metetra
.669 .747 .909 r
.83575 .45336 .83964 .45878 .84899 .45561 .84512 .45024 Metetra
.668 .749 .911 r
.84512 .45024 .84899 .45561 .85837 .45246 .85453 .44714 Metetra
.665 .75 .914 r
.85453 .44714 .85837 .45246 .86779 .4494 .86398 .4441 Metetra
.662 .751 .916 r
.86398 .4441 .86779 .4494 .87725 .4464 .87346 .4411 Metetra
.661 .751 .917 r
.87346 .4411 .87725 .4464 .88674 .44343 .88298 .43813 Metetra
.66 .752 .918 r
.88298 .43813 .88674 .44343 .89626 .44047 .89253 .43517 Metetra
.659 .752 .919 r
.89253 .43517 .89626 .44047 .90582 .43753 .90211 .43222 Metetra
.658 .752 .919 r
.90211 .43222 .90582 .43753 .91542 .43461 .91173 .42929 Metetra
.657 .752 .92 r
.91173 .42929 .91542 .43461 .92504 .4317 .92138 .42636 Metetra
.654 .749 .919 r
.31727 .60416 .32223 .60853 .33003 .60624 .3251 .60184 Metetra
.653 .748 .919 r
.3251 .60184 .33003 .60624 .33786 .60395 .33294 .59953 Metetra
.653 .748 .919 r
.33294 .59953 .33786 .60395 .34572 .60167 .34081 .59722 Metetra
.653 .747 .919 r
.34081 .59722 .34572 .60167 .3536 .59939 .3487 .59491 Metetra
.653 .746 .918 r
.3487 .59491 .3536 .59939 .3615 .59709 .35662 .59259 Metetra
.654 .746 .917 r
.35662 .59259 .3615 .59709 .36942 .59477 .36456 .59025 Metetra
.656 .746 .916 r
.36456 .59025 .36942 .59477 .37738 .5924 .37253 .58786 Metetra
.658 .746 .915 r
.37253 .58786 .37738 .5924 .38535 .58997 .38052 .58542 Metetra
.659 .747 .915 r
.38052 .58542 .38535 .58997 .39336 .58751 .38854 .58294 Metetra
.66 .747 .914 r
.38854 .58294 .39336 .58751 .40138 .58501 .39658 .58044 Metetra
.662 .748 .914 r
.39658 .58044 .40138 .58501 .40944 .58245 .40465 .57788 Metetra
.662 .749 .914 r
.40465 .57788 .40944 .58245 .41751 .57989 .41274 .57532 Metetra
.66 .749 .916 r
.41274 .57532 .41751 .57989 .42561 .57739 .42085 .57281 Metetra
.655 .748 .918 r
.42085 .57281 .42561 .57739 .43373 .57499 .42899 .57039 Metetra
.649 .746 .92 r
.42899 .57039 .43373 .57499 .44187 .57271 .43714 .56807 Metetra
.648 .744 .92 r
.43714 .56807 .44187 .57271 .45004 .57045 .44533 .56577 Metetra
.649 .743 .918 r
.44533 .56577 .45004 .57045 .45823 .56817 .45354 .56345 Metetra
.649 .742 .918 r
.45354 .56345 .45823 .56817 .46645 .56588 .46177 .56113 Metetra
.656 .743 .914 r
.46177 .56113 .46645 .56588 .4747 .56343 .47003 .55866 Metetra
.669 .746 .909 r
.47003 .55866 .4747 .56343 .48297 .56066 .47832 .5559 Metetra
.687 .753 .901 r
.47832 .5559 .48297 .56066 .49128 .55738 .48664 .55269 Metetra
.705 .761 .896 r
.48664 .55269 .49128 .55738 .49961 .55357 .49499 .54903 Metetra
.712 .769 .897 r
.49499 .54903 .49961 .55357 .50796 .5496 .50336 .54521 Metetra
.712 .777 .903 r
.50336 .54521 .50796 .5496 .51633 .54563 .51174 .5414 Metetra
.708 .784 .911 r
.51174 .5414 .51633 .54563 .52471 .54178 .52015 .53769 Metetra
.69 .787 .924 r
.52015 .53769 .52471 .54178 .53312 .5384 .52858 .5344 Metetra
.657 .783 .941 r
.52858 .5344 .53312 .5384 .54155 .53578 .53703 .53178 Metetra
.593 .763 .96 r
.53703 .53178 .54155 .53578 .55002 .53437 .54551 .53021 Metetra
.52 .727 .968 r
.54551 .53021 .55002 .53437 .55853 .53413 .55403 .52967 Metetra
.492 .7 .962 r
.55403 .52967 .55853 .53413 .56708 .53443 .5626 .52961 Metetra
.491 .683 .951 r
.5626 .52961 .56708 .53443 .57568 .53493 .57121 .52972 Metetra
.515 .676 .938 r
.57121 .52972 .57568 .53493 .58432 .53524 .57986 .52966 Metetra
.556 .679 .92 r
.57986 .52966 .58432 .53524 .59299 .53494 .58853 .52907 Metetra
.605 .688 .901 r
.58853 .52907 .59299 .53494 .60168 .53367 .59723 .52761 Metetra
.666 .706 .877 r
.59723 .52761 .60168 .53367 .61036 .53077 .60592 .52473 Metetra
.712 .723 .858 r
.60592 .52473 .61036 .53077 .61902 .52633 .6146 .5205 Metetra
.735 .737 .853 r
.6146 .5205 .61902 .52633 .62767 .52104 .62329 .51551 Metetra
.748 .752 .855 r
.62329 .51551 .62767 .52104 .63632 .51533 .63197 .51016 Metetra
.75 .766 .866 r
.63197 .51016 .63632 .51533 .64499 .50972 .64067 .50489 Metetra
.745 .778 .88 r
.64067 .50489 .64499 .50972 .65368 .50445 .6494 .49991 Metetra
.729 .788 .899 r
.6494 .49991 .65368 .50445 .66241 .49978 .65816 .49547 Metetra
.689 .788 .926 r
.65816 .49547 .66241 .49978 .67121 .49629 .66699 .49206 Metetra
.642 .778 .946 r
.66699 .49206 .67121 .49629 .68008 .49386 .67588 .48958 Metetra
.609 .765 .954 r
.67588 .48958 .68008 .49386 .68902 .49208 .68483 .48767 Metetra
.595 .754 .954 r
.68483 .48767 .68902 .49208 .698 .4906 .69383 .48603 Metetra
.601 .748 .948 r
.69383 .48603 .698 .4906 .70702 .48907 .70285 .48434 Metetra
.604 .743 .943 r
.70285 .48434 .70702 .48907 .71607 .48749 .71192 .48261 Metetra
.612 .74 .936 r
.71192 .48261 .71607 .48749 .72515 .48578 .72101 .48076 Metetra
.63 .741 .928 r
.72101 .48076 .72515 .48578 .73424 .4837 .73011 .47857 Metetra
.644 .743 .921 r
.73011 .47857 .73424 .4837 .74334 .48128 .73922 .4761 Metetra
.653 .745 .917 r
.73922 .4761 .74334 .48128 .75245 .47864 .74836 .47343 Metetra
.654 .744 .916 r
.74836 .47343 .75245 .47864 .7616 .47596 .75752 .47072 Metetra
.651 .742 .917 r
.75752 .47072 .7616 .47596 .77078 .47336 .76672 .46808 Metetra
.652 .742 .916 r
.76672 .46808 .77078 .47336 .77998 .47072 .77595 .46541 Metetra
.655 .742 .914 r
.77595 .46541 .77998 .47072 .78922 .46801 .7852 .46267 Metetra
.657 .743 .913 r
.7852 .46267 .78922 .46801 .79847 .46522 .79448 .45986 Metetra
.66 .744 .912 r
.79448 .45986 .79847 .46522 .80776 .46235 .80378 .45698 Metetra
.661 .744 .912 r
.80378 .45698 .80776 .46235 .81706 .45945 .81311 .45407 Metetra
.664 .746 .911 r
.81311 .45407 .81706 .45945 .82639 .45645 .82246 .45107 Metetra
.667 .748 .911 r
.82246 .45107 .82639 .45645 .83575 .45336 .83184 .448 Metetra
.668 .75 .912 r
.83184 .448 .83575 .45336 .84512 .45024 .84124 .44489 Metetra
.667 .751 .913 r
.84124 .44489 .84512 .45024 .85453 .44714 .85068 .4418 Metetra
.664 .751 .915 r
.85068 .4418 .85453 .44714 .86398 .4441 .86015 .43876 Metetra
.662 .751 .916 r
.86015 .43876 .86398 .4441 .87346 .4411 .86966 .43577 Metetra
.661 .751 .917 r
.86966 .43577 .87346 .4411 .88298 .43813 .8792 .43279 Metetra
.66 .751 .917 r
.8792 .43279 .88298 .43813 .89253 .43517 .88877 .42982 Metetra
.659 .751 .918 r
.88877 .42982 .89253 .43517 .90211 .43222 .89837 .42685 Metetra
.658 .751 .918 r
.89837 .42685 .90211 .43222 .91173 .42929 .90801 .4239 Metetra
.657 .75 .919 r
.90801 .4239 .91173 .42929 .92138 .42636 .91769 .42095 Metetra
.655 .749 .919 r
.31229 .59977 .31727 .60416 .3251 .60184 .32013 .59742 Metetra
.654 .748 .919 r
.32013 .59742 .3251 .60184 .33294 .59953 .32799 .59508 Metetra
.654 .748 .919 r
.32799 .59508 .33294 .59953 .34081 .59722 .33587 .59274 Metetra
.654 .747 .918 r
.33587 .59274 .34081 .59722 .3487 .59491 .34378 .5904 Metetra
.654 .746 .918 r
.34378 .5904 .3487 .59491 .35662 .59259 .35171 .58805 Metetra
.655 .746 .917 r
.35171 .58805 .35662 .59259 .36456 .59025 .35967 .58568 Metetra
.656 .745 .916 r
.35967 .58568 .36456 .59025 .37253 .58786 .36765 .58327 Metetra
.658 .746 .915 r
.36765 .58327 .37253 .58786 .38052 .58542 .37566 .58082 Metetra
.659 .746 .914 r
.37566 .58082 .38052 .58542 .38854 .58294 .38369 .57833 Metetra
.66 .746 .914 r
.38369 .57833 .38854 .58294 .39658 .58044 .39175 .57583 Metetra
.662 .747 .914 r
.39175 .57583 .39658 .58044 .40465 .57788 .39983 .57328 Metetra
.661 .748 .914 r
.39983 .57328 .40465 .57788 .41274 .57532 .40794 .57072 Metetra
.659 .748 .916 r
.40794 .57072 .41274 .57532 .42085 .57281 .41606 .5682 Metetra
.655 .747 .918 r
.41606 .5682 .42085 .57281 .42899 .57039 .42422 .56575 Metetra
.651 .746 .919 r
.42422 .56575 .42899 .57039 .43714 .56807 .43239 .56339 Metetra
.65 .744 .918 r
.43239 .56339 .43714 .56807 .44533 .56577 .44059 .56104 Metetra
.651 .743 .917 r
.44059 .56104 .44533 .56577 .45354 .56345 .44881 .55867 Metetra
.651 .741 .916 r
.44881 .55867 .45354 .56345 .46177 .56113 .45706 .5563 Metetra
.656 .741 .913 r
.45706 .5563 .46177 .56113 .47003 .55866 .46534 .55381 Metetra
.667 .744 .908 r
.46534 .55381 .47003 .55866 .47832 .5559 .47365 .55108 Metetra
.682 .75 .903 r
.47365 .55108 .47832 .5559 .48664 .55269 .48198 .54798 Metetra
.697 .759 .9 r
.48198 .54798 .48664 .55269 .49499 .54903 .49034 .54451 Metetra
.703 .769 .904 r
.49034 .54451 .49499 .54903 .50336 .54521 .49873 .54092 Metetra
.703 .78 .911 r
.49873 .54092 .50336 .54521 .51174 .5414 .50713 .53732 Metetra
.7 .79 .92 r
.50713 .53732 .51174 .5414 .52015 .53769 .51556 .53381 Metetra
.684 .796 .934 r
.51556 .53381 .52015 .53769 .52858 .5344 .52401 .53064 Metetra
.654 .795 .95 r
.52401 .53064 .52858 .5344 .53703 .53178 .53248 .528 Metetra
.6 .779 .966 r
.53248 .528 .53703 .53178 .54551 .53021 .54098 .52623 Metetra
.544 .748 .971 r
.54098 .52623 .54551 .53021 .55403 .52967 .54952 .5253 Metetra
.525 .721 .962 r
.54952 .5253 .55403 .52967 .5626 .52961 .55809 .52475 Metetra
.529 .699 .947 r
.55809 .52475 .5626 .52961 .57121 .52972 .56671 .52434 Metetra
.549 .685 .929 r
.56671 .52434 .57121 .52972 .57986 .52966 .57536 .52379 Metetra
.581 .679 .908 r
.57536 .52379 .57986 .52966 .58853 .52907 .58404 .52281 Metetra
.617 .68 .887 r
.58404 .52281 .58853 .52907 .59723 .52761 .59274 .52112 Metetra
.663 .691 .866 r
.59274 .52112 .59723 .52761 .60592 .52473 .60145 .51827 Metetra
.7 .706 .852 r
.60145 .51827 .60592 .52473 .6146 .5205 .61016 .51431 Metetra
.72 .722 .851 r
.61016 .51431 .6146 .5205 .62329 .51551 .61887 .50974 Metetra
.732 .74 .858 r
.61887 .50974 .62329 .51551 .63197 .51016 .62759 .50487 Metetra
.735 .759 .872 r
.62759 .50487 .63197 .51016 .64067 .50489 .63633 .50006 Metetra
.731 .777 .889 r
.63633 .50006 .64067 .50489 .6494 .49991 .64509 .49549 Metetra
.718 .792 .91 r
.64509 .49549 .6494 .49991 .65816 .49547 .65389 .49136 Metetra
.682 .797 .936 r
.65389 .49136 .65816 .49547 .66699 .49206 .66275 .48806 Metetra
.641 .791 .954 r
.66275 .48806 .66699 .49206 .67588 .48958 .67166 .48552 Metetra
.614 .779 .96 r
.67166 .48552 .67588 .48958 .68483 .48767 .68062 .48345 Metetra
.604 .767 .958 r
.68062 .48345 .68483 .48767 .69383 .48603 .68963 .48159 Metetra
.609 .76 .951 r
.68963 .48159 .69383 .48603 .70285 .48434 .69867 .47969 Metetra
.613 .752 .944 r
.69867 .47969 .70285 .48434 .71192 .48261 .70774 .47775 Metetra
.62 .746 .936 r
.70774 .47775 .71192 .48261 .72101 .48076 .71684 .47572 Metetra
.635 .744 .927 r
.71684 .47572 .72101 .48076 .73011 .47857 .72595 .47341 Metetra
.647 .744 .92 r
.72595 .47341 .73011 .47857 .73922 .4761 .73509 .47087 Metetra
.654 .744 .916 r
.73509 .47087 .73922 .4761 .74836 .47343 .74424 .46816 Metetra
.655 .743 .915 r
.74424 .46816 .74836 .47343 .75752 .47072 .75342 .46542 Metetra
.652 .742 .915 r
.75342 .46542 .75752 .47072 .76672 .46808 .76264 .46273 Metetra
.653 .741 .914 r
.76264 .46273 .76672 .46808 .77595 .46541 .77188 .46002 Metetra
.655 .741 .913 r
.77188 .46002 .77595 .46541 .7852 .46267 .78115 .45725 Metetra
.657 .741 .911 r
.78115 .45725 .7852 .46267 .79448 .45986 .79045 .45442 Metetra
.659 .742 .911 r
.79045 .45442 .79448 .45986 .80378 .45698 .79978 .45153 Metetra
.66 .742 .911 r
.79978 .45153 .80378 .45698 .81311 .45407 .80913 .44861 Metetra
.663 .744 .91 r
.80913 .44861 .81311 .45407 .82246 .45107 .81851 .44563 Metetra
.665 .746 .91 r
.81851 .44563 .82246 .45107 .83184 .448 .82791 .44257 Metetra
.666 .748 .911 r
.82791 .44257 .83184 .448 .84124 .44489 .83734 .4395 Metetra
.665 .749 .913 r
.83734 .4395 .84124 .44489 .85068 .4418 .8468 .43642 Metetra
.663 .75 .915 r
.8468 .43642 .85068 .4418 .86015 .43876 .85629 .4334 Metetra
.661 .75 .916 r
.85629 .4334 .86015 .43876 .86966 .43577 .86583 .4304 Metetra
.66 .751 .917 r
.86583 .4304 .86966 .43577 .8792 .43279 .87539 .42741 Metetra
.659 .751 .918 r
.87539 .42741 .8792 .43279 .88877 .42982 .88499 .42444 Metetra
.659 .751 .918 r
.88499 .42444 .88877 .42982 .89837 .42685 .89462 .42146 Metetra
.658 .751 .919 r
.89462 .42146 .89837 .42685 .90801 .4239 .90428 .41849 Metetra
.657 .751 .919 r
.90428 .41849 .90801 .4239 .91769 .42095 .91398 .41553 Metetra
.657 .751 .92 r
.30728 .59538 .31229 .59977 .32013 .59742 .31514 .59299 Metetra
.656 .749 .918 r
.31514 .59299 .32013 .59742 .32799 .59508 .32301 .59059 Metetra
.656 .748 .917 r
.32301 .59059 .32799 .59508 .33587 .59274 .33091 .5882 Metetra
.656 .746 .916 r
.33091 .5882 .33587 .59274 .34378 .5904 .33884 .58579 Metetra
.656 .743 .914 r
.33884 .58579 .34378 .5904 .35171 .58805 .34679 .58338 Metetra
.657 .741 .912 r
.34679 .58338 .35171 .58805 .35967 .58568 .35476 .58095 Metetra
.657 .74 .911 r
.35476 .58095 .35967 .58568 .36765 .58327 .36276 .57851 Metetra
.658 .739 .91 r
.36276 .57851 .36765 .58327 .37566 .58082 .37078 .57605 Metetra
.658 .739 .91 r
.37078 .57605 .37566 .58082 .38369 .57833 .37882 .57357 Metetra
.659 .74 .91 r
.37882 .57357 .38369 .57833 .39175 .57583 .38689 .57107 Metetra
.659 .742 .911 r
.38689 .57107 .39175 .57583 .39983 .57328 .39499 .56855 Metetra
.659 .744 .912 r
.39499 .56855 .39983 .57328 .40794 .57072 .40311 .56603 Metetra
.658 .745 .914 r
.40311 .56603 .40794 .57072 .41606 .5682 .41125 .56352 Metetra
.657 .746 .916 r
.41125 .56352 .41606 .5682 .42422 .56575 .41942 .56103 Metetra
.655 .744 .915 r
.41942 .56103 .42422 .56575 .43239 .56339 .42761 .55856 Metetra
.655 .74 .912 r
.42761 .55856 .43239 .56339 .44059 .56104 .43583 .5561 Metetra
.655 .736 .909 r
.43583 .5561 .44059 .56104 .44881 .55867 .44407 .55363 Metetra
.655 .733 .906 r
.44407 .55363 .44881 .55867 .45706 .5563 .45233 .55114 Metetra
.657 .729 .902 r
.45233 .55114 .45706 .5563 .46534 .55381 .46063 .54861 Metetra
.661 .729 .9 r
.46063 .54861 .46534 .55381 .47365 .55108 .46895 .54599 Metetra
.667 .736 .901 r
.46895 .54599 .47365 .55108 .48198 .54798 .4773 .54322 Metetra
.673 .752 .91 r
.4773 .54322 .48198 .54798 .49034 .54451 .48567 .5403 Metetra
.675 .778 .927 r
.48567 .5403 .49034 .54451 .49873 .54092 .49407 .53734 Metetra
.672 .808 .948 r
.49407 .53734 .49873 .54092 .50713 .53732 .50249 .53437 Metetra
.662 .838 .968 r
.50249 .53437 .50713 .53732 .51556 .53381 .51093 .53142 Metetra
.639 .863 .983 r
.51093 .53142 .51556 .53381 .52401 .53064 .5194 .5286 Metetra
.609 .873 .991 r
.5194 .5286 .52401 .53064 .53248 .528 .5279 .52597 Metetra
.579 .865 .995 r
.5279 .52597 .53248 .528 .54098 .52623 .53642 .52367 Metetra
.576 .837 .994 r
.53642 .52367 .54098 .52623 .54952 .5253 .54497 .52167 Metetra
.6 .789 .971 r
.54497 .52167 .54952 .5253 .55809 .52475 .55356 .51982 Metetra
.616 .732 .929 r
.55356 .51982 .55809 .52475 .56671 .52434 .56217 .51801 Metetra
.625 .681 .883 r
.56217 .51801 .56671 .52434 .57536 .52379 .57082 .51614 Metetra
.631 .643 .844 r
.57082 .51614 .57536 .52379 .58404 .52281 .57949 .5141 Metetra
.637 .621 .817 r
.57949 .5141 .58404 .52281 .59274 .52112 .58819 .5118 Metetra
.647 .613 .802 r
.58819 .5118 .59274 .52112 .60145 .51827 .59691 .50905 Metetra
.659 .621 .801 r
.59691 .50905 .60145 .51827 .61016 .51431 .60564 .50588 Metetra
.669 .643 .815 r
.60564 .50588 .61016 .51431 .61887 .50974 .6144 .50248 Metetra
.68 .677 .84 r
.6144 .50248 .61887 .50974 .62759 .50487 .62317 .49896 Metetra
.687 .723 .877 r
.62317 .49896 .62759 .50487 .63633 .50006 .63197 .49545 Metetra
.688 .776 .918 r
.63197 .49545 .63633 .50006 .64509 .49549 .6408 .49203 Metetra
.675 .828 .957 r
.6408 .49203 .64509 .49549 .65389 .49136 .64966 .48877 Metetra
.638 .864 .984 r
.64966 .48877 .65389 .49136 .66275 .48806 .65855 .48582 Metetra
.602 .871 .992 r
.65855 .48582 .66275 .48806 .67166 .48552 .66748 .48314 Metetra
.593 .862 .994 r
.66748 .48314 .67166 .48552 .68062 .48345 .67646 .48064 Metetra
.604 .843 .989 r
.67646 .48064 .68062 .48345 .68963 .48159 .68546 .47821 Metetra
.622 .82 .976 r
.68546 .47821 .68963 .48159 .69867 .47969 .6945 .47576 Metetra
.632 .796 .961 r
.6945 .47576 .69867 .47969 .70774 .47775 .70356 .4733 Metetra
.641 .773 .944 r
.70356 .4733 .70774 .47775 .71684 .47572 .71265 .47078 Metetra
.649 .755 .927 r
.71265 .47078 .71684 .47572 .72595 .47341 .72177 .46817 Metetra
.654 .744 .916 r
.72177 .46817 .72595 .47341 .73509 .47087 .73092 .46545 Metetra
.657 .739 .91 r
.73092 .46545 .73509 .47087 .74424 .46816 .74008 .46267 Metetra
.657 .736 .908 r
.74008 .46267 .74424 .46816 .75342 .46542 .74928 .45987 Metetra
.656 .734 .907 r
.74928 .45987 .75342 .46542 .76264 .46273 .75851 .45709 Metetra
.656 .731 .905 r
.75851 .45709 .76264 .46273 .77188 .46002 .76777 .45429 Metetra
.657 .729 .902 r
.76777 .45429 .77188 .46002 .78115 .45725 .77706 .45146 Metetra
.658 .728 .901 r
.77706 .45146 .78115 .45725 .79045 .45442 .78638 .4486 Metetra
.659 .728 .9 r
.78638 .4486 .79045 .45442 .79978 .45153 .79572 .44572 Metetra
.659 .728 .901 r
.79572 .44572 .79978 .45153 .80913 .44861 .8051 .44282 Metetra
.66 .73 .902 r
.8051 .44282 .80913 .44861 .81851 .44563 .8145 .43989 Metetra
.661 .733 .903 r
.8145 .43989 .81851 .44563 .82791 .44257 .82393 .43692 Metetra
.661 .738 .907 r
.82393 .43692 .82791 .44257 .83734 .4395 .8334 .43394 Metetra
.661 .742 .911 r
.8334 .43394 .83734 .4395 .8468 .43642 .84289 .43096 Metetra
.66 .746 .914 r
.84289 .43096 .8468 .43642 .85629 .4334 .85242 .42799 Metetra
.659 .749 .917 r
.85242 .42799 .85629 .4334 .86583 .4304 .86197 .42503 Metetra
.658 .751 .918 r
.86197 .42503 .86583 .4304 .87539 .42741 .87157 .42206 Metetra
.658 .752 .92 r
.87157 .42206 .87539 .42741 .88499 .42444 .88119 .41909 Metetra
.658 .753 .92 r
.88119 .41909 .88499 .42444 .89462 .42146 .89084 .41611 Metetra
.658 .754 .921 r
.89084 .41611 .89462 .42146 .90428 .41849 .90053 .41313 Metetra
.657 .754 .921 r
.90053 .41313 .90428 .41849 .91398 .41553 .91025 .41015 Metetra
.66 .754 .92 r
.30224 .59102 .30728 .59538 .31514 .59299 .31012 .58855 Metetra
.66 .751 .917 r
.31012 .58855 .31514 .59299 .32301 .59059 .31801 .58606 Metetra
.661 .748 .914 r
.31801 .58606 .32301 .59059 .33091 .5882 .32593 .58355 Metetra
.661 .744 .911 r
.32593 .58355 .33091 .5882 .33884 .58579 .33388 .58104 Metetra
.661 .74 .908 r
.33388 .58104 .33884 .58579 .34679 .58338 .34184 .57852 Metetra
.66 .735 .905 r
.34184 .57852 .34679 .58338 .35476 .58095 .34983 .576 Metetra
.659 .732 .903 r
.34983 .576 .35476 .58095 .36276 .57851 .35784 .57351 Metetra
.658 .73 .903 r
.35784 .57351 .36276 .57851 .37078 .57605 .36588 .57103 Metetra
.657 .73 .903 r
.36588 .57103 .37078 .57605 .37882 .57357 .37394 .56857 Metetra
.656 .731 .904 r
.37394 .56857 .37882 .57357 .38689 .57107 .38202 .56611 Metetra
.655 .733 .907 r
.38202 .56611 .38689 .57107 .39499 .56855 .39013 .56368 Metetra
.655 .737 .91 r
.39013 .56368 .39499 .56855 .40311 .56603 .39826 .56124 Metetra
.657 .741 .912 r
.39826 .56124 .40311 .56603 .41125 .56352 .40641 .55875 Metetra
.66 .744 .912 r
.40641 .55875 .41125 .56352 .41942 .56103 .4146 .55619 Metetra
.663 .743 .909 r
.4146 .55619 .41942 .56103 .42761 .55856 .42281 .55354 Metetra
.664 .736 .903 r
.42281 .55354 .42761 .55856 .43583 .5561 .43105 .55087 Metetra
.664 .728 .897 r
.43105 .55087 .43583 .5561 .44407 .55363 .43931 .54819 Metetra
.663 .721 .891 r
.43931 .54819 .44407 .55363 .45233 .55114 .44759 .54551 Metetra
.659 .712 .887 r
.44759 .54551 .45233 .55114 .46063 .54861 .4559 .54292 Metetra
.651 .708 .889 r
.4559 .54292 .46063 .54861 .46895 .54599 .46423 .54051 Metetra
.637 .712 .901 r
.46423 .54051 .46895 .54599 .4773 .54322 .47258 .53839 Metetra
.618 .733 .928 r
.47258 .53839 .4773 .54322 .48567 .5403 .48096 .53658 Metetra
.596 .779 .968 r
.48096 .53658 .48567 .5403 .49407 .53734 .48936 .53486 Metetra
.552 .831 .997 r
.48936 .53486 .49407 .53734 .50249 .53437 .4978 .53312 Metetra
.469 .855 .979 r
.4978 .53312 .50249 .53437 .51093 .53142 .50626 .5313 Metetra
.373 .836 .894 r
.50626 .5313 .51093 .53142 .5194 .5286 .51476 .52918 Metetra
.339 .82 .821 r
.51476 .52918 .5194 .5286 .5279 .52597 .52329 .52658 Metetra
.441 .878 .851 r
.52329 .52658 .5279 .52597 .53642 .52367 .53184 .52325 Metetra
.635 .947 .949 r
.53184 .52325 .53642 .52367 .54497 .52167 .54041 .51919 Metetra
.732 .88 .949 r
.54041 .51919 .54497 .52167 .55356 .51982 .54899 .51478 Metetra
.73 .763 .879 r
.54899 .51478 .55356 .51982 .56217 .51801 .5576 .51026 Metetra
.702 .671 .816 r
.5576 .51026 .56217 .51801 .57082 .51614 .56622 .50584 Metetra
.674 .608 .774 r
.56622 .50584 .57082 .51614 .57949 .5141 .57487 .50177 Metetra
.65 .568 .749 r
.57487 .50177 .57949 .5141 .58819 .5118 .58354 .49828 Metetra
.625 .541 .739 r
.58354 .49828 .58819 .5118 .59691 .50905 .59226 .49575 Metetra
.605 .532 .746 r
.59226 .49575 .59691 .50905 .60564 .50588 .60103 .49413 Metetra
.595 .547 .77 r
.60103 .49413 .60564 .50588 .6144 .50248 .60985 .49301 Metetra
.588 .583 .814 r
.60985 .49301 .6144 .50248 .62317 .49896 .61871 .49213 Metetra
.583 .65 .882 r
.61871 .49213 .62317 .49896 .63197 .49545 .6276 .49119 Metetra
.559 .747 .965 r
.6276 .49119 .63197 .49545 .6408 .49203 .63652 .49003 Metetra
.48 .834 .996 r
.63652 .49003 .6408 .49203 .64966 .48877 .64547 .48849 Metetra
.377 .839 .896 r
.64547 .48849 .64966 .48877 .65855 .48582 .65443 .48623 Metetra
.364 .835 .828 r
.65443 .48623 .65855 .48582 .66748 .48314 .66339 .48331 Metetra
.45 .883 .873 r
.66339 .48331 .66748 .48314 .67646 .48064 .67235 .47997 Metetra
.565 .923 .949 r
.67235 .47997 .67646 .48064 .68546 .47821 .68134 .47644 Metetra
.638 .909 .982 r
.68134 .47644 .68546 .47821 .6945 .47576 .69035 .47294 Metetra
.672 .867 .973 r
.69035 .47294 .6945 .47576 .70356 .4733 .69939 .46944 Metetra
.682 .817 .948 r
.69939 .46944 .70356 .4733 .71265 .47078 .70846 .46601 Metetra
.675 .772 .924 r
.70846 .46601 .71265 .47078 .72177 .46817 .71756 .4628 Metetra
.667 .745 .909 r
.71756 .4628 .72177 .46817 .73092 .46545 .72671 .45977 Metetra
.661 .731 .901 r
.72671 .45977 .73092 .46545 .74008 .46267 .73589 .45686 Metetra
.66 .727 .898 r
.73589 .45686 .74008 .46267 .74928 .45987 .7451 .45397 Metetra
.663 .724 .895 r
.7451 .45397 .74928 .45987 .75851 .45709 .75434 .451 Metetra
.661 .718 .89 r
.75434 .451 .75851 .45709 .76777 .45429 .7636 .44805 Metetra
.66 .712 .887 r
.7636 .44805 .76777 .45429 .77706 .45146 .77291 .44513 Metetra
.658 .709 .885 r
.77291 .44513 .77706 .45146 .78638 .4486 .78224 .44224 Metetra
.657 .708 .885 r
.78224 .44224 .78638 .4486 .79572 .44572 .79161 .43938 Metetra
.656 .709 .887 r
.79161 .43938 .79572 .44572 .8051 .44282 .80101 .43653 Metetra
.654 .711 .889 r
.80101 .43653 .8051 .44282 .8145 .43989 .81044 .43372 Metetra
.652 .715 .894 r
.81044 .43372 .8145 .43989 .82393 .43692 .81991 .43095 Metetra
.652 .722 .901 r
.81991 .43095 .82393 .43692 .8334 .43394 .82942 .42818 Metetra
.652 .732 .908 r
.82942 .42818 .8334 .43394 .84289 .43096 .83895 .42539 Metetra
.654 .741 .914 r
.83895 .42539 .84289 .43096 .85242 .42799 .84851 .42254 Metetra
.655 .747 .918 r
.84851 .42254 .85242 .42799 .86197 .42503 .8581 .41966 Metetra
.655 .751 .921 r
.8581 .41966 .86197 .42503 .87157 .42206 .86773 .41674 Metetra
.656 .755 .923 r
.86773 .41674 .87157 .42206 .88119 .41909 .87738 .4138 Metetra
.656 .757 .924 r
.87738 .4138 .88119 .41909 .89084 .41611 .88706 .41084 Metetra
.657 .759 .925 r
.88706 .41084 .89084 .41611 .90053 .41313 .89677 .40785 Metetra
.657 .759 .925 r
.89677 .40785 .90053 .41313 .91025 .41015 .90652 .40485 Metetra
.665 .757 .919 r
.29717 .58668 .30224 .59102 .31012 .58855 .30506 .58409 Metetra
.667 .753 .915 r
.30506 .58409 .31012 .58855 .31801 .58606 .31298 .58146 Metetra
.668 .748 .91 r
.31298 .58146 .31801 .58606 .32593 .58355 .32093 .5788 Metetra
.668 .742 .905 r
.32093 .5788 .32593 .58355 .33388 .58104 .32889 .57612 Metetra
.668 .736 .901 r
.32889 .57612 .33388 .58104 .34184 .57852 .33688 .57344 Metetra
.665 .729 .897 r
.33688 .57344 .34184 .57852 .34983 .576 .34489 .5708 Metetra
.662 .724 .895 r
.34489 .5708 .34983 .576 .35784 .57351 .35292 .56822 Metetra
.658 .72 .895 r
.35292 .56822 .35784 .57351 .36588 .57103 .36097 .56574 Metetra
.655 .719 .896 r
.36097 .56574 .36588 .57103 .37394 .56857 .36904 .56331 Metetra
.653 .721 .899 r
.36904 .56331 .37394 .56857 .38202 .56611 .37713 .56092 Metetra
.648 .723 .903 r
.37713 .56092 .38202 .56611 .39013 .56368 .38524 .55862 Metetra
.648 .729 .908 r
.38524 .55862 .39013 .56368 .39826 .56124 .39338 .55632 Metetra
.654 .737 .91 r
.39338 .55632 .39826 .56124 .40641 .55875 .40155 .55388 Metetra
.664 .742 .908 r
.40155 .55388 .40641 .55875 .4146 .55619 .40976 .55121 Metetra
.675 .741 .9 r
.40976 .55121 .4146 .55619 .42281 .55354 .41799 .54828 Metetra
.677 .731 .891 r
.41799 .54828 .42281 .55354 .43105 .55087 .42625 .54529 Metetra
.674 .719 .883 r
.42625 .54529 .43105 .55087 .43931 .54819 .43453 .54232 Metetra
.674 .709 .874 r
.43453 .54232 .43931 .54819 .44759 .54551 .44284 .53933 Metetra
.661 .695 .871 r
.44284 .53933 .44759 .54551 .4559 .54292 .45116 .53665 Metetra
.635 .683 .878 r
.45116 .53665 .4559 .54292 .46423 .54051 .4595 .53458 Metetra
.587 .677 .903 r
.4595 .53458 .46423 .54051 .47258 .53839 .46784 .53349 Metetra
.503 .687 .949 r
.46784 .53349 .47258 .53839 .48096 .53658 .47621 .53341 Metetra
.379 .719 .988 r
.47621 .53341 .48096 .53658 .48936 .53486 .48461 .53366 Metetra
.148 .672 .879 r
.48461 .53366 .48936 .53486 .4978 .53312 .49305 .53388 Metetra
.104 0 0 r
.49305 .53388 .4978 .53312 .50626 .5313 .50153 .53384 Metetra
.178 0 0 r
.50153 .53384 .50626 .5313 .51476 .52918 .51006 .53284 Metetra
.103 0 0 r
.51006 .53284 .51476 .52918 .52329 .52658 .51862 .5303 Metetra
.51862 .5303 .52329 .52658 .53184 .52325 .52721 .52534 Metetra
.691 .972 .769 r
.52721 .52534 .53184 .52325 .54041 .51919 .53581 .51803 Metetra
.866 .932 .865 r
.53581 .51803 .54041 .51919 .54899 .51478 .54441 .50964 Metetra
.823 .774 .806 r
.54441 .50964 .54899 .51478 .5576 .51026 .55299 .50087 Metetra
.76 .662 .753 r
.55299 .50087 .5576 .51026 .56622 .50584 .56158 .49248 Metetra
.706 .587 .72 r
.56158 .49248 .56622 .50584 .57487 .50177 .57018 .48528 Metetra
.66 .536 .702 r
.57018 .48528 .57487 .50177 .58354 .49828 .57882 .47997 Metetra
.606 .491 .696 r
.57882 .47997 .58354 .49828 .59226 .49575 .58753 .47778 Metetra
.552 .459 .703 r
.58753 .47778 .59226 .49575 .60103 .49413 .59633 .47856 Metetra
.507 .451 .728 r
.59633 .47856 .60103 .49413 .60985 .49301 .60522 .481 Metetra
.453 .461 .777 r
.60522 .481 .60985 .49301 .61871 .49213 .61419 .48425 Metetra
.377 .51 .865 r
.61419 .48425 .61871 .49213 .6276 .49119 .62321 .48732 Metetra
.185 .571 .937 r
.62321 .48732 .6276 .49119 .63652 .49003 .63227 .48973 Metetra
.128 0 0 r
.63227 .48973 .63652 .49003 .64547 .48849 .64135 .49091 Metetra
.159 0 0 r
.64135 .49091 .64547 .48849 .65443 .48623 .65038 .48976 Metetra
.035 0 0 r
.65038 .48976 .65443 .48623 .66339 .48331 .65937 .48645 Metetra
.65937 .48645 .66339 .48331 .67235 .47997 .66833 .48182 Metetra
.437 .852 .692 r
.66833 .48182 .67235 .47997 .68134 .47644 .67727 .47655 Metetra
.639 .964 .894 r
.67727 .47655 .68134 .47644 .69035 .47294 .68624 .4714 Metetra
.732 .943 .952 r
.68624 .4714 .69035 .47294 .69939 .46944 .69523 .4663 Metetra
.744 .869 .938 r
.69523 .4663 .69939 .46944 .70846 .46601 .70424 .46144 Metetra
.713 .794 .915 r
.70424 .46144 .70846 .46601 .71756 .4628 .71332 .4573 Metetra
.685 .748 .899 r
.71332 .4573 .71756 .4628 .72671 .45977 .72246 .45379 Metetra
.668 .723 .891 r
.72246 .45379 .72671 .45977 .73589 .45686 .73164 .45069 Metetra
.665 .716 .887 r
.73164 .45069 .73589 .45686 .7451 .45397 .74087 .44765 Metetra
.671 .714 .881 r
.74087 .44765 .7451 .45397 .75434 .451 .7501 .44442 Metetra
.668 .704 .874 r
.7501 .44442 .75434 .451 .7636 .44805 .75937 .44124 Metetra
.663 .695 .87 r
.75937 .44124 .7636 .44805 .77291 .44513 .76868 .43818 Metetra
.657 .689 .868 r
.76868 .43818 .77291 .44513 .78224 .44224 .77803 .43525 Metetra
.653 .686 .869 r
.77803 .43525 .78224 .44224 .79161 .43938 .78742 .43243 Metetra
.651 .687 .871 r
.78742 .43243 .79161 .43938 .80101 .43653 .79685 .42967 Metetra
.645 .688 .876 r
.79685 .42967 .80101 .43653 .81044 .43372 .80632 .42706 Metetra
.639 .693 .884 r
.80632 .42706 .81044 .43372 .81991 .43095 .81584 .4246 Metetra
.637 .704 .894 r
.81584 .4246 .81991 .43095 .82942 .42818 .82539 .42217 Metetra
.639 .718 .905 r
.82539 .42217 .82942 .42818 .83895 .42539 .83498 .41969 Metetra
.644 .733 .913 r
.83498 .41969 .83895 .42539 .84851 .42254 .84459 .41705 Metetra
.648 .744 .919 r
.84459 .41705 .84851 .42254 .8581 .41966 .85421 .4143 Metetra
.65 .751 .923 r
.85421 .4143 .8581 .41966 .86773 .41674 .86387 .41147 Metetra
.652 .757 .926 r
.86387 .41147 .86773 .41674 .87738 .4138 .87355 .40859 Metetra
.653 .76 .928 r
.87355 .40859 .87738 .4138 .88706 .41084 .88327 .40567 Metetra
.655 .764 .929 r
.88327 .40567 .88706 .41084 .89677 .40785 .89301 .40268 Metetra
.657 .765 .929 r
.89301 .40268 .89677 .40785 .90652 .40485 .90277 .39965 Metetra
.67 .759 .917 r
.29207 .58234 .29717 .58668 .30506 .58409 .29999 .57962 Metetra
.673 .755 .912 r
.29999 .57962 .30506 .58409 .31298 .58146 .30793 .57683 Metetra
.675 .749 .907 r
.30793 .57683 .31298 .58146 .32093 .5788 .3159 .574 Metetra
.676 .743 .901 r
.3159 .574 .32093 .5788 .32889 .57612 .32389 .57113 Metetra
.675 .736 .896 r
.32389 .57113 .32889 .57612 .33688 .57344 .3319 .56826 Metetra
.671 .728 .893 r
.3319 .56826 .33688 .57344 .34489 .5708 .33993 .56548 Metetra
.665 .721 .891 r
.33993 .56548 .34489 .5708 .35292 .56822 .34798 .56282 Metetra
.657 .717 .892 r
.34798 .56282 .35292 .56822 .36097 .56574 .35604 .56033 Metetra
.652 .715 .894 r
.35604 .56033 .36097 .56574 .36904 .56331 .36412 .55794 Metetra
.648 .716 .898 r
.36412 .55794 .36904 .56331 .37713 .56092 .37222 .55564 Metetra
.64 .717 .904 r
.37222 .55564 .37713 .56092 .38524 .55862 .38034 .55349 Metetra
.64 .724 .909 r
.38034 .55349 .38524 .55862 .39338 .55632 .38848 .55134 Metetra
.651 .734 .91 r
.38848 .55134 .39338 .55632 .40155 .55388 .39667 .54895 Metetra
.668 .742 .905 r
.39667 .54895 .40155 .55388 .40976 .55121 .40489 .54617 Metetra
.687 .743 .894 r
.40489 .54617 .40976 .55121 .41799 .54828 .41315 .54293 Metetra
.69 .732 .883 r
.41315 .54293 .41799 .54828 .42625 .54529 .42143 .53958 Metetra
.686 .719 .874 r
.42143 .53958 .42625 .54529 .43453 .54232 .42974 .53627 Metetra
.685 .707 .865 r
.42974 .53627 .43453 .54232 .44284 .53933 .43807 .53294 Metetra
.663 .69 .865 r
.43807 .53294 .44284 .53933 .45116 .53665 .4464 .53016 Metetra
.618 .67 .878 r
.4464 .53016 .45116 .53665 .4595 .53458 .45474 .52848 Metetra
.52 .643 .91 r
.45474 .52848 .4595 .53458 .46784 .53349 .46308 .52855 Metetra
.318 .595 .944 r
.46308 .52855 .46784 .53349 .47621 .53341 .47143 .53043 Metetra
.03 .517 .879 r
.47143 .53043 .47621 .53341 .48461 .53366 .47981 .5329 Metetra
.279 0 0 r
.47981 .5329 .48461 .53366 .49305 .53388 .48825 .53534 Metetra
.419 0 0 r
.48825 .53534 .49305 .53388 .50153 .53384 .49675 .53733 Metetra
.374 0 0 r
.49675 .53733 .50153 .53384 .51006 .53284 .5053 .5376 Metetra
.2 0 0 r
.5053 .5376 .51006 .53284 .51862 .5303 .51391 .53512 Metetra
.51391 .53512 .51862 .5303 .52721 .52534 .52255 .52833 Metetra
.838 .986 .712 r
.52255 .52833 .52721 .52534 .53581 .51803 .53118 .51734 Metetra
.932 .906 .774 r
.53118 .51734 .53581 .51803 .54441 .50964 .53979 .50443 Metetra
.874 .771 .744 r
.53979 .50443 .54441 .50964 .55299 .50087 .54837 .49091 Metetra
.805 .671 .715 r
.54837 .49091 .55299 .50087 .56158 .49248 .55693 .47809 Metetra
.741 .597 .696 r
.55693 .47809 .56158 .49248 .57018 .48528 .56549 .4674 Metetra
.68 .539 .686 r
.56549 .4674 .57018 .48528 .57882 .47997 .57408 .46007 Metetra
.596 .475 .685 r
.57408 .46007 .57882 .47997 .58753 .47778 .58277 .45826 Metetra
.498 .414 .692 r
.58277 .45826 .58753 .47778 .59633 .47856 .59161 .46171 Metetra
.402 .372 .711 r
.59161 .46171 .59633 .47856 .60522 .481 .60057 .46811 Metetra
.264 .33 .744 r
.60057 .46811 .60522 .481 .61419 .48425 .60965 .47599 Metetra
.05 .294 .784 r
.60965 .47599 .61419 .48425 .62321 .48732 .6188 .48357 Metetra
0 .191 .656 r
.6188 .48357 .62321 .48732 .63227 .48973 .628 .49002 Metetra
.508 0 0 r
.628 .49002 .63227 .48973 .64135 .49091 .63721 .4943 Metetra
.349 0 0 r
.63721 .4943 .64135 .49091 .65038 .48976 .64634 .4944 Metetra
.097 0 0 r
.64634 .4944 .65038 .48976 .65937 .48645 .65535 .49066 Metetra
.65535 .49066 .65937 .48645 .66833 .48182 .6643 .48455 Metetra
.52 .871 .625 r
.6643 .48455 .66833 .48182 .67727 .47655 .6732 .47732 Metetra
.723 .989 .836 r
.6732 .47732 .67727 .47655 .68624 .4714 .68212 .4703 Metetra
.807 .967 .907 r
.68212 .4703 .68624 .4714 .69523 .4663 .69105 .46338 Metetra
.803 .888 .906 r
.69105 .46338 .69523 .4663 .70424 .46144 .70001 .45691 Metetra
.75 .807 .898 r
.70001 .45691 .70424 .46144 .71332 .4573 .70905 .45174 Metetra
.704 .753 .89 r
.70905 .45174 .71332 .4573 .72246 .45379 .71818 .44769 Metetra
.675 .723 .886 r
.71818 .44769 .72246 .45379 .73164 .45069 .72737 .44438 Metetra
.67 .714 .881 r
.72737 .44438 .73164 .45069 .74087 .44765 .7366 .44118 Metetra
.681 .713 .873 r
.7366 .44118 .74087 .44765 .7501 .44442 .74584 .43764 Metetra
.675 .702 .867 r
.74584 .43764 .7501 .44442 .75937 .44124 .75511 .43421 Metetra
.666 .691 .863 r
.75511 .43421 .75937 .44124 .76868 .43818 .76443 .431 Metetra
.658 .683 .862 r
.76443 .431 .76868 .43818 .77803 .43525 .77379 .42802 Metetra
.65 .679 .864 r
.77379 .42802 .77803 .43525 .78742 .43243 .7832 .42525 Metetra
.646 .679 .867 r
.7832 .42525 .78742 .43243 .79685 .42967 .79265 .42259 Metetra
.636 .678 .873 r
.79265 .42259 .79685 .42967 .80632 .42706 .80216 .4202 Metetra
.625 .681 .883 r
.80216 .4202 .80632 .42706 .81584 .4246 .81173 .41809 Metetra
.621 .692 .895 r
.81173 .41809 .81584 .4246 .82539 .42217 .82134 .41606 Metetra
.623 .708 .907 r
.82134 .41606 .82539 .42217 .83498 .41969 .83098 .41393 Metetra
.633 .727 .915 r
.83098 .41393 .83498 .41969 .84459 .41705 .84063 .41153 Metetra
.641 .741 .921 r
.84063 .41153 .84459 .41705 .85421 .4143 .8503 .40892 Metetra
.645 .75 .925 r
.8503 .40892 .85421 .4143 .86387 .41147 .85999 .4062 Metetra
.648 .756 .928 r
.85999 .4062 .86387 .41147 .87355 .40859 .86971 .40338 Metetra
.65 .761 .93 r
.86971 .40338 .87355 .40859 .88327 .40567 .87945 .4005 Metetra
.654 .765 .931 r
.87945 .4005 .88327 .40567 .89301 .40268 .88922 .39752 Metetra
.657 .767 .931 r
.88922 .39752 .89301 .40268 .90277 .39965 .89901 .39447 Metetra
.676 .761 .915 r
.28694 .57798 .29207 .58234 .29999 .57962 .29488 .57513 Metetra
.68 .757 .909 r
.29488 .57513 .29999 .57962 .30793 .57683 .30285 .57218 Metetra
.682 .751 .903 r
.30285 .57218 .30793 .57683 .3159 .574 .31084 .56917 Metetra
.684 .744 .897 r
.31084 .56917 .3159 .574 .32389 .57113 .31886 .5661 Metetra
.682 .737 .892 r
.31886 .5661 .32389 .57113 .3319 .56826 .32689 .56305 Metetra
.676 .729 .89 r
.32689 .56305 .3319 .56826 .33993 .56548 .33494 .56012 Metetra
.668 .722 .889 r
.33494 .56012 .33993 .56548 .34798 .56282 .34301 .55738 Metetra
.657 .716 .892 r
.34301 .55738 .34798 .56282 .35604 .56033 .35108 .55487 Metetra
.65 .714 .895 r
.35108 .55487 .35604 .56033 .36412 .55794 .35917 .55253 Metetra
.644 .714 .899 r
.35917 .55253 .36412 .55794 .37222 .55564 .36728 .55031 Metetra
.632 .714 .906 r
.36728 .55031 .37222 .55564 .38034 .55349 .37541 .54832 Metetra
.632 .721 .912 r
.37541 .54832 .38034 .55349 .38848 .55134 .38356 .54632 Metetra
.647 .733 .912 r
.38356 .54632 .38848 .55134 .39667 .54895 .39175 .544 Metetra
.673 .743 .903 r
.39175 .544 .39667 .54895 .40489 .54617 .39999 .5411 Metetra
.699 .746 .888 r
.39999 .5411 .40489 .54617 .41315 .54293 .40828 .53753 Metetra
.702 .735 .876 r
.40828 .53753 .41315 .54293 .42143 .53958 .41659 .53382 Metetra
.697 .721 .868 r
.41659 .53382 .42143 .53958 .42974 .53627 .42492 .53016 Metetra
.696 .71 .859 r
.42492 .53016 .42974 .53627 .43807 .53294 .43327 .52648 Metetra
.666 .689 .862 r
.43327 .52648 .43807 .53294 .4464 .53016 .44163 .52359 Metetra
.599 .661 .882 r
.44163 .52359 .4464 .53016 .45474 .52848 .44997 .52232 Metetra
.435 .601 .916 r
.44997 .52232 .45474 .52848 .46308 .52855 .45829 .52358 Metetra
.066 .442 .877 r
.45829 .52358 .46308 .52855 .47143 .53043 .46661 .52747 Metetra
0 .234 .644 r
.46661 .52747 .47143 .53043 .47981 .5329 .47498 .53224 Metetra
.537 0 0 r
.47498 .53224 .47981 .5329 .48825 .53534 .48341 .53697 Metetra
.578 .04 0 r
.48341 .53697 .48825 .53534 .49675 .53733 .49191 .54106 Metetra
.476 0 0 r
.49191 .54106 .49675 .53733 .5053 .5376 .50049 .54266 Metetra
.223 0 0 r
.50049 .54266 .5053 .5376 .51391 .53512 .50914 .54024 Metetra
.50914 .54024 .51391 .53512 .52255 .52833 .51783 .53154 Metetra
.93 .967 .682 r
.51783 .53154 .52255 .52833 .53118 .51734 .52651 .51674 Metetra
.957 .869 .71 r
.52651 .51674 .53118 .51734 .53979 .50443 .53515 .49919 Metetra
.902 .763 .698 r
.53515 .49919 .53979 .50443 .54837 .49091 .54374 .4808 Metetra
.838 .68 .687 r
.54374 .4808 .54837 .49091 .55693 .47809 .55227 .46346 Metetra
.773 .612 .68 r
.55227 .46346 .55693 .47809 .56549 .4674 .5608 .44924 Metetra
.702 .55 .679 r
.5608 .44924 .56549 .4674 .57408 .46007 .56935 .43986 Metetra
.589 .469 .684 r
.56935 .43986 .57408 .46007 .58277 .45826 .57803 .43844 Metetra
.436 .371 .687 r
.57803 .43844 .58277 .45826 .59161 .46171 .58688 .44458 Metetra
.264 .279 .688 r
.58688 .44458 .59161 .46171 .60057 .46811 .59591 .45502 Metetra
.01 .157 .67 r
.59591 .45502 .60057 .46811 .60965 .47599 .60508 .46762 Metetra
0 .018 .588 r
.60508 .46762 .60965 .47599 .6188 .48357 .61436 .47983 Metetra
.642 .127 0 r
.61436 .47983 .6188 .48357 .628 .49002 .6237 .49044 Metetra
.679 .14 0 r
.6237 .49044 .628 .49002 .63721 .4943 .63304 .49793 Metetra
.449 0 0 r
.63304 .49793 .63721 .4943 .64634 .4944 .64225 .49935 Metetra
.077 0 0 r
.64225 .49935 .64634 .4944 .65535 .49066 .6513 .49515 Metetra
.6513 .49515 .65535 .49066 .6643 .48455 .66023 .4875 Metetra
.664 .929 .639 r
.66023 .4875 .6643 .48455 .6732 .47732 .66909 .47825 Metetra
.817 1 .806 r
.66909 .47825 .6732 .47732 .68212 .4703 .67797 .4693 Metetra
.867 .963 .861 r
.67797 .4693 .68212 .4703 .69105 .46338 .68684 .46051 Metetra
.847 .889 .868 r
.68684 .46051 .69105 .46338 .70001 .45691 .69575 .45237 Metetra
.782 .814 .878 r
.69575 .45237 .70001 .45691 .70905 .45174 .70476 .44613 Metetra
.722 .758 .881 r
.70476 .44613 .70905 .45174 .71818 .44769 .71387 .44153 Metetra
.682 .725 .882 r
.71387 .44153 .71818 .44769 .72737 .44438 .72308 .43801 Metetra
.675 .715 .879 r
.72308 .43801 .72737 .44438 .7366 .44118 .73231 .43464 Metetra
.69 .716 .869 r
.73231 .43464 .7366 .44118 .74584 .43764 .74155 .43079 Metetra
.683 .704 .863 r
.74155 .43079 .74584 .43764 .75511 .43421 .75082 .4271 Metetra
.671 .691 .861 r
.75082 .4271 .75511 .43421 .76443 .431 .76014 .42373 Metetra
.659 .682 .861 r
.76014 .42373 .76443 .431 .77379 .42802 .76952 .4207 Metetra
.647 .676 .863 r
.76952 .4207 .77379 .42802 .7832 .42525 .77895 .41799 Metetra
.642 .676 .867 r
.77895 .41799 .7832 .42525 .79265 .42259 .78843 .41543 Metetra
.626 .672 .874 r
.78843 .41543 .79265 .42259 .80216 .4202 .79798 .41328 Metetra
.61 .673 .885 r
.79798 .41328 .80216 .4202 .81173 .41809 .80759 .41153 Metetra
.603 .683 .898 r
.80759 .41153 .81173 .41809 .82134 .41606 .81726 .40989 Metetra
.606 .7 .91 r
.81726 .40989 .82134 .41606 .83098 .41393 .82696 .40812 Metetra
.621 .722 .918 r
.82696 .40812 .83098 .41393 .84063 .41153 .83666 .40597 Metetra
.633 .737 .923 r
.83666 .40597 .84063 .41153 .8503 .40892 .84636 .40351 Metetra
.639 .747 .927 r
.84636 .40351 .8503 .40892 .85999 .4062 .85609 .4009 Metetra
.644 .755 .929 r
.85609 .4009 .85999 .4062 .86971 .40338 .86584 .39815 Metetra
.647 .76 .931 r
.86584 .39815 .86971 .40338 .87945 .4005 .87562 .39532 Metetra
.653 .765 .932 r
.87562 .39532 .87945 .4005 .88922 .39752 .88541 .39234 Metetra
.657 .768 .931 r
.88541 .39234 .88922 .39752 .89901 .39447 .89523 .38927 Metetra
.682 .762 .912 r
.28178 .57361 .28694 .57798 .29488 .57513 .28974 .57061 Metetra
.687 .758 .906 r
.28974 .57061 .29488 .57513 .30285 .57218 .29774 .56749 Metetra
.689 .752 .899 r
.29774 .56749 .30285 .57218 .31084 .56917 .30575 .56429 Metetra
.691 .746 .893 r
.30575 .56429 .31084 .56917 .31886 .5661 .3138 .56102 Metetra
.689 .738 .888 r
.3138 .56102 .31886 .5661 .32689 .56305 .32186 .55778 Metetra
.682 .729 .886 r
.32186 .55778 .32689 .56305 .33494 .56012 .32993 .5547 Metetra
.671 .721 .887 r
.32993 .5547 .33494 .56012 .34301 .55738 .33801 .55186 Metetra
.657 .714 .89 r
.33801 .55186 .34301 .55738 .35108 .55487 .3461 .54935 Metetra
.647 .711 .894 r
.3461 .54935 .35108 .55487 .35917 .55253 .3542 .54705 Metetra
.639 .711 .899 r
.3542 .54705 .35917 .55253 .36728 .55031 .36232 .54491 Metetra
.623 .71 .908 r
.36232 .54491 .36728 .55031 .37541 .54832 .37045 .54309 Metetra
.622 .717 .914 r
.37045 .54309 .37541 .54832 .38356 .54632 .37861 .54126 Metetra
.643 .731 .912 r
.37861 .54126 .38356 .54632 .39175 .544 .38681 .539 Metetra
.677 .744 .901 r
.38681 .539 .39175 .544 .39999 .5411 .39507 .53598 Metetra
.71 .748 .881 r
.39507 .53598 .39999 .5411 .40828 .53753 .40339 .53207 Metetra
.714 .737 .869 r
.40339 .53207 .40828 .53753 .41659 .53382 .41173 .52797 Metetra
.708 .722 .861 r
.41173 .52797 .41659 .53382 .42492 .53016 .42009 .52396 Metetra
.706 .711 .852 r
.42009 .52396 .42492 .53016 .43327 .52648 .42846 .5199 Metetra
.669 .688 .859 r
.42846 .5199 .43327 .52648 .44163 .52359 .43683 .51691 Metetra
.578 .649 .884 r
.43683 .51691 .44163 .52359 .44997 .52232 .44517 .51606 Metetra
.328 .542 .908 r
.44517 .51606 .44997 .52232 .45829 .52358 .45347 .51857 Metetra
0 .231 .725 r
.45347 .51857 .45829 .52358 .46661 .52747 .46176 .52459 Metetra
.584 .029 0 r
.46176 .52459 .46661 .52747 .47498 .53224 .47009 .53178 Metetra
.689 .15 0 r
.47009 .53178 .47498 .53224 .48341 .53697 .47851 .53895 Metetra
.679 .18 .055 r
.47851 .53895 .48341 .53697 .49191 .54106 .48701 .54527 Metetra
.558 .08 .075 r
.48701 .54527 .49191 .54106 .50049 .54266 .49561 .54828 Metetra
.259 0 0 r
.49561 .54828 .50049 .54266 .50914 .54024 .50431 .54593 Metetra
.575 .834 .473 r
.50431 .54593 .50914 .54024 .51783 .53154 .51306 .5352 Metetra
.967 .935 .643 r
.51306 .5352 .51783 .53154 .52651 .51674 .5218 .51635 Metetra
.968 .842 .664 r
.5218 .51635 .52651 .51674 .53515 .49919 .53049 .49391 Metetra
.919 .756 .663 r
.53049 .49391 .53515 .49919 .54374 .4808 .53909 .4704 Metetra
.861 .685 .662 r
.53909 .4704 .54374 .4808 .55227 .46346 .54762 .44836 Metetra
.796 .621 .664 r
.54762 .44836 .55227 .46346 .5608 .44924 .55611 .43047 Metetra
.719 .558 .67 r
.55611 .43047 .5608 .44924 .56935 .43986 .56463 .41898 Metetra
.581 .46 .679 r
.56463 .41898 .56935 .43986 .57803 .43844 .57329 .41795 Metetra
.366 .32 .674 r
.57329 .41795 .57803 .43844 .58688 .44458 .58216 .42689 Metetra
.106 .166 .643 r
.58216 .42689 .58688 .44458 .59591 .45502 .59123 .44151 Metetra
0 0 .542 r
.59123 .44151 .59591 .45502 .60508 .46762 .6005 .45905 Metetra
0 0 .355 r
.6005 .45905 .60508 .46762 .61436 .47983 .60989 .47614 Metetra
.793 .314 0 r
.60989 .47614 .61436 .47983 .6237 .49044 .61936 .49115 Metetra
.771 .278 .048 r
.61936 .49115 .6237 .49044 .63304 .49793 .62883 .50205 Metetra
.533 .039 .03 r
.62883 .50205 .63304 .49793 .64225 .49935 .63813 .50487 Metetra
.078 0 0 r
.63813 .50487 .64225 .49935 .6513 .49515 .64721 .50019 Metetra
.64721 .50019 .6513 .49515 .66023 .4875 .65613 .49091 Metetra
.752 .944 .617 r
.65613 .49091 .66023 .4875 .66909 .47825 .66496 .47949 Metetra
.874 .993 .762 r
.66496 .47949 .66909 .47825 .67797 .4693 .67379 .4685 Metetra
.907 .954 .815 r
.67379 .4685 .67797 .4693 .68684 .46051 .68261 .45773 Metetra
.882 .887 .832 r
.68261 .45773 .68684 .46051 .69575 .45237 .69146 .44784 Metetra
.81 .819 .858 r
.69146 .44784 .69575 .45237 .70476 .44613 .70044 .44048 Metetra
.74 .763 .871 r
.70044 .44048 .70476 .44613 .71387 .44153 .70954 .43529 Metetra
.689 .726 .878 r
.70954 .43529 .71387 .44153 .72308 .43801 .71875 .43154 Metetra
.68 .715 .875 r
.71875 .43154 .72308 .43801 .73231 .43464 .728 .428 Metetra
.7 .718 .863 r
.728 .428 .73231 .43464 .74155 .43079 .73723 .42383 Metetra
.691 .705 .858 r
.73723 .42383 .74155 .43079 .75082 .4271 .74651 .41986 Metetra
.675 .69 .857 r
.74651 .41986 .75082 .4271 .76014 .42373 .75583 .41634 Metetra
.659 .679 .858 r
.75583 .41634 .76014 .42373 .76952 .4207 .76522 .41326 Metetra
.645 .672 .862 r
.76522 .41326 .76952 .4207 .77895 .41799 .77468 .4106 Metetra
.637 .671 .866 r
.77468 .4106 .77895 .41799 .78843 .41543 .78418 .40815 Metetra
.616 .665 .874 r
.78418 .40815 .78843 .41543 .79798 .41328 .79376 .40625 Metetra
.593 .663 .887 r
.79376 .40625 .79798 .41328 .80759 .41153 .80343 .40488 Metetra
.584 .672 .9 r
.80343 .40488 .80759 .41153 .81726 .40989 .81316 .40366 Metetra
.588 .69 .912 r
.81316 .40366 .81726 .40989 .82696 .40812 .82291 .40227 Metetra
.609 .715 .92 r
.82291 .40227 .82696 .40812 .83666 .40597 .83266 .40037 Metetra
.625 .734 .925 r
.83266 .40037 .83666 .40597 .84636 .40351 .8424 .39808 Metetra
.633 .745 .929 r
.8424 .39808 .84636 .40351 .85609 .4009 .85217 .39558 Metetra
.64 .754 .931 r
.85217 .39558 .85609 .4009 .86584 .39815 .86195 .39291 Metetra
.644 .76 .933 r
.86195 .39291 .86584 .39815 .87562 .39532 .87176 .39012 Metetra
.652 .766 .933 r
.87176 .39012 .87562 .39532 .88541 .39234 .88158 .38715 Metetra
.657 .769 .932 r
.88158 .38715 .88541 .39234 .89523 .38927 .89142 .38405 Metetra
.686 .761 .909 r
.27659 .56916 .28178 .57361 .28974 .57061 .28458 .56606 Metetra
.692 .758 .903 r
.28458 .56606 .28974 .57061 .29774 .56749 .2926 .5628 Metetra
.695 .754 .898 r
.2926 .5628 .29774 .56749 .30575 .56429 .30064 .55946 Metetra
.697 .749 .892 r
.30064 .55946 .30575 .56429 .3138 .56102 .30871 .55604 Metetra
.695 .743 .889 r
.30871 .55604 .3138 .56102 .32186 .55778 .31679 .55264 Metetra
.686 .736 .889 r
.31679 .55264 .32186 .55778 .32993 .5547 .32489 .54944 Metetra
.674 .729 .892 r
.32489 .54944 .32993 .5547 .33801 .55186 .33298 .54653 Metetra
.657 .722 .897 r
.33298 .54653 .33801 .55186 .3461 .54935 .34108 .54401 Metetra
.645 .719 .902 r
.34108 .54401 .3461 .54935 .3542 .54705 .3492 .54174 Metetra
.635 .718 .907 r
.3492 .54174 .3542 .54705 .36232 .54491 .35732 .53967 Metetra
.615 .714 .916 r
.35732 .53967 .36232 .54491 .37045 .54309 .36546 .53797 Metetra
.614 .72 .921 r
.36546 .53797 .37045 .54309 .37861 .54126 .37362 .53626 Metetra
.64 .734 .916 r
.37362 .53626 .37861 .54126 .38681 .539 .38184 .53404 Metetra
.681 .747 .901 r
.38184 .53404 .38681 .539 .39507 .53598 .39012 .53092 Metetra
.719 .753 .879 r
.39012 .53092 .39507 .53598 .40339 .53207 .39846 .52676 Metetra
.724 .745 .868 r
.39846 .52676 .40339 .53207 .41173 .52797 .40683 .52236 Metetra
.718 .734 .863 r
.40683 .52236 .41173 .52797 .42009 .52396 .41521 .51807 Metetra
.717 .725 .856 r
.41521 .51807 .42009 .52396 .42846 .5199 .42361 .51373 Metetra
.673 .703 .87 r
.42361 .51373 .42846 .5199 .43683 .51691 .43199 .51066 Metetra
.556 .656 .902 r
.43199 .51066 .43683 .51691 .44517 .51606 .44033 .51012 Metetra
.204 .486 .897 r
.44033 .51012 .44517 .51606 .45347 .51857 .44862 .51357 Metetra
0 .068 .574 r
.44862 .51357 .45347 .51857 .46176 .52459 .45688 .52119 Metetra
.671 .141 0 r
.45688 .52119 .46176 .52459 .47009 .53178 .46519 .53021 Metetra
.737 .212 0 r
.46519 .53021 .47009 .53178 .47851 .53895 .47359 .53923 Metetra
.725 .212 0 r
.47359 .53923 .47851 .53895 .48701 .54527 .48209 .54724 Metetra
.578 .048 0 r
.48209 .54724 .48701 .54527 .49561 .54828 .49071 .55132 Metetra
.057 0 0 r
.49071 .55132 .49561 .54828 .50431 .54593 .49944 .54902 Metetra
.878 .985 .711 r
.49944 .54902 .50431 .54593 .51306 .5352 .50825 .53674 Metetra
.981 .879 .656 r
.50825 .53674 .51306 .5352 .5218 .51635 .51706 .51482 Metetra
.961 .807 .644 r
.51706 .51482 .5218 .51635 .53049 .49391 .52579 .48867 Metetra
.928 .751 .643 r
.52579 .48867 .53049 .49391 .53909 .4704 .53443 .46131 Metetra
.887 .704 .649 r
.53443 .46131 .53909 .4704 .54762 .44836 .54297 .43574 Metetra
.834 .656 .662 r
.54297 .43574 .54762 .44836 .55611 .43047 .55147 .41512 Metetra
.757 .599 .681 r
.55147 .41512 .55611 .43047 .56463 .41898 .55997 .40206 Metetra
.579 .482 .709 r
.55997 .40206 .56463 .41898 .57329 .41795 .56862 .40132 Metetra
.219 .252 .683 r
.56862 .40132 .57329 .41795 .58216 .42689 .57749 .41233 Metetra
0 0 .551 r
.57749 .41233 .58216 .42689 .59123 .44151 .58659 .43007 Metetra
0 0 .33 r
.58659 .43007 .59123 .44151 .6005 .45905 .59591 .4513 Metetra
.774 .366 0 r
.59591 .4513 .6005 .45905 .60989 .47614 .60538 .47206 Metetra
.841 .389 0 r
.60538 .47206 .60989 .47614 .61936 .49115 .61494 .4904 Metetra
.81 .325 .028 r
.61494 .4904 .61936 .49115 .62883 .50205 .6245 .50389 Metetra
.537 0 0 r
.6245 .50389 .62883 .50205 .63813 .50487 .63387 .50777 Metetra
.63387 .50777 .63813 .50487 .64721 .50019 .64298 .50271 Metetra
.786 .977 .696 r
.64298 .50271 .64721 .50019 .65613 .49091 .65191 .49218 Metetra
.921 .977 .734 r
.65191 .49218 .65613 .49091 .66496 .47949 .66072 .47912 Metetra
.932 .949 .776 r
.66072 .47912 .66496 .47949 .67379 .4685 .66952 .46658 Metetra
.922 .904 .789 r
.66952 .46658 .67379 .4685 .68261 .45773 .67831 .4543 Metetra
.892 .858 .801 r
.67831 .4543 .68261 .45773 .69146 .44784 .68714 .44309 Metetra
.825 .813 .839 r
.68714 .44309 .69146 .44784 .70044 .44048 .6961 .43488 Metetra
.753 .769 .867 r
.6961 .43488 .70044 .44048 .70954 .43529 .7052 .42924 Metetra
.695 .736 .882 r
.7052 .42924 .70954 .43529 .71875 .43154 .71442 .42532 Metetra
.686 .727 .881 r
.71442 .42532 .71875 .43154 .728 .428 .72368 .42165 Metetra
.709 .732 .868 r
.72368 .42165 .728 .428 .73723 .42383 .73292 .41723 Metetra
.7 .72 .866 r
.73292 .41723 .73723 .42383 .74651 .41986 .7422 .41305 Metetra
.681 .707 .867 r
.7422 .41305 .74651 .41986 .75583 .41634 .75154 .4094 Metetra
.662 .696 .871 r
.75154 .4094 .75583 .41634 .76522 .41326 .76094 .40628 Metetra
.643 .687 .876 r
.76094 .40628 .76522 .41326 .77468 .4106 .77042 .40366 Metetra
.634 .684 .88 r
.77042 .40366 .77468 .4106 .78418 .40815 .77995 .40129 Metetra
.607 .675 .889 r
.77995 .40129 .78418 .40815 .79376 .40625 .78956 .39956 Metetra
.578 .668 .901 r
.78956 .39956 .79376 .40625 .80343 .40488 .79927 .39847 Metetra
.566 .673 .911 r
.79927 .39847 .80343 .40488 .81316 .40366 .80905 .39756 Metetra
.571 .689 .92 r
.80905 .39756 .81316 .40366 .82291 .40227 .81884 .39646 Metetra
.598 .714 .925 r
.81884 .39646 .82291 .40227 .83266 .40037 .82863 .39475 Metetra
.618 .731 .927 r
.82863 .39475 .83266 .40037 .8424 .39808 .83842 .39257 Metetra
.629 .742 .929 r
.83842 .39257 .8424 .39808 .85217 .39558 .84821 .39015 Metetra
.637 .749 .93 r
.84821 .39015 .85217 .39558 .86195 .39291 .85803 .38754 Metetra
.643 .755 .93 r
.85803 .38754 .86195 .39291 .87176 .39012 .86786 .38478 Metetra
.652 .761 .929 r
.86786 .38478 .87176 .39012 .88158 .38715 .87771 .3818 Metetra
.658 .764 .928 r
.87771 .3818 .88158 .38715 .89142 .38405 .88758 .37868 Metetra
.687 .757 .905 r
.27138 .56459 .27659 .56916 .28458 .56606 .27939 .56145 Metetra
.693 .757 .901 r
.27939 .56145 .28458 .56606 .2926 .5628 .28742 .55814 Metetra
.696 .757 .898 r
.28742 .55814 .2926 .5628 .30064 .55946 .29548 .55475 Metetra
.699 .756 .895 r
.29548 .55475 .30064 .55946 .30871 .55604 .30357 .55127 Metetra
.698 .754 .895 r
.30357 .55127 .30871 .55604 .31679 .55264 .31167 .54781 Metetra
.689 .75 .898 r
.31167 .54781 .31679 .55264 .32489 .54944 .31979 .54457 Metetra
.675 .746 .904 r
.31979 .54457 .32489 .54944 .33298 .54653 .3279 .54163 Metetra
.657 .741 .911 r
.3279 .54163 .33298 .54653 .34108 .54401 .33602 .53909 Metetra
.644 .737 .917 r
.33602 .53909 .34108 .54401 .3492 .54174 .34414 .53682 Metetra
.632 .734 .921 r
.34414 .53682 .3492 .54174 .35732 .53967 .35228 .53476 Metetra
.61 .728 .929 r
.35228 .53476 .35732 .53967 .36546 .53797 .36043 .53309 Metetra
.61 .73 .931 r
.36043 .53309 .36546 .53797 .37362 .53626 .36861 .53141 Metetra
.639 .741 .922 r
.36861 .53141 .37362 .53626 .38184 .53404 .37684 .52918 Metetra
.682 .753 .905 r
.37684 .52918 .38184 .53404 .39012 .53092 .38513 .52603 Metetra
.723 .761 .883 r
.38513 .52603 .39012 .53092 .39846 .52676 .3935 .52177 Metetra
.73 .76 .876 r
.3935 .52177 .39846 .52676 .40683 .52236 .40189 .51728 Metetra
.726 .756 .876 r
.40189 .51728 .40683 .52236 .41521 .51807 .41029 .5129 Metetra
.726 .753 .874 r
.41029 .5129 .41521 .51807 .42361 .51373 .41871 .50847 Metetra
.678 .738 .896 r
.41871 .50847 .42361 .51373 .43199 .51066 .42711 .50536 Metetra
.534 .687 .937 r
.42711 .50536 .43199 .51066 .44033 .51012 .43546 .5049 Metetra
.101 .457 .886 r
.43546 .5049 .44033 .51012 .44862 .51357 .44374 .50862 Metetra
0 .019 .522 r
.44374 .50862 .44862 .51357 .45688 .52119 .45199 .51671 Metetra
.632 .122 0 r
.45199 .51671 .45688 .52119 .46519 .53021 .4603 .52627 Metetra
.663 .143 0 r
.4603 .52627 .46519 .53021 .47359 .53923 .46869 .53582 Metetra
.628 .091 0 r
.46869 .53582 .47359 .53923 .48209 .54724 .47718 .54433 Metetra
0 .286 .685 r
.47718 .54433 .48209 .54724 .49071 .55132 .48581 .54872 Metetra
.589 .846 .993 r
.48581 .54872 .49071 .55132 .49944 .54902 .49457 .54643 Metetra
.905 .848 .776 r
.49457 .54643 .49944 .54902 .50825 .53674 .50342 .53367 Metetra
.94 .793 .67 r
.50342 .53367 .50825 .53674 .51706 .51482 .51228 .51081 Metetra
.939 .768 .644 r
.51228 .51081 .51706 .51482 .52579 .48867 .52107 .48355 Metetra
.931 .752 .637 r
.52107 .48355 .52579 .48867 .53443 .46131 .52976 .45503 Metetra
.917 .739 .645 r
.52976 .45503 .53443 .46131 .54297 .43574 .53835 .42841 Metetra
.892 .727 .671 r
.53835 .42841 .54297 .43574 .55147 .41512 .54687 .40696 Metetra
.836 .707 .722 r
.54687 .40696 .55147 .41512 .55997 .40206 .5554 .39343 Metetra
.575 .595 .835 r
.5554 .39343 .55997 .40206 .56862 .40132 .56405 .39276 Metetra
0 .03 .6 r
.56405 .39276 .56862 .40132 .57749 .41233 .57292 .40437 Metetra
.725 .32 0 r
.57292 .40437 .57749 .41233 .58659 .43007 .58202 .42302 Metetra
.836 .425 0 r
.58202 .42302 .58659 .43007 .59591 .4513 .59135 .44534 Metetra
.852 .429 0 r
.59135 .44534 .59591 .4513 .60538 .47206 .60082 .46718 Metetra
.838 .395 0 r
.60082 .46718 .60538 .47206 .61494 .4904 .6104 .48651 Metetra
.763 .276 0 r
.6104 .48651 .61494 .4904 .6245 .50389 .61999 .50076 Metetra
0 .378 .782 r
.61999 .50076 .6245 .50389 .63387 .50777 .62938 .50495 Metetra
.751 .887 .94 r
.62938 .50495 .63387 .50777 .64298 .50271 .63852 .49977 Metetra
.891 .873 .812 r
.63852 .49977 .64298 .50271 .65191 .49218 .64747 .48885 Metetra
.914 .848 .765 r
.64747 .48885 .65191 .49218 .66072 .47912 .6563 .47528 Metetra
.903 .836 .77 r
.6563 .47528 .66072 .47912 .66952 .46658 .66512 .46226 Metetra
.893 .823 .771 r
.66512 .46226 .66952 .46658 .67831 .4543 .67393 .44953 Metetra
.875 .811 .783 r
.67393 .44953 .67831 .4543 .68714 .44309 .68276 .4379 Metetra
.823 .798 .828 r
.68276 .4379 .68714 .44309 .6961 .43488 .69174 .42942 Metetra
.758 .777 .869 r
.69174 .42942 .6961 .43488 .7052 .42924 .70086 .42365 Metetra
.699 .755 .895 r
.70086 .42365 .7052 .42924 .71442 .42532 .7101 .41966 Metetra
.689 .75 .898 r
.7101 .41966 .71442 .42532 .72368 .42165 .71938 .41593 Metetra
.717 .758 .885 r
.71938 .41593 .72368 .42165 .73292 .41723 .72864 .41142 Metetra
.707 .752 .887 r
.72864 .41142 .73292 .41723 .7422 .41305 .73793 .40717 Metetra
.687 .743 .894 r
.73793 .40717 .7422 .41305 .75154 .4094 .74729 .40347 Metetra
.665 .734 .901 r
.74729 .40347 .75154 .4094 .76094 .40628 .75672 .40033 Metetra
.643 .724 .908 r
.75672 .40033 .76094 .40628 .77042 .40366 .76621 .3977 Metetra
.631 .72 .911 r
.76621 .3977 .77042 .40366 .77995 .40129 .77576 .39534 Metetra
.599 .707 .92 r
.77576 .39534 .77995 .40129 .78956 .39956 .7854 .39366 Metetra
.564 .693 .927 r
.7854 .39366 .78956 .39956 .79927 .39847 .79514 .39264 Metetra
.553 .691 .931 r
.79514 .39264 .79927 .39847 .80905 .39756 .80494 .39181 Metetra
.562 .7 .933 r
.80494 .39181 .80905 .39756 .81884 .39646 .81477 .39078 Metetra
.594 .718 .931 r
.81477 .39078 .81884 .39646 .82863 .39475 .82458 .38911 Metetra
.616 .731 .928 r
.82458 .38911 .82863 .39475 .83842 .39257 .83439 .38696 Metetra
.628 .738 .927 r
.83439 .38696 .83842 .39257 .84821 .39015 .84422 .38455 Metetra
.637 .743 .925 r
.84422 .38455 .84821 .39015 .85803 .38754 .85406 .38193 Metetra
.643 .746 .924 r
.85406 .38193 .85803 .38754 .86786 .38478 .86392 .37917 Metetra
.652 .751 .922 r
.86392 .37917 .86786 .38478 .87771 .3818 .87379 .37618 Metetra
.658 .754 .921 r
.87379 .37618 .87771 .3818 .88758 .37868 .88368 .37304 Metetra
.683 .75 .902 r
.26616 .55984 .27138 .56459 .27939 .56145 .27417 .55676 Metetra
.689 .755 .902 r
.27417 .55676 .27939 .56145 .28742 .55814 .28221 .55354 Metetra
.692 .759 .903 r
.28221 .55354 .28742 .55814 .29548 .55475 .29028 .55025 Metetra
.695 .765 .905 r
.29028 .55025 .29548 .55475 .30357 .55127 .29838 .54687 Metetra
.694 .77 .909 r
.29838 .54687 .30357 .55127 .31167 .54781 .30649 .54352 Metetra
.686 .773 .917 r
.30649 .54352 .31167 .54781 .31979 .54457 .31462 .54035 Metetra
.673 .774 .926 r
.31462 .54035 .31979 .54457 .3279 .54163 .32274 .53745 Metetra
.655 .772 .935 r
.32274 .53745 .3279 .54163 .33602 .53909 .33088 .53489 Metetra
.642 .769 .94 r
.33088 .53489 .33602 .53909 .34414 .53682 .33902 .53256 Metetra
.631 .764 .943 r
.33902 .53256 .34414 .53682 .35228 .53476 .34718 .53042 Metetra
.611 .755 .947 r
.34718 .53042 .35228 .53476 .36043 .53309 .35535 .52862 Metetra
.612 .75 .943 r
.35535 .52862 .36043 .53309 .36861 .53141 .36355 .52681 Metetra
.64 .753 .931 r
.36355 .52681 .36861 .53141 .37684 .52918 .37179 .52452 Metetra
.68 .762 .913 r
.37179 .52452 .37684 .52918 .38513 .52603 .38011 .52142 Metetra
.718 .773 .896 r
.38011 .52142 .38513 .52603 .3935 .52177 .38848 .51736 Metetra
.727 .783 .897 r
.38848 .51736 .3935 .52177 .40189 .51728 .39688 .51309 Metetra
.724 .792 .906 r
.39688 .51309 .40189 .51728 .41029 .5129 .40529 .50891 Metetra
.727 .803 .912 r
.40529 .50891 .41029 .5129 .41871 .50847 .41373 .50469 Metetra
.674 .804 .944 r
.41373 .50469 .41871 .50847 .42711 .50536 .42215 .50163 Metetra
.509 .754 .984 r
.42215 .50163 .42711 .50536 .43546 .5049 .43052 .50088 Metetra
.08 .504 .9 r
.43052 .50088 .43546 .5049 .44374 .50862 .43884 .50377 Metetra
0 .146 .642 r
.43884 .50377 .44374 .50862 .45199 .51671 .44712 .51046 Metetra
0 .114 .648 r
.44712 .51046 .45199 .51671 .4603 .52627 .45545 .51843 Metetra
0 .197 .727 r
.45545 .51843 .4603 .52627 .46869 .53582 .46386 .52638 Metetra
.105 .304 .78 r
.46386 .52638 .46869 .53582 .47718 .54433 .47237 .53342 Metetra
.409 .459 .801 r
.47237 .53342 .47718 .54433 .48581 .54872 .481 .53686 Metetra
.624 .565 .768 r
.481 .53686 .48581 .54872 .49457 .54643 .48976 .5345 Metetra
.771 .637 .713 r
.48976 .5345 .49457 .54643 .50342 .53367 .49861 .52303 Metetra
.849 .681 .673 r
.49861 .52303 .50342 .53367 .51228 .51081 .5075 .50278 Metetra
.892 .718 .659 r
.5075 .50278 .51228 .51081 .52107 .48355 .51632 .47864 Metetra
.928 .76 .654 r
.51632 .47864 .52107 .48355 .52976 .45503 .52507 .45337 Metetra
.96 .816 .657 r
.52507 .45337 .52976 .45503 .53835 .42841 .53372 .42971 Metetra
.977 .9 .673 r
.53372 .42971 .53835 .42841 .54687 .40696 .54232 .41056 Metetra
.838 .971 .657 r
.54232 .41056 .54687 .40696 .5554 .39343 .55091 .39833 Metetra
.334 0 0 r
.55091 .39833 .5554 .39343 .56405 .39276 .5596 .39739 Metetra
.741 .309 .224 r
.5596 .39739 .56405 .39276 .57292 .40437 .56848 .40721 Metetra
.83 .41 .24 r
.56848 .40721 .57292 .40437 .58202 .42302 .57755 .42318 Metetra
.871 .445 .192 r
.57755 .42318 .58202 .42302 .59135 .44534 .58681 .44233 Metetra
.864 .416 .05 r
.58681 .44233 .59135 .44534 .60082 .46718 .59621 .46101 Metetra
.731 .286 0 r
.59621 .46101 .60082 .46718 .6104 .48651 .60571 .47747 Metetra
0 .063 .627 r
.60571 .47747 .6104 .48651 .61999 .50076 .61522 .48948 Metetra
.434 .471 .799 r
.61522 .48948 .61999 .50076 .62938 .50495 .62458 .49272 Metetra
.675 .592 .754 r
.62458 .49272 .62938 .50495 .63852 .49977 .63373 .48783 Metetra
.756 .635 .727 r
.63373 .48783 .63852 .49977 .64747 .48885 .64273 .47795 Metetra
.794 .665 .721 r
.64273 .47795 .64747 .48885 .6563 .47528 .65163 .46575 Metetra
.806 .689 .736 r
.65163 .46575 .6563 .47528 .66512 .46226 .66053 .45403 Metetra
.821 .716 .75 r
.66053 .45403 .66512 .46226 .67393 .44953 .66942 .44254 Metetra
.827 .746 .774 r
.66942 .44254 .67393 .44953 .68276 .4379 .67833 .43202 Metetra
.8 .772 .828 r
.67833 .43202 .68276 .4379 .69174 .42942 .68737 .42423 Metetra
.75 .787 .882 r
.68737 .42423 .69174 .42942 .70086 .42365 .69654 .4188 Metetra
.697 .787 .92 r
.69654 .4188 .70086 .42365 .7101 .41966 .70581 .41493 Metetra
.687 .79 .928 r
.70581 .41493 .7101 .41966 .71938 .41593 .71512 .41128 Metetra
.715 .803 .919 r
.71512 .41128 .71938 .41593 .72864 .41142 .72441 .40696 Metetra
.706 .809 .929 r
.72441 .40696 .72864 .41142 .73793 .40717 .73375 .40285 Metetra
.684 .81 .943 r
.73375 .40285 .73793 .40717 .74729 .40347 .74314 .39922 Metetra
.658 .806 .954 r
.74314 .39922 .74729 .40347 .75672 .40033 .75259 .39608 Metetra
.633 .797 .961 r
.75259 .39608 .75672 .40033 .76621 .3977 .76211 .39339 Metetra
.621 .79 .963 r
.76211 .39339 .76621 .3977 .77576 .39534 .77168 .39093 Metetra
.587 .772 .968 r
.77168 .39093 .77576 .39534 .7854 .39366 .78133 .38906 Metetra
.554 .749 .968 r
.78133 .38906 .7854 .39366 .79514 .39264 .79107 .38776 Metetra
.55 .734 .961 r
.79107 .38776 .79514 .39264 .80494 .39181 .80087 .38663 Metetra
.566 .729 .951 r
.80087 .38663 .80494 .39181 .81477 .39078 .81069 .38533 Metetra
.6 .733 .938 r
.81069 .38533 .81477 .39078 .82458 .38911 .82051 .38346 Metetra
.622 .735 .928 r
.82051 .38346 .82458 .38911 .83439 .38696 .83033 .38118 Metetra
.632 .735 .922 r
.83033 .38118 .83439 .38696 .84422 .38455 .84017 .37866 Metetra
.64 .735 .917 r
.84017 .37866 .84422 .38455 .85406 .38193 .85003 .37597 Metetra
.646 .734 .914 r
.85003 .37597 .85406 .38193 .86392 .37917 .85991 .37314 Metetra
.654 .736 .91 r
.85991 .37314 .86392 .37917 .87379 .37618 .8698 .37012 Metetra
.659 .738 .908 r
.8698 .37012 .87379 .37618 .88368 .37304 .87972 .36696 Metetra
.674 .741 .901 r
.26092 .55488 .26616 .55984 .27417 .55676 .26893 .55199 Metetra
.678 .75 .905 r
.26893 .55199 .27417 .55676 .28221 .55354 .27697 .54901 Metetra
.68 .761 .912 r
.27697 .54901 .28221 .55354 .29028 .55025 .28504 .54598 Metetra
.683 .773 .92 r
.28504 .54598 .29028 .55025 .29838 .54687 .29313 .54289 Metetra
.682 .786 .929 r
.29313 .54289 .29838 .54687 .30649 .54352 .30124 .53981 Metetra
.675 .799 .941 r
.30124 .53981 .30649 .54352 .31462 .54035 .30937 .53684 Metetra
.663 .807 .952 r
.30937 .53684 .31462 .54035 .32274 .53745 .31751 .53405 Metetra
.648 .81 .961 r
.31751 .53405 .32274 .53745 .33088 .53489 .32566 .53147 Metetra
.639 .807 .964 r
.32566 .53147 .33088 .53489 .33902 .53256 .33382 .52904 Metetra
.632 .801 .963 r
.33382 .52904 .33902 .53256 .34718 .53042 .34201 .52672 Metetra
.62 .789 .963 r
.34201 .52672 .34718 .53042 .35535 .52862 .35021 .52461 Metetra
.624 .777 .954 r
.35021 .52461 .35535 .52862 .36355 .52681 .35844 .5225 Metetra
.645 .769 .938 r
.35844 .5225 .36355 .52681 .37179 .52452 .36671 .52008 Metetra
.672 .77 .924 r
.36671 .52008 .37179 .52452 .38011 .52142 .37503 .51713 Metetra
.699 .784 .916 r
.37503 .51713 .38011 .52142 .38848 .51736 .3834 .51357 Metetra
.705 .808 .929 r
.3834 .51357 .38848 .51736 .39688 .51309 .3918 .50988 Metetra
.701 .835 .947 r
.3918 .50988 .39688 .51309 .40529 .50891 .40022 .50624 Metetra
.697 .861 .96 r
.40022 .50624 .40529 .50891 .41373 .50469 .40866 .50257 Metetra
.635 .877 .986 r
.40866 .50257 .41373 .50469 .42215 .50163 .41709 .49963 Metetra
.483 .831 .997 r
.41709 .49963 .42215 .50163 .43052 .50088 .42551 .49817 Metetra
.231 .667 .956 r
.42551 .49817 .43052 .50088 .43884 .50377 .4339 .49903 Metetra
.106 .486 .899 r
.4339 .49903 .43884 .50377 .44712 .51046 .44227 .5023 Metetra
.276 .449 .852 r
.44227 .5023 .44712 .51046 .45545 .51843 .45068 .50636 Metetra
.398 .43 .777 r
.45068 .50636 .45545 .51843 .46386 .52638 .45915 .5104 Metetra
.468 .423 .725 r
.45915 .5104 .46386 .52638 .47237 .53342 .46769 .51383 Metetra
.538 .441 .693 r
.46769 .51383 .47237 .53342 .481 .53686 .47633 .51499 Metetra
.6 .47 .675 r
.47633 .51499 .481 .53686 .48976 .5345 .48506 .51247 Metetra
.671 .515 .665 r
.48506 .51247 .48976 .5345 .49861 .52303 .49387 .5042 Metetra
.74 .572 .666 r
.49387 .5042 .49861 .52303 .5075 .50278 .50272 .49035 Metetra
.809 .649 .684 r
.50272 .49035 .5075 .50278 .51632 .47864 .51155 .47397 Metetra
.905 .781 .713 r
.51155 .47397 .51632 .47864 .52507 .45337 .52033 .45681 Metetra
.942 .957 .66 r
.52033 .45681 .52507 .45337 .53372 .42971 .52907 .4406 Metetra
.52907 .4406 .53372 .42971 .54232 .41056 .53777 .42725 Metetra
.266 0 .26 r
.53777 .42725 .54232 .41056 .55091 .39833 .54648 .41833 Metetra
.492 .185 .373 r
.54648 .41833 .55091 .39833 .5596 .39739 .55525 .41671 Metetra
.602 .282 .401 r
.55525 .41671 .5596 .39739 .56848 .40721 .56413 .42205 Metetra
.666 .322 .381 r
.56413 .42205 .56848 .40721 .57755 .42318 .57315 .43131 Metetra
.731 .339 .308 r
.57315 .43131 .57755 .42318 .58681 .44233 .5823 .44256 Metetra
.772 .275 .027 r
.5823 .44256 .58681 .44233 .59621 .46101 .59155 .45343 Metetra
0 .15 .692 r
.59155 .45343 .59621 .46101 .60571 .47747 .60087 .46283 Metetra
.353 .37 .738 r
.60087 .46283 .60571 .47747 .61522 .48948 .61021 .46936 Metetra
.543 .444 .692 r
.61021 .46936 .61522 .48948 .62458 .49272 .61947 .47033 Metetra
.621 .483 .673 r
.61947 .47033 .62458 .49272 .63373 .48783 .62863 .46617 Metetra
.661 .512 .671 r
.62863 .46617 .63373 .48783 .64273 .47795 .6377 .45884 Metetra
.69 .542 .681 r
.6377 .45884 .64273 .47795 .65163 .46575 .64672 .45005 Metetra
.707 .574 .703 r
.64672 .45005 .65163 .46575 .66053 .45403 .65575 .44153 Metetra
.731 .617 .731 r
.65575 .44153 .66053 .45403 .66942 .44254 .66479 .43315 Metetra
.753 .672 .772 r
.66479 .43315 .66942 .44254 .67833 .43202 .67385 .42537 Metetra
.751 .737 .84 r
.67385 .42537 .67833 .43202 .68737 .42423 .68299 .41933 Metetra
.723 .793 .907 r
.68299 .41933 .68737 .42423 .69654 .4188 .69223 .41478 Metetra
.679 .821 .951 r
.69223 .41478 .69654 .4188 .70581 .41493 .70155 .41123 Metetra
.669 .834 .963 r
.70155 .41123 .70581 .41493 .71512 .41128 .7109 .40781 Metetra
.688 .852 .961 r
.7109 .40781 .71512 .41128 .72441 .40696 .72025 .40395 Metetra
.672 .872 .974 r
.72025 .40395 .72441 .40696 .73375 .40285 .72964 .40024 Metetra
.642 .882 .985 r
.72964 .40024 .73375 .40285 .74314 .39922 .73908 .39682 Metetra
.61 .883 .991 r
.73908 .39682 .74314 .39922 .75259 .39608 .74857 .39371 Metetra
.585 .875 .994 r
.74857 .39371 .75259 .39608 .76211 .39339 .75811 .39088 Metetra
.579 .867 .995 r
.75811 .39088 .76211 .39339 .77168 .39093 .76769 .3882 Metetra
.559 .848 .998 r
.76769 .3882 .77168 .39093 .78133 .38906 .77734 .38589 Metetra
.55 .822 .997 r
.77734 .38589 .78133 .38906 .79107 .38776 .78706 .38394 Metetra
.566 .796 .986 r
.78706 .38394 .79107 .38776 .80087 .38663 .79682 .3821 Metetra
.591 .772 .966 r
.79682 .3821 .80087 .38663 .81069 .38533 .80662 .38014 Metetra
.619 .754 .942 r
.80662 .38014 .81069 .38533 .82051 .38346 .81642 .37781 Metetra
.635 .742 .925 r
.81642 .37781 .82051 .38346 .83033 .38118 .82624 .37522 Metetra
.642 .733 .915 r
.82624 .37522 .83033 .38118 .84017 .37866 .83608 .37248 Metetra
.647 .727 .907 r
.83608 .37248 .84017 .37866 .85003 .37597 .84594 .36961 Metetra
.65 .723 .902 r
.84594 .36961 .85003 .37597 .85991 .37314 .85583 .36666 Metetra
.655 .721 .897 r
.85583 .36666 .85991 .37314 .8698 .37012 .86574 .36358 Metetra
.658 .721 .895 r
.86574 .36358 .8698 .37012 .87972 .36696 .87568 .36041 Metetra
.662 .734 .904 r
.25566 .54981 .26092 .55488 .26893 .55199 .26366 .54717 Metetra
.663 .745 .911 r
.26366 .54717 .26893 .55199 .27697 .54901 .27169 .54451 Metetra
.663 .759 .922 r
.27169 .54451 .27697 .54901 .28504 .54598 .27975 .54182 Metetra
.663 .775 .933 r
.27975 .54182 .28504 .54598 .29313 .54289 .28783 .53911 Metetra
.661 .793 .945 r
.28783 .53911 .29313 .54289 .30124 .53981 .29593 .5364 Metetra
.655 .81 .958 r
.29593 .5364 .30124 .53981 .30937 .53684 .30406 .53371 Metetra
.649 .823 .967 r
.30406 .53371 .30937 .53684 .31751 .53405 .31221 .53106 Metetra
.642 .829 .972 r
.31221 .53106 .31751 .53405 .32566 .53147 .32038 .52846 Metetra
.64 .828 .973 r
.32038 .52846 .32566 .53147 .33382 .52904 .32857 .52589 Metetra
.64 .822 .97 r
.32857 .52589 .33382 .52904 .34201 .52672 .33679 .52334 Metetra
.64 .811 .965 r
.33679 .52334 .34201 .52672 .35021 .52461 .34503 .52084 Metetra
.645 .794 .954 r
.34503 .52084 .35021 .52461 .35844 .5225 .35329 .51832 Metetra
.652 .778 .94 r
.35329 .51832 .35844 .5225 .36671 .52008 .36159 .51573 Metetra
.66 .773 .933 r
.36159 .51573 .36671 .52008 .37503 .51713 .36992 .513 Metetra
.667 .785 .937 r
.36992 .513 .37503 .51713 .3834 .51357 .37828 .51011 Metetra
.664 .816 .957 r
.37828 .51011 .3834 .51357 .3918 .50988 .38667 .50718 Metetra
.651 .852 .977 r
.38667 .50718 .3918 .50988 .40022 .50624 .39508 .50425 Metetra
.63 .882 .988 r
.39508 .50425 .40022 .50624 .40866 .50257 .40352 .50131 Metetra
.574 .897 .985 r
.40352 .50131 .40866 .50257 .41709 .49963 .41197 .49855 Metetra
.519 .883 .978 r
.41197 .49855 .41709 .49963 .42551 .49817 .42044 .49616 Metetra
.522 .847 .998 r
.42044 .49616 .42551 .49817 .4339 .49903 .42892 .49433 Metetra
.57 .733 .952 r
.42892 .49433 .4339 .49903 .44227 .5023 .43742 .4931 Metetra
.589 .592 .823 r
.43742 .4931 .44227 .5023 .45068 .50636 .44595 .49206 Metetra
.586 .512 .738 r
.44595 .49206 .45068 .50636 .45915 .5104 .45451 .491 Metetra
.583 .47 .691 r
.45451 .491 .45915 .5104 .46769 .51383 .46311 .48977 Metetra
.586 .451 .663 r
.46311 .48977 .46769 .51383 .47633 .51499 .47176 .48798 Metetra
.594 .446 .65 r
.47176 .48798 .47633 .51499 .48506 .51247 .48045 .48527 Metetra
.61 .457 .649 r
.48045 .48527 .48506 .51247 .49387 .5042 .48919 .48113 Metetra
.636 .488 .664 r
.48919 .48113 .49387 .5042 .50272 .49035 .49795 .4756 Metetra
.682 .564 .716 r
.49795 .4756 .50272 .49035 .51155 .47397 .50674 .46942 Metetra
.785 .801 .865 r
.50674 .46942 .51155 .47397 .52033 .45681 .51553 .46301 Metetra
.51553 .46301 .52033 .45681 .52907 .4406 .52434 .45681 Metetra
.368 .05 .289 r
.52434 .45681 .52907 .4406 .53777 .42725 .53315 .45132 Metetra
.455 .166 .384 r
.53315 .45132 .53777 .42725 .54648 .41833 .54199 .44693 Metetra
.497 .216 .417 r
.54199 .44693 .54648 .41833 .55525 .41671 .55086 .4444 Metetra
.519 .233 .419 r
.55086 .4444 .55525 .41671 .56413 .42205 .55978 .44363 Metetra
.525 .219 .39 r
.55978 .44363 .56413 .42205 .57315 .43131 .56875 .44384 Metetra
.514 .154 .293 r
.56875 .44384 .57315 .43131 .5823 .44256 .57777 .44453 Metetra
.287 0 0 r
.57777 .44453 .5823 .44256 .59155 .45343 .58685 .44509 Metetra
.532 .591 .859 r
.58685 .44509 .59155 .45343 .60087 .46283 .59596 .44526 Metetra
.571 .478 .71 r
.59596 .44526 .60087 .46283 .61021 .46936 .6051 .44469 Metetra
.587 .451 .663 r
.6051 .44469 .61021 .46936 .61947 .47033 .61425 .44274 Metetra
.598 .449 .65 r
.61425 .44274 .61947 .47033 .62863 .46617 .62339 .43952 Metetra
.609 .459 .653 r
.62339 .43952 .62863 .46617 .6377 .45884 .63254 .4355 Metetra
.62 .478 .667 r
.63254 .4355 .6377 .45884 .64672 .45005 .64169 .43111 Metetra
.632 .508 .693 r
.64169 .43111 .64672 .45005 .65575 .44153 .65088 .42679 Metetra
.649 .55 .729 r
.65088 .42679 .65575 .44153 .66479 .43315 .66008 .42248 Metetra
.669 .612 .782 r
.66008 .42248 .66479 .43315 .67385 .42537 .66932 .41831 Metetra
.682 .701 .862 r
.66932 .41831 .67385 .42537 .68299 .41933 .6786 .41457 Metetra
.674 .785 .933 r
.6786 .41457 .68299 .41933 .69223 .41478 .68792 .41119 Metetra
.65 .834 .971 r
.68792 .41119 .69223 .41478 .70155 .41123 .69729 .40806 Metetra
.639 .852 .981 r
.69729 .40806 .70155 .41123 .7109 .40781 .70668 .40495 Metetra
.637 .868 .985 r
.70668 .40495 .7109 .40781 .72025 .40395 .71611 .40172 Metetra
.61 .89 .989 r
.71611 .40172 .72025 .40395 .72964 .40024 .72556 .39852 Metetra
.573 .899 .983 r
.72556 .39852 .72964 .40024 .73908 .39682 .73505 .39539 Metetra
.544 .899 .974 r
.73505 .39539 .73908 .39682 .74857 .39371 .74458 .39233 Metetra
.532 .895 .971 r
.74458 .39233 .74857 .39371 .75811 .39088 .75414 .38933 Metetra
.541 .894 .977 r
.75414 .38933 .75811 .39088 .76769 .3882 .76374 .38636 Metetra
.552 .888 .986 r
.76374 .38636 .76769 .3882 .77734 .38589 .77338 .38348 Metetra
.578 .874 .994 r
.77338 .38348 .77734 .38589 .78706 .38394 .78306 .38067 Metetra
.611 .845 .988 r
.78306 .38067 .78706 .38394 .79682 .3821 .79278 .37789 Metetra
.633 .807 .966 r
.79278 .37789 .79682 .3821 .80662 .38014 .80253 .37507 Metetra
.647 .772 .94 r
.80253 .37507 .80662 .38014 .81642 .37781 .8123 .37215 Metetra
.652 .75 .921 r
.8123 .37215 .81642 .37781 .82624 .37522 .82211 .36915 Metetra
.654 .735 .909 r
.82211 .36915 .82624 .37522 .83608 .37248 .83194 .36611 Metetra
.655 .725 .901 r
.83194 .36611 .83608 .37248 .84594 .36961 .84181 .36303 Metetra
.656 .718 .895 r
.84181 .36303 .84594 .36961 .85583 .36666 .85171 .35992 Metetra
.657 .714 .89 r
.85171 .35992 .85583 .36666 .86574 .36358 .86164 .35678 Metetra
.657 .713 .889 r
.86164 .35678 .86574 .36358 .87568 .36041 .8716 .3536 Metetra
.648 .729 .908 r
.25037 .54466 .25566 .54981 .26366 .54717 .25836 .54231 Metetra
.645 .74 .919 r
.25836 .54231 .26366 .54717 .27169 .54451 .26638 .54 Metetra
.642 .755 .931 r
.26638 .54 .27169 .54451 .27975 .54182 .27442 .53771 Metetra
.637 .773 .945 r
.27442 .53771 .27975 .54182 .28783 .53911 .28249 .53544 Metetra
.633 .793 .959 r
.28249 .53544 .28783 .53911 .29593 .5364 .29058 .53315 Metetra
.631 .814 .97 r
.29058 .53315 .29593 .5364 .30406 .53371 .2987 .53078 Metetra
.632 .83 .976 r
.2987 .53078 .30406 .53371 .31221 .53106 .30686 .52829 Metetra
.638 .84 .978 r
.30686 .52829 .31221 .53106 .32038 .52846 .31505 .52567 Metetra
.645 .841 .976 r
.31505 .52567 .32038 .52846 .32857 .52589 .32327 .52294 Metetra
.653 .836 .971 r
.32327 .52294 .32857 .52589 .33679 .52334 .33152 .52013 Metetra
.665 .826 .961 r
.33152 .52013 .33679 .52334 .34503 .52084 .33981 .51718 Metetra
.669 .806 .949 r
.33981 .51718 .34503 .52084 .35329 .51832 .34811 .51422 Metetra
.662 .784 .94 r
.34811 .51422 .35329 .51832 .36159 .51573 .35644 .51143 Metetra
.646 .772 .94 r
.35644 .51143 .36159 .51573 .36992 .513 .36477 .50894 Metetra
.622 .778 .956 r
.36477 .50894 .36992 .513 .37828 .51011 .37311 .50681 Metetra
.602 .81 .98 r
.37311 .50681 .37828 .51011 .38667 .50718 .38148 .50475 Metetra
.575 .845 .996 r
.38148 .50475 .38667 .50718 .39508 .50425 .38988 .50264 Metetra
.527 .866 .993 r
.38988 .50264 .39508 .50425 .40352 .50131 .39831 .50054 Metetra
.511 .89 .966 r
.39831 .50054 .40352 .50131 .41197 .49855 .40679 .49798 Metetra
.595 .927 .962 r
.40679 .49798 .41197 .49855 .42044 .49616 .41532 .49452 Metetra
.743 .919 .951 r
.41532 .49452 .42044 .49616 .42892 .49433 .42392 .48965 Metetra
.781 .787 .857 r
.42392 .48965 .42892 .49433 .43742 .4931 .43258 .48333 Metetra
.731 .646 .764 r
.43258 .48333 .43742 .4931 .44595 .49206 .44125 .47655 Metetra
.685 .559 .706 r
.44125 .47655 .44595 .49206 .45451 .491 .44993 .46979 Metetra
.653 .506 .671 r
.44993 .46979 .45451 .491 .46311 .48977 .45861 .4634 Metetra
.622 .467 .65 r
.45861 .4634 .46311 .48977 .47176 .48798 .46727 .45835 Metetra
.592 .437 .64 r
.46727 .45835 .47176 .48798 .48045 .48527 .47592 .45543 Metetra
.552 .409 .64 r
.47592 .45543 .48045 .48527 .48919 .48113 .48456 .45587 Metetra
.498 .386 .657 r
.48456 .45587 .48919 .48113 .49795 .4756 .4932 .45961 Metetra
.404 .384 .723 r
.4932 .45961 .49795 .4756 .50674 .46942 .5019 .46492 Metetra
0 .241 .717 r
.5019 .46492 .50674 .46942 .51553 .46301 .51067 .4708 Metetra
.631 .221 .248 r
.51067 .4708 .51553 .46301 .52434 .45681 .51951 .4762 Metetra
.577 .257 .389 r
.51951 .4762 .52434 .45681 .53315 .45132 .52842 .47991 Metetra
.54 .251 .426 r
.52842 .47991 .53315 .45132 .54199 .44693 .53739 .48089 Metetra
.492 .221 .431 r
.53739 .48089 .54199 .44693 .55086 .4444 .54638 .47728 Metetra
.434 .17 .412 r
.54638 .47728 .55086 .4444 .55978 .44363 .55535 .46932 Metetra
.349 .081 .358 r
.55535 .46932 .55978 .44363 .56875 .44384 .5643 .45896 Metetra
.12 0 .174 r
.5643 .45896 .56875 .44384 .57777 .44453 .57322 .44748 Metetra
.81 .978 .69 r
.57322 .44748 .57777 .44453 .58685 .44509 .58212 .43632 Metetra
.796 .696 .754 r
.58212 .43632 .58685 .44509 .59596 .44526 .59103 .42613 Metetra
.686 .538 .68 r
.59103 .42613 .59596 .44526 .6051 .44469 .59997 .41768 Metetra
.62 .465 .649 r
.59997 .41768 .6051 .44469 .61425 .44274 .60899 .4125 Metetra
.583 .431 .64 r
.60899 .4125 .61425 .44274 .62339 .43952 .61811 .41032 Metetra
.562 .419 .645 r
.61811 .41032 .62339 .43952 .63254 .4355 .62733 .40996 Metetra
.551 .424 .66 r
.62733 .40996 .63254 .4355 .64169 .43111 .63662 .41048 Metetra
.553 .448 .688 r
.63662 .41048 .64169 .43111 .65088 .42679 .64596 .41082 Metetra
.552 .481 .729 r
.64596 .41082 .65088 .42679 .66008 .42248 .65534 .41109 Metetra
.555 .541 .793 r
.65534 .41109 .66008 .42248 .66932 .41831 .66476 .41101 Metetra
.581 .651 .884 r
.66476 .41101 .66932 .41831 .6786 .41457 .67417 .40987 Metetra
.604 .764 .956 r
.67417 .40987 .6786 .41457 .68792 .41119 .68359 .40783 Metetra
.614 .834 .984 r
.68359 .40783 .68792 .41119 .69729 .40806 .69301 .40517 Metetra
.605 .856 .991 r
.69301 .40517 .69729 .40806 .70668 .40495 .70245 .40242 Metetra
.569 .86 .996 r
.70245 .40242 .70668 .40495 .71611 .40172 .71195 .39991 Metetra
.532 .878 .987 r
.71195 .39991 .71611 .40172 .72556 .39852 .72148 .3973 Metetra
.5 .886 .963 r
.72148 .3973 .72556 .39852 .73505 .39539 .73103 .3945 Metetra
.487 .889 .944 r
.73103 .3945 .73505 .39539 .74458 .39233 .74059 .39149 Metetra
.498 .896 .94 r
.74059 .39149 .74458 .39233 .75414 .38933 .75018 .3883 Metetra
.525 .904 .952 r
.75018 .3883 .75414 .38933 .76374 .38636 .7598 .385 Metetra
.572 .915 .968 r
.7598 .385 .76374 .38636 .77338 .38348 .76942 .38147 Metetra
.629 .912 .981 r
.76942 .38147 .77338 .38348 .78306 .38067 .77906 .37769 Metetra
.668 .881 .977 r
.77906 .37769 .78306 .38067 .79278 .37789 .78872 .37384 Metetra
.681 .833 .957 r
.78872 .37384 .79278 .37789 .80253 .37507 .79842 .37005 Metetra
.676 .787 .933 r
.79842 .37005 .80253 .37507 .8123 .37215 .80816 .36646 Metetra
.67 .757 .916 r
.80816 .36646 .8123 .37215 .82211 .36915 .81795 .36301 Metetra
.667 .739 .904 r
.81795 .36301 .82211 .36915 .83194 .36611 .82778 .35963 Metetra
.664 .726 .896 r
.82778 .35963 .83194 .36611 .84181 .36303 .83764 .35631 Metetra
.661 .717 .89 r
.83764 .35631 .84181 .36303 .85171 .35992 .84755 .35303 Metetra
.658 .711 .886 r
.84755 .35303 .85171 .35992 .86164 .35678 .85749 .3498 Metetra
.657 .708 .885 r
.85749 .3498 .86164 .35678 .8716 .3536 .86748 .34661 Metetra
.632 .724 .914 r
.24505 .53947 .25037 .54466 .25836 .54231 .25304 .53742 Metetra
.624 .734 .926 r
.25304 .53742 .25836 .54231 .26638 .54 .26104 .53548 Metetra
.617 .749 .94 r
.26104 .53548 .26638 .54 .27442 .53771 .26906 .5336 Metetra
.607 .766 .955 r
.26906 .5336 .27442 .53771 .28249 .53544 .27711 .53179 Metetra
.602 .787 .969 r
.27711 .53179 .28249 .53544 .29058 .53315 .28518 .52993 Metetra
.605 .81 .979 r
.28518 .52993 .29058 .53315 .2987 .53078 .2933 .52789 Metetra
.617 .83 .982 r
.2933 .52789 .2987 .53078 .30686 .52829 .30146 .52558 Metetra
.638 .844 .979 r
.30146 .52558 .30686 .52829 .31505 .52567 .30968 .52292 Metetra
.654 .847 .974 r
.30968 .52292 .31505 .52567 .32327 .52294 .31793 .52004 Metetra
.668 .842 .966 r
.31793 .52004 .32327 .52294 .33152 .52013 .32622 .51695 Metetra
.69 .834 .952 r
.32622 .51695 .33152 .52013 .33981 .51718 .33455 .51354 Metetra
.692 .813 .94 r
.33455 .51354 .33981 .51718 .34811 .51422 .3429 .51011 Metetra
.671 .788 .936 r
.3429 .51011 .34811 .51422 .35644 .51143 .35125 .50712 Metetra
.63 .769 .946 r
.35125 .50712 .35644 .51143 .36477 .50894 .35959 .50489 Metetra
.565 .761 .97 r
.35959 .50489 .36477 .50894 .37311 .50681 .36791 .50355 Metetra
.522 .785 .993 r
.36791 .50355 .37311 .50681 .38148 .50475 .37626 .50239 Metetra
.481 .815 .999 r
.37626 .50239 .38148 .50475 .38988 .50264 .38464 .50114 Metetra
.405 .817 .976 r
.38464 .50114 .38988 .50264 .39831 .50054 .39306 .49991 Metetra
.468 .875 .952 r
.39306 .49991 .39831 .50054 .40679 .49798 .40156 .49756 Metetra
.683 .956 .95 r
.40156 .49756 .40679 .49798 .41532 .49452 .41016 .49299 Metetra
.853 .911 .873 r
.41016 .49299 .41532 .49452 .42392 .48965 .41889 .48495 Metetra
.861 .784 .773 r
.41889 .48495 .42392 .48965 .43258 .48333 .42772 .47335 Metetra
.803 .671 .718 r
.42772 .47335 .43258 .48333 .44125 .47655 .43656 .46066 Metetra
.749 .592 .682 r
.43656 .46066 .44125 .47655 .44993 .46979 .44538 .44809 Metetra
.705 .537 .658 r
.44538 .44809 .44993 .46979 .45861 .4634 .45415 .43646 Metetra
.653 .486 .645 r
.45415 .43646 .45861 .4634 .46727 .45835 .46284 .42811 Metetra
.593 .436 .637 r
.46284 .42811 .46727 .45835 .47592 .45543 .47145 .42498 Metetra
.487 .361 .634 r
.47145 .42498 .47592 .45543 .48456 .45587 .47996 .43003 Metetra
.29 .239 .627 r
.47996 .43003 .48456 .45587 .4932 .45961 .48846 .44323 Metetra
0 0 .557 r
.48846 .44323 .4932 .45961 .5019 .46492 .49703 .46041 Metetra
.869 .43 .038 r
.49703 .46041 .5019 .46492 .51067 .4708 .50573 .47918 Metetra
.793 .421 .353 r
.50573 .47918 .51067 .4708 .51951 .4762 .51458 .49692 Metetra
.684 .362 .425 r
.51458 .49692 .51951 .4762 .52842 .47991 .52357 .51056 Metetra
.598 .305 .444 r
.52357 .51056 .52842 .47991 .53739 .48089 .53266 .51737 Metetra
.481 .214 .432 r
.53266 .51737 .53739 .48089 .54638 .47728 .54178 .51258 Metetra
.327 .085 .386 r
.54178 .51258 .54638 .47728 .55535 .46932 .55083 .49681 Metetra
.098 0 .275 r
.55083 .49681 .55535 .46932 .5643 .45896 .55977 .47512 Metetra
.55977 .47512 .5643 .45896 .57322 .44748 .56861 .45076 Metetra
.985 .903 .603 r
.56861 .45076 .57322 .44748 .58212 .43632 .57737 .42738 Metetra
.879 .714 .673 r
.57737 .42738 .58212 .43632 .59103 .42613 .5861 .40654 Metetra
.757 .579 .655 r
.5861 .40654 .59103 .42613 .59997 .41768 .59485 .39009 Metetra
.651 .483 .643 r
.59485 .39009 .59997 .41768 .60899 .4125 .60375 .38166 Metetra
.57 .419 .638 r
.60375 .38166 .60899 .4125 .61811 .41032 .61285 .38052 Metetra
.514 .384 .641 r
.61285 .38052 .61811 .41032 .62733 .40996 .62213 .38386 Metetra
.473 .368 .655 r
.62213 .38386 .62733 .40996 .63662 .41048 .63154 .38936 Metetra
.458 .383 .684 r
.63154 .38936 .63662 .41048 .64596 .41082 .64102 .39449 Metetra
.428 .4 .726 r
.64102 .39449 .64596 .41082 .65534 .41109 .65057 .39946 Metetra
.396 .444 .793 r
.65057 .39946 .65534 .41109 .66476 .41101 .66017 .4036 Metetra
.439 .576 .893 r
.66017 .4036 .66476 .41101 .67417 .40987 .66972 .40517 Metetra
.512 .725 .97 r
.66972 .40517 .67417 .40987 .68359 .40783 .67922 .40452 Metetra
.575 .823 .992 r
.67922 .40452 .68359 .40783 .69301 .40517 .6887 .40236 Metetra
.571 .848 .996 r
.6887 .40236 .69301 .40517 .70245 .40242 .6982 .39997 Metetra
.495 .833 .998 r
.6982 .39997 .70245 .40242 .71195 .39991 .70777 .39822 Metetra
.458 .849 .979 r
.70777 .39822 .71195 .39991 .72148 .3973 .71737 .39623 Metetra
.447 .864 .95 r
.71737 .39623 .72148 .3973 .73103 .3945 .72697 .39377 Metetra
.461 .88 .929 r
.72697 .39377 .73103 .3945 .74059 .39149 .73658 .39083 Metetra
.499 .9 .929 r
.73658 .39083 .74059 .39149 .75018 .3883 .7462 .38743 Metetra
.54 .915 .943 r
.7462 .38743 .75018 .3883 .7598 .385 .75583 .38379 Metetra
.615 .937 .957 r
.75583 .38379 .7598 .385 .76942 .38147 .76544 .37958 Metetra
.69 .937 .965 r
.76544 .37958 .76942 .38147 .77906 .37769 .77504 .37479 Metetra
.725 .902 .958 r
.77504 .37479 .77906 .37769 .78872 .37384 .78464 .36983 Metetra
.726 .85 .94 r
.78464 .36983 .78872 .37384 .79842 .37005 .79429 .36503 Metetra
.705 .799 .923 r
.79429 .36503 .79842 .37005 .80816 .36646 .804 .36073 Metetra
.688 .765 .91 r
.804 .36073 .80816 .36646 .81795 .36301 .81377 .35681 Metetra
.679 .744 .9 r
.81377 .35681 .81795 .36301 .82778 .35963 .82359 .35309 Metetra
.672 .729 .892 r
.82359 .35309 .82778 .35963 .83764 .35631 .83345 .34952 Metetra
.667 .719 .887 r
.83345 .34952 .83764 .35631 .84755 .35303 .84336 .34605 Metetra
.66 .71 .885 r
.84336 .34605 .84755 .35303 .85749 .3498 .85332 .34275 Metetra
.656 .706 .884 r
.85332 .34275 .85749 .3498 .86748 .34661 .86333 .33955 Metetra
.617 .722 .921 r
.23971 .53431 .24505 .53947 .25304 .53742 .24768 .53251 Metetra
.604 .729 .933 r
.24768 .53251 .25304 .53742 .26104 .53548 .25567 .5309 Metetra
.593 .741 .946 r
.25567 .5309 .26104 .53548 .26906 .5336 .26367 .52938 Metetra
.58 .753 .96 r
.26367 .52938 .26906 .5336 .27711 .53179 .2717 .52796 Metetra
.575 .771 .972 r
.2717 .52796 .27711 .53179 .28518 .52993 .27977 .52648 Metetra
.587 .794 .978 r
.27977 .52648 .28518 .52993 .2933 .52789 .28788 .52473 Metetra
.611 .815 .979 r
.28788 .52473 .2933 .52789 .30146 .52558 .29605 .52256 Metetra
.644 .831 .972 r
.29605 .52256 .30146 .52558 .30968 .52292 .30429 .51988 Metetra
.667 .835 .964 r
.30429 .51988 .30968 .52292 .31793 .52004 .31257 .51685 Metetra
.684 .832 .954 r
.31257 .51685 .31793 .52004 .32622 .51695 .32089 .51353 Metetra
.71 .826 .936 r
.32089 .51353 .32622 .51695 .33455 .51354 .32926 .5097 Metetra
.71 .808 .926 r
.32926 .5097 .33455 .51354 .3429 .51011 .33765 .50587 Metetra
.68 .785 .93 r
.33765 .50587 .3429 .51011 .35125 .50712 .34603 .5027 Metetra
.617 .762 .948 r
.34603 .5027 .35125 .50712 .35959 .50489 .35438 .50069 Metetra
.511 .735 .975 r
.35438 .50069 .35959 .50489 .36791 .50355 .36268 .50004 Metetra
.451 .745 .991 r
.36268 .50004 .36791 .50355 .37626 .50239 .37101 .49967 Metetra
.415 .769 .995 r
.37101 .49967 .37626 .50239 .38464 .50114 .37938 .49916 Metetra
.341 .766 .974 r
.37938 .49916 .38464 .50114 .39306 .49991 .38779 .49869 Metetra
.498 .871 .98 r
.38779 .49869 .39306 .49991 .40156 .49756 .3963 .49652 Metetra
.765 .944 .939 r
.3963 .49652 .40156 .49756 .41016 .49299 .40497 .49098 Metetra
.891 .871 .811 r
.40497 .49098 .41016 .49299 .41889 .48495 .41382 .48017 Metetra
.892 .773 .723 r
.41382 .48017 .41889 .48495 .42772 .47335 .42283 .464 Metetra
.847 .692 .69 r
.42283 .464 .42772 .47335 .43656 .46066 .43184 .44621 Metetra
.798 .628 .67 r
.43184 .44621 .43656 .46066 .44538 .44809 .44079 .42866 Metetra
.753 .576 .656 r
.44079 .42866 .44538 .44809 .45415 .43646 .44966 .41256 Metetra
.69 .519 .651 r
.44966 .41256 .45415 .43646 .46284 .42811 .45839 .40142 Metetra
.6 .449 .649 r
.45839 .40142 .46284 .42811 .47145 .42498 .46696 .39811 Metetra
.399 .31 .638 r
.46696 .39811 .47145 .42498 .47996 .43003 .47536 .40707 Metetra
0 .008 .537 r
.47536 .40707 .47996 .43003 .48846 .44323 .4837 .42834 Metetra
.703 .398 0 r
.4837 .42834 .48846 .44323 .49703 .46041 .49213 .45578 Metetra
.93 .548 .214 r
.49213 .45578 .49703 .46041 .50573 .47918 .50073 .48585 Metetra
.862 .504 .371 r
.50073 .48585 .50573 .47918 .51458 .49692 .50955 .51456 Metetra
.761 .43 .426 r
.50955 .51456 .51458 .49692 .52357 .51056 .51858 .53715 Metetra
.65 .344 .439 r
.51858 .53715 .52357 .51056 .53266 .51737 .52777 .54926 Metetra
.455 .181 .408 r
.52777 .54926 .53266 .51737 .54178 .51258 .53701 .5434 Metetra
.126 0 .297 r
.53701 .5434 .54178 .51258 .55083 .49681 .54615 .52055 Metetra
0 0 .05 r
.54615 .52055 .55083 .49681 .55977 .47512 .55513 .48868 Metetra
.877 .82 .342 r
.55513 .48868 .55977 .47512 .56861 .45076 .56394 .45293 Metetra
.995 .833 .569 r
.56394 .45293 .56861 .45076 .57737 .42738 .57262 .41889 Metetra
.914 .721 .628 r
.57262 .41889 .57737 .42738 .5861 .40654 .58122 .38888 Metetra
.813 .62 .64 r
.58122 .38888 .5861 .40654 .59485 .39009 .58983 .3656 Metetra
.687 .516 .649 r
.58983 .3656 .59485 .39009 .60375 .38166 .59864 .35441 Metetra
.56 .422 .65 r
.59864 .35441 .60375 .38166 .61285 .38052 .60772 .35416 Metetra
.454 .354 .652 r
.60772 .35416 .61285 .38052 .62213 .38386 .61704 .36064 Metetra
.366 .309 .66 r
.61704 .36064 .62213 .38386 .63154 .38936 .62655 .37037 Metetra
.328 .311 .688 r
.62655 .37037 .63154 .38936 .64102 .39449 .63614 .37959 Metetra
.254 .304 .721 r
.63614 .37959 .64102 .39449 .65057 .39946 .64583 .38862 Metetra
.178 .323 .773 r
.64583 .38862 .65057 .39946 .66017 .4036 .65557 .3964 Metetra
.265 .483 .883 r
.65557 .3964 .66017 .4036 .66972 .40517 .66523 .40033 Metetra
.421 .675 .967 r
.66523 .40033 .66972 .40517 .67922 .40452 .67482 .40088 Metetra
.552 .799 .99 r
.67482 .40088 .67922 .40452 .6887 .40236 .68434 .39916 Metetra
.561 .825 .995 r
.68434 .39916 .6887 .40236 .6982 .39997 .69388 .39709 Metetra
.46 .796 .999 r
.69388 .39709 .6982 .39997 .70777 .39822 .70352 .39599 Metetra
.445 .82 .992 r
.70352 .39599 .70777 .39822 .71737 .39623 .71318 .39454 Metetra
.471 .856 .98 r
.71318 .39454 .71737 .39623 .72697 .39377 .72284 .39238 Metetra
.517 .889 .97 r
.72284 .39238 .72697 .39377 .73658 .39083 .73249 .38949 Metetra
.574 .916 .967 r
.73249 .38949 .73658 .39083 .7462 .38743 .74213 .38591 Metetra
.614 .926 .97 r
.74213 .38591 .7462 .38743 .75583 .38379 .75178 .38197 Metetra
.689 .939 .964 r
.75178 .38197 .75583 .38379 .76544 .37958 .76139 .37716 Metetra
.751 .929 .947 r
.76139 .37716 .76544 .37958 .77504 .37479 .77095 .37148 Metetra
.769 .893 .931 r
.77095 .37148 .77504 .37479 .78464 .36983 .78051 .36556 Metetra
.759 .848 .917 r
.78051 .36556 .78464 .36983 .79429 .36503 .79011 .35987 Metetra
.727 .802 .91 r
.79011 .35987 .79429 .36503 .804 .36073 .7998 .35496 Metetra
.703 .77 .904 r
.7998 .35496 .804 .36073 .81377 .35681 .80956 .35063 Metetra
.69 .75 .897 r
.80956 .35063 .81377 .35681 .82359 .35309 .81938 .3466 Metetra
.68 .735 .893 r
.81938 .3466 .82359 .35309 .83345 .34952 .82925 .34281 Metetra
.673 .725 .889 r
.82925 .34281 .83345 .34952 .84336 .34605 .83916 .33918 Metetra
.663 .716 .888 r
.83916 .33918 .84336 .34605 .85332 .34275 .84914 .33581 Metetra
.656 .712 .889 r
.84914 .33581 .85332 .34275 .86333 .33955 .85917 .3326 Metetra
.605 .723 .928 r
.23432 .52924 .23971 .53431 .24768 .53251 .24229 .52762 Metetra
.589 .726 .939 r
.24229 .52762 .24768 .53251 .25567 .5309 .25027 .52622 Metetra
.577 .732 .948 r
.25027 .52622 .25567 .5309 .26367 .52938 .25827 .52494 Metetra
.563 .739 .959 r
.25827 .52494 .26367 .52938 .2717 .52796 .26629 .52378 Metetra
.562 .752 .966 r
.26629 .52378 .2717 .52796 .27977 .52648 .27435 .52256 Metetra
.581 .771 .969 r
.27435 .52256 .27977 .52648 .28788 .52473 .28247 .521 Metetra
.614 .79 .966 r
.28247 .521 .28788 .52473 .29605 .52256 .29065 .51893 Metetra
.653 .805 .956 r
.29065 .51893 .29605 .52256 .30429 .51988 .2989 .51623 Metetra
.677 .809 .946 r
.2989 .51623 .30429 .51988 .31257 .51685 .3072 .5131 Metetra
.695 .808 .936 r
.3072 .5131 .31257 .51685 .32089 .51353 .31555 .50961 Metetra
.721 .806 .917 r
.31555 .50961 .32089 .51353 .32926 .5097 .32396 .5055 Metetra
.72 .794 .91 r
.32396 .5055 .32926 .5097 .33765 .50587 .33239 .50138 Metetra
.685 .776 .92 r
.33239 .50138 .33765 .50587 .34603 .5027 .34079 .49809 Metetra
.61 .751 .945 r
.34079 .49809 .34603 .5027 .35438 .50069 .34914 .49621 Metetra
.477 .709 .971 r
.34914 .49621 .35438 .50069 .36268 .50004 .35744 .49603 Metetra
.418 .706 .982 r
.35744 .49603 .36268 .50004 .37101 .49967 .36576 .4962 Metetra
.405 .728 .99 r
.36576 .4962 .37101 .49967 .37938 .49916 .37412 .49618 Metetra
.359 .731 .988 r
.37412 .49618 .37938 .49916 .38779 .49869 .38253 .49623 Metetra
.562 .844 .997 r
.38253 .49623 .38779 .49869 .3963 .49652 .39106 .49419 Metetra
.799 .888 .909 r
.39106 .49419 .3963 .49652 .40497 .49098 .39978 .48797 Metetra
.895 .828 .774 r
.39978 .48797 .40497 .49098 .41382 .48017 .40873 .47526 Metetra
.904 .764 .697 r
.40873 .47526 .41382 .48017 .42283 .464 .41788 .45596 Metetra
.877 .714 .675 r
.41788 .45596 .42283 .464 .43184 .44621 .42703 .43471 Metetra
.843 .669 .667 r
.42703 .43471 .43184 .44621 .44079 .42866 .4361 .41378 Metetra
.805 .628 .662 r
.4361 .41378 .44079 .42866 .44966 .41256 .44505 .39468 Metetra
.739 .574 .67 r
.44505 .39468 .44966 .41256 .45839 .40142 .45382 .38167 Metetra
.616 .488 .683 r
.45382 .38167 .45839 .40142 .46696 .39811 .46237 .37823 Metetra
.228 .229 .652 r
.46237 .37823 .46696 .39811 .47536 .40707 .47069 .38981 Metetra
0 0 .281 r
.47069 .38981 .47536 .40707 .4837 .42834 .47889 .41651 Metetra
.903 .554 .083 r
.47889 .41651 .4837 .42834 .49213 .45578 .4872 .45092 Metetra
.944 .583 .268 r
.4872 .45092 .49213 .45578 .50073 .48585 .49571 .48877 Metetra
.906 .551 .355 r
.49571 .48877 .50073 .48585 .50955 .51456 .50447 .52511 Metetra
.835 .486 .396 r
.50447 .52511 .50955 .51456 .51858 .53715 .5135 .55399 Metetra
.718 .38 .404 r
.5135 .55399 .51858 .53715 .52777 .54926 .52275 .56984 Metetra
.375 .073 .319 r
.52275 .56984 .52777 .54926 .53701 .5434 .53208 .56321 Metetra
.53208 .56321 .53701 .5434 .54615 .52055 .54132 .53536 Metetra
.887 .817 .341 r
.54132 .53536 .54615 .52055 .55513 .48868 .55037 .49636 Metetra
.997 .835 .491 r
.55037 .49636 .55513 .48868 .56394 .45293 .55919 .4527 Metetra
.984 .789 .564 r
.55919 .4527 .56394 .45293 .57262 .41889 .56785 .41134 Metetra
.934 .729 .603 r
.56785 .41134 .57262 .41889 .58122 .38888 .57641 .37511 Metetra
.864 .665 .632 r
.57641 .37511 .58122 .38888 .58983 .3656 .58496 .34724 Metetra
.738 .572 .669 r
.58496 .34724 .58983 .3656 .59864 .35441 .59372 .3342 Metetra
.55 .446 .688 r
.59372 .3342 .59864 .35441 .60772 .35416 .60279 .33453 Metetra
.352 .32 .683 r
.60279 .33453 .60772 .35416 .61704 .36064 .61213 .3431 Metetra
.173 .219 .669 r
.61213 .3431 .61704 .36064 .62655 .37037 .6217 .35568 Metetra
.105 .206 .686 r
.6217 .35568 .62655 .37037 .63614 .37959 .63136 .36766 Metetra
0 .17 .69 r
.63136 .36766 .63614 .37959 .64583 .38862 .64113 .37943 Metetra
0 .176 .71 r
.64113 .37943 .64583 .38862 .65557 .3964 .65097 .38969 Metetra
.095 .394 .85 r
.65097 .38969 .65557 .3964 .66523 .40033 .66071 .39522 Metetra
.362 .631 .956 r
.66071 .39522 .66523 .40033 .67482 .40088 .67035 .39659 Metetra
.55 .767 .978 r
.67035 .39659 .67482 .40088 .68434 .39916 .67991 .39516 Metetra
.57 .79 .982 r
.67991 .39516 .68434 .39916 .69388 .39709 .68949 .39331 Metetra
.469 .755 .992 r
.68949 .39331 .69388 .39709 .70352 .39599 .69918 .39265 Metetra
.482 .785 .998 r
.69918 .39265 .70352 .39599 .71318 .39454 .70889 .39156 Metetra
.536 .829 .999 r
.70889 .39156 .71318 .39454 .72284 .39238 .71859 .3896 Metetra
.597 .865 .993 r
.71859 .3896 .72284 .39238 .73249 .38949 .72828 .38673 Metetra
.652 .886 .983 r
.72828 .38673 .73249 .38949 .74213 .38591 .73794 .38303 Metetra
.681 .89 .974 r
.73794 .38303 .74213 .38591 .75178 .38197 .74761 .37888 Metetra
.739 .896 .95 r
.74761 .37888 .75178 .38197 .76139 .37716 .75722 .37365 Metetra
.782 .886 .92 r
.75722 .37365 .76139 .37716 .77095 .37148 .76677 .36736 Metetra
.79 .861 .902 r
.76677 .36736 .77095 .37148 .78051 .36556 .77632 .36076 Metetra
.776 .83 .895 r
.77632 .36076 .78051 .36556 .79011 .35987 .7859 .35446 Metetra
.74 .797 .898 r
.7859 .35446 .79011 .35987 .7998 .35496 .79558 .34913 Metetra
.712 .772 .899 r
.79558 .34913 .7998 .35496 .80956 .35063 .80534 .34451 Metetra
.697 .756 .897 r
.80534 .34451 .80956 .35063 .81938 .3466 .81516 .34027 Metetra
.686 .745 .896 r
.81516 .34027 .81938 .3466 .82925 .34281 .82504 .33632 Metetra
.677 .736 .895 r
.82504 .33632 .82925 .34281 .83916 .33918 .83497 .33257 Metetra
.665 .727 .896 r
.83497 .33257 .83916 .33918 .84914 .33581 .84497 .32914 Metetra
.656 .723 .898 r
.84497 .32914 .84914 .33581 .85917 .3326 .85502 .32592 Metetra
.601 .732 .936 r
.22888 .52438 .23432 .52924 .24229 .52762 .23686 .52277 Metetra
.586 .728 .941 r
.23686 .52277 .24229 .52762 .25027 .52622 .24485 .52139 Metetra
.576 .726 .945 r
.24485 .52139 .25027 .52622 .25827 .52494 .25286 .52014 Metetra
.566 .725 .948 r
.25286 .52014 .25827 .52494 .26629 .52378 .26089 .51901 Metetra
.57 .728 .949 r
.26089 .51901 .26629 .52378 .27435 .52256 .26896 .51781 Metetra
.593 .737 .944 r
.26896 .51781 .27435 .52256 .28247 .521 .27709 .51627 Metetra
.624 .748 .936 r
.27709 .51627 .28247 .521 .29065 .51893 .28528 .51421 Metetra
.659 .758 .923 r
.28528 .51421 .29065 .51893 .2989 .51623 .29355 .51148 Metetra
.679 .763 .914 r
.29355 .51148 .2989 .51623 .3072 .5131 .30187 .50832 Metetra
.694 .766 .907 r
.30187 .50832 .3072 .5131 .31555 .50961 .31024 .50479 Metetra
.718 .769 .893 r
.31024 .50479 .31555 .50961 .32396 .5055 .31867 .50062 Metetra
.718 .768 .892 r
.31867 .50062 .32396 .5055 .33239 .50138 .32712 .49645 Metetra
.685 .759 .908 r
.32712 .49645 .33239 .50138 .34079 .49809 .33554 .49312 Metetra
.611 .738 .935 r
.33554 .49312 .34079 .49809 .34914 .49621 .34391 .49126 Metetra
.486 .692 .959 r
.34391 .49126 .34914 .49621 .35744 .49603 .35221 .49113 Metetra
.451 .679 .962 r
.35221 .49113 .35744 .49603 .36576 .4962 .36054 .49137 Metetra
.465 .689 .964 r
.36054 .49137 .36576 .4962 .37412 .49618 .36891 .49143 Metetra
.456 .689 .966 r
.36891 .49143 .37412 .49618 .38253 .49623 .37732 .49154 Metetra
.616 .755 .945 r
.37732 .49154 .38253 .49623 .39106 .49419 .38587 .4895 Metetra
.781 .79 .86 r
.38587 .4895 .39106 .49419 .39978 .48797 .39462 .48317 Metetra
.872 .78 .757 r
.39462 .48317 .39978 .48797 .40873 .47526 .40362 .47015 Metetra
.903 .76 .693 r
.40362 .47015 .40873 .47526 .41788 .45596 .41283 .45034 Metetra
.905 .749 .678 r
.41283 .45034 .41788 .45596 .42703 .43471 .42204 .42852 Metetra
.899 .741 .678 r
.42204 .42852 .42703 .43471 .4361 .41378 .43117 .40705 Metetra
.887 .735 .687 r
.43117 .40705 .4361 .41378 .44505 .39468 .44017 .38746 Metetra
.844 .726 .733 r
.44017 .38746 .44505 .39468 .45382 .38167 .44897 .37415 Metetra
.675 .673 .84 r
.44897 .37415 .45382 .38167 .46237 .37823 .45753 .37067 Metetra
0 0 .445 r
.45753 .37067 .46237 .37823 .47069 .38981 .46583 .38265 Metetra
.919 .535 .133 r
.46583 .38265 .47069 .38981 .47889 .41651 .474 .41019 Metetra
.944 .58 .233 r
.474 .41019 .47889 .41651 .4872 .45092 .48225 .44568 Metetra
.946 .588 .269 r
.48225 .44568 .4872 .45092 .49571 .48877 .49069 .48475 Metetra
.941 .577 .273 r
.49069 .48475 .49571 .48877 .50447 .52511 .49941 .5223 Metetra
.923 .536 .237 r
.49941 .5223 .50447 .52511 .5135 .55399 .50842 .55217 Metetra
.849 .389 .078 r
.50842 .55217 .5135 .55399 .52275 .56984 .51767 .56861 Metetra
.794 .954 .921 r
.51767 .56861 .52275 .56984 .53208 .56321 .52703 .56184 Metetra
.971 .815 .631 r
.52703 .56184 .53208 .56321 .54132 .53536 .53634 .53317 Metetra
.971 .776 .584 r
.53634 .53317 .54132 .53536 .55037 .49636 .54546 .49301 Metetra
.966 .758 .572 r
.54546 .49301 .55037 .49636 .55919 .4527 .55436 .44807 Metetra
.959 .751 .579 r
.55436 .44807 .55919 .4527 .56785 .41134 .56308 .40555 Metetra
.948 .746 .596 r
.56308 .40555 .56785 .41134 .57641 .37511 .57169 .36832 Metetra
.928 .743 .631 r
.57169 .36832 .57641 .37511 .58496 .34724 .58028 .33972 Metetra
.85 .734 .735 r
.58028 .33972 .58496 .34724 .59372 .3342 .58907 .32637 Metetra
.509 .595 .876 r
.58907 .32637 .59372 .3342 .60279 .33453 .59815 .32678 Metetra
0 .185 .719 r
.59815 .32678 .60279 .33453 .61213 .3431 .6075 .33566 Metetra
0 0 .498 r
.6075 .33566 .61213 .3431 .6217 .35568 .61707 .34866 Metetra
0 0 .512 r
.61707 .34866 .6217 .35568 .63136 .36766 .62674 .36107 Metetra
0 0 .506 r
.62674 .36107 .63136 .36766 .64113 .37943 .63652 .37325 Metetra
0 .031 .574 r
.63652 .37325 .64113 .37943 .65097 .38969 .64637 .38389 Metetra
0 .359 .83 r
.64637 .38389 .65097 .38969 .66071 .39522 .65614 .38965 Metetra
.373 .618 .946 r
.65614 .38965 .66071 .39522 .67035 .39659 .6658 .39114 Metetra
.571 .723 .945 r
.6658 .39114 .67035 .39659 .67991 .39516 .67538 .38974 Metetra
.594 .735 .942 r
.67538 .38974 .67991 .39516 .68949 .39331 .68499 .3879 Metetra
.52 .703 .954 r
.68499 .3879 .68949 .39331 .69918 .39265 .6947 .3873 Metetra
.546 .718 .953 r
.6947 .3873 .69918 .39265 .70889 .39156 .70443 .38625 Metetra
.597 .744 .946 r
.70443 .38625 .70889 .39156 .71859 .3896 .71416 .38431 Metetra
.644 .764 .936 r
.71416 .38431 .71859 .3896 .72828 .38673 .72387 .38143 Metetra
.682 .778 .924 r
.72387 .38143 .72828 .38673 .73794 .38303 .73356 .37768 Metetra
.7 .784 .916 r
.73356 .37768 .73794 .38303 .74761 .37888 .74324 .37348 Metetra
.739 .795 .897 r
.74324 .37348 .74761 .37888 .75722 .37365 .75288 .36817 Metetra
.772 .801 .877 r
.75288 .36817 .75722 .37365 .76677 .36736 .76246 .36177 Metetra
.779 .8 .87 r
.76246 .36177 .76677 .36736 .77632 .36076 .77202 .35504 Metetra
.769 .794 .873 r
.77202 .35504 .77632 .36076 .7859 .35446 .78162 .34863 Metetra
.739 .782 .887 r
.78162 .34863 .7859 .35446 .79558 .34913 .79132 .34321 Metetra
.714 .771 .897 r
.79132 .34321 .79558 .34913 .80534 .34451 .80111 .33854 Metetra
.699 .764 .902 r
.80111 .33854 .80534 .34451 .81516 .34027 .81095 .33424 Metetra
.687 .758 .906 r
.81095 .33424 .81516 .34027 .82504 .33632 .82086 .33025 Metetra
.679 .754 .908 r
.82086 .33025 .82504 .33632 .83497 .33257 .83081 .32647 Metetra
.665 .748 .912 r
.83081 .32647 .83497 .33257 .84497 .32914 .84083 .32301 Metetra
.656 .744 .914 r
.84083 .32301 .84497 .32914 .85502 .32592 .85091 .31977 Metetra
.608 .744 .942 r
.22339 .51972 .22888 .52438 .23686 .52277 .23139 .51796 Metetra
.596 .734 .941 r
.23139 .51796 .23686 .52277 .24485 .52139 .23941 .5164 Metetra
.591 .725 .937 r
.23941 .5164 .24485 .52139 .25286 .52014 .24745 .51494 Metetra
.586 .716 .933 r
.24745 .51494 .25286 .52014 .26089 .51901 .25551 .5136 Metetra
.591 .709 .925 r
.25551 .5136 .26089 .51901 .26896 .51781 .2636 .51219 Metetra
.61 .707 .914 r
.2636 .51219 .26896 .51781 .27709 .51627 .27175 .51048 Metetra
.633 .709 .902 r
.27175 .51048 .27709 .51627 .28528 .51421 .27997 .50832 Metetra
.658 .714 .889 r
.27997 .50832 .28528 .51421 .29355 .51148 .28825 .50559 Metetra
.673 .719 .883 r
.28825 .50559 .29355 .51148 .30187 .50832 .29658 .50247 Metetra
.685 .724 .879 r
.29658 .50247 .30187 .50832 .31024 .50479 .30496 .49904 Metetra
.705 .733 .873 r
.30496 .49904 .31024 .50479 .31867 .50062 .31339 .49505 Metetra
.706 .74 .878 r
.31339 .49505 .31867 .50062 .32712 .49645 .32185 .49106 Metetra
.68 .741 .897 r
.32185 .49106 .32712 .49645 .33554 .49312 .33028 .4878 Metetra
.62 .727 .923 r
.33028 .4878 .33554 .49312 .34391 .49126 .33866 .4858 Metetra
.527 .687 .94 r
.33866 .4858 .34391 .49126 .35221 .49113 .347 .4853 Metetra
.511 .666 .932 r
.347 .4853 .35221 .49113 .36054 .49137 .35535 .48512 Metetra
.53 .658 .917 r
.35535 .48512 .36054 .49137 .36891 .49143 .36376 .48478 Metetra
.532 .645 .905 r
.36376 .48478 .36891 .49143 .37732 .49154 .3722 .48449 Metetra
.628 .671 .872 r
.3722 .48449 .37732 .49154 .38587 .4895 .38076 .48233 Metetra
.741 .706 .819 r
.38076 .48233 .38587 .4895 .39462 .48317 .3895 .47646 Metetra
.834 .735 .756 r
.3895 .47646 .39462 .48317 .40362 .47015 .39848 .46481 Metetra
.892 .761 .71 r
.39848 .46481 .40362 .47015 .41283 .45034 .40765 .44726 Metetra
.927 .8 .7 r
.40765 .44726 .41283 .45034 .42204 .42852 .41683 .42796 Metetra
.955 .853 .701 r
.41683 .42796 .42204 .42852 .43117 .40705 .42594 .40892 Metetra
.968 .918 .701 r
.42594 .40892 .43117 .40705 .44017 .38746 .43495 .3915 Metetra
.836 .977 .676 r
.43495 .3915 .44017 .38746 .44897 .37415 .44378 .37953 Metetra
.113 0 0 r
.44378 .37953 .44897 .37415 .45753 .37067 .45238 .37611 Metetra
.738 .32 .255 r
.45238 .37611 .45753 .37067 .46583 .38265 .46074 .38615 Metetra
.868 .491 .327 r
.46074 .38615 .46583 .38265 .474 .41019 .46897 .40969 Metetra
.916 .544 .301 r
.46897 .40969 .474 .41019 .48225 .44568 .47727 .44004 Metetra
.938 .565 .222 r
.47727 .44004 .48225 .44568 .49069 .48475 .48574 .47337 Metetra
.883 .524 .04 r
.48574 .47337 .49069 .48475 .49941 .5223 .49445 .50527 Metetra
0 0 .348 r
.49445 .50527 .49941 .5223 .50842 .55217 .50342 .53047 Metetra
.199 .207 .642 r
.50342 .53047 .50842 .55217 .51767 .56861 .51262 .54411 Metetra
.638 .487 .662 r
.51262 .54411 .51767 .56861 .52703 .56184 .52196 .53789 Metetra
.782 .582 .629 r
.52196 .53789 .52703 .56184 .53634 .53317 .53128 .51288 Metetra
.842 .629 .613 r
.53128 .51288 .53634 .53317 .54546 .49301 .54046 .47794 Metetra
.886 .669 .604 r
.54046 .47794 .54546 .49301 .55436 .44807 .54946 .43879 Metetra
.922 .714 .605 r
.54946 .43879 .55436 .44807 .56308 .40555 .55831 .4016 Metetra
.958 .772 .609 r
.55831 .4016 .56308 .40555 .57169 .36832 .56705 .3689 Metetra
.987 .858 .623 r
.56705 .3689 .57169 .36832 .58028 .33972 .57577 .34362 Metetra
.773 .947 .614 r
.57577 .34362 .58028 .33972 .58907 .32637 .58465 .3316 Metetra
.387 0 0 r
.58465 .3316 .58907 .32637 .59815 .32678 .59376 .33155 Metetra
.677 .215 .148 r
.59376 .33155 .59815 .32678 .6075 .33566 .6031 .33887 Metetra
.756 .29 .142 r
.6031 .33887 .6075 .33566 .61707 .34866 .61264 .34976 Metetra
.748 .245 .022 r
.61264 .34976 .61707 .34866 .62674 .36107 .62227 .36011 Metetra
.717 .183 0 r
.62227 .36011 .62674 .36107 .63652 .37325 .632 .37025 Metetra
.563 .017 0 r
.632 .37025 .63652 .37325 .64637 .38389 .64179 .37904 Metetra
.013 .422 .861 r
.64179 .37904 .64637 .38389 .65614 .38965 .65152 .3836 Metetra
.438 .634 .938 r
.65152 .3836 .65614 .38965 .6658 .39114 .66116 .38445 Metetra
.595 .686 .906 r
.66116 .38445 .6658 .39114 .67538 .38974 .67076 .3828 Metetra
.612 .686 .895 r
.67076 .3828 .67538 .38974 .68499 .3879 .68037 .38078 Metetra
.564 .658 .9 r
.68037 .38078 .68499 .3879 .6947 .3873 .69008 .37982 Metetra
.584 .656 .887 r
.69008 .37982 .6947 .3873 .70443 .38625 .69981 .37847 Metetra
.616 .663 .873 r
.69981 .37847 .70443 .38625 .71416 .38431 .70954 .37635 Metetra
.645 .672 .861 r
.70954 .37635 .71416 .38431 .72387 .38143 .71927 .37341 Metetra
.669 .682 .853 r
.71927 .37341 .72387 .38143 .73356 .37768 .72898 .36973 Metetra
.682 .689 .851 r
.72898 .36973 .73356 .37768 .74324 .37348 .73869 .36565 Metetra
.71 .705 .843 r
.73869 .36565 .74324 .37348 .75288 .36817 .74837 .36061 Metetra
.738 .724 .838 r
.74837 .36061 .75288 .36817 .76246 .36177 .758 .35462 Metetra
.749 .741 .844 r
.758 .35462 .76246 .36177 .77202 .35504 .76763 .34836 Metetra
.747 .755 .859 r
.76763 .34836 .77202 .35504 .78162 .34863 .77729 .34236 Metetra
.726 .763 .882 r
.77729 .34236 .78162 .34863 .79132 .34321 .78704 .33722 Metetra
.706 .766 .899 r
.78704 .33722 .79132 .34321 .80111 .33854 .79687 .33272 Metetra
.695 .77 .909 r
.79687 .33272 .80111 .33854 .81095 .33424 .80675 .32854 Metetra
.684 .772 .917 r
.80675 .32854 .81095 .33424 .82086 .33025 .81669 .32463 Metetra
.677 .773 .923 r
.81669 .32463 .82086 .33025 .83081 .32647 .82668 .3209 Metetra
.664 .771 .929 r
.82668 .3209 .83081 .32647 .84083 .32301 .83672 .31745 Metetra
.655 .768 .932 r
.83672 .31745 .84083 .32301 .85091 .31977 .84683 .31418 Metetra
.621 .754 .941 r
.21785 .51519 .22339 .51972 .23139 .51796 .22589 .51317 Metetra
.614 .742 .937 r
.22589 .51317 .23139 .51796 .23941 .5164 .23395 .5113 Metetra
.611 .729 .929 r
.23395 .5113 .23941 .5164 .24745 .51494 .24203 .50951 Metetra
.609 .714 .92 r
.24203 .50951 .24745 .51494 .25551 .5136 .25013 .50779 Metetra
.613 .702 .908 r
.25013 .50779 .25551 .5136 .2636 .51219 .25826 .50602 Metetra
.625 .693 .894 r
.25826 .50602 .2636 .51219 .27175 .51048 .26644 .50403 Metetra
.639 .689 .881 r
.26644 .50403 .27175 .51048 .27997 .50832 .27468 .50171 Metetra
.656 .69 .87 r
.27468 .50171 .27997 .50832 .28825 .50559 .28297 .49897 Metetra
.666 .694 .866 r
.28297 .49897 .28825 .50559 .29658 .50247 .29131 .49595 Metetra
.675 .7 .866 r
.29131 .49595 .29658 .50247 .30496 .49904 .29968 .4927 Metetra
.69 .711 .864 r
.29968 .4927 .30496 .49904 .31339 .49505 .30811 .48904 Metetra
.692 .723 .873 r
.30811 .48904 .31339 .49505 .32185 .49106 .31656 .48537 Metetra
.673 .73 .892 r
.31656 .48537 .32185 .49106 .33028 .4878 .325 .48224 Metetra
.632 .722 .913 r
.325 .48224 .33028 .4878 .33866 .4858 .33341 .48002 Metetra
.572 .693 .923 r
.33341 .48002 .33866 .4858 .347 .4853 .34179 .47889 Metetra
.565 .667 .907 r
.34179 .47889 .347 .4853 .35535 .48512 .35019 .478 Metetra
.576 .648 .884 r
.35019 .478 .35535 .48512 .36376 .48478 .35863 .47698 Metetra
.578 .628 .865 r
.35863 .47698 .36376 .48478 .3722 .48449 .36711 .47599 Metetra
.632 .634 .834 r
.36711 .47599 .3722 .48449 .38076 .48233 .37569 .47365 Metetra
.707 .661 .802 r
.37569 .47365 .38076 .48233 .3895 .47646 .38441 .46859 Metetra
.791 .705 .769 r
.38441 .46859 .3895 .47646 .39848 .46481 .39332 .45932 Metetra
.868 .764 .746 r
.39332 .45932 .39848 .46481 .40765 .44726 .40238 .44573 Metetra
.929 .859 .75 r
.40238 .44573 .40765 .44726 .41683 .42796 .41146 .43082 Metetra
.942 .963 .717 r
.41146 .43082 .41683 .42796 .42594 .40892 .4205 .41607 Metetra
.693 .875 .484 r
.4205 .41607 .42594 .40892 .43495 .3915 .42947 .40248 Metetra
.42947 .40248 .43495 .3915 .44378 .37953 .4383 .39288 Metetra
.384 .032 .239 r
.4383 .39288 .44378 .37953 .45238 .37611 .44697 .3896 Metetra
.633 .277 .349 r
.44697 .3896 .45238 .37611 .46074 .38615 .45545 .39622 Metetra
.77 .407 .367 r
.45545 .39622 .46074 .38615 .46897 .40969 .46383 .41274 Metetra
.862 .472 .302 r
.46383 .41274 .46897 .40969 .47727 .44004 .47226 .43414 Metetra
.897 .488 .088 r
.47226 .43414 .47727 .44004 .48574 .47337 .48082 .45756 Metetra
0 0 .386 r
.48082 .45756 .48574 .47337 .49445 .50527 .48958 .4798 Metetra
.152 .15 .601 r
.48958 .4798 .49445 .50527 .50342 .53047 .49853 .49708 Metetra
.43 .316 .623 r
.49853 .49708 .50342 .53047 .51262 .54411 .50768 .50601 Metetra
.6 .427 .62 r
.50768 .50601 .51262 .54411 .52196 .53789 .51695 .5007 Metetra
.695 .496 .614 r
.51695 .5007 .52196 .53789 .53128 .51288 .52624 .48191 Metetra
.755 .547 .615 r
.52624 .48191 .53128 .51288 .54046 .47794 .53544 .4559 Metetra
.813 .605 .621 r
.53544 .4559 .54046 .47794 .54946 .43879 .54453 .4267 Metetra
.878 .684 .636 r
.54453 .4267 .54946 .43879 .55831 .4016 .55351 .39877 Metetra
.959 .808 .65 r
.55351 .39877 .55831 .4016 .56705 .3689 .56242 .374 Metetra
.921 .932 .564 r
.56242 .374 .56705 .3689 .57577 .34362 .57131 .35459 Metetra
.02 0 .035 r
.57131 .35459 .57577 .34362 .58465 .3316 .5803 .34491 Metetra
.465 .106 .271 r
.5803 .34491 .58465 .3316 .59376 .33155 .58947 .34406 Metetra
.592 .22 .305 r
.58947 .34406 .59376 .33155 .6031 .33887 .59881 .34864 Metetra
.65 .252 .277 r
.59881 .34864 .6031 .33887 .61264 .34976 .60829 .35584 Metetra
.655 .207 .175 r
.60829 .35584 .61264 .34976 .62227 .36011 .61785 .36261 Metetra
.647 .128 0 r
.61785 .36261 .62227 .36011 .632 .37025 .6275 .36919 Metetra
.486 0 0 r
.6275 .36919 .632 .37025 .64179 .37904 .6372 .37477 Metetra
.183 .568 .936 r
.6372 .37477 .64179 .37904 .65152 .3836 .64686 .37725 Metetra
.515 .662 .927 r
.64686 .37725 .65152 .3836 .66116 .38445 .65648 .37701 Metetra
.614 .671 .881 r
.65648 .37701 .66116 .38445 .67076 .3828 .66607 .37495 Metetra
.625 .664 .868 r
.66607 .37495 .67076 .3828 .68037 .38078 .67568 .37261 Metetra
.595 .641 .867 r
.67568 .37261 .68037 .38078 .69008 .37982 .68537 .37104 Metetra
.606 .631 .85 r
.68537 .37104 .69008 .37982 .69981 .37847 .69509 .36919 Metetra
.624 .628 .834 r
.69509 .36919 .69981 .37847 .70954 .37635 .70482 .36676 Metetra
.641 .63 .824 r
.70482 .36676 .70954 .37635 .71927 .37341 .71455 .36375 Metetra
.656 .636 .818 r
.71455 .36375 .71927 .37341 .72898 .36973 .72428 .36019 Metetra
.665 .643 .819 r
.72428 .36019 .72898 .36973 .73869 .36565 .73403 .35633 Metetra
.685 .658 .818 r
.73403 .35633 .73869 .36565 .74837 .36061 .74375 .35178 Metetra
.706 .679 .821 r
.74375 .35178 .74837 .36061 .758 .35462 .75345 .34653 Metetra
.718 .703 .835 r
.75345 .34653 .758 .35462 .76763 .34836 .76316 .34107 Metetra
.721 .728 .856 r
.76316 .34107 .76763 .34836 .77729 .34236 .77291 .3358 Metetra
.708 .747 .883 r
.77291 .3358 .77729 .34236 .78704 .33722 .78272 .33116 Metetra
.694 .761 .903 r
.78272 .33116 .78704 .33722 .79687 .33272 .79261 .32698 Metetra
.685 .771 .916 r
.79261 .32698 .79687 .33272 .80675 .32854 .80254 .32303 Metetra
.677 .778 .926 r
.80254 .32303 .80675 .32854 .81669 .32463 .81252 .31927 Metetra
.671 .783 .933 r
.81252 .31927 .81669 .32463 .82668 .3209 .82255 .31564 Metetra
.661 .784 .94 r
.82255 .31564 .82668 .3209 .83672 .31745 .83263 .31222 Metetra
.654 .783 .943 r
.83263 .31222 .83672 .31745 .84683 .31418 .84276 .30892 Metetra
.638 .763 .938 r
.21228 .51071 .21785 .51519 .22589 .51317 .22036 .50838 Metetra
.635 .749 .93 r
.22036 .50838 .22589 .51317 .23395 .5113 .22846 .50613 Metetra
.635 .733 .919 r
.22846 .50613 .23395 .5113 .24203 .50951 .23659 .5039 Metetra
.633 .717 .907 r
.23659 .5039 .24203 .50951 .25013 .50779 .24474 .50172 Metetra
.635 .701 .893 r
.24474 .50172 .25013 .50779 .25826 .50602 .25292 .4995 Metetra
.639 .687 .879 r
.25292 .4995 .25826 .50602 .26644 .50403 .26114 .49716 Metetra
.646 .679 .867 r
.26114 .49716 .26644 .50403 .27468 .50171 .26939 .49465 Metetra
.653 .676 .859 r
.26939 .49465 .27468 .50171 .28297 .49897 .2777 .4919 Metetra
.659 .678 .857 r
.2777 .4919 .28297 .49897 .29131 .49595 .28603 .48901 Metetra
.664 .684 .859 r
.28603 .48901 .29131 .49595 .29968 .4927 .29441 .48599 Metetra
.673 .695 .863 r
.29441 .48599 .29968 .4927 .30811 .48904 .30282 .48274 Metetra
.675 .709 .874 r
.30282 .48274 .30811 .48904 .31656 .48537 .31125 .47949 Metetra
.666 .721 .891 r
.31125 .47949 .31656 .48537 .325 .48224 .3197 .47652 Metetra
.644 .722 .904 r
.3197 .47652 .325 .48224 .33341 .48002 .32814 .47403 Metetra
.617 .703 .906 r
.32814 .47403 .33341 .48002 .34179 .47889 .33657 .47211 Metetra
.613 .674 .885 r
.33657 .47211 .34179 .47889 .35019 .478 .34503 .47031 Metetra
.615 .648 .859 r
.34503 .47031 .35019 .478 .35863 .47698 .35353 .46844 Metetra
.614 .625 .838 r
.35353 .46844 .35863 .47698 .36711 .47599 .36205 .46658 Metetra
.635 .615 .813 r
.36205 .46658 .36711 .47599 .37569 .47365 .37064 .464 Metetra
.674 .628 .796 r
.37064 .464 .37569 .47365 .38441 .46859 .37933 .45998 Metetra
.733 .673 .791 r
.37933 .45998 .38441 .46859 .39332 .45932 .38813 .45372 Metetra
.812 .766 .81 r
.38813 .45372 .39332 .45932 .40238 .44573 .39703 .44517 Metetra
.879 .943 .852 r
.39703 .44517 .40238 .44573 .41146 .43082 .40595 .43588 Metetra
.582 .873 .563 r
.40595 .43588 .41146 .43082 .4205 .41607 .41487 .42666 Metetra
.41487 .42666 .4205 .41607 .42947 .40248 .42376 .41803 Metetra
.293 0 .227 r
.42376 .41803 .42947 .40248 .4383 .39288 .43258 .41152 Metetra
.435 .115 .322 r
.43258 .41152 .4383 .39288 .44697 .3896 .44133 .40841 Metetra
.547 .22 .366 r
.44133 .40841 .44697 .3896 .45545 .39622 .44999 .41061 Metetra
.64 .288 .359 r
.44999 .41061 .45545 .39622 .46383 .41274 .45859 .41808 Metetra
.734 .308 .238 r
.45859 .41808 .46383 .41274 .47226 .43414 .46723 .42807 Metetra
.573 .104 0 r
.46723 .42807 .47226 .43414 .48082 .45756 .47596 .43903 Metetra
.244 .258 .676 r
.47596 .43903 .48082 .45756 .48958 .4798 .4848 .44926 Metetra
.438 .328 .632 r
.4848 .44926 .48958 .4798 .49853 .49708 .49377 .45682 Metetra
.517 .363 .611 r
.49377 .45682 .49853 .49708 .50768 .50601 .50285 .46 Metetra
.582 .403 .604 r
.50285 .46 .50768 .50601 .51695 .5007 .51203 .45581 Metetra
.631 .44 .605 r
.51203 .45581 .51695 .5007 .52624 .48191 .52124 .44462 Metetra
.672 .479 .615 r
.52124 .44462 .52624 .48191 .53544 .4559 .53043 .42961 Metetra
.723 .536 .636 r
.53043 .42961 .53544 .4559 .54453 .4267 .53958 .41284 Metetra
.801 .639 .682 r
.53958 .41284 .54453 .4267 .55351 .39877 .54868 .39664 Metetra
.934 .875 .755 r
.54868 .39664 .55351 .39877 .56242 .374 .55775 .38202 Metetra
.55775 .38202 .56242 .374 .57131 .35459 .56683 .3702 Metetra
.308 0 .242 r
.56683 .3702 .57131 .35459 .5803 .34491 .57596 .36358 Metetra
.467 .143 .333 r
.57596 .36358 .5803 .34491 .58947 .34406 .5852 .3617 Metetra
.522 .187 .34 r
.5852 .3617 .58947 .34406 .59881 .34864 .59454 .36273 Metetra
.545 .184 .306 r
.59454 .36273 .59881 .34864 .60829 .35584 .60397 .36514 Metetra
.529 .118 .207 r
.60397 .36514 .60829 .35584 .61785 .36261 .61345 .36731 Metetra
.481 0 0 r
.61345 .36731 .61785 .36261 .6275 .36919 .62299 .36936 Metetra
.206 0 0 r
.62299 .36936 .6275 .36919 .6372 .37477 .63258 .37085 Metetra
.426 .73 .989 r
.63258 .37085 .6372 .37477 .64686 .37725 .64217 .37068 Metetra
.59 .691 .912 r
.64217 .37068 .64686 .37725 .65648 .37701 .65175 .36907 Metetra
.633 .666 .864 r
.65175 .36907 .65648 .37701 .66607 .37495 .66133 .36649 Metetra
.637 .654 .85 r
.66133 .36649 .66607 .37495 .67568 .37261 .67094 .36376 Metetra
.622 .637 .845 r
.67094 .36376 .67568 .37261 .68537 .37104 .68061 .36143 Metetra
.625 .621 .827 r
.68061 .36143 .68537 .37104 .69509 .36919 .6903 .35894 Metetra
.632 .612 .812 r
.6903 .35894 .69509 .36919 .70482 .36676 .70002 .35615 Metetra
.639 .609 .803 r
.70002 .35615 .70482 .36676 .71455 .36375 .70975 .35304 Metetra
.646 .611 .8 r
.70975 .35304 .71455 .36375 .72428 .36019 .7195 .34963 Metetra
.651 .617 .802 r
.7195 .34963 .72428 .36019 .73403 .35633 .72928 .34607 Metetra
.662 .628 .806 r
.72928 .34607 .73403 .35633 .74375 .35178 .73906 .34213 Metetra
.676 .648 .815 r
.73906 .34213 .74375 .35178 .75345 .34653 .74884 .33782 Metetra
.685 .675 .834 r
.74884 .33782 .75345 .34653 .76316 .34107 .75865 .33339 Metetra
.69 .705 .859 r
.75865 .33339 .76316 .34107 .77291 .3358 .76849 .32905 Metetra
.684 .733 .887 r
.76849 .32905 .77291 .3358 .78272 .33116 .77838 .32504 Metetra
.677 .754 .909 r
.77838 .32504 .78272 .33116 .79261 .32698 .78832 .32127 Metetra
.672 .769 .923 r
.78832 .32127 .79261 .32698 .80254 .32303 .79831 .31762 Metetra
.667 .78 .933 r
.79831 .31762 .80254 .32303 .81252 .31927 .80834 .31406 Metetra
.663 .788 .941 r
.80834 .31406 .81252 .31927 .82255 .31564 .81841 .31057 Metetra
.657 .792 .947 r
.81841 .31057 .82255 .31564 .83263 .31222 .82852 .30717 Metetra
.653 .793 .949 r
.82852 .30717 .83263 .31222 .84276 .30892 .83868 .30384 Metetra
.656 .768 .932 r
.20666 .50624 .21228 .51071 .22036 .50838 .21479 .50358 Metetra
.656 .755 .922 r
.21479 .50358 .22036 .50838 .22846 .50613 .22294 .5009 Metetra
.657 .739 .91 r
.22294 .5009 .22846 .50613 .23659 .5039 .23112 .49823 Metetra
.656 .722 .897 r
.23112 .49823 .23659 .5039 .24474 .50172 .23933 .49554 Metetra
.655 .704 .883 r
.23933 .49554 .24474 .50172 .25292 .4995 .24756 .49285 Metetra
.654 .689 .871 r
.24756 .49285 .25292 .4995 .26114 .49716 .25581 .49014 Metetra
.653 .678 .861 r
.25581 .49014 .26114 .49716 .26939 .49465 .2641 .48742 Metetra
.652 .672 .856 r
.2641 .48742 .26939 .49465 .2777 .4919 .27241 .48467 Metetra
.653 .672 .856 r
.27241 .48467 .2777 .4919 .28603 .48901 .28075 .48191 Metetra
.654 .677 .86 r
.28075 .48191 .28603 .48901 .29441 .48599 .28911 .47913 Metetra
.655 .686 .867 r
.28911 .47913 .29441 .48599 .30282 .48274 .2975 .47633 Metetra
.657 .701 .879 r
.2975 .47633 .30282 .48274 .31125 .47949 .30592 .47353 Metetra
.657 .717 .893 r
.30592 .47353 .31125 .47949 .3197 .47652 .31437 .47073 Metetra
.657 .724 .899 r
.31437 .47073 .3197 .47652 .32814 .47403 .32284 .46795 Metetra
.655 .713 .891 r
.32284 .46795 .32814 .47403 .33657 .47211 .33134 .46518 Metetra
.652 .685 .868 r
.33134 .46518 .33657 .47211 .34503 .47031 .33986 .46242 Metetra
.648 .657 .844 r
.33986 .46242 .34503 .47031 .35353 .46844 .34841 .45964 Metetra
.644 .633 .824 r
.34841 .45964 .35353 .46844 .36205 .46658 .35699 .45686 Metetra
.641 .612 .805 r
.35699 .45686 .36205 .46658 .37064 .464 .3656 .45403 Metetra
.642 .608 .8 r
.3656 .45403 .37064 .464 .37933 .45998 .37424 .45111 Metetra
.651 .636 .822 r
.37424 .45111 .37933 .45998 .38813 .45372 .38291 .44808 Metetra
.67 .738 .901 r
.38291 .44808 .38813 .45372 .39703 .44517 .39161 .44491 Metetra
.523 .909 .938 r
.39161 .44491 .39703 .44517 .40595 .43588 .40035 .44169 Metetra
.145 0 0 r
.40035 .44169 .40595 .43588 .41487 .42666 .40911 .43847 Metetra
.356 0 .187 r
.40911 .43847 .41487 .42666 .42376 .41803 .41789 .43526 Metetra
.423 .094 .3 r
.41789 .43526 .42376 .41803 .43258 .41152 .4267 .43216 Metetra
.449 .135 .341 r
.4267 .43216 .43258 .41152 .44133 .40841 .43553 .42923 Metetra
.456 .142 .345 r
.43553 .42923 .44133 .40841 .44999 .41061 .44438 .42658 Metetra
.434 .095 .29 r
.44438 .42658 .44999 .41061 .45859 .41808 .45326 .42419 Metetra
.252 0 0 r
.45326 .42419 .45859 .41808 .46723 .42807 .46217 .42192 Metetra
.625 .71 .907 r
.46217 .42192 .46723 .42807 .47596 .43903 .47111 .41968 Metetra
.595 .481 .694 r
.47111 .41968 .47596 .43903 .4848 .44926 .48008 .41739 Metetra
.578 .422 .633 r
.48008 .41739 .4848 .44926 .49377 .45682 .48909 .41495 Metetra
.572 .4 .609 r
.48909 .41495 .49377 .45682 .50285 .46 .49814 .41228 Metetra
.571 .392 .6 r
.49814 .41228 .50285 .46 .51203 .45581 .50721 .40922 Metetra
.575 .396 .602 r
.50721 .40922 .51203 .45581 .52124 .44462 .51632 .4058 Metetra
.583 .412 .616 r
.51632 .4058 .52124 .44462 .53043 .42961 .52546 .40217 Metetra
.599 .449 .649 r
.52546 .40217 .53043 .42961 .53958 .41284 .53462 .39843 Metetra
.637 .548 .738 r
.53462 .39843 .53958 .41284 .54868 .39664 .54381 .39471 Metetra
.638 .908 .983 r
.54381 .39471 .54868 .39664 .55775 .38202 .55303 .39105 Metetra
.289 0 .084 r
.55303 .39105 .55775 .38202 .56683 .3702 .56227 .38753 Metetra
.425 .096 .302 r
.56227 .38753 .56683 .3702 .57596 .36358 .57155 .38428 Metetra
.45 .137 .342 r
.57155 .38428 .57596 .36358 .5852 .3617 .58086 .38126 Metetra
.448 .129 .331 r
.58086 .38126 .5852 .3617 .59454 .36273 .59021 .37839 Metetra
.424 .084 .282 r
.59021 .37839 .59454 .36273 .60397 .36514 .59959 .37558 Metetra
.359 0 .159 r
.59959 .37558 .60397 .36514 .61345 .36731 .60901 .37275 Metetra
.19 0 0 r
.60901 .37275 .61345 .36731 .62299 .36936 .61846 .3699 Metetra
.316 .805 .799 r
.61846 .3699 .62299 .36936 .63258 .37085 .62794 .36702 Metetra
.635 .827 .974 r
.62794 .36702 .63258 .37085 .64217 .37068 .63745 .36403 Metetra
.654 .716 .894 r
.63745 .36403 .64217 .37068 .65175 .36907 .64699 .36096 Metetra
.651 .67 .855 r
.64699 .36096 .65175 .36907 .66133 .36649 .65657 .35783 Metetra
.649 .655 .842 r
.65657 .35783 .66133 .36649 .67094 .36376 .66617 .35468 Metetra
.647 .644 .834 r
.66617 .35468 .67094 .36376 .68061 .36143 .67581 .35154 Metetra
.643 .625 .817 r
.67581 .35154 .68061 .36143 .6903 .35894 .68548 .34838 Metetra
.641 .611 .804 r
.68548 .34838 .6903 .35894 .70002 .35615 .69519 .34519 Metetra
.639 .603 .797 r
.69519 .34519 .70002 .35615 .70975 .35304 .70492 .34198 Metetra
.639 .602 .796 r
.70492 .34198 .70975 .35304 .7195 .34963 .71469 .33875 Metetra
.641 .606 .799 r
.71469 .33875 .7195 .34963 .72928 .34607 .7245 .33549 Metetra
.643 .613 .805 r
.7245 .33549 .72928 .34607 .73906 .34213 .73433 .3322 Metetra
.646 .629 .818 r
.73433 .3322 .73906 .34213 .74884 .33782 .7442 .32889 Metetra
.651 .655 .84 r
.7442 .32889 .74884 .33782 .75865 .33339 .7541 .32555 Metetra
.656 .687 .867 r
.7541 .32555 .75865 .33339 .76849 .32905 .76404 .32222 Metetra
.659 .721 .895 r
.76404 .32222 .76849 .32905 .77838 .32504 .77401 .31888 Metetra
.659 .746 .915 r
.77401 .31888 .77838 .32504 .78832 .32127 .78402 .31555 Metetra
.658 .764 .928 r
.78402 .31555 .78832 .32127 .79831 .31762 .79406 .31221 Metetra
.657 .778 .938 r
.79406 .31221 .79831 .31762 .80834 .31406 .80414 .30887 Metetra
.655 .787 .945 r
.80414 .30887 .80834 .31406 .81841 .31057 .81425 .30552 Metetra
.654 .794 .949 r
.81425 .30552 .81841 .31057 .82852 .30717 .8244 .30217 Metetra
.653 .796 .951 r
.8244 .30217 .82852 .30717 .83868 .30384 .83458 .2988 Metetra
.671 .77 .924 r
.20102 .50172 .20666 .50624 .21479 .50358 .20919 .49873 Metetra
.674 .758 .914 r
.20919 .49873 .21479 .50358 .22294 .5009 .21739 .49567 Metetra
.675 .744 .902 r
.21739 .49567 .22294 .5009 .23112 .49823 .22562 .49256 Metetra
.675 .729 .89 r
.22562 .49256 .23112 .49823 .23933 .49554 .23388 .48941 Metetra
.673 .712 .878 r
.23388 .48941 .23933 .49554 .24756 .49285 .24216 .48627 Metetra
.667 .696 .868 r
.24216 .48627 .24756 .49285 .25581 .49014 .25046 .48321 Metetra
.66 .684 .862 r
.25046 .48321 .25581 .49014 .2641 .48742 .25877 .48028 Metetra
.652 .676 .86 r
.25877 .48028 .2641 .48742 .27241 .48467 .26709 .47753 Metetra
.648 .675 .862 r
.26709 .47753 .27241 .48467 .28075 .48191 .27542 .4749 Metetra
.645 .678 .867 r
.27542 .4749 .28075 .48191 .28911 .47913 .28378 .47235 Metetra
.638 .683 .876 r
.28378 .47235 .28911 .47913 .2975 .47633 .29216 .46997 Metetra
.639 .698 .888 r
.29216 .46997 .2975 .47633 .30592 .47353 .30056 .46758 Metetra
.65 .717 .897 r
.30056 .46758 .30592 .47353 .31437 .47073 .30901 .46495 Metetra
.668 .729 .895 r
.30901 .46495 .31437 .47073 .32284 .46795 .31751 .46189 Metetra
.686 .725 .88 r
.31751 .46189 .32284 .46795 .33134 .46518 .32607 .45833 Metetra
.684 .699 .858 r
.32607 .45833 .33134 .46518 .33986 .46242 .33465 .45466 Metetra
.677 .672 .838 r
.33465 .45466 .33986 .46242 .34841 .45964 .34326 .45104 Metetra
.671 .649 .82 r
.34326 .45104 .34841 .45964 .35699 .45686 .35189 .44738 Metetra
.649 .621 .809 r
.35189 .44738 .35699 .45686 .3656 .45403 .36052 .44432 Metetra
.611 .599 .815 r
.36052 .44432 .3656 .45403 .37424 .45111 .36911 .44244 Metetra
.532 .586 .854 r
.36911 .44244 .37424 .45111 .38291 .44808 .37766 .44242 Metetra
.308 .58 .937 r
.37766 .44242 .38291 .44808 .39161 .44491 .38616 .44434 Metetra
.313 0 0 r
.38616 .44434 .39161 .44491 .40035 .44169 .3947 .44688 Metetra
.526 .052 .073 r
.3947 .44688 .40035 .44169 .40911 .43847 .40329 .4494 Metetra
.534 .148 .255 r
.40329 .4494 .40911 .43847 .41789 .43526 .41196 .45143 Metetra
.5 .157 .316 r
.41196 .45143 .41789 .43526 .4267 .43216 .42073 .45163 Metetra
.444 .123 .326 r
.42073 .45163 .4267 .43216 .43553 .42923 .42965 .44888 Metetra
.323 .016 .28 r
.42965 .44888 .43553 .42923 .44438 .42658 .43871 .44152 Metetra
.02 0 .087 r
.43871 .44152 .44438 .42658 .45326 .42419 .44788 .42966 Metetra
.806 .945 .595 r
.44788 .42966 .45326 .42419 .46217 .42192 .45708 .41577 Metetra
.873 .761 .736 r
.45708 .41577 .46217 .42192 .47111 .41968 .46626 .40122 Metetra
.744 .577 .669 r
.46626 .40122 .47111 .41968 .48008 .41739 .47539 .38743 Metetra
.669 .489 .632 r
.47539 .38743 .48008 .41739 .48909 .41495 .48447 .37592 Metetra
.618 .436 .613 r
.48447 .37592 .48909 .41495 .49814 .41228 .49349 .36798 Metetra
.564 .39 .604 r
.49349 .36798 .49814 .41228 .50721 .40922 .50247 .36594 Metetra
.513 .354 .603 r
.50247 .36594 .50721 .40922 .51632 .4058 .51146 .36951 Metetra
.467 .333 .615 r
.51146 .36951 .51632 .4058 .52546 .40217 .52052 .37624 Metetra
.398 .317 .648 r
.52052 .37624 .52546 .40217 .53462 .39843 .52966 .38455 Metetra
.23 .306 .735 r
.52966 .38455 .53462 .39843 .54381 .39471 .5389 .39254 Metetra
.532 0 0 r
.5389 .39254 .54381 .39471 .55303 .39105 .54822 .39932 Metetra
.591 .168 .207 r
.54822 .39932 .55303 .39105 .56227 .38753 .55761 .40379 Metetra
.494 .149 .31 r
.55761 .40379 .56227 .38753 .57155 .38428 .56702 .4038 Metetra
.417 .1 .317 r
.56702 .4038 .57155 .38428 .58086 .38126 .57641 .39968 Metetra
.344 .03 .282 r
.57641 .39968 .58086 .38126 .59021 .37839 .58578 .39303 Metetra
.241 0 .195 r
.58578 .39303 .59021 .37839 .59959 .37558 .59513 .3852 Metetra
.077 0 .007 r
.59513 .3852 .59959 .37558 .60901 .37275 .60449 .37758 Metetra
.60449 .37758 .60901 .37275 .61846 .3699 .61386 .37007 Metetra
.742 .991 .876 r
.61386 .37007 .61846 .3699 .62794 .36702 .62326 .36303 Metetra
.76 .853 .92 r
.62326 .36303 .62794 .36702 .63745 .36403 .63271 .35739 Metetra
.703 .736 .877 r
.63271 .35739 .63745 .36403 .64699 .36096 .64222 .35294 Metetra
.668 .681 .853 r
.64222 .35294 .64699 .36096 .65657 .35783 .65179 .34929 Metetra
.662 .665 .843 r
.65179 .34929 .65657 .35783 .66617 .35468 .66139 .34575 Metetra
.67 .66 .831 r
.66139 .34575 .66617 .35468 .67581 .35154 .67101 .34185 Metetra
.662 .639 .817 r
.67101 .34185 .67581 .35154 .68548 .34838 .68066 .33806 Metetra
.651 .622 .807 r
.68066 .33806 .68548 .34838 .69519 .34519 .69036 .33451 Metetra
.643 .611 .802 r
.69036 .33451 .69519 .34519 .70492 .34198 .7001 .3312 Metetra
.636 .606 .803 r
.7001 .3312 .70492 .34198 .71469 .33875 .70989 .32812 Metetra
.633 .608 .807 r
.70989 .32812 .71469 .33875 .7245 .33549 .71972 .32515 Metetra
.626 .61 .815 r
.71972 .32515 .7245 .33549 .73433 .3322 .7296 .32248 Metetra
.619 .62 .83 r
.7296 .32248 .73433 .3322 .7442 .32889 .73955 .3201 Metetra
.618 .643 .853 r
.73955 .3201 .7442 .32889 .7541 .32555 .74954 .31779 Metetra
.622 .674 .879 r
.74954 .31779 .7541 .32555 .76404 .32222 .75957 .31539 Metetra
.632 .711 .903 r
.75957 .31539 .76404 .32222 .77401 .31888 .76961 .31269 Metetra
.64 .739 .92 r
.76961 .31269 .77401 .31888 .78402 .31555 .77968 .30977 Metetra
.644 .757 .931 r
.77968 .30977 .78402 .31555 .79406 .31221 .78977 .30673 Metetra
.647 .772 .94 r
.78977 .30673 .79406 .31221 .80414 .30887 .7999 .30359 Metetra
.648 .782 .945 r
.7999 .30359 .80414 .30887 .81425 .30552 .81005 .30037 Metetra
.652 .79 .948 r
.81005 .30037 .81425 .30552 .8244 .30217 .82024 .29705 Metetra
.654 .794 .949 r
.82024 .29705 .8244 .30217 .83458 .2988 .83045 .29366 Metetra
.683 .769 .917 r
.19534 .49708 .20102 .50172 .20919 .49873 .20356 .49383 Metetra
.688 .76 .907 r
.20356 .49383 .20919 .49873 .21739 .49567 .2118 .49045 Metetra
.689 .749 .897 r
.2118 .49045 .21739 .49567 .22562 .49256 .22008 .48699 Metetra
.69 .737 .886 r
.22008 .48699 .22562 .49256 .23388 .48941 .22839 .48345 Metetra
.687 .723 .877 r
.22839 .48345 .23388 .48941 .24216 .48627 .23671 .47994 Metetra
.678 .709 .871 r
.23671 .47994 .24216 .48627 .25046 .48321 .24504 .4766 Metetra
.667 .697 .868 r
.24504 .4766 .25046 .48321 .25877 .48028 .25338 .47351 Metetra
.654 .688 .87 r
.25338 .47351 .25877 .48028 .26709 .47753 .26171 .47075 Metetra
.645 .685 .874 r
.26171 .47075 .26709 .47753 .27542 .4749 .27005 .46821 Metetra
.637 .686 .88 r
.27005 .46821 .27542 .4749 .28378 .47235 .27841 .46585 Metetra
.622 .688 .89 r
.27841 .46585 .28378 .47235 .29216 .46997 .28677 .46381 Metetra
.622 .7 .901 r
.28677 .46381 .29216 .46997 .30056 .46758 .29516 .46175 Metetra
.643 .72 .904 r
.29516 .46175 .30056 .46758 .30901 .46495 .30361 .45925 Metetra
.677 .735 .895 r
.30361 .45925 .30901 .46495 .31751 .46189 .31214 .45596 Metetra
.708 .736 .873 r
.31214 .45596 .31751 .46189 .32607 .45833 .32075 .45176 Metetra
.709 .716 .854 r
.32075 .45176 .32607 .45833 .33465 .45466 .3294 .44735 Metetra
.7 .693 .84 r
.3294 .44735 .33465 .45466 .34326 .45104 .33806 .44303 Metetra
.695 .674 .825 r
.33806 .44303 .34326 .45104 .35189 .44738 .34674 .43867 Metetra
.659 .643 .823 r
.34674 .43867 .35189 .44738 .36052 .44432 .35538 .43541 Metetra
.579 .603 .841 r
.35538 .43541 .36052 .44432 .36911 .44244 .36394 .43436 Metetra
.365 .518 .876 r
.36394 .43436 .36911 .44244 .37766 .44242 .37238 .43679 Metetra
0 .226 .723 r
.37238 .43679 .37766 .44242 .38616 .44434 .38071 .44285 Metetra
.662 .108 0 r
.38071 .44285 .38616 .44434 .3947 .44688 .38906 .45013 Metetra
.692 .22 .124 r
.38906 .45013 .3947 .44688 .40329 .4494 .3975 .45739 Metetra
.647 .237 .251 r
.3975 .45739 .40329 .4494 .41196 .45143 .40605 .46376 Metetra
.557 .183 .287 r
.40605 .46376 .41196 .45143 .42073 .45163 .4148 .46671 Metetra
.415 .066 .262 r
.4148 .46671 .42073 .45163 .42965 .44888 .42378 .46411 Metetra
.053 0 .1 r
.42378 .46411 .42965 .44888 .43871 .44152 .43304 .45282 Metetra
.674 .797 .338 r
.43304 .45282 .43871 .44152 .44788 .42966 .44249 .43312 Metetra
.985 .9 .632 r
.44249 .43312 .44788 .42966 .45708 .41577 .45196 .40972 Metetra
.917 .752 .661 r
.45196 .40972 .45708 .41577 .46626 .40122 .46137 .38523 Metetra
.823 .634 .648 r
.46137 .38523 .46626 .40122 .47539 .38743 .47067 .36227 Metetra
.741 .549 .634 r
.47067 .36227 .47539 .38743 .48447 .37592 .47982 .34361 Metetra
.665 .48 .625 r
.47982 .34361 .48447 .37592 .49349 .36798 .48884 .33157 Metetra
.56 .398 .618 r
.48884 .33157 .49349 .36798 .50247 .36594 .49775 .33032 Metetra
.43 .307 .611 r
.49775 .33032 .50247 .36594 .51146 .36951 .50663 .33935 Metetra
.284 .22 .607 r
.50663 .33935 .51146 .36951 .52052 .37624 .5156 .35426 Metetra
.037 .089 .588 r
.5156 .35426 .52052 .37624 .52966 .38455 .5247 .37221 Metetra
0 0 .465 r
.5247 .37221 .52966 .38455 .5389 .39254 .53394 .38969 Metetra
.817 .338 0 r
.53394 .38969 .5389 .39254 .54822 .39932 .54333 .40504 Metetra
.738 .304 .22 r
.54333 .40504 .54822 .39932 .55761 .40379 .55282 .41614 Metetra
.546 .166 .271 r
.55282 .41614 .55761 .40379 .56702 .4038 .56233 .41887 Metetra
.344 .004 .235 r
.56233 .41887 .56702 .4038 .57641 .39968 .57179 .41383 Metetra
.138 0 .139 r
.57179 .41383 .57641 .39968 .58578 .39303 .58119 .40403 Metetra
.58119 .40403 .58578 .39303 .59513 .3852 .59053 .39201 Metetra
.59053 .39201 .59513 .3852 .60449 .37758 .59987 .38045 Metetra
.788 .973 .682 r
.59987 .38045 .60449 .37758 .61386 .37007 .60919 .3691 Metetra
.892 .961 .834 r
.60919 .3691 .61386 .37007 .62326 .36303 .61853 .35868 Metetra
.819 .845 .868 r
.61853 .35868 .62326 .36303 .63271 .35739 .62794 .35087 Metetra
.738 .752 .864 r
.62794 .35087 .63271 .35739 .64222 .35294 .63743 .3453 Metetra
.683 .699 .858 r
.63743 .3453 .64222 .35294 .65179 .34929 .647 .34123 Metetra
.674 .684 .851 r
.647 .34123 .65179 .34929 .66139 .34575 .65661 .33736 Metetra
.691 .683 .838 r
.65661 .33736 .66139 .34575 .67101 .34185 .66622 .33284 Metetra
.68 .664 .827 r
.66622 .33284 .67101 .34185 .68066 .33806 .67586 .32854 Metetra
.664 .645 .821 r
.67586 .32854 .68066 .33806 .69036 .33451 .68555 .32469 Metetra
.649 .632 .819 r
.68555 .32469 .69036 .33451 .7001 .3312 .6953 .3213 Metetra
.636 .624 .822 r
.6953 .3213 .7001 .3312 .70989 .32812 .70511 .31834 Metetra
.629 .624 .826 r
.70511 .31834 .70989 .32812 .71972 .32515 .71497 .3156 Metetra
.612 .621 .836 r
.71497 .3156 .71972 .32515 .7296 .32248 .7249 .31341 Metetra
.593 .624 .852 r
.7249 .31341 .7296 .32248 .73955 .3201 .73491 .31178 Metetra
.585 .641 .873 r
.73491 .31178 .73955 .3201 .74954 .31779 .74498 .3103 Metetra
.589 .669 .895 r
.74498 .3103 .74954 .31779 .75957 .31539 .75508 .30865 Metetra
.609 .705 .913 r
.75508 .30865 .75957 .31539 .76961 .31269 .76518 .30647 Metetra
.624 .732 .924 r
.76518 .30647 .76961 .31269 .77968 .30977 .7753 .30388 Metetra
.632 .75 .933 r
.7753 .30388 .77968 .30977 .78977 .30673 .78545 .30108 Metetra
.639 .763 .938 r
.78545 .30108 .78977 .30673 .7999 .30359 .79561 .2981 Metetra
.643 .773 .942 r
.79561 .2981 .7999 .30359 .81005 .30037 .80581 .29499 Metetra
.651 .781 .943 r
.80581 .29499 .81005 .30037 .82024 .29705 .81602 .29169 Metetra
.656 .785 .943 r
.81602 .29169 .82024 .29705 .83045 .29366 .82626 .28826 Metetra
.688 .763 .909 r
.18966 .49224 .19534 .49708 .20356 .49383 .1979 .48885 Metetra
.694 .759 .902 r
.1979 .48885 .20356 .49383 .2118 .49045 .20618 .4853 Metetra
.696 .754 .896 r
.20618 .4853 .2118 .49045 .22008 .48699 .21448 .48166 Metetra
.698 .748 .89 r
.21448 .48166 .22008 .48699 .22839 .48345 .22282 .47792 Metetra
.696 .741 .886 r
.22282 .47792 .22839 .48345 .23671 .47994 .23118 .47421 Metetra
.687 .733 .885 r
.23118 .47421 .23671 .47994 .24504 .4766 .23954 .47072 Metetra
.673 .724 .888 r
.23954 .47072 .24504 .4766 .25338 .47351 .24789 .46754 Metetra
.656 .717 .893 r
.24789 .46754 .25338 .47351 .26171 .47075 .25624 .46477 Metetra
.644 .713 .898 r
.25624 .46477 .26171 .47075 .27005 .46821 .26459 .46227 Metetra
.633 .712 .904 r
.26459 .46227 .27005 .46821 .27841 .46585 .27295 .45999 Metetra
.612 .709 .914 r
.27295 .45999 .27841 .46585 .28677 .46381 .28131 .45811 Metetra
.612 .715 .919 r
.28131 .45811 .28677 .46381 .29516 .46175 .2897 .45622 Metetra
.639 .731 .915 r
.2897 .45622 .29516 .46175 .30361 .45925 .29816 .45377 Metetra
.682 .746 .9 r
.29816 .45377 .30361 .45925 .31214 .45596 .30672 .45036 Metetra
.721 .751 .876 r
.30672 .45036 .31214 .45596 .32075 .45176 .31537 .44582 Metetra
.726 .742 .864 r
.31537 .44582 .32075 .45176 .3294 .44735 .32405 .44104 Metetra
.719 .728 .858 r
.32405 .44104 .3294 .44735 .33806 .44303 .33275 .43637 Metetra
.717 .718 .85 r
.33275 .43637 .33806 .44303 .34674 .43867 .34147 .43165 Metetra
.671 .693 .862 r
.34147 .43165 .34674 .43867 .35538 .43541 .35013 .42828 Metetra
.55 .643 .895 r
.35013 .42828 .35538 .43541 .36394 .43436 .35867 .42764 Metetra
.179 .46 .884 r
.35867 .42764 .36394 .43436 .37238 .43679 .36705 .43128 Metetra
0 .019 .527 r
.36705 .43128 .37238 .43679 .38071 .44285 .37529 .4394 Metetra
.709 .183 0 r
.37529 .4394 .38071 .44285 .38906 .45013 .38355 .44904 Metetra
.755 .242 0 r
.38355 .44904 .38906 .45013 .3975 .45739 .3919 .45868 Metetra
.729 .235 .062 r
.3919 .45868 .3975 .45739 .40605 .46376 .40039 .46724 Metetra
.587 .084 .027 r
.40039 .46724 .40605 .46376 .4148 .46671 .40913 .47158 Metetra
.143 0 0 r
.40913 .47158 .4148 .46671 .42378 .46411 .41815 .46904 Metetra
.823 .965 .641 r
.41815 .46904 .42378 .46411 .43304 .45282 .42752 .45575 Metetra
.985 .892 .641 r
.42752 .45575 .43304 .45282 .44249 .43312 .43715 .43209 Metetra
.967 .813 .637 r
.43715 .43209 .44249 .43312 .45196 .40972 .4468 .40391 Metetra
.93 .749 .637 r
.4468 .40391 .45196 .40972 .46137 .38523 .45638 .37448 Metetra
.883 .694 .641 r
.45638 .37448 .46137 .38523 .47067 .36227 .46579 .347 Metetra
.825 .639 .651 r
.46579 .347 .47067 .36227 .47982 .34361 .47502 .32485 Metetra
.744 .575 .665 r
.47502 .32485 .47982 .34361 .48884 .33157 .48406 .3108 Metetra
.565 .451 .683 r
.48406 .3108 .48884 .33157 .49775 .33032 .49293 .30992 Metetra
.221 .225 .651 r
.49293 .30992 .49775 .33032 .50663 .33935 .50176 .32161 Metetra
0 0 .531 r
.50176 .32161 .50663 .33935 .5156 .35426 .51066 .34051 Metetra
0 0 .318 r
.51066 .34051 .5156 .35426 .5247 .37221 .51971 .36319 Metetra
.787 .39 0 r
.51971 .36319 .5247 .37221 .53394 .38969 .52895 .3854 Metetra
.856 .41 .01 r
.52895 .3854 .53394 .38969 .54333 .40504 .53835 .40504 Metetra
.816 .341 .076 r
.53835 .40504 .54333 .40504 .55282 .41614 .54788 .41948 Metetra
.553 .031 0 r
.54788 .41948 .55282 .41614 .56233 .41887 .55744 .42359 Metetra
.55744 .42359 .56233 .41887 .57179 .41383 .56695 .41807 Metetra
.698 .923 .596 r
.56695 .41807 .57179 .41383 .58119 .40403 .57638 .40665 Metetra
.895 .978 .689 r
.57638 .40665 .58119 .40403 .59053 .39201 .58575 .39251 Metetra
.931 .966 .756 r
.58575 .39251 .59053 .39201 .59987 .38045 .59509 .37895 Metetra
.931 .92 .781 r
.59509 .37895 .59987 .38045 .60919 .3691 .60442 .36567 Metetra
.901 .869 .797 r
.60442 .36567 .60919 .3691 .61853 .35868 .61375 .35354 Metetra
.831 .818 .836 r
.61375 .35354 .61853 .35868 .62794 .35087 .62315 .34464 Metetra
.756 .768 .863 r
.62315 .34464 .62794 .35087 .63743 .3453 .63265 .3385 Metetra
.696 .731 .878 r
.63265 .3385 .63743 .3453 .647 .34123 .64224 .33421 Metetra
.685 .721 .877 r
.64224 .33421 .647 .34123 .65661 .33736 .65186 .33017 Metetra
.709 .725 .862 r
.65186 .33017 .65661 .33736 .66622 .33284 .66147 .32534 Metetra
.699 .712 .859 r
.66147 .32534 .66622 .33284 .67586 .32854 .67113 .32077 Metetra
.679 .697 .86 r
.67113 .32077 .67586 .32854 .68555 .32469 .68083 .31675 Metetra
.659 .685 .863 r
.68083 .31675 .68555 .32469 .6953 .3213 .69059 .31331 Metetra
.64 .676 .868 r
.69059 .31331 .6953 .3213 .70511 .31834 .70042 .3104 Metetra
.63 .673 .872 r
.70042 .3104 .70511 .31834 .71497 .3156 .7103 .30776 Metetra
.603 .664 .882 r
.7103 .30776 .71497 .3156 .7249 .31341 .72027 .30581 Metetra
.573 .657 .894 r
.72027 .30581 .7249 .31341 .73491 .31178 .73032 .30455 Metetra
.56 .664 .907 r
.73032 .30455 .73491 .31178 .74498 .3103 .74043 .30347 Metetra
.567 .682 .918 r
.74043 .30347 .74498 .3103 .75508 .30865 .75058 .30218 Metetra
.595 .71 .924 r
.75058 .30218 .75508 .30865 .76518 .30647 .76073 .30025 Metetra
.616 .73 .927 r
.76073 .30025 .76518 .30647 .7753 .30388 .77089 .29781 Metetra
.627 .742 .93 r
.77089 .29781 .7753 .30388 .78545 .30108 .78107 .29511 Metetra
.636 .751 .931 r
.78107 .29511 .78545 .30108 .79561 .2981 .79127 .2922 Metetra
.642 .757 .932 r
.79127 .2922 .79561 .2981 .80581 .29499 .80149 .28914 Metetra
.652 .764 .931 r
.80149 .28914 .80581 .29499 .81602 .29169 .81174 .28584 Metetra
.658 .767 .93 r
.81174 .28584 .81602 .29169 .82626 .28826 .82201 .28238 Metetra
.687 .755 .904 r
.18395 .48718 .18966 .49224 .1979 .48885 .19221 .48378 Metetra
.693 .757 .901 r
.19221 .48378 .1979 .48885 .20618 .4853 .2005 .48022 Metetra
.696 .758 .899 r
.2005 .48022 .20618 .4853 .21448 .48166 .20883 .47657 Metetra
.7 .759 .898 r
.20883 .47657 .21448 .48166 .22282 .47792 .21718 .47282 Metetra
.698 .759 .899 r
.21718 .47282 .22282 .47792 .23118 .47421 .22556 .4691 Metetra
.689 .757 .903 r
.22556 .4691 .23118 .47421 .23954 .47072 .23393 .46559 Metetra
.676 .754 .91 r
.23393 .46559 .23954 .47072 .24789 .46754 .2423 .4624 Metetra
.657 .75 .918 r
.2423 .4624 .24789 .46754 .25624 .46477 .25066 .45962 Metetra
.643 .746 .924 r
.25066 .45962 .25624 .46477 .26459 .46227 .25903 .4571 Metetra
.631 .742 .928 r
.25903 .4571 .26459 .46227 .27295 .45999 .26741 .4548 Metetra
.608 .735 .935 r
.26741 .4548 .27295 .45999 .28131 .45811 .27578 .4529 Metetra
.609 .735 .935 r
.27578 .4529 .28131 .45811 .2897 .45622 .28419 .45098 Metetra
.639 .744 .925 r
.28419 .45098 .2897 .45622 .29816 .45377 .29267 .44851 Metetra
.682 .756 .907 r
.29267 .44851 .29816 .45377 .30672 .45036 .30124 .44509 Metetra
.724 .765 .885 r
.30124 .44509 .30672 .45036 .31537 .44582 .30991 .44054 Metetra
.731 .766 .881 r
.30991 .44054 .31537 .44582 .32405 .44104 .31861 .43576 Metetra
.728 .766 .884 r
.31861 .43576 .32405 .44104 .33275 .43637 .32733 .43108 Metetra
.729 .767 .883 r
.32733 .43108 .33275 .43637 .34147 .43165 .33606 .42635 Metetra
.679 .756 .91 r
.33606 .42635 .34147 .43165 .35013 .42828 .34474 .42297 Metetra
.524 .703 .952 r
.34474 .42297 .35013 .42828 .35867 .42764 .35331 .42229 Metetra
.064 .45 .88 r
.35331 .42229 .35867 .42764 .36705 .43128 .36169 .42588 Metetra
0 .019 .521 r
.36169 .42588 .36705 .43128 .37529 .4394 .36993 .43392 Metetra
.59 .092 0 r
.36993 .43392 .37529 .4394 .38355 .44904 .37819 .44347 Metetra
.575 .08 0 r
.37819 .44347 .38355 .44904 .3919 .45868 .38654 .45301 Metetra
0 .017 .527 r
.38654 .45301 .3919 .45868 .40039 .46724 .39504 .46149 Metetra
.029 .411 .86 r
.39504 .46149 .40039 .46724 .40913 .47158 .40377 .46576 Metetra
.635 .733 .919 r
.40377 .46576 .40913 .47158 .41815 .46904 .41281 .46321 Metetra
.865 .771 .756 r
.41281 .46321 .41815 .46904 .42752 .45575 .42222 .44995 Metetra
.916 .757 .67 r
.42222 .44995 .42752 .45575 .43715 .43209 .4319 .4264 Metetra
.927 .753 .645 r
.4319 .4264 .43715 .43209 .4468 .40391 .44161 .39835 Metetra
.932 .753 .638 r
.44161 .39835 .4468 .40391 .45638 .37448 .45124 .36905 Metetra
.931 .757 .645 r
.45124 .36905 .45638 .37448 .46579 .347 .46071 .3417 Metetra
.921 .768 .675 r
.46071 .3417 .46579 .347 .47502 .32485 .46999 .31964 Metetra
.885 .786 .747 r
.46999 .31964 .47502 .32485 .48406 .3108 .47907 .30563 Metetra
.534 .716 .956 r
.47907 .30563 .48406 .3108 .49293 .30992 .48796 .30472 Metetra
.655 .166 0 r
.48796 .30472 .49293 .30992 .50176 .32161 .49678 .31631 Metetra
.844 .401 0 r
.49678 .31631 .50176 .32161 .51066 .34051 .50567 .33506 Metetra
.879 .456 .044 r
.50567 .33506 .51066 .34051 .51971 .36319 .5147 .35758 Metetra
.868 .441 .018 r
.5147 .35758 .51971 .36319 .52895 .3854 .52392 .37962 Metetra
.829 .387 0 r
.52392 .37962 .52895 .3854 .53835 .40504 .5333 .3991 Metetra
.69 .222 0 r
.5333 .3991 .53835 .40504 .54788 .41948 .54282 .41342 Metetra
.128 .462 .889 r
.54282 .41342 .54788 .41948 .55744 .42359 .55239 .41746 Metetra
.739 .766 .875 r
.55239 .41746 .55744 .42359 .56695 .41807 .56193 .41194 Metetra
.851 .784 .785 r
.56193 .41194 .56695 .41807 .57638 .40665 .57139 .40055 Metetra
.88 .785 .751 r
.57139 .40055 .57638 .40665 .58575 .39251 .5808 .38646 Metetra
.877 .787 .758 r
.5808 .38646 .58575 .39251 .59509 .37895 .59019 .37294 Metetra
.875 .789 .762 r
.59019 .37294 .59509 .37895 .60442 .36567 .59955 .3597 Metetra
.865 .792 .777 r
.59955 .3597 .60442 .36567 .61375 .35354 .60891 .3476 Metetra
.82 .791 .825 r
.60891 .3476 .61375 .35354 .62315 .34464 .61835 .33871 Metetra
.759 .781 .871 r
.61835 .33871 .62315 .34464 .63265 .3385 .62788 .33258 Metetra
.7 .765 .902 r
.62788 .33258 .63265 .3385 .64224 .33421 .63749 .32827 Metetra
.69 .762 .906 r
.63749 .32827 .64224 .33421 .65186 .33017 .64713 .32421 Metetra
.719 .771 .894 r
.64713 .32421 .65186 .33017 .66147 .32534 .65677 .31937 Metetra
.709 .769 .899 r
.65677 .31937 .66147 .32534 .67113 .32077 .66645 .31478 Metetra
.688 .762 .908 r
.66645 .31478 .67113 .32077 .68083 .31675 .67618 .31075 Metetra
.665 .753 .916 r
.67618 .31075 .68083 .31675 .69059 .31331 .68597 .30729 Metetra
.642 .744 .923 r
.68597 .30729 .69059 .31331 .70042 .3104 .69582 .30436 Metetra
.629 .739 .927 r
.69582 .30436 .70042 .3104 .7103 .30776 .70572 .30169 Metetra
.595 .724 .934 r
.70572 .30169 .7103 .30776 .72027 .30581 .7157 .29972 Metetra
.559 .707 .94 r
.7157 .29972 .72027 .30581 .73032 .30455 .72578 .29841 Metetra
.548 .701 .941 r
.72578 .29841 .73032 .30455 .74043 .30347 .73591 .2973 Metetra
.559 .706 .939 r
.73591 .2973 .74043 .30347 .75058 .30218 .74608 .29598 Metetra
.593 .721 .933 r
.74608 .29598 .75058 .30218 .76073 .30025 .75625 .29401 Metetra
.616 .731 .928 r
.75625 .29401 .76073 .30025 .77089 .29781 .76643 .29155 Metetra
.628 .736 .925 r
.76643 .29155 .77089 .29781 .78107 .29511 .77664 .28883 Metetra
.637 .74 .923 r
.77664 .28883 .78107 .29511 .79127 .2922 .78686 .28589 Metetra
.643 .743 .921 r
.78686 .28589 .79127 .2922 .80149 .28914 .79711 .2828 Metetra
.653 .747 .919 r
.79711 .2828 .80149 .28914 .81174 .28584 .80738 .27948 Metetra
.659 .749 .917 r
.80738 .27948 .81174 .28584 .82201 .28238 .81768 .27601 Metetra
.683 .75 .902 r
.17823 .48198 .18395 .48718 .19221 .48378 .18649 .47865 Metetra
.689 .755 .902 r
.18649 .47865 .19221 .48378 .2005 .48022 .19479 .47517 Metetra
.692 .759 .903 r
.19479 .47517 .2005 .48022 .20883 .47657 .20312 .47162 Metetra
.695 .764 .905 r
.20312 .47162 .20883 .47657 .21718 .47282 .21148 .46798 Metetra
.694 .769 .909 r
.21148 .46798 .21718 .47282 .22556 .4691 .21986 .46437 Metetra
.687 .773 .917 r
.21986 .46437 .22556 .4691 .23393 .46559 .22825 .46094 Metetra
.674 .774 .926 r
.22825 .46094 .23393 .46559 .2423 .4624 .23663 .45778 Metetra
.656 .772 .935 r
.23663 .45778 .2423 .4624 .25066 .45962 .24501 .45498 Metetra
.643 .769 .939 r
.24501 .45498 .25066 .45962 .25903 .4571 .2534 .4524 Metetra
.632 .764 .942 r
.2534 .4524 .25903 .4571 .26741 .4548 .26179 .45002 Metetra
.612 .755 .947 r
.26179 .45002 .26741 .4548 .27578 .4529 .27019 .44798 Metetra
.613 .75 .943 r
.27019 .44798 .27578 .4529 .28419 .45098 .27863 .44592 Metetra
.641 .753 .93 r
.27863 .44592 .28419 .45098 .29267 .44851 .28712 .44338 Metetra
.68 .761 .913 r
.28712 .44338 .29267 .44851 .30124 .44509 .29571 .44002 Metetra
.718 .772 .895 r
.29571 .44002 .30124 .44509 .30991 .44054 .30439 .43567 Metetra
.726 .782 .897 r
.30439 .43567 .30991 .44054 .31861 .43576 .3131 .43112 Metetra
.724 .792 .905 r
.3131 .43112 .31861 .43576 .32733 .43108 .32182 .42665 Metetra
.727 .802 .911 r
.32182 .42665 .32733 .43108 .33606 .42635 .33056 .42214 Metetra
.676 .802 .943 r
.33056 .42214 .33606 .42635 .34474 .42297 .33926 .41881 Metetra
.515 .754 .983 r
.33926 .41881 .34474 .42297 .35331 .42229 .34786 .41782 Metetra
.095 .513 .906 r
.34786 .41782 .35331 .42229 .36169 .42588 .3563 .42054 Metetra
0 .152 .648 r
.3563 .42054 .36169 .42588 .36993 .43392 .3646 .42712 Metetra
0 .109 .643 r
.3646 .42712 .36993 .43392 .37819 .44347 .37293 .435 Metetra
0 .183 .717 r
.37293 .435 .37819 .44347 .38654 .45301 .38135 .44287 Metetra
.079 .288 .772 r
.38135 .44287 .38654 .45301 .39504 .46149 .38989 .4498 Metetra
.393 .449 .8 r
.38989 .4498 .39504 .46149 .40377 .46576 .39865 .45308 Metetra
.619 .561 .768 r
.39865 .45308 .40377 .46576 .41281 .46321 .4077 .45045 Metetra
.771 .637 .712 r
.4077 .45045 .41281 .46321 .42222 .44995 .41708 .43855 Metetra
.85 .681 .672 r
.41708 .43855 .42222 .44995 .4319 .4264 .42671 .41771 Metetra
.892 .718 .659 r
.42671 .41771 .4319 .4264 .44161 .39835 .43638 .39294 Metetra
.927 .76 .655 r
.43638 .39294 .44161 .39835 .45124 .36905 .44599 .36703 Metetra
.958 .815 .66 r
.44599 .36703 .45124 .36905 .46071 .3417 .45546 .34277 Metetra
.974 .897 .682 r
.45546 .34277 .46071 .3417 .46999 .31964 .46476 .32309 Metetra
.863 .982 .693 r
.46476 .32309 .46999 .31964 .47907 .30563 .47388 .31044 Metetra
.267 0 0 r
.47388 .31044 .47907 .30563 .48796 .30472 .48282 .30925 Metetra
.73 .281 .186 r
.48282 .30925 .48796 .30472 .49678 .31631 .49168 .31897 Metetra
.825 .393 .214 r
.49168 .31897 .49678 .31631 .50567 .33506 .5006 .33493 Metetra
.867 .433 .172 r
.5006 .33493 .50567 .33506 .5147 .35758 .50965 .35413 Metetra
.859 .408 .036 r
.50965 .35413 .5147 .35758 .52392 .37962 .51886 .37287 Metetra
.733 .287 0 r
.51886 .37287 .52392 .37962 .5333 .3991 .52822 .38935 Metetra
0 .044 .612 r
.52822 .38935 .5333 .3991 .54282 .41342 .53771 .40132 Metetra
.42 .462 .798 r
.53771 .40132 .54282 .41342 .55239 .41746 .54727 .40437 Metetra
.672 .589 .754 r
.54727 .40437 .55239 .41746 .56193 .41194 .55681 .39914 Metetra
.756 .635 .727 r
.55681 .39914 .56193 .41194 .57139 .40055 .56631 .38884 Metetra
.795 .665 .72 r
.56631 .38884 .57139 .40055 .5808 .38646 .57576 .37619 Metetra
.806 .689 .736 r
.57576 .37619 .5808 .38646 .59019 .37294 .58519 .36402 Metetra
.821 .717 .75 r
.58519 .36402 .59019 .37294 .59955 .3597 .59461 .35209 Metetra
.827 .746 .775 r
.59461 .35209 .59955 .3597 .60891 .3476 .60403 .34113 Metetra
.799 .773 .828 r
.60403 .34113 .60891 .3476 .61835 .33871 .61352 .33297 Metetra
.75 .786 .883 r
.61352 .33297 .61835 .33871 .62788 .33258 .62309 .32719 Metetra
.697 .786 .92 r
.62309 .32719 .62788 .33258 .63749 .32827 .63273 .323 Metetra
.688 .789 .927 r
.63273 .323 .63749 .32827 .64713 .32421 .6424 .31903 Metetra
.715 .802 .918 r
.6424 .31903 .64713 .32421 .65677 .31937 .65208 .31437 Metetra
.706 .808 .928 r
.65208 .31437 .65677 .31937 .66645 .31478 .66179 .30993 Metetra
.685 .808 .941 r
.66179 .30993 .66645 .31478 .67618 .31075 .67155 .30598 Metetra
.66 .804 .952 r
.67155 .30598 .67618 .31075 .68597 .30729 .68137 .30252 Metetra
.636 .796 .959 r
.68137 .30252 .68597 .30729 .69582 .30436 .69125 .29951 Metetra
.624 .789 .961 r
.69125 .29951 .69582 .30436 .70572 .30169 .70117 .29674 Metetra
.59 .772 .966 r
.70117 .29674 .70572 .30169 .7157 .29972 .71117 .29457 Metetra
.558 .749 .966 r
.71117 .29457 .7157 .29972 .72578 .29841 .72125 .29298 Metetra
.553 .735 .96 r
.72125 .29298 .72578 .29841 .73591 .2973 .73139 .29155 Metetra
.568 .729 .95 r
.73139 .29155 .73591 .2973 .74608 .29598 .74157 .28994 Metetra
.601 .733 .937 r
.74157 .28994 .74608 .29598 .75625 .29401 .75175 .28776 Metetra
.622 .735 .928 r
.75175 .28776 .75625 .29401 .76643 .29155 .76194 .28516 Metetra
.632 .735 .922 r
.76194 .28516 .76643 .29155 .77664 .28883 .77216 .28232 Metetra
.64 .735 .917 r
.77216 .28232 .77664 .28883 .78686 .28589 .78241 .2793 Metetra
.645 .735 .914 r
.78241 .2793 .78686 .28589 .79711 .2828 .79268 .27615 Metetra
.653 .736 .911 r
.79268 .27615 .79711 .2828 .80738 .27948 .80297 .27279 Metetra
.658 .738 .909 r
.80297 .27279 .80738 .27948 .81768 .27601 .81329 .26929 Metetra
.677 .746 .903 r
.17248 .47667 .17823 .48198 .18649 .47865 .18074 .47346 Metetra
.682 .752 .905 r
.18074 .47346 .18649 .47865 .19479 .47517 .18904 .47014 Metetra
.684 .759 .908 r
.18904 .47014 .19479 .47517 .20312 .47162 .19737 .46675 Metetra
.687 .767 .912 r
.19737 .46675 .20312 .47162 .21148 .46798 .20573 .4633 Metetra
.687 .775 .919 r
.20573 .4633 .21148 .46798 .21986 .46437 .21411 .45987 Metetra
.68 .782 .927 r
.21411 .45987 .21986 .46437 .22825 .46094 .2225 .45657 Metetra
.669 .786 .936 r
.2225 .45657 .22825 .46094 .23663 .45778 .2309 .45348 Metetra
.655 .786 .945 r
.2309 .45348 .23663 .45778 .24501 .45498 .23929 .45065 Metetra
.644 .784 .948 r
.23929 .45065 .24501 .45498 .2534 .4524 .2477 .448 Metetra
.636 .779 .949 r
.2477 .448 .2534 .4524 .26179 .45002 .25613 .44549 Metetra
.621 .77 .951 r
.25613 .44549 .26179 .45002 .27019 .44798 .26456 .44323 Metetra
.623 .762 .945 r
.26456 .44323 .27019 .44798 .27863 .44592 .27302 .44096 Metetra
.644 .76 .933 r
.27302 .44096 .27863 .44592 .28712 .44338 .28154 .43833 Metetra
.675 .764 .918 r
.28154 .43833 .28712 .44338 .29571 .44002 .29014 .43506 Metetra
.706 .776 .906 r
.29014 .43506 .29571 .44002 .30439 .43567 .29881 .43105 Metetra
.713 .791 .912 r
.29881 .43105 .30439 .43567 .3131 .43112 .30751 .42687 Metetra
.711 .807 .925 r
.30751 .42687 .3131 .43112 .32182 .42665 .31624 .42276 Metetra
.713 .823 .934 r
.31624 .42276 .32182 .42665 .33056 .42214 .32498 .41862 Metetra
.665 .832 .963 r
.32498 .41862 .33056 .42214 .33926 .41881 .3337 .41536 Metetra
.531 .796 .994 r
.3337 .41536 .33926 .41881 .34786 .41782 .34234 .41389 Metetra
.236 .628 .958 r
.34234 .41389 .34786 .41782 .3563 .42054 .35086 .41523 Metetra
0 .385 .837 r
.35086 .41523 .3563 .42054 .3646 .42712 .35929 .41949 Metetra
.06 .355 .828 r
.35929 .41949 .3646 .42712 .37293 .435 .36774 .42472 Metetra
.223 .376 .807 r
.36774 .42472 .37293 .435 .38135 .44287 .37626 .42992 Metetra
.351 .4 .772 r
.37626 .42992 .38135 .44287 .38989 .4498 .38489 .4344 Metetra
.492 .453 .742 r
.38489 .4344 .38989 .4498 .39865 .45308 .3937 .43612 Metetra
.606 .508 .716 r
.3937 .43612 .39865 .45308 .4077 .45045 .40273 .43338 Metetra
.713 .57 .692 r
.40273 .43338 .4077 .45045 .41708 .43855 .41203 .42365 Metetra
.793 .628 .677 r
.41203 .42365 .41708 .43855 .42671 .41771 .42155 .40714 Metetra
.852 .69 .681 r
.42155 .40714 .42671 .41771 .43638 .39294 .43111 .38761 Metetra
.914 .772 .69 r
.43111 .38761 .43638 .39294 .44599 .36703 .44063 .36716 Metetra
.967 .883 .696 r
.44063 .36716 .44599 .36703 .45546 .34277 .45006 .34791 Metetra
.88 .958 .617 r
.45006 .34791 .45546 .34277 .46476 .32309 .45935 .33211 Metetra
.45935 .33211 .46476 .32309 .47388 .31044 .46851 .32167 Metetra
.402 .013 .183 r
.46851 .32167 .47388 .31044 .48282 .30925 .47752 .32002 Metetra
.635 .243 .285 r
.47752 .32002 .48282 .30925 .49168 .31897 .48647 .32672 Metetra
.73 .321 .274 r
.48647 .32672 .49168 .31897 .5006 .33493 .49546 .33817 Metetra
.797 .354 .195 r
.49546 .33817 .5006 .33493 .50965 .35413 .50455 .35204 Metetra
.797 .302 0 r
.50455 .35204 .50965 .35413 .51886 .37287 .51377 .3655 Metetra
0 0 .508 r
.51377 .3655 .51886 .37287 .52822 .38935 .52312 .37719 Metetra
.135 .281 .749 r
.52312 .37719 .52822 .38935 .53771 .40132 .53258 .38544 Metetra
.503 .459 .741 r
.53258 .38544 .53771 .40132 .54727 .40437 .54211 .38694 Metetra
.639 .527 .711 r
.54211 .38694 .54727 .40437 .55681 .39914 .55165 .3822 Metetra
.699 .566 .701 r
.55165 .3822 .55681 .39914 .56631 .38884 .56116 .37363 Metetra
.735 .6 .706 r
.56116 .37363 .56631 .38884 .57576 .37619 .57065 .36327 Metetra
.751 .631 .727 r
.57065 .36327 .57576 .37619 .58519 .36402 .58014 .35326 Metetra
.772 .67 .75 r
.58014 .35326 .58519 .36402 .59461 .35209 .58963 .34343 Metetra
.787 .714 .783 r
.58963 .34343 .59461 .35209 .60403 .34113 .59912 .33432 Metetra
.77 .757 .841 r
.59912 .33432 .60403 .34113 .61352 .33297 .60867 .32732 Metetra
.732 .787 .896 r
.60867 .32732 .61352 .33297 .62309 .32719 .61828 .32213 Metetra
.688 .798 .933 r
.61828 .32213 .62309 .32719 .63273 .323 .62795 .31814 Metetra
.68 .805 .942 r
.62795 .31814 .63273 .323 .6424 .31903 .63766 .31432 Metetra
.702 .819 .937 r
.63766 .31432 .6424 .31903 .65208 .31437 .64738 .30997 Metetra
.693 .831 .949 r
.64738 .30997 .65208 .31437 .66179 .30993 .65713 .30578 Metetra
.673 .837 .962 r
.65713 .30578 .66179 .30993 .67155 .30598 .66693 .30196 Metetra
.65 .837 .972 r
.66693 .30196 .67155 .30598 .68137 .30252 .67678 .29852 Metetra
.629 .831 .978 r
.67678 .29852 .68137 .30252 .69125 .29951 .68668 .29541 Metetra
.62 .823 .979 r
.68668 .29541 .69125 .29951 .70117 .29674 .69663 .29248 Metetra
.594 .807 .981 r
.69663 .29248 .70117 .29674 .71117 .29457 .70664 .29 Metetra
.572 .784 .979 r
.70664 .29 .71117 .29457 .72125 .29298 .71672 .28796 Metetra
.573 .764 .969 r
.71672 .28796 .72125 .29298 .73139 .29155 .72686 .28604 Metetra
.588 .75 .955 r
.72686 .28604 .73139 .29155 .74157 .28994 .73703 .28398 Metetra
.614 .744 .938 r
.73703 .28398 .74157 .28994 .75175 .28776 .74722 .28149 Metetra
.631 .739 .926 r
.74722 .28149 .75175 .28776 .76194 .28516 .75742 .27867 Metetra
.639 .735 .918 r
.75742 .27867 .76194 .28516 .77216 .28232 .76765 .27567 Metetra
.645 .732 .913 r
.76765 .27567 .77216 .28232 .78241 .2793 .77791 .27252 Metetra
.648 .73 .909 r
.77791 .27252 .78241 .2793 .79268 .27615 .7882 .26927 Metetra
.654 .73 .905 r
.7882 .26927 .79268 .27615 .80297 .27279 .79852 .26586 Metetra
.658 .731 .904 r
.79852 .26586 .80297 .27279 .81329 .26929 .80886 .26235 Metetra
.67 .744 .906 r
.1667 .47131 .17248 .47667 .18074 .47346 .17496 .46823 Metetra
.673 .75 .908 r
.17496 .46823 .18074 .47346 .18904 .47014 .18326 .46508 Metetra
.675 .758 .913 r
.18326 .46508 .18904 .47014 .19737 .46675 .19158 .46189 Metetra
.677 .766 .918 r
.19158 .46189 .19737 .46675 .20573 .4633 .19994 .45865 Metetra
.677 .775 .925 r
.19994 .45865 .20573 .4633 .21411 .45987 .20831 .45541 Metetra
.672 .783 .933 r
.20831 .45541 .21411 .45987 .2225 .45657 .21671 .45226 Metetra
.664 .789 .941 r
.21671 .45226 .2225 .45657 .2309 .45348 .22511 .44925 Metetra
.654 .791 .947 r
.22511 .44925 .2309 .45348 .23929 .45065 .23353 .4464 Metetra
.648 .789 .949 r
.23353 .4464 .23929 .45065 .2477 .448 .24196 .44365 Metetra
.643 .784 .949 r
.24196 .44365 .2477 .448 .25613 .44549 .25041 .441 Metetra
.634 .777 .949 r
.25041 .441 .25613 .44549 .26456 .44323 .25888 .43851 Metetra
.635 .768 .943 r
.25888 .43851 .26456 .44323 .27302 .44096 .26738 .43601 Metetra
.649 .762 .932 r
.26738 .43601 .27302 .44096 .28154 .43833 .27592 .43327 Metetra
.669 .764 .921 r
.27592 .43327 .28154 .43833 .29014 .43506 .28453 .43011 Metetra
.69 .774 .915 r
.28453 .43011 .29014 .43506 .29881 .43105 .29319 .42647 Metetra
.695 .791 .924 r
.29319 .42647 .29881 .43105 .30751 .42687 .30189 .42272 Metetra
.693 .809 .937 r
.30189 .42272 .30751 .42687 .31624 .42276 .3106 .41901 Metetra
.693 .827 .947 r
.3106 .41901 .31624 .42276 .32498 .41862 .31935 .41527 Metetra
.657 .838 .97 r
.31935 .41527 .32498 .41862 .3337 .41536 .32808 .4121 Metetra
.57 .819 .992 r
.32808 .4121 .3337 .41536 .34234 .41389 .33677 .41009 Metetra
.415 .731 .99 r
.33677 .41009 .34234 .41389 .35086 .41523 .34539 .4099 Metetra
.292 .595 .948 r
.34539 .4099 .35086 .41523 .35929 .41949 .35396 .4116 Metetra
.354 .526 .887 r
.35396 .4116 .35929 .41949 .36774 .42472 .36255 .41391 Metetra
.426 .486 .819 r
.36255 .41391 .36774 .42472 .37626 .42992 .3712 .41619 Metetra
.479 .465 .765 r
.3712 .41619 .37626 .42992 .38489 .4344 .37993 .418 Metetra
.543 .474 .728 r
.37993 .418 .38489 .4344 .3937 .43612 .38879 .41802 Metetra
.604 .497 .705 r
.38879 .41802 .3937 .43612 .40273 .43338 .39781 .41515 Metetra
.676 .54 .692 r
.39781 .41515 .40273 .43338 .41203 .42365 .40703 .40778 Metetra
.744 .596 .692 r
.40703 .40778 .41203 .42365 .42155 .40714 .4164 .39603 Metetra
.807 .67 .712 r
.4164 .39603 .42155 .40714 .43111 .38761 .42581 .38228 Metetra
.884 .785 .747 r
.42581 .38228 .43111 .38761 .44063 .36716 .43521 .36789 Metetra
.937 .949 .765 r
.43521 .36789 .44063 .36716 .45006 .34791 .44456 .35423 Metetra
.594 .846 .487 r
.44456 .35423 .45006 .34791 .45935 .33211 .45383 .34281 Metetra
.046 0 0 r
.45383 .34281 .45935 .33211 .46851 .32167 .46301 .33487 Metetra
.403 .033 .219 r
.46301 .33487 .46851 .32167 .47752 .32002 .4721 .3327 Metetra
.557 .178 .278 r
.4721 .3327 .47752 .32002 .48647 .32672 .48115 .336 Metetra
.632 .222 .248 r
.48115 .336 .48647 .32672 .49546 .33817 .49024 .34239 Metetra
.688 .216 .126 r
.49024 .34239 .49546 .33817 .50455 .35204 .4994 .35031 Metetra
.613 .047 0 r
.4994 .35031 .50455 .35204 .51377 .3655 .50865 .35792 Metetra
0 .311 .802 r
.50865 .35792 .51377 .3655 .52312 .37719 .51801 .36436 Metetra
.375 .422 .782 r
.51801 .36436 .52312 .37719 .53258 .38544 .52745 .36853 Metetra
.548 .476 .727 r
.52745 .36853 .53258 .38544 .54211 .38694 .53695 .36835 Metetra
.625 .51 .702 r
.53695 .36835 .54211 .38694 .55165 .3822 .54648 .36414 Metetra
.666 .538 .699 r
.54648 .36414 .55165 .3822 .56116 .37363 .55601 .35745 Metetra
.694 .57 .71 r
.55601 .35745 .56116 .37363 .57065 .36327 .56553 .34961 Metetra
.71 .603 .735 r
.56553 .34961 .57065 .36327 .58014 .35326 .57507 .34198 Metetra
.73 .644 .763 r
.57507 .34198 .58014 .35326 .58963 .34343 .58461 .33445 Metetra
.746 .694 .802 r
.58461 .33445 .58963 .34343 .59912 .33432 .59417 .32738 Metetra
.736 .744 .859 r
.59417 .32738 .59912 .33432 .60867 .32732 .60378 .32168 Metetra
.708 .782 .909 r
.60378 .32168 .60867 .32732 .61828 .32213 .61344 .31714 Metetra
.677 .799 .94 r
.61344 .31714 .61828 .32213 .62795 .31814 .62314 .31337 Metetra
.67 .807 .949 r
.62314 .31337 .62795 .31814 .63766 .31432 .63289 .30972 Metetra
.685 .82 .948 r
.63289 .30972 .63766 .31432 .64738 .30997 .64265 .30571 Metetra
.677 .834 .959 r
.64265 .30571 .64738 .30997 .65713 .30578 .65244 .30181 Metetra
.661 .843 .97 r
.65244 .30181 .65713 .30578 .66693 .30196 .66228 .29814 Metetra
.645 .845 .977 r
.66228 .29814 .66693 .30196 .67678 .29852 .67216 .2947 Metetra
.63 .841 .981 r
.67216 .2947 .67678 .29852 .68668 .29541 .68209 .29149 Metetra
.625 .835 .981 r
.68209 .29149 .68668 .29541 .69663 .29248 .69206 .28839 Metetra
.61 .822 .982 r
.69206 .28839 .69663 .29248 .70664 .29 .70209 .28557 Metetra
.598 .803 .978 r
.70209 .28557 .70664 .29 .71672 .28796 .71217 .28303 Metetra
.601 .782 .967 r
.71217 .28303 .71672 .28796 .72686 .28604 .7223 .28057 Metetra
.613 .764 .952 r
.7223 .28057 .72686 .28604 .73703 .28398 .73246 .27802 Metetra
.63 .752 .935 r
.73246 .27802 .73703 .28398 .74722 .28149 .74265 .27517 Metetra
.641 .744 .923 r
.74265 .27517 .74722 .28149 .75742 .27867 .75286 .27211 Metetra
.646 .738 .916 r
.75286 .27211 .75742 .27867 .76765 .27567 .76311 .26893 Metetra
.649 .733 .911 r
.76311 .26893 .76765 .27567 .77791 .27252 .77338 .26565 Metetra
.652 .73 .907 r
.77338 .26565 .77791 .27252 .7882 .26927 .78369 .2623 Metetra
.655 .729 .904 r
.78369 .2623 .7882 .26927 .79852 .26586 .79403 .25884 Metetra
.658 .729 .902 r
.79403 .25884 .79852 .26586 .80886 .26235 .8044 .25531 Metetra
.663 .742 .909 r
.16088 .46592 .1667 .47131 .17496 .46823 .16915 .46298 Metetra
.665 .748 .912 r
.16915 .46298 .17496 .46823 .18326 .46508 .17744 .46 Metetra
.666 .756 .917 r
.17744 .46 .18326 .46508 .19158 .46189 .18576 .457 Metetra
.667 .764 .923 r
.18576 .457 .19158 .46189 .19994 .45865 .19411 .45397 Metetra
.666 .773 .93 r
.19411 .45397 .19994 .45865 .20831 .45541 .20248 .45093 Metetra
.664 .782 .937 r
.20248 .45093 .20831 .45541 .21671 .45226 .21087 .44794 Metetra
.66 .788 .943 r
.21087 .44794 .21671 .45226 .22511 .44925 .21929 .44499 Metetra
.655 .791 .947 r
.21929 .44499 .22511 .44925 .23353 .4464 .22772 .44212 Metetra
.652 .79 .948 r
.22772 .44212 .23353 .4464 .24196 .44365 .23618 .43929 Metetra
.65 .786 .947 r
.23618 .43929 .24196 .44365 .25041 .441 .24466 .43649 Metetra
.646 .78 .945 r
.24466 .43649 .25041 .441 .25888 .43851 .25317 .43377 Metetra
.647 .771 .939 r
.25317 .43377 .25888 .43851 .26738 .43601 .2617 .43103 Metetra
.654 .764 .93 r
.2617 .43103 .26738 .43601 .27592 .43327 .27027 .42818 Metetra
.663 .762 .924 r
.27027 .42818 .27592 .43327 .28453 .43011 .27888 .42514 Metetra
.673 .77 .924 r
.27888 .42514 .28453 .43011 .29319 .42647 .28753 .42187 Metetra
.675 .787 .934 r
.28753 .42187 .29319 .42647 .30189 .42272 .29622 .41855 Metetra
.672 .805 .946 r
.29622 .41855 .30189 .42272 .3106 .41901 .30493 .41523 Metetra
.67 .823 .957 r
.30493 .41523 .3106 .41901 .31935 .41527 .31367 .41191 Metetra
.65 .838 .973 r
.31367 .41191 .31935 .41527 .32808 .4121 .32242 .40883 Metetra
.611 .833 .985 r
.32242 .40883 .32808 .4121 .33677 .41009 .33116 .40627 Metetra
.561 .792 .986 r
.33116 .40627 .33677 .41009 .34539 .4099 .33989 .40454 Metetra
.532 .712 .954 r
.33989 .40454 .34539 .4099 .35396 .4116 .34861 .40365 Metetra
.547 .624 .88 r
.34861 .40365 .35396 .4116 .36255 .41391 .35735 .40303 Metetra
.558 .558 .809 r
.35735 .40303 .36255 .41391 .3712 .41619 .36614 .40238 Metetra
.566 .516 .758 r
.36614 .40238 .3712 .41619 .37993 .418 .37498 .40151 Metetra
.583 .497 .723 r
.37498 .40151 .37993 .418 .38879 .41802 .3839 .39983 Metetra
.606 .497 .704 r
.3839 .39983 .38879 .41802 .39781 .41515 .39291 .39685 Metetra
.641 .518 .698 r
.39291 .39685 .39781 .41515 .40703 .40778 .40202 .39183 Metetra
.684 .562 .711 r
.40202 .39183 .40703 .40778 .4164 .39603 .41123 .38483 Metetra
.737 .641 .754 r
.41123 .38483 .4164 .39603 .42581 .38228 .42047 .37691 Metetra
.812 .792 .834 r
.42047 .37691 .42581 .38228 .43521 .36789 .42973 .36868 Metetra
.795 .996 .862 r
.42973 .36868 .43521 .36789 .44456 .35423 .43898 .36075 Metetra
.43898 .36075 .44456 .35423 .45383 .34281 .44821 .35382 Metetra
.215 0 .078 r
.44821 .35382 .45383 .34281 .46301 .33487 .45741 .34848 Metetra
.386 .019 .214 r
.45741 .34848 .46301 .33487 .4721 .3327 .46658 .34577 Metetra
.463 .087 .239 r
.46658 .34577 .4721 .3327 .48115 .336 .47575 .34556 Metetra
.486 .07 .175 r
.47575 .34556 .48115 .336 .49024 .34239 .48495 .34674 Metetra
.455 0 0 r
.48495 .34674 .49024 .34239 .4994 .35031 .4942 .3486 Metetra
0 .523 .794 r
.4942 .3486 .4994 .35031 .50865 .35792 .50351 .3503 Metetra
.436 .586 .903 r
.50351 .3503 .50865 .35792 .51801 .36436 .51289 .35144 Metetra
.535 .516 .781 r
.51289 .35144 .51801 .36436 .52745 .36853 .52232 .35154 Metetra
.585 .498 .722 r
.52232 .35154 .52745 .36853 .53695 .36835 .5318 .34968 Metetra
.615 .503 .703 r
.5318 .34968 .53695 .36835 .54648 .36414 .54132 .34599 Metetra
.636 .52 .704 r
.54132 .34599 .54648 .36414 .55601 .35745 .55085 .34119 Metetra
.654 .546 .72 r
.55085 .34119 .55601 .35745 .56553 .34961 .56041 .33586 Metetra
.667 .58 .747 r
.56041 .33586 .56553 .34961 .57507 .34198 .56998 .33061 Metetra
.683 .622 .781 r
.56998 .33061 .57507 .34198 .58461 .33445 .57958 .32541 Metetra
.698 .674 .824 r
.57958 .32541 .58461 .33445 .59417 .32738 .5892 .3204 Metetra
.696 .731 .877 r
.5892 .3204 .59417 .32738 .60378 .32168 .59886 .316 Metetra
.682 .773 .92 r
.59886 .316 .60378 .32168 .61344 .31714 .60856 .31212 Metetra
.665 .795 .944 r
.60856 .31212 .61344 .31714 .62314 .31337 .6183 .30858 Metetra
.661 .805 .952 r
.6183 .30858 .62314 .31337 .63289 .30972 .62808 .30509 Metetra
.667 .815 .954 r
.62808 .30509 .63289 .30972 .64265 .30571 .63788 .30143 Metetra
.662 .83 .964 r
.63788 .30143 .64265 .30571 .65244 .30181 .64772 .29782 Metetra
.652 .84 .973 r
.64772 .29782 .65244 .30181 .66228 .29814 .6576 .2943 Metetra
.642 .845 .978 r
.6576 .2943 .66228 .29814 .67216 .2947 .66751 .29088 Metetra
.635 .844 .98 r
.66751 .29088 .67216 .2947 .68209 .29149 .67747 .28756 Metetra
.634 .84 .979 r
.67747 .28756 .68209 .29149 .69206 .28839 .68746 .28428 Metetra
.629 .83 .978 r
.68746 .28428 .69206 .28839 .70209 .28557 .6975 .28112 Metetra
.626 .815 .973 r
.6975 .28112 .70209 .28557 .71217 .28303 .70758 .27808 Metetra
.631 .795 .961 r
.70758 .27808 .71217 .28303 .7223 .28057 .71771 .27508 Metetra
.637 .775 .946 r
.71771 .27508 .7223 .28057 .73246 .27802 .72787 .27202 Metetra
.645 .758 .931 r
.72787 .27202 .73246 .27802 .74265 .27517 .73806 .26882 Metetra
.65 .747 .921 r
.73806 .26882 .74265 .27517 .75286 .27211 .74828 .26552 Metetra
.652 .74 .914 r
.74828 .26552 .75286 .27211 .76311 .26893 .75854 .26215 Metetra
.654 .735 .909 r
.75854 .26215 .76311 .26893 .77338 .26565 .76883 .25874 Metetra
.655 .732 .906 r
.76883 .25874 .77338 .26565 .78369 .2623 .77915 .25528 Metetra
.656 .729 .903 r
.77915 .25528 .78369 .2623 .79403 .25884 .78951 .25177 Metetra
.657 .729 .902 r
.78951 .25177 .79403 .25884 .8044 .25531 .79991 .24822 Metetra
.657 .741 .912 r
.15503 .46052 .16088 .46592 .16915 .46298 .1633 .4577 Metetra
.657 .747 .916 r
.1633 .4577 .16915 .46298 .17744 .46 .17159 .45487 Metetra
.657 .753 .921 r
.17159 .45487 .17744 .46 .18576 .457 .1799 .45204 Metetra
.657 .76 .926 r
.1799 .45204 .18576 .457 .19411 .45397 .18825 .44919 Metetra
.656 .769 .932 r
.18825 .44919 .19411 .45397 .20248 .45093 .19662 .44634 Metetra
.656 .777 .938 r
.19662 .44634 .20248 .45093 .21087 .44794 .20501 .44347 Metetra
.656 .783 .942 r
.20501 .44347 .21087 .44794 .21929 .44499 .21344 .44059 Metetra
.656 .786 .944 r
.21344 .44059 .21929 .44499 .22772 .44212 .22189 .43769 Metetra
.656 .786 .944 r
.22189 .43769 .22772 .44212 .23618 .43929 .23037 .43478 Metetra
.656 .783 .942 r
.23037 .43478 .23618 .43929 .24466 .43649 .23888 .43186 Metetra
.657 .779 .938 r
.23888 .43186 .24466 .43649 .25317 .43377 .24742 .42892 Metetra
.658 .771 .933 r
.24742 .42892 .25317 .43377 .2617 .43103 .25599 .42598 Metetra
.658 .763 .927 r
.25599 .42598 .2617 .43103 .27027 .42818 .26458 .42303 Metetra
.657 .76 .925 r
.26458 .42303 .27027 .42818 .27888 .42514 .2732 .42008 Metetra
.656 .764 .929 r
.2732 .42008 .27888 .42514 .28753 .42187 .28185 .41715 Metetra
.655 .778 .939 r
.28185 .41715 .28753 .42187 .29622 .41855 .29053 .4142 Metetra
.653 .794 .95 r
.29053 .4142 .29622 .41855 .30493 .41523 .29923 .41124 Metetra
.65 .81 .96 r
.29923 .41124 .30493 .41523 .31367 .41191 .30796 .40828 Metetra
.647 .826 .969 r
.30796 .40828 .31367 .41191 .32242 .40883 .31673 .40528 Metetra
.648 .831 .97 r
.31673 .40528 .32242 .40883 .33116 .40627 .32552 .40224 Metetra
.657 .812 .958 r
.32552 .40224 .33116 .40627 .33989 .40454 .33435 .39912 Metetra
.665 .757 .919 r
.33435 .39912 .33989 .40454 .34861 .40365 .34321 .39593 Metetra
.658 .679 .858 r
.34321 .39593 .34861 .40365 .35735 .40303 .35211 .39271 Metetra
.644 .612 .803 r
.35211 .39271 .35735 .40303 .36614 .40238 .36103 .38948 Metetra
.631 .564 .761 r
.36103 .38948 .36614 .40238 .37498 .40151 .36997 .38626 Metetra
.619 .531 .732 r
.36997 .38626 .37498 .40151 .3839 .39983 .37895 .38309 Metetra
.612 .513 .717 r
.37895 .38309 .3839 .39983 .39291 .39685 .38795 .38 Metetra
.609 .51 .717 r
.38795 .38 .39291 .39685 .40202 .39183 .39697 .37705 Metetra
.613 .533 .74 r
.39697 .37705 .40202 .39183 .41123 .38483 .40602 .37423 Metetra
.628 .602 .804 r
.40602 .37423 .41123 .38483 .42047 .37691 .4151 .37147 Metetra
.639 .755 .932 r
.4151 .37147 .42047 .37691 .42973 .36868 .42421 .36873 Metetra
.4 .854 .884 r
.42421 .36873 .42973 .36868 .43898 .36075 .43336 .36595 Metetra
.123 0 0 r
.43336 .36595 .43898 .36075 .44821 .35382 .44254 .36309 Metetra
.291 0 .061 r
.44254 .36309 .44821 .35382 .45741 .34848 .45176 .36009 Metetra
.334 0 .146 r
.45176 .36009 .45741 .34848 .46658 .34577 .46101 .35689 Metetra
.316 0 .126 r
.46101 .35689 .46658 .34577 .47575 .34556 .4703 .35349 Metetra
.218 0 0 r
.4703 .35349 .47575 .34556 .48495 .34674 .47962 .34998 Metetra
.47962 .34998 .48495 .34674 .4942 .3486 .48897 .34641 Metetra
.629 .899 .986 r
.48897 .34641 .4942 .3486 .50351 .3503 .49834 .34283 Metetra
.666 .699 .871 r
.49834 .34283 .50351 .3503 .51289 .35144 .50775 .33929 Metetra
.638 .585 .778 r
.50775 .33929 .51289 .35144 .52232 .35154 .51719 .33581 Metetra
.619 .53 .732 r
.51719 .33581 .52232 .35154 .5318 .34968 .52667 .33247 Metetra
.611 .512 .717 r
.52667 .33247 .5318 .34968 .54132 .34599 .53617 .32924 Metetra
.611 .516 .722 r
.53617 .32924 .54132 .34599 .55085 .34119 .54571 .32609 Metetra
.616 .536 .741 r
.54571 .32609 .55085 .34119 .56041 .33586 .55528 .32297 Metetra
.626 .569 .771 r
.55528 .32297 .56041 .33586 .56998 .33061 .56488 .31982 Metetra
.635 .609 .806 r
.56488 .31982 .56998 .33061 .57958 .32541 .57452 .31666 Metetra
.645 .66 .85 r
.57452 .31666 .57958 .32541 .5892 .3204 .5842 .31348 Metetra
.653 .718 .896 r
.5842 .31348 .5892 .3204 .59886 .316 .5939 .31023 Metetra
.656 .762 .928 r
.5939 .31023 .59886 .316 .60856 .31212 .60364 .30694 Metetra
.655 .787 .945 r
.60364 .30694 .60856 .31212 .6183 .30858 .61342 .3036 Metetra
.654 .796 .951 r
.61342 .3036 .6183 .30858 .62808 .30509 .62323 .30026 Metetra
.652 .802 .955 r
.62323 .30026 .62808 .30509 .63788 .30143 .63307 .29691 Metetra
.649 .816 .963 r
.63307 .29691 .63788 .30143 .64772 .29782 .64295 .29354 Metetra
.647 .827 .97 r
.64295 .29354 .64772 .29782 .6576 .2943 .65286 .29016 Metetra
.645 .834 .973 r
.65286 .29016 .6576 .2943 .66751 .29088 .66281 .28675 Metetra
.645 .835 .974 r
.66281 .28675 .66751 .29088 .67747 .28756 .67279 .28333 Metetra
.646 .832 .972 r
.67279 .28333 .67747 .28756 .68746 .28428 .68281 .27989 Metetra
.649 .826 .968 r
.68281 .27989 .68746 .28428 .6975 .28112 .69286 .27643 Metetra
.652 .815 .962 r
.69286 .27643 .6975 .28112 .70758 .27808 .70295 .27294 Metetra
.656 .798 .951 r
.70295 .27294 .70758 .27808 .71771 .27508 .71308 .26944 Metetra
.658 .779 .938 r
.71308 .26944 .71771 .27508 .72787 .27202 .72324 .26593 Metetra
.658 .762 .926 r
.72324 .26593 .72787 .27202 .73806 .26882 .73343 .26242 Metetra
.658 .751 .918 r
.73343 .26242 .73806 .26882 .74828 .26552 .74367 .2589 Metetra
.658 .743 .913 r
.74367 .2589 .74828 .26552 .75854 .26215 .75394 .25537 Metetra
.658 .738 .909 r
.75394 .25537 .75854 .26215 .76883 .25874 .76424 .25183 Metetra
.658 .735 .906 r
.76424 .25183 .76883 .25874 .77915 .25528 .77459 .24828 Metetra
.657 .732 .905 r
.77459 .24828 .77915 .25528 .78951 .25177 .78497 .24472 Metetra
.657 .731 .904 r
.78497 .24472 .78951 .25177 .79991 .24822 .79539 .24116 Metetra
.653 .743 .916 r
.14914 .45517 .15503 .46052 .1633 .4577 .15741 .45241 Metetra
.652 .746 .919 r
.15741 .45241 .1633 .4577 .17159 .45487 .1657 .44967 Metetra
.652 .75 .922 r
.1657 .44967 .17159 .45487 .1799 .45204 .17402 .44693 Metetra
.651 .754 .925 r
.17402 .44693 .1799 .45204 .18825 .44919 .18237 .44419 Metetra
.651 .759 .929 r
.18237 .44419 .18825 .44919 .19662 .44634 .19074 .44143 Metetra
.652 .764 .931 r
.19074 .44143 .19662 .44634 .20501 .44347 .19915 .43864 Metetra
.654 .768 .933 r
.19915 .43864 .20501 .44347 .21344 .44059 .20759 .43579 Metetra
.657 .771 .933 r
.20759 .43579 .21344 .44059 .22189 .43769 .21606 .43287 Metetra
.659 .771 .932 r
.21606 .43287 .22189 .43769 .23037 .43478 .22456 .42991 Metetra
.661 .77 .931 r
.22456 .42991 .23037 .43478 .23888 .43186 .23309 .4269 Metetra
.664 .768 .928 r
.23309 .4269 .23888 .43186 .24742 .42892 .24166 .42383 Metetra
.664 .764 .924 r
.24166 .42383 .24742 .42892 .25599 .42598 .25025 .42075 Metetra
.66 .758 .922 r
.25025 .42075 .25599 .42598 .26458 .42303 .25887 .41773 Metetra
.654 .754 .924 r
.25887 .41773 .26458 .42303 .2732 .42008 .2675 .41484 Metetra
.646 .755 .929 r
.2675 .41484 .2732 .42008 .28185 .41715 .27615 .41209 Metetra
.644 .763 .935 r
.27615 .41209 .28185 .41715 .29053 .4142 .28483 .40937 Metetra
.644 .773 .942 r
.28483 .40937 .29053 .4142 .29923 .41124 .29353 .40662 Metetra
.642 .781 .948 r
.29353 .40662 .29923 .41124 .30796 .40828 .30227 .40386 Metetra
.651 .794 .951 r
.30227 .40386 .30796 .40828 .31673 .40528 .31105 .4009 Metetra
.671 .801 .945 r
.31105 .4009 .31673 .40528 .32552 .40224 .31989 .39756 Metetra
.699 .795 .925 r
.31989 .39756 .32552 .40224 .33435 .39912 .32879 .39361 Metetra
.718 .768 .892 r
.32879 .39361 .33435 .39912 .34321 .39593 .33775 .38904 Metetra
.714 .722 .856 r
.33775 .38904 .34321 .39593 .35211 .39271 .34674 .38426 Metetra
.7 .676 .824 r
.34674 .38426 .35211 .39271 .36103 .38948 .35575 .37948 Metetra
.683 .637 .797 r
.35575 .37948 .36103 .38948 .36997 .38626 .36477 .37485 Metetra
.659 .601 .779 r
.36477 .37485 .36997 .38626 .37895 .38309 .37379 .37079 Metetra
.631 .574 .772 r
.37379 .37079 .37895 .38309 .38795 .38 .38279 .36763 Metetra
.592 .552 .779 r
.38279 .36763 .38795 .38 .39697 .37705 .39177 .36589 Metetra
.544 .548 .809 r
.39177 .36589 .39697 .37705 .40602 .37423 .40072 .36556 Metetra
.499 .584 .871 r
.40072 .36556 .40602 .37423 .4151 .37147 .4097 .36588 Metetra
.415 .655 .958 r
.4097 .36588 .4151 .37147 .42421 .36873 .41872 .36642 Metetra
.215 .69 .937 r
.41872 .36642 .42421 .36873 .43336 .36595 .4278 .36675 Metetra
.031 0 0 r
.4278 .36675 .43336 .36595 .44254 .36309 .43695 .36634 Metetra
.115 0 0 r
.43695 .36634 .44254 .36309 .45176 .36009 .44618 .36477 Metetra
.02 0 0 r
.44618 .36477 .45176 .36009 .46101 .35689 .45549 .36127 Metetra
.45549 .36127 .46101 .35689 .4703 .35349 .46486 .35592 Metetra
.537 .908 .732 r
.46486 .35592 .4703 .35349 .47962 .34998 .47427 .34955 Metetra
.771 .981 .91 r
.47427 .34955 .47962 .34998 .48897 .34641 .4837 .34269 Metetra
.795 .866 .901 r
.4837 .34269 .48897 .34641 .49834 .34283 .49314 .33595 Metetra
.753 .747 .846 r
.49314 .33595 .49834 .34283 .50775 .33929 .50259 .3296 Metetra
.707 .662 .803 r
.50259 .3296 .50775 .33929 .51719 .33581 .51205 .32399 Metetra
.658 .601 .779 r
.51205 .32399 .51719 .33581 .52667 .33247 .52152 .31976 Metetra
.622 .569 .774 r
.52152 .31976 .52667 .33247 .53617 .32924 .53103 .3168 Metetra
.602 .562 .782 r
.53103 .3168 .53617 .32924 .54571 .32609 .54057 .31462 Metetra
.593 .575 .802 r
.54057 .31462 .54571 .32609 .55528 .32297 .55016 .31279 Metetra
.598 .603 .828 r
.55016 .31279 .55528 .32297 .56488 .31982 .55979 .31089 Metetra
.6 .635 .857 r
.55979 .31089 .56488 .31982 .57452 .31666 .56946 .30895 Metetra
.606 .673 .888 r
.56946 .30895 .57452 .31666 .5842 .31348 .57917 .30684 Metetra
.623 .718 .914 r
.57917 .30684 .5842 .31348 .5939 .31023 .58891 .30428 Metetra
.639 .751 .929 r
.58891 .30428 .5939 .31023 .60364 .30694 .59869 .30133 Metetra
.65 .769 .936 r
.59869 .30133 .60364 .30694 .61342 .3036 .60849 .29811 Metetra
.651 .775 .939 r
.60849 .29811 .61342 .3036 .62323 .30026 .61833 .29484 Metetra
.646 .777 .943 r
.61833 .29484 .62323 .30026 .63307 .29691 .6282 .29167 Metetra
.646 .785 .948 r
.6282 .29167 .63307 .29691 .64295 .29354 .63811 .28844 Metetra
.649 .793 .951 r
.63811 .28844 .64295 .29354 .65286 .29016 .64806 .28513 Metetra
.653 .799 .953 r
.64806 .28513 .65286 .29016 .66281 .28675 .65804 .28172 Metetra
.656 .801 .952 r
.65804 .28172 .66281 .28675 .67279 .28333 .66804 .27823 Metetra
.659 .799 .95 r
.66804 .27823 .67279 .28333 .68281 .27989 .67809 .27468 Metetra
.664 .798 .946 r
.67809 .27468 .68281 .27989 .69286 .27643 .68816 .27103 Metetra
.669 .792 .941 r
.68816 .27103 .69286 .27643 .70295 .27294 .69826 .26726 Metetra
.671 .783 .933 r
.69826 .26726 .70295 .27294 .71308 .26944 .70839 .26346 Metetra
.67 .771 .926 r
.70839 .26346 .71308 .26944 .72324 .26593 .71857 .25967 Metetra
.666 .76 .92 r
.71857 .25967 .72324 .26593 .73343 .26242 .72878 .25596 Metetra
.663 .752 .916 r
.72878 .25596 .73343 .26242 .74367 .2589 .73903 .2523 Metetra
.661 .747 .914 r
.73903 .2523 .74367 .2589 .75394 .25537 .74932 .24866 Metetra
.66 .744 .912 r
.74932 .24866 .75394 .25537 .76424 .25183 .75965 .24504 Metetra
.659 .741 .91 r
.75965 .24504 .76424 .25183 .77459 .24828 .77001 .24143 Metetra
.658 .739 .91 r
.77001 .24143 .77459 .24828 .78497 .24472 .78042 .23783 Metetra
.657 .738 .909 r
.78042 .23783 .78497 .24472 .79539 .24116 .79086 .23424 Metetra
.652 .746 .919 r
.1432 .44987 .14914 .45517 .15741 .45241 .15148 .44712 Metetra
.65 .747 .92 r
.15148 .44712 .15741 .45241 .1657 .44967 .15979 .44439 Metetra
.65 .748 .921 r
.15979 .44439 .1657 .44967 .17402 .44693 .16812 .44167 Metetra
.649 .749 .923 r
.16812 .44167 .17402 .44693 .18237 .44419 .17648 .43896 Metetra
.649 .751 .924 r
.17648 .43896 .18237 .44419 .19074 .44143 .18486 .43623 Metetra
.651 .753 .924 r
.18486 .43623 .19074 .44143 .19915 .43864 .19328 .43344 Metetra
.654 .755 .924 r
.19328 .43344 .19915 .43864 .20759 .43579 .20173 .43059 Metetra
.658 .757 .923 r
.20173 .43059 .20759 .43579 .21606 .43287 .21022 .42766 Metetra
.66 .757 .922 r
.21022 .42766 .21606 .43287 .22456 .42991 .21874 .42466 Metetra
.662 .757 .921 r
.21874 .42466 .22456 .42991 .23309 .4269 .22729 .42162 Metetra
.666 .757 .919 r
.22729 .42162 .23309 .4269 .24166 .42383 .23588 .41849 Metetra
.666 .756 .917 r
.23588 .41849 .24166 .42383 .25025 .42075 .24449 .41535 Metetra
.661 .753 .918 r
.24449 .41535 .25025 .42075 .25887 .41773 .25313 .4123 Metetra
.653 .75 .921 r
.25313 .4123 .25887 .41773 .2675 .41484 .26177 .40941 Metetra
.643 .748 .925 r
.26177 .40941 .2675 .41484 .27615 .41209 .27043 .40672 Metetra
.64 .75 .928 r
.27043 .40672 .27615 .41209 .28483 .40937 .27912 .40406 Metetra
.641 .754 .93 r
.27912 .40406 .28483 .40937 .29353 .40662 .28784 .40136 Metetra
.641 .757 .933 r
.28784 .40136 .29353 .40662 .30227 .40386 .29659 .39867 Metetra
.653 .763 .93 r
.29659 .39867 .30227 .40386 .31105 .4009 .30539 .39572 Metetra
.677 .77 .921 r
.30539 .39572 .31105 .4009 .31989 .39756 .31425 .39225 Metetra
.708 .774 .904 r
.31425 .39225 .31989 .39756 .32879 .39361 .32319 .388 Metetra
.733 .769 .881 r
.32319 .388 .32879 .39361 .33775 .38904 .3322 .38293 Metetra
.737 .753 .866 r
.3322 .38293 .33775 .38904 .34674 .38426 .34124 .3776 Metetra
.731 .735 .855 r
.34124 .3776 .34674 .38426 .35575 .37948 .3503 .37228 Metetra
.72 .717 .846 r
.3503 .37228 .35575 .37948 .36477 .37485 .35936 .36715 Metetra
.695 .695 .847 r
.35936 .36715 .36477 .37485 .37379 .37079 .36841 .36276 Metetra
.654 .672 .855 r
.36841 .36276 .37379 .37079 .38279 .36763 .37743 .35956 Metetra
.578 .64 .876 r
.37743 .35956 .38279 .36763 .39177 .36589 .38639 .35823 Metetra
.471 .603 .901 r
.38639 .35823 .39177 .36589 .40072 .36556 .39532 .35875 Metetra
.385 .59 .925 r
.39532 .35875 .40072 .36556 .4097 .36588 .40427 .36013 Metetra
.311 .594 .945 r
.40427 .36013 .4097 .36588 .41872 .36642 .41326 .36181 Metetra
.272 .625 .961 r
.41326 .36181 .41872 .36642 .4278 .36675 .42233 .3632 Metetra
.307 .695 .978 r
.42233 .3632 .4278 .36675 .43695 .36634 .43147 .36365 Metetra
.424 .795 .994 r
.43147 .36365 .43695 .36634 .44618 .36477 .44071 .36257 Metetra
.634 .899 .985 r
.44071 .36257 .44618 .36477 .45549 .36127 .45006 .35894 Metetra
.771 .919 .936 r
.45006 .35894 .45549 .36127 .46486 .35592 .45948 .35289 Metetra
.816 .892 .897 r
.45948 .35289 .46486 .35592 .47427 .34955 .46894 .34551 Metetra
.824 .852 .869 r
.46894 .34551 .47427 .34955 .4837 .34269 .47842 .33749 Metetra
.808 .811 .853 r
.47842 .33749 .4837 .34269 .49314 .33595 .4879 .32963 Metetra
.783 .772 .843 r
.4879 .32963 .49314 .33595 .50259 .3296 .49738 .3223 Metetra
.749 .735 .839 r
.49738 .3223 .50259 .3296 .51205 .32399 .50687 .31593 Metetra
.693 .696 .848 r
.50687 .31593 .51205 .32399 .52152 .31976 .51636 .31138 Metetra
.637 .665 .861 r
.51636 .31138 .52152 .31976 .53103 .3168 .52588 .3085 Metetra
.597 .65 .873 r
.52588 .3085 .53103 .3168 .54057 .31462 .53544 .30664 Metetra
.575 .65 .887 r
.53544 .30664 .54057 .31462 .55016 .31279 .54504 .30525 Metetra
.577 .665 .899 r
.54504 .30525 .55016 .31279 .55979 .31089 .55469 .30377 Metetra
.577 .68 .911 r
.55469 .30377 .55979 .31089 .56946 .30895 .56438 .30223 Metetra
.584 .699 .921 r
.56438 .30223 .56946 .30895 .57917 .30684 .57412 .30048 Metetra
.611 .724 .926 r
.57412 .30048 .57917 .30684 .58891 .30428 .58389 .29815 Metetra
.634 .743 .927 r
.58389 .29815 .58891 .30428 .59869 .30133 .59369 .2953 Metetra
.649 .754 .926 r
.59369 .2953 .59869 .30133 .60849 .29811 .60351 .29211 Metetra
.651 .756 .926 r
.60351 .29211 .60849 .29811 .61833 .29484 .61337 .28885 Metetra
.644 .755 .929 r
.61337 .28885 .61833 .29484 .6282 .29167 .62328 .28572 Metetra
.647 .758 .931 r
.62328 .28572 .6282 .29167 .63811 .28844 .63322 .28253 Metetra
.651 .762 .931 r
.63322 .28253 .63811 .28844 .64806 .28513 .64319 .27923 Metetra
.656 .765 .93 r
.64319 .27923 .64806 .28513 .65804 .28172 .65319 .27581 Metetra
.66 .767 .929 r
.65319 .27581 .65804 .28172 .66804 .27823 .66322 .27228 Metetra
.663 .768 .928 r
.66322 .27228 .66804 .27823 .67809 .27468 .67329 .26868 Metetra
.668 .769 .925 r
.67329 .26868 .67809 .27468 .68816 .27103 .68339 .26494 Metetra
.673 .768 .922 r
.68339 .26494 .68816 .27103 .69826 .26726 .69351 .26106 Metetra
.675 .765 .919 r
.69351 .26106 .69826 .26726 .70839 .26346 .70366 .25714 Metetra
.673 .761 .917 r
.70366 .25714 .70839 .26346 .71857 .25967 .71385 .25324 Metetra
.668 .756 .916 r
.71385 .25324 .71857 .25967 .72878 .25596 .72409 .24944 Metetra
.665 .752 .915 r
.72409 .24944 .72878 .25596 .73903 .2523 .73436 .24572 Metetra
.663 .75 .915 r
.73436 .24572 .73903 .2523 .74932 .24866 .74468 .24203 Metetra
.661 .748 .915 r
.74468 .24203 .74932 .24866 .75965 .24504 .75503 .23836 Metetra
.66 .747 .914 r
.75503 .23836 .75965 .24504 .77001 .24143 .76542 .23471 Metetra
.659 .746 .914 r
.76542 .23471 .77001 .24143 .78042 .23783 .77585 .23108 Metetra
.657 .745 .915 r
.77585 .23108 .78042 .23783 .79086 .23424 .78633 .22747 Metetra
.652 .748 .92 r
.13722 .44458 .1432 .44987 .15148 .44712 .14552 .44181 Metetra
.651 .747 .92 r
.14552 .44181 .15148 .44712 .15979 .44439 .15384 .43906 Metetra
.65 .747 .92 r
.15384 .43906 .15979 .44439 .16812 .44167 .16219 .43631 Metetra
.649 .747 .92 r
.16219 .43631 .16812 .44167 .17648 .43896 .17056 .43357 Metetra
.65 .746 .92 r
.17056 .43357 .17648 .43896 .18486 .43623 .17896 .43081 Metetra
.652 .746 .919 r
.17896 .43081 .18486 .43623 .19328 .43344 .1874 .42801 Metetra
.654 .747 .918 r
.1874 .42801 .19328 .43344 .20173 .43059 .19587 .42514 Metetra
.658 .748 .916 r
.19587 .42514 .20173 .43059 .21022 .42766 .20437 .42219 Metetra
.66 .748 .915 r
.20437 .42219 .21022 .42766 .21874 .42466 .21291 .41917 Metetra
.662 .749 .915 r
.21291 .41917 .21874 .42466 .22729 .42162 .22148 .41611 Metetra
.665 .75 .913 r
.22148 .41611 .22729 .42162 .23588 .41849 .23008 .41297 Metetra
.665 .75 .914 r
.23008 .41297 .23588 .41849 .24449 .41535 .23871 .40982 Metetra
.661 .749 .916 r
.23871 .40982 .24449 .41535 .25313 .4123 .24736 .40676 Metetra
.653 .747 .919 r
.24736 .40676 .25313 .4123 .26177 .40941 .25602 .40385 Metetra
.644 .745 .922 r
.25602 .40385 .26177 .40941 .27043 .40672 .2647 .40112 Metetra
.642 .743 .923 r
.2647 .40112 .27043 .40672 .27912 .40406 .2734 .39843 Metetra
.643 .743 .922 r
.2734 .39843 .27912 .40406 .28784 .40136 .28214 .3957 Metetra
.642 .742 .921 r
.28214 .3957 .28784 .40136 .29659 .39867 .29091 .39297 Metetra
.654 .745 .917 r
.29091 .39297 .29659 .39867 .30539 .39572 .29973 .39 Metetra
.675 .751 .908 r
.29973 .39 .30539 .39572 .31425 .39225 .3086 .38654 Metetra
.704 .759 .895 r
.3086 .38654 .31425 .39225 .32319 .388 .31756 .38232 Metetra
.73 .767 .882 r
.31756 .38232 .32319 .388 .3322 .38293 .32658 .37733 Metetra
.738 .772 .88 r
.32658 .37733 .3322 .38293 .34124 .3776 .33564 .37208 Metetra
.739 .776 .883 r
.33564 .37208 .34124 .3776 .3503 .37228 .34472 .36684 Metetra
.733 .778 .889 r
.34472 .36684 .3503 .37228 .35936 .36715 .3538 .36179 Metetra
.709 .777 .905 r
.3538 .36179 .35936 .36715 .36841 .36276 .36287 .35744 Metetra
.661 .767 .928 r
.36287 .35744 .36841 .36276 .37743 .35956 .37191 .35423 Metetra
.56 .732 .956 r
.37191 .35423 .37743 .35956 .38639 .35823 .38089 .3528 Metetra
.424 .668 .963 r
.38089 .3528 .38639 .35823 .39532 .35875 .38984 .35312 Metetra
.355 .625 .954 r
.38984 .35312 .39532 .35875 .40427 .36013 .39881 .35426 Metetra
.338 .606 .947 r
.39881 .35426 .40427 .36013 .41326 .36181 .40782 .35569 Metetra
.375 .616 .945 r
.40782 .35569 .41326 .36181 .42233 .3632 .4169 .35685 Metetra
.457 .649 .941 r
.4169 .35685 .42233 .3632 .43147 .36365 .42607 .35711 Metetra
.557 .688 .927 r
.42607 .35711 .43147 .36365 .44071 .36257 .43532 .3559 Metetra
.672 .729 .893 r
.43532 .3559 .44071 .36257 .45006 .35894 .44469 .35228 Metetra
.745 .751 .857 r
.44469 .35228 .45006 .35894 .45948 .35289 .45413 .34635 Metetra
.777 .762 .84 r
.45413 .34635 .45948 .35289 .46894 .34551 .46361 .33914 Metetra
.792 .771 .834 r
.46361 .33914 .46894 .34551 .47842 .33749 .47312 .33132 Metetra
.791 .778 .841 r
.47312 .33132 .47842 .33749 .4879 .32963 .48262 .32366 Metetra
.783 .784 .853 r
.48262 .32366 .4879 .32963 .49738 .3223 .49213 .3165 Metetra
.762 .787 .873 r
.49213 .3165 .49738 .3223 .50687 .31593 .50164 .31025 Metetra
.708 .779 .908 r
.50164 .31025 .50687 .31593 .51636 .31138 .51116 .30574 Metetra
.639 .76 .936 r
.51116 .30574 .51636 .31138 .52588 .3085 .5207 .30282 Metetra
.587 .739 .948 r
.5207 .30282 .52588 .3085 .53544 .30664 .53028 .30087 Metetra
.56 .725 .951 r
.53028 .30087 .53544 .30664 .54504 .30525 .5399 .29937 Metetra
.567 .724 .947 r
.5399 .29937 .54504 .30525 .55469 .30377 .54957 .29778 Metetra
.571 .722 .944 r
.54957 .29778 .55469 .30377 .56438 .30223 .55928 .29613 Metetra
.582 .723 .94 r
.55928 .29613 .56438 .30223 .57412 .30048 .56904 .29429 Metetra
.612 .733 .931 r
.56904 .29429 .57412 .30048 .58389 .29815 .57883 .29189 Metetra
.635 .74 .924 r
.57883 .29189 .58389 .29815 .59369 .2953 .58865 .28899 Metetra
.65 .745 .919 r
.58865 .28899 .59369 .2953 .60351 .29211 .5985 .28576 Metetra
.652 .745 .918 r
.5985 .28576 .60351 .29211 .61337 .28885 .60838 .28248 Metetra
.646 .742 .92 r
.60838 .28248 .61337 .28885 .62328 .28572 .61831 .27931 Metetra
.648 .743 .919 r
.61831 .27931 .62328 .28572 .63322 .28253 .62827 .27609 Metetra
.652 .744 .917 r
.62827 .27609 .63322 .28253 .64319 .27923 .63826 .27276 Metetra
.656 .745 .916 r
.63826 .27276 .64319 .27923 .65319 .27581 .64829 .26931 Metetra
.66 .747 .914 r
.64829 .26931 .65319 .27581 .66322 .27228 .65835 .26576 Metetra
.662 .748 .914 r
.65835 .26576 .66322 .27228 .67329 .26868 .66844 .26215 Metetra
.667 .75 .912 r
.66844 .26215 .67329 .26868 .68339 .26494 .67856 .2584 Metetra
.672 .752 .911 r
.67856 .2584 .68339 .26494 .69351 .26106 .68871 .25451 Metetra
.673 .754 .911 r
.68871 .25451 .69351 .26106 .70366 .25714 .69889 .25058 Metetra
.672 .754 .912 r
.69889 .25058 .70366 .25714 .71385 .25324 .70911 .24668 Metetra
.668 .753 .914 r
.70911 .24668 .71385 .25324 .72409 .24944 .71937 .24287 Metetra
.664 .752 .915 r
.71937 .24287 .72409 .24944 .73436 .24572 .72967 .23913 Metetra
.662 .751 .916 r
.72967 .23913 .73436 .24572 .74468 .24203 .74001 .23542 Metetra
.661 .751 .917 r
.74001 .23542 .74468 .24203 .75503 .23836 .75039 .23174 Metetra
.66 .751 .917 r
.75039 .23174 .75503 .23836 .76542 .23471 .76081 .22806 Metetra
.659 .75 .918 r
.76081 .22806 .76542 .23471 .77585 .23108 .77127 .22441 Metetra
.658 .75 .918 r
.77127 .22441 .77585 .23108 .78633 .22747 .78177 .22078 Metetra
.653 .749 .92 r
.13121 .43928 .13722 .44458 .14552 .44181 .13952 .43647 Metetra
.652 .748 .92 r
.13952 .43647 .14552 .44181 .15384 .43906 .14786 .43368 Metetra
.652 .747 .919 r
.14786 .43368 .15384 .43906 .16219 .43631 .15623 .43088 Metetra
.651 .746 .919 r
.15623 .43088 .16219 .43631 .17056 .43357 .16462 .42809 Metetra
.651 .744 .918 r
.16462 .42809 .17056 .43357 .17896 .43081 .17304 .42528 Metetra
.653 .743 .916 r
.17304 .42528 .17896 .43081 .1874 .42801 .18149 .42244 Metetra
.655 .743 .915 r
.18149 .42244 .1874 .42801 .19587 .42514 .18998 .41953 Metetra
.658 .743 .913 r
.18998 .41953 .19587 .42514 .20437 .42219 .1985 .41656 Metetra
.659 .744 .912 r
.1985 .41656 .20437 .42219 .21291 .41917 .20705 .41355 Metetra
.661 .745 .912 r
.20705 .41355 .21291 .41917 .22148 .41611 .21563 .41049 Metetra
.663 .746 .912 r
.21563 .41049 .22148 .41611 .23008 .41297 .22425 .40736 Metetra
.664 .747 .912 r
.22425 .40736 .23008 .41297 .23871 .40982 .23289 .40422 Metetra
.66 .748 .915 r
.23289 .40422 .23871 .40982 .24736 .40676 .24155 .40115 Metetra
.654 .746 .918 r
.24155 .40115 .24736 .40676 .25602 .40385 .25024 .39821 Metetra
.647 .744 .92 r
.25024 .39821 .25602 .40385 .2647 .40112 .25894 .3954 Metetra
.645 .741 .919 r
.25894 .3954 .2647 .40112 .2734 .39843 .26766 .39262 Metetra
.646 .739 .917 r
.26766 .39262 .2734 .39843 .28214 .3957 .27642 .38981 Metetra
.646 .736 .915 r
.27642 .38981 .28214 .3957 .29091 .39297 .28521 .387 Metetra
.654 .736 .91 r
.28521 .387 .29091 .39297 .29973 .39 .29405 .38399 Metetra
.671 .741 .903 r
.29405 .38399 .29973 .39 .3086 .38654 .30294 .38059 Metetra
.694 .75 .894 r
.30294 .38059 .3086 .38654 .31756 .38232 .31189 .37658 Metetra
.717 .763 .889 r
.31189 .37658 .31756 .38232 .32658 .37733 .32092 .37195 Metetra
.727 .779 .894 r
.32092 .37195 .32658 .37733 .33564 .37208 .32997 .36712 Metetra
.729 .796 .905 r
.32997 .36712 .33564 .37208 .34472 .36684 .33905 .36228 Metetra
.725 .812 .919 r
.33905 .36228 .34472 .36684 .3538 .36179 .34814 .3576 Metetra
.702 .824 .94 r
.34814 .3576 .3538 .36179 .36287 .35744 .35722 .35347 Metetra
.653 .823 .965 r
.35722 .35347 .36287 .35744 .37191 .35423 .36628 .35025 Metetra
.555 .792 .987 r
.36628 .35025 .37191 .35423 .38089 .3528 .3753 .34846 Metetra
.444 .729 .987 r
.3753 .34846 .38089 .3528 .38984 .35312 .3843 .34807 Metetra
.412 .682 .973 r
.3843 .34807 .38984 .35312 .39881 .35426 .39331 .34832 Metetra
.425 .65 .952 r
.39331 .34832 .39881 .35426 .40782 .35569 .40237 .34881 Metetra
.468 .634 .927 r
.40237 .34881 .40782 .35569 .4169 .35685 .4115 .34907 Metetra
.527 .632 .898 r
.4115 .34907 .4169 .35685 .42607 .35711 .42069 .34861 Metetra
.587 .639 .869 r
.42069 .34861 .42607 .35711 .43532 .3559 .42997 .34698 Metetra
.658 .659 .84 r
.42997 .34698 .43532 .3559 .44469 .35228 .43934 .34341 Metetra
.71 .682 .821 r
.43934 .34341 .44469 .35228 .45413 .34635 .44879 .338 Metetra
.739 .705 .819 r
.44879 .338 .45413 .34635 .46361 .33914 .45828 .33157 Metetra
.758 .731 .827 r
.45828 .33157 .46361 .33914 .47312 .33132 .46779 .32465 Metetra
.766 .759 .846 r
.46779 .32465 .47312 .33132 .48262 .32366 .47731 .31785 Metetra
.766 .788 .871 r
.47731 .31785 .48262 .32366 .49213 .3165 .48684 .31144 Metetra
.751 .813 .901 r
.48684 .31144 .49213 .3165 .50164 .31025 .49637 .30576 Metetra
.7 .826 .943 r
.49637 .30576 .50164 .31025 .51116 .30574 .50591 .30147 Metetra
.632 .817 .971 r
.50591 .30147 .51116 .30574 .5207 .30282 .51548 .29845 Metetra
.583 .796 .98 r
.51548 .29845 .5207 .30282 .53028 .30087 .52509 .2962 Metetra
.564 .776 .978 r
.52509 .2962 .53028 .30087 .5399 .29937 .53473 .29431 Metetra
.576 .764 .968 r
.53473 .29431 .5399 .29937 .54957 .29778 .54442 .29234 Metetra
.584 .752 .958 r
.54442 .29234 .54957 .29778 .55928 .29613 .55415 .29033 Metetra
.596 .742 .946 r
.55415 .29033 .55928 .29613 .56904 .29429 .56392 .28816 Metetra
.621 .74 .932 r
.56392 .28816 .56904 .29429 .57883 .29189 .57373 .28554 Metetra
.64 .74 .921 r
.57373 .28554 .57883 .29189 .58865 .28899 .58357 .28252 Metetra
.651 .741 .915 r
.58357 .28252 .58865 .28899 .5985 .28576 .59344 .27923 Metetra
.653 .74 .914 r
.59344 .27923 .5985 .28576 .60838 .28248 .60335 .27589 Metetra
.648 .737 .914 r
.60335 .27589 .60838 .28248 .61831 .27931 .6133 .27265 Metetra
.65 .736 .912 r
.6133 .27265 .61831 .27931 .62827 .27609 .62328 .26936 Metetra
.653 .735 .91 r
.62328 .26936 .62827 .27609 .63826 .27276 .63329 .26598 Metetra
.656 .736 .908 r
.63329 .26598 .63826 .27276 .64829 .26931 .64334 .2625 Metetra
.659 .737 .907 r
.64334 .2625 .64829 .26931 .65835 .26576 .65343 .25894 Metetra
.661 .738 .907 r
.65343 .25894 .65835 .26576 .66844 .26215 .66354 .25533 Metetra
.665 .74 .906 r
.66354 .25533 .66844 .26215 .67856 .2584 .67369 .2516 Metetra
.669 .744 .906 r
.67369 .2516 .67856 .2584 .68871 .25451 .68387 .24777 Metetra
.67 .747 .908 r
.68387 .24777 .68871 .25451 .69889 .25058 .69408 .24389 Metetra
.669 .749 .91 r
.69408 .24389 .69889 .25058 .70911 .24668 .70433 .24003 Metetra
.666 .75 .913 r
.70433 .24003 .70911 .24668 .71937 .24287 .71462 .23625 Metetra
.663 .751 .916 r
.71462 .23625 .71937 .24287 .72967 .23913 .72494 .23252 Metetra
.662 .752 .917 r
.72494 .23252 .72967 .23913 .74001 .23542 .73531 .22881 Metetra
.66 .752 .918 r
.73531 .22881 .74001 .23542 .75039 .23174 .74572 .22512 Metetra
.66 .752 .919 r
.74572 .22512 .75039 .23174 .76081 .22806 .75617 .22143 Metetra
.658 .752 .919 r
.75617 .22143 .76081 .22806 .77127 .22441 .76665 .21776 Metetra
.658 .752 .92 r
.76665 .21776 .77127 .22441 .78177 .22078 .77718 .2141 Metetra
.654 .75 .92 r
.12515 .43396 .13121 .43928 .13952 .43647 .13348 .43111 Metetra
.654 .748 .919 r
.13348 .43111 .13952 .43647 .14786 .43368 .14184 .42827 Metetra
.653 .747 .919 r
.14184 .42827 .14786 .43368 .15623 .43088 .15023 .42542 Metetra
.653 .746 .918 r
.15023 .42542 .15623 .43088 .16462 .42809 .15864 .42258 Metetra
.653 .745 .917 r
.15864 .42258 .16462 .42809 .17304 .42528 .16708 .41972 Metetra
.654 .744 .916 r
.16708 .41972 .17304 .42528 .18149 .42244 .17555 .41683 Metetra
.656 .743 .914 r
.17555 .41683 .18149 .42244 .18998 .41953 .18405 .4139 Metetra
.658 .743 .913 r
.18405 .4139 .18998 .41953 .1985 .41656 .19259 .41091 Metetra
.659 .744 .913 r
.19259 .41091 .1985 .41656 .20705 .41355 .20115 .40788 Metetra
.66 .744 .913 r
.20115 .40788 .20705 .41355 .21563 .41049 .20975 .40482 Metetra
.662 .746 .912 r
.20975 .40482 .21563 .41049 .22425 .40736 .21838 .40171 Metetra
.662 .747 .913 r
.21838 .40171 .22425 .40736 .23289 .40422 .22704 .39859 Metetra
.659 .747 .915 r
.22704 .39859 .23289 .40422 .24155 .40115 .23572 .39551 Metetra
.655 .747 .917 r
.23572 .39551 .24155 .40115 .25024 .39821 .24442 .39253 Metetra
.649 .744 .919 r
.24442 .39253 .25024 .39821 .25894 .3954 .25314 .38965 Metetra
.648 .742 .918 r
.25314 .38965 .25894 .3954 .26766 .39262 .26189 .38678 Metetra
.649 .74 .916 r
.26189 .38678 .26766 .39262 .27642 .38981 .27067 .3839 Metetra
.649 .737 .914 r
.27067 .3839 .27642 .38981 .28521 .387 .27948 .381 Metetra
.655 .737 .91 r
.27948 .381 .28521 .387 .29405 .38399 .28833 .37796 Metetra
.667 .74 .904 r
.28833 .37796 .29405 .38399 .30294 .38059 .29723 .37461 Metetra
.686 .748 .899 r
.29723 .37461 .30294 .38059 .31189 .37658 .30619 .37081 Metetra
.704 .761 .896 r
.30619 .37081 .31189 .37658 .32092 .37195 .31521 .36654 Metetra
.712 .776 .902 r
.31521 .36654 .32092 .37195 .32997 .36712 .32427 .3621 Metetra
.713 .792 .913 r
.32427 .3621 .32997 .36712 .33905 .36228 .33334 .35767 Metetra
.71 .808 .926 r
.33334 .35767 .33905 .36228 .34814 .3576 .34243 .35334 Metetra
.691 .82 .945 r
.34243 .35334 .34814 .3576 .35722 .35347 .35152 .34944 Metetra
.653 .821 .964 r
.35152 .34944 .35722 .35347 .36628 .35025 .36061 .34621 Metetra
.582 .8 .982 r
.36061 .34621 .36628 .35025 .3753 .34846 .36967 .34406 Metetra
.508 .756 .985 r
.36967 .34406 .3753 .34846 .3843 .34807 .37872 .34296 Metetra
.488 .717 .972 r
.37872 .34296 .3843 .34807 .39331 .34832 .38779 .34235 Metetra
.497 .684 .95 r
.38779 .34235 .39331 .34832 .40237 .34881 .3969 .3419 Metetra
.524 .661 .923 r
.3969 .3419 .40237 .34881 .4115 .34907 .40606 .34129 Metetra
.563 .65 .893 r
.40606 .34129 .4115 .34907 .42069 .34861 .41529 .34012 Metetra
.604 .648 .867 r
.41529 .34012 .42069 .34861 .42997 .34698 .42459 .33807 Metetra
.655 .66 .842 r
.42459 .33807 .42997 .34698 .43934 .34341 .43397 .33456 Metetra
.696 .678 .828 r
.43397 .33456 .43934 .34341 .44879 .338 .44342 .32966 Metetra
.721 .7 .83 r
.44342 .32966 .44879 .338 .45828 .33157 .45291 .32399 Metetra
.738 .726 .84 r
.45291 .32399 .45828 .33157 .46779 .32465 .46243 .31795 Metetra
.745 .754 .86 r
.46243 .31795 .46779 .32465 .47731 .31785 .47196 .31199 Metetra
.744 .783 .884 r
.47196 .31199 .47731 .31785 .48684 .31144 .4815 .30632 Metetra
.731 .808 .912 r
.4815 .30632 .48684 .31144 .49637 .30576 .49106 .3012 Metetra
.689 .822 .946 r
.49106 .3012 .49637 .30576 .50591 .30147 .50063 .29713 Metetra
.637 .817 .969 r
.50063 .29713 .50591 .30147 .51548 .29845 .51023 .294 Metetra
.602 .801 .976 r
.51023 .294 .51548 .29845 .52509 .2962 .51986 .29146 Metetra
.589 .784 .973 r
.51986 .29146 .52509 .2962 .53473 .29431 .52953 .28919 Metetra
.598 .771 .963 r
.52953 .28919 .53473 .29431 .54442 .29234 .53924 .28685 Metetra
.603 .759 .953 r
.53924 .28685 .54442 .29234 .55415 .29033 .54899 .28448 Metetra
.612 .749 .942 r
.54899 .28448 .55415 .29033 .56392 .28816 .55878 .28199 Metetra
.631 .744 .929 r
.55878 .28199 .56392 .28816 .57373 .28554 .5686 .27914 Metetra
.644 .742 .92 r
.5686 .27914 .57373 .28554 .58357 .28252 .57846 .276 Metetra
.653 .741 .915 r
.57846 .276 .58357 .28252 .59344 .27923 .58836 .27266 Metetra
.654 .741 .913 r
.58836 .27266 .59344 .27923 .60335 .27589 .59829 .26927 Metetra
.65 .738 .914 r
.59829 .26927 .60335 .27589 .6133 .27265 .60825 .26595 Metetra
.652 .737 .912 r
.60825 .26595 .6133 .27265 .62328 .26936 .61826 .26259 Metetra
.654 .736 .91 r
.61826 .26259 .62328 .26936 .63329 .26598 .6283 .25916 Metetra
.657 .736 .908 r
.6283 .25916 .63329 .26598 .64334 .2625 .63837 .25566 Metetra
.659 .737 .907 r
.63837 .25566 .64334 .2625 .65343 .25894 .64847 .25209 Metetra
.66 .738 .907 r
.64847 .25209 .65343 .25894 .66354 .25533 .65862 .24847 Metetra
.663 .74 .907 r
.65862 .24847 .66354 .25533 .67369 .2516 .66879 .24477 Metetra
.666 .743 .907 r
.66879 .24477 .67369 .2516 .68387 .24777 .679 .24098 Metetra
.667 .746 .909 r
.679 .24098 .68387 .24777 .69408 .24389 .68924 .23716 Metetra
.666 .748 .911 r
.68924 .23716 .69408 .24389 .70433 .24003 .69951 .23335 Metetra
.664 .75 .914 r
.69951 .23335 .70433 .24003 .71462 .23625 .70983 .22959 Metetra
.662 .75 .916 r
.70983 .22959 .71462 .23625 .72494 .23252 .72019 .22587 Metetra
.661 .751 .917 r
.72019 .22587 .72494 .23252 .73531 .22881 .73058 .22216 Metetra
.66 .752 .918 r
.73058 .22216 .73531 .22881 .74572 .22512 .74102 .21846 Metetra
.659 .752 .919 r
.74102 .21846 .74572 .22512 .75617 .22143 .75149 .21476 Metetra
.658 .752 .919 r
.75149 .21476 .75617 .22143 .76665 .21776 .76201 .21107 Metetra
.658 .752 .92 r
.76201 .21107 .76665 .21776 .77718 .2141 .77256 .20738 Metetra
.656 .75 .919 r
.11906 .4286 .12515 .43396 .13348 .43111 .12741 .42571 Metetra
.655 .749 .919 r
.12741 .42571 .13348 .43111 .14184 .42827 .13579 .42282 Metetra
.655 .748 .918 r
.13579 .42282 .14184 .42827 .15023 .42542 .14419 .41993 Metetra
.654 .746 .917 r
.14419 .41993 .15023 .42542 .15864 .42258 .15262 .41703 Metetra
.655 .745 .916 r
.15262 .41703 .15864 .42258 .16708 .41972 .16108 .41412 Metetra
.655 .744 .915 r
.16108 .41412 .16708 .41972 .17555 .41683 .16957 .41118 Metetra
.656 .743 .914 r
.16957 .41118 .17555 .41683 .18405 .4139 .17809 .40822 Metetra
.658 .743 .913 r
.17809 .40822 .18405 .4139 .19259 .41091 .18664 .40521 Metetra
.658 .743 .913 r
.18664 .40521 .19259 .41091 .20115 .40788 .19522 .40218 Metetra
.659 .744 .913 r
.19522 .40218 .20115 .40788 .20975 .40482 .20383 .39912 Metetra
.66 .745 .913 r
.20383 .39912 .20975 .40482 .21838 .40171 .21248 .39602 Metetra
.66 .746 .914 r
.21248 .39602 .21838 .40171 .22704 .39859 .22115 .39292 Metetra
.659 .747 .915 r
.22115 .39292 .22704 .39859 .23572 .39551 .22984 .38984 Metetra
.656 .747 .917 r
.22984 .38984 .23572 .39551 .24442 .39253 .23856 .38681 Metetra
.652 .745 .918 r
.23856 .38681 .24442 .39253 .25314 .38965 .24731 .38385 Metetra
.652 .743 .916 r
.24731 .38385 .25314 .38965 .26189 .38678 .25608 .3809 Metetra
.652 .74 .914 r
.25608 .3809 .26189 .38678 .27067 .3839 .26488 .37793 Metetra
.652 .738 .912 r
.26488 .37793 .27067 .3839 .27948 .381 .27371 .37495 Metetra
.656 .736 .909 r
.27371 .37495 .27948 .381 .28833 .37796 .28258 .37186 Metetra
.664 .738 .905 r
.28258 .37186 .28833 .37796 .29723 .37461 .2915 .36858 Metetra
.676 .745 .902 r
.2915 .36858 .29723 .37461 .30619 .37081 .30046 .365 Metetra
.689 .757 .903 r
.30046 .365 .30619 .37081 .31521 .36654 .30947 .36111 Metetra
.694 .773 .912 r
.30947 .36111 .31521 .36654 .32427 .3621 .31852 .35711 Metetra
.695 .791 .924 r
.31852 .35711 .32427 .3621 .33334 .35767 .32759 .3531 Metetra
.692 .808 .937 r
.32759 .3531 .33334 .35767 .34243 .35334 .33668 .34916 Metetra
.678 .822 .952 r
.33668 .34916 .34243 .35334 .35152 .34944 .34578 .34549 Metetra
.651 .826 .967 r
.34578 .34549 .35152 .34944 .36061 .34621 .35489 .34226 Metetra
.606 .814 .98 r
.35489 .34226 .36061 .34621 .36967 .34406 .36399 .33973 Metetra
.564 .783 .981 r
.36399 .33973 .36967 .34406 .37872 .34296 .37309 .33787 Metetra
.556 .748 .966 r
.37309 .33787 .37872 .34296 .38779 .34235 .38222 .33633 Metetra
.563 .712 .942 r
.38222 .33633 .38779 .34235 .3969 .3419 .39139 .3349 Metetra
.577 .682 .912 r
.39139 .3349 .3969 .3419 .40606 .34129 .4006 .33334 Metetra
.598 .661 .883 r
.4006 .33334 .40606 .34129 .41529 .34012 .40987 .33142 Metetra
.62 .65 .858 r
.40987 .33142 .41529 .34012 .42459 .33807 .41919 .32893 Metetra
.652 .653 .839 r
.41919 .32893 .42459 .33807 .43397 .33456 .42858 .32548 Metetra
.679 .667 .831 r
.42858 .32548 .43397 .33456 .44342 .32966 .43803 .32113 Metetra
.698 .688 .837 r
.43803 .32113 .44342 .32966 .45291 .32399 .44752 .31627 Metetra
.711 .715 .852 r
.44752 .31627 .45291 .32399 .46243 .31795 .45704 .31116 Metetra
.718 .746 .874 r
.45704 .31116 .46243 .31795 .47196 .31199 .46657 .30611 Metetra
.718 .777 .899 r
.46657 .30611 .47196 .31199 .4815 .30632 .47613 .30124 Metetra
.708 .806 .926 r
.47613 .30124 .4815 .30632 .49106 .3012 .48571 .29672 Metetra
.676 .823 .954 r
.48571 .29672 .49106 .3012 .50063 .29713 .4953 .29287 Metetra
.64 .823 .971 r
.4953 .29287 .50063 .29713 .51023 .294 .50493 .28964 Metetra
.618 .812 .975 r
.50493 .28964 .51023 .294 .51986 .29146 .51458 .28679 Metetra
.612 .797 .97 r
.51458 .28679 .51986 .29146 .52953 .28919 .52428 .28411 Metetra
.619 .782 .96 r
.52428 .28411 .52953 .28919 .53924 .28685 .53401 .28138 Metetra
.623 .769 .95 r
.53401 .28138 .53924 .28685 .54899 .28448 .54379 .27862 Metetra
.629 .756 .939 r
.54379 .27862 .54899 .28448 .55878 .28199 .5536 .27578 Metetra
.64 .748 .927 r
.5536 .27578 .55878 .28199 .5686 .27914 .56344 .27271 Metetra
.649 .744 .918 r
.56344 .27271 .5686 .27914 .57846 .276 .57332 .26944 Metetra
.654 .742 .914 r
.57332 .26944 .57846 .276 .58836 .27266 .58324 .26603 Metetra
.655 .741 .913 r
.58324 .26603 .58836 .27266 .59829 .26927 .59319 .26259 Metetra
.653 .739 .912 r
.59319 .26259 .59829 .26927 .60825 .26595 .60318 .25919 Metetra
.654 .737 .911 r
.60318 .25919 .60825 .26595 .61826 .26259 .6132 .25576 Metetra
.655 .736 .909 r
.6132 .25576 .61826 .26259 .6283 .25916 .62326 .25228 Metetra
.657 .735 .908 r
.62326 .25228 .6283 .25916 .63837 .25566 .63336 .24875 Metetra
.658 .736 .907 r
.63336 .24875 .63837 .25566 .64847 .25209 .64349 .24516 Metetra
.659 .737 .907 r
.64349 .24516 .64847 .25209 .65862 .24847 .65366 .24155 Metetra
.661 .738 .907 r
.65366 .24155 .65862 .24847 .66879 .24477 .66386 .23787 Metetra
.663 .741 .908 r
.66386 .23787 .66879 .24477 .679 .24098 .67409 .23414 Metetra
.664 .744 .91 r
.67409 .23414 .679 .24098 .68924 .23716 .68436 .23037 Metetra
.663 .747 .912 r
.68436 .23037 .68924 .23716 .69951 .23335 .69467 .22661 Metetra
.662 .749 .915 r
.69467 .22661 .69951 .23335 .70983 .22959 .70501 .22288 Metetra
.66 .75 .916 r
.70501 .22288 .70983 .22959 .72019 .22587 .7154 .21917 Metetra
.66 .751 .918 r
.7154 .21917 .72019 .22587 .73058 .22216 .72583 .21546 Metetra
.659 .752 .918 r
.72583 .21546 .73058 .22216 .74102 .21846 .73629 .21175 Metetra
.659 .752 .919 r
.73629 .21175 .74102 .21846 .75149 .21476 .74679 .20804 Metetra
.658 .752 .92 r
.74679 .20804 .75149 .21476 .76201 .21107 .75733 .20433 Metetra
.658 .752 .92 r
.75733 .20433 .76201 .21107 .77256 .20738 .76792 .20061 Metetra
.657 .75 .919 r
.11294 .4232 .11906 .4286 .12741 .42571 .1213 .42027 Metetra
.656 .749 .918 r
.1213 .42027 .12741 .42571 .13579 .42282 .1297 .41734 Metetra
.656 .748 .918 r
.1297 .41734 .13579 .42282 .14419 .41993 .13812 .4144 Metetra
.656 .747 .917 r
.13812 .4144 .14419 .41993 .15262 .41703 .14657 .41146 Metetra
.656 .746 .916 r
.14657 .41146 .15262 .41703 .16108 .41412 .15505 .4085 Metetra
.656 .745 .915 r
.15505 .4085 .16108 .41412 .16957 .41118 .16355 .40552 Metetra
.657 .744 .914 r
.16355 .40552 .16957 .41118 .17809 .40822 .17209 .40252 Metetra
.658 .744 .914 r
.17209 .40252 .17809 .40822 .18664 .40521 .18066 .3995 Metetra
.658 .744 .913 r
.18066 .3995 .18664 .40521 .19522 .40218 .18925 .39646 Metetra
.658 .744 .913 r
.18925 .39646 .19522 .40218 .20383 .39912 .19788 .3934 Metetra
.659 .745 .914 r
.19788 .3934 .20383 .39912 .21248 .39602 .20654 .39031 Metetra
.659 .746 .914 r
.20654 .39031 .21248 .39602 .22115 .39292 .21522 .38722 Metetra
.658 .747 .916 r
.21522 .38722 .22115 .39292 .22984 .38984 .22393 .38413 Metetra
.657 .747 .917 r
.22393 .38413 .22984 .38984 .23856 .38681 .23267 .38107 Metetra
.655 .746 .917 r
.23267 .38107 .23856 .38681 .24731 .38385 .24144 .37804 Metetra
.654 .744 .916 r
.24144 .37804 .24731 .38385 .25608 .3809 .25023 .375 Metetra
.655 .742 .914 r
.25023 .375 .25608 .3809 .26488 .37793 .25905 .37195 Metetra
.654 .74 .912 r
.25905 .37195 .26488 .37793 .27371 .37495 .26791 .36889 Metetra
.657 .738 .91 r
.26791 .36889 .27371 .37495 .28258 .37186 .2768 .36578 Metetra
.661 .739 .908 r
.2768 .36578 .28258 .37186 .2915 .36858 .28572 .36255 Metetra
.668 .743 .907 r
.28572 .36255 .2915 .36858 .30046 .365 .29469 .35916 Metetra
.675 .753 .91 r
.29469 .35916 .30046 .365 .30947 .36111 .3037 .3556 Metetra
.678 .767 .918 r
.3037 .3556 .30947 .36111 .31852 .35711 .31273 .35197 Metetra
.678 .782 .929 r
.31273 .35197 .31852 .35711 .32759 .3531 .3218 .34834 Metetra
.676 .798 .94 r
.3218 .34834 .32759 .3531 .33668 .34916 .3309 .34474 Metetra
.667 .81 .952 r
.3309 .34474 .33668 .34916 .34578 .34549 .34001 .34128 Metetra
.653 .816 .962 r
.34001 .34128 .34578 .34549 .35489 .34226 .34914 .33804 Metetra
.63 .811 .969 r
.34914 .33804 .35489 .34226 .36399 .33973 .35828 .33517 Metetra
.612 .791 .967 r
.35828 .33517 .36399 .33973 .37309 .33787 .36744 .33265 Metetra
.609 .763 .953 r
.36744 .33265 .37309 .33787 .38222 .33633 .37662 .33029 Metetra
.611 .732 .931 r
.37662 .33029 .38222 .33633 .39139 .3349 .38584 .32797 Metetra
.617 .703 .906 r
.38584 .32797 .39139 .3349 .4006 .33334 .3951 .32559 Metetra
.625 .68 .882 r
.3951 .32559 .4006 .33334 .40987 .33142 .4044 .32302 Metetra
.635 .666 .862 r
.4044 .32302 .40987 .33142 .41919 .32893 .41376 .32013 Metetra
.651 .663 .848 r
.41376 .32013 .41919 .32893 .42858 .32548 .42316 .31674 Metetra
.667 .671 .844 r
.42316 .31674 .42858 .32548 .43803 .32113 .43261 .31286 Metetra
.678 .688 .852 r
.43261 .31286 .43803 .32113 .44752 .31627 .44209 .30871 Metetra
.687 .712 .868 r
.44209 .30871 .44752 .31627 .45704 .31116 .45161 .30442 Metetra
.691 .74 .888 r
.45161 .30442 .45704 .31116 .46657 .30611 .46115 .30015 Metetra
.691 .769 .911 r
.46115 .30015 .46657 .30611 .47613 .30124 .47072 .29598 Metetra
.685 .794 .932 r
.47072 .29598 .47613 .30124 .48571 .29672 .48032 .29198 Metetra
.666 .811 .953 r
.48032 .29198 .48571 .29672 .4953 .29287 .48994 .28834 Metetra
.647 .815 .964 r
.48994 .28834 .4953 .29287 .50493 .28964 .49959 .28502 Metetra
.637 .808 .965 r
.49959 .28502 .50493 .28964 .51458 .28679 .50928 .28188 Metetra
.634 .796 .96 r
.50928 .28188 .51458 .28679 .52428 .28411 .519 .27884 Metetra
.638 .783 .951 r
.519 .27884 .52428 .28411 .53401 .28138 .52875 .27576 Metetra
.64 .771 .942 r
.52875 .27576 .53401 .28138 .54379 .27862 .53855 .27266 Metetra
.643 .759 .933 r
.53855 .27266 .54379 .27862 .5536 .27578 .54838 .26951 Metetra
.649 .75 .924 r
.54838 .26951 .5536 .27578 .56344 .27271 .55825 .26624 Metetra
.653 .745 .917 r
.55825 .26624 .56344 .27271 .57332 .26944 .56815 .26285 Metetra
.656 .743 .914 r
.56815 .26285 .57332 .26944 .58324 .26603 .57809 .25938 Metetra
.656 .742 .913 r
.57809 .25938 .58324 .26603 .59319 .26259 .58806 .2559 Metetra
.655 .741 .913 r
.58806 .2559 .59319 .26259 .60318 .25919 .59807 .25242 Metetra
.655 .739 .911 r
.59807 .25242 .60318 .25919 .6132 .25576 .60812 .24893 Metetra
.656 .738 .91 r
.60812 .24893 .6132 .25576 .62326 .25228 .6182 .2454 Metetra
.657 .737 .909 r
.6182 .2454 .62326 .25228 .63336 .24875 .62832 .24184 Metetra
.658 .737 .908 r
.62832 .24184 .63336 .24875 .64349 .24516 .63847 .23824 Metetra
.658 .738 .909 r
.63847 .23824 .64349 .24516 .65366 .24155 .64867 .23462 Metetra
.659 .739 .909 r
.64867 .23462 .65366 .24155 .66386 .23787 .65889 .23097 Metetra
.66 .741 .91 r
.65889 .23097 .66386 .23787 .67409 .23414 .66915 .22727 Metetra
.661 .744 .911 r
.66915 .22727 .67409 .23414 .68436 .23037 .67945 .22356 Metetra
.661 .746 .913 r
.67945 .22356 .68436 .23037 .69467 .22661 .68979 .21984 Metetra
.66 .748 .915 r
.68979 .21984 .69467 .22661 .70501 .22288 .70017 .21613 Metetra
.659 .749 .917 r
.70017 .21613 .70501 .22288 .7154 .21917 .71058 .21242 Metetra
.659 .75 .918 r
.71058 .21242 .7154 .21917 .72583 .21546 .72103 .20871 Metetra
.658 .751 .918 r
.72103 .20871 .72583 .21546 .73629 .21175 .73152 .20499 Metetra
.658 .752 .919 r
.73152 .20499 .73629 .21175 .74679 .20804 .74205 .20126 Metetra
.658 .752 .919 r
.74205 .20126 .74679 .20804 .75733 .20433 .75262 .19753 Metetra
.658 .752 .919 r
.75262 .19753 .75733 .20433 .76792 .20061 .76323 .19379 Metetra
.657 .749 .918 r
.10677 .41776 .11294 .4232 .1213 .42027 .11516 .4148 Metetra
.657 .749 .918 r
.11516 .4148 .1213 .42027 .1297 .41734 .12357 .41184 Metetra
.657 .749 .918 r
.12357 .41184 .1297 .41734 .13812 .4144 .13201 .40887 Metetra
.656 .748 .918 r
.13201 .40887 .13812 .4144 .14657 .41146 .14047 .4059 Metetra
.657 .748 .917 r
.14047 .4059 .14657 .41146 .15505 .4085 .14897 .40291 Metetra
.657 .748 .917 r
.14897 .40291 .15505 .4085 .16355 .40552 .15749 .39991 Metetra
.657 .747 .916 r
.15749 .39991 .16355 .40552 .17209 .40252 .16605 .39689 Metetra
.658 .747 .916 r
.16605 .39689 .17209 .40252 .18066 .3995 .17463 .39385 Metetra
.658 .747 .916 r
.17463 .39385 .18066 .3995 .18925 .39646 .18324 .39079 Metetra
.658 .748 .916 r
.18324 .39079 .18925 .39646 .19788 .3934 .19188 .38772 Metetra
.659 .748 .916 r
.19188 .38772 .19788 .3934 .20654 .39031 .20055 .38462 Metetra
.659 .748 .916 r
.20055 .38462 .20654 .39031 .21522 .38722 .20926 .38152 Metetra
.658 .749 .917 r
.20926 .38152 .21522 .38722 .22393 .38413 .21798 .37842 Metetra
.657 .748 .917 r
.21798 .37842 .22393 .38413 .23267 .38107 .22674 .37533 Metetra
.656 .748 .918 r
.22674 .37533 .23267 .38107 .24144 .37804 .23552 .37226 Metetra
.655 .747 .917 r
.23552 .37226 .24144 .37804 .25023 .375 .24434 .36919 Metetra
.656 .746 .917 r
.24434 .36919 .25023 .375 .25905 .37195 .25318 .3661 Metetra
.655 .746 .916 r
.25318 .3661 .25905 .37195 .26791 .36889 .26205 .363 Metetra
.657 .745 .915 r
.26205 .363 .26791 .36889 .2768 .36578 .27096 .35986 Metetra
.66 .746 .914 r
.27096 .35986 .2768 .36578 .28572 .36255 .2799 .35664 Metetra
.665 .748 .912 r
.2799 .35664 .28572 .36255 .29469 .35916 .28888 .35329 Metetra
.67 .752 .912 r
.28888 .35329 .29469 .35916 .3037 .3556 .2979 .34983 Metetra
.672 .757 .915 r
.2979 .34983 .3037 .3556 .31273 .35197 .30695 .34632 Metetra
.672 .762 .918 r
.30695 .34632 .31273 .35197 .3218 .34834 .31603 .3428 Metetra
.671 .767 .922 r
.31603 .3428 .3218 .34834 .3309 .34474 .32513 .3393 Metetra
.666 .77 .927 r
.32513 .3393 .3309 .34474 .34001 .34128 .33426 .33589 Metetra
.658 .771 .933 r
.33426 .33589 .34001 .34128 .34914 .33804 .34341 .33263 Metetra
.645 .767 .937 r
.34341 .33263 .34914 .33804 .35828 .33517 .35258 .32963 Metetra
.632 .759 .939 r
.35258 .32963 .35828 .33517 .36744 .33265 .36177 .32688 Metetra
.627 .749 .935 r
.36177 .32688 .36744 .33265 .37662 .33029 .37099 .32423 Metetra
.626 .738 .928 r
.37099 .32423 .37662 .33029 .38584 .32797 .38024 .32161 Metetra
.629 .728 .919 r
.38024 .32161 .38584 .32797 .3951 .32559 .38952 .31895 Metetra
.635 .721 .91 r
.38952 .31895 .3951 .32559 .4044 .32302 .39885 .31614 Metetra
.644 .717 .901 r
.39885 .31614 .4044 .32302 .41376 .32013 .40823 .31311 Metetra
.658 .718 .893 r
.40823 .31311 .41376 .32013 .42316 .31674 .41765 .30972 Metetra
.671 .723 .889 r
.41765 .30972 .42316 .31674 .43261 .31286 .42711 .30598 Metetra
.679 .731 .89 r
.42711 .30598 .43261 .31286 .44209 .30871 .43661 .30205 Metetra
.683 .741 .895 r
.43661 .30205 .44209 .30871 .45161 .30442 .44614 .29802 Metetra
.683 .751 .902 r
.44614 .29802 .45161 .30442 .46115 .30015 .4557 .294 Metetra
.681 .76 .911 r
.4557 .294 .46115 .30015 .47072 .29598 .46529 .29004 Metetra
.676 .767 .919 r
.46529 .29004 .47072 .29598 .48032 .29198 .4749 .28621 Metetra
.666 .77 .928 r
.4749 .28621 .48032 .29198 .48994 .28834 .48455 .28262 Metetra
.655 .77 .934 r
.48455 .28262 .48994 .28834 .49959 .28502 .49422 .27925 Metetra
.648 .766 .935 r
.49422 .27925 .49959 .28502 .50928 .28188 .50393 .27601 Metetra
.645 .762 .934 r
.50393 .27601 .50928 .28188 .519 .27884 .51368 .27282 Metetra
.646 .758 .931 r
.51368 .27282 .519 .27884 .52875 .27576 .52346 .26961 Metetra
.646 .754 .928 r
.52346 .26961 .52875 .27576 .53855 .27266 .53327 .26639 Metetra
.648 .75 .924 r
.53327 .26639 .53855 .27266 .54838 .26951 .54313 .26312 Metetra
.651 .748 .921 r
.54313 .26312 .54838 .26951 .55825 .26624 .55302 .25976 Metetra
.654 .747 .918 r
.55302 .25976 .55825 .26624 .56815 .26285 .56294 .25632 Metetra
.656 .747 .916 r
.56294 .25632 .56815 .26285 .57809 .25938 .57291 .25282 Metetra
.657 .747 .916 r
.57291 .25282 .57809 .25938 .58806 .2559 .5829 .2493 Metetra
.656 .746 .916 r
.5829 .2493 .58806 .2559 .59807 .25242 .59294 .24579 Metetra
.656 .745 .916 r
.59294 .24579 .59807 .25242 .60812 .24893 .60301 .24225 Metetra
.657 .745 .915 r
.60301 .24225 .60812 .24893 .6182 .2454 .61311 .23869 Metetra
.657 .745 .915 r
.61311 .23869 .6182 .2454 .62832 .24184 .62326 .2351 Metetra
.658 .745 .914 r
.62326 .2351 .62832 .24184 .63847 .23824 .63344 .23149 Metetra
.658 .746 .914 r
.63344 .23149 .63847 .23824 .64867 .23462 .64365 .22785 Metetra
.659 .746 .914 r
.64365 .22785 .64867 .23462 .65889 .23097 .6539 .22419 Metetra
.66 .747 .915 r
.6539 .22419 .65889 .23097 .66915 .22727 .66419 .22049 Metetra
.66 .748 .915 r
.66419 .22049 .66915 .22727 .67945 .22356 .67452 .21678 Metetra
.66 .749 .916 r
.67452 .21678 .67945 .22356 .68979 .21984 .68488 .21305 Metetra
.659 .749 .917 r
.68488 .21305 .68979 .21984 .70017 .21613 .69528 .20933 Metetra
.659 .749 .917 r
.69528 .20933 .70017 .21613 .71058 .21242 .70573 .20561 Metetra
.658 .75 .917 r
.70573 .20561 .71058 .21242 .72103 .20871 .71621 .20188 Metetra
.658 .75 .918 r
.71621 .20188 .72103 .20871 .73152 .20499 .72672 .19814 Metetra
.658 .75 .918 r
.72672 .19814 .73152 .20499 .74205 .20126 .73728 .19439 Metetra
.658 .75 .918 r
.73728 .19439 .74205 .20126 .75262 .19753 .74788 .19064 Metetra
.658 .75 .918 r
.74788 .19064 .75262 .19753 .76323 .19379 .75852 .18687 Metetra
.657 .749 .918 r
.10058 .41226 .10677 .41776 .11516 .4148 .10897 .40929 Metetra
.656 .749 .918 r
.10897 .40929 .11516 .4148 .12357 .41184 .1174 .40632 Metetra
.656 .749 .918 r
.1174 .40632 .12357 .41184 .13201 .40887 .12585 .40334 Metetra
.656 .749 .918 r
.12585 .40334 .13201 .40887 .14047 .4059 .13433 .40035 Metetra
.656 .749 .919 r
.13433 .40035 .14047 .4059 .14897 .40291 .14284 .39736 Metetra
.657 .75 .919 r
.14284 .39736 .14897 .40291 .15749 .39991 .15138 .39434 Metetra
.657 .75 .919 r
.15138 .39434 .15749 .39991 .16605 .39689 .15995 .3913 Metetra
.658 .75 .918 r
.15995 .3913 .16605 .39689 .17463 .39385 .16855 .38825 Metetra
.658 .75 .918 r
.16855 .38825 .17463 .39385 .18324 .39079 .17718 .38517 Metetra
.658 .75 .918 r
.17718 .38517 .18324 .39079 .19188 .38772 .18584 .38207 Metetra
.659 .75 .918 r
.18584 .38207 .19188 .38772 .20055 .38462 .19453 .37895 Metetra
.659 .75 .917 r
.19453 .37895 .20055 .38462 .20926 .38152 .20325 .37582 Metetra
.658 .75 .918 r
.20325 .37582 .20926 .38152 .21798 .37842 .212 .37269 Metetra
.657 .749 .918 r
.212 .37269 .21798 .37842 .22674 .37533 .22077 .36959 Metetra
.655 .749 .919 r
.22077 .36959 .22674 .37533 .23552 .37226 .22957 .36651 Metetra
.655 .749 .919 r
.22957 .36651 .23552 .37226 .24434 .36919 .2384 .36344 Metetra
.655 .75 .92 r
.2384 .36344 .24434 .36919 .25318 .3661 .24726 .36034 Metetra
.655 .75 .92 r
.24726 .36034 .25318 .3661 .26205 .363 .25615 .35724 Metetra
.657 .751 .92 r
.25615 .35724 .26205 .363 .27096 .35986 .26507 .35408 Metetra
.661 .753 .918 r
.26507 .35408 .27096 .35986 .2799 .35664 .27403 .35082 Metetra
.667 .754 .915 r
.27403 .35082 .2799 .35664 .28888 .35329 .28303 .34741 Metetra
.673 .754 .911 r
.28303 .34741 .28888 .35329 .2979 .34983 .29208 .34384 Metetra
.675 .751 .908 r
.29208 .34384 .2979 .34983 .30695 .34632 .30115 .34021 Metetra
.675 .748 .906 r
.30115 .34021 .30695 .34632 .31603 .3428 .31026 .33658 Metetra
.673 .744 .904 r
.31026 .33658 .31603 .3428 .32513 .3393 .31939 .33297 Metetra
.667 .739 .904 r
.31939 .33297 .32513 .3393 .33426 .33589 .32854 .32949 Metetra
.658 .735 .906 r
.32854 .32949 .33426 .33589 .34341 .33263 .33771 .32621 Metetra
.643 .73 .912 r
.33771 .32621 .34341 .33263 .35258 .32963 .34689 .32327 Metetra
.627 .727 .919 r
.34689 .32327 .35258 .32963 .36177 .32688 .35609 .32064 Metetra
.619 .729 .925 r
.35609 .32064 .36177 .32688 .37099 .32423 .36531 .31816 Metetra
.616 .735 .931 r
.36531 .31816 .37099 .32423 .38024 .32161 .37457 .31573 Metetra
.617 .744 .936 r
.37457 .31573 .38024 .32161 .38952 .31895 .38387 .31323 Metetra
.625 .754 .939 r
.38387 .31323 .38952 .31895 .39885 .31614 .39321 .31055 Metetra
.639 .764 .939 r
.39321 .31055 .39885 .31614 .40823 .31311 .40261 .30758 Metetra
.661 .774 .933 r
.40261 .30758 .40823 .31311 .41765 .30972 .41205 .30415 Metetra
.68 .779 .925 r
.41205 .30415 .41765 .30972 .42711 .30598 .42154 .30028 Metetra
.69 .778 .918 r
.42154 .30028 .42711 .30598 .43661 .30205 .43107 .29616 Metetra
.694 .773 .912 r
.43107 .29616 .43661 .30205 .44614 .29802 .44063 .29191 Metetra
.692 .765 .908 r
.44063 .29191 .44614 .29802 .4557 .294 .45021 .28767 Metetra
.687 .757 .904 r
.45021 .28767 .4557 .294 .46529 .29004 .45983 .28352 Metetra
.68 .749 .903 r
.45983 .28352 .46529 .29004 .4749 .28621 .46947 .27954 Metetra
.667 .74 .905 r
.46947 .27954 .4749 .28621 .48455 .28262 .47913 .27587 Metetra
.654 .733 .908 r
.47913 .27587 .48455 .28262 .49422 .27925 .48883 .2725 Metetra
.646 .731 .911 r
.48883 .2725 .49422 .27925 .50393 .27601 .49856 .26929 Metetra
.642 .732 .913 r
.49856 .26929 .50393 .27601 .51368 .27282 .50832 .26617 Metetra
.643 .735 .915 r
.50832 .26617 .51368 .27282 .52346 .26961 .51813 .26301 Metetra
.643 .738 .917 r
.51813 .26301 .52346 .26961 .53327 .26639 .52797 .25984 Metetra
.645 .741 .919 r
.52797 .25984 .53327 .26639 .54313 .26312 .53784 .25662 Metetra
.65 .745 .919 r
.53784 .25662 .54313 .26312 .55302 .25976 .54776 .25328 Metetra
.654 .748 .919 r
.54776 .25328 .55302 .25976 .56294 .25632 .55771 .24983 Metetra
.656 .75 .919 r
.55771 .24983 .56294 .25632 .57291 .25282 .56769 .24632 Metetra
.657 .75 .919 r
.56769 .24632 .57291 .25282 .5829 .2493 .57771 .24278 Metetra
.655 .75 .919 r
.57771 .24278 .5829 .2493 .59294 .24579 .58777 .23925 Metetra
.656 .751 .92 r
.58777 .23925 .59294 .24579 .60301 .24225 .59786 .23571 Metetra
.657 .751 .92 r
.59786 .23571 .60301 .24225 .61311 .23869 .608 .23213 Metetra
.657 .752 .92 r
.608 .23213 .61311 .23869 .62326 .2351 .61816 .22852 Metetra
.658 .752 .919 r
.61816 .22852 .62326 .2351 .63344 .23149 .62837 .22487 Metetra
.659 .752 .919 r
.62837 .22487 .63344 .23149 .64365 .22785 .63861 .22121 Metetra
.66 .752 .919 r
.63861 .22121 .64365 .22785 .6539 .22419 .64889 .21751 Metetra
.66 .752 .918 r
.64889 .21751 .6539 .22419 .66419 .22049 .6592 .21377 Metetra
.661 .752 .918 r
.6592 .21377 .66419 .22049 .67452 .21678 .66955 .21001 Metetra
.66 .751 .917 r
.66955 .21001 .67452 .21678 .68488 .21305 .67994 .20625 Metetra
.66 .75 .917 r
.67994 .20625 .68488 .21305 .69528 .20933 .69037 .20249 Metetra
.659 .75 .917 r
.69037 .20249 .69528 .20933 .70573 .20561 .70084 .19874 Metetra
.659 .749 .917 r
.70084 .19874 .70573 .20561 .71621 .20188 .71134 .19498 Metetra
.658 .749 .917 r
.71134 .19498 .71621 .20188 .72672 .19814 .72189 .19121 Metetra
.658 .749 .917 r
.72189 .19121 .72672 .19814 .73728 .19439 .73247 .18744 Metetra
.658 .749 .917 r
.73247 .18744 .73728 .19439 .74788 .19064 .7431 .18365 Metetra
.658 .748 .917 r
.7431 .18365 .74788 .19064 .75852 .18687 .75376 .17986 Metetra
.656 .748 .918 r
.09434 .40672 .10058 .41226 .10897 .40929 .10275 .40374 Metetra
.656 .748 .918 r
.10275 .40374 .10897 .40929 .1174 .40632 .11119 .40077 Metetra
.655 .749 .919 r
.11119 .40077 .1174 .40632 .12585 .40334 .11966 .39778 Metetra
.655 .749 .919 r
.11966 .39778 .12585 .40334 .13433 .40035 .12816 .3948 Metetra
.655 .75 .92 r
.12816 .3948 .13433 .40035 .14284 .39736 .13668 .3918 Metetra
.656 .751 .92 r
.13668 .3918 .14284 .39736 .15138 .39434 .14523 .38878 Metetra
.657 .752 .92 r
.14523 .38878 .15138 .39434 .15995 .3913 .15382 .38573 Metetra
.658 .752 .92 r
.15382 .38573 .15995 .3913 .16855 .38825 .16243 .38265 Metetra
.658 .752 .919 r
.16243 .38265 .16855 .38825 .17718 .38517 .17108 .37955 Metetra
.659 .752 .919 r
.17108 .37955 .17718 .38517 .18584 .38207 .17976 .37642 Metetra
.66 .752 .918 r
.17976 .37642 .18584 .38207 .19453 .37895 .18847 .37326 Metetra
.66 .751 .918 r
.18847 .37326 .19453 .37895 .20325 .37582 .1972 .3701 Metetra
.659 .75 .918 r
.1972 .3701 .20325 .37582 .212 .37269 .20597 .36695 Metetra
.656 .75 .919 r
.20597 .36695 .212 .37269 .22077 .36959 .21476 .36384 Metetra
.654 .749 .92 r
.21476 .36384 .22077 .36959 .22957 .36651 .22357 .36077 Metetra
.653 .75 .921 r
.22357 .36077 .22957 .36651 .2384 .36344 .23241 .35771 Metetra
.653 .752 .922 r
.23241 .35771 .2384 .36344 .24726 .36034 .24129 .35462 Metetra
.653 .753 .923 r
.24129 .35462 .24726 .36034 .25615 .35724 .25019 .35153 Metetra
.657 .755 .922 r
.25019 .35153 .25615 .35724 .26507 .35408 .25913 .34836 Metetra
.663 .757 .92 r
.25913 .34836 .26507 .35408 .27403 .35082 .26812 .34504 Metetra
.673 .758 .915 r
.26812 .34504 .27403 .35082 .28303 .34741 .27715 .34149 Metetra
.682 .756 .908 r
.27715 .34149 .28303 .34741 .29208 .34384 .28623 .3377 Metetra
.684 .75 .901 r
.28623 .3377 .29208 .34384 .30115 .34021 .29534 .33383 Metetra
.683 .742 .896 r
.29534 .33383 .30115 .34021 .31026 .33658 .30448 .32996 Metetra
.679 .733 .891 r
.30448 .32996 .31026 .33658 .31939 .33297 .31364 .32613 Metetra
.67 .724 .889 r
.31364 .32613 .31939 .33297 .32854 .32949 .32282 .3225 Metetra
.657 .715 .891 r
.32282 .3225 .32854 .32949 .33771 .32621 .332 .31919 Metetra
.634 .707 .899 r
.332 .31919 .33771 .32621 .34689 .32327 .34119 .3164 Metetra
.61 .704 .911 r
.34119 .3164 .34689 .32327 .35609 .32064 .35038 .31412 Metetra
.597 .712 .925 r
.35038 .31412 .35609 .32064 .36531 .31816 .3596 .31207 Metetra
.589 .726 .938 r
.3596 .31207 .36531 .31816 .37457 .31573 .36885 .3101 Metetra
.59 .745 .951 r
.36885 .3101 .37457 .31573 .38387 .31323 .37815 .30803 Metetra
.601 .768 .959 r
.37815 .30803 .38387 .31323 .39321 .31055 .3875 .30569 Metetra
.622 .79 .962 r
.3875 .30569 .39321 .31055 .40261 .30758 .39691 .30291 Metetra
.66 .81 .955 r
.39691 .30291 .40261 .30758 .41205 .30415 .40638 .29942 Metetra
.692 .817 .942 r
.40638 .29942 .41205 .30415 .42154 .30028 .4159 .29524 Metetra
.708 .809 .928 r
.4159 .29524 .42154 .30028 .43107 .29616 .42547 .29069 Metetra
.714 .795 .915 r
.42547 .29069 .43107 .29616 .44063 .29191 .43507 .28594 Metetra
.71 .777 .904 r
.43507 .28594 .44063 .29191 .45021 .28767 .44469 .28123 Metetra
.702 .758 .896 r
.44469 .28123 .45021 .28767 .45983 .28352 .45434 .27665 Metetra
.69 .741 .89 r
.45434 .27665 .45983 .28352 .46947 .27954 .46401 .27233 Metetra
.67 .724 .89 r
.46401 .27233 .46947 .27954 .47913 .27587 .4737 .26851 Metetra
.651 .713 .893 r
.4737 .26851 .47913 .27587 .48883 .2725 .48341 .26516 Metetra
.639 .71 .898 r
.48341 .26516 .48883 .2725 .49856 .26929 .49316 .26208 Metetra
.634 .713 .904 r
.49316 .26208 .49856 .26929 .50832 .26617 .50294 .25912 Metetra
.635 .72 .908 r
.50294 .25912 .50832 .26617 .51813 .26301 .51276 .25613 Metetra
.636 .726 .913 r
.51276 .25613 .51813 .26301 .52797 .25984 .52262 .25311 Metetra
.638 .733 .917 r
.52262 .25311 .52797 .25984 .53784 .25662 .53252 .25003 Metetra
.645 .742 .92 r
.53252 .25003 .53784 .25662 .54776 .25328 .54246 .24676 Metetra
.651 .748 .92 r
.54246 .24676 .54776 .25328 .55771 .24983 .55243 .24335 Metetra
.655 .751 .92 r
.55243 .24335 .55771 .24983 .56769 .24632 .56244 .23983 Metetra
.656 .752 .921 r
.56244 .23983 .56769 .24632 .57771 .24278 .57249 .23628 Metetra
.654 .752 .922 r
.57249 .23628 .57771 .24278 .58777 .23925 .58257 .23276 Metetra
.655 .753 .922 r
.58257 .23276 .58777 .23925 .59786 .23571 .59269 .22922 Metetra
.656 .755 .923 r
.59269 .22922 .59786 .23571 .608 .23213 .60285 .22563 Metetra
.657 .756 .922 r
.60285 .22563 .608 .23213 .61816 .22852 .61304 .22199 Metetra
.659 .756 .922 r
.61304 .22199 .61816 .22852 .62837 .22487 .62327 .21832 Metetra
.659 .756 .922 r
.62327 .21832 .62837 .22487 .63861 .22121 .63354 .21462 Metetra
.661 .756 .921 r
.63354 .21462 .63861 .22121 .64889 .21751 .64384 .21087 Metetra
.662 .756 .92 r
.64384 .21087 .64889 .21751 .6592 .21377 .65418 .20707 Metetra
.662 .755 .919 r
.65418 .20707 .6592 .21377 .66955 .21001 .66455 .20325 Metetra
.662 .753 .918 r
.66455 .20325 .66955 .21001 .67994 .20625 .67497 .19942 Metetra
.661 .751 .917 r
.67497 .19942 .67994 .20625 .69037 .20249 .68542 .19561 Metetra
.66 .75 .917 r
.68542 .19561 .69037 .20249 .70084 .19874 .69591 .19181 Metetra
.659 .749 .917 r
.69591 .19181 .70084 .19874 .71134 .19498 .70645 .18802 Metetra
.659 .749 .916 r
.70645 .18802 .71134 .19498 .72189 .19121 .71702 .18421 Metetra
.658 .748 .916 r
.71702 .18421 .72189 .19121 .73247 .18744 .72763 .18041 Metetra
.658 .748 .916 r
.72763 .18041 .73247 .18744 .7431 .18365 .73828 .17659 Metetra
.658 .748 .916 r
.73828 .17659 .7431 .18365 .75376 .17986 .74898 .17278 Metetra
.655 .748 .918 r
.08807 .40114 .09434 .40672 .10275 .40374 .0965 .39816 Metetra
.655 .748 .918 r
.0965 .39816 .10275 .40374 .11119 .40077 .10495 .39518 Metetra
.655 .749 .919 r
.10495 .39518 .11119 .40077 .11966 .39778 .11343 .3922 Metetra
.654 .749 .919 r
.11343 .3922 .11966 .39778 .12816 .3948 .12194 .38921 Metetra
.655 .75 .92 r
.12194 .38921 .12816 .3948 .13668 .3918 .13048 .38621 Metetra
.655 .751 .92 r
.13048 .38621 .13668 .3918 .14523 .38878 .13904 .38318 Metetra
.656 .752 .92 r
.13904 .38318 .14523 .38878 .15382 .38573 .14764 .38012 Metetra
.658 .752 .92 r
.14764 .38012 .15382 .38573 .16243 .38265 .15628 .37702 Metetra
.659 .752 .919 r
.15628 .37702 .16243 .38265 .17108 .37955 .16494 .37389 Metetra
.659 .752 .919 r
.16494 .37389 .17108 .37955 .17976 .37642 .17364 .37074 Metetra
.661 .752 .918 r
.17364 .37074 .17976 .37642 .18847 .37326 .18236 .36755 Metetra
.661 .752 .918 r
.18236 .36755 .18847 .37326 .1972 .3701 .19112 .36434 Metetra
.659 .751 .918 r
.19112 .36434 .1972 .3701 .20597 .36695 .1999 .36117 Metetra
.656 .749 .919 r
.1999 .36117 .20597 .36695 .21476 .36384 .20871 .35804 Metetra
.652 .749 .921 r
.20871 .35804 .21476 .36384 .22357 .36077 .21754 .35499 Metetra
.651 .75 .922 r
.21754 .35499 .22357 .36077 .23241 .35771 .22639 .35194 Metetra
.652 .751 .922 r
.22639 .35194 .23241 .35771 .24129 .35462 .23528 .34887 Metetra
.652 .752 .923 r
.23528 .34887 .24129 .35462 .25019 .35153 .2442 .34579 Metetra
.656 .755 .923 r
.2442 .34579 .25019 .35153 .25913 .34836 .25316 .34261 Metetra
.665 .758 .919 r
.25316 .34261 .25913 .34836 .26812 .34504 .26217 .33923 Metetra
.678 .76 .913 r
.26217 .33923 .26812 .34504 .27715 .34149 .27123 .33554 Metetra
.69 .758 .904 r
.27123 .33554 .27715 .34149 .28623 .3377 .28034 .33153 Metetra
.692 .752 .897 r
.28034 .33153 .28623 .3377 .29534 .33383 .28949 .32741 Metetra
.691 .744 .892 r
.28949 .32741 .29534 .33383 .30448 .32996 .29866 .32329 Metetra
.687 .735 .888 r
.29866 .32329 .30448 .32996 .31364 .32613 .30786 .31924 Metetra
.675 .725 .887 r
.30786 .31924 .31364 .32613 .32282 .3225 .31706 .31545 Metetra
.657 .715 .891 r
.31706 .31545 .32282 .3225 .332 .31919 .32626 .31212 Metetra
.626 .704 .901 r
.32626 .31212 .332 .31919 .34119 .3164 .33545 .30949 Metetra
.592 .697 .916 r
.33545 .30949 .34119 .3164 .35038 .31412 .34464 .30756 Metetra
.572 .702 .93 r
.34464 .30756 .35038 .31412 .3596 .31207 .35385 .30594 Metetra
.56 .715 .944 r
.35385 .30594 .3596 .31207 .36885 .3101 .3631 .30443 Metetra
.561 .734 .957 r
.3631 .30443 .36885 .3101 .37815 .30803 .37239 .3028 Metetra
.578 .76 .964 r
.37239 .3028 .37815 .30803 .3875 .30569 .38175 .3008 Metetra
.61 .786 .966 r
.38175 .3008 .3875 .30569 .39691 .30291 .39117 .29821 Metetra
.662 .811 .955 r
.39117 .29821 .39691 .30291 .40638 .29942 .40067 .29465 Metetra
.705 .82 .937 r
.40067 .29465 .40638 .29942 .4159 .29524 .41023 .29018 Metetra
.724 .813 .92 r
.41023 .29018 .4159 .29524 .42547 .29069 .41984 .28518 Metetra
.731 .799 .906 r
.41984 .28518 .42547 .29069 .43507 .28594 .42948 .27993 Metetra
.726 .781 .896 r
.42948 .27993 .43507 .28594 .44469 .28123 .43914 .27473 Metetra
.716 .762 .889 r
.43914 .27473 .44469 .28123 .45434 .27665 .44882 .26973 Metetra
.701 .744 .885 r
.44882 .26973 .45434 .27665 .46401 .27233 .45851 .26508 Metetra
.674 .726 .888 r
.45851 .26508 .46401 .27233 .4737 .26851 .46822 .26111 Metetra
.649 .712 .894 r
.46822 .26111 .4737 .26851 .48341 .26516 .47796 .25777 Metetra
.633 .707 .9 r
.47796 .25777 .48341 .26516 .49316 .26208 .48772 .25481 Metetra
.625 .709 .906 r
.48772 .25481 .49316 .26208 .50294 .25912 .49752 .25203 Metetra
.627 .716 .911 r
.49752 .25203 .50294 .25912 .51276 .25613 .50736 .2492 Metetra
.628 .723 .916 r
.50736 .2492 .51276 .25613 .52262 .25311 .51724 .24634 Metetra
.631 .73 .919 r
.51724 .24634 .52262 .25311 .53252 .25003 .52716 .24339 Metetra
.641 .74 .921 r
.52716 .24339 .53252 .25003 .54246 .24676 .53712 .24021 Metetra
.649 .747 .921 r
.53712 .24021 .54246 .24676 .55243 .24335 .54712 .23683 Metetra
.655 .751 .921 r
.54712 .23683 .55243 .24335 .56244 .23983 .55716 .2333 Metetra
.655 .752 .921 r
.55716 .2333 .56244 .23983 .57249 .23628 .56723 .22974 Metetra
.653 .752 .922 r
.56723 .22974 .57249 .23628 .58257 .23276 .57733 .22623 Metetra
.654 .753 .923 r
.57733 .22623 .58257 .23276 .59269 .22922 .58748 .22268 Metetra
.656 .755 .923 r
.58748 .22268 .59269 .22922 .60285 .22563 .59766 .21908 Metetra
.657 .756 .923 r
.59766 .21908 .60285 .22563 .61304 .22199 .60788 .21543 Metetra
.659 .756 .922 r
.60788 .21543 .61304 .22199 .62327 .21832 .61814 .21172 Metetra
.66 .756 .922 r
.61814 .21172 .62327 .21832 .63354 .21462 .62843 .20798 Metetra
.662 .757 .921 r
.62843 .20798 .63354 .21462 .64384 .21087 .63876 .20418 Metetra
.664 .757 .919 r
.63876 .20418 .64384 .21087 .65418 .20707 .64912 .20032 Metetra
.664 .756 .918 r
.64912 .20032 .65418 .20707 .66455 .20325 .65952 .19643 Metetra
.664 .754 .917 r
.65952 .19643 .66455 .20325 .67497 .19942 .66996 .19254 Metetra
.662 .752 .917 r
.66996 .19254 .67497 .19942 .68542 .19561 .68044 .18868 Metetra
.66 .75 .917 r
.68044 .18868 .68542 .19561 .69591 .19181 .69096 .18484 Metetra
.66 .749 .917 r
.69096 .18484 .69591 .19181 .70645 .18802 .70152 .18101 Metetra
.659 .749 .916 r
.70152 .18101 .70645 .18802 .71702 .18421 .71212 .17717 Metetra
.659 .748 .916 r
.71212 .17717 .71702 .18421 .72763 .18041 .72275 .17333 Metetra
.658 .748 .916 r
.72275 .17333 .72763 .18041 .73828 .17659 .73343 .16949 Metetra
.658 .748 .916 r
.73343 .16949 .73828 .17659 .74898 .17278 .74415 .16564 Metetra
.655 .748 .918 r
.08176 .39554 .08807 .40114 .0965 .39816 .0902 .39254 Metetra
.655 .748 .919 r
.0902 .39254 .0965 .39816 .10495 .39518 .09867 .38955 Metetra
.654 .748 .919 r
.09867 .38955 .10495 .39518 .11343 .3922 .10716 .38656 Metetra
.654 .749 .919 r
.10716 .38656 .11343 .3922 .12194 .38921 .11568 .38356 Metetra
.654 .749 .92 r
.11568 .38356 .12194 .38921 .13048 .38621 .12424 .38055 Metetra
.655 .75 .92 r
.12424 .38055 .13048 .38621 .13904 .38318 .13282 .37752 Metetra
.656 .75 .919 r
.13282 .37752 .13904 .38318 .14764 .38012 .14144 .37444 Metetra
.658 .751 .919 r
.14144 .37444 .14764 .38012 .15628 .37702 .15009 .37132 Metetra
.659 .751 .918 r
.15009 .37132 .15628 .37702 .16494 .37389 .15877 .36817 Metetra
.66 .751 .918 r
.15877 .36817 .16494 .37389 .17364 .37074 .16748 .36499 Metetra
.661 .751 .917 r
.16748 .36499 .17364 .37074 .18236 .36755 .17622 .36177 Metetra
.661 .751 .917 r
.17622 .36177 .18236 .36755 .19112 .36434 .185 .35854 Metetra
.659 .75 .917 r
.185 .35854 .19112 .36434 .1999 .36117 .1938 .35534 Metetra
.656 .749 .919 r
.1938 .35534 .1999 .36117 .20871 .35804 .20262 .3522 Metetra
.651 .748 .92 r
.20262 .3522 .20871 .35804 .21754 .35499 .21146 .34914 Metetra
.651 .748 .921 r
.21146 .34914 .21754 .35499 .22639 .35194 .22034 .34609 Metetra
.651 .749 .922 r
.22034 .34609 .22639 .35194 .23528 .34887 .22924 .34302 Metetra
.651 .75 .922 r
.22924 .34302 .23528 .34887 .2442 .34579 .23818 .33994 Metetra
.656 .752 .921 r
.23818 .33994 .2442 .34579 .25316 .34261 .24716 .33675 Metetra
.666 .755 .917 r
.24716 .33675 .25316 .34261 .26217 .33923 .25618 .33332 Metetra
.68 .758 .91 r
.25618 .33332 .26217 .33923 .27123 .33554 .26527 .32954 Metetra
.694 .759 .902 r
.26527 .32954 .27123 .33554 .28034 .33153 .27441 .3254 Metetra
.698 .756 .897 r
.27441 .3254 .28034 .33153 .28949 .32741 .28359 .32113 Metetra
.697 .752 .894 r
.28359 .32113 .28949 .32741 .29866 .32329 .29279 .31686 Metetra
.693 .746 .893 r
.29279 .31686 .29866 .32329 .30786 .31924 .30201 .31266 Metetra
.68 .739 .895 r
.30201 .31266 .30786 .31924 .31706 .31545 .31124 .30879 Metetra
.658 .729 .902 r
.31124 .30879 .31706 .31545 .32626 .31212 .32046 .30543 Metetra
.621 .717 .914 r
.32046 .30543 .32626 .31212 .33545 .30949 .32966 .30288 Metetra
.578 .704 .928 r
.32966 .30288 .33545 .30949 .34464 .30756 .33885 .30114 Metetra
.554 .702 .938 r
.33885 .30114 .34464 .30756 .35385 .30594 .34807 .29976 Metetra
.543 .707 .947 r
.34807 .29976 .35385 .30594 .3631 .30443 .35731 .29851 Metetra
.547 .72 .953 r
.35731 .29851 .3631 .30443 .37239 .3028 .36661 .29712 Metetra
.571 .74 .956 r
.36661 .29712 .37239 .3028 .38175 .3008 .37598 .2953 Metetra
.609 .762 .953 r
.37598 .2953 .38175 .3008 .39117 .29821 .38541 .29281 Metetra
.665 .785 .938 r
.38541 .29281 .39117 .29821 .40067 .29465 .39494 .28921 Metetra
.71 .796 .918 r
.39494 .28921 .40067 .29465 .41023 .29018 .40453 .28455 Metetra
.73 .795 .904 r
.40453 .28455 .41023 .29018 .41984 .28518 .41418 .27929 Metetra
.738 .788 .893 r
.41418 .27929 .41984 .28518 .42948 .27993 .42385 .27374 Metetra
.733 .778 .888 r
.42385 .27374 .42948 .27993 .43914 .27473 .43354 .26826 Metetra
.724 .766 .887 r
.43354 .26826 .43914 .27473 .44882 .26973 .44325 .263 Metetra
.708 .754 .888 r
.44325 .263 .44882 .26973 .45851 .26508 .45298 .25814 Metetra
.679 .739 .896 r
.45298 .25814 .45851 .26508 .46822 .26111 .46271 .25408 Metetra
.649 .726 .905 r
.46271 .25408 .46822 .26111 .47796 .25777 .47246 .25075 Metetra
.63 .72 .912 r
.47246 .25075 .47796 .25777 .48772 .25481 .48225 .24785 Metetra
.62 .719 .917 r
.48225 .24785 .48772 .25481 .49752 .25203 .49207 .24515 Metetra
.622 .723 .919 r
.49207 .24515 .49752 .25203 .50736 .2492 .50193 .2424 Metetra
.623 .727 .922 r
.50193 .2424 .50736 .2492 .51724 .24634 .51183 .23962 Metetra
.626 .732 .923 r
.51183 .23962 .51724 .24634 .52716 .24339 .52177 .23674 Metetra
.638 .74 .923 r
.52177 .23674 .52716 .24339 .53712 .24021 .53175 .2336 Metetra
.648 .746 .921 r
.53175 .2336 .53712 .24021 .54712 .23683 .54178 .23022 Metetra
.654 .75 .92 r
.54178 .23022 .54712 .23683 .55716 .2333 .55183 .22668 Metetra
.655 .75 .92 r
.55183 .22668 .55716 .2333 .56723 .22974 .56193 .22311 Metetra
.652 .75 .921 r
.56193 .22311 .56723 .22974 .57733 .22623 .57206 .21959 Metetra
.653 .75 .921 r
.57206 .21959 .57733 .22623 .58748 .22268 .58223 .21603 Metetra
.655 .752 .921 r
.58223 .21603 .58748 .22268 .59766 .21908 .59244 .21241 Metetra
.657 .753 .92 r
.59244 .21241 .59766 .21908 .60788 .21543 .60268 .20873 Metetra
.659 .754 .92 r
.60268 .20873 .60788 .21543 .61814 .21172 .61297 .205 Metetra
.66 .754 .92 r
.61297 .205 .61814 .21172 .62843 .20798 .62328 .20123 Metetra
.662 .754 .919 r
.62328 .20123 .62843 .20798 .63876 .20418 .63364 .19739 Metetra
.664 .755 .918 r
.63364 .19739 .63876 .20418 .64912 .20032 .64403 .19348 Metetra
.665 .754 .917 r
.64403 .19348 .64912 .20032 .65952 .19643 .65445 .18954 Metetra
.664 .753 .916 r
.65445 .18954 .65952 .19643 .66996 .19254 .66492 .1856 Metetra
.662 .752 .916 r
.66492 .1856 .66996 .19254 .68044 .18868 .67542 .1817 Metetra
.661 .75 .917 r
.67542 .1817 .68044 .18868 .69096 .18484 .68597 .17783 Metetra
.66 .75 .917 r
.68597 .17783 .69096 .18484 .70152 .18101 .69655 .17396 Metetra
.659 .749 .917 r
.69655 .17396 .70152 .18101 .71212 .17717 .70718 .17009 Metetra
.659 .749 .917 r
.70718 .17009 .71212 .17717 .72275 .17333 .71785 .16622 Metetra
.658 .748 .917 r
.71785 .16622 .72275 .17333 .73343 .16949 .72855 .16235 Metetra
.658 .748 .917 r
.72855 .16235 .73343 .16949 .74415 .16564 .7393 .15848 Metetra
.655 .748 .918 r
.07541 .3899 .08176 .39554 .0902 .39254 .08386 .3869 Metetra
.654 .748 .919 r
.08386 .3869 .0902 .39254 .09867 .38955 .09234 .38389 Metetra
.654 .748 .919 r
.09234 .38389 .09867 .38955 .10716 .38656 .10085 .38089 Metetra
.654 .748 .919 r
.10085 .38089 .10716 .38656 .11568 .38356 .10939 .37788 Metetra
.654 .749 .919 r
.10939 .37788 .11568 .38356 .12424 .38055 .11796 .37485 Metetra
.655 .749 .919 r
.11796 .37485 .12424 .38055 .13282 .37752 .12656 .3718 Metetra
.656 .75 .919 r
.12656 .3718 .13282 .37752 .14144 .37444 .13519 .36871 Metetra
.658 .75 .918 r
.13519 .36871 .14144 .37444 .15009 .37132 .14386 .36557 Metetra
.659 .75 .918 r
.14386 .36557 .15009 .37132 .15877 .36817 .15255 .3624 Metetra
.66 .751 .917 r
.15255 .3624 .15877 .36817 .16748 .36499 .16128 .35919 Metetra
.661 .751 .917 r
.16128 .35919 .16748 .36499 .17622 .36177 .17005 .35595 Metetra
.661 .751 .916 r
.17005 .35595 .17622 .36177 .185 .35854 .17884 .35269 Metetra
.659 .75 .917 r
.17884 .35269 .185 .35854 .1938 .35534 .18766 .34946 Metetra
.655 .749 .919 r
.18766 .34946 .1938 .35534 .20262 .3522 .1965 .34631 Metetra
.651 .748 .92 r
.1965 .34631 .20262 .3522 .21146 .34914 .20536 .34324 Metetra
.65 .748 .921 r
.20536 .34324 .21146 .34914 .22034 .34609 .21425 .34018 Metetra
.65 .748 .921 r
.21425 .34018 .22034 .34609 .22924 .34302 .22317 .33711 Metetra
.65 .749 .921 r
.22317 .33711 .22924 .34302 .23818 .33994 .23212 .33402 Metetra
.656 .751 .92 r
.23212 .33402 .23818 .33994 .24716 .33675 .24112 .3308 Metetra
.666 .754 .916 r
.24112 .3308 .24716 .33675 .25618 .33332 .25016 .32734 Metetra
.682 .757 .909 r
.25016 .32734 .25618 .33332 .26527 .32954 .25927 .3235 Metetra
.696 .76 .901 r
.25927 .3235 .26527 .32954 .27441 .3254 .26844 .31927 Metetra
.701 .758 .897 r
.26844 .31927 .27441 .3254 .28359 .32113 .27764 .31491 Metetra
.7 .756 .895 r
.27764 .31491 .28359 .32113 .29279 .31686 .28687 .31054 Metetra
.696 .752 .895 r
.28687 .31054 .29279 .31686 .30201 .31266 .29612 .30626 Metetra
.682 .746 .9 r
.29612 .30626 .30201 .31266 .31124 .30879 .30537 .30232 Metetra
.659 .738 .908 r
.30537 .30232 .31124 .30879 .32046 .30543 .31461 .29893 Metetra
.618 .724 .922 r
.31461 .29893 .32046 .30543 .32966 .30288 .32383 .29643 Metetra
.57 .708 .935 r
.32383 .29643 .32966 .30288 .33885 .30114 .33302 .29478 Metetra
.544 .701 .943 r
.33302 .29478 .33885 .30114 .34807 .29976 .34224 .29353 Metetra
.533 .702 .948 r
.34224 .29353 .34807 .29976 .35731 .29851 .3515 .29242 Metetra
.539 .712 .951 r
.3515 .29242 .35731 .29851 .36661 .29712 .36081 .29116 Metetra
.566 .729 .951 r
.36081 .29116 .36661 .29712 .37598 .2953 .37018 .28944 Metetra
.607 .749 .945 r
.37018 .28944 .37598 .2953 .38541 .29281 .37964 .287 Metetra
.666 .771 .928 r
.37964 .287 .38541 .29281 .39494 .28921 .38918 .28336 Metetra
.712 .783 .908 r
.38918 .28336 .39494 .28921 .40453 .28455 .39881 .27858 Metetra
.733 .785 .894 r
.39881 .27858 .40453 .28455 .41418 .27929 .40848 .27316 Metetra
.741 .782 .886 r
.40848 .27316 .41418 .27929 .42385 .27374 .41819 .26744 Metetra
.737 .776 .884 r
.41819 .26744 .42385 .27374 .43354 .26826 .42791 .26178 Metetra
.728 .769 .885 r
.42791 .26178 .43354 .26826 .44325 .263 .43765 .25635 Metetra
.713 .76 .89 r
.43765 .25635 .44325 .263 .45298 .25814 .4474 .25138 Metetra
.681 .747 .901 r
.4474 .25138 .45298 .25814 .46271 .25408 .45716 .24725 Metetra
.649 .734 .911 r
.45716 .24725 .46271 .25408 .47246 .25075 .46693 .2439 Metetra
.627 .727 .918 r
.46693 .2439 .47246 .25075 .48225 .24785 .47674 .24103 Metetra
.617 .724 .923 r
.47674 .24103 .48225 .24785 .49207 .24515 .48657 .23837 Metetra
.619 .727 .924 r
.48657 .23837 .49207 .24515 .50193 .2424 .49646 .23566 Metetra
.619 .73 .925 r
.49646 .23566 .50193 .2424 .51183 .23962 .50638 .23292 Metetra
.624 .733 .926 r
.50638 .23292 .51183 .23962 .52177 .23674 .51634 .23007 Metetra
.636 .74 .923 r
.51634 .23007 .52177 .23674 .53175 .2336 .52635 .22693 Metetra
.647 .745 .921 r
.52635 .22693 .53175 .2336 .54178 .23022 .53639 .22355 Metetra
.654 .749 .919 r
.53639 .22355 .54178 .23022 .55183 .22668 .54648 .21999 Metetra
.655 .749 .919 r
.54648 .21999 .55183 .22668 .56193 .22311 .55659 .2164 Metetra
.652 .748 .92 r
.55659 .2164 .56193 .22311 .57206 .21959 .56675 .21286 Metetra
.653 .749 .92 r
.56675 .21286 .57206 .21959 .58223 .21603 .57695 .20929 Metetra
.655 .75 .92 r
.57695 .20929 .58223 .21603 .59244 .21241 .58718 .20565 Metetra
.657 .751 .919 r
.58718 .20565 .59244 .21241 .60268 .20873 .59745 .20195 Metetra
.659 .752 .919 r
.59745 .20195 .60268 .20873 .61297 .205 .60776 .19818 Metetra
.66 .752 .918 r
.60776 .19818 .61297 .205 .62328 .20123 .6181 .19438 Metetra
.663 .753 .917 r
.6181 .19438 .62328 .20123 .63364 .19739 .62848 .19051 Metetra
.665 .754 .916 r
.62848 .19051 .63364 .19739 .64403 .19348 .6389 .18656 Metetra
.666 .754 .916 r
.6389 .18656 .64403 .19348 .65445 .18954 .64935 .18258 Metetra
.665 .753 .916 r
.64935 .18258 .65445 .18954 .66492 .1856 .65984 .17861 Metetra
.663 .751 .916 r
.65984 .17861 .66492 .1856 .67542 .1817 .67037 .17467 Metetra
.661 .75 .916 r
.67037 .17467 .67542 .1817 .68597 .17783 .68094 .17077 Metetra
.66 .75 .917 r
.68094 .17077 .68597 .17783 .69655 .17396 .69156 .16687 Metetra
.659 .749 .917 r
.69156 .16687 .69655 .17396 .70718 .17009 .70221 .16297 Metetra
.659 .749 .917 r
.70221 .16297 .70718 .17009 .71785 .16622 .7129 .15907 Metetra
.658 .749 .917 r
.7129 .15907 .71785 .16622 .72855 .16235 .72364 .15517 Metetra
.658 .749 .917 r
.72364 .15517 .72855 .16235 .7393 .15848 .73442 .15128 Metetra
.655 .748 .919 r
.06902 .38424 .07541 .3899 .08386 .3869 .07749 .38121 Metetra
.654 .748 .919 r
.07749 .38121 .08386 .3869 .09234 .38389 .08598 .37819 Metetra
.654 .748 .919 r
.08598 .37819 .09234 .38389 .10085 .38089 .09451 .37517 Metetra
.654 .748 .919 r
.09451 .37517 .10085 .38089 .10939 .37788 .10306 .37214 Metetra
.654 .748 .919 r
.10306 .37214 .10939 .37788 .11796 .37485 .11165 .3691 Metetra
.655 .748 .919 r
.11165 .3691 .11796 .37485 .12656 .3718 .12026 .36602 Metetra
.656 .749 .918 r
.12026 .36602 .12656 .3718 .13519 .36871 .12891 .36291 Metetra
.658 .749 .918 r
.12891 .36291 .13519 .36871 .14386 .36557 .13759 .35975 Metetra
.659 .75 .917 r
.13759 .35975 .14386 .36557 .15255 .3624 .14631 .35656 Metetra
.66 .75 .917 r
.14631 .35656 .15255 .3624 .16128 .35919 .15505 .35334 Metetra
.661 .75 .916 r
.15505 .35334 .16128 .35919 .17005 .35595 .16383 .35007 Metetra
.661 .75 .916 r
.16383 .35007 .17005 .35595 .17884 .35269 .17264 .34679 Metetra
.659 .75 .917 r
.17264 .34679 .17884 .35269 .18766 .34946 .18148 .34355 Metetra
.655 .749 .918 r
.18148 .34355 .18766 .34946 .1965 .34631 .19034 .34037 Metetra
.651 .747 .92 r
.19034 .34037 .1965 .34631 .20536 .34324 .19921 .33729 Metetra
.65 .747 .921 r
.19921 .33729 .20536 .34324 .21425 .34018 .20812 .33421 Metetra
.65 .747 .92 r
.20812 .33421 .21425 .34018 .22317 .33711 .21706 .33111 Metetra
.65 .747 .92 r
.21706 .33111 .22317 .33711 .23212 .33402 .22603 .328 Metetra
.656 .749 .918 r
.22603 .328 .23212 .33402 .24112 .3308 .23504 .32477 Metetra
.666 .752 .914 r
.23504 .32477 .24112 .3308 .25016 .32734 .24411 .32128 Metetra
.682 .756 .907 r
.24411 .32128 .25016 .32734 .25927 .3235 .25324 .31742 Metetra
.697 .76 .9 r
.25324 .31742 .25927 .3235 .26844 .31927 .26243 .31316 Metetra
.701 .76 .898 r
.26243 .31316 .26844 .31927 .27764 .31491 .27165 .30877 Metetra
.701 .76 .898 r
.27165 .30877 .27764 .31491 .28687 .31054 .2809 .30437 Metetra
.697 .759 .9 r
.2809 .30437 .28687 .31054 .29612 .30626 .29017 .30006 Metetra
.683 .755 .906 r
.29017 .30006 .29612 .30626 .30537 .30232 .29944 .29609 Metetra
.659 .748 .916 r
.29944 .29609 .30537 .30232 .31461 .29893 .3087 .29269 Metetra
.617 .734 .93 r
.3087 .29269 .31461 .29893 .32383 .29643 .31794 .29017 Metetra
.567 .715 .942 r
.31794 .29017 .32383 .29643 .33302 .29478 .32715 .28851 Metetra
.541 .705 .946 r
.32715 .28851 .33302 .29478 .34224 .29353 .33638 .28726 Metetra
.532 .702 .948 r
.33638 .28726 .34224 .29353 .3515 .29242 .34565 .28614 Metetra
.541 .706 .947 r
.34565 .28614 .3515 .29242 .36081 .29116 .35498 .28487 Metetra
.569 .718 .943 r
.35498 .28487 .36081 .29116 .37018 .28944 .36437 .28314 Metetra
.609 .734 .934 r
.36437 .28314 .37018 .28944 .37964 .287 .37384 .28069 Metetra
.666 .754 .916 r
.37384 .28069 .37964 .287 .38918 .28336 .38341 .27702 Metetra
.71 .767 .897 r
.38341 .27702 .38918 .28336 .39881 .27858 .39306 .27221 Metetra
.73 .772 .886 r
.39306 .27221 .39881 .27858 .40848 .27316 .40276 .26676 Metetra
.739 .774 .881 r
.40276 .26676 .40848 .27316 .41819 .26744 .41249 .26099 Metetra
.737 .773 .882 r
.41249 .26099 .41819 .26744 .42791 .26178 .42224 .25529 Metetra
.729 .77 .886 r
.42224 .25529 .42791 .26178 .43765 .25635 .43201 .24983 Metetra
.714 .766 .893 r
.43201 .24983 .43765 .25635 .4474 .25138 .44178 .24482 Metetra
.682 .756 .907 r
.44178 .24482 .4474 .25138 .45716 .24725 .45157 .24066 Metetra
.649 .744 .919 r
.45157 .24066 .45716 .24725 .46693 .2439 .46136 .23729 Metetra
.627 .736 .926 r
.46136 .23729 .46693 .2439 .47674 .24103 .47118 .2344 Metetra
.616 .732 .929 r
.47118 .2344 .47674 .24103 .48657 .23837 .48104 .23173 Metetra
.618 .733 .929 r
.48104 .23173 .48657 .23837 .49646 .23566 .49095 .229 Metetra
.619 .734 .928 r
.49095 .229 .49646 .23566 .50638 .23292 .50089 .22624 Metetra
.623 .736 .927 r
.50089 .22624 .50638 .23292 .51634 .23007 .51088 .22337 Metetra
.636 .741 .924 r
.51088 .22337 .51634 .23007 .52635 .22693 .52091 .22021 Metetra
.647 .745 .921 r
.52091 .22021 .52635 .22693 .53639 .22355 .53097 .21681 Metetra
.654 .748 .919 r
.53097 .21681 .53639 .22355 .54648 .21999 .54108 .21323 Metetra
.655 .748 .919 r
.54108 .21323 .54648 .21999 .55659 .2164 .55122 .20961 Metetra
.652 .747 .919 r
.55122 .20961 .55659 .2164 .56675 .21286 .56141 .20605 Metetra
.653 .747 .919 r
.56141 .20605 .56675 .21286 .57695 .20929 .57163 .20245 Metetra
.655 .748 .919 r
.57163 .20245 .57695 .20929 .58718 .20565 .58188 .19878 Metetra
.657 .749 .918 r
.58188 .19878 .58718 .20565 .59745 .20195 .59218 .19506 Metetra
.659 .75 .917 r
.59218 .19506 .59745 .20195 .60776 .19818 .60251 .19127 Metetra
.66 .75 .917 r
.60251 .19127 .60776 .19818 .6181 .19438 .61288 .18744 Metetra
.662 .751 .916 r
.61288 .18744 .6181 .19438 .62848 .19051 .62329 .18354 Metetra
.665 .752 .915 r
.62329 .18354 .62848 .19051 .6389 .18656 .63373 .17957 Metetra
.666 .752 .915 r
.63373 .17957 .6389 .18656 .64935 .18258 .64421 .17556 Metetra
.665 .752 .915 r
.64421 .17556 .64935 .18258 .65984 .17861 .65473 .17156 Metetra
.663 .751 .916 r
.65473 .17156 .65984 .17861 .67037 .17467 .66529 .1676 Metetra
.661 .75 .916 r
.66529 .1676 .67037 .17467 .68094 .17077 .67589 .16366 Metetra
.66 .75 .917 r
.67589 .16366 .68094 .17077 .69156 .16687 .68653 .15974 Metetra
.659 .75 .917 r
.68653 .15974 .69156 .16687 .70221 .16297 .69721 .15581 Metetra
.659 .75 .917 r
.69721 .15581 .70221 .16297 .7129 .15907 .70793 .15188 Metetra
.658 .749 .917 r
.70793 .15188 .7129 .15907 .72364 .15517 .71869 .14796 Metetra
.658 .749 .917 r
.71869 .14796 .72364 .15517 .73442 .15128 .7295 .14403 Metetra
.655 .749 .919 r
.06258 .37855 .06902 .38424 .07749 .38121 .07107 .3755 Metetra
.655 .748 .919 r
.07107 .3755 .07749 .38121 .08598 .37819 .07958 .37245 Metetra
.654 .748 .919 r
.07958 .37245 .08598 .37819 .09451 .37517 .08813 .3694 Metetra
.654 .748 .919 r
.08813 .3694 .09451 .37517 .10306 .37214 .0967 .36635 Metetra
.654 .748 .918 r
.0967 .36635 .10306 .37214 .11165 .3691 .1053 .36328 Metetra
.655 .748 .918 r
.1053 .36328 .11165 .3691 .12026 .36602 .11393 .36018 Metetra
.656 .748 .917 r
.11393 .36018 .12026 .36602 .12891 .36291 .12259 .35705 Metetra
.658 .748 .917 r
.12259 .35705 .12891 .36291 .13759 .35975 .13129 .35387 Metetra
.659 .748 .916 r
.13129 .35387 .13759 .35975 .14631 .35656 .14002 .35066 Metetra
.66 .748 .916 r
.14002 .35066 .14631 .35656 .15505 .35334 .14879 .34742 Metetra
.661 .749 .915 r
.14879 .34742 .15505 .35334 .16383 .35007 .15758 .34414 Metetra
.661 .749 .916 r
.15758 .34414 .16383 .35007 .17264 .34679 .16641 .34084 Metetra
.659 .749 .917 r
.16641 .34084 .17264 .34679 .18148 .34355 .17526 .33758 Metetra
.656 .748 .918 r
.17526 .33758 .18148 .34355 .19034 .34037 .18414 .33439 Metetra
.651 .747 .92 r
.18414 .33439 .19034 .34037 .19921 .33729 .19303 .33126 Metetra
.651 .746 .919 r
.19303 .33126 .19921 .33729 .20812 .33421 .20196 .32815 Metetra
.651 .746 .919 r
.20196 .32815 .20812 .33421 .21706 .33111 .21092 .32502 Metetra
.651 .745 .919 r
.21092 .32502 .21706 .33111 .22603 .328 .21991 .32188 Metetra
.656 .746 .916 r
.21991 .32188 .22603 .328 .23504 .32477 .22894 .31862 Metetra
.665 .749 .912 r
.22894 .31862 .23504 .32477 .24411 .32128 .23802 .31513 Metetra
.68 .753 .907 r
.23802 .31513 .24411 .32128 .25324 .31742 .24717 .31129 Metetra
.693 .759 .902 r
.24717 .31129 .25324 .31742 .26243 .31316 .25637 .30709 Metetra
.698 .763 .902 r
.25637 .30709 .26243 .31316 .27165 .30877 .26561 .30277 Metetra
.698 .766 .904 r
.26561 .30277 .27165 .30877 .2809 .30437 .27487 .29844 Metetra
.695 .768 .908 r
.27487 .29844 .2809 .30437 .29017 .30006 .28416 .29419 Metetra
.682 .768 .916 r
.28416 .29419 .29017 .30006 .29944 .29609 .29345 .29026 Metetra
.66 .764 .927 r
.29345 .29026 .29944 .29609 .3087 .29269 .30273 .28683 Metetra
.619 .751 .941 r
.30273 .28683 .3087 .29269 .31794 .29017 .31198 .28422 Metetra
.573 .731 .95 r
.31198 .28422 .31794 .29017 .32715 .28851 .32122 .28239 Metetra
.551 .717 .95 r
.32122 .28239 .32715 .28851 .33638 .28726 .33048 .28093 Metetra
.545 .707 .946 r
.33048 .28093 .33638 .28726 .34565 .28614 .33978 .27959 Metetra
.555 .704 .939 r
.33978 .27959 .34565 .28614 .35498 .28487 .34913 .27811 Metetra
.581 .707 .929 r
.34913 .27811 .35498 .28487 .36437 .28314 .35855 .27621 Metetra
.616 .715 .917 r
.35855 .27621 .36437 .28314 .37384 .28069 .36804 .27365 Metetra
.663 .73 .899 r
.36804 .27365 .37384 .28069 .38341 .27702 .37763 .26998 Metetra
.701 .743 .883 r
.37763 .26998 .38341 .27702 .39306 .27221 .3873 .26526 Metetra
.721 .752 .877 r
.3873 .26526 .39306 .27221 .40276 .26676 .39701 .25995 Metetra
.73 .76 .876 r
.39701 .25995 .40276 .26676 .41249 .26099 .40676 .25435 Metetra
.73 .766 .882 r
.40676 .25435 .41249 .26099 .42224 .25529 .41654 .24882 Metetra
.724 .771 .89 r
.41654 .24882 .42224 .25529 .43201 .24983 .42632 .2435 Metetra
.711 .773 .901 r
.42632 .2435 .43201 .24983 .44178 .24482 .43612 .23859 Metetra
.681 .769 .917 r
.43612 .23859 .44178 .24482 .45157 .24066 .44592 .23447 Metetra
.65 .761 .93 r
.44592 .23447 .45157 .24066 .46136 .23729 .45574 .23106 Metetra
.629 .752 .936 r
.45574 .23106 .46136 .23729 .47118 .2344 .46559 .22808 Metetra
.618 .746 .937 r
.46559 .22808 .47118 .2344 .48104 .23173 .47547 .2253 Metetra
.621 .744 .935 r
.47547 .2253 .48104 .23173 .49095 .229 .4854 .22248 Metetra
.622 .742 .932 r
.4854 .22248 .49095 .229 .50089 .22624 .49537 .21962 Metetra
.626 .741 .929 r
.49537 .21962 .50089 .22624 .51088 .22337 .50538 .21666 Metetra
.638 .743 .924 r
.50538 .21666 .51088 .22337 .52091 .22021 .51543 .21343 Metetra
.648 .745 .92 r
.51543 .21343 .52091 .22021 .53097 .21681 .52552 .20998 Metetra
.654 .747 .918 r
.52552 .20998 .53097 .21681 .54108 .21323 .53565 .20637 Metetra
.655 .747 .917 r
.53565 .20637 .54108 .21323 .55122 .20961 .54582 .20272 Metetra
.652 .745 .918 r
.54582 .20272 .55122 .20961 .56141 .20605 .55602 .19912 Metetra
.653 .745 .917 r
.55602 .19912 .56141 .20605 .57163 .20245 .56627 .19548 Metetra
.655 .746 .916 r
.56627 .19548 .57163 .20245 .58188 .19878 .57655 .19179 Metetra
.657 .746 .916 r
.57655 .19179 .58188 .19878 .59218 .19506 .58687 .18804 Metetra
.659 .747 .915 r
.58687 .18804 .59218 .19506 .60251 .19127 .59723 .18423 Metetra
.66 .747 .915 r
.59723 .18423 .60251 .19127 .61288 .18744 .60762 .18038 Metetra
.662 .748 .914 r
.60762 .18038 .61288 .18744 .62329 .18354 .61806 .17646 Metetra
.664 .75 .914 r
.61806 .17646 .62329 .18354 .63373 .17957 .62853 .17248 Metetra
.665 .75 .914 r
.62853 .17248 .63373 .17957 .64421 .17556 .63903 .16846 Metetra
.664 .751 .915 r
.63903 .16846 .64421 .17556 .65473 .17156 .64958 .16445 Metetra
.662 .751 .916 r
.64958 .16445 .65473 .17156 .66529 .1676 .66016 .16047 Metetra
.661 .75 .916 r
.66016 .16047 .66529 .1676 .67589 .16366 .67079 .15651 Metetra
.66 .75 .917 r
.67079 .15651 .67589 .16366 .68653 .15974 .68146 .15257 Metetra
.659 .75 .917 r
.68146 .15257 .68653 .15974 .69721 .15581 .69217 .14862 Metetra
.659 .75 .917 r
.69217 .14862 .69721 .15581 .70793 .15188 .70292 .14466 Metetra
.658 .75 .918 r
.70292 .14466 .70793 .15188 .71869 .14796 .71371 .14072 Metetra
.658 .75 .918 r
.71371 .14072 .71869 .14796 .7295 .14403 .72454 .13676 Metetra
.656 .749 .919 r
.05611 .37283 .06258 .37855 .07107 .3755 .06461 .36975 Metetra
.655 .749 .919 r
.06461 .36975 .07107 .3755 .07958 .37245 .07314 .36667 Metetra
.655 .748 .918 r
.07314 .36667 .07958 .37245 .08813 .3694 .0817 .36359 Metetra
.655 .748 .918 r
.0817 .36359 .08813 .3694 .0967 .36635 .09029 .3605 Metetra
.655 .747 .918 r
.09029 .3605 .0967 .36635 .1053 .36328 .09891 .3574 Metetra
.655 .747 .917 r
.09891 .3574 .1053 .36328 .11393 .36018 .10756 .35427 Metetra
.656 .747 .916 r
.10756 .35427 .11393 .36018 .12259 .35705 .11624 .35111 Metetra
.658 .747 .916 r
.11624 .35111 .12259 .35705 .13129 .35387 .12496 .34792 Metetra
.658 .747 .915 r
.12496 .34792 .13129 .35387 .14002 .35066 .1337 .34469 Metetra
.659 .747 .915 r
.1337 .34469 .14002 .35066 .14879 .34742 .14248 .34144 Metetra
.66 .748 .915 r
.14248 .34144 .14879 .34742 .15758 .34414 .1513 .33815 Metetra
.66 .749 .915 r
.1513 .33815 .15758 .34414 .16641 .34084 .16014 .33485 Metetra
.659 .749 .916 r
.16014 .33485 .16641 .34084 .17526 .33758 .16901 .33157 Metetra
.656 .748 .918 r
.16901 .33157 .17526 .33758 .18414 .33439 .1779 .32835 Metetra
.653 .747 .919 r
.1779 .32835 .18414 .33439 .19303 .33126 .18681 .32518 Metetra
.652 .746 .918 r
.18681 .32518 .19303 .33126 .20196 .32815 .19576 .32202 Metetra
.652 .745 .918 r
.19576 .32202 .20196 .32815 .21092 .32502 .20474 .31884 Metetra
.652 .744 .917 r
.20474 .31884 .21092 .32502 .21991 .32188 .21375 .31565 Metetra
.656 .744 .915 r
.21375 .31565 .21991 .32188 .22894 .31862 .2228 .31236 Metetra
.664 .746 .911 r
.2228 .31236 .22894 .31862 .23802 .31513 .2319 .30889 Metetra
.676 .751 .907 r
.2319 .30889 .23802 .31513 .24717 .31129 .24105 .30512 Metetra
.688 .757 .904 r
.24105 .30512 .24717 .31129 .25637 .30709 .25026 .30105 Metetra
.692 .763 .907 r
.25026 .30105 .25637 .30709 .26561 .30277 .25951 .29688 Metetra
.692 .77 .911 r
.25951 .29688 .26561 .30277 .27487 .29844 .26878 .2927 Metetra
.69 .775 .917 r
.26878 .2927 .27487 .29844 .28416 .29419 .27808 .28859 Metetra
.679 .778 .925 r
.27808 .28859 .28416 .29419 .29345 .29026 .28738 .28473 Metetra
.659 .777 .936 r
.28738 .28473 .29345 .29026 .30273 .28683 .29668 .28129 Metetra
.624 .766 .947 r
.29668 .28129 .30273 .28683 .31198 .28422 .30597 .27851 Metetra
.587 .748 .954 r
.30597 .27851 .31198 .28422 .32122 .28239 .31525 .27638 Metetra
.571 .731 .95 r
.31525 .27638 .32122 .28239 .33048 .28093 .32455 .27455 Metetra
.568 .716 .942 r
.32455 .27455 .33048 .28093 .33978 .27959 .33388 .27281 Metetra
.578 .706 .93 r
.33388 .27281 .33978 .27959 .34913 .27811 .34327 .27096 Metetra
.597 .702 .916 r
.34327 .27096 .34913 .27811 .35855 .27621 .35272 .26877 Metetra
.623 .703 .902 r
.35272 .26877 .35855 .27621 .36804 .27365 .36224 .26602 Metetra
.66 .711 .886 r
.36224 .26602 .36804 .27365 .37763 .26998 .37184 .26236 Metetra
.691 .723 .875 r
.37184 .26236 .37763 .26998 .3873 .26526 .38152 .25783 Metetra
.707 .735 .872 r
.38152 .25783 .3873 .26526 .39701 .25995 .39124 .25281 Metetra
.717 .747 .876 r
.39124 .25281 .39701 .25995 .40676 .25435 .401 .24756 Metetra
.718 .759 .885 r
.401 .24756 .40676 .25435 .41654 .24882 .41079 .24235 Metetra
.714 .77 .896 r
.41079 .24235 .41654 .24882 .42632 .2435 .42059 .23732 Metetra
.703 .778 .91 r
.42059 .23732 .42632 .2435 .43612 .23859 .4304 .23263 Metetra
.678 .779 .927 r
.4304 .23263 .43612 .23859 .44592 .23447 .44023 .22857 Metetra
.651 .774 .939 r
.44023 .22857 .44592 .23447 .45574 .23106 .45007 .22511 Metetra
.633 .766 .943 r
.45007 .22511 .45574 .23106 .46559 .22808 .45995 .222 Metetra
.625 .759 .943 r
.45995 .222 .46559 .22808 .47547 .2253 .46986 .21905 Metetra
.627 .754 .938 r
.46986 .21905 .47547 .2253 .4854 .22248 .47981 .21605 Metetra
.628 .749 .935 r
.47981 .21605 .4854 .22248 .49537 .21962 .4898 .21303 Metetra
.632 .746 .93 r
.4898 .21303 .49537 .21962 .50538 .21666 .49984 .20992 Metetra
.642 .745 .924 r
.49984 .20992 .50538 .21666 .51543 .21343 .50991 .2066 Metetra
.65 .745 .919 r
.50991 .2066 .51543 .21343 .52552 .20998 .52003 .20308 Metetra
.655 .746 .917 r
.52003 .20308 .52552 .20998 .53565 .20637 .53018 .19942 Metetra
.655 .745 .916 r
.53018 .19942 .53565 .20637 .54582 .20272 .54037 .19574 Metetra
.653 .744 .917 r
.54037 .19574 .54582 .20272 .55602 .19912 .5506 .19209 Metetra
.654 .744 .916 r
.5506 .19209 .55602 .19912 .56627 .19548 .56087 .18841 Metetra
.655 .744 .915 r
.56087 .18841 .56627 .19548 .57655 .19179 .57118 .18468 Metetra
.657 .744 .914 r
.57118 .18468 .57655 .19179 .58687 .18804 .58152 .1809 Metetra
.658 .744 .914 r
.58152 .1809 .58687 .18804 .59723 .18423 .59191 .17707 Metetra
.659 .745 .913 r
.59191 .17707 .59723 .18423 .60762 .18038 .60233 .17321 Metetra
.661 .746 .913 r
.60233 .17321 .60762 .18038 .61806 .17646 .61279 .16928 Metetra
.663 .747 .913 r
.61279 .16928 .61806 .17646 .62853 .17248 .62328 .1653 Metetra
.663 .749 .914 r
.62328 .1653 .62853 .17248 .63903 .16846 .63382 .16129 Metetra
.663 .749 .914 r
.63382 .16129 .63903 .16846 .64958 .16445 .64439 .15728 Metetra
.661 .75 .916 r
.64439 .15728 .64958 .16445 .66016 .16047 .65501 .15329 Metetra
.66 .75 .917 r
.65501 .15329 .66016 .16047 .67079 .15651 .66566 .14932 Metetra
.659 .75 .917 r
.66566 .14932 .67079 .15651 .68146 .15257 .67636 .14535 Metetra
.659 .75 .918 r
.67636 .14535 .68146 .15257 .69217 .14862 .6871 .14138 Metetra
.659 .75 .918 r
.6871 .14138 .69217 .14862 .70292 .14466 .69787 .13741 Metetra
.658 .75 .918 r
.69787 .13741 .70292 .14466 .71371 .14072 .70869 .13343 Metetra
.658 .75 .918 r
.70869 .13343 .71371 .14072 .72454 .13676 .71956 .12945 Metetra
.656 .749 .919 r
.0496 .36708 .05611 .37283 .06461 .36975 .05812 .36397 Metetra
.656 .749 .918 r
.05812 .36397 .06461 .36975 .07314 .36667 .06666 .36086 Metetra
.656 .748 .918 r
.06666 .36086 .07314 .36667 .0817 .36359 .07524 .35774 Metetra
.655 .748 .918 r
.07524 .35774 .0817 .36359 .09029 .3605 .08385 .35461 Metetra
.656 .747 .917 r
.08385 .35461 .09029 .3605 .09891 .3574 .09248 .35147 Metetra
.656 .746 .917 r
.09248 .35147 .09891 .3574 .10756 .35427 .10115 .34831 Metetra
.657 .746 .916 r
.10115 .34831 .10756 .35427 .11624 .35111 .10985 .34512 Metetra
.658 .746 .915 r
.10985 .34512 .11624 .35111 .12496 .34792 .11858 .34191 Metetra
.658 .746 .915 r
.11858 .34191 .12496 .34792 .1337 .34469 .12735 .33867 Metetra
.659 .747 .915 r
.12735 .33867 .1337 .34469 .14248 .34144 .13614 .3354 Metetra
.66 .747 .915 r
.13614 .3354 .14248 .34144 .1513 .33815 .14497 .33211 Metetra
.66 .748 .915 r
.14497 .33211 .1513 .33815 .16014 .33485 .15383 .32881 Metetra
.658 .748 .916 r
.15383 .32881 .16014 .33485 .16901 .33157 .16271 .32552 Metetra
.656 .748 .917 r
.16271 .32552 .16901 .33157 .1779 .32835 .17162 .32226 Metetra
.654 .747 .918 r
.17162 .32226 .1779 .32835 .18681 .32518 .18056 .31904 Metetra
.653 .746 .917 r
.18056 .31904 .18681 .32518 .19576 .32202 .18953 .31583 Metetra
.654 .744 .916 r
.18953 .31583 .19576 .32202 .20474 .31884 .19852 .31259 Metetra
.654 .743 .916 r
.19852 .31259 .20474 .31884 .21375 .31565 .20756 .30935 Metetra
.656 .743 .914 r
.20756 .30935 .21375 .31565 .2228 .31236 .21662 .30603 Metetra
.662 .744 .911 r
.21662 .30603 .2228 .31236 .2319 .30889 .22574 .30257 Metetra
.671 .748 .909 r
.22574 .30257 .2319 .30889 .24105 .30512 .2349 .2989 Metetra
.68 .755 .908 r
.2349 .2989 .24105 .30512 .25026 .30105 .24411 .29501 Metetra
.683 .763 .912 r
.24411 .29501 .25026 .30105 .25951 .29688 .25336 .29105 Metetra
.683 .771 .917 r
.25336 .29105 .25951 .29688 .26878 .2927 .26264 .28707 Metetra
.682 .779 .924 r
.26264 .28707 .26878 .2927 .27808 .28859 .27194 .28314 Metetra
.673 .784 .933 r
.27194 .28314 .27808 .28859 .28738 .28473 .28126 .27938 Metetra
.658 .785 .942 r
.28126 .27938 .28738 .28473 .29668 .28129 .29058 .27593 Metetra
.633 .778 .95 r
.29058 .27593 .29668 .28129 .30597 .27851 .2999 .27295 Metetra
.608 .762 .953 r
.2999 .27295 .30597 .27851 .31525 .27638 .30923 .27043 Metetra
.598 .745 .947 r
.30923 .27043 .31525 .27638 .32455 .27455 .31857 .26812 Metetra
.596 .727 .935 r
.31857 .26812 .32455 .27455 .33388 .27281 .32796 .26588 Metetra
.603 .712 .921 r
.32796 .26588 .33388 .27281 .34327 .27096 .33739 .26355 Metetra
.615 .701 .906 r
.33739 .26355 .34327 .27096 .35272 .26877 .34687 .26096 Metetra
.632 .696 .891 r
.34687 .26096 .35272 .26877 .36224 .26602 .35642 .25798 Metetra
.657 .699 .878 r
.35642 .25798 .36224 .26602 .37184 .26236 .36604 .25434 Metetra
.679 .709 .87 r
.36604 .25434 .37184 .26236 .38152 .25783 .37572 .25007 Metetra
.692 .721 .872 r
.37572 .25007 .38152 .25783 .39124 .25281 .38545 .24545 Metetra
.7 .737 .879 r
.38545 .24545 .39124 .25281 .401 .24756 .39521 .24065 Metetra
.702 .752 .891 r
.39521 .24065 .401 .24756 .41079 .24235 .405 .23588 Metetra
.7 .767 .904 r
.405 .23588 .41079 .24235 .42059 .23732 .41481 .23123 Metetra
.692 .779 .918 r
.41481 .23123 .42059 .23732 .4304 .23263 .42464 .22682 Metetra
.673 .785 .934 r
.42464 .22682 .4304 .23263 .44023 .22857 .43449 .22287 Metetra
.652 .783 .944 r
.43449 .22287 .44023 .22857 .45007 .22511 .44436 .21934 Metetra
.639 .777 .947 r
.44436 .21934 .45007 .22511 .45995 .222 .45426 .21606 Metetra
.634 .77 .945 r
.45426 .21606 .45995 .222 .46986 .21905 .4642 .21289 Metetra
.636 .763 .94 r
.4642 .21289 .46986 .21905 .47981 .21605 .47418 .20969 Metetra
.637 .756 .935 r
.47418 .20969 .47981 .21605 .4898 .21303 .4842 .20646 Metetra
.639 .751 .929 r
.4842 .20646 .4898 .21303 .49984 .20992 .49426 .20316 Metetra
.646 .747 .923 r
.49426 .20316 .49984 .20992 .50991 .2066 .50436 .19971 Metetra
.652 .746 .919 r
.50436 .19971 .50991 .2066 .52003 .20308 .5145 .19611 Metetra
.655 .745 .916 r
.5145 .19611 .52003 .20308 .53018 .19942 .52467 .19241 Metetra
.656 .745 .915 r
.52467 .19241 .53018 .19942 .54037 .19574 .53489 .18869 Metetra
.654 .744 .915 r
.53489 .18869 .54037 .19574 .5506 .19209 .54515 .18498 Metetra
.655 .743 .915 r
.54515 .18498 .5506 .19209 .56087 .18841 .55544 .18125 Metetra
.656 .743 .914 r
.55544 .18125 .56087 .18841 .57118 .18468 .56577 .17748 Metetra
.657 .742 .913 r
.56577 .17748 .57118 .18468 .58152 .1809 .57614 .17367 Metetra
.658 .743 .912 r
.57614 .17367 .58152 .1809 .59191 .17707 .58655 .16982 Metetra
.659 .743 .912 r
.58655 .16982 .59191 .17707 .60233 .17321 .597 .16594 Metetra
.66 .744 .912 r
.597 .16594 .60233 .17321 .61279 .16928 .60748 .16202 Metetra
.661 .746 .913 r
.60748 .16202 .61279 .16928 .62328 .1653 .61801 .15805 Metetra
.662 .747 .913 r
.61801 .15805 .62328 .1653 .63382 .16129 .62857 .15405 Metetra
.661 .748 .915 r
.62857 .15405 .63382 .16129 .64439 .15728 .63917 .15005 Metetra
.66 .749 .916 r
.63917 .15005 .64439 .15728 .65501 .15329 .64981 .14606 Metetra
.659 .75 .917 r
.64981 .14606 .65501 .15329 .66566 .14932 .6605 .14208 Metetra
.659 .75 .917 r
.6605 .14208 .66566 .14932 .67636 .14535 .67122 .1381 Metetra
.659 .75 .918 r
.67122 .1381 .67636 .14535 .6871 .14138 .68199 .13411 Metetra
.658 .751 .918 r
.68199 .13411 .6871 .14138 .69787 .13741 .69279 .13011 Metetra
.658 .751 .918 r
.69279 .13011 .69787 .13741 .70869 .13343 .70364 .12611 Metetra
.658 .751 .919 r
.70364 .12611 .70869 .13343 .71956 .12945 .71454 .1221 Metetra
.657 .75 .918 r
.04304 .36129 .0496 .36708 .05812 .36397 .05158 .35815 Metetra
.657 .749 .918 r
.05158 .35815 .05812 .36397 .06666 .36086 .06014 .355 Metetra
.656 .748 .918 r
.06014 .355 .06666 .36086 .07524 .35774 .06874 .35184 Metetra
.656 .748 .917 r
.06874 .35184 .07524 .35774 .08385 .35461 .07737 .34868 Metetra
.656 .747 .917 r
.07737 .34868 .08385 .35461 .09248 .35147 .08602 .3455 Metetra
.657 .747 .916 r
.08602 .3455 .09248 .35147 .10115 .34831 .09471 .34231 Metetra
.657 .746 .916 r
.09471 .34231 .10115 .34831 .10985 .34512 .10342 .33909 Metetra
.658 .746 .915 r
.10342 .33909 .10985 .34512 .11858 .34191 .11217 .33586 Metetra
.658 .746 .915 r
.11217 .33586 .11858 .34191 .12735 .33867 .12095 .3326 Metetra
.658 .746 .915 r
.12095 .3326 .12735 .33867 .13614 .3354 .12976 .32933 Metetra
.659 .747 .915 r
.12976 .32933 .13614 .3354 .14497 .33211 .1386 .32603 Metetra
.659 .748 .916 r
.1386 .32603 .14497 .33211 .15383 .32881 .14747 .32272 Metetra
.658 .748 .916 r
.14747 .32272 .15383 .32881 .16271 .32552 .15638 .31942 Metetra
.657 .748 .917 r
.15638 .31942 .16271 .32552 .17162 .32226 .16531 .31613 Metetra
.655 .747 .917 r
.16531 .31613 .17162 .32226 .18056 .31904 .17426 .31286 Metetra
.655 .746 .917 r
.17426 .31286 .18056 .31904 .18953 .31583 .18325 .30959 Metetra
.655 .745 .916 r
.18325 .30959 .18953 .31583 .19852 .31259 .19227 .3063 Metetra
.655 .743 .915 r
.19227 .3063 .19852 .31259 .20756 .30935 .20132 .303 Metetra
.657 .743 .913 r
.20132 .303 .20756 .30935 .21662 .30603 .21041 .29965 Metetra
.66 .743 .912 r
.21041 .29965 .21662 .30603 .22574 .30257 .21954 .29621 Metetra
.665 .746 .911 r
.21954 .29621 .22574 .30257 .2349 .2989 .22871 .29265 Metetra
.671 .752 .912 r
.22871 .29265 .2349 .2989 .24411 .29501 .23792 .28894 Metetra
.673 .76 .916 r
.23792 .28894 .24411 .29501 .25336 .29105 .24717 .28519 Metetra
.673 .769 .922 r
.24717 .28519 .25336 .29105 .26264 .28707 .25645 .28143 Metetra
.672 .777 .929 r
.25645 .28143 .26264 .28707 .27194 .28314 .26576 .27769 Metetra
.667 .784 .936 r
.26576 .27769 .27194 .28314 .28126 .27938 .27508 .27404 Metetra
.658 .787 .943 r
.27508 .27404 .28126 .27938 .29058 .27593 .28443 .27057 Metetra
.643 .783 .948 r
.28443 .27057 .29058 .27593 .2999 .27295 .29379 .26738 Metetra
.629 .771 .948 r
.29379 .26738 .2999 .27295 .30923 .27043 .30316 .26445 Metetra
.624 .754 .94 r
.30316 .26445 .30923 .27043 .31857 .26812 .31256 .26165 Metetra
.623 .737 .928 r
.31256 .26165 .31857 .26812 .32796 .26588 .322 .25887 Metetra
.626 .72 .914 r
.322 .25887 .32796 .26588 .33739 .26355 .33147 .25604 Metetra
.632 .706 .9 r
.33147 .25604 .33739 .26355 .34687 .26096 .341 .25306 Metetra
.641 .698 .887 r
.341 .25306 .34687 .26096 .35642 .25798 .35057 .24983 Metetra
.655 .697 .877 r
.35057 .24983 .35642 .25798 .36604 .25434 .3602 .24621 Metetra
.668 .703 .873 r
.3602 .24621 .36604 .25434 .37572 .25007 .36989 .24221 Metetra
.677 .715 .877 r
.36989 .24221 .37572 .25007 .38545 .24545 .37961 .238 Metetra
.683 .73 .886 r
.37961 .238 .38545 .24545 .39521 .24065 .38938 .23367 Metetra
.685 .746 .898 r
.38938 .23367 .39521 .24065 .405 .23588 .39917 .22936 Metetra
.683 .762 .911 r
.39917 .22936 .405 .23588 .41481 .23123 .40899 .22512 Metetra
.679 .776 .924 r
.40899 .22512 .41481 .23123 .42464 .22682 .41883 .22101 Metetra
.667 .784 .937 r
.41883 .22101 .42464 .22682 .43449 .22287 .42871 .21717 Metetra
.654 .786 .944 r
.42871 .21717 .43449 .22287 .44436 .21934 .4386 .21357 Metetra
.647 .781 .946 r
.4386 .21357 .44436 .21934 .45426 .21606 .44854 .21011 Metetra
.644 .774 .943 r
.44854 .21011 .45426 .21606 .4642 .21289 .4585 .20671 Metetra
.645 .767 .937 r
.4585 .20671 .4642 .21289 .47418 .20969 .46851 .20329 Metetra
.646 .76 .932 r
.46851 .20329 .47418 .20969 .4842 .20646 .47856 .19985 Metetra
.647 .754 .927 r
.47856 .19985 .4842 .20646 .49426 .20316 .48864 .19636 Metetra
.651 .749 .922 r
.48864 .19636 .49426 .20316 .50436 .19971 .49877 .19277 Metetra
.654 .747 .918 r
.49877 .19277 .50436 .19971 .5145 .19611 .50893 .18909 Metetra
.656 .746 .916 r
.50893 .18909 .5145 .19611 .52467 .19241 .51913 .18534 Metetra
.657 .745 .915 r
.51913 .18534 .52467 .19241 .53489 .18869 .52937 .18158 Metetra
.656 .744 .915 r
.52937 .18158 .53489 .18869 .54515 .18498 .53965 .17782 Metetra
.656 .743 .914 r
.53965 .17782 .54515 .18498 .55544 .18125 .54997 .17404 Metetra
.657 .742 .913 r
.54997 .17404 .55544 .18125 .56577 .17748 .56033 .17023 Metetra
.657 .742 .913 r
.56033 .17023 .56577 .17748 .57614 .17367 .57072 .16639 Metetra
.658 .742 .912 r
.57072 .16639 .57614 .17367 .58655 .16982 .58115 .16252 Metetra
.658 .743 .912 r
.58115 .16252 .58655 .16982 .597 .16594 .59163 .15862 Metetra
.659 .744 .913 r
.59163 .15862 .597 .16594 .60748 .16202 .60214 .1547 Metetra
.66 .745 .913 r
.60214 .1547 .60748 .16202 .61801 .15805 .61269 .15074 Metetra
.66 .746 .914 r
.61269 .15074 .61801 .15805 .62857 .15405 .62328 .14676 Metetra
.66 .748 .915 r
.62328 .14676 .62857 .15405 .63917 .15005 .63391 .14277 Metetra
.659 .749 .916 r
.63391 .14277 .63917 .15005 .64981 .14606 .64458 .13878 Metetra
.659 .749 .917 r
.64458 .13878 .64981 .14606 .6605 .14208 .6553 .13479 Metetra
.658 .75 .918 r
.6553 .13479 .6605 .14208 .67122 .1381 .66605 .13079 Metetra
.658 .75 .918 r
.66605 .13079 .67122 .1381 .68199 .13411 .67684 .12679 Metetra
.658 .751 .918 r
.67684 .12679 .68199 .13411 .69279 .13011 .68768 .12277 Metetra
.658 .751 .918 r
.68768 .12277 .69279 .13011 .70364 .12611 .69856 .11874 Metetra
.658 .751 .919 r
.69856 .11874 .70364 .12611 .71454 .1221 .70948 .1147 Metetra
.657 .75 .918 r
.03644 .35547 .04304 .36129 .05158 .35815 .045 .35229 Metetra
.657 .749 .918 r
.045 .35229 .05158 .35815 .06014 .355 .05358 .34911 Metetra
.657 .749 .917 r
.05358 .34911 .06014 .355 .06874 .35184 .0622 .34592 Metetra
.657 .748 .917 r
.0622 .34592 .06874 .35184 .07737 .34868 .07084 .34272 Metetra
.657 .747 .917 r
.07084 .34272 .07737 .34868 .08602 .3455 .07951 .3395 Metetra
.657 .747 .916 r
.07951 .3395 .08602 .3455 .09471 .34231 .08822 .33627 Metetra
.657 .746 .916 r
.08822 .33627 .09471 .34231 .10342 .33909 .09695 .33303 Metetra
.658 .746 .915 r
.09695 .33303 .10342 .33909 .11217 .33586 .10572 .32978 Metetra
.658 .746 .915 r
.10572 .32978 .11217 .33586 .12095 .3326 .11451 .3265 Metetra
.658 .747 .915 r
.11451 .3265 .12095 .3326 .12976 .32933 .12334 .32322 Metetra
.658 .747 .916 r
.12334 .32322 .12976 .32933 .1386 .32603 .13219 .31992 Metetra
.658 .748 .916 r
.13219 .31992 .1386 .32603 .14747 .32272 .14108 .31661 Metetra
.658 .748 .917 r
.14108 .31661 .14747 .32272 .15638 .31942 .15 .31329 Metetra
.657 .748 .917 r
.15 .31329 .15638 .31942 .16531 .31613 .15895 .30997 Metetra
.657 .748 .917 r
.15895 .30997 .16531 .31613 .17426 .31286 .16793 .30665 Metetra
.657 .747 .916 r
.16793 .30665 .17426 .31286 .18325 .30959 .17694 .30332 Metetra
.657 .745 .915 r
.17694 .30332 .18325 .30959 .19227 .3063 .18598 .29998 Metetra
.657 .744 .915 r
.18598 .29998 .19227 .3063 .20132 .303 .19505 .29662 Metetra
.657 .743 .913 r
.19505 .29662 .20132 .303 .21041 .29965 .20416 .29324 Metetra
.658 .743 .913 r
.20416 .29324 .21041 .29965 .21954 .29621 .2133 .28983 Metetra
.66 .745 .913 r
.2133 .28983 .21954 .29621 .22871 .29265 .22248 .28635 Metetra
.663 .75 .915 r
.22248 .28635 .22871 .29265 .23792 .28894 .23169 .28282 Metetra
.664 .757 .92 r
.23169 .28282 .23792 .28894 .24717 .28519 .24094 .27926 Metetra
.664 .765 .925 r
.24094 .27926 .24717 .28519 .25645 .28143 .25022 .27569 Metetra
.663 .773 .931 r
.25022 .27569 .25645 .28143 .26576 .27769 .25953 .27212 Metetra
.661 .78 .937 r
.25953 .27212 .26576 .27769 .27508 .27404 .26887 .26858 Metetra
.658 .783 .941 r
.26887 .26858 .27508 .27404 .28443 .27057 .27824 .26509 Metetra
.653 .782 .943 r
.27824 .26509 .28443 .27057 .29379 .26738 .28763 .2617 Metetra
.648 .774 .94 r
.28763 .2617 .29379 .26738 .30316 .26445 .29705 .2584 Metetra
.646 .76 .932 r
.29705 .2584 .30316 .26445 .31256 .26165 .30651 .25513 Metetra
.645 .744 .921 r
.30651 .25513 .31256 .26165 .322 .25887 .31599 .25187 Metetra
.646 .728 .909 r
.31599 .25187 .322 .25887 .33147 .25604 .32551 .24858 Metetra
.647 .715 .897 r
.32551 .24858 .33147 .25604 .341 .25306 .33508 .24523 Metetra
.649 .705 .887 r
.33508 .24523 .341 .25306 .35057 .24983 .34468 .24177 Metetra
.654 .7 .88 r
.34468 .24177 .35057 .24983 .3602 .24621 .35433 .23817 Metetra
.659 .703 .88 r
.35433 .23817 .3602 .24621 .36989 .24221 .36402 .23441 Metetra
.663 .713 .885 r
.36402 .23441 .36989 .24221 .37961 .238 .37374 .23057 Metetra
.666 .726 .894 r
.37374 .23057 .37961 .238 .38938 .23367 .3835 .22668 Metetra
.668 .742 .906 r
.3835 .22668 .38938 .23367 .39917 .22936 .3933 .22279 Metetra
.668 .757 .917 r
.3933 .22279 .39917 .22936 .40899 .22512 .40313 .21891 Metetra
.666 .77 .928 r
.40313 .21891 .40899 .22512 .41883 .22101 .41299 .21508 Metetra
.661 .78 .937 r
.41299 .21508 .41883 .22101 .42871 .21717 .42288 .21133 Metetra
.656 .783 .941 r
.42288 .21133 .42871 .21717 .4386 .21357 .43281 .20767 Metetra
.654 .78 .941 r
.43281 .20767 .4386 .21357 .44854 .21011 .44277 .20404 Metetra
.653 .775 .938 r
.44277 .20404 .44854 .21011 .4585 .20671 .45277 .20044 Metetra
.653 .768 .933 r
.45277 .20044 .4585 .20671 .46851 .20329 .4628 .19681 Metetra
.654 .762 .929 r
.4628 .19681 .46851 .20329 .47856 .19985 .47287 .19317 Metetra
.654 .756 .924 r
.47287 .19317 .47856 .19985 .48864 .19636 .48299 .1895 Metetra
.655 .751 .92 r
.48299 .1895 .48864 .19636 .49877 .19277 .49314 .18578 Metetra
.656 .748 .917 r
.49314 .18578 .49877 .19277 .50893 .18909 .50332 .18203 Metetra
.657 .746 .916 r
.50332 .18203 .50893 .18909 .51913 .18534 .51355 .17824 Metetra
.657 .745 .915 r
.51355 .17824 .51913 .18534 .52937 .18158 .52382 .17443 Metetra
.657 .745 .915 r
.52382 .17443 .52937 .18158 .53965 .17782 .53412 .17062 Metetra
.657 .744 .914 r
.53412 .17062 .53965 .17782 .54997 .17404 .54446 .16679 Metetra
.657 .743 .913 r
.54446 .16679 .54997 .17404 .56033 .17023 .55484 .16294 Metetra
.657 .743 .913 r
.55484 .16294 .56033 .17023 .57072 .16639 .56526 .15907 Metetra
.658 .743 .913 r
.56526 .15907 .57072 .16639 .58115 .16252 .57572 .15518 Metetra
.658 .743 .913 r
.57572 .15518 .58115 .16252 .59163 .15862 .58622 .15127 Metetra
.658 .744 .913 r
.58622 .15127 .59163 .15862 .60214 .1547 .59676 .14734 Metetra
.658 .745 .914 r
.59676 .14734 .60214 .1547 .61269 .15074 .60734 .14339 Metetra
.658 .746 .915 r
.60734 .14339 .61269 .15074 .62328 .14676 .61796 .13942 Metetra
.658 .747 .916 r
.61796 .13942 .62328 .14676 .63391 .14277 .62862 .13544 Metetra
.658 .748 .917 r
.62862 .13544 .63391 .14277 .64458 .13878 .63932 .13145 Metetra
.658 .749 .917 r
.63932 .13145 .64458 .13878 .6553 .13479 .65006 .12745 Metetra
.658 .75 .918 r
.65006 .12745 .6553 .13479 .66605 .13079 .66084 .12343 Metetra
.658 .75 .918 r
.66084 .12343 .66605 .13079 .67684 .12679 .67166 .11941 Metetra
.658 .75 .918 r
.67166 .11941 .67684 .12679 .68768 .12277 .68253 .11536 Metetra
.658 .75 .918 r
.68253 .11536 .68768 .12277 .69856 .11874 .69343 .11131 Metetra
.658 .751 .918 r
.69343 .11131 .69856 .11874 .70948 .1147 .70438 .10724 Metetra
.658 .75 .918 r
.02981 .3496 .03644 .35547 .045 .35229 .03838 .3464 Metetra
.658 .749 .917 r
.03838 .3464 .045 .35229 .05358 .34911 .04698 .34318 Metetra
.658 .749 .917 r
.04698 .34318 .05358 .34911 .0622 .34592 .05561 .33996 Metetra
.658 .748 .917 r
.05561 .33996 .0622 .34592 .07084 .34272 .06427 .33672 Metetra
.658 .748 .916 r
.06427 .33672 .07084 .34272 .07951 .3395 .07297 .33347 Metetra
.658 .747 .916 r
.07297 .33347 .07951 .3395 .08822 .33627 .08169 .33021 Metetra
.658 .747 .916 r
.08169 .33021 .08822 .33627 .09695 .33303 .09044 .32694 Metetra
.658 .747 .916 r
.09044 .32694 .09695 .33303 .10572 .32978 .09922 .32366 Metetra
.657 .747 .916 r
.09922 .32366 .10572 .32978 .11451 .3265 .10803 .32038 Metetra
.657 .747 .916 r
.10803 .32038 .11451 .3265 .12334 .32322 .11687 .31708 Metetra
.657 .747 .916 r
.11687 .31708 .12334 .32322 .13219 .31992 .12574 .31377 Metetra
.657 .748 .916 r
.12574 .31377 .13219 .31992 .14108 .31661 .13465 .31045 Metetra
.658 .748 .917 r
.13465 .31045 .14108 .31661 .15 .31329 .14358 .30712 Metetra
.658 .748 .917 r
.14358 .30712 .15 .31329 .15895 .30997 .15255 .30377 Metetra
.658 .748 .917 r
.15255 .30377 .15895 .30997 .16793 .30665 .16155 .3004 Metetra
.658 .747 .916 r
.16155 .3004 .16793 .30665 .17694 .30332 .17058 .29702 Metetra
.658 .746 .915 r
.17058 .29702 .17694 .30332 .18598 .29998 .17964 .29363 Metetra
.658 .745 .914 r
.17964 .29363 .18598 .29998 .19505 .29662 .18874 .29022 Metetra
.658 .744 .914 r
.18874 .29022 .19505 .29662 .20416 .29324 .19786 .28681 Metetra
.657 .744 .914 r
.19786 .28681 .20416 .29324 .2133 .28983 .20702 .28341 Metetra
.656 .744 .915 r
.20702 .28341 .2133 .28983 .22248 .28635 .21621 .28002 Metetra
.655 .748 .918 r
.21621 .28002 .22248 .28635 .23169 .28282 .22542 .27664 Metetra
.655 .754 .923 r
.22542 .27664 .23169 .28282 .24094 .27926 .23467 .27325 Metetra
.655 .761 .928 r
.23467 .27325 .24094 .27926 .25022 .27569 .24396 .26985 Metetra
.655 .768 .933 r
.24396 .26985 .25022 .27569 .25953 .27212 .25327 .26644 Metetra
.656 .775 .937 r
.25327 .26644 .25953 .27212 .26887 .26858 .26263 .26299 Metetra
.658 .78 .939 r
.26263 .26299 .26887 .26858 .27824 .26509 .27202 .25948 Metetra
.66 .781 .938 r
.27202 .25948 .27824 .26509 .28763 .2617 .28144 .25591 Metetra
.663 .776 .933 r
.28144 .25591 .28763 .2617 .29705 .2584 .29091 .25226 Metetra
.664 .764 .924 r
.29091 .25226 .29705 .2584 .30651 .25513 .30041 .24858 Metetra
.664 .75 .914 r
.30041 .24858 .30651 .25513 .31599 .25187 .30995 .24487 Metetra
.663 .736 .904 r
.30995 .24487 .31599 .25187 .32551 .24858 .31952 .24116 Metetra
.66 .722 .895 r
.31952 .24116 .32551 .24858 .33508 .24523 .32912 .23747 Metetra
.657 .711 .888 r
.32912 .23747 .33508 .24523 .34468 .24177 .33875 .23381 Metetra
.653 .704 .884 r
.33875 .23381 .34468 .24177 .35433 .23817 .34841 .23021 Metetra
.65 .704 .886 r
.34841 .23021 .35433 .23817 .36402 .23441 .3581 .22668 Metetra
.65 .711 .893 r
.3581 .22668 .36402 .23441 .37374 .23057 .36783 .22318 Metetra
.65 .723 .902 r
.36783 .22318 .37374 .23057 .3835 .22668 .37759 .21968 Metetra
.651 .737 .912 r
.37759 .21968 .3835 .22668 .3933 .22279 .38739 .21616 Metetra
.652 .751 .922 r
.38739 .21616 .3933 .22279 .40313 .21891 .39723 .21262 Metetra
.654 .765 .931 r
.39723 .21262 .40313 .21891 .41299 .21508 .4071 .20903 Metetra
.656 .775 .937 r
.4071 .20903 .41299 .21508 .42288 .21133 .41702 .20537 Metetra
.658 .78 .939 r
.41702 .20537 .42288 .21133 .43281 .20767 .42697 .20164 Metetra
.66 .779 .937 r
.42697 .20164 .43281 .20767 .44277 .20404 .43696 .19786 Metetra
.661 .775 .934 r
.43696 .19786 .44277 .20404 .45277 .20044 .44699 .19406 Metetra
.661 .769 .93 r
.44699 .19406 .45277 .20044 .4628 .19681 .45705 .19025 Metetra
.66 .763 .926 r
.45705 .19025 .4628 .19681 .47287 .19317 .46715 .18642 Metetra
.66 .757 .922 r
.46715 .18642 .47287 .19317 .48299 .1895 .47729 .18259 Metetra
.659 .752 .919 r
.47729 .18259 .48299 .1895 .49314 .18578 .48747 .17876 Metetra
.658 .748 .917 r
.48747 .17876 .49314 .18578 .50332 .18203 .49768 .17493 Metetra
.658 .747 .916 r
.49768 .17493 .50332 .18203 .51355 .17824 .50793 .17109 Metetra
.658 .746 .915 r
.50793 .17109 .51355 .17824 .52382 .17443 .51822 .16725 Metetra
.658 .746 .915 r
.51822 .16725 .52382 .17443 .53412 .17062 .52855 .16338 Metetra
.658 .745 .914 r
.52855 .16338 .53412 .17062 .54446 .16679 .53892 .15951 Metetra
.658 .744 .914 r
.53892 .15951 .54446 .16679 .55484 .16294 .54932 .15562 Metetra
.657 .743 .913 r
.54932 .15562 .55484 .16294 .56526 .15907 .55977 .15172 Metetra
.657 .743 .913 r
.55977 .15172 .56526 .15907 .57572 .15518 .57025 .14781 Metetra
.657 .744 .914 r
.57025 .14781 .57572 .15518 .58622 .15127 .58078 .14388 Metetra
.657 .744 .914 r
.58078 .14388 .58622 .15127 .59676 .14734 .59134 .13995 Metetra
.657 .745 .914 r
.59134 .13995 .59676 .14734 .60734 .14339 .60195 .136 Metetra
.657 .746 .915 r
.60195 .136 .60734 .14339 .61796 .13942 .6126 .13204 Metetra
.657 .747 .916 r
.6126 .13204 .61796 .13942 .62862 .13544 .62328 .12806 Metetra
.657 .748 .917 r
.62328 .12806 .62862 .13544 .63932 .13145 .63401 .12406 Metetra
.657 .749 .917 r
.63401 .12406 .63932 .13145 .65006 .12745 .64478 .12005 Metetra
.658 .749 .918 r
.64478 .12005 .65006 .12745 .66084 .12343 .65559 .11602 Metetra
.658 .75 .918 r
.65559 .11602 .66084 .12343 .67166 .11941 .66644 .11197 Metetra
.658 .75 .918 r
.66644 .11197 .67166 .11941 .68253 .11536 .67734 .10791 Metetra
.658 .75 .918 r
.67734 .10791 .68253 .11536 .69343 .11131 .68828 .10382 Metetra
.658 .75 .918 r
.68828 .10382 .69343 .11131 .70438 .10724 .69925 .09973 Metetra
.658 .75 .918 r
.02313 .3437 .02981 .3496 .03838 .3464 .03172 .34047 Metetra
.658 .749 .917 r
.03172 .34047 .03838 .3464 .04698 .34318 .04034 .33722 Metetra
.658 .749 .917 r
.04034 .33722 .04698 .34318 .05561 .33996 .04898 .33396 Metetra
.658 .749 .917 r
.04898 .33396 .05561 .33996 .06427 .33672 .05766 .33069 Metetra
.658 .748 .916 r
.05766 .33069 .06427 .33672 .07297 .33347 .06637 .32741 Metetra
.658 .748 .916 r
.06637 .32741 .07297 .33347 .08169 .33021 .07511 .32412 Metetra
.658 .747 .916 r
.07511 .32412 .08169 .33021 .09044 .32694 .08388 .32082 Metetra
.658 .747 .916 r
.08388 .32082 .09044 .32694 .09922 .32366 .09268 .31753 Metetra
.657 .747 .916 r
.09268 .31753 .09922 .32366 .10803 .32038 .10151 .31422 Metetra
.657 .747 .916 r
.10151 .31422 .10803 .32038 .11687 .31708 .11036 .31091 Metetra
.657 .747 .917 r
.11036 .31091 .11687 .31708 .12574 .31377 .11925 .30759 Metetra
.657 .748 .917 r
.11925 .30759 .12574 .31377 .13465 .31045 .12817 .30426 Metetra
.657 .748 .917 r
.12817 .30426 .13465 .31045 .14358 .30712 .13712 .30091 Metetra
.658 .749 .917 r
.13712 .30091 .14358 .30712 .15255 .30377 .14611 .29754 Metetra
.659 .749 .916 r
.14611 .29754 .15255 .30377 .16155 .3004 .15513 .29412 Metetra
.659 .748 .916 r
.15513 .29412 .16155 .3004 .17058 .29702 .16418 .2907 Metetra
.659 .747 .915 r
.16418 .2907 .17058 .29702 .17964 .29363 .17326 .28726 Metetra
.659 .746 .914 r
.17326 .28726 .17964 .29363 .18874 .29022 .18238 .28381 Metetra
.658 .745 .914 r
.18238 .28381 .18874 .29022 .19786 .28681 .19152 .28037 Metetra
.656 .744 .915 r
.19152 .28037 .19786 .28681 .20702 .28341 .2007 .27697 Metetra
.652 .744 .917 r
.2007 .27697 .20702 .28341 .21621 .28002 .20989 .27364 Metetra
.648 .746 .921 r
.20989 .27364 .21621 .28002 .22542 .27664 .21911 .27038 Metetra
.647 .751 .925 r
.21911 .27038 .22542 .27664 .23467 .27325 .22837 .26713 Metetra
.647 .756 .929 r
.22837 .26713 .23467 .27325 .24396 .26985 .23766 .26387 Metetra
.648 .762 .933 r
.23766 .26387 .24396 .26985 .25327 .26644 .24698 .26058 Metetra
.652 .769 .935 r
.24698 .26058 .25327 .26644 .26263 .26299 .25635 .25719 Metetra
.658 .774 .935 r
.25635 .25719 .26263 .26299 .27202 .25948 .26576 .25367 Metetra
.667 .777 .932 r
.26576 .25367 .27202 .25948 .28144 .25591 .27522 .24995 Metetra
.675 .774 .925 r
.27522 .24995 .28144 .25591 .29091 .25226 .28473 .24602 Metetra
.678 .766 .917 r
.28473 .24602 .29091 .25226 .30041 .24858 .29428 .24199 Metetra
.678 .755 .909 r
.29428 .24199 .30041 .24858 .30995 .24487 .30386 .23791 Metetra
.676 .743 .901 r
.30386 .23791 .30995 .24487 .31952 .24116 .31347 .23386 Metetra
.671 .73 .895 r
.31347 .23386 .31952 .24116 .32912 .23747 .32311 .22988 Metetra
.664 .72 .891 r
.32311 .22988 .32912 .23747 .33875 .23381 .33277 .22605 Metetra
.653 .712 .891 r
.33277 .22605 .33875 .23381 .34841 .23021 .34244 .22246 Metetra
.643 .709 .895 r
.34244 .22246 .34841 .23021 .3581 .22668 .35214 .2191 Metetra
.638 .713 .902 r
.35214 .2191 .3581 .22668 .36783 .22318 .36187 .21587 Metetra
.636 .722 .91 r
.36187 .21587 .36783 .22318 .37759 .21968 .37164 .21268 Metetra
.637 .734 .918 r
.37164 .21268 .37759 .21968 .38739 .21616 .38144 .20947 Metetra
.639 .746 .926 r
.38144 .20947 .38739 .21616 .39723 .21262 .39129 .20618 Metetra
.643 .758 .932 r
.39129 .20618 .39723 .21262 .4071 .20903 .40118 .20279 Metetra
.652 .769 .935 r
.40118 .20279 .4071 .20903 .41702 .20537 .41112 .19919 Metetra
.66 .775 .934 r
.41112 .19919 .41702 .20537 .42697 .20164 .42109 .19541 Metetra
.665 .775 .932 r
.42109 .19541 .42697 .20164 .43696 .19786 .43111 .19151 Metetra
.667 .772 .928 r
.43111 .19151 .43696 .19786 .44699 .19406 .44117 .18754 Metetra
.666 .767 .925 r
.44117 .18754 .44699 .19406 .45705 .19025 .45126 .18357 Metetra
.666 .762 .922 r
.45126 .18357 .45705 .19025 .46715 .18642 .46139 .17959 Metetra
.665 .757 .919 r
.46139 .17959 .46715 .18642 .47729 .18259 .47156 .17561 Metetra
.662 .752 .917 r
.47156 .17561 .47729 .18259 .48747 .17876 .48176 .17168 Metetra
.66 .749 .916 r
.48176 .17168 .48747 .17876 .49768 .17493 .492 .16779 Metetra
.658 .747 .916 r
.492 .16779 .49768 .17493 .50793 .17109 .50227 .16392 Metetra
.658 .747 .915 r
.50227 .16392 .50793 .17109 .51822 .16725 .51259 .16004 Metetra
.659 .747 .915 r
.51259 .16004 .51822 .16725 .52855 .16338 .52294 .15612 Metetra
.658 .746 .915 r
.52294 .15612 .52855 .16338 .53892 .15951 .53333 .1522 Metetra
.658 .745 .914 r
.53333 .1522 .53892 .15951 .54932 .15562 .54377 .14828 Metetra
.658 .745 .914 r
.54377 .14828 .54932 .15562 .55977 .15172 .55424 .14435 Metetra
.657 .744 .914 r
.55424 .14435 .55977 .15172 .57025 .14781 .56475 .14041 Metetra
.657 .744 .914 r
.56475 .14041 .57025 .14781 .58078 .14388 .5753 .13647 Metetra
.656 .745 .915 r
.5753 .13647 .58078 .14388 .59134 .13995 .58589 .13252 Metetra
.656 .745 .915 r
.58589 .13252 .59134 .13995 .60195 .136 .59652 .12857 Metetra
.656 .746 .916 r
.59652 .12857 .60195 .136 .6126 .13204 .6072 .12461 Metetra
.656 .747 .917 r
.6072 .12461 .6126 .13204 .62328 .12806 .61791 .12063 Metetra
.657 .748 .917 r
.61791 .12063 .62328 .12806 .63401 .12406 .62867 .11663 Metetra
.657 .749 .918 r
.62867 .11663 .63401 .12406 .64478 .12005 .63947 .1126 Metetra
.657 .749 .918 r
.63947 .1126 .64478 .12005 .65559 .11602 .65031 .10855 Metetra
.657 .75 .918 r
.65031 .10855 .65559 .11602 .66644 .11197 .66119 .10447 Metetra
.657 .75 .918 r
.66119 .10447 .66644 .11197 .67734 .10791 .67211 .10039 Metetra
.658 .75 .918 r
.67211 .10039 .67734 .10791 .68828 .10382 .68308 .09628 Metetra
.658 .75 .918 r
.68308 .09628 .68828 .10382 .69925 .09973 .69409 .09215 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],

Cell["\<\
The assumption of separability of a two\[Hyphen]dimensional wavelet \
into a product of two one\[Hyphen]dimensional wavelets makes it possible to \
do two\[Hyphen]dimensional wavelet transforms without any added difficulty. \
If we define the inner product \
\>", "Text",
  CellTags->{"S1.5.4", "4.20"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_\(k  l\)\%j\), "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\),
         \(2\^j\), "\[Phi]", \((\(2\^j\) x - k, \(2\^j\) y - l)\), "f", \((x, 
        y)\), 
        RowBox[{
          StyleBox[\("dx"\),
            "TI"], " ", 
          StyleBox[\("dy"\),
            "TI"]}]}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.4", "4.21"}],

Cell[TextData[{
  "and similarly, letting ",
  Cell[BoxData[
      \(TraditionalForm\`S = I, I  I\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`I  I  I\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", "
}], "Text",
  CellTags->{"S1.5.4", "4.22"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(d\_\(k  l\)\%\(\((S)\) j\)\), "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(2\^j\), 
        \(\[Psi]\^\((S)\)\), \((\(2\^j\) x - k, \(2\^j\) y - l)\), "f", \((x, 
        y)\), 
        RowBox[{
          StyleBox[\("dx"\),
            "TI"], " ", 
          StyleBox[\("dy"\),
            "TI"]}], ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.4", "4.23"}],

Cell["the wavelet decomposition formulas are given by ", "Text",
  CellTags->{"S1.5.4", "4.24"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_\(k  l\)\%j\), "=", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], \(h\_\(m - 2  k, n - 2  l\)\), 
        \(f\_\(m, n\)\%\(j + 1\)\), \("and"\), \(d\_\(k  l\)\%\(\((S)\) j\)\),
         "=", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], \(g\_\(m - 2  k, n - 2  l\)\%\((S)\)\), 
        \(f\_\(m, n\)\%\(j + 1\)\), ","}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.5.4", "4.25"}],

Cell["and the reconstruction formula is ", "Text",
  CellTags->{"S1.5.4", "4.26"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_\(k  l\)\%\(j + 1\)\), "=", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], \(h\_\(m - 2  k, n - 2  l\)\), 
        \(f\_\(m, n\)\%j\), "+", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], \(g\_\(m - 2  k, n - 2  l\)\%\((I)\)\), 
        \(d\_\(m, n\)\%\(\((I)\) j\)\), "+", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], \(g\_\(m - 2  k, n - 2  l\)\%\((I  I)\)\),
         \(d\_\(m, n\)\%\(\((I  I)\) j\)\), "+", 
        UnderscriptBox["\[Sum]", \(n, m\),
          LimitsPositioning->True], 
        \(g\_\(m - 2  k, n - 2  l\)\%\((I  I  I)\)\), 
        \(d\_\(m, n\)\%\(\((I  I  I)\) j\)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.4", "4.27"}],

Cell[TextData[{
  "So after one decomposition, the original data matrix ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_\(k  l\)\%\(j + 1\)}\)], "InlineFormula",
    CellTags->"S1.5.4"],
  " of size ",
  Cell[BoxData[
      \(TraditionalForm\`N\[Cross]N\)], "InlineFormula",
    CellTags->"S1.5.4"],
  " becomes four matrices (",
  Cell[BoxData[
      \(TraditionalForm\`{f\_\(k  l\)\%j}\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(k  l\)\%\(\((I)\) j\)}\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(k  l\)\%\(\((I  I)\) j\)}\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(k  l\)\%\(\((I  I  I)\) j\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.4"],
  ") of size ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\[Cross]N/2\)], "InlineFormula",
    CellTags->"S1.5.4"],
  ", one representing the smooth part and the other three, the details. The \
wavelet transformation can be repeated, further decomposing the smooth part \
until the coarsest level is reached. "
}], "Text",
  CellTags->{"S1.5.4", "4.28"}],

Cell[TextData[{
  "1.5.5 ",
  StyleBox["Mathematica", "SBO"],
  " Functions for Doing Wavelet Transforms"
}], "Subsection",
  CellTags->{"S1.5.5", "5.1"}],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica", "TI"],
  " function for doing wavelet transforms is "
}], "Text",
  CellTags->{"S1.5.5", "5.2"}],

Cell[TextData[{
  StyleBox["WaveletTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.5", "5.3"}],

Cell[TextData[{
  "The argument ",
  StyleBox["filter", "TI"],
  " is the lowpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " used for the wavelet transformation. It has the form "
}], "Text",
  CellTags->{"S1.5.5", "5.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{h\_\(-m\), h\_\(-m + 1\), \[Ellipsis], h\_\(-m + L - 1\)}, -m}, 
    \)\)], "DisplayFormula",
  CellTags->{"S1.5.5", "5.5"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is the length of the filter and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " denotes the index of the first filter coefficient. We require that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " be nonnegative and ",
  Cell[BoxData[
      \(TraditionalForm\`L - 2 \[GreaterEqual] m\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". This, in general, can always be satisfied by an appropriate choice of \
the origin for the scaling function. Note that only the lowpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is needed since the highpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is calculated internally using the convention ",
  Cell[BoxData[
      \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) h\_\(1 - k\)\)], 
    "InlineFormula",
    CellTags->"S1.5.5"],
  ". \nThe argument ",
  StyleBox["data", "TI"],
  " is the input data at the finest level. It can be either a vector (for one\
\[Hyphen]dimensional data) or a matrix (for two\[Hyphen]dimensional data). It \
should be in standard ",
  StyleBox["Mathematica", "TI"],
  " format for a vector or a matrix, that is, ",
  StyleBox["data", "TI"],
  " has the form of a list ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.5"],
  " or that of a list of lists ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\(f  \[Null]\)\& \[RightVector] \)\_0, 
        \(\(f  \[Null]\)\& \[RightVector] \)\_1, \[Ellipsis], 
        \(\(f  \[Null]\)\& \[RightVector] \)\_\(N - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f  \[Null]\)\& \[RightVector] \)\_i\)], 
    "InlineFormula",
    CellTags->"S1.5.5"],
  " itself is a list ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\(f  \[Null]\)\& \[RightVector] \)\_i = {f\_\(i  0\), f\_\(i  1\), 
          \[Ellipsis], f\_\(i, M - 1\)}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". Since the algorithm effectively involves down sampling by 2, the data \
length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " (and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ") must be even in order to do any decomposition at all. \nTheoretically, \
the data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " should be the inner products of the continuous signal or function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " under consideration with the basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(J  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`J\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " corresponds to the finest level. However, in practice we do not always \
know the form of the signal ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " and, besides, the inner products are expensive to compute. So the inner \
products are rarely computed and approximations to those inner products are \
employed in practice. Often we are given a series of discrete sample points \
that are obtained from a measurement of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " at equally spaced time intervals ",
  Cell[BoxData[
      \(TraditionalForm\`{f \((k/2\^J)\)}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". Now the question is if we can use these function values at discrete \
points to approximate the inner products ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%J}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". By definition, "
}], "Text",
  CellTags->{"S1.5.5", "5.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_k\%j\), "=", \(2\^\(j/2\)\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "f", \((t)\), 
        "\[Phi]", \((\(2\^j\) t - k)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(2\^\(j/2\)\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "f", \((
        t + \(2\^\(-j\)\) k)\), "\[Phi]", \((\(2\^j\) t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.5", "5.7"}],

Cell[TextData[{
  "Now if ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is large, in general, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((\(2\^j\) t)\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is highly concentrated in a small region near ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", and if ",
  Cell[BoxData[
      \(TraditionalForm\`f\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is smooth, we can expand it around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ": "
}], "Text",
  CellTags->{"S1.5.5", "5.8"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(f\_k\%j\),
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(2\^\(j/2\)\), \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                \(\[InvisibleSpace]\([
                f \((k \[CapitalDelta])\) + \(f\^\[Prime]\) \((
                  k \[CapitalDelta])\) t + \(1\/2\) \(f\^\[Prime]\[Prime]\) 
                  \((k \[CapitalDelta])\) t\^2 + \[CenterEllipsis]]\)\), 
                "\[Phi]", \((\(2\^j\) t)\), " ", 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            
            StyleBox[
              \(\(2\^\(-j/2\)\) \(\[InvisibleSpace]\([
                f \((k \[CapitalDelta])\) + \(f\^\[Prime]\) \((
                  k \[CapitalDelta])\) \(M\_1\) \[CapitalDelta] + \(1\/2\) 
                  \(f\^\[Prime]\[Prime]\) \((k \[CapitalDelta])\) \(M\_2\) 
                  \[CapitalDelta]\^2 + \[CenterEllipsis]]\)\)\),
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.5.5", "5.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] = 2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", and "
}], "Text",
  CellTags->{"S1.5.5", "5.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(M\_i\), "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(x\^i\),
         "\[Phi]", \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"]}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.5", "5.11"}],

Cell[TextData[{
  "is the ",
  Cell[BoxData[
      \(TraditionalForm\`i\^th\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " moment of the scaling function and we have used ",
  Cell[BoxData[
      \(TraditionalForm\`M\_0 = 1\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". \nSo we see that to the leading order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\%j\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is simply "
}], "Text",
  CellTags->{"S1.5.5", "5.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`f\_k\%j = \(2\^\(-j/2\)\) \(\[InvisibleSpace]\([
      f \((k\/2\^j)\) + O \((2\^\(-j\))\)]\)\).\)], "DisplayFormula",
  CellTags->{"S1.5.5", "5.13"}],

Cell[TextData[{
  "Intuitively, this says that when ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is large, in the narrow region of order ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " the smooth function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " can be viewed as a constant and taken out of the integral sign. In so \
doing, the error made is the order of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". Therefore, in practice the first argument ",
  StyleBox["data", "TI"],
  " in ",
  StyleBox["WaveletTransform", "MR"],
  " is the sample points of a signal measured at dyadic points. Although \
there is a proportionality constant of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-j/2\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", it is often ignored. However, we should keep in mind the existence of \
such a constant and put it back in if needed. \nThe function ",
  StyleBox["WaveletTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " does the wavelet decomposition down to the lowest level. That is, it \
iterates the decomposition of the trend into a trend and details as many \
times as possible and stops when the length of the trend part becomes either \
odd or smaller than the filter length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". Sometimes we would like to be able to control how many times the \
decomposition is done. In that case, we can use "
}], "Text",
  CellTags->{"S1.5.5", "5.14"}],

Cell[TextData[{
  StyleBox["WaveletTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["l", "TI"],
  StyleBox["]", "MR"],
  ", "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.5", "5.15"}],

Cell[TextData[{
  "where the optional argument ",
  Cell[BoxData[
      \(TraditionalForm\`l\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is the number of times the wavelet decomposition is done. Since each \
decomposition subdivides the \"smooth\" or trend part into a trend and \
details of half of its length, the data length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " (and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ") should be divisible by ",
  Cell[BoxData[
      \(TraditionalForm\`2\^l\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " in order to do decomposition ",
  Cell[BoxData[
      \(TraditionalForm\`l\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " times. If ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is not divisible by ",
  Cell[BoxData[
      \(TraditionalForm\`2\^l\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", ",
  StyleBox["WaveletTransform", "MR"],
  " will do the maximum number of allowed decompositions and return the \
result along with a warning message. \nSince the data length is invariably \
finite, we have to address the issue of how to handle the data points at the \
boundary. For example, the boundary points are obtained using "
}], "Text",
  CellTags->{"S1.5.5", "5.16"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_0\%\(j - 1\)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = -m\), \(-m + L - 1\),
          LimitsPositioning->True], \(h\_k\), \(f\_k\%j\), \("and"\), 
        \(f\_\(N/2 - 1\)\%\(j - 1\)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = N - 2 - m\), \(N + L - m - 3\),
          LimitsPositioning->True], \(h\_\(k - N + 2\)\), \(f\_k\%j\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.5", "5.17"}],

Cell[TextData[{
  "So we need to pad the original data with ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " data points in the front and ",
  Cell[BoxData[
      \(TraditionalForm\`L - 2 - m\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " data points at the end. (The number of data points padded at the \
boundaries for inverse transforms can be worked out similarly.) Note that \
there are other ways of padding the boundaries and they can be done by \
changing the value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " in the filter. For example, if we want to pad symmetrically with ",
  Cell[BoxData[
      \(TraditionalForm\`L/2 - 1\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " sites padded at both boundaries (assuming ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " is even) we can simply set ",
  Cell[BoxData[
      \(TraditionalForm\`m = L/2 - 1\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". \nThe values of data points that are padded at the boundaries are \
determined by the choice of the boundary condition. There is an option ",
  StyleBox["BoundaryCondition", "MR"],
  "for the function ",
  StyleBox["WaveletTransform", "MR"],
  ". The default boundary condition is periodic, that is, we assume ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(i + N\) = f\_i\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". The advantage of employing periodic boundary conditions is that it \
guarantees perfect reconstruction for orthogonal wavelets. Other allowed \
boundary conditions include zero, fixed, and reflective boundary conditions. \
Zero boundary conditions set all padded values to zero; fixed boundary \
conditions extend the values at the boundaries ",
  Cell[BoxData[
      \(TraditionalForm\`f\_0\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(N - 1\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " to points beyond; and reflective boundary conditions assume ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(-i\) = f\_\(i - 1\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(N - 1 + i\) = f\_\(N - i\)\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`i > 0\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ". \nThe output of the function ",
  StyleBox["WaveletTransform", "MR"],
  " for one\[Hyphen]dimensional data is a list of lists, "
}], "Text",
  CellTags->{"S1.5.5", "5.18"}],

Cell[BoxData[
    \(TraditionalForm
    \`{{f\_k\%j}, {d\_k\%j}, {d\_k\%\(j + 1\)}, 
      \[Ellipsis], {d\_k\%\((J - 1)\)}}\)], "DisplayFormula",
  CellTags->{"S1.5.5", "5.19"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " refers to the coarsest level and ",
  Cell[BoxData[
      \(TraditionalForm\`J\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " the finest. For two\[Hyphen]dimensional data, the output is a bit more \
complicated. It is of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`{f\^j, {d\^\(\((I)\) j\), d\^\(\((I  I)\) j\), 
          d\^\(\((I  I  I)\) j\)}, 
        \[Ellipsis], {d\^\(\((I)\) \(J - 1\)\), d\^\(\((I  I)\) \(J - 1\)\), 
          d\^\(\((I  I  I)\) \(J - 1\)\)}}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f\^j = {f\_\(k  l\)\%j}\)], "InlineFormula",
    CellTags->"S1.5.5"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(\((S)\) j\) = {d\_\(k  l\)\%\(\((S)\) j\)}\)], 
    "InlineFormula",
    CellTags->"S1.5.5"],
  " are matrices. \nThe inverse transform is given by "
}], "Text",
  CellTags->{"S1.5.5", "5.20"}],

Cell[TextData[{
  StyleBox["InverseWaveletTransform[", "MR"],
  StyleBox["wtcoef", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.5", "5.21"}],

Cell[TextData[{
  "where ",
  StyleBox["wtcoef", "TI"],
  " is the output of ",
  StyleBox["WaveletTransform", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.5.5", "5.22"}],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["WaveletTransform", "MR"],
  ", we generate a set of random data of length 12."
}], "MathCaption",
  CellTags->{"S1.5.5", "5.23"}],

Cell["\<\
(SeedRandom[458476];
 data = Table[Random[], {12}];)\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.5.5"],

Cell[TextData[{
  "This gives the wavelet transform of ",
  StyleBox["data", "TI"],
  " using the Daubechies filter of order 2."
}], "MathCaption",
  CellTags->{"S1.5.5", "5.24"}],

Cell[CellGroupData[{

Cell["\<\
(h = DaubechiesFilter[2];
 WaveletTransform[data, h])\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.5.5"],

Cell[BoxData[
    \({{1.05087626542695278`, 0.48370672835919839`, 0.935487038505878309`}, {
        \(-0.233622758824279763`\), 0.460541883631316473`, 
        \(-0.139769012148602556`\)}, {0.110970698277624291`, 
        \(-0.225192904940352667`\), 0.128330626801872016`, 
        \(-0.253530443097793067`\), 0.00558050824865247108`, 
        \(-0.431581330303411991`\)}}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S1.5.5"]
}, Open  ]],

Cell["This does decomposition only once.", "MathCaption",
  CellTags->{"S1.5.5", "5.25"}],

Cell[CellGroupData[{

Cell["WaveletTransform[data, h, 1]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.5.5"],

Cell[BoxData[
    \({{0.462190193862622678`, 0.767617687220966793`, 0.872498116943641477`, 
        0.0775388860025383319`, 0.473539394675054747`, 
        0.839822260973913081`}, {0.110970698277624291`, 
        \(-0.225192904940352667`\), 0.128330626801872016`, 
        \(-0.253530443097793067`\), 0.00558050824865247108`, 
        \(-0.431581330303411991`\)}}\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"S1.5.5"]
}, Open  ]],

Cell[TextData[{
  StyleBox["InverseWaveletTransform", "MR"],
  " gives back the original data."
}], "MathCaption",
  CellTags->{"S1.5.5", "5.26"}],

Cell[CellGroupData[{

Cell["InverseWaveletTransform[%, h]==data", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S1.5.5"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"S1.5.5"]
}, Open  ]],

Cell["1.5.6 Wavelet Packets and Wavelet Packet Transforms", "Subsection",
  CellTags->{"S1.5.6", "6.1"}],

Cell[TextData[{
  "A wavelet decomposition or transform simply re\[Hyphen]expresses a \
function in terms of the wavelet basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". This amounts to decomposing the function space ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " into a direct sum of orthogonal subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{W\_j}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and choosing the combination of the orthonormal bases for ",
  Cell[BoxData[
      \(TraditionalForm\`W\)], "InlineFormula",
    CellTags->"S1.5.6"],
  "s as the orthonormal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". In the case of finite data with information up to a resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`J\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", a wavelet transform performs a decomposition of the space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_J\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " into a direct sum of orthogonal subspaces"
}], "Text",
  CellTags->{"S1.5.6", "6.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`V\_J = W\_\(J - 1\)\[CirclePlus]V\_\(J - 1\) = 
      W\_\(J - 1\)\[CirclePlus]W\_\(J - 2\)\[CirclePlus]V\_\(J - 2\) = 
      \[CenterEllipsis] = 
      \[CirclePlus]\_\(j = 0\)\%\(J - 1\)W\_j\[CirclePlus]V\_0\)], 
  "DisplayFormula",
  CellTags->{"S1.5.6", "6.3"}],

Cell[TextData[{
  "and the union of the bases of these subspaces forms a basis for the \
wavelet decomposition. This, of course, is by no means the only way to \
decompose the space ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`V\_J\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". In this section we generalize the wavelet decomposition and introduce a \
whole family of orthonormal bases for function space. \nFrom multiresolution \
analysis, we know that given the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(1  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " constitute an orthonormal basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`W\_0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", respectively, and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1 = V\_0\[CirclePlus]W\_0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", where "
}], "Text",
  CellTags->{"S1.5.6", "6.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  t - k)\), 
        \("and"\), "\[Psi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.6", "6.5"}],

Cell[TextData[{
  "So the ",
  Cell[BoxData[
      \(TraditionalForm\`V\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " space can be decomposed into a direct sum of the two orthogonal subspaces \
defined by their basis functions given by the above two equations. This \
\"splitting trick\" or splitting algorithm can be used to decompose ",
  Cell[BoxData[
      \(TraditionalForm\`W\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " spaces as well. For example, if we analogously define"
}], "Text",
  CellTags->{"S1.5.6", "6.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(w\_2\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Psi]", \((2  t - k)\), 
        \("and"\), \(w\_3\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Psi]", \((2  t - k)\), ","}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.6", "6.7"}],

Cell[TextData[{
  "then ",
  Cell[BoxData[
      \(TraditionalForm\`{\(w\_2\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(w\_3\) \((t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " are orthonormal basis functions for the two subspaces whose direct sum is \
",
  Cell[BoxData[
      \(TraditionalForm\`W\_1\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". In general, for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, \[Ellipsis]\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", we define a sequence of functions as follows: "
}], "Text",
  CellTags->{"S1.5.6", "6.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(w\_\(2  n\)\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), \(w\_n\), \((2  t - k)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.12) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.6", "6.9"}],

Cell["and ", "Text",
  CellTags->{"S1.5.6", "6.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(w\_\(2  n + 1\)\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), \(w\_n\), \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(5.13) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.5.6", "6.11"}],

Cell[TextData[{
  "Clearly, setting ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", we get ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_0\) \((t)\) = \[Phi] \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.6"],
  ", the scaling function, and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_1\) \((t)\) = \[Psi] \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.6"],
  ", the mother wavelet. So far we have been using the combination of ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((\(2\^j\) t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi] \((\(2\^j\) t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " to form a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_J\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", and now we have a whole sequence of functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " at our disposal. Various combinations of these and their dilations and \
translations can give rise to various bases for the function space. So we \
have a whole collection of orthonormal bases generated from ",
  Cell[BoxData[
      \(TraditionalForm\`{\(w\_n\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". We call this collection a \"library of wavelet packet bases\", and the \
function of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`w\_\(n, j, k\) = \(2\^\(j/2\)\) \(w\_n\) \((\(2\^j\) t - k)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.6"],
  " is called a wavelet packet. \nLet us call the space formed by the basis ",
  
  Cell[BoxData[
      \(TraditionalForm\`{\(w\_\(n, j, k\)\) \((t)\)}\_k\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[\("w"\),
            "TB"], \(n, j\)], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.6"],
  "; the following diagram illustrates the decomposition of the space ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[\("w"\),
            "TB"], \(0, 3\)], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.6"],
  " (",
  StyleBox["i.e.", "TI"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`V\_3\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ") using wavelet packets. "
}], "Text",
  CellTags->{"S1.5.6", "6.12"}],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000720001`QP00`40o`000?l0003o
oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?oo
ooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo
`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?o
ool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`ooo
o`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo
003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00
oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?oo
ooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo
`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?o
ool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`ooo
o`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool000[oooooo`00
[Ol000coool000Woooooo`00[ol000_oool000[oool1o`000Ooooc?oool2o`00=?oo
o`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o
000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooo
oc?oool2o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o
0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l0
03?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Oooo`_o
ool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l0
03Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:oooo
0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0
007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo
<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo<ooo
o`;o000coooo0_l003Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2o`00
=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<ooo
o`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`00
0Ooooc?oool2o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?oo
o`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolcoooo
0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooo
o`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo
0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:
oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo
0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o0001
oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo
<oooo`;o000coooo0_l003Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2
o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00
<oooo`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1
o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00
=?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolc
oooo0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`00
0Oooo`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000c
oooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo
000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000d
oooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o
0001oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001
oooo<oooo`;o000coooo0_l003Coool1o`000Oooo`_oool000[oool1o`000Ooooc?o
ool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2
o`00<oooo`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolMoooo0P0001Co
ool2o`007Oooo`80000Eoooo0Ol0007ooolMoooo0P0001Coool2o`007Oooo`80000D
oooo0_l001goool200005Oooo`7o0001oooo7Oooo`80000Doooo0_l001goool20000
5?ooo`;o000Noooo0P0001Coool1o`000Oooo`_oool000[oool1o`000Ooooagoool2
00005?ooo`;o000Moooo0P0001Goool1o`000Ooooagoool200005?ooo`;o000Moooo
0P0001Coool2o`007Oooo`80000Eoooo0Ol0007ooolMoooo0P0001Coool2o`007Ooo
o`80000Doooo0_l001koool200005?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo
4oooo`@00007oooo0P0000Woool400001_ooo`;o000Aoooo200000Goool200002_oo
o`@00006oooo0Ol0007oool@oooo1`0000Ooool200002Oooo`@00006oooo0_l001;o
ool400002?ooo`800009oooo100000Koool2o`004oooo`H00005oooo0P0000[oool4
00001_ooo`7o0001oooo4_ooo`D00007oooo0P0000Woool400001_ooo`;o000Coooo
0`0000Soool200002Oooo`@00006oooo0_l001?oool200002_ooo`800009oooo1000
00Koool1o`000Oooo`_oool000[oool1o`000Ooooa;oool600001_ooo`800008oooo
1P0000Goool2o`004Oooo`P00005oooo0P0000Woool600001Oooo`7o0001oooo4?oo
o`L00007oooo0P0000Soool600001Oooo`;o000@oooo1`0000Ooool200002?ooo`H0
0005oooo0_l001?oool600001Oooo`800009oooo1P0000Goool1o`000Ooooa3oool8
00001_ooo`800008oooo1P0000Goool2o`004_ooo`D00007oooo0P0000Soool60000
1Oooo`;o000Doooo0P0000Woool200002?ooo`H00005oooo0Ol0007oool;oooo000:
oooo0Ol0007ooolBoooo0P0000;oool200001_ooo`<00007oooo0P0000;oool20000
1Oooo`;o000Doooo0P0000Soool300002?ooo`800002oooo0P0000Goool1o`000Ooo
oa3oool300000_ooo`800007oooo0`0000Ooool200000_ooo`800005oooo0_l0013o
ool100000Oooo`?oool300001_ooo`<00007oooo0P0000;oool200001Oooo`;o000E
oooo0P0000Ooool300002?ooo`800002oooo0P0000Goool1o`000Ooooa7oool10000
0Oooo`?oool200001_ooo`<00007oooo0P0000;oool200001Oooo`;o000Boooo0P00
007oool100000P0000Koool300001oooo`800002oooo0P0000Goool2o`005?ooo`80
0009oooo0`0000Ooool200000_ooo`800005oooo0Ol0007oool;oooo000:oooo0Ol0
007ooolAoooo0P0000Coool200003_ooo`800004oooo0P0000Coool2o`005?ooo`80
000Boooo0P0000Coool200001?ooo`7o0001oooo4Oooo`<00001oooo0@0000400001
oooo3oooo`800004oooo0P0000Coool2o`005_ooo`80000?oooo0P0000Coool20000
1?ooo`;o000@oooo2@0000ooool200001?ooo`800004oooo0Ol0007ooolGoooo0P00
00koool200001?ooo`800004oooo0_l0017oool200000oooo`80000?oooo0P0000Co
ool200001?ooo`;o000Eoooo0@00007ooolAoooo0P0000Coool200001?ooo`7o0001
oooo2oooo`002_ooo`7o0001oooo4Oooo`800004oooo0P0000koool200001?ooo`80
0004oooo0_l001Coool200004_ooo`800004oooo0P0000Coool1o`000Ooooa;oool3
00004_ooo`800004oooo0P0000Coool2o`005_ooo`80000?oooo0P0000Coool20000
1?ooo`;o000@oooo2@0000ooool200001?ooo`800004oooo0Ol0007ooolGoooo0P00
00koool200001?ooo`800004oooo0_l0017oool200000oooo`80000?oooo0P0000Co
ool200001?ooo`;o000Eoooo0P00017oool200001?ooo`800004oooo0Ol0007oool;
oooo000:oooo0Ol0007ooolAoooo0P0000Coool200003_ooo`800004oooo0P0000Co
ool2o`005?ooo`80000Boooo0P0000Coool200001?ooo`7o0001oooo4oooo`<0000A
oooo0P0000Coool200001?ooo`;o000Coooo1000013oool200001?ooo`800004oooo
0_l0013oool200000oooo`80000Aoooo0P0000Coool200001?ooo`7o0001oooo4_oo
o`400001oooo0_ooo`<0000>oooo0P0000Coool200001?ooo`;o000Aoooo0P0000?o
ool200003oooo`800004oooo0P0000Coool2o`005Oooo`80000Aoooo0P0000Coool2
00001?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo4Oooo`800004oooo0P0000ko
ool200001?ooo`800004oooo0_l001Coool200004_ooo`800004oooo0P0000Coool1
o`000OoooaCoool200004Oooo`800004oooo0P0000Coool2o`004oooo`<0000Aoooo
0P0000Coool200001?ooo`;o000Aoooo0P0000;oool200004Oooo`800004oooo0P00
00Coool1o`000Ooooa7oool700003oooo`800004oooo0P0000Coool2o`004Oooo`H0
000@oooo0P0000Coool200001?ooo`;o000Foooo0@00007oool@oooo0P0000Coool2
00001?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo4Oooo`800004oooo0P0000ko
ool200001?ooo`800004oooo0_l001Coool200004_ooo`800004oooo0P0000Coool1
o`000OoooaGoool200004?ooo`800004oooo0P0000Coool2o`005Oooo`80000@oooo
0P0000Coool200001?ooo`;o000Boooo0@00007oool1oooo0@0000400001oooo4?oo
o`800004oooo0P0000Coool1o`000Ooooa7oool600004?ooo`800004oooo0P0000Co
ool2o`004Oooo`D0000Aoooo0P0000Coool200001?ooo`;o000Foooo0P00013oool2
00001?ooo`800004oooo0Ol0007oool;oooo000:oooo0Ol0007ooolAoooo0P0000Co
ool200003_ooo`800004oooo0P0000Coool2o`004Oooo`400001oooo0Oooo`400001
00000Ooooa7oool200001?ooo`800004oooo0Ol0007oool@oooo0P0000?oool20000
4?ooo`800004oooo0P0000Coool2o`005_ooo`80000?oooo0P0000Coool200001?oo
o`;o000Boooo0P00007oool100000@00007oool@oooo0P0000Coool200001?ooo`7o
0001oooo4Oooo`80000Doooo0P0000Coool200001?ooo`;o000Aoooo0P0001Coool2
00001?ooo`800004oooo0_l001Koool200004?ooo`800004oooo0P0000Coool1o`00
0Oooo`_oool000[oool1o`000Ooooa;oool200000_ooo`80000@oooo0P0000;oool2
00001Oooo`;o000Aoooo1@0001?oool200000_ooo`800005oooo0Ol0007oool@oooo
0P0000?oool200004Oooo`800002oooo0P0000Goool2o`004Oooo`400001oooo0ooo
o`80000@oooo0P0000;oool200001Oooo`;o000Coooo00<0003oool000000@00007o
oolAoooo0P0000;oool200001Oooo`7o0001oooo4Oooo`80000Eoooo0P0000;oool2
00001Oooo`;o000Boooo0P0001Coool200000_ooo`800005oooo0_l0017oool20000
1?ooo`80000@oooo0P0000;oool200001Oooo`7o0001oooo2oooo`002_ooo`7o0001
oooo4_ooo`H0000@oooo1P0000Goool2o`004_ooo`@0000Coooo1P0000Goool1o`00
0Ooooa3oool600004_ooo`H00005oooo0_l0017oool600004Oooo`H00005oooo0_l0
01?oool400004_ooo`H00005oooo0Ol0007ooolAoooo1`00013oool600001Oooo`;o
000Coooo1@00013oool600001Oooo`;o000Aoooo2000013oool600001Oooo`7o0001
oooo2oooo`002_ooo`7o0001oooo4oooo`@0000Boooo100000Koool2o`005?ooo`80
000Doooo100000Koool1o`000Ooooa;oool300005?ooo`@00006oooo0_l001;oool4
00004oooo`@00006oooo0_l001Coool300004oooo`@00006oooo0Ol0007ooolAoooo
1`00017oool400001_ooo`;o000Doooo1000017oool400001_ooo`;o000Aoooo2000
017oool400001_ooo`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo
0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l0
03Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo
<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0
007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2o`00
<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooo1Oooo`800002oooo0P0002Soool2o`001_ooo`800002oooo
0P0002Soool1o`000Oooo`Goool200000_ooo`80000Xoooo0_l000Koool200000_oo
o`80000Woooo0_l000Koool200000_ooo`80000Xoooo0Ol0007oool5oooo0P0000;o
ool20000:?ooo`;o0006oooo0P0000;oool200009oooo`;o0006oooo0P0000;oool2
0000:?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo1Oooo`800002oooo0`0002Oo
ool2o`001_ooo`800002oooo0`0002Ooool1o`000Oooo`Goool200000_ooo`<0000W
oooo0_l000Koool200000_ooo`<0000Voooo0_l000Koool200000_ooo`<0000Woooo
0Ol0007oool5oooo0P0000;oool300009oooo`;o0006oooo0P0000;oool300009_oo
o`;o0006oooo0P0000;oool300009oooo`7o0001oooo2oooo`002_ooo`7o0001oooo
1Oooo`<00001oooo0@000080000Woooo0_l000Koool300000Oooo`40000200009ooo
o`7o0001oooo1Oooo`<00001oooo0@000080000Woooo0_l000Koool300000Oooo`40
000200009_ooo`;o0006oooo0`00007oool100000P0002Ooool1o`000Oooo`Goool3
00000Oooo`40000200009oooo`;o0006oooo0`00007oool100000P0002Koool2o`00
1_ooo`<00001oooo0@000080000Woooo0Ol0007oool;oooo000:oooo0Ol0007oool5
oooo00D0003oool0003oool000000P0002Ooool2o`001_ooo`050000oooo0000oooo
00000080000Woooo0Ol0007oool5oooo00D0003oool0003oool000000P0002Ooool2
o`001_ooo`050000oooo0000oooo00000080000Voooo0_l000Koool01@000?ooo`00
0?ooo`00000200009oooo`7o0001oooo1Oooo`050000oooo0000oooo00000080000W
oooo0_l000Koool01@000?ooo`000?ooo`00000200009_ooo`;o0006oooo00D0003o
ool0003oool000000P0002Ooool1o`000Oooo`_oool000[oool1o`000Oooo`Coool2
00000Oooo`400002000000?oool0003oool09_ooo`;o0005oooo0P00007oool10000
0P000003oooo0000oooo02Koool1o`000Oooo`Coool200000Oooo`400002000000?o
ool0003oool09_ooo`;o0005oooo0P00007oool100000P000003oooo0000oooo02Go
ool2o`001Oooo`800001oooo0@00008000000oooo`000?ooo`0Voooo0Ol0007oool4
oooo0P00007oool100000P000003oooo0000oooo02Koool2o`001Oooo`800001oooo
0@00008000000oooo`000?ooo`0Uoooo0_l000Goool200000Oooo`400002000000?o
ool0003oool09_ooo`7o0001oooo2oooo`002_ooo`7o0001oooo1?ooo`800001oooo
0@0000800001oooo0@0000400001oooo9Oooo`;o0005oooo0P00007oool100000P00
007oool100000@00007ooolUoooo0Ol0007oool4oooo0P00007oool100000P00007o
ool100000@00007ooolUoooo0_l000Goool200000Oooo`40000200000Oooo`400001
00000OooobCoool2o`001Oooo`800001oooo0@0000800001oooo0@0000400001oooo
9Oooo`7o0001oooo1?ooo`800001oooo0@0000800001oooo0@0000400001oooo9Ooo
o`;o0005oooo0P00007oool100000P00007oool100000@00007ooolToooo0_l000Go
ool200000Oooo`40000200000Oooo`40000100000OooobGoool1o`000Oooo`_oool0
00[oool1o`000Oooo`Coool200000Oooo`40000100000Oooo`7oool100000@00007o
oolUoooo0_l000Goool200000Oooo`40000100000Oooo`7oool100000@00007ooolU
oooo0Ol0007oool4oooo0P00007oool100000@00007oool1oooo0@0000400001oooo
9Oooo`;o0005oooo0P00007oool100000@00007oool1oooo0@0000400001oooo9?oo
o`;o0005oooo0P00007oool100000@00007oool1oooo0@0000400001oooo9Oooo`7o
0001oooo1?ooo`800001oooo0@0000400001oooo0Oooo`40000100000OooobGoool2
o`001Oooo`800001oooo0@0000400001oooo0Oooo`40000100000OooobCoool2o`00
1Oooo`800001oooo0@0000400001oooo0Oooo`40000100000OooobGoool1o`000Ooo
o`_oool000[oool1o`000Oooo`?oool400000oooo`@0000Uoooo0_l000Coool40000
0oooo`@0000Uoooo0Ol0007oool3oooo100000?oool400009Oooo`;o0004oooo1000
00?oool400009?ooo`;o0004oooo100000?oool400009Oooo`7o0001oooo0oooo`@0
0003oooo100002Goool2o`001?ooo`@00003oooo100002Coool2o`001?ooo`@00003
oooo100002Goool1o`000Oooo`_oool000[oool1o`000Oooo`?oool400000oooo`@0
000Uoooo0_l000Coool400000oooo`@0000Uoooo0Ol0007oool3oooo100000?oool4
00009Oooo`;o0004oooo100000?oool400009?ooo`;o0004oooo100000?oool40000
9Oooo`7o0001oooo0oooo`@00003oooo100002Goool2o`001?ooo`@00003oooo1000
02Coool2o`001?ooo`@00003oooo100002Goool1o`000Oooo`_oool000[oool1o`00
0Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooo
oc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo
0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l0
03?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo
0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l0
03Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo
<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0
007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2o`00
<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00
=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Oooo`_oool000[oool1
o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`00
0Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007ooolc
oooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007ooolcoooo
0_l003?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o000d
oooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo
0_l003Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o0001
oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo
0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2
o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo
2oooo`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2
o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Oooo`_oool000[o
ool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1
o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:oooo0Ol0007o
oolcoooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007ooolc
oooo0_l003?oool2o`00=?ooo`7o0001oooo2oooo`002_ooo`7o0001oooo<oooo`;o
000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001oooo<oooo`;o000c
oooo0_l003Coool1o`000Oooo`_oool000[oool1o`000Ooooc?oool2o`00=?ooo`7o
0001oooo<oooo`;o000coooo0_l003Coool1o`000Ooooc?oool2o`00<oooo`;o000d
oooo0Ol0007oool;oooo000:oooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?o
ool2o`00<oooo`;o000doooo0Ol0007ooolcoooo0_l003?oool2o`00=?ooo`7o0001
oooo2oooo`002_ooo`7o0001oooo<oooo`;o000doooo0Ol0007ooolcoooo0_l003?o
ool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Coool1o`000Oooo`_oool0
00[oool1o`000Ooooc?oool2o`00=?ooo`7o0001oooo<oooo`;o000coooo0_l003Co
ool1o`000Ooooc?oool2o`00<oooo`;o000doooo0Ol0007oool;oooo000:ooooool0
0:go000<oooo0009ooooool00:oo000;oooo000:oooo0Ol0007oooldoooo0Ol0007o
oolcoooo0Ol0007ooolcoooo0Ol0007ooolcoooo0_l003Coool1o`000Ooooc?oool2
o`00=?ooo`7o0001oooo<oooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o
0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`000Ooo
ofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo
0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo2ooo
o`002_ooo`7o0001ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`00
0Oooo`_oool000[oool1o`000OooofWoool1o`000OooofSoool2o`00JOooo`;o001Y
oooo0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Wo
ool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o0001ooooJ?oo
o`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`000OooofWoool1o`00
0OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo0Ol0007ooomY
oooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o
0001ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool0
00[oool1o`000OooofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007o
ool;oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOoo
o`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo
0_l006Woool1o`000Oooo`_oool000[oool1o`000OooofWoool1o`000OooofSoool2
o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo0Ol0007o
oomXoooo0_l006Woool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOoo
o`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`00
0OooofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:
oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo
2oooo`002_ooo`7o0001oooo>?ooo`80000_oooo0Ol0007ooolgoooo0P0002ooool2
o`00>?ooo`80000_oooo0_l003Soool20000;oooo`7o0001oooo2oooo`002_ooo`7o
0001oooo>?ooo`80000_oooo0Ol0007ooolgoooo0P0002ooool2o`00>?ooo`80000_
oooo0_l003Soool20000;oooo`7o0001oooo2oooo`002_ooo`7o0001oooo;Oooo`@0
0008oooo0P0000Ooool800007oooo`7o0001oooo:oooo`P00005oooo0P0000Soool8
00007_ooo`;o000/oooo1`0000Koool200001oooo`P0000Ooooo0_l002goool40000
2?ooo`800007oooo200001ooool1o`000Oooo`_oool000[oool1o`000Oooobcoool6
00001oooo`800007oooo200001ooool1o`000Oooob_oool800001Oooo`800008oooo
200001koool2o`00;?ooo`L00006oooo0P0000Ooool800007oooo`;o000[oooo1`00
00Ooool200001oooo`P0000Ooooo0Ol0007oool;oooo000:oooo0Ol0007oool/oooo
0P0000;oool200001oooo`<00009oooo0P0002;oool1o`000Oooobkoool200002?oo
o`<0000:oooo0P00027oool2o`00;?ooo`<00002oooo0P0000Koool300002Oooo`80
000Roooo0_l002_oool100000Oooo`?oool300001_ooo`<00009oooo0P0002;oool1
o`000Oooo`_oool000[oool1o`000Oooob_oool200001?ooo`80000Boooo0P0002;o
ool1o`000Oooobkoool200005Oooo`80000Qoooo0_l002goool300000Oooo`400001
00000Ooooa7oool200008_ooo`;o000aoooo0P0001;oool200008_ooo`7o0001oooo
2oooo`002_ooo`7o0001oooo:oooo`800004oooo0P0001;oool200008_ooo`7o0001
oooo;_ooo`80000Eoooo0P00027oool2o`00;_ooo`<0000Doooo0P0002;oool2o`00
<Oooo`80000Boooo0P0002;oool1o`000Oooo`_oool000[oool1o`000Oooob_oool2
00001?ooo`80000Boooo0P0002;oool1o`000Oooobkoool200005Oooo`80000Qoooo
0_l002ooool300004oooo`80000Roooo0_l002koool400004oooo`80000Roooo0Ol0
007oool;oooo000:oooo0Ol0007oool[oooo0P0000Coool200004_ooo`80000Roooo
0Ol0007oool^oooo0P0001Goool200008Oooo`;o000`oooo0P0001?oool200008_oo
o`;o000^oooo0`0001Coool200008_ooo`7o0001oooo2oooo`002_ooo`7o0001oooo
:oooo`800004oooo0P0001;oool200008_ooo`7o0001oooo;_ooo`80000Eoooo0P00
027oool2o`00<Oooo`80000Boooo0P0002;oool2o`00<?ooo`80000Coooo0P0002;o
ool1o`000Oooo`_oool000[oool1o`000Oooob_oool200001?ooo`80000?oooo0@00
007oool1oooo0@0000400001oooo8Oooo`7o0001oooo:oooo`400001oooo0Oooo`40
000100000Ooooa7oool100000Oooo`7oool100000@00007ooolPoooo0_l002coool2
00000oooo`80000?oooo0@00007oool1oooo0@0000400001oooo8Oooo`;o000aoooo
0P0000ooool100000Oooo`7oool100000@00007ooolQoooo0Ol0007oool;oooo000:
oooo0Ol0007oool/oooo0P0000;oool200004?ooo`D0000Roooo0Ol0007oool[oooo
1@0001;oool500008Oooo`;o000/oooo0P0000?oool200003oooo`D0000Roooo0_l0
02coool100000Oooo`?oool200003oooo`D0000Roooo0Ol0007oool;oooo000:oooo
0Ol0007oool/oooo1P00017oool400008_ooo`7o0001oooo;?ooo`@0000Coooo1000
027oool2o`00;?ooo`H0000Aoooo100002;oool2o`00;?ooo`H0000Aoooo100002;o
ool1o`000Oooo`_oool000[oool1o`000Oooobgoool400005?ooo`80000Roooo0Ol0
007oool^oooo0P0001Goool200008Oooo`;o000^oooo0`0001Coool200008_ooo`;o
000]oooo100001Coool200008_ooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOoo
o`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`00
0OooofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:
oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo
2oooo`002_ooo`7o0001oooo8?ooo`800002oooo0P0004?oool1o`000Oooob3oool2
00000_ooo`800012oooo0_l0027oool200000_ooo`800012oooo0_l0023oool20000
0_ooo`800013oooo0Ol0007oool;oooo000:oooo0Ol0007ooolPoooo0P0000;oool3
0000@_ooo`7o0001oooo8?ooo`800002oooo0`00047oool2o`008Oooo`800002oooo
0`00047oool2o`008?ooo`800002oooo0`0004;oool1o`000Oooo`_oool000[oool1
o`000Oooob3oool300000Oooo`4000020000@_ooo`7o0001oooo8?ooo`<00001oooo
0@0000800011oooo0_l0027oool300000Oooo`4000020000@Oooo`;o000Poooo0`00
007oool100000P0004;oool1o`000Oooo`_oool000[oool1o`000Oooob3oool01@00
0?ooo`000?ooo`0000020000@_ooo`7o0001oooo8?ooo`050000oooo0000oooo0000
00800011oooo0_l0027oool01@000?ooo`000?ooo`0000020000@Oooo`;o000Poooo
00D0003oool0003oool000000P0004;oool1o`000Oooo`_oool000[oool1o`000Ooo
oaooool200000Oooo`400002000000?oool0003oool0@Oooo`7o0001oooo7oooo`80
0001oooo0@00008000000oooo`000?ooo`10oooo0_l0023oool200000Oooo`400002
000000?oool0003oool0@?ooo`;o000Ooooo0P00007oool100000P000003oooo0000
oooo047oool1o`000Oooo`_oool000[oool1o`000Ooooaooool200000Oooo`400002
00000Oooo`40000100000Ooood3oool1o`000Ooooaooool200000Oooo`4000020000
0Oooo`40000100000Oooocooool2o`008?ooo`800001oooo0@0000800001oooo0@00
00400001oooo?oooo`;o000Ooooo0P00007oool100000P00007oool100000@00007o
oom0oooo0Ol0007oool;oooo000:oooo0Ol0007ooolOoooo0P00007oool100000@00
007oool1oooo0@0000400001oooo@?ooo`7o0001oooo7oooo`800001oooo0@000040
0001oooo0Oooo`40000100000Oooocooool2o`008?ooo`800001oooo0@0000400001
oooo0Oooo`40000100000Oooocooool2o`007oooo`800001oooo0@0000400001oooo
0Oooo`40000100000Ooood3oool1o`000Oooo`_oool000[oool1o`000Ooooakoool4
00000oooo`@00010oooo0Ol0007ooolNoooo100000?oool40000?oooo`;o000Ooooo
100000?oool40000?oooo`;o000Noooo100000?oool40000@?ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooo7_ooo`@00003oooo1000043oool1o`000Ooooakoool40000
0oooo`@0000ooooo0_l001ooool400000oooo`@0000ooooo0_l001koool400000ooo
o`@00010oooo0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomXoooo
0_l006Woool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o0001
ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`000OooofWo
ool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo0Ol0
007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo2oooo`00
2_ooo`7o0001ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Ooo
o`_oool000[oool1o`000OooofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo
0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2
o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o0001ooooJ?ooo`;o
001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`000OooofWoool1o`000Ooo
ofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo
0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001
ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[o
ool1o`000OooofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;
oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o
0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o0001ooooJ?ooo`;o001Yoooo0_l0
06Woool1o`000Oooo`_oool000[oool1o`000OooofWoool1o`000OooofSoool2o`00
JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo0Ol0007ooomYoooo0Ol0007ooomX
oooo0_l006Woool2o`00JOooo`7o0001oooo2oooo`002_ooo`7o0001ooooJOooo`7o
0001ooooJ?ooo`;o001Yoooo0_l006Woool1o`000Oooo`_oool000[oool1o`000Ooo
ofWoool1o`000OooofSoool2o`00JOooo`;o001Yoooo0Ol0007oool;oooo000:oooo
0Ol0007ooomYoooo0Ol0007ooomXoooo0_l006Woool2o`00JOooo`7o0001oooo2ooo
o`002_oooooo002^o`002oooo`002Ooooooo002_o`002oooo`002_ooo`7o0001oooo
JOooo`7o0001ooooJ?ooo`;o001Yoooo0Ol0007ooomYoooo0Ol0007oool;oooo000:
oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1o`000Oooom?o
ool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0
007oool;oooo000:oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[o
ool1o`000Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodooo
o`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo0_l00=Coool1o`00
0Oooo`_oool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_oo
o`7o0001oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo
0_l00=Coool1o`000Oooo`_oool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001
oooo2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo
0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1o`000Oooom?oool2
o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007o
ool;oooo000:oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1
o`000Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o
003Doooo0Ol0007oool;oooo000:oooo0Ol0007ooom]oooo0P0006Coool2o`00K_oo
o`80001Toooo0Ol0007oool;oooo000:oooo0Ol0007ooom]oooo0P0006Coool2o`00
K_ooo`80001Toooo0Ol0007oool;oooo000:oooo0Ol0007ooomSoooo100000Ooool2
00002?ooo`L0001Doooo0_l006;oool800001Oooo`800007oooo1`0005Goool1o`00
0Oooo`_oool000[oool1o`000Oooof;oool600001_ooo`800008oooo1`0005Coool2
o`00H_ooo`P00005oooo0P0000Ooool70000EOooo`7o0001oooo2oooo`002_ooo`7o
0001ooooH_ooo`800002oooo0P0000Koool300001oooo`<00002oooo0P0005Coool2
o`00IOooo`800008oooo0`0000Koool300000_ooo`80001Eoooo0Ol0007oool;oooo
000:oooo0Ol0007ooomQoooo0P0000Coool200004?ooo`<00001oooo0@0000400001
ooooDoooo`;o001Uoooo0P0001;oool300000Oooo`40000100000OoooeCoool1o`00
0Oooo`_oool000[oool1o`000Oooof7oool200001?ooo`80000Aoooo0`0005Koool2
o`00IOooo`80000Coooo0`0005Ooool1o`000Oooo`_oool000[oool1o`000Oooof7o
ool200001?ooo`80000Boooo0`0005Goool2o`00IOooo`80000Doooo0`0005Koool1
o`000Oooo`_oool000[oool1o`000Oooof7oool200001?ooo`80000Coooo0P0005Go
ool2o`00IOooo`80000Eoooo0P0005Koool1o`000Oooo`_oool000[oool1o`000Ooo
of7oool200001?ooo`80000Doooo0P0005Coool2o`00IOooo`80000Foooo0P0005Go
ool1o`000Oooo`_oool000[oool1o`000Oooof7oool200001?ooo`80000?oooo0P00
00?oool20000E?ooo`;o001Roooo0@00007oool1oooo0@0000400001oooo4?ooo`80
0003oooo0P0005Goool1o`000Oooo`_oool000[oool1o`000Oooof;oool200000_oo
o`80000@oooo0P0000?oool20000E?ooo`;o001Roooo1@00017oool200000oooo`80
001Eoooo0Ol0007oool;oooo000:oooo0Ol0007ooomRoooo1P00013oool60000EOoo
o`;o001Soooo1000017oool60000E_ooo`7o0001oooo2oooo`002_ooo`7o0001oooo
Hoooo`@0000Coooo0`0005Koool2o`00IOooo`80000Coooo0`0005Ooool1o`000Ooo
o`_oool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o
0001oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo0_l0
0=Coool1o`000Oooo`_oool000[oool1o`000OoooeKoool200000_ooo`80001goooo
0_l005Koool200000_ooo`80001hoooo0Ol0007oool;oooo000:oooo0Ol0007ooomF
oooo0P0000;oool30000M_ooo`;o001Foooo0P0000;oool30000Moooo`7o0001oooo
2oooo`002_ooo`7o0001ooooE_ooo`<00001oooo0@000080001foooo0_l005Koool3
00000Oooo`4000020000Moooo`7o0001oooo2oooo`002_ooo`7o0001ooooE_ooo`05
0000oooo0000oooo00000080001foooo0_l005Koool01@000?ooo`000?ooo`000002
0000Moooo`7o0001oooo2oooo`002_ooo`7o0001ooooEOooo`800001oooo0@000080
00000oooo`000?ooo`1eoooo0_l005Goool200000Oooo`400002000000?oool0003o
ool0M_ooo`7o0001oooo2oooo`002_ooo`7o0001ooooEOooo`800001oooo0@000080
0001oooo0@0000400001ooooM?ooo`;o001Eoooo0P00007oool100000P00007oool1
00000@00007ooomeoooo0Ol0007oool;oooo000:oooo0Ol0007ooomEoooo0P00007o
ool100000@00007oool1oooo0@0000400001ooooM?ooo`;o001Eoooo0P00007oool1
00000@00007oool1oooo0@0000400001ooooMOooo`7o0001oooo2oooo`002_ooo`7o
0001ooooE?ooo`@00003oooo100007Coool2o`00E?ooo`@00003oooo100007Goool1
o`000Oooo`_oool000[oool1o`000OoooeCoool400000oooo`@0001doooo0_l005Co
ool400000oooo`@0001eoooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo0_l0
0=Coool1o`000Oooo`_oool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001oooo
2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0
007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1o`000Oooom?oool2o`00
e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007oool;
oooo000:oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1o`00
0Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o003D
oooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_o
ool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001oooo2oooo`002_ooo`7o0001
oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0007ooooCoooo0_l00=Co
ool1o`000Oooo`_oool000[oool1o`000Oooom?oool2o`00e?ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007oool;oooo000:oooo0Ol0007o
oooCoooo0_l00=Coool1o`000Oooo`_oool000[oool1o`000Oooom?oool2o`00e?oo
o`7o0001oooo2oooo`002_ooo`7o0001oooodoooo`;o003Doooo0Ol0007oool;oooo
000:oooo0Ol0007ooooCoooo0_l00=Coool1o`000Oooo`_oool000[oooooo`00[_l0
00_oool000Woooooo`00[ol000_oool000[oool1o`000OooomCoool1o`000Oooom?o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007oool;oooo000:
oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001oooooooooj[o
ool1o`000Oooo`_oool000[oool1o`000OooomSoool20000coooo`7o0001oooo2ooo
o`002_ooo`7o0001oooof?ooo`80003?oooo0Ol0007oool;oooo000:oooo0Ol0007o
ooo>oooo100000Ooool200002?ooo`@00032oooo0Ol0007oool;oooo000:oooo0Ol0
007oooo=oooo1P0000Koool200001_ooo`L00031oooo0Ol0007oool;oooo000:oooo
0Ol0007oooo=oooo0P0000;oool200001_ooo`<00005oooo0@00007oool3oooo0`00
0<3oool1o`000Oooo`_oool000[oool1o`000Oooolcoool200001?ooo`80000Coooo
0P000<3oool1o`000Oooo`_oool000[oool1o`000Oooolcoool200001?ooo`80000C
oooo0P000<3oool1o`000Oooo`_oool000[oool1o`000Oooolcoool200001?ooo`80
000@oooo10000<7oool1o`000Oooo`_oool000[oool1o`000Oooolcoool200001?oo
o`80000@oooo0`000<;oool1o`000Oooo`_oool000[oool1o`000Oooolcoool20000
1?ooo`80000Boooo0P000<7oool1o`000Oooo`_oool000[oool1o`000Oooolcoool2
00001?ooo`80000Coooo0P000<3oool1o`000Oooo`_oool000[oool1o`000Oooolgo
ool200000_ooo`80000?oooo0@00007oool3oooo0P000<3oool1o`000Oooo`_oool0
00[oool1o`000Oooolgoool600003oooo`H00031oooo0Ol0007oool;oooo000:oooo
0Ol0007oooo>oooo1000017oool40000`_ooo`7o0001oooo2oooo`002_ooo`7o0001
oooooooooj[oool1o`000Oooo`_oool000[oool1o`000OoooooooonZoooo0Ol0007o
ool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2oooo`002_ooo`7o0001
oooo`Oooo`800002oooo0P000>;oool1o`000Oooo`_oool000[oool1o`000Ooool7o
ool200000_ooo`<0003Qoooo0Ol0007oool;oooo000:oooo0Ol0007oooo1oooo0`00
007oool100000P000>7oool1o`000Oooo`_oool000[oool1o`000Ooool7oool01@00
0?ooo`000?ooo`0000020000hOooo`7o0001oooo2oooo`002_ooo`7o0001oooo`?oo
o`800001oooo0@00008000000oooo`000?ooo`3Poooo0Ol0007oool;oooo000:oooo
0Ol0007oooo0oooo0P00007oool100000P00007oool100000@00007ooooOoooo0Ol0
007oool;oooo000:oooo0Ol0007oooo0oooo0P00007oool100000@00007oool1oooo
0@0000400001oooogoooo`7o0001oooo2oooo`002_ooo`7o0001oooo_oooo`@00003
oooo10000=ooool1o`000Oooo`_oool000[oool1o`000Ooookooool400000oooo`@0
003Ooooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_ooo`7o0001oooooooooj[oool1o`000Oooo`_oool000[oool1o`000Ooooooo
oonZoooo0Ol0007oool;oooo000:oooo0Ol0007oooooooooZ_ooo`7o0001oooo2ooo
o`002_oooooo002^o`002oooo`002Ooooooo002_o`002oooo`002_ooo`7o0001oooo
oooooj[oool1o`000Oooo`_oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00
oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?oo
ooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo
`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?o
ool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`ooo
o`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo
003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool0
0?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00
oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003o
oooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?oo
ooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooo
ol?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo
`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?oool00?ooooo3
oooo003ooooo`oooo`00oooool?oool00?ooooo3oooo003ooooo`oooo`00oooool?o
ool00?ooooo3oooo003ooooo`oooo`000040\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{450, 450},
  ImageMargins->{{0, 0}, {0, 0}},
  CellTags->"S1.5.6"]], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.13"}],

Cell[TextData[{
  "As an example, we look at the wavelet packets generated from the Haar \
filter. Since the Haar filter has ",
  Cell[BoxData[
      \(TraditionalForm\`h\_0 = h\_1 = 1/\@2\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", and, using ",
  Cell[BoxData[
      \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) h\_\(1 - k\)\)], 
    "InlineFormula",
    CellTags->"S1.5.6"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`g\_0 = -g\_1 = 1/\@2\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", we have "
}], "Text",
  CellTags->{"S1.5.6", "6.14"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(w\_\(2  n\)\) \((t)\) = \(w\_n\) \((2  t)\) + \(w\_n\) \((2  t - 1)
      \)\)], "DisplayFormula",
  CellTags->{"S1.5.6", "6.15"}],

Cell["and ", "Text",
  CellTags->{"S1.5.6", "6.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(w\_\(2  n + 1\)\) \((t)\) = \(w\_n\) \((2  t)\) - \(w\_n\) \((
      2  t - 1)\)\)], "DisplayFormula",
  CellTags->{"S1.5.6", "6.17"}],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " the characteristic function on the unit interval. We can easily plot \
these functions using ",
  StyleBox["Mathematica", "TI"],
  ". "
}], "Text",
  CellTags->{"S1.5.6", "6.18"}],

Cell[TextData[{
  "We define ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " first."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.19"}],

Cell["\<\
(w[0, t_]:=1 /; t >= 0 && t < 1;
 w[0, t_]:=0 /; t < 0 || t >= 1;)\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S1.5.6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(w\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is defined recursively according to (",
  ButtonBox["5.12",
    ButtonData:>{"Wavelets 1.5.6", "6.9"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["5.13",
    ButtonData:>{"Wavelets 1.5.6", "6.11"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.20"}],

Cell["\<\
(w[n_?(#>0 && EvenQ[#]&), t_]:=
 w[n/2, 2t] + w[n/2, 2t-1];
 w[n_?OddQ, t_]:= w[(n-1)/2, 2t] - w[(n-1)/2, 2t-1];)\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S1.5.6"],

Cell[TextData[{
  "Here is the plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", the Haar wavelet."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.21"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[w[1, t]], {t, 0, 1.2}, AspectRatio -> 1/2,
AxesLabel -> {\"t\", \"w[1, t]\"}]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.25 0.238095 [
[.18254 .2375 -9 -9 ]
[.18254 .2375 9 0 ]
[.34127 .2375 -9 -9 ]
[.34127 .2375 9 0 ]
[.5 .2375 -9 -9 ]
[.5 .2375 9 0 ]
[.65873 .2375 -9 -9 ]
[.65873 .2375 9 0 ]
[.81746 .2375 -3 -9 ]
[.81746 .2375 3 0 ]
[.97619 .2375 -9 -9 ]
[.97619 .2375 9 0 ]
[1.025 .25 0 -4.5 ]
[1.025 .25 6 4.5 ]
[.01131 .0119 -12 -4.5 ]
[.01131 .0119 0 4.5 ]
[.01131 .13095 -24 -4.5 ]
[.01131 .13095 0 4.5 ]
[.01131 .36905 -18 -4.5 ]
[.01131 .36905 0 4.5 ]
[.01131 .4881 -6 -4.5 ]
[.01131 .4881 0 4.5 ]
[.02381 .525 -21 0 ]
[.02381 .525 21 9 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .25 m
.18254 .25625 L
s
[(0.2)] .18254 .2375 0 1 Mshowa
.34127 .25 m
.34127 .25625 L
s
[(0.4)] .34127 .2375 0 1 Mshowa
.5 .25 m
.5 .25625 L
s
[(0.6)] .5 .2375 0 1 Mshowa
.65873 .25 m
.65873 .25625 L
s
[(0.8)] .65873 .2375 0 1 Mshowa
.81746 .25 m
.81746 .25625 L
s
[(1)] .81746 .2375 0 1 Mshowa
.97619 .25 m
.97619 .25625 L
s
[(1.2)] .97619 .2375 0 1 Mshowa
.125 Mabswid
.06349 .25 m
.06349 .25375 L
s
.10317 .25 m
.10317 .25375 L
s
.14286 .25 m
.14286 .25375 L
s
.22222 .25 m
.22222 .25375 L
s
.2619 .25 m
.2619 .25375 L
s
.30159 .25 m
.30159 .25375 L
s
.38095 .25 m
.38095 .25375 L
s
.42063 .25 m
.42063 .25375 L
s
.46032 .25 m
.46032 .25375 L
s
.53968 .25 m
.53968 .25375 L
s
.57937 .25 m
.57937 .25375 L
s
.61905 .25 m
.61905 .25375 L
s
.69841 .25 m
.69841 .25375 L
s
.7381 .25 m
.7381 .25375 L
s
.77778 .25 m
.77778 .25375 L
s
.85714 .25 m
.85714 .25375 L
s
.89683 .25 m
.89683 .25375 L
s
.93651 .25 m
.93651 .25375 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
[(t)] 1.025 .25 -1 0 Mshowa
.02381 .0119 m
.03006 .0119 L
s
[(-1)] .01131 .0119 1 0 Mshowa
.02381 .13095 m
.03006 .13095 L
s
[(-0.5)] .01131 .13095 1 0 Mshowa
.02381 .36905 m
.03006 .36905 L
s
[(0.5)] .01131 .36905 1 0 Mshowa
.02381 .4881 m
.03006 .4881 L
s
[(1)] .01131 .4881 1 0 Mshowa
.125 Mabswid
.02381 .03571 m
.02756 .03571 L
s
.02381 .05952 m
.02756 .05952 L
s
.02381 .08333 m
.02756 .08333 L
s
.02381 .10714 m
.02756 .10714 L
s
.02381 .15476 m
.02756 .15476 L
s
.02381 .17857 m
.02756 .17857 L
s
.02381 .20238 m
.02756 .20238 L
s
.02381 .22619 m
.02756 .22619 L
s
.02381 .27381 m
.02756 .27381 L
s
.02381 .29762 m
.02756 .29762 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .34524 m
.02756 .34524 L
s
.02381 .39286 m
.02756 .39286 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44048 m
.02756 .44048 L
s
.02381 .46429 m
.02756 .46429 L
s
.25 Mabswid
.02381 0 m
.02381 .5 L
s
[(w[1, t])] .02381 .525 0 -1 Mshowa
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.02381 .4881 m
.06244 .4881 L
.10458 .4881 L
.14415 .4881 L
.18221 .4881 L
.22272 .4881 L
.26171 .4881 L
.30316 .4881 L
.34309 .4881 L
.3815 .4881 L
.40134 .4881 L
.41134 .4881 L
.41409 .4881 L
.41703 .4881 L
.41846 .4881 L
.41917 .4881 L
.41982 .4881 L
.42104 .0119 L
.42168 .0119 L
.42237 .0119 L
.46395 .0119 L
.50401 .0119 L
.54257 .0119 L
.58357 .0119 L
.62306 .0119 L
.66103 .0119 L
.70145 .0119 L
.74036 .0119 L
.76017 .0119 L
.78172 .0119 L
.79176 .0119 L
.80242 .0119 L
.81152 .0119 L
.81401 .0119 L
.81532 .0119 L
.81604 .0119 L
.8167 .0119 L
.81791 .25 L
.81856 .25 L
.81924 .25 L
.82157 .25 L
.86306 .25 L
.90305 .25 L
.94151 .25 L
.97619 .25 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_6\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.22"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[w[6, t]], {t, 0, 1.2}, AspectRatio -> 1/2,
AxesLabel -> {\"t\", \"w[6, t]\"}]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.25 0.238095 [
[.18254 .2375 -9 -9 ]
[.18254 .2375 9 0 ]
[.34127 .2375 -9 -9 ]
[.34127 .2375 9 0 ]
[.5 .2375 -9 -9 ]
[.5 .2375 9 0 ]
[.65873 .2375 -9 -9 ]
[.65873 .2375 9 0 ]
[.81746 .2375 -3 -9 ]
[.81746 .2375 3 0 ]
[.97619 .2375 -9 -9 ]
[.97619 .2375 9 0 ]
[1.025 .25 0 -4.5 ]
[1.025 .25 6 4.5 ]
[.01131 .0119 -12 -4.5 ]
[.01131 .0119 0 4.5 ]
[.01131 .13095 -24 -4.5 ]
[.01131 .13095 0 4.5 ]
[.01131 .36905 -18 -4.5 ]
[.01131 .36905 0 4.5 ]
[.01131 .4881 -6 -4.5 ]
[.01131 .4881 0 4.5 ]
[.02381 .525 -21 0 ]
[.02381 .525 21 9 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .25 m
.18254 .25625 L
s
[(0.2)] .18254 .2375 0 1 Mshowa
.34127 .25 m
.34127 .25625 L
s
[(0.4)] .34127 .2375 0 1 Mshowa
.5 .25 m
.5 .25625 L
s
[(0.6)] .5 .2375 0 1 Mshowa
.65873 .25 m
.65873 .25625 L
s
[(0.8)] .65873 .2375 0 1 Mshowa
.81746 .25 m
.81746 .25625 L
s
[(1)] .81746 .2375 0 1 Mshowa
.97619 .25 m
.97619 .25625 L
s
[(1.2)] .97619 .2375 0 1 Mshowa
.125 Mabswid
.06349 .25 m
.06349 .25375 L
s
.10317 .25 m
.10317 .25375 L
s
.14286 .25 m
.14286 .25375 L
s
.22222 .25 m
.22222 .25375 L
s
.2619 .25 m
.2619 .25375 L
s
.30159 .25 m
.30159 .25375 L
s
.38095 .25 m
.38095 .25375 L
s
.42063 .25 m
.42063 .25375 L
s
.46032 .25 m
.46032 .25375 L
s
.53968 .25 m
.53968 .25375 L
s
.57937 .25 m
.57937 .25375 L
s
.61905 .25 m
.61905 .25375 L
s
.69841 .25 m
.69841 .25375 L
s
.7381 .25 m
.7381 .25375 L
s
.77778 .25 m
.77778 .25375 L
s
.85714 .25 m
.85714 .25375 L
s
.89683 .25 m
.89683 .25375 L
s
.93651 .25 m
.93651 .25375 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
[(t)] 1.025 .25 -1 0 Mshowa
.02381 .0119 m
.03006 .0119 L
s
[(-1)] .01131 .0119 1 0 Mshowa
.02381 .13095 m
.03006 .13095 L
s
[(-0.5)] .01131 .13095 1 0 Mshowa
.02381 .36905 m
.03006 .36905 L
s
[(0.5)] .01131 .36905 1 0 Mshowa
.02381 .4881 m
.03006 .4881 L
s
[(1)] .01131 .4881 1 0 Mshowa
.125 Mabswid
.02381 .03571 m
.02756 .03571 L
s
.02381 .05952 m
.02756 .05952 L
s
.02381 .08333 m
.02756 .08333 L
s
.02381 .10714 m
.02756 .10714 L
s
.02381 .15476 m
.02756 .15476 L
s
.02381 .17857 m
.02756 .17857 L
s
.02381 .20238 m
.02756 .20238 L
s
.02381 .22619 m
.02756 .22619 L
s
.02381 .27381 m
.02756 .27381 L
s
.02381 .29762 m
.02756 .29762 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .34524 m
.02756 .34524 L
s
.02381 .39286 m
.02756 .39286 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44048 m
.02756 .44048 L
s
.02381 .46429 m
.02756 .46429 L
s
.25 Mabswid
.02381 0 m
.02381 .5 L
s
[(w[6, t])] .02381 .525 0 -1 Mshowa
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.02381 .4881 m
.06244 .4881 L
.08255 .4881 L
.0932 .4881 L
.10458 .4881 L
.11009 .4881 L
.11531 .4881 L
.11999 .4881 L
.12127 .4881 L
.12197 .4881 L
.12263 .4881 L
.12379 .0119 L
.12507 .0119 L
.14415 .0119 L
.18292 .0119 L
.22415 .0119 L
.26386 .0119 L
.28389 .0119 L
.30205 .0119 L
.30692 .0119 L
.31218 .0119 L
.3146 .0119 L
.31715 .0119 L
.31933 .0119 L
.32057 .0119 L
.32172 .4881 L
.32302 .4881 L
.32444 .4881 L
.32702 .4881 L
.33184 .4881 L
.3427 .4881 L
.38348 .4881 L
.42274 .4881 L
.46049 .4881 L
.48147 .4881 L
.5007 .4881 L
.51046 .4881 L
.51522 .4881 L
.51729 .4881 L
.51839 .4881 L
.51954 .4881 L
.52077 .0119 L
.5219 .0119 L
.52412 .0119 L
.52902 .0119 L
.53938 .0119 L
.57727 .0119 L
.61761 .0119 L
.65644 .0119 L
.67618 .0119 L
Mistroke
.68661 .0119 L
.69771 .0119 L
.70329 .0119 L
.70854 .0119 L
.71325 .0119 L
.71454 .0119 L
.71591 .0119 L
.71707 .0119 L
.71834 .4881 L
.71963 .4881 L
.72085 .4881 L
.72312 .4881 L
.72824 .4881 L
.73747 .4881 L
.77585 .4881 L
.79528 .4881 L
.80559 .4881 L
.811 .4881 L
.81395 .4881 L
.81539 .4881 L
.81669 .4881 L
.81795 .25 L
.81914 .25 L
.82175 .25 L
.82728 .25 L
.83698 .25 L
.85601 .25 L
.89453 .25 L
.9355 .25 L
.97495 .25 L
.97619 .25 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "The graph of ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_7\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is shown here."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.23"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[w[7, t]], {t, 0, 1.2}, AspectRatio -> 1/2,
AxesLabel -> {\"t\", \"w[7, t]\"}]\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.25 0.238095 [
[.18254 .2375 -9 -9 ]
[.18254 .2375 9 0 ]
[.34127 .2375 -9 -9 ]
[.34127 .2375 9 0 ]
[.5 .2375 -9 -9 ]
[.5 .2375 9 0 ]
[.65873 .2375 -9 -9 ]
[.65873 .2375 9 0 ]
[.81746 .2375 -3 -9 ]
[.81746 .2375 3 0 ]
[.97619 .2375 -9 -9 ]
[.97619 .2375 9 0 ]
[1.025 .25 0 -4.5 ]
[1.025 .25 6 4.5 ]
[.01131 .0119 -12 -4.5 ]
[.01131 .0119 0 4.5 ]
[.01131 .13095 -24 -4.5 ]
[.01131 .13095 0 4.5 ]
[.01131 .36905 -18 -4.5 ]
[.01131 .36905 0 4.5 ]
[.01131 .4881 -6 -4.5 ]
[.01131 .4881 0 4.5 ]
[.02381 .525 -21 0 ]
[.02381 .525 21 9 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .25 m
.18254 .25625 L
s
[(0.2)] .18254 .2375 0 1 Mshowa
.34127 .25 m
.34127 .25625 L
s
[(0.4)] .34127 .2375 0 1 Mshowa
.5 .25 m
.5 .25625 L
s
[(0.6)] .5 .2375 0 1 Mshowa
.65873 .25 m
.65873 .25625 L
s
[(0.8)] .65873 .2375 0 1 Mshowa
.81746 .25 m
.81746 .25625 L
s
[(1)] .81746 .2375 0 1 Mshowa
.97619 .25 m
.97619 .25625 L
s
[(1.2)] .97619 .2375 0 1 Mshowa
.125 Mabswid
.06349 .25 m
.06349 .25375 L
s
.10317 .25 m
.10317 .25375 L
s
.14286 .25 m
.14286 .25375 L
s
.22222 .25 m
.22222 .25375 L
s
.2619 .25 m
.2619 .25375 L
s
.30159 .25 m
.30159 .25375 L
s
.38095 .25 m
.38095 .25375 L
s
.42063 .25 m
.42063 .25375 L
s
.46032 .25 m
.46032 .25375 L
s
.53968 .25 m
.53968 .25375 L
s
.57937 .25 m
.57937 .25375 L
s
.61905 .25 m
.61905 .25375 L
s
.69841 .25 m
.69841 .25375 L
s
.7381 .25 m
.7381 .25375 L
s
.77778 .25 m
.77778 .25375 L
s
.85714 .25 m
.85714 .25375 L
s
.89683 .25 m
.89683 .25375 L
s
.93651 .25 m
.93651 .25375 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
[(t)] 1.025 .25 -1 0 Mshowa
.02381 .0119 m
.03006 .0119 L
s
[(-1)] .01131 .0119 1 0 Mshowa
.02381 .13095 m
.03006 .13095 L
s
[(-0.5)] .01131 .13095 1 0 Mshowa
.02381 .36905 m
.03006 .36905 L
s
[(0.5)] .01131 .36905 1 0 Mshowa
.02381 .4881 m
.03006 .4881 L
s
[(1)] .01131 .4881 1 0 Mshowa
.125 Mabswid
.02381 .03571 m
.02756 .03571 L
s
.02381 .05952 m
.02756 .05952 L
s
.02381 .08333 m
.02756 .08333 L
s
.02381 .10714 m
.02756 .10714 L
s
.02381 .15476 m
.02756 .15476 L
s
.02381 .17857 m
.02756 .17857 L
s
.02381 .20238 m
.02756 .20238 L
s
.02381 .22619 m
.02756 .22619 L
s
.02381 .27381 m
.02756 .27381 L
s
.02381 .29762 m
.02756 .29762 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .34524 m
.02756 .34524 L
s
.02381 .39286 m
.02756 .39286 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44048 m
.02756 .44048 L
s
.02381 .46429 m
.02756 .46429 L
s
.25 Mabswid
.02381 0 m
.02381 .5 L
s
[(w[7, t])] .02381 .525 0 -1 Mshowa
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.02381 .4881 m
.06244 .4881 L
.08255 .4881 L
.0932 .4881 L
.10458 .4881 L
.11009 .4881 L
.11531 .4881 L
.11999 .4881 L
.12127 .4881 L
.12197 .4881 L
.12263 .4881 L
.12379 .0119 L
.12507 .0119 L
.14415 .0119 L
.18292 .0119 L
.22415 .0119 L
.26386 .0119 L
.28389 .0119 L
.30205 .0119 L
.30692 .0119 L
.31218 .0119 L
.3146 .0119 L
.31715 .0119 L
.31933 .0119 L
.32057 .0119 L
.32172 .4881 L
.32302 .4881 L
.32444 .4881 L
.32702 .4881 L
.33184 .4881 L
.3427 .4881 L
.36208 .4881 L
.38348 .4881 L
.39322 .4881 L
.40373 .4881 L
.40856 .4881 L
.41365 .4881 L
.41799 .4881 L
.41918 .4881 L
.42045 .4881 L
.42165 .0119 L
.42274 .0119 L
.46273 .0119 L
.48104 .0119 L
.49145 .0119 L
.50119 .0119 L
.51077 .0119 L
.51353 .0119 L
.51615 .0119 L
.5185 .0119 L
Mistroke
.51915 .0119 L
.51983 .0119 L
.52107 .4881 L
.52176 .4881 L
.52249 .4881 L
.5238 .4881 L
.52676 .4881 L
.53211 .4881 L
.54211 .4881 L
.58013 .4881 L
.62061 .4881 L
.65957 .4881 L
.67942 .4881 L
.68988 .4881 L
.70098 .4881 L
.71085 .4881 L
.71355 .4881 L
.71497 .4881 L
.71646 .4881 L
.71777 .4881 L
.71852 .0119 L
.71921 .0119 L
.72172 .0119 L
.74088 .0119 L
.77998 .0119 L
.79025 .0119 L
.80137 .0119 L
.80647 .0119 L
.81186 .0119 L
.81409 .0119 L
.81531 .0119 L
.81647 .0119 L
.81712 .0119 L
.81784 .25 L
.81909 .25 L
.82153 .25 L
.86228 .25 L
.90151 .25 L
.93923 .25 L
.97619 .25 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "These are the so\[Hyphen]called Walsh functions. They are all orthogonal \
to each other and, what is more, to their own translations and dilations \
(with the exception of ",
  Cell[BoxData[
      \(TraditionalForm\`w\_0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ")."
}], "Text",
  CellTags->{"S1.5.6", "6.24"}],

Cell[TextData[{
  "Here is the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_7\) \((2  t - 1)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". It is orthogonal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_7\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.6", "6.25"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[w[7, 2t-1]], {t, 0, 1.2},
AspectRatio -> 1/2,
AxesLabel -> {\"t\", \"w[7, 2t-1]\"}]\
\>", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.25 0.238095 [
[.18254 .2375 -9 -9 ]
[.18254 .2375 9 0 ]
[.34127 .2375 -9 -9 ]
[.34127 .2375 9 0 ]
[.5 .2375 -9 -9 ]
[.5 .2375 9 0 ]
[.65873 .2375 -9 -9 ]
[.65873 .2375 9 0 ]
[.81746 .2375 -3 -9 ]
[.81746 .2375 3 0 ]
[.97619 .2375 -9 -9 ]
[.97619 .2375 9 0 ]
[1.025 .25 0 -4.5 ]
[1.025 .25 6 4.5 ]
[.01131 .0119 -12 -4.5 ]
[.01131 .0119 0 4.5 ]
[.01131 .13095 -24 -4.5 ]
[.01131 .13095 0 4.5 ]
[.01131 .36905 -18 -4.5 ]
[.01131 .36905 0 4.5 ]
[.01131 .4881 -6 -4.5 ]
[.01131 .4881 0 4.5 ]
[.02381 .525 -30 0 ]
[.02381 .525 30 9 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .25 m
.18254 .25625 L
s
[(0.2)] .18254 .2375 0 1 Mshowa
.34127 .25 m
.34127 .25625 L
s
[(0.4)] .34127 .2375 0 1 Mshowa
.5 .25 m
.5 .25625 L
s
[(0.6)] .5 .2375 0 1 Mshowa
.65873 .25 m
.65873 .25625 L
s
[(0.8)] .65873 .2375 0 1 Mshowa
.81746 .25 m
.81746 .25625 L
s
[(1)] .81746 .2375 0 1 Mshowa
.97619 .25 m
.97619 .25625 L
s
[(1.2)] .97619 .2375 0 1 Mshowa
.125 Mabswid
.06349 .25 m
.06349 .25375 L
s
.10317 .25 m
.10317 .25375 L
s
.14286 .25 m
.14286 .25375 L
s
.22222 .25 m
.22222 .25375 L
s
.2619 .25 m
.2619 .25375 L
s
.30159 .25 m
.30159 .25375 L
s
.38095 .25 m
.38095 .25375 L
s
.42063 .25 m
.42063 .25375 L
s
.46032 .25 m
.46032 .25375 L
s
.53968 .25 m
.53968 .25375 L
s
.57937 .25 m
.57937 .25375 L
s
.61905 .25 m
.61905 .25375 L
s
.69841 .25 m
.69841 .25375 L
s
.7381 .25 m
.7381 .25375 L
s
.77778 .25 m
.77778 .25375 L
s
.85714 .25 m
.85714 .25375 L
s
.89683 .25 m
.89683 .25375 L
s
.93651 .25 m
.93651 .25375 L
s
.25 Mabswid
0 .25 m
1 .25 L
s
[(t)] 1.025 .25 -1 0 Mshowa
.02381 .0119 m
.03006 .0119 L
s
[(-1)] .01131 .0119 1 0 Mshowa
.02381 .13095 m
.03006 .13095 L
s
[(-0.5)] .01131 .13095 1 0 Mshowa
.02381 .36905 m
.03006 .36905 L
s
[(0.5)] .01131 .36905 1 0 Mshowa
.02381 .4881 m
.03006 .4881 L
s
[(1)] .01131 .4881 1 0 Mshowa
.125 Mabswid
.02381 .03571 m
.02756 .03571 L
s
.02381 .05952 m
.02756 .05952 L
s
.02381 .08333 m
.02756 .08333 L
s
.02381 .10714 m
.02756 .10714 L
s
.02381 .15476 m
.02756 .15476 L
s
.02381 .17857 m
.02756 .17857 L
s
.02381 .20238 m
.02756 .20238 L
s
.02381 .22619 m
.02756 .22619 L
s
.02381 .27381 m
.02756 .27381 L
s
.02381 .29762 m
.02756 .29762 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .34524 m
.02756 .34524 L
s
.02381 .39286 m
.02756 .39286 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44048 m
.02756 .44048 L
s
.02381 .46429 m
.02756 .46429 L
s
.25 Mabswid
.02381 0 m
.02381 .5 L
s
[(w[7, 2t-1])] .02381 .525 0 -1 Mshowa
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
.02381 .25 m
.06244 .25 L
.10458 .25 L
.14415 .25 L
.18221 .25 L
.22272 .25 L
.26171 .25 L
.30316 .25 L
.34309 .25 L
.3815 .25 L
.40134 .25 L
.41134 .25 L
.41409 .25 L
.41703 .25 L
.41846 .25 L
.41917 .25 L
.41982 .25 L
.42104 .4881 L
.42168 .4881 L
.42237 .4881 L
.44234 .4881 L
.45285 .4881 L
.45859 .4881 L
.46395 .4881 L
.46641 .4881 L
.46875 .4881 L
.47004 .4881 L
.47077 .0119 L
.47144 .0119 L
.4739 .0119 L
.48482 .0119 L
.50401 .0119 L
.52427 .0119 L
.54328 .0119 L
.55213 .0119 L
.56145 .0119 L
.56633 .0119 L
.56766 .0119 L
.5684 .0119 L
.56909 .0119 L
.56974 .4881 L
.57044 .4881 L
.57166 .4881 L
.58103 .4881 L
.60091 .4881 L
.61093 .4881 L
.61367 .4881 L
.61519 .4881 L
.61662 .4881 L
.61795 .4881 L
Mistroke
.61871 .4881 L
.61941 .0119 L
.62064 .0119 L
.62195 .0119 L
.64196 .0119 L
.65248 .0119 L
.65823 .0119 L
.66358 .0119 L
.66606 .0119 L
.66728 .0119 L
.6684 .0119 L
.6697 .4881 L
.67038 .4881 L
.6711 .4881 L
.67356 .4881 L
.68449 .4881 L
.7037 .4881 L
.74151 .4881 L
.75096 .4881 L
.76089 .4881 L
.76341 .4881 L
.7661 .4881 L
.76689 .4881 L
.76764 .4881 L
.76832 .0119 L
.76905 .0119 L
.77179 .0119 L
.78176 .0119 L
.80168 .0119 L
.81171 .0119 L
.81446 .0119 L
.81597 .0119 L
.81672 .0119 L
.81741 .0119 L
.81805 .25 L
.81874 .25 L
.82019 .25 L
.82273 .25 L
.86045 .25 L
.90062 .25 L
.93928 .25 L
.97619 .25 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "Using a pair of lowpass and highpass filters to split a space corresponds \
to splitting the frequency content of a signal into roughly a \
low\[Hyphen]frequency and a high\[Hyphen]frequency component. In wavelet \
decomposition we leave the high\[Hyphen]frequency part alone and keep \
splitting the low\[Hyphen]frequency part. In wavelet packet decomposition, we \
can choose to split the high\[Hyphen]frequency part also into a \
low\[Hyphen]frequency part and a high\[Hyphen]frequency part. So in general, \
wavelet packet decomposition divides the frequency space into various parts \
and allows better frequency localization of signals. \nThe transformation of \
data into wavelet packet basis presents no extra difficulties. We can simply \
do a convolution using filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " on the details ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " as well as on the trend ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". As in the wavelet transform, we can keep doing the decomposition until \
we cannot go any further. On the other hand, we can also choose not to \
decompose a particular subspace while decomposing others. So there are many \
choices for decomposing a signal. We can keep all the coefficients at all \
decomposition levels and generate a table of coefficients of wavelet packet \
decomposition. The function "
}], "Text",
  CellTags->{"S1.5.6", "6.26"}],

Cell[TextData[{
  StyleBox["WaveletPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.27"}],

Cell["or ", "Text",
  CellTags->{"S1.5.6", "6.28"}],

Cell[TextData[{
  StyleBox["WaveletPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["l", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.29"}],

Cell[TextData[{
  "gives the wavelet packet coefficients table of ",
  StyleBox["data", "TI"],
  " using the filter ",
  StyleBox["filter", "TI"],
  ". As in the ",
  StyleBox["WaveletTransform", "MR"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`l\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " specifies the number of times the decomposition is done. \nTo illustrate \
the use of the function ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  ", we first look at a simple example. We generate a list of 8 random \
numbers and then calculate the wavelet packet coefficients using the Haar \
filter. "
}], "Text",
  CellTags->{"S1.5.6", "6.30"}],

Cell["This generates a list of 8 random numbers.", "MathCaption",
  CellTags->{"S1.5.6", "6.31"}],

Cell[CellGroupData[{

Cell["\<\
(SeedRandom[37561];
 data = Table[Random[],{8}])\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({0.0876232948358210528`, 0.0218343907982543727`, 0.574652828028574891`, 
      0.662378082795778055`, 0.794088739560665146`, 0.618741857670105144`, 
      0.502055273506782917`, 0.230342410188279789`}\)], "Output",
  CellLabel->"Out[19]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["This is the Haar filter.", "MathCaption",
  CellTags->{"S1.5.6", "6.32"}],

Cell[CellGroupData[{

Cell["h = DaubechiesFilter[1]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{0.70710678118654755`, 0.70710678118654755`}, 0}\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["A table of wavelet packet coefficients is produced.", "MathCaption",
  CellTags->{"S1.5.6", "6.33"}],

Cell[CellGroupData[{

Cell["wpcoef = WaveletPacketCoefficients[data, h]", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{{0.0876232948358210528`, 0.0218343907982543727`, 
          0.574652828028574891`, 0.662378082795778055`, 
          0.794088739560665146`, 0.618741857670105144`, 
          0.502055273506782917`, 0.230342410188279789`}}, {{
          0.0773982717648400875`, 0.874712945581271306`, 
          0.999022095969717582`, 0.517883368666098942`}, {
          0.0465197801717944336`, \(-0.0620311225272068877`\), 
          0.123988969244731572`, 0.192130008188127092`}}, {{
          0.673244298229214255`, 1.07261414046291658`}, {
          \(-0.563786612595138869`\), 0.340216456767853836`}, {
          \(-0.0109681753648182645`\), 0.223529872604531565`}, {
          0.0767570794023849511`, \(-0.0481829907139715896`\)}}, {{
          1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
          \(-0.158087973256406355`\)}, {\(-0.63922670056002504`\)}, {
          0.150303817538723123`}, {\(-0.165815159894135577`\)}, {
          0.0202049318778029096`}, {0.0883459708211984384`}}}\)], "Output",
  CellLabel->"Out[21]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "We see that the output is a list of matrices, each of which corresponds to \
a particular level of decomposition. The first entry is our original data and \
we label it as level zero (since no decomposition is done). Each level \
reflects the decomposition of ",
  StyleBox["every", "TI"],
  " frequency part of the previous level into a low\[Hyphen]frequency part \
and a high\[Hyphen]frequency part (or \"smooth\" part and details). The \
output data structure corresponds to the diagram given in the beginning of \
this section. Note that although we arrange the data at each level according \
to increasing ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", it does not necessarily mean that higher ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " corresponds to a higher\[Hyphen]frequency component. See Wickerhauser \
(1993) for more details. \nThis table of coefficients is a representation of \
the original signal in different wavelet packet bases. It is highly redundant \
and we need to choose from among all the representations the one that \
represents the signal most efficiently. By \"efficient\" we mean that a \
signal can be represented by a small number of wave forms or wavelet packets, \
that is, the basis for the decomposition is chosen such that the weight of \
the coefficients is concentrated on a small number of wavelet packets and a \
large number of coefficients are close to zero. \nThe commonly used criterion \
for choosing the most efficient or best basis for a given signal is the \
minimum entropy criterion (see Coifman and Wickerhauser (1992) and \
Wickerhauser (1994)). That is, let ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_i}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " be the decomposition coefficients of a signal for a particular choice of \
the wavelet packet basis. For each set of decomposition coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_i}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " we associate a nonnegative quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) \(({v\_i})\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " called entropy defined by "
}], "Text",
  CellTags->{"S1.5.6", "6.34"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Epsilon]\^2\), \(({v\_i})\), "=", "-", 
        UnderscriptBox["\[Sum]", "i",
          LimitsPositioning->True], 
        \(v\_i\%2\/\( \[VerticalSeparator]  \[VerticalSeparator] v 
              \[VerticalSeparator] \( \[VerticalSeparator] \^2\)\)\), 
        \(log\_2\), 
        \(v\_i\%2\/\( \[VerticalSeparator]  \[VerticalSeparator] v 
              \[VerticalSeparator] \( \[VerticalSeparator] \^2\)\)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.6", "6.35"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
        "\[VerticalSeparator]", "\[VerticalSeparator]", "v", 
          "\[VerticalSeparator]", \( \[VerticalSeparator] \^2\), "=", 
          UnderscriptBox["\[Sum]", "i",
            LimitsPositioning->True], \(v\_i\%2\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.6"],
  ". The best basis is the one which produces the least entropy. Intuitively, \
the entropy defined above gives a measure of how many effective components \
are needed to represent the signal in a specific basis. For example, if in a \
particular basis the decomposition produces all zero coefficients except one \
(",
  StyleBox["i.e.", "TI"],
  ", the signal coincides with a wave form), then the entropy reaches its \
minimum value of zero. On the other hand, if in some basis the decomposition \
coefficients are all equally important, say ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i = 1/\@N\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is the length of the data, the entropy in this case is maximum, ",
  Cell[BoxData[
      \(TraditionalForm\`\(log\_2\) N\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ". Any other decomposition will fall in between these two extreme cases. In \
general, the smaller the entropy the fewer significant coefficients needed to \
represent the signal. \nThe function "
}], "Text",
  CellTags->{"S1.5.6", "6.36"}],

Cell[TextData[{
  StyleBox["WaveletPacketTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.37"}],

Cell["or ", "Text",
  CellTags->{"S1.5.6", "6.38"}],

Cell[TextData[{
  StyleBox["WaveletPacketTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["l", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.39"}],

Cell[TextData[{
  "gives the wavelet packet transform of ",
  StyleBox["data", "TI"],
  " by choosing the best basis using the entropy criterion given ",
  StyleBox["filter", "TI"],
  ", the filter that generates the wavelet packets. Again ",
  Cell[BoxData[
      \(TraditionalForm\`l\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " specifies the number of decompositions. "
}], "Text",
  CellTags->{"S1.5.6", "6.40"}],

Cell["\<\
For example, we use the above data again to get the wavelet packet \
transform. \
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.41"}],

Cell[CellGroupData[{

Cell["WaveletPacketTransform[data, h]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
        \(-0.158087973256406355`\)}, {\(-0.63922670056002504`\)}, {
        \(-0.0109681753648182645`\), 0.223529872604531565`}, {
        0.0202049318778029096`}, {0.0883459708211984384`}}\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["\<\
We can visualize how the space is split or equivalently what basis \
functions are chosen by plotting the basis location using the function \
\>", 
  "Text",
  CellTags->{"S1.5.6", "6.42"}],

Cell[TextData[{
  StyleBox["ShowBasisPosition[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox["]", "MR"],
  ", "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.43"}],

Cell[TextData[{
  "where ",
  StyleBox["coefs", "TI"],
  " is the result of wavelet transform or wavelet packet transform of one\
\[Hyphen]dimensional data. "
}], "Text",
  CellTags->{"S1.5.6", "6.44"}],

Cell["\<\
The top row represents the original space. Each decomposition \
splits each space in the previous level into two subspaces. In this example, \
the best basis is the combination of the basis functions from the shaded \
spaces.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.45"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .16187 translate
.2381 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "Sometimes we may want to use other criteria to choose the best basis \
rather than the entropy criterion. In that case, we can set the option ",
  StyleBox["CostFunction", "MR"],
  " to the function of our choice. For example, if we want to use the so\
\[Hyphen]called threshold function as the cost function "
}], "Text",
  CellTags->{"S1.5.6", "6.46"}],

Cell[BoxData[
    FormBox[
      RowBox[{"C", \(({v\_i})\), "=", 
        UnderscriptBox["\[Sum]", "i",
          LimitsPositioning->True], "\[Theta]", \((
        \( \[VerticalSeparator] v\_i \[VerticalSeparator] -\[Tau]\))\), ","}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.5.6", "6.47"}],

Cell[TextData[{
  "where the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is the step function (",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \((t)\) = 1\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] \((t)\) = 0\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " otherwise) and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is the threshold, we can do the following (we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 0.3\)], "InlineFormula",
    CellTags->"S1.5.6"],
  "). "
}], "Text",
  CellTags->{"S1.5.6", "6.48"}],

Cell["\<\
The threshold function is used here as the cost function. Note that \
it has to be input as a pure function.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.49"}],

Cell[CellGroupData[{

Cell["\<\
WaveletPacketTransform[data, h,
CostFunction -> (If[Abs[#] > 0.3, 1, 0]&)]\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
        \(-0.158087973256406355`\)}, {\(-0.63922670056002504`\)}, {
        0.0465197801717944336`, \(-0.0620311225272068877`\), 
        0.123988969244731572`, 0.192130008188127092`}}\)], "Output",
  CellLabel->"Out[24]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["This shows the position of the chosen subspaces or basis.", 
  "MathCaption",
  CellTags->{"S1.5.6", "6.50"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .30902 translate
.47619 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell[TextData[{
  "Comparing with the previous output, we see that, in general, different \
cost functions result in different best bases. Note also that the cost \
function we give must be additive (",
  StyleBox["i.e.", "TI"],
  ", the total cost is the sum of the cost incurred by each coefficient) and \
it must be input as a pure function. To find out more about pure functions, \
see Wolfram (1996). \nSometimes one may prefer to choose basis functions that \
are all in the same level. That is, the basis is formed by functions of the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`{\(w\_n\) \((\(2\^j\) t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.6"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.6"],
  " is chosen such that the particular level of decomposition gives the \
lowest cost. To do wavelet packet transform by selecting the best level, we \
set the option ",
  StyleBox["BestLevel", "MR"],
  " to ",
  StyleBox["True", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.5.6", "6.51"}],

Cell["\<\
This gives the wavelet packet transform by choosing the best level.\
\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.52"}],

Cell[CellGroupData[{

Cell["\<\
WaveletPacketTransform[data, h,  BestLevel -> True,
CostFunction -> (If[Abs[#] > 0.3, 1, 0]&)]\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
        \(-0.158087973256406355`\)}, {\(-0.63922670056002504`\)}, {
        0.150303817538723123`}, {\(-0.165815159894135577`\)}, {
        0.0202049318778029096`}, {0.0883459708211984384`}}\)], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["\<\
We see that all the sublists in the output have the same length. \
These coefficients are in the same level (here level 3), and they give the \
lowest cost among all levels from 0 to 3. \
\>", "Text",
  CellTags->{"S1.5.6", "6.53"}],

Cell["This shows the position of the chosen basis.", "MathCaption",
  CellTags->{"S1.5.6", "6.54"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["\<\
A given wavelet basis corresponds to a particular choice of the \
wavelet packet basis. It can be obtained from picking a particular \
combination of the coefficients in the wavelet packet coefficient table. \
\
\>", "Text",
  CellTags->{"S1.5.6", "6.55"}],

Cell["\<\
For example, this particular choice of the coefficients corresponds \
to the wavelet transform.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.56"}],

Cell[CellGroupData[{

Cell["Join[{wpcoef[[-1,1]]}, #[[2]]& /@ Reverse[Rest[wpcoef]]]", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
        \(-0.563786612595138869`\), 0.340216456767853836`}, {
        0.0465197801717944336`, \(-0.0620311225272068877`\), 
        0.123988969244731572`, 0.192130008188127092`}}\)], "Output",
  CellLabel->"Out[28]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["This gives the same result as above.", "MathCaption",
  CellTags->{"S1.5.6", "6.57"}],

Cell[CellGroupData[{

Cell["WaveletTransform[data, h]", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.23450834099096407`}, {\(-0.282397123644852587`\)}, {
        \(-0.563786612595138869`\), 0.340216456767853836`}, {
        0.0465197801717944336`, \(-0.0620311225272068877`\), 
        0.123988969244731572`, 0.192130008188127092`}}\)], "Output",
  CellLabel->"Out[29]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["\<\
The wavelet transform only decomposes the spaces corresponding to \
the low\[Hyphen]frequency part.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.58"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S1.5.6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .16187 translate
.2381 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .30902 translate
.47619 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["\<\
Here is an example where the best basis using the entropy criterion \
happens to be the wavelet basis.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.59"}],

Cell[CellGroupData[{

Cell["\<\
(SeedRandom[3756];
 data = Table[Random[],{8}];
 WaveletPacketTransform[data, h])\
\>", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({{1.70561770120764988`}, {\(-0.614048348072698058`\)}, {
        \(-0.697218982931632336`\), \(-0.122039928451392665`\)}, {
        \(-0.0464400176456784219`\), 0.317948793530409812`, 
        0.169052187515028462`, \(-0.0189964812282678288`\)}}\)], "Output",
  CellLabel->"Out[31]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["The above result is the same as doing wavelet transform.", "MathCaption",
  CellTags->{"S1.5.6", "6.60"}],

Cell[CellGroupData[{

Cell["WaveletTransform[data, h]==%", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[32]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["The inverse transform is done using ", "Text",
  CellTags->{"S1.5.6", "6.61"}],

Cell[TextData[{
  StyleBox["InverseWaveletPacketTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.6", "6.62"}],

Cell["This gives the inverse wavelet packet transform.", "MathCaption",
  CellTags->{"S1.5.6", "6.63"}],

Cell["InverseWaveletPacketTransform[%%, h];", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S1.5.6"],

Cell["\<\
Since the filter is orthogonal and the default periodic boundary \
condition is used, the original data are recovered.\
\>", "MathCaption",
  CellTags->{"S1.5.6", "6.64"}],

Cell[CellGroupData[{

Cell["Chop[% - data]", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"S1.5.6"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[34]= ",
  CellTags->"S1.5.6"]
}, Open  ]],

Cell["1.5.7 Generating Wavelet Packets", "Subsection",
  CellTags->{"S1.5.7", "7.1"}],

Cell[TextData[{
  "In Section ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ", we demonstrated how to get the scaling function and the basic wavelet by \
first solving the eigenvalue problem and then recursively finding the values \
at dyadic points. We can generate wavelet packets using the same procedure. \
The function "
}], "Text",
  CellTags->{"S1.5.7", "7.2"}],

Cell[TextData[{
  StyleBox["WaveletPacket[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.7", "7.3"}],

Cell[TextData[{
  "computes the values of the wavelet packet ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " generated from the filter ",
  StyleBox["filter", "TI"],
  " at the dyadic points ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.7"],
  ". (Note that when ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("jmax"\),
            "TI"], "\[LessEqual]", \(log\_2\), "n"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.7"],
  ", ",
  StyleBox["jmax", "TI"],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(log\_2\) n]\)\) + 1\)], 
    "InlineFormula",
    CellTags->"S1.5.7"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([x]\)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " is the integer part of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ".) "
}], "Text",
  CellTags->{"S1.5.7", "7.4"}],

Cell["This gives the third\[Hyphen]order Daubechies filter.", "MathCaption",
  CellTags->{"S1.5.7", "7.5"}],

Cell["d3 = DaubechiesFilter[3];", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"S1.5.7"],

Cell["\<\
Here are the first 6 wavelet packets generated from the Daubechies \
filter of order 3 using the recursion method.\
\>", "MathCaption",
  CellTags->{"S1.5.7", "7.6"}],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[Partition[
Table[ListPlot[WaveletPacket[i, d3, 6],
PlotLabel -> \"w[\"<>ToString[i]<>\", t]\",
DisplayFunction -> Identity, Ticks -> None,
PlotJoined -> True, PlotRange -> All],
{i, 0, 5}], 2]], PlotLabel -> \"wavelet packets\"]\
\>", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"S1.5.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[.5 .95427 -45 0 ]
[.5 .95427 45 9 ]
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(wavelet packets)] .5 .95427 0 -1 Mshowa
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.119048 0.190476 0.308559 0.14353 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30856 m
1 .30856 L
s
.11905 0 m
.11905 .61803 L
s
[(w[4, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .30856 m
.02679 .30877 L
.02976 .30901 L
.03274 .30923 L
.03571 .30952 L
.03869 .30974 L
.04167 .30998 L
.04464 .31028 L
.04762 .31059 L
.0506 .31082 L
.05357 .31106 L
.05655 .31133 L
.05952 .31158 L
.0625 .3119 L
.06548 .31223 L
.06845 .31255 L
.07143 .31289 L
.0744 .31202 L
.07738 .31102 L
.08036 .31015 L
.08333 .30888 L
.08631 .30802 L
.08929 .30703 L
.09226 .30571 L
.09524 .30436 L
.09821 .30351 L
.10119 .30261 L
.10417 .30156 L
.10714 .3006 L
.11012 .29927 L
.1131 .2979 L
.11607 .2966 L
.11905 .29519 L
.12202 .30062 L
.125 .30687 L
.12798 .31238 L
.13095 .32015 L
.13393 .3256 L
.1369 .33184 L
.13988 .33995 L
.14286 .3482 L
.14583 .33557 L
.14881 .32096 L
.15179 .30898 L
.15476 .29043 L
.15774 .27996 L
.16071 .26755 L
.16369 .24967 L
.16667 .23195 L
.16964 .2536 L
Mistroke
.17262 .27866 L
.1756 .2986 L
.17857 .33073 L
.18155 .34687 L
.18452 .36638 L
.1875 .39611 L
.19048 .42514 L
.19345 .39418 L
.19643 .35831 L
.1994 .33039 L
.20238 .28404 L
.20536 .26278 L
.20833 .2366 L
.21131 .19496 L
.21429 .15472 L
.21726 .19442 L
.22024 .24038 L
.22321 .27567 L
.22619 .33536 L
.22917 .36091 L
.23214 .39284 L
.23512 .44527 L
.2381 .49553 L
.24107 .44468 L
.24405 .38596 L
.24702 .34066 L
.25 .26448 L
.25298 .2317 L
.25595 .19088 L
.25893 .12407 L
.2619 .06008 L
.26488 .12347 L
.26786 .19677 L
.27083 .25319 L
.27381 .34851 L
.27679 .38912 L
.27976 .43987 L
.28274 .52337 L
.28571 .60332 L
.28869 .53332 L
.29167 .45216 L
.29464 .39124 L
.29762 .28484 L
.3006 .2439 L
.30357 .19144 L
.30655 .1007 L
.30952 .01472 L
.3125 .08383 L
.31548 .16382 L
.31845 .22259 L
Mistroke
.32143 .32806 L
.3244 .36412 L
.32738 .41158 L
.33036 .49844 L
.33333 .57957 L
.33631 .51816 L
.33929 .44724 L
.34226 .39583 L
.34524 .30168 L
.34821 .27268 L
.35119 .23352 L
.35417 .1582 L
.35714 .08869 L
.36012 .13785 L
.3631 .19453 L
.36607 .23496 L
.36905 .3108 L
.37202 .33128 L
.375 .35997 L
.37798 .41872 L
.38095 .47216 L
.38393 .43517 L
.3869 .39268 L
.38988 .36252 L
.39286 .30545 L
.39583 .29134 L
.39881 .27111 L
.40179 .22795 L
.40476 .18912 L
.40774 .21535 L
.41071 .24545 L
.41369 .26675 L
.41667 .3074 L
.41964 .3168 L
.42262 .33056 L
.4256 .36086 L
.42857 .38793 L
.43155 .37483 L
.43452 .35973 L
.4375 .35023 L
.44048 .32898 L
.44345 .32797 L
.44643 .32456 L
.4494 .31107 L
.45238 .30003 L
.45536 .29797 L
.45833 .29546 L
.46131 .29143 L
.46429 .28958 L
.46726 .28089 L
Mistroke
.47024 .27208 L
.47321 .26529 L
.47619 .2569 L
.47917 .26946 L
.48214 .28434 L
.48512 .29641 L
.4881 .31513 L
.49107 .32687 L
.49405 .34071 L
.49702 .35996 L
.5 .37945 L
.50298 .36259 L
.50595 .34291 L
.50893 .32837 L
.5119 .30282 L
.51488 .29252 L
.51786 .27941 L
.52083 .25716 L
.52381 .2359 L
.52679 .25125 L
.52976 .26907 L
.53274 .28173 L
.53571 .30534 L
.53869 .31241 L
.54167 .32206 L
.54464 .34092 L
.54762 .35831 L
.5506 .34805 L
.55357 .3362 L
.55655 .32825 L
.55952 .31215 L
.5625 .30931 L
.56548 .3047 L
.56845 .29316 L
.57143 .28305 L
.5744 .28922 L
.57738 .29621 L
.58036 .30097 L
.58333 .3105 L
.58631 .31179 L
.58929 .31407 L
.59226 .32046 L
.59524 .32586 L
.59821 .32184 L
.60119 .31729 L
.60417 .31392 L
.60714 .30773 L
.61012 .30625 L
.6131 .30412 L
.61607 .29955 L
Mistroke
.61905 .29548 L
.62202 .29725 L
.625 .29931 L
.62798 .30057 L
.63095 .30355 L
.63393 .30359 L
.6369 .30399 L
.63988 .30586 L
.64286 .30739 L
.64583 .30856 L
.64881 .30992 L
.65179 .31142 L
.65476 .31293 L
.65774 .31513 L
.66071 .31746 L
.66369 .31978 L
.66667 .32236 L
.66964 .31917 L
.67262 .31541 L
.6756 .31241 L
.67857 .3076 L
.68155 .30489 L
.68452 .30164 L
.6875 .2969 L
.69048 .29217 L
.69345 .29594 L
.69643 .30033 L
.6994 .30352 L
.70238 .30926 L
.70536 .31135 L
.70833 .31408 L
.71131 .31894 L
.71429 .32353 L
.71726 .32072 L
.72024 .31745 L
.72321 .31524 L
.72619 .31084 L
.72917 .30989 L
.73214 .30846 L
.73512 .30517 L
.7381 .30224 L
.74107 .30321 L
.74405 .30432 L
.74702 .30486 L
.75 .3065 L
.75298 .30607 L
.75595 .30583 L
.75893 .30654 L
.7619 .30696 L
.76488 .30721 L
Mistroke
.76786 .30756 L
.77083 .30793 L
.77381 .30829 L
.77679 .30902 L
.77976 .30981 L
.78274 .31057 L
.78571 .31146 L
.78869 .31086 L
.79167 .31014 L
.79464 .30966 L
.79762 .30875 L
.8006 .30839 L
.80357 .30793 L
.80655 .30712 L
.80952 .30633 L
.8125 .30677 L
.81548 .30727 L
.81845 .30758 L
.82143 .30825 L
.8244 .30834 L
.82738 .30849 L
.83036 .30895 L
.83333 .30934 L
.83631 .30922 L
.83929 .3091 L
.84226 .30904 L
.84524 .30885 L
.84821 .30893 L
.85119 .309 L
.85417 .30894 L
.85714 .30892 L
.86012 .30887 L
.8631 .3088 L
.86607 .30874 L
.86905 .30867 L
.87202 .30857 L
.875 .30845 L
.87798 .30833 L
.88095 .3082 L
.88393 .30826 L
.8869 .30833 L
.88988 .30838 L
.89286 .30847 L
.89583 .30849 L
.89881 .30852 L
.90179 .30859 L
.90476 .30866 L
.90774 .30864 L
.91071 .3086 L
.91369 .30859 L
Mistroke
.91667 .30855 L
.91964 .30856 L
.92262 .30857 L
.9256 .30855 L
.92857 .30854 L
.93155 .30855 L
.93452 .30855 L
.9375 .30856 L
.94048 .30856 L
.94345 .30856 L
.94643 .30856 L
.9494 .30856 L
.95238 .30856 L
.95536 .30856 L
.95833 .30856 L
.96131 .30856 L
.96429 .30856 L
.96726 .30856 L
.97024 .30856 L
.97321 .30856 L
.97619 .30856 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.190476 0.302602 0.134961 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .3026 m
1 .3026 L
s
.5 0 m
.5 .61803 L
s
[(w[5, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .3026 m
.02679 .30262 L
.02976 .30265 L
.03274 .30267 L
.03571 .3027 L
.03869 .30272 L
.04167 .30274 L
.04464 .30277 L
.04762 .3028 L
.0506 .30283 L
.05357 .30285 L
.05655 .30288 L
.05952 .3029 L
.0625 .30293 L
.06548 .30297 L
.06845 .303 L
.07143 .30303 L
.0744 .30295 L
.07738 .30285 L
.08036 .30276 L
.08333 .30263 L
.08631 .30255 L
.08929 .30245 L
.09226 .30232 L
.09524 .30218 L
.09821 .3021 L
.10119 .30201 L
.10417 .3019 L
.10714 .30181 L
.11012 .30168 L
.1131 .30154 L
.11607 .30141 L
.11905 .30127 L
.12202 .30181 L
.125 .30243 L
.12798 .30298 L
.13095 .30376 L
.13393 .3043 L
.1369 .30492 L
.13988 .30573 L
.14286 .30655 L
.14583 .30529 L
.14881 .30384 L
.15179 .30264 L
.15476 .3008 L
.15774 .29975 L
.16071 .29852 L
.16369 .29674 L
.16667 .29497 L
.16964 .29713 L
Mistroke
.17262 .29963 L
.1756 .30161 L
.17857 .30481 L
.18155 .30642 L
.18452 .30836 L
.1875 .31132 L
.19048 .31421 L
.19345 .31113 L
.19643 .30756 L
.1994 .30478 L
.20238 .30016 L
.20536 .29804 L
.20833 .29544 L
.21131 .29129 L
.21429 .28728 L
.21726 .29113 L
.22024 .29558 L
.22321 .29898 L
.22619 .30477 L
.22917 .3072 L
.23214 .31026 L
.23512 .31532 L
.2381 .32016 L
.24107 .31498 L
.24405 .30901 L
.24702 .30436 L
.25 .29664 L
.25298 .29322 L
.25595 .28898 L
.25893 .28216 L
.2619 .27561 L
.26488 .28237 L
.26786 .29019 L
.27083 .29626 L
.27381 .30641 L
.27679 .3109 L
.27976 .31647 L
.28274 .32547 L
.28571 .33413 L
.28869 .3276 L
.29167 .31999 L
.29464 .31447 L
.29762 .30437 L
.3006 .30099 L
.30357 .29647 L
.30655 .28811 L
.30952 .28029 L
.3125 .28435 L
.31548 .28907 L
.31845 .29206 L
Mistroke
.32143 .29853 L
.3244 .29928 L
.32738 .30077 L
.33036 .30521 L
.33333 .309 L
.33631 .30944 L
.33929 .30997 L
.34226 .31107 L
.34524 .31133 L
.34821 .31388 L
.35119 .31642 L
.35417 .31821 L
.35714 .32049 L
.36012 .31414 L
.3631 .30677 L
.36607 .30044 L
.36905 .29131 L
.37202 .28497 L
.375 .27769 L
.37798 .26811 L
.38095 .25835 L
.38393 .27075 L
.3869 .28514 L
.38988 .29664 L
.39286 .31503 L
.39583 .32466 L
.39881 .33624 L
.40179 .35356 L
.40476 .37059 L
.40774 .35323 L
.41071 .33308 L
.41369 .31754 L
.41667 .29147 L
.41964 .2798 L
.42262 .26533 L
.4256 .24204 L
.42857 .21958 L
.43155 .24536 L
.43452 .27507 L
.4375 .29845 L
.44048 .33666 L
.44345 .35454 L
.44643 .37639 L
.4494 .4107 L
.45238 .44386 L
.45536 .40813 L
.45833 .36679 L
.46131 .33445 L
.46429 .28094 L
.46726 .25639 L
Mistroke
.47024 .22616 L
.47321 .17813 L
.47619 .13172 L
.47917 .16674 L
.48214 .20765 L
.48512 .2373 L
.4881 .2915 L
.49107 .30992 L
.49405 .33439 L
.49702 .37949 L
.5 .42181 L
.50298 .39887 L
.50595 .37224 L
.50893 .3551 L
.5119 .31881 L
.51488 .3137 L
.51786 .30452 L
.52083 .27916 L
.52381 .25723 L
.52679 .25052 L
.52976 .24291 L
.53274 .23236 L
.53571 .22537 L
.53869 .20675 L
.54167 .18774 L
.54464 .17193 L
.54762 .15327 L
.5506 .19953 L
.55357 .25325 L
.55655 .29918 L
.55952 .36612 L
.5625 .41128 L
.56548 .46338 L
.56845 .53285 L
.57143 .60332 L
.5744 .53674 L
.57738 .45867 L
.58036 .39929 L
.58333 .29787 L
.58631 .25234 L
.58929 .19553 L
.59226 .10371 L
.59524 .01472 L
.59821 .07804 L
.60119 .15176 L
.60417 .20378 L
.60714 .30131 L
.61012 .33078 L
.6131 .37099 L
.61607 .44938 L
Mistroke
.61905 .52185 L
.62202 .48606 L
.625 .44457 L
.62798 .4188 L
.63095 .36142 L
.63393 .35703 L
.6369 .34615 L
.63988 .30845 L
.64286 .27695 L
.64583 .2718 L
.64881 .26558 L
.65179 .25481 L
.65476 .25056 L
.65774 .22702 L
.66071 .20329 L
.66369 .18547 L
.66667 .16325 L
.66964 .19393 L
.67262 .23048 L
.6756 .25986 L
.67857 .30603 L
.68155 .33479 L
.68452 .36882 L
.6875 .4165 L
.69048 .46479 L
.69345 .42855 L
.69643 .38607 L
.6994 .3559 L
.70238 .30037 L
.70536 .28096 L
.70833 .25538 L
.71131 .20873 L
.71429 .1648 L
.71726 .19109 L
.72024 .22153 L
.72321 .24184 L
.72619 .28284 L
.72917 .29074 L
.73214 .30315 L
.73512 .33302 L
.7381 .35941 L
.74107 .35058 L
.74405 .34049 L
.74702 .33557 L
.75 .32062 L
.75298 .32461 L
.75595 .32688 L
.75893 .32051 L
.7619 .31686 L
.76488 .31459 L
Mistroke
.76786 .31149 L
.77083 .30822 L
.77381 .305 L
.77679 .29847 L
.77976 .29146 L
.78274 .28474 L
.78571 .27686 L
.78869 .28216 L
.79167 .28854 L
.79464 .29278 L
.79762 .30095 L
.8006 .30407 L
.80357 .30816 L
.80655 .3154 L
.80952 .32237 L
.8125 .31851 L
.81548 .31407 L
.81845 .31128 L
.82143 .30535 L
.8244 .30458 L
.82738 .30317 L
.83036 .29913 L
.83333 .29568 L
.83631 .29669 L
.83929 .29782 L
.84226 .29831 L
.84524 .30006 L
.84821 .29929 L
.85119 .29872 L
.85417 .29925 L
.85714 .29939 L
.86012 .29984 L
.8631 .30043 L
.86607 .30097 L
.86905 .30163 L
.87202 .30253 L
.875 .30353 L
.87798 .3046 L
.88095 .3058 L
.88393 .30526 L
.8869 .3046 L
.88988 .30423 L
.89286 .30336 L
.89583 .30321 L
.89881 .30295 L
.90179 .30228 L
.90476 .30168 L
.90774 .30192 L
.91071 .30219 L
.91369 .30233 L
Mistroke
.91667 .30269 L
.91964 .3026 L
.92262 .30253 L
.9256 .30267 L
.92857 .30273 L
.93155 .30269 L
.93452 .30265 L
.9375 .30262 L
.94048 .30255 L
.94345 .30258 L
.94643 .30261 L
.9494 .3026 L
.95238 .30261 L
.95536 .3026 L
.95833 .3026 L
.96131 .3026 L
.96429 .3026 L
.96726 .3026 L
.97024 .3026 L
.97321 .3026 L
.97619 .3026 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.302673 0.160155 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .30267 m
1 .30267 L
s
.21429 0 m
.21429 .61803 L
s
[(w[2, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .30267 m
.02679 .30291 L
.02976 .30318 L
.03274 .30342 L
.03571 .30374 L
.03869 .30399 L
.04167 .30426 L
.04464 .3046 L
.04762 .30494 L
.0506 .3052 L
.05357 .30546 L
.05655 .30576 L
.05952 .30604 L
.0625 .3064 L
.06548 .30677 L
.06845 .30712 L
.07143 .3075 L
.0744 .30777 L
.07738 .30804 L
.08036 .30834 L
.08333 .30861 L
.08631 .30892 L
.08929 .30924 L
.09226 .30953 L
.09524 .30984 L
.09821 .31021 L
.10119 .31059 L
.10417 .31097 L
.10714 .31137 L
.11012 .31175 L
.1131 .31213 L
.11607 .31253 L
.11905 .31294 L
.12202 .31199 L
.125 .31089 L
.12798 .30992 L
.13095 .30851 L
.13393 .30755 L
.1369 .30644 L
.13988 .30495 L
.14286 .30344 L
.14583 .30245 L
.14881 .3014 L
.15179 .30018 L
.15476 .29905 L
.15774 .2975 L
.16071 .29591 L
.16369 .29438 L
.16667 .29272 L
.16964 .2917 L
Mistroke
.17262 .2907 L
.1756 .28956 L
.17857 .28857 L
.18155 .28732 L
.18452 .28608 L
.1875 .28496 L
.19048 .2838 L
.19345 .28224 L
.19643 .28065 L
.1994 .27909 L
.20238 .2774 L
.20536 .27588 L
.20833 .27431 L
.21131 .27264 L
.21429 .27096 L
.21726 .27637 L
.22024 .28263 L
.22321 .28818 L
.22619 .29608 L
.22917 .30157 L
.23214 .3079 L
.23512 .3162 L
.2381 .32465 L
.24107 .33033 L
.24405 .33633 L
.24702 .34325 L
.25 .3497 L
.25298 .35831 L
.25595 .3672 L
.25893 .37575 L
.2619 .38498 L
.26488 .37068 L
.26786 .35372 L
.27083 .33952 L
.27381 .31769 L
.27679 .30397 L
.27976 .28774 L
.28274 .26517 L
.28571 .2423 L
.28869 .22937 L
.29167 .21563 L
.29464 .19899 L
.29762 .18431 L
.3006 .16253 L
.30357 .14006 L
.30655 .11909 L
.30952 .09607 L
.3125 .12156 L
.31548 .15239 L
.31845 .17722 L
Mistroke
.32143 .21761 L
.3244 .24127 L
.32738 .26992 L
.33036 .31142 L
.33333 .35341 L
.33631 .3743 L
.33929 .39661 L
.34226 .42479 L
.34524 .44862 L
.34821 .48708 L
.35119 .52672 L
.35417 .56299 L
.35714 .60332 L
.36012 .57283 L
.3631 .53478 L
.36607 .50606 L
.36905 .45488 L
.37202 .42827 L
.375 .3947 L
.37798 .34272 L
.38095 .2903 L
.38393 .26976 L
.3869 .24753 L
.38988 .21697 L
.39286 .1933 L
.39583 .14833 L
.39881 .10203 L
.40179 .06118 L
.40476 .01472 L
.40774 .04339 L
.41071 .07988 L
.41369 .1059 L
.41667 .1555 L
.41964 .1791 L
.42262 .2098 L
.4256 .25966 L
.42857 .30979 L
.43155 .32487 L
.43452 .34136 L
.4375 .36654 L
.44048 .38383 L
.44345 .42378 L
.44643 .46476 L
.4494 .49945 L
.45238 .5398 L
.45536 .5201 L
.45833 .49427 L
.46131 .47727 L
.46429 .44161 L
.46726 .42651 L
Mistroke
.47024 .40595 L
.47321 .37035 L
.47619 .33464 L
.47917 .32803 L
.48214 .32057 L
.48512 .30621 L
.4881 .29862 L
.49107 .27282 L
.49405 .24645 L
.49702 .22553 L
.5 .20027 L
.50298 .20699 L
.50595 .21684 L
.50893 .22145 L
.5119 .23578 L
.51488 .23935 L
.51786 .24558 L
.52083 .25948 L
.52381 .27331 L
.52679 .27042 L
.52976 .26764 L
.53274 .26846 L
.53571 .26513 L
.53869 .27161 L
.54167 .27807 L
.54464 .28115 L
.54762 .28631 L
.5506 .28794 L
.55357 .28932 L
.55655 .29187 L
.55952 .29356 L
.5625 .29607 L
.56548 .29852 L
.56845 .30048 L
.57143 .30253 L
.5744 .30786 L
.57738 .31351 L
.58036 .31879 L
.58333 .32512 L
.58631 .33016 L
.58929 .33553 L
.59226 .34178 L
.59524 .34802 L
.59821 .34354 L
.60119 .33797 L
.60417 .33366 L
.60714 .32593 L
.61012 .32223 L
.6131 .31746 L
.61607 .30982 L
Mistroke
.61905 .30219 L
.62202 .29887 L
.625 .29524 L
.62798 .29044 L
.63095 .28652 L
.63393 .27955 L
.6369 .27234 L
.63988 .26582 L
.64286 .25846 L
.64583 .26203 L
.64881 .26668 L
.65179 .26976 L
.65476 .27624 L
.65774 .27886 L
.66071 .28247 L
.66369 .28883 L
.66667 .29518 L
.66964 .29637 L
.67262 .29772 L
.6756 .3003 L
.67857 .30167 L
.68155 .3063 L
.68452 .31103 L
.6875 .3148 L
.69048 .31935 L
.69345 .31846 L
.69643 .31705 L
.6994 .31656 L
.70238 .31443 L
.70536 .31413 L
.70833 .3134 L
.71131 .31137 L
.71429 .30938 L
.71726 .31026 L
.72024 .31114 L
.72321 .31143 L
.72619 .31244 L
.72917 .31179 L
.73214 .31115 L
.73512 .31112 L
.7381 .31074 L
.74107 .3102 L
.74405 .30963 L
.74702 .30894 L
.75 .30816 L
.75298 .30751 L
.75595 .3068 L
.75893 .30596 L
.7619 .30511 L
.76488 .30402 L
Mistroke
.76786 .30285 L
.77083 .30165 L
.77381 .30034 L
.77679 .29903 L
.77976 .29764 L
.78274 .29615 L
.78571 .2946 L
.78869 .29519 L
.79167 .29597 L
.79464 .29647 L
.79762 .29764 L
.8006 .298 L
.80357 .29856 L
.80655 .29966 L
.80952 .30075 L
.8125 .30092 L
.81548 .30113 L
.81845 .30157 L
.82143 .30179 L
.8244 .30262 L
.82738 .30348 L
.83036 .30417 L
.83333 .305 L
.83631 .30474 L
.83929 .30438 L
.84226 .30421 L
.84524 .3037 L
.84821 .30358 L
.85119 .30337 L
.85417 .3029 L
.85714 .30244 L
.86012 .30256 L
.8631 .30269 L
.86607 .3027 L
.86905 .30285 L
.87202 .30268 L
.875 .30251 L
.87798 .30246 L
.88095 .30235 L
.88393 .3024 L
.8869 .30245 L
.88988 .30248 L
.89286 .30255 L
.89583 .30258 L
.89881 .30263 L
.90179 .30271 L
.90476 .30279 L
.90774 .30276 L
.91071 .30272 L
.91369 .30271 L
Mistroke
.91667 .30266 L
.91964 .30267 L
.92262 .30268 L
.9256 .30266 L
.92857 .30266 L
.93155 .30266 L
.93452 .30267 L
.9375 .30267 L
.94048 .30268 L
.94345 .30268 L
.94643 .30267 L
.9494 .30267 L
.95238 .30267 L
.95536 .30267 L
.95833 .30267 L
.96131 .30267 L
.96429 .30267 L
.96726 .30267 L
.97024 .30267 L
.97321 .30267 L
.97619 .30267 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.595238 0.190476 0.277066 0.172636 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .27707 m
1 .27707 L
s
.59524 0 m
.59524 .61803 L
s
[(w[3, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .27707 m
.02679 .27709 L
.02976 .27712 L
.03274 .27715 L
.03571 .27719 L
.03869 .27722 L
.04167 .27725 L
.04464 .27729 L
.04762 .27732 L
.0506 .27735 L
.05357 .27738 L
.05655 .27742 L
.05952 .27745 L
.0625 .27749 L
.06548 .27753 L
.06845 .27757 L
.07143 .27762 L
.0744 .27765 L
.07738 .27768 L
.08036 .27771 L
.08333 .27774 L
.08631 .27778 L
.08929 .27781 L
.09226 .27785 L
.09524 .27788 L
.09821 .27793 L
.10119 .27797 L
.10417 .27801 L
.10714 .27806 L
.11012 .2781 L
.1131 .27814 L
.11607 .27819 L
.11905 .27824 L
.12202 .27813 L
.125 .278 L
.12798 .27789 L
.13095 .27773 L
.13393 .27762 L
.1369 .2775 L
.13988 .27733 L
.14286 .27715 L
.14583 .27704 L
.14881 .27692 L
.15179 .27678 L
.15476 .27665 L
.15774 .27648 L
.16071 .27629 L
.16369 .27612 L
.16667 .27593 L
.16964 .27581 L
Mistroke
.17262 .2757 L
.1756 .27557 L
.17857 .27546 L
.18155 .27531 L
.18452 .27517 L
.1875 .27504 L
.19048 .27491 L
.19345 .27473 L
.19643 .27455 L
.1994 .27437 L
.20238 .27418 L
.20536 .27401 L
.20833 .27383 L
.21131 .27364 L
.21429 .27345 L
.21726 .27392 L
.22024 .27448 L
.22321 .27497 L
.22619 .27568 L
.22917 .27616 L
.23214 .27672 L
.23512 .27746 L
.2381 .27822 L
.24107 .27872 L
.24405 .27925 L
.24702 .27986 L
.25 .28043 L
.25298 .2812 L
.25595 .28199 L
.25893 .28276 L
.2619 .28359 L
.26488 .28179 L
.26786 .2797 L
.27083 .2779 L
.27381 .27525 L
.27679 .27349 L
.27976 .27145 L
.28274 .2687 L
.28571 .26591 L
.28869 .26421 L
.29167 .26241 L
.29464 .26029 L
.29762 .25838 L
.3006 .25567 L
.30357 .25288 L
.30655 .25024 L
.30952 .24737 L
.3125 .25084 L
.31548 .25502 L
.31845 .25843 L
Mistroke
.32143 .26388 L
.3244 .26715 L
.32738 .27108 L
.33036 .27671 L
.33333 .2824 L
.33631 .28537 L
.33929 .28855 L
.34226 .29249 L
.34524 .29588 L
.34821 .30119 L
.35119 .30666 L
.35417 .31171 L
.35714 .3173 L
.36012 .31443 L
.3631 .31068 L
.36607 .30809 L
.36905 .30283 L
.37202 .30054 L
.375 .29745 L
.37798 .29218 L
.38095 .28689 L
.38393 .28547 L
.3869 .28388 L
.38988 .28132 L
.39286 .27963 L
.39583 .2754 L
.39881 .27104 L
.40179 .26738 L
.40476 .26307 L
.40774 .26395 L
.41071 .26531 L
.41369 .26582 L
.41667 .2679 L
.41964 .26817 L
.42262 .26885 L
.4256 .27078 L
.42857 .27267 L
.43155 .27189 L
.43452 .27112 L
.4375 .27091 L
.44048 .27002 L
.44345 .27069 L
.44643 .27135 L
.4494 .27145 L
.45238 .27187 L
.45536 .27908 L
.45833 .28715 L
.46131 .2947 L
.46429 .30455 L
.46726 .31209 L
Mistroke
.47024 .3205 L
.47321 .3309 L
.47619 .34149 L
.47917 .34973 L
.48214 .35838 L
.48512 .36796 L
.4881 .37722 L
.49107 .38854 L
.49405 .40023 L
.49702 .41171 L
.5 .42394 L
.50298 .40397 L
.50595 .38032 L
.50893 .36034 L
.5119 .32989 L
.51488 .31051 L
.51786 .28766 L
.52083 .25607 L
.52381 .22403 L
.52679 .20538 L
.52976 .18555 L
.53274 .16174 L
.53571 .1405 L
.53869 .10953 L
.54167 .07758 L
.54464 .04758 L
.54762 .01472 L
.5506 .02687 L
.55357 .0436 L
.55655 .05413 L
.55952 .07875 L
.5625 .08745 L
.56548 .10034 L
.56845 .12474 L
.57143 .14918 L
.5744 .15298 L
.57738 .15761 L
.58036 .16733 L
.58333 .17238 L
.58631 .19081 L
.58929 .20983 L
.59226 .22513 L
.59524 .24377 L
.59821 .25851 L
.60119 .27358 L
.60417 .29081 L
.60714 .30758 L
.61012 .32604 L
.6131 .34507 L
.61607 .36413 L
Mistroke
.61905 .38395 L
.62202 .40864 L
.625 .43439 L
.62798 .46032 L
.63095 .48825 L
.63393 .51516 L
.6369 .54315 L
.63988 .57292 L
.64286 .60332 L
.64583 .58089 L
.64881 .55273 L
.65179 .53067 L
.65476 .49158 L
.65774 .47144 L
.66071 .44579 L
.66369 .40589 L
.66667 .3656 L
.66964 .34696 L
.67262 .32658 L
.6756 .3 L
.67857 .27771 L
.68155 .23987 L
.68452 .2006 L
.6875 .16466 L
.69048 .12425 L
.69345 .13107 L
.69643 .14224 L
.6994 .14602 L
.70238 .16415 L
.70536 .16519 L
.70833 .17007 L
.71131 .18649 L
.71429 .20245 L
.71726 .19521 L
.72024 .1882 L
.72321 .1861 L
.72619 .17826 L
.72917 .18426 L
.73214 .19026 L
.73512 .19153 L
.7381 .19576 L
.74107 .20097 L
.74405 .20661 L
.74702 .21335 L
.75 .22089 L
.75298 .22766 L
.75595 .2351 L
.75893 .24354 L
.7619 .25231 L
.76488 .26341 L
Mistroke
.76786 .27529 L
.77083 .28748 L
.77381 .30081 L
.77679 .31418 L
.77976 .32831 L
.78274 .34345 L
.78571 .3592 L
.78869 .35328 L
.79167 .3453 L
.79464 .34019 L
.79762 .32831 L
.8006 .32462 L
.80357 .31897 L
.80655 .30772 L
.80952 .29662 L
.8125 .29487 L
.81548 .29273 L
.81845 .28832 L
.82143 .28603 L
.8244 .27759 L
.82738 .26887 L
.83036 .26187 L
.83333 .25332 L
.83631 .25598 L
.83929 .25967 L
.84226 .26145 L
.84524 .2666 L
.84821 .26785 L
.85119 .26997 L
.85417 .27474 L
.85714 .27941 L
.86012 .27817 L
.8631 .2769 L
.86607 .27683 L
.86905 .27523 L
.87202 .27702 L
.875 .27872 L
.87798 .27919 L
.88095 .28031 L
.88393 .27989 L
.8869 .27928 L
.88988 .27904 L
.89286 .27836 L
.89583 .27798 L
.89881 .27748 L
.90179 .27668 L
.90476 .27584 L
.90774 .27618 L
.91071 .27656 L
.91369 .27671 L
Mistroke
.91667 .27718 L
.91964 .27706 L
.92262 .27697 L
.9256 .27715 L
.92857 .27723 L
.93155 .27718 L
.93452 .27713 L
.9375 .27709 L
.94048 .277 L
.94345 .27704 L
.94643 .27707 L
.9494 .27706 L
.95238 .27707 L
.95536 .27707 L
.95833 .27706 L
.96131 .27707 L
.96429 .27707 L
.96726 .27707 L
.97024 .27707 L
.97321 .27707 L
.97619 .27707 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.15053 0.352 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .15053 m
1 .15053 L
s
.02381 0 m
.02381 .61803 L
s
[(w[0, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .15053 m
.02679 .15544 L
.02976 .16097 L
.03274 .16602 L
.03571 .17271 L
.03869 .17778 L
.04167 .18345 L
.04464 .1905 L
.04762 .19768 L
.0506 .20295 L
.05357 .20846 L
.05655 .21464 L
.05952 .2205 L
.0625 .22789 L
.06548 .23549 L
.06845 .24287 L
.07143 .25075 L
.0744 .25638 L
.07738 .26195 L
.08036 .26809 L
.08333 .27367 L
.08631 .28024 L
.08929 .28679 L
.09226 .29294 L
.09524 .29926 L
.09821 .30702 L
.10119 .31495 L
.10417 .32279 L
.10714 .33111 L
.11012 .33887 L
.1131 .3468 L
.11607 .35517 L
.11905 .36355 L
.12202 .36961 L
.125 .37552 L
.12798 .38178 L
.13095 .38735 L
.13393 .39396 L
.1369 .40041 L
.13988 .40629 L
.14286 .41227 L
.14583 .41925 L
.14881 .42624 L
.15179 .43307 L
.15476 .44016 L
.15774 .44668 L
.16071 .45322 L
.16369 .45999 L
.16667 .46666 L
.16964 .47482 L
Mistroke
.17262 .48317 L
.1756 .49135 L
.17857 .50002 L
.18155 .50826 L
.18452 .51667 L
.1875 .52549 L
.19048 .53437 L
.19345 .54258 L
.19643 .55085 L
.1994 .55935 L
.20238 .56772 L
.20536 .57658 L
.20833 .5855 L
.21131 .59433 L
.21429 .60332 L
.21726 .59797 L
.22024 .59089 L
.22321 .58529 L
.22619 .57495 L
.22917 .56941 L
.23214 .56221 L
.23512 .55104 L
.2381 .53955 L
.24107 .53381 L
.24405 .52743 L
.24702 .51918 L
.25 .51194 L
.25298 .5003 L
.25595 .48809 L
.25893 .47663 L
.2619 .46378 L
.26488 .4575 L
.26786 .45146 L
.27083 .44383 L
.27381 .4379 L
.27679 .42916 L
.27976 .42057 L
.28274 .41322 L
.28571 .40542 L
.28869 .39351 L
.29167 .3812 L
.29464 .36923 L
.29762 .35591 L
.3006 .3443 L
.30357 .33225 L
.30655 .31902 L
.30952 .3058 L
.3125 .29968 L
.31548 .29411 L
.31845 .28755 L
Mistroke
.32143 .28315 L
.3244 .27574 L
.32738 .26888 L
.33036 .26381 L
.33333 .25855 L
.33631 .25033 L
.33929 .24216 L
.34226 .23458 L
.34524 .22628 L
.34821 .21982 L
.35119 .21336 L
.35417 .20628 L
.35714 .1996 L
.36012 .18857 L
.3631 .17703 L
.36607 .16609 L
.36905 .15375 L
.37202 .1428 L
.375 .1314 L
.37798 .11888 L
.38095 .10629 L
.38393 .09577 L
.3869 .08513 L
.38988 .07394 L
.39286 .06319 L
.39583 .05106 L
.39881 .03884 L
.40179 .02696 L
.40476 .01472 L
.40774 .0161 L
.41071 .01908 L
.41369 .02053 L
.41667 .02643 L
.41964 .02775 L
.42262 .03058 L
.4256 .03712 L
.42857 .0439 L
.43155 .045 L
.43452 .04662 L
.4375 .04997 L
.44048 .05226 L
.44345 .05872 L
.44643 .06562 L
.4494 .07173 L
.45238 .07908 L
.45536 .08033 L
.45833 .08128 L
.46131 .08366 L
.46429 .08442 L
.46726 .08768 L
Mistroke
.47024 .09076 L
.47321 .09265 L
.47619 .09489 L
.47917 .10088 L
.48214 .10719 L
.48512 .11312 L
.4881 .12025 L
.49107 .12574 L
.49405 .13158 L
.49702 .13845 L
.5 .14526 L
.50298 .14481 L
.50595 .14373 L
.50893 .14355 L
.5119 .14112 L
.51488 .14163 L
.51786 .14149 L
.52083 .13945 L
.52381 .13753 L
.52679 .13853 L
.52976 .1394 L
.53274 .13957 L
.53571 .14041 L
.53869 .13928 L
.54167 .13807 L
.54464 .13741 L
.54762 .13625 L
.5506 .13936 L
.55357 .14289 L
.55655 .14574 L
.55952 .14989 L
.5625 .15258 L
.56548 .15562 L
.56845 .1597 L
.57143 .16377 L
.5744 .16568 L
.57738 .16763 L
.58036 .17004 L
.58333 .17192 L
.58631 .1751 L
.58929 .17828 L
.59226 .18103 L
.59524 .18406 L
.59821 .1832 L
.60119 .18189 L
.60417 .18108 L
.60714 .179 L
.61012 .17819 L
.6131 .17696 L
.61607 .17471 L
Mistroke
.61905 .17239 L
.62202 .17185 L
.625 .17119 L
.62798 .17002 L
.63095 .16923 L
.63393 .16721 L
.6369 .16509 L
.63988 .16325 L
.64286 .16107 L
.64583 .16041 L
.64881 .15983 L
.65179 .1589 L
.65476 .15837 L
.65774 .15723 L
.66071 .15615 L
.66369 .15537 L
.66667 .1545 L
.66964 .15268 L
.67262 .15078 L
.6756 .14898 L
.67857 .14689 L
.68155 .14521 L
.68452 .14345 L
.6875 .14143 L
.69048 .13943 L
.69345 .13994 L
.69643 .14071 L
.6994 .14119 L
.70238 .14246 L
.70536 .14278 L
.70833 .14334 L
.71131 .14457 L
.71429 .1458 L
.71726 .14603 L
.72024 .14633 L
.72321 .1469 L
.72619 .14727 L
.72917 .14834 L
.73214 .14947 L
.73512 .15043 L
.7381 .15159 L
.74107 .15137 L
.74405 .15103 L
.74702 .15095 L
.75 .15046 L
.75298 .15048 L
.75595 .15042 L
.75893 .15004 L
.7619 .14969 L
.76488 .15009 L
Mistroke
.76786 .15051 L
.77083 .1508 L
.77381 .15129 L
.77679 .15138 L
.77976 .1515 L
.78274 .15179 L
.78571 .15202 L
.78869 .15194 L
.79167 .15183 L
.79464 .15174 L
.79762 .15155 L
.8006 .15151 L
.80357 .15144 L
.80655 .15128 L
.80952 .15112 L
.8125 .15104 L
.81548 .15095 L
.81845 .15083 L
.82143 .15072 L
.8244 .15054 L
.82738 .15035 L
.83036 .15017 L
.83333 .14997 L
.83631 .15003 L
.83929 .15012 L
.84226 .15017 L
.84524 .1503 L
.84821 .15032 L
.85119 .15037 L
.85417 .15048 L
.85714 .15058 L
.86012 .15055 L
.8631 .15053 L
.86607 .15052 L
.86905 .15049 L
.87202 .15053 L
.875 .15057 L
.87798 .15058 L
.88095 .1506 L
.88393 .15059 L
.8869 .15058 L
.88988 .15057 L
.89286 .15056 L
.89583 .15055 L
.89881 .15054 L
.90179 .15052 L
.90476 .1505 L
.90774 .15051 L
.91071 .15052 L
.91369 .15052 L
Mistroke
.91667 .15053 L
.91964 .15053 L
.92262 .15053 L
.9256 .15053 L
.92857 .15053 L
.93155 .15053 L
.93452 .15053 L
.9375 .15053 L
.94048 .15053 L
.94345 .15053 L
.94643 .15053 L
.9494 .15053 L
.95238 .15053 L
.95536 .15053 L
.95833 .15053 L
.96131 .15053 L
.96429 .15053 L
.96726 .15053 L
.97024 .15053 L
.97321 .15053 L
.97619 .15053 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.246907 0.209516 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .24691 m
1 .24691 L
s
.40476 0 m
.40476 .61803 L
s
[(w[1, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .24691 m
.02679 .24722 L
.02976 .24757 L
.03274 .24788 L
.03571 .24831 L
.03869 .24863 L
.04167 .24898 L
.04464 .24943 L
.04762 .24988 L
.0506 .25021 L
.05357 .25056 L
.05655 .25095 L
.05952 .25132 L
.0625 .25178 L
.06548 .25226 L
.06845 .25273 L
.07143 .25322 L
.0744 .25358 L
.07738 .25393 L
.08036 .25432 L
.08333 .25467 L
.08631 .25508 L
.08929 .2555 L
.09226 .25588 L
.09524 .25628 L
.09821 .25677 L
.10119 .25727 L
.10417 .25776 L
.10714 .25829 L
.11012 .25878 L
.1131 .25928 L
.11607 .25981 L
.11905 .26033 L
.12202 .26072 L
.125 .26109 L
.12798 .26148 L
.13095 .26183 L
.13393 .26225 L
.1369 .26266 L
.13988 .26303 L
.14286 .2634 L
.14583 .26384 L
.14881 .26428 L
.15179 .26472 L
.15476 .26516 L
.15774 .26557 L
.16071 .26599 L
.16369 .26641 L
.16667 .26683 L
.16964 .26735 L
Mistroke
.17262 .26787 L
.1756 .26839 L
.17857 .26893 L
.18155 .26945 L
.18452 .26998 L
.1875 .27054 L
.19048 .2711 L
.19345 .27162 L
.19643 .27214 L
.1994 .27267 L
.20238 .2732 L
.20536 .27376 L
.20833 .27432 L
.21131 .27488 L
.21429 .27545 L
.21726 .27349 L
.22024 .27123 L
.22321 .26922 L
.22619 .26637 L
.22917 .26435 L
.23214 .26203 L
.23512 .25901 L
.2381 .25593 L
.24107 .25384 L
.24405 .25162 L
.24702 .24907 L
.25 .24669 L
.25298 .24353 L
.25595 .24026 L
.25893 .23711 L
.2619 .23371 L
.26488 .23146 L
.26786 .22925 L
.27083 .22675 L
.27381 .22455 L
.27679 .22183 L
.27976 .21914 L
.28274 .21666 L
.28571 .21409 L
.28869 .21078 L
.29167 .2074 L
.29464 .20407 L
.29762 .2005 L
.3006 .19722 L
.30357 .19385 L
.30655 .19026 L
.30952 .18668 L
.3125 .1843 L
.31548 .18201 L
.31845 .17953 L
Mistroke
.32143 .17742 L
.3244 .17479 L
.32738 .17223 L
.33036 .16998 L
.33333 .16769 L
.33631 .16487 L
.33929 .16206 L
.34226 .15934 L
.34524 .15648 L
.34821 .15393 L
.35119 .15138 L
.35417 .1487 L
.35714 .14609 L
.36012 .14271 L
.3631 .13924 L
.36607 .13586 L
.36905 .13224 L
.37202 .12884 L
.375 .12535 L
.37798 .12167 L
.38095 .11796 L
.38393 .11459 L
.3869 .1112 L
.38988 .10771 L
.39286 .10428 L
.39583 .1006 L
.39881 .0969 L
.40179 .09325 L
.40476 .08952 L
.40774 .10076 L
.41071 .11386 L
.41369 .12546 L
.41667 .14205 L
.41964 .15366 L
.42262 .16705 L
.4256 .18463 L
.42857 .20258 L
.43155 .21462 L
.43452 .22737 L
.4375 .24212 L
.44048 .25587 L
.44345 .27424 L
.44643 .29323 L
.4494 .31152 L
.45238 .33129 L
.45536 .34421 L
.45833 .35691 L
.46131 .37133 L
.46429 .384 L
.46726 .39967 L
Mistroke
.47024 .41523 L
.47321 .42952 L
.47619 .44433 L
.47917 .46348 L
.48214 .48311 L
.48512 .50241 L
.4881 .52317 L
.49107 .54218 L
.49405 .5617 L
.49702 .5825 L
.5 .60332 L
.50298 .5905 L
.50595 .57384 L
.50893 .5608 L
.5119 .53677 L
.51488 .52459 L
.51786 .50872 L
.52083 .48359 L
.52381 .45803 L
.52679 .44582 L
.52976 .4323 L
.53274 .41465 L
.53571 .39947 L
.53869 .37429 L
.54167 .34797 L
.54464 .32352 L
.54762 .29603 L
.5506 .28518 L
.55357 .27522 L
.55655 .26163 L
.55952 .25255 L
.5625 .23672 L
.56548 .22154 L
.56845 .20976 L
.57143 .19712 L
.5744 .17466 L
.57738 .15148 L
.58036 .12943 L
.58333 .10434 L
.58631 .08377 L
.58929 .06239 L
.59226 .03839 L
.59524 .01472 L
.59821 .02202 L
.60119 .03263 L
.60417 .03982 L
.60714 .05702 L
.61012 .06274 L
.6131 .0717 L
.61607 .08909 L
Mistroke
.61905 .10664 L
.62202 .11205 L
.625 .11852 L
.62798 .12854 L
.63095 .1362 L
.63393 .15278 L
.6369 .17024 L
.63988 .18588 L
.64286 .20414 L
.64583 .20587 L
.64881 .2065 L
.65179 .21041 L
.65476 .20966 L
.65774 .21531 L
.66071 .22008 L
.66369 .22126 L
.66667 .22305 L
.66964 .2341 L
.67262 .2456 L
.6756 .25576 L
.67857 .26862 L
.68155 .27684 L
.68452 .2856 L
.6875 .29665 L
.69048 .30714 L
.69345 .30452 L
.69643 .3006 L
.6994 .2981 L
.70238 .29138 L
.70536 .28987 L
.70833 .28705 L
.71131 .28064 L
.71429 .27429 L
.71726 .27277 L
.72024 .27083 L
.72321 .26752 L
.72619 .26516 L
.72917 .25921 L
.73214 .25293 L
.73512 .24739 L
.7381 .24081 L
.74107 .24213 L
.74405 .24405 L
.74702 .24455 L
.75 .24735 L
.75298 .24718 L
.75595 .24753 L
.75893 .24968 L
.7619 .25163 L
.76488 .24939 L
Mistroke
.76786 .24704 L
.77083 .24541 L
.77381 .24263 L
.77679 .2421 L
.77976 .24143 L
.78274 .2398 L
.78571 .23853 L
.78869 .239 L
.79167 .23962 L
.79464 .24012 L
.79762 .24119 L
.8006 .24141 L
.80357 .2418 L
.80655 .24271 L
.80952 .24357 L
.8125 .24403 L
.81548 .24456 L
.81845 .24522 L
.82143 .24583 L
.8244 .24684 L
.82738 .2479 L
.83036 .24892 L
.83333 .25007 L
.83631 .24969 L
.83929 .24919 L
.84226 .24893 L
.84524 .24821 L
.84821 .24807 L
.85119 .24782 L
.85417 .2472 L
.85714 .24661 L
.86012 .24677 L
.8631 .24693 L
.86607 .24694 L
.86905 .24714 L
.87202 .24691 L
.875 .24669 L
.87798 .24663 L
.88095 .24649 L
.88393 .24654 L
.8869 .24662 L
.88988 .24665 L
.89286 .24674 L
.89583 .24679 L
.89881 .24685 L
.90179 .24696 L
.90476 .24706 L
.90774 .24702 L
.91071 .24697 L
.91369 .24695 L
Mistroke
.91667 .24689 L
.91964 .24691 L
.92262 .24692 L
.9256 .2469 L
.92857 .24689 L
.93155 .24689 L
.93452 .2469 L
.9375 .2469 L
.94048 .24692 L
.94345 .24691 L
.94643 .24691 L
.9494 .24691 L
.95238 .24691 L
.95536 .24691 L
.95833 .24691 L
.96131 .24691 L
.96429 .24691 L
.96726 .24691 L
.97024 .24691 L
.97321 .24691 L
.97619 .24691 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["WaveletPacket[0,", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " is the same as ",
  StyleBox["ScalingFunction[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  ", and, similarly, both ",
  StyleBox["WaveletPacket[1,", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " and ",
  StyleBox["Wavelet[", "MR"],
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["jmax", "TI"],
  StyleBox["]", "MR"],
  " yield identical results. \nIn this section we introduce a way of getting \
approximate values of the scaling function, wavelet, or wavelet packet at \
dyadic points using inverse wavelet transform or inverse wavelet packet \
transform. This is the so\[Hyphen]called cascade algorithm.In a wavelet \
transform, ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%j}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " are the inner products of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " with the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ". Suppose ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " is one of the basis functions itself, say, the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ", then the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%0} = 0\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\%0 = 0\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " except for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`f\_0\%0 = 1\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " by orthogonality of the functions. So if we take such a data set and do \
inverse wavelet transform, we will get ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%J}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ", the inner products of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Phi] \((\(2\^J\) t - k)\)}\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`J\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " is the number of times the reconstruction has been done. In Section ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.1"},
    ButtonStyle->"AddOnsLink"],
  " we learned that these inner products can be approximated using ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\%J = \(2\^\(-J/2\)\) f \((k/2\^J)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.7"],
  ". Now we are in a reverse situation where the inner products are known and \
we can approximate the function values at ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^J\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`f \((k/2\^J)\) = \(2\^\(J/2\)\) f\_k\%J\)], 
    "InlineFormula",
    CellTags->"S1.5.7"],
  " and the corrections are ",
  Cell[BoxData[
      \(TraditionalForm\`O \((2\^\(-J\))\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ". Similarly, the values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`n > 1\)], "InlineFormula",
    CellTags->"S1.5.7"],
  ") at the dyadic points can be obtained approximately by doing inverse \
wavelet transform and inverse wavelet packet transform, respectively, on the \
data with a single nonzero element placed at the appropriate position. \nThe \
advantage of this method is that for wavelets with noncompact support, the \
sum in the dilation equation is infinite and we cannot expect that the \
dilation equation with a truncated sum will again have an eigenvalue 1. For \
example, if we try to get the spline scaling function of order 3 by solving \
the eigenvalue problem, we simply fail. "
}], "Text",
  CellTags->{"S1.5.7", "7.7"}],

Cell["This gives the spline filter of order 3.", "MathCaption",
  CellTags->{"S1.5.7", "7.8"}],

Cell["h3 = SplineFilter[3, 8];", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"S1.5.7"],

Cell["\<\
The dilation equation with truncated filter no longer has \
eigenvalue 1.\
\>", "MathCaption",
  CellTags->{"S1.5.7", "7.9"}],

Cell[CellGroupData[{

Cell["ScalingFunction[h3, 6]", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"S1.5.7"],

Cell["\<\
ScalingFunction::noder: The eigenvalue 1 does not exist or the \
components of the eigenvector sum to zero. Try the inverse transform \
method.\
\>", "Message",
  CellTags->"S1.5.7"],

Cell[BoxData[
    \(ScalingFunction[{{0.00868529481306950579`, \(-0.0179823209809605906`\), 
          \(-0.0171763154919796097`\), 0.0420683514406834557`, 
          0.0320808974701902815`, \(-0.110037018388013274`\), 
          \(-0.0502017246714501119`\), 0.433922633589276873`, 
          0.766130053759815687`, 0.433922633589276873`, 
          \(-0.0502017246714501119`\), \(-0.110037018388013274`\), 
          0.0320808974701902815`, 0.0420683514406834557`, 
          \(-0.0171763154919796097`\), \(-0.0179823209809605906`\), 
          0.00868529481306950579`}, \(-8\)}, 6]\)], "Output",
  CellLabel->"Out[38]= ",
  CellTags->"S1.5.7"]
}, Open  ]],

Cell[TextData[{
  "To use the inverse transform method to generate the scaling function, \
wavelet, or wavelet packets, we use the same functions (",
  StyleBox["ScalingFunction", "MR"],
  ", ",
  StyleBox["Wavelet", "MR"],
  ", ",
  StyleBox["WaveletPacket", "MR"],
  ") with the ",
  StyleBox["InverseTransform", "MR"],
  " option set to ",
  StyleBox["True", "MR"],
  "."
}], "Text",
  CellTags->{"S1.5.7", "7.10"}],

Cell[TextData[{
  "This gives the approximate values of the scaling function at dyadic points \
",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^6\)], "InlineFormula",
    CellTags->"S1.5.7"],
  " using the inverse transform method."
}], "MathCaption",
  CellTags->{"S1.5.7", "7.11"}],

Cell["ScalingFunction[h3, 6, InverseTransform -> True];", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"S1.5.7"],

Cell["Here is the plot of the above scaling function.", "MathCaption",
  CellTags->{"S1.5.7", "7.12"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"spline phi_3\"}]\
\>", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"S1.5.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.102342 0.449411 [
[.05357 .08984 -12 -9 ]
[.05357 .08984 12 0 ]
[.20238 .08984 -6 -9 ]
[.20238 .08984 6 0 ]
[.35119 .08984 -12 -9 ]
[.35119 .08984 12 0 ]
[.64881 .08984 -9 -9 ]
[.64881 .08984 9 0 ]
[.79762 .08984 -3 -9 ]
[.79762 .08984 3 0 ]
[.94643 .08984 -9 -9 ]
[.94643 .08984 9 0 ]
[1.025 .10234 0 -4.5 ]
[1.025 .10234 6 4.5 ]
[.4875 .01246 -24 -4.5 ]
[.4875 .01246 0 4.5 ]
[.4875 .19222 -18 -4.5 ]
[.4875 .19222 0 4.5 ]
[.4875 .28211 -18 -4.5 ]
[.4875 .28211 0 4.5 ]
[.4875 .37199 -18 -4.5 ]
[.4875 .37199 0 4.5 ]
[.4875 .46187 -18 -4.5 ]
[.4875 .46187 0 4.5 ]
[.4875 .55175 -6 -4.5 ]
[.4875 .55175 0 4.5 ]
[.5 .64303 -36 0 ]
[.5 .64303 36 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .10234 m
.05357 .10859 L
s
[(-7.5)] .05357 .08984 0 1 Mshowa
.20238 .10234 m
.20238 .10859 L
s
[(-5)] .20238 .08984 0 1 Mshowa
.35119 .10234 m
.35119 .10859 L
s
[(-2.5)] .35119 .08984 0 1 Mshowa
.64881 .10234 m
.64881 .10859 L
s
[(2.5)] .64881 .08984 0 1 Mshowa
.79762 .10234 m
.79762 .10859 L
s
[(5)] .79762 .08984 0 1 Mshowa
.94643 .10234 m
.94643 .10859 L
s
[(7.5)] .94643 .08984 0 1 Mshowa
.125 Mabswid
.08333 .10234 m
.08333 .10609 L
s
.1131 .10234 m
.1131 .10609 L
s
.14286 .10234 m
.14286 .10609 L
s
.17262 .10234 m
.17262 .10609 L
s
.23214 .10234 m
.23214 .10609 L
s
.2619 .10234 m
.2619 .10609 L
s
.29167 .10234 m
.29167 .10609 L
s
.32143 .10234 m
.32143 .10609 L
s
.38095 .10234 m
.38095 .10609 L
s
.41071 .10234 m
.41071 .10609 L
s
.44048 .10234 m
.44048 .10609 L
s
.47024 .10234 m
.47024 .10609 L
s
.52976 .10234 m
.52976 .10609 L
s
.55952 .10234 m
.55952 .10609 L
s
.58929 .10234 m
.58929 .10609 L
s
.61905 .10234 m
.61905 .10609 L
s
.67857 .10234 m
.67857 .10609 L
s
.70833 .10234 m
.70833 .10609 L
s
.7381 .10234 m
.7381 .10609 L
s
.76786 .10234 m
.76786 .10609 L
s
.82738 .10234 m
.82738 .10609 L
s
.85714 .10234 m
.85714 .10609 L
s
.8869 .10234 m
.8869 .10609 L
s
.91667 .10234 m
.91667 .10609 L
s
.02381 .10234 m
.02381 .10609 L
s
.97619 .10234 m
.97619 .10609 L
s
.25 Mabswid
0 .10234 m
1 .10234 L
s
[(t)] 1.025 .10234 -1 0 Mshowa
.5 .01246 m
.50625 .01246 L
s
[(-0.2)] .4875 .01246 1 0 Mshowa
.5 .19222 m
.50625 .19222 L
s
[(0.2)] .4875 .19222 1 0 Mshowa
.5 .28211 m
.50625 .28211 L
s
[(0.4)] .4875 .28211 1 0 Mshowa
.5 .37199 m
.50625 .37199 L
s
[(0.6)] .4875 .37199 1 0 Mshowa
.5 .46187 m
.50625 .46187 L
s
[(0.8)] .4875 .46187 1 0 Mshowa
.5 .55175 m
.50625 .55175 L
s
[(1)] .4875 .55175 1 0 Mshowa
.125 Mabswid
.5 .03493 m
.50375 .03493 L
s
.5 .0574 m
.50375 .0574 L
s
.5 .07987 m
.50375 .07987 L
s
.5 .12481 m
.50375 .12481 L
s
.5 .14728 m
.50375 .14728 L
s
.5 .16975 m
.50375 .16975 L
s
.5 .21469 m
.50375 .21469 L
s
.5 .23717 m
.50375 .23717 L
s
.5 .25964 m
.50375 .25964 L
s
.5 .30458 m
.50375 .30458 L
s
.5 .32705 m
.50375 .32705 L
s
.5 .34952 m
.50375 .34952 L
s
.5 .39446 m
.50375 .39446 L
s
.5 .41693 m
.50375 .41693 L
s
.5 .4394 m
.50375 .4394 L
s
.5 .48434 m
.50375 .48434 L
s
.5 .50681 m
.50375 .50681 L
s
.5 .52928 m
.50375 .52928 L
s
.5 .57422 m
.50375 .57422 L
s
.5 .59669 m
.50375 .59669 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(spline phi_3)] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .10234 m
.02474 .10234 L
.02567 .10234 L
.0266 .10234 L
.02753 .10234 L
.02846 .10234 L
.02939 .10234 L
.03032 .10234 L
.03125 .10234 L
.03218 .10234 L
.03311 .10234 L
.03404 .10234 L
.03497 .10234 L
.0359 .10234 L
.03683 .10234 L
.03776 .10234 L
.03869 .10234 L
.03962 .10234 L
.04055 .10234 L
.04148 .10234 L
.04241 .10234 L
.04334 .10234 L
.04427 .10234 L
.0452 .10234 L
.04613 .10234 L
.04706 .10234 L
.04799 .10234 L
.04892 .10234 L
.04985 .10234 L
.05078 .10234 L
.05171 .10234 L
.05264 .10234 L
.05357 .10234 L
.0545 .10234 L
.05543 .10234 L
.05636 .10234 L
.05729 .10234 L
.05822 .10234 L
.05915 .10234 L
.06008 .10234 L
.06101 .10234 L
.06194 .10234 L
.06287 .10234 L
.0638 .10234 L
.06473 .10234 L
.06566 .10234 L
.06659 .10234 L
.06752 .10234 L
.06845 .10234 L
.06938 .10234 L
Mistroke
.07031 .10234 L
.07124 .10234 L
.07217 .10234 L
.0731 .10234 L
.07403 .10234 L
.07496 .10234 L
.07589 .10234 L
.07682 .10234 L
.07775 .10234 L
.07868 .10234 L
.07961 .10234 L
.08054 .10234 L
.08147 .10234 L
.0824 .10234 L
.08333 .10234 L
.08426 .10234 L
.08519 .10234 L
.08612 .10234 L
.08705 .10234 L
.08798 .10234 L
.08891 .10234 L
.08984 .10234 L
.09077 .10234 L
.0917 .10234 L
.09263 .10234 L
.09356 .10234 L
.09449 .10234 L
.09542 .10234 L
.09635 .10234 L
.09728 .10234 L
.09821 .10234 L
.09914 .10234 L
.10007 .10234 L
.101 .10234 L
.10193 .10234 L
.10286 .10235 L
.10379 .10235 L
.10472 .10235 L
.10565 .10235 L
.10658 .10235 L
.10751 .10235 L
.10844 .10235 L
.10938 .10235 L
.11031 .10235 L
.11124 .10235 L
.11217 .10235 L
.1131 .10235 L
.11403 .10234 L
.11496 .10234 L
.11589 .10234 L
Mistroke
.11682 .10234 L
.11775 .10233 L
.11868 .10233 L
.11961 .10233 L
.12054 .10233 L
.12147 .10233 L
.1224 .10233 L
.12333 .10233 L
.12426 .10234 L
.12519 .10234 L
.12612 .10234 L
.12705 .10234 L
.12798 .10234 L
.12891 .10235 L
.12984 .10235 L
.13077 .10236 L
.1317 .10236 L
.13263 .10236 L
.13356 .10237 L
.13449 .10237 L
.13542 .10237 L
.13635 .10238 L
.13728 .10238 L
.13821 .10239 L
.13914 .10239 L
.14007 .1024 L
.141 .1024 L
.14193 .1024 L
.14286 .1024 L
.14379 .1024 L
.14472 .1024 L
.14565 .1024 L
.14658 .1024 L
.14751 .1024 L
.14844 .10239 L
.14937 .10238 L
.1503 .10237 L
.15123 .10236 L
.15216 .10234 L
.15309 .10232 L
.15402 .10229 L
.15495 .10228 L
.15588 .10226 L
.15681 .10224 L
.15774 .10221 L
.15867 .10219 L
.1596 .10216 L
.16053 .10213 L
.16146 .1021 L
.16239 .10209 L
Mistroke
.16332 .10206 L
.16425 .10206 L
.16518 .10204 L
.16611 .10203 L
.16704 .10201 L
.16797 .10201 L
.1689 .10201 L
.16983 .10201 L
.17076 .10201 L
.17169 .10204 L
.17262 .10206 L
.17355 .10209 L
.17448 .10212 L
.17541 .10216 L
.17634 .10221 L
.17727 .10225 L
.1782 .1023 L
.17913 .10237 L
.18006 .10244 L
.18099 .10251 L
.18192 .1026 L
.18285 .10268 L
.18378 .10277 L
.18471 .10283 L
.18564 .1029 L
.18657 .10294 L
.1875 .103 L
.18843 .10303 L
.18936 .10307 L
.19029 .10308 L
.19122 .10311 L
.19215 .1031 L
.19308 .1031 L
.19401 .10307 L
.19494 .10306 L
.19587 .10304 L
.1968 .10305 L
.19773 .10302 L
.19866 .103 L
.19959 .10296 L
.20052 .10293 L
.20145 .10286 L
.20238 .10278 L
.20331 .10269 L
.20424 .10259 L
.20517 .10247 L
.2061 .10235 L
.20703 .10224 L
.20796 .10211 L
.20889 .10199 L
Mistroke
.20982 .10184 L
.21075 .10171 L
.21168 .10155 L
.21261 .10142 L
.21354 .10129 L
.21447 .10121 L
.2154 .10114 L
.21633 .10111 L
.21726 .10104 L
.21819 .101 L
.21912 .10093 L
.22005 .10094 L
.22098 .10093 L
.22191 .10099 L
.22284 .10104 L
.22377 .10115 L
.2247 .10121 L
.22563 .10124 L
.22656 .10122 L
.22749 .10128 L
.22842 .10134 L
.22935 .10143 L
.23028 .10156 L
.23121 .10176 L
.23214 .10198 L
.23307 .10215 L
.234 .10235 L
.23493 .1026 L
.23586 .1029 L
.23679 .10314 L
.23772 .10344 L
.23865 .10376 L
.23958 .10413 L
.24051 .10432 L
.24144 .10459 L
.24237 .10481 L
.2433 .10514 L
.24423 .10525 L
.24516 .10551 L
.24609 .10571 L
.24702 .1061 L
.24795 .10627 L
.24888 .10665 L
.24981 .1069 L
.25074 .10732 L
.25167 .10741 L
.2526 .10767 L
.25353 .10777 L
.25446 .1081 L
.25539 .10814 L
Mistroke
.25632 .1084 L
.25725 .10845 L
.25818 .10866 L
.25911 .10848 L
.26004 .10844 L
.26097 .1082 L
.2619 .10819 L
.26283 .10797 L
.26376 .10796 L
.26469 .10771 L
.26563 .1076 L
.26656 .10719 L
.26749 .10687 L
.26842 .10633 L
.26935 .10595 L
.27028 .10555 L
.27121 .10524 L
.27214 .10477 L
.27307 .10428 L
.274 .10374 L
.27493 .10309 L
.27586 .10234 L
.27679 .10152 L
.27772 .10093 L
.27865 .10021 L
.27958 .09947 L
.28051 .09854 L
.28144 .09789 L
.28237 .097 L
.2833 .09618 L
.28423 .09516 L
.28516 .09471 L
.28609 .09398 L
.28702 .09346 L
.28795 .09256 L
.28888 .0923 L
.28981 .09158 L
.29074 .09111 L
.29167 .09015 L
.2926 .08999 L
.29353 .08929 L
.29446 .08892 L
.29539 .08801 L
.29632 .08803 L
.29725 .08748 L
.29818 .08731 L
.29911 .08657 L
.30004 .08687 L
.30097 .08657 L
.3019 .08667 L
Mistroke
.30283 .08617 L
.30376 .08678 L
.30469 .08672 L
.30562 .08703 L
.30655 .0866 L
.30748 .08715 L
.30841 .08698 L
.30934 .08718 L
.31027 .08677 L
.3112 .08746 L
.31213 .08759 L
.31306 .08807 L
.31399 .08793 L
.31492 .08866 L
.31585 .08883 L
.31678 .08935 L
.31771 .0894 L
.31864 .09037 L
.31957 .09094 L
.3205 .09182 L
.32143 .09217 L
.32236 .093 L
.32329 .09341 L
.32422 .09414 L
.32515 .09455 L
.32608 .09542 L
.32701 .09615 L
.32794 .09718 L
.32887 .09798 L
.3298 .09874 L
.33073 .09947 L
.33166 .10042 L
.33259 .10152 L
.33352 .10247 L
.33445 .10379 L
.33538 .10526 L
.33631 .10709 L
.33724 .10832 L
.33817 .11006 L
.3391 .11178 L
.34003 .11408 L
.34096 .11552 L
.34189 .11762 L
.34282 .1194 L
.34375 .12176 L
.34468 .12268 L
.34561 .12428 L
.34654 .12532 L
.34747 .12723 L
.3484 .1276 L
Mistroke
.34933 .12901 L
.35026 .12976 L
.35119 .13157 L
.35212 .13155 L
.35305 .13272 L
.35398 .13311 L
.35491 .13464 L
.35584 .13402 L
.35677 .13464 L
.3577 .13451 L
.35863 .13561 L
.35956 .13442 L
.36049 .13458 L
.36142 .13398 L
.36235 .13473 L
.36328 .133 L
.36421 .13278 L
.36514 .13196 L
.36607 .13296 L
.367 .13198 L
.36793 .13274 L
.36886 .13278 L
.36979 .13429 L
.37072 .13345 L
.37165 .13381 L
.37258 .1333 L
.37351 .13415 L
.37444 .13332 L
.37537 .13355 L
.3763 .1328 L
.37723 .13284 L
.37816 .13111 L
.37909 .12985 L
.38002 .12759 L
.38095 .12606 L
.38188 .12377 L
.38281 .12192 L
.38374 .11913 L
.38467 .11656 L
.3856 .11339 L
.38653 .1102 L
.38746 .10645 L
.38839 .10295 L
.38932 .10022 L
.39025 .09741 L
.39118 .09448 L
.39211 .09091 L
.39304 .08819 L
.39397 .08438 L
.3949 .08078 L
Mistroke
.39583 .07618 L
.39676 .07368 L
.39769 .0698 L
.39862 .0665 L
.39955 .06169 L
.40048 .05956 L
.40141 .05564 L
.40234 .0527 L
.40327 .04827 L
.4042 .04796 L
.40513 .04572 L
.40606 .04486 L
.40699 .0415 L
.40792 .04245 L
.40885 .04023 L
.40978 .03921 L
.41071 .03463 L
.41164 .03455 L
.41257 .03068 L
.4135 .02834 L
.41443 .02275 L
.41536 .02287 L
.41629 .01993 L
.41722 .01889 L
.41815 .01485 L
.41908 .01669 L
.42001 .01552 L
.42094 .0167 L
.42188 .01472 L
.42281 .01891 L
.42374 .01965 L
.42467 .0224 L
.4256 .02055 L
.42653 .02291 L
.42746 .02101 L
.42839 .02143 L
.42932 .01884 L
.43025 .02189 L
.43118 .02282 L
.43211 .02629 L
.43304 .02723 L
.43397 .03166 L
.4349 .03424 L
.43583 .03949 L
.43676 .04351 L
.43769 .05128 L
.43862 .05819 L
.43955 .06691 L
.44048 .07302 L
.44141 .07816 L
Mistroke
.44234 .0817 L
.44327 .08686 L
.4442 .09255 L
.44513 .09859 L
.44606 .10668 L
.44699 .11596 L
.44792 .1263 L
.44885 .13199 L
.44978 .14008 L
.45071 .14881 L
.45164 .16157 L
.45257 .17004 L
.4535 .18359 L
.45443 .19647 L
.45536 .21218 L
.45629 .21642 L
.45722 .22506 L
.45815 .23237 L
.45908 .2468 L
.46001 .25117 L
.46094 .26457 L
.46187 .27587 L
.4628 .29453 L
.46373 .29598 L
.46466 .30655 L
.46559 .3142 L
.46652 .3334 L
.46745 .33646 L
.46838 .35256 L
.46931 .36459 L
.47024 .38713 L
.47117 .38535 L
.4721 .39571 L
.47303 .40128 L
.47396 .4219 L
.47489 .42021 L
.47582 .43521 L
.47675 .44459 L
.47768 .46842 L
.47861 .46216 L
.47954 .4718 L
.48047 .47501 L
.4814 .49707 L
.48233 .49156 L
.48326 .50611 L
.48419 .5134 L
.48512 .53815 L
.48605 .52786 L
.48698 .53604 L
.48791 .53634 L
Mistroke
.48884 .55805 L
.48977 .54816 L
.4907 .5604 L
.49163 .56411 L
.49256 .58723 L
.49349 .572 L
.49442 .57671 L
.49535 .57246 L
.49628 .59117 L
.49721 .5762 L
.49814 .5845 L
.49907 .58366 L
.5 .60332 L
.50093 .58366 L
.50186 .5845 L
.50279 .5762 L
.50372 .59117 L
.50465 .57246 L
.50558 .57671 L
.50651 .572 L
.50744 .58723 L
.50837 .56411 L
.5093 .5604 L
.51023 .54816 L
.51116 .55805 L
.51209 .53634 L
.51302 .53604 L
.51395 .52786 L
.51488 .53815 L
.51581 .5134 L
.51674 .50611 L
.51767 .49156 L
.5186 .49707 L
.51953 .47501 L
.52046 .4718 L
.52139 .46216 L
.52232 .46842 L
.52325 .44459 L
.52418 .43521 L
.52511 .42021 L
.52604 .4219 L
.52697 .40128 L
.5279 .39571 L
.52883 .38535 L
.52976 .38713 L
.53069 .36459 L
.53162 .35256 L
.53255 .33646 L
.53348 .3334 L
.53441 .3142 L
Mistroke
.53534 .30655 L
.53627 .29598 L
.5372 .29453 L
.53813 .27587 L
.53906 .26457 L
.53999 .25117 L
.54092 .2468 L
.54185 .23237 L
.54278 .22506 L
.54371 .21642 L
.54464 .21218 L
.54557 .19647 L
.5465 .18359 L
.54743 .17004 L
.54836 .16157 L
.54929 .14881 L
.55022 .14008 L
.55115 .13199 L
.55208 .1263 L
.55301 .11596 L
.55394 .10668 L
.55487 .09859 L
.5558 .09255 L
.55673 .08686 L
.55766 .0817 L
.55859 .07816 L
.55952 .07302 L
.56045 .06691 L
.56138 .05819 L
.56231 .05128 L
.56324 .04351 L
.56417 .03949 L
.5651 .03424 L
.56603 .03166 L
.56696 .02723 L
.56789 .02629 L
.56882 .02282 L
.56975 .02189 L
.57068 .01884 L
.57161 .02143 L
.57254 .02101 L
.57347 .02291 L
.5744 .02055 L
.57533 .0224 L
.57626 .01965 L
.57719 .01891 L
.57812 .01472 L
.57906 .0167 L
.57999 .01552 L
.58092 .01669 L
Mistroke
.58185 .01485 L
.58278 .01889 L
.58371 .01993 L
.58464 .02287 L
.58557 .02275 L
.5865 .02834 L
.58743 .03068 L
.58836 .03455 L
.58929 .03463 L
.59022 .03921 L
.59115 .04023 L
.59208 .04245 L
.59301 .0415 L
.59394 .04486 L
.59487 .04572 L
.5958 .04796 L
.59673 .04827 L
.59766 .0527 L
.59859 .05564 L
.59952 .05956 L
.60045 .06169 L
.60138 .0665 L
.60231 .0698 L
.60324 .07368 L
.60417 .07618 L
.6051 .08078 L
.60603 .08438 L
.60696 .08819 L
.60789 .09091 L
.60882 .09448 L
.60975 .09741 L
.61068 .10022 L
.61161 .10295 L
.61254 .10645 L
.61347 .1102 L
.6144 .11339 L
.61533 .11656 L
.61626 .11913 L
.61719 .12192 L
.61812 .12377 L
.61905 .12606 L
.61998 .12759 L
.62091 .12985 L
.62184 .13111 L
.62277 .13284 L
.6237 .1328 L
.62463 .13355 L
.62556 .13332 L
.62649 .13415 L
.62742 .1333 L
Mistroke
.62835 .13381 L
.62928 .13345 L
.63021 .13429 L
.63114 .13278 L
.63207 .13274 L
.633 .13198 L
.63393 .13296 L
.63486 .13196 L
.63579 .13278 L
.63672 .133 L
.63765 .13473 L
.63858 .13398 L
.63951 .13458 L
.64044 .13442 L
.64137 .13561 L
.6423 .13451 L
.64323 .13464 L
.64416 .13402 L
.64509 .13464 L
.64602 .13311 L
.64695 .13272 L
.64788 .13155 L
.64881 .13157 L
.64974 .12976 L
.65067 .12901 L
.6516 .1276 L
.65253 .12723 L
.65346 .12532 L
.65439 .12428 L
.65532 .12268 L
.65625 .12176 L
.65718 .1194 L
.65811 .11762 L
.65904 .11552 L
.65997 .11408 L
.6609 .11178 L
.66183 .11006 L
.66276 .10832 L
.66369 .10709 L
.66462 .10526 L
.66555 .10379 L
.66648 .10247 L
.66741 .10152 L
.66834 .10042 L
.66927 .09947 L
.6702 .09874 L
.67113 .09798 L
.67206 .09718 L
.67299 .09615 L
.67392 .09542 L
Mistroke
.67485 .09455 L
.67578 .09414 L
.67671 .09341 L
.67764 .093 L
.67857 .09217 L
.6795 .09182 L
.68043 .09094 L
.68136 .09037 L
.68229 .0894 L
.68322 .08935 L
.68415 .08883 L
.68508 .08866 L
.68601 .08793 L
.68694 .08807 L
.68787 .08759 L
.6888 .08746 L
.68973 .08677 L
.69066 .08718 L
.69159 .08698 L
.69252 .08715 L
.69345 .0866 L
.69438 .08703 L
.69531 .08672 L
.69624 .08678 L
.69717 .08617 L
.6981 .08667 L
.69903 .08657 L
.69996 .08687 L
.70089 .08657 L
.70182 .08731 L
.70275 .08748 L
.70368 .08803 L
.70461 .08801 L
.70554 .08892 L
.70647 .08929 L
.7074 .08999 L
.70833 .09015 L
.70926 .09111 L
.71019 .09158 L
.71112 .0923 L
.71205 .09256 L
.71298 .09346 L
.71391 .09398 L
.71484 .09471 L
.71577 .09516 L
.7167 .09618 L
.71763 .097 L
.71856 .09789 L
.71949 .09854 L
.72042 .09947 L
Mistroke
.72135 .10021 L
.72228 .10093 L
.72321 .10152 L
.72414 .10234 L
.72507 .10309 L
.726 .10374 L
.72693 .10428 L
.72786 .10477 L
.72879 .10524 L
.72972 .10555 L
.73065 .10595 L
.73158 .10633 L
.73251 .10687 L
.73344 .10719 L
.73437 .1076 L
.73531 .10771 L
.73624 .10796 L
.73717 .10797 L
.7381 .10819 L
.73903 .1082 L
.73996 .10844 L
.74089 .10848 L
.74182 .10866 L
.74275 .10845 L
.74368 .1084 L
.74461 .10814 L
.74554 .1081 L
.74647 .10777 L
.7474 .10767 L
.74833 .10741 L
.74926 .10732 L
.75019 .1069 L
.75112 .10665 L
.75205 .10627 L
.75298 .1061 L
.75391 .10571 L
.75484 .10551 L
.75577 .10525 L
.7567 .10514 L
.75763 .10481 L
.75856 .10459 L
.75949 .10432 L
.76042 .10413 L
.76135 .10376 L
.76228 .10344 L
.76321 .10314 L
.76414 .1029 L
.76507 .1026 L
.766 .10235 L
.76693 .10215 L
Mistroke
.76786 .10198 L
.76879 .10176 L
.76972 .10156 L
.77065 .10143 L
.77158 .10134 L
.77251 .10128 L
.77344 .10122 L
.77437 .10124 L
.7753 .10121 L
.77623 .10115 L
.77716 .10104 L
.77809 .10099 L
.77902 .10093 L
.77995 .10094 L
.78088 .10093 L
.78181 .101 L
.78274 .10104 L
.78367 .10111 L
.7846 .10114 L
.78553 .10121 L
.78646 .10129 L
.78739 .10142 L
.78832 .10155 L
.78925 .10171 L
.79018 .10184 L
.79111 .10199 L
.79204 .10211 L
.79297 .10224 L
.7939 .10235 L
.79483 .10247 L
.79576 .10259 L
.79669 .10269 L
.79762 .10278 L
.79855 .10286 L
.79948 .10293 L
.80041 .10296 L
.80134 .103 L
.80227 .10302 L
.8032 .10305 L
.80413 .10304 L
.80506 .10306 L
.80599 .10307 L
.80692 .1031 L
.80785 .1031 L
.80878 .10311 L
.80971 .10308 L
.81064 .10307 L
.81157 .10303 L
.8125 .103 L
.81343 .10294 L
Mistroke
.81436 .1029 L
.81529 .10283 L
.81622 .10277 L
.81715 .10268 L
.81808 .1026 L
.81901 .10251 L
.81994 .10244 L
.82087 .10237 L
.8218 .1023 L
.82273 .10225 L
.82366 .10221 L
.82459 .10216 L
.82552 .10212 L
.82645 .10209 L
.82738 .10206 L
.82831 .10204 L
.82924 .10201 L
.83017 .10201 L
.8311 .10201 L
.83203 .10201 L
.83296 .10201 L
.83389 .10203 L
.83482 .10204 L
.83575 .10206 L
.83668 .10206 L
.83761 .10209 L
.83854 .1021 L
.83947 .10213 L
.8404 .10216 L
.84133 .10219 L
.84226 .10221 L
.84319 .10224 L
.84412 .10226 L
.84505 .10228 L
.84598 .10229 L
.84691 .10232 L
.84784 .10234 L
.84877 .10236 L
.8497 .10237 L
.85063 .10238 L
.85156 .10239 L
.85249 .1024 L
.85342 .1024 L
.85435 .1024 L
.85528 .1024 L
.85621 .1024 L
.85714 .1024 L
.85807 .1024 L
.859 .1024 L
.85993 .1024 L
Mistroke
.86086 .10239 L
.86179 .10239 L
.86272 .10238 L
.86365 .10238 L
.86458 .10237 L
.86551 .10237 L
.86644 .10237 L
.86737 .10236 L
.8683 .10236 L
.86923 .10236 L
.87016 .10235 L
.87109 .10235 L
.87202 .10234 L
.87295 .10234 L
.87388 .10234 L
.87481 .10234 L
.87574 .10234 L
.87667 .10233 L
.8776 .10233 L
.87853 .10233 L
.87946 .10233 L
.88039 .10233 L
.88132 .10233 L
.88225 .10233 L
.88318 .10234 L
.88411 .10234 L
.88504 .10234 L
.88597 .10234 L
.8869 .10235 L
.88783 .10235 L
.88876 .10235 L
.88969 .10235 L
.89062 .10235 L
.89156 .10235 L
.89249 .10235 L
.89342 .10235 L
.89435 .10235 L
.89528 .10235 L
.89621 .10235 L
.89714 .10235 L
.89807 .10234 L
.899 .10234 L
.89993 .10234 L
.90086 .10234 L
.90179 .10234 L
.90272 .10234 L
.90365 .10234 L
.90458 .10234 L
.90551 .10234 L
.90644 .10234 L
Mistroke
.90737 .10234 L
.9083 .10234 L
.90923 .10234 L
.91016 .10234 L
.91109 .10234 L
.91202 .10234 L
.91295 .10234 L
.91388 .10234 L
.91481 .10234 L
.91574 .10234 L
.91667 .10234 L
.9176 .10234 L
.91853 .10234 L
.91946 .10234 L
.92039 .10234 L
.92132 .10234 L
.92225 .10234 L
.92318 .10234 L
.92411 .10234 L
.92504 .10234 L
.92597 .10234 L
.9269 .10234 L
.92783 .10234 L
.92876 .10234 L
.92969 .10234 L
.93062 .10234 L
.93155 .10234 L
.93248 .10234 L
.93341 .10234 L
.93434 .10234 L
.93527 .10234 L
.9362 .10234 L
.93713 .10234 L
.93806 .10234 L
.93899 .10234 L
.93992 .10234 L
.94085 .10234 L
.94178 .10234 L
.94271 .10234 L
.94364 .10234 L
.94457 .10234 L
.9455 .10234 L
.94643 .10234 L
.94736 .10234 L
.94829 .10234 L
.94922 .10234 L
.95015 .10234 L
.95108 .10234 L
.95201 .10234 L
.95294 .10234 L
Mistroke
.95387 .10234 L
.9548 .10234 L
.95573 .10234 L
.95666 .10234 L
.95759 .10234 L
.95852 .10234 L
.95945 .10234 L
.96038 .10234 L
.96131 .10234 L
.96224 .10234 L
.96317 .10234 L
.9641 .10234 L
.96503 .10234 L
.96596 .10234 L
.96689 .10234 L
.96782 .10234 L
.96875 .10234 L
.96968 .10234 L
.97061 .10234 L
.97154 .10234 L
.97247 .10234 L
.9734 .10234 L
.97433 .10234 L
.97526 .10234 L
.97619 .10234 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],

Cell["\<\
Here are some of the wavelet packets generated from the spline \
filter of order 3 using the inverse transform method.\
\>", "MathCaption",
  CellTags->{"S1.5.7", "7.13"}],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[Partition[
Table[ListPlot[WaveletPacket[i, h3, 6,
InverseTransform -> True],
PlotLabel -> \"w[\"<>ToString[i]<>\", t]\",
DisplayFunction -> Identity, Ticks -> None,
PlotJoined -> True, PlotRange -> All], {i, 1, 4}], 2]
], PlotLabel -> \"spline wavelet packets\"]\
\>", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"S1.5.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(spline wavelet packets)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.455357 0.0595238 0.274761 0.251354 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .27476 m
1 .27476 L
s
.45536 0 m
.45536 .61803 L
s
[(w[3, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .27476 m
.02474 .27476 L
.02567 .27476 L
.0266 .27476 L
.02753 .27476 L
.02846 .27476 L
.02939 .27476 L
.03032 .27476 L
.03125 .27476 L
.03218 .27476 L
.03311 .27476 L
.03404 .27476 L
.03497 .27476 L
.0359 .27476 L
.03683 .27476 L
.03776 .27476 L
.03869 .27476 L
.03962 .27476 L
.04055 .27476 L
.04148 .27476 L
.04241 .27476 L
.04334 .27476 L
.04427 .27476 L
.0452 .27476 L
.04613 .27476 L
.04706 .27476 L
.04799 .27476 L
.04892 .27476 L
.04985 .27476 L
.05078 .27476 L
.05171 .27476 L
.05264 .27476 L
.05357 .27476 L
.0545 .27476 L
.05543 .27476 L
.05636 .27476 L
.05729 .27476 L
.05822 .27476 L
.05915 .27476 L
.06008 .27476 L
.06101 .27476 L
.06194 .27476 L
.06287 .27476 L
.0638 .27476 L
.06473 .27476 L
.06566 .27476 L
.06659 .27476 L
.06752 .27476 L
.06845 .27476 L
.06938 .27476 L
Mistroke
.07031 .27476 L
.07124 .27476 L
.07217 .27476 L
.0731 .27476 L
.07403 .27476 L
.07496 .27476 L
.07589 .27476 L
.07682 .27476 L
.07775 .27476 L
.07868 .27476 L
.07961 .27476 L
.08054 .27476 L
.08147 .27476 L
.0824 .27476 L
.08333 .27476 L
.08426 .27476 L
.08519 .27476 L
.08612 .27476 L
.08705 .27476 L
.08798 .27476 L
.08891 .27476 L
.08984 .27476 L
.09077 .27476 L
.0917 .27476 L
.09263 .27476 L
.09356 .27476 L
.09449 .27476 L
.09542 .27476 L
.09635 .27476 L
.09728 .27476 L
.09821 .27476 L
.09914 .27476 L
.10007 .27476 L
.101 .27476 L
.10193 .27476 L
.10286 .27476 L
.10379 .27476 L
.10472 .27476 L
.10565 .27476 L
.10658 .27476 L
.10751 .27476 L
.10844 .27476 L
.10938 .27476 L
.11031 .27476 L
.11124 .27476 L
.11217 .27476 L
.1131 .27476 L
.11403 .27476 L
.11496 .27476 L
.11589 .27476 L
Mistroke
.11682 .27476 L
.11775 .27476 L
.11868 .27476 L
.11961 .27476 L
.12054 .27476 L
.12147 .27476 L
.1224 .27476 L
.12333 .27476 L
.12426 .27476 L
.12519 .27476 L
.12612 .27476 L
.12705 .27476 L
.12798 .27476 L
.12891 .27476 L
.12984 .27476 L
.13077 .27476 L
.1317 .27477 L
.13263 .27477 L
.13356 .27477 L
.13449 .27477 L
.13542 .27477 L
.13635 .27477 L
.13728 .27478 L
.13821 .27478 L
.13914 .27478 L
.14007 .27478 L
.141 .27479 L
.14193 .27479 L
.14286 .2748 L
.14379 .2748 L
.14472 .2748 L
.14565 .27481 L
.14658 .27482 L
.14751 .27482 L
.14844 .27482 L
.14937 .27483 L
.1503 .27483 L
.15123 .27484 L
.15216 .27484 L
.15309 .27484 L
.15402 .27484 L
.15495 .27484 L
.15588 .27485 L
.15681 .27484 L
.15774 .27484 L
.15867 .27484 L
.1596 .27484 L
.16053 .27483 L
.16146 .27483 L
.16239 .27482 L
Mistroke
.16332 .27482 L
.16425 .27481 L
.16518 .27481 L
.16611 .2748 L
.16704 .27479 L
.16797 .27478 L
.1689 .27478 L
.16983 .27477 L
.17076 .27477 L
.17169 .27476 L
.17262 .27476 L
.17355 .27476 L
.17448 .27475 L
.17541 .27475 L
.17634 .27475 L
.17727 .27475 L
.1782 .27475 L
.17913 .27475 L
.18006 .27475 L
.18099 .27475 L
.18192 .27475 L
.18285 .27475 L
.18378 .27475 L
.18471 .27474 L
.18564 .27474 L
.18657 .27474 L
.1875 .27473 L
.18843 .27473 L
.18936 .27473 L
.19029 .27472 L
.19122 .27472 L
.19215 .27472 L
.19308 .27473 L
.19401 .27473 L
.19494 .27473 L
.19587 .27474 L
.1968 .27474 L
.19773 .27474 L
.19866 .27473 L
.19959 .27474 L
.20052 .27474 L
.20145 .27474 L
.20238 .27472 L
.20331 .27472 L
.20424 .27471 L
.20517 .27469 L
.2061 .27466 L
.20703 .27463 L
.20796 .27459 L
.20889 .27456 L
Mistroke
.20982 .27453 L
.21075 .2745 L
.21168 .27448 L
.21261 .27448 L
.21354 .27448 L
.21447 .27447 L
.2154 .27447 L
.21633 .27448 L
.21726 .27452 L
.21819 .27457 L
.21912 .27463 L
.22005 .2747 L
.22098 .27481 L
.22191 .27493 L
.22284 .27506 L
.22377 .27515 L
.2247 .27524 L
.22563 .27533 L
.22656 .2754 L
.22749 .27541 L
.22842 .27541 L
.22935 .27544 L
.23028 .27543 L
.23121 .27537 L
.23214 .27523 L
.23307 .27509 L
.234 .27487 L
.23493 .27465 L
.23586 .27434 L
.23679 .27404 L
.23772 .27371 L
.23865 .27347 L
.23958 .27323 L
.24051 .27299 L
.24144 .2728 L
.24237 .27274 L
.2433 .27271 L
.24423 .27264 L
.24516 .27264 L
.24609 .27278 L
.24702 .27308 L
.24795 .2734 L
.24888 .27385 L
.24981 .27438 L
.25074 .27502 L
.25167 .27564 L
.2526 .2763 L
.25353 .27684 L
.25446 .27741 L
.25539 .27796 L
Mistroke
.25632 .27845 L
.25725 .27874 L
.25818 .27898 L
.25911 .27925 L
.26004 .2794 L
.26097 .27926 L
.2619 .27892 L
.26283 .2785 L
.26376 .2779 L
.26469 .2771 L
.26563 .27615 L
.26656 .27525 L
.26749 .27432 L
.26842 .27342 L
.26935 .27245 L
.27028 .2715 L
.27121 .27059 L
.27214 .2699 L
.27307 .26924 L
.274 .26861 L
.27493 .26812 L
.27586 .26805 L
.27679 .26816 L
.27772 .26838 L
.27865 .26878 L
.27958 .26956 L
.28051 .27047 L
.28144 .2713 L
.28237 .27218 L
.2833 .27325 L
.28423 .27441 L
.28516 .27555 L
.28609 .27668 L
.28702 .27777 L
.28795 .27888 L
.28888 .27987 L
.28981 .28077 L
.29074 .28134 L
.29167 .28188 L
.2926 .28228 L
.29353 .28262 L
.29446 .28252 L
.29539 .28244 L
.29632 .28232 L
.29725 .28223 L
.29818 .28167 L
.29911 .28108 L
.30004 .28041 L
.30097 .27974 L
.3019 .27874 L
Mistroke
.30283 .27771 L
.30376 .27675 L
.30469 .2758 L
.30562 .27478 L
.30655 .27361 L
.30748 .27246 L
.30841 .27122 L
.30934 .27018 L
.31027 .26897 L
.3112 .26781 L
.31213 .26661 L
.31306 .26593 L
.31399 .26521 L
.31492 .26462 L
.31585 .26409 L
.31678 .26419 L
.31771 .26433 L
.31864 .26445 L
.31957 .26469 L
.3205 .26553 L
.32143 .26668 L
.32236 .26799 L
.32329 .26955 L
.32422 .27141 L
.32515 .27354 L
.32608 .27561 L
.32701 .27773 L
.32794 .27962 L
.32887 .28163 L
.3298 .28361 L
.33073 .28549 L
.33166 .28675 L
.33259 .28794 L
.33352 .28911 L
.33445 .29 L
.33538 .28994 L
.33631 .28947 L
.33724 .28881 L
.33817 .28776 L
.3391 .28589 L
.34003 .28373 L
.34096 .2817 L
.34189 .27957 L
.34282 .27709 L
.34375 .27436 L
.34468 .27172 L
.34561 .26906 L
.34654 .26659 L
.34747 .26408 L
.3484 .26186 L
Mistroke
.34933 .25983 L
.35026 .25862 L
.35119 .25749 L
.35212 .25671 L
.35305 .25606 L
.35398 .25649 L
.35491 .25686 L
.35584 .25737 L
.35677 .25781 L
.3577 .2593 L
.35863 .26077 L
.35956 .26235 L
.36049 .26388 L
.36142 .26614 L
.36235 .26844 L
.36328 .27062 L
.36421 .27278 L
.36514 .27511 L
.36607 .27775 L
.367 .28026 L
.36793 .28298 L
.36886 .28525 L
.36979 .28799 L
.37072 .29056 L
.37165 .29336 L
.37258 .29502 L
.37351 .29689 L
.37444 .29836 L
.37537 .29985 L
.3763 .29992 L
.37723 .29997 L
.37816 .29977 L
.37909 .2994 L
.38002 .29772 L
.38095 .29547 L
.38188 .29264 L
.38281 .28941 L
.38374 .28545 L
.38467 .28101 L
.3856 .27621 L
.38653 .2715 L
.38746 .2673 L
.38839 .2633 L
.38932 .25934 L
.39025 .25603 L
.39118 .25389 L
.39211 .25215 L
.39304 .24999 L
.39397 .24853 L
.3949 .24877 L
Mistroke
.39583 .25022 L
.39676 .25214 L
.39769 .25505 L
.39862 .25926 L
.39955 .26407 L
.40048 .26851 L
.40141 .2729 L
.40234 .27728 L
.40327 .28195 L
.4042 .28668 L
.40513 .29104 L
.40606 .29444 L
.40699 .29767 L
.40792 .30118 L
.40885 .30386 L
.40978 .30432 L
.41071 .30378 L
.41164 .30326 L
.41257 .30156 L
.4135 .29783 L
.41443 .29351 L
.41536 .29074 L
.41629 .28737 L
.41722 .28248 L
.41815 .27592 L
.41908 .26979 L
.42001 .26237 L
.42094 .25498 L
.42187 .2466 L
.42281 .2404 L
.42374 .23384 L
.42467 .22939 L
.4256 .22335 L
.42653 .2181 L
.42746 .21198 L
.42839 .2093 L
.42932 .20563 L
.43025 .20278 L
.43118 .20001 L
.43211 .20234 L
.43304 .20497 L
.43397 .20792 L
.4349 .21186 L
.43583 .22012 L
.43676 .22928 L
.43769 .23642 L
.43862 .245 L
.43955 .25662 L
.44048 .27186 L
.44141 .28615 L
Mistroke
.44234 .30361 L
.44327 .32051 L
.4442 .34042 L
.44513 .35606 L
.44606 .37345 L
.44699 .38598 L
.44792 .40222 L
.44885 .41593 L
.44978 .43171 L
.45071 .43943 L
.45164 .44858 L
.45257 .45376 L
.4535 .45854 L
.45443 .4527 L
.45536 .44623 L
.45629 .43698 L
.45722 .4266 L
.45815 .40743 L
.45908 .38703 L
.46001 .36666 L
.46094 .34538 L
.46187 .31889 L
.4628 .2898 L
.46373 .26174 L
.46466 .23213 L
.46559 .20342 L
.46652 .17294 L
.46745 .14795 L
.46838 .1223 L
.46931 .1036 L
.47024 .0815 L
.47117 .06435 L
.4721 .04457 L
.47303 .03647 L
.47396 .02527 L
.47489 .02127 L
.47582 .01472 L
.47675 .02222 L
.47768 .02569 L
.47861 .03371 L
.47954 .03824 L
.48047 .05561 L
.4814 .07118 L
.48233 .09074 L
.48326 .10927 L
.48419 .13751 L
.48512 .16699 L
.48605 .19823 L
.48698 .23045 L
.48791 .26526 L
Mistroke
.48884 .30283 L
.48977 .33824 L
.4907 .37544 L
.49163 .40769 L
.49256 .44415 L
.49349 .4769 L
.49442 .51229 L
.49535 .53549 L
.49628 .56112 L
.49721 .57883 L
.49814 .59755 L
.49907 .59953 L
.5 .60332 L
.50093 .59953 L
.50186 .59755 L
.50279 .57883 L
.50372 .56112 L
.50465 .53549 L
.50558 .51229 L
.50651 .4769 L
.50744 .44415 L
.50837 .40769 L
.5093 .37544 L
.51023 .33824 L
.51116 .30283 L
.51209 .26526 L
.51302 .23045 L
.51395 .19823 L
.51488 .16699 L
.51581 .13751 L
.51674 .10927 L
.51767 .09074 L
.5186 .07118 L
.51953 .05561 L
.52046 .03824 L
.52139 .03371 L
.52232 .02569 L
.52325 .02222 L
.52418 .01472 L
.52511 .02127 L
.52604 .02527 L
.52697 .03647 L
.5279 .04457 L
.52883 .06435 L
.52976 .0815 L
.53069 .1036 L
.53162 .1223 L
.53255 .14795 L
.53348 .17294 L
.53441 .20342 L
Mistroke
.53534 .23213 L
.53627 .26174 L
.5372 .2898 L
.53813 .31889 L
.53906 .34538 L
.53999 .36666 L
.54092 .38703 L
.54185 .40743 L
.54278 .4266 L
.54371 .43698 L
.54464 .44623 L
.54557 .4527 L
.5465 .45854 L
.54743 .45376 L
.54836 .44858 L
.54929 .43943 L
.55022 .43171 L
.55115 .41593 L
.55208 .40222 L
.55301 .38598 L
.55394 .37345 L
.55487 .35606 L
.5558 .34042 L
.55673 .32051 L
.55766 .30361 L
.55859 .28615 L
.55952 .27186 L
.56045 .25662 L
.56138 .245 L
.56231 .23642 L
.56324 .22928 L
.56417 .22012 L
.5651 .21186 L
.56603 .20792 L
.56696 .20497 L
.56789 .20234 L
.56882 .20001 L
.56975 .20278 L
.57068 .20563 L
.57161 .2093 L
.57254 .21198 L
.57347 .2181 L
.5744 .22335 L
.57533 .22939 L
.57626 .23384 L
.57719 .2404 L
.57812 .2466 L
.57906 .25498 L
.57999 .26237 L
.58092 .26979 L
Mistroke
.58185 .27592 L
.58278 .28248 L
.58371 .28737 L
.58464 .29074 L
.58557 .29351 L
.5865 .29783 L
.58743 .30156 L
.58836 .30326 L
.58929 .30378 L
.59022 .30432 L
.59115 .30386 L
.59208 .30118 L
.59301 .29767 L
.59394 .29444 L
.59487 .29104 L
.5958 .28668 L
.59673 .28195 L
.59766 .27728 L
.59859 .2729 L
.59952 .26851 L
.60045 .26407 L
.60138 .25926 L
.60231 .25505 L
.60324 .25214 L
.60417 .25022 L
.6051 .24877 L
.60603 .24853 L
.60696 .24999 L
.60789 .25215 L
.60882 .25389 L
.60975 .25603 L
.61068 .25934 L
.61161 .2633 L
.61254 .2673 L
.61347 .2715 L
.6144 .27621 L
.61533 .28101 L
.61626 .28545 L
.61719 .28941 L
.61812 .29264 L
.61905 .29547 L
.61998 .29772 L
.62091 .2994 L
.62184 .29977 L
.62277 .29997 L
.6237 .29992 L
.62463 .29985 L
.62556 .29836 L
.62649 .29689 L
.62742 .29502 L
Mistroke
.62835 .29336 L
.62928 .29056 L
.63021 .28799 L
.63114 .28525 L
.63207 .28298 L
.633 .28026 L
.63393 .27775 L
.63486 .27511 L
.63579 .27278 L
.63672 .27062 L
.63765 .26844 L
.63858 .26614 L
.63951 .26388 L
.64044 .26235 L
.64137 .26077 L
.6423 .2593 L
.64323 .25781 L
.64416 .25737 L
.64509 .25686 L
.64602 .25649 L
.64695 .25606 L
.64788 .25671 L
.64881 .25749 L
.64974 .25862 L
.65067 .25983 L
.6516 .26186 L
.65253 .26408 L
.65346 .26659 L
.65439 .26906 L
.65532 .27172 L
.65625 .27436 L
.65718 .27709 L
.65811 .27957 L
.65904 .2817 L
.65997 .28373 L
.6609 .28589 L
.66183 .28776 L
.66276 .28881 L
.66369 .28947 L
.66462 .28994 L
.66555 .29 L
.66648 .28911 L
.66741 .28794 L
.66834 .28675 L
.66927 .28549 L
.6702 .28361 L
.67113 .28163 L
.67206 .27962 L
.67299 .27773 L
.67392 .27561 L
Mistroke
.67485 .27354 L
.67578 .27141 L
.67671 .26955 L
.67764 .26799 L
.67857 .26668 L
.6795 .26553 L
.68043 .26469 L
.68136 .26445 L
.68229 .26433 L
.68322 .26419 L
.68415 .26409 L
.68508 .26462 L
.68601 .26521 L
.68694 .26593 L
.68787 .26661 L
.6888 .26781 L
.68973 .26897 L
.69066 .27018 L
.69159 .27122 L
.69252 .27246 L
.69345 .27361 L
.69438 .27478 L
.69531 .2758 L
.69624 .27675 L
.69717 .27771 L
.6981 .27874 L
.69903 .27974 L
.69996 .28041 L
.70089 .28108 L
.70182 .28167 L
.70275 .28223 L
.70368 .28232 L
.70461 .28244 L
.70554 .28252 L
.70647 .28262 L
.7074 .28228 L
.70833 .28188 L
.70926 .28134 L
.71019 .28077 L
.71112 .27987 L
.71205 .27888 L
.71298 .27777 L
.71391 .27668 L
.71484 .27555 L
.71577 .27441 L
.7167 .27325 L
.71763 .27218 L
.71856 .2713 L
.71949 .27047 L
.72042 .26956 L
Mistroke
.72135 .26878 L
.72228 .26838 L
.72321 .26816 L
.72414 .26805 L
.72507 .26812 L
.726 .26861 L
.72693 .26924 L
.72786 .2699 L
.72879 .27059 L
.72972 .2715 L
.73065 .27245 L
.73158 .27342 L
.73251 .27432 L
.73344 .27525 L
.73437 .27615 L
.73531 .2771 L
.73624 .2779 L
.73717 .2785 L
.7381 .27892 L
.73903 .27926 L
.73996 .2794 L
.74089 .27925 L
.74182 .27898 L
.74275 .27874 L
.74368 .27845 L
.74461 .27796 L
.74554 .27741 L
.74647 .27684 L
.7474 .2763 L
.74833 .27564 L
.74926 .27502 L
.75019 .27438 L
.75112 .27385 L
.75205 .2734 L
.75298 .27308 L
.75391 .27278 L
.75484 .27264 L
.75577 .27264 L
.7567 .27271 L
.75763 .27274 L
.75856 .2728 L
.75949 .27299 L
.76042 .27323 L
.76135 .27347 L
.76228 .27371 L
.76321 .27404 L
.76414 .27434 L
.76507 .27465 L
.766 .27487 L
.76693 .27509 L
Mistroke
.76786 .27523 L
.76879 .27537 L
.76972 .27543 L
.77065 .27544 L
.77158 .27541 L
.77251 .27541 L
.77344 .2754 L
.77437 .27533 L
.7753 .27524 L
.77623 .27515 L
.77716 .27506 L
.77809 .27493 L
.77902 .27481 L
.77995 .2747 L
.78088 .27463 L
.78181 .27457 L
.78274 .27452 L
.78367 .27448 L
.7846 .27447 L
.78553 .27447 L
.78646 .27448 L
.78739 .27448 L
.78832 .27448 L
.78925 .2745 L
.79018 .27453 L
.79111 .27456 L
.79204 .27459 L
.79297 .27463 L
.7939 .27466 L
.79483 .27469 L
.79576 .27471 L
.79669 .27472 L
.79762 .27472 L
.79855 .27474 L
.79948 .27474 L
.80041 .27474 L
.80134 .27473 L
.80227 .27474 L
.8032 .27474 L
.80413 .27474 L
.80506 .27473 L
.80599 .27473 L
.80692 .27473 L
.80785 .27472 L
.80878 .27472 L
.80971 .27472 L
.81064 .27473 L
.81157 .27473 L
.8125 .27473 L
.81343 .27474 L
Mistroke
.81436 .27474 L
.81529 .27474 L
.81622 .27475 L
.81715 .27475 L
.81808 .27475 L
.81901 .27475 L
.81994 .27475 L
.82087 .27475 L
.8218 .27475 L
.82273 .27475 L
.82366 .27475 L
.82459 .27475 L
.82552 .27475 L
.82645 .27476 L
.82738 .27476 L
.82831 .27476 L
.82924 .27477 L
.83017 .27477 L
.8311 .27478 L
.83203 .27478 L
.83296 .27479 L
.83389 .2748 L
.83482 .27481 L
.83575 .27481 L
.83668 .27482 L
.83761 .27482 L
.83854 .27483 L
.83947 .27483 L
.8404 .27484 L
.84133 .27484 L
.84226 .27484 L
.84319 .27484 L
.84412 .27485 L
.84505 .27484 L
.84598 .27484 L
.84691 .27484 L
.84784 .27484 L
.84877 .27484 L
.8497 .27483 L
.85063 .27483 L
.85156 .27482 L
.85249 .27482 L
.85342 .27482 L
.85435 .27481 L
.85528 .2748 L
.85621 .2748 L
.85714 .2748 L
.85807 .27479 L
.859 .27479 L
.85993 .27478 L
Mistroke
.86086 .27478 L
.86179 .27478 L
.86272 .27478 L
.86365 .27477 L
.86458 .27477 L
.86551 .27477 L
.86644 .27477 L
.86737 .27477 L
.8683 .27477 L
.86923 .27476 L
.87016 .27476 L
.87109 .27476 L
.87202 .27476 L
.87295 .27476 L
.87388 .27476 L
.87481 .27476 L
.87574 .27476 L
.87667 .27476 L
.8776 .27476 L
.87853 .27476 L
.87946 .27476 L
.88039 .27476 L
.88132 .27476 L
.88225 .27476 L
.88318 .27476 L
.88411 .27476 L
.88504 .27476 L
.88597 .27476 L
.8869 .27476 L
.88783 .27476 L
.88876 .27476 L
.88969 .27476 L
.89062 .27476 L
.89156 .27476 L
.89249 .27476 L
.89342 .27476 L
.89435 .27476 L
.89528 .27476 L
.89621 .27476 L
.89714 .27476 L
.89807 .27476 L
.899 .27476 L
.89993 .27476 L
.90086 .27476 L
.90179 .27476 L
.90272 .27476 L
.90365 .27476 L
.90458 .27476 L
.90551 .27476 L
.90644 .27476 L
Mistroke
.90737 .27476 L
.9083 .27476 L
.90923 .27476 L
.91016 .27476 L
.91109 .27476 L
.91202 .27476 L
.91295 .27476 L
.91388 .27476 L
.91481 .27476 L
.91574 .27476 L
.91667 .27476 L
.9176 .27476 L
.91853 .27476 L
.91946 .27476 L
.92039 .27476 L
.92132 .27476 L
.92225 .27476 L
.92318 .27476 L
.92411 .27476 L
.92504 .27476 L
.92597 .27476 L
.9269 .27476 L
.92783 .27476 L
.92876 .27476 L
.92969 .27476 L
.93062 .27476 L
.93155 .27476 L
.93248 .27476 L
.93341 .27476 L
.93434 .27476 L
.93527 .27476 L
.9362 .27476 L
.93713 .27476 L
.93806 .27476 L
.93899 .27476 L
.93992 .27476 L
.94085 .27476 L
.94178 .27476 L
.94271 .27476 L
.94364 .27476 L
.94457 .27476 L
.9455 .27476 L
.94643 .27476 L
.94736 .27476 L
.94829 .27476 L
.94922 .27476 L
.95015 .27476 L
.95108 .27476 L
.95201 .27476 L
.95294 .27476 L
Mistroke
.95387 .27476 L
.9548 .27476 L
.95573 .27476 L
.95666 .27476 L
.95759 .27476 L
.95852 .27476 L
.95945 .27476 L
.96038 .27476 L
.96131 .27476 L
.96224 .27476 L
.96317 .27476 L
.9641 .27476 L
.96503 .27476 L
.96596 .27476 L
.96689 .27476 L
.96782 .27476 L
.96875 .27476 L
.96968 .27476 L
.97061 .27476 L
.97154 .27476 L
.97247 .27476 L
.9734 .27476 L
.97433 .27476 L
.97526 .27476 L
.97619 .27476 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49256 0.0595238 0.313774 0.201125 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .31377 m
1 .31377 L
s
.49256 0 m
.49256 .61803 L
s
[(w[4, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .31377 m
.02474 .31377 L
.02567 .31377 L
.0266 .31377 L
.02753 .31377 L
.02846 .31377 L
.02939 .31377 L
.03032 .31377 L
.03125 .31377 L
.03218 .31377 L
.03311 .31377 L
.03404 .31377 L
.03497 .31377 L
.0359 .31377 L
.03683 .31377 L
.03776 .31377 L
.03869 .31377 L
.03962 .31377 L
.04055 .31377 L
.04148 .31377 L
.04241 .31377 L
.04334 .31377 L
.04427 .31377 L
.0452 .31377 L
.04613 .31377 L
.04706 .31377 L
.04799 .31377 L
.04892 .31377 L
.04985 .31377 L
.05078 .31377 L
.05171 .31377 L
.05264 .31377 L
.05357 .31377 L
.0545 .31377 L
.05543 .31377 L
.05636 .31377 L
.05729 .31377 L
.05822 .31377 L
.05915 .31377 L
.06008 .31377 L
.06101 .31377 L
.06194 .31377 L
.06287 .31377 L
.0638 .31377 L
.06473 .31377 L
.06566 .31377 L
.06659 .31377 L
.06752 .31377 L
.06845 .31377 L
.06938 .31377 L
Mistroke
.07031 .31377 L
.07124 .31377 L
.07217 .31377 L
.0731 .31377 L
.07403 .31377 L
.07496 .31377 L
.07589 .31377 L
.07682 .31377 L
.07775 .31377 L
.07868 .31377 L
.07961 .31377 L
.08054 .31377 L
.08147 .31377 L
.0824 .31377 L
.08333 .31377 L
.08426 .31377 L
.08519 .31377 L
.08612 .31377 L
.08705 .31377 L
.08798 .31377 L
.08891 .31377 L
.08984 .31377 L
.09077 .31377 L
.0917 .31377 L
.09263 .31377 L
.09356 .31377 L
.09449 .31377 L
.09542 .31377 L
.09635 .31377 L
.09728 .31378 L
.09821 .31378 L
.09914 .31378 L
.10007 .31378 L
.101 .31378 L
.10193 .31378 L
.10286 .31378 L
.10379 .31378 L
.10472 .31378 L
.10565 .31378 L
.10658 .31378 L
.10751 .31378 L
.10844 .31378 L
.10938 .31378 L
.11031 .31377 L
.11124 .31377 L
.11217 .31377 L
.1131 .31377 L
.11403 .31377 L
.11496 .31377 L
.11589 .31377 L
Mistroke
.11682 .31377 L
.11775 .31377 L
.11868 .31377 L
.11961 .31377 L
.12054 .31377 L
.12147 .31377 L
.1224 .31377 L
.12333 .31377 L
.12426 .31377 L
.12519 .31377 L
.12612 .31377 L
.12705 .31377 L
.12798 .31377 L
.12891 .31377 L
.12984 .31378 L
.13077 .31378 L
.1317 .31379 L
.13263 .31379 L
.13356 .31379 L
.13449 .31379 L
.13542 .31379 L
.13635 .31379 L
.13728 .31378 L
.13821 .31378 L
.13914 .31377 L
.14007 .31377 L
.141 .31376 L
.14193 .31375 L
.14286 .31375 L
.14379 .31375 L
.14472 .31374 L
.14565 .31374 L
.14658 .31374 L
.14751 .31374 L
.14844 .31375 L
.14937 .31376 L
.1503 .31377 L
.15123 .31379 L
.15216 .31381 L
.15309 .31384 L
.15402 .31385 L
.15495 .31386 L
.15588 .31387 L
.15681 .31386 L
.15774 .31385 L
.15867 .31382 L
.1596 .31379 L
.16053 .31375 L
.16146 .31371 L
.16239 .31368 L
Mistroke
.16332 .31365 L
.16425 .31363 L
.16518 .31363 L
.16611 .31363 L
.16704 .31366 L
.16797 .31369 L
.1689 .31373 L
.16983 .31377 L
.17076 .31382 L
.17169 .31386 L
.17262 .3139 L
.17355 .31393 L
.17448 .31395 L
.17541 .31398 L
.17634 .31398 L
.17727 .31397 L
.1782 .31394 L
.17913 .31391 L
.18006 .31385 L
.18099 .31378 L
.18192 .3137 L
.18285 .31361 L
.18378 .31354 L
.18471 .31347 L
.18564 .31344 L
.18657 .31342 L
.1875 .31344 L
.18843 .3135 L
.18936 .31359 L
.19029 .31369 L
.19122 .3138 L
.19215 .31391 L
.19308 .31401 L
.19401 .31409 L
.19494 .31413 L
.19587 .31415 L
.1968 .31411 L
.19773 .31407 L
.19866 .31399 L
.19959 .3139 L
.20052 .31379 L
.20145 .31369 L
.20238 .31359 L
.20331 .31349 L
.20424 .31342 L
.20517 .31335 L
.2061 .31332 L
.20703 .31331 L
.20796 .31334 L
.20889 .31339 L
Mistroke
.20982 .3135 L
.21075 .31363 L
.21168 .3138 L
.21261 .31397 L
.21354 .31413 L
.21447 .31427 L
.2154 .31437 L
.21633 .31444 L
.21726 .31442 L
.21819 .31436 L
.21912 .31422 L
.22005 .31407 L
.22098 .31389 L
.22191 .31369 L
.22284 .31351 L
.22377 .31334 L
.2247 .31324 L
.22563 .31315 L
.22656 .31313 L
.22749 .3131 L
.22842 .31316 L
.22935 .31324 L
.23028 .31341 L
.23121 .31357 L
.23214 .3138 L
.23307 .31408 L
.234 .31438 L
.23493 .31472 L
.23586 .31496 L
.23679 .31515 L
.23772 .31516 L
.23865 .31514 L
.23958 .31489 L
.24051 .31445 L
.24144 .31384 L
.24237 .31315 L
.2433 .31253 L
.24423 .31196 L
.24516 .31163 L
.24609 .31138 L
.24702 .31155 L
.24795 .31202 L
.24888 .31285 L
.24981 .31377 L
.25074 .31473 L
.25167 .31565 L
.2526 .31634 L
.25353 .31691 L
.25446 .31696 L
.25539 .31665 L
Mistroke
.25632 .31584 L
.25725 .31495 L
.25818 .31388 L
.25911 .3128 L
.26004 .31184 L
.26097 .31101 L
.2619 .31064 L
.26283 .31059 L
.26376 .31101 L
.26469 .31149 L
.26563 .31227 L
.26656 .31312 L
.26749 .31407 L
.26842 .31491 L
.26935 .31557 L
.27028 .3161 L
.27121 .31638 L
.27214 .31667 L
.27307 .3166 L
.274 .31641 L
.27493 .31587 L
.27586 .31534 L
.27679 .31454 L
.27772 .31355 L
.27865 .31239 L
.27958 .31112 L
.28051 .31012 L
.28144 .30929 L
.28237 .30903 L
.2833 .30888 L
.28423 .30955 L
.28516 .31078 L
.28609 .31271 L
.28702 .31489 L
.28795 .31697 L
.28888 .3189 L
.28981 .32016 L
.29074 .32117 L
.29167 .32089 L
.2926 .3197 L
.29353 .31732 L
.29446 .31458 L
.29539 .31168 L
.29632 .30889 L
.29725 .30675 L
.29818 .30494 L
.29911 .30471 L
.30004 .30562 L
.30097 .30805 L
.3019 .31088 L
Mistroke
.30283 .3141 L
.30376 .3173 L
.30469 .32 L
.30562 .3223 L
.30655 .32298 L
.30748 .32248 L
.30841 .32037 L
.30934 .3179 L
.31027 .31486 L
.3112 .31176 L
.31213 .30895 L
.31306 .30653 L
.31399 .30549 L
.31492 .3055 L
.31585 .30693 L
.31678 .3086 L
.31771 .31096 L
.31864 .31346 L
.31957 .31599 L
.3205 .3182 L
.32143 .31949 L
.32236 .32011 L
.32329 .31974 L
.32422 .31931 L
.32515 .31812 L
.32608 .31669 L
.32701 .31485 L
.32794 .31321 L
.32887 .31172 L
.3298 .31031 L
.33073 .3092 L
.33166 .30797 L
.33259 .30748 L
.33352 .3073 L
.33445 .30801 L
.33538 .30873 L
.33631 .31037 L
.33724 .31265 L
.33817 .31563 L
.3391 .31892 L
.34003 .32173 L
.34096 .3242 L
.34189 .3254 L
.34282 .32624 L
.34375 .32502 L
.34468 .32234 L
.34561 .31783 L
.34654 .3127 L
.34747 .30761 L
.3484 .30278 L
Mistroke
.34933 .29938 L
.35026 .29662 L
.35119 .29682 L
.35212 .29913 L
.35305 .30426 L
.35398 .31023 L
.35491 .3167 L
.35584 .32297 L
.35677 .32796 L
.3577 .3322 L
.35863 .33309 L
.35956 .33145 L
.36049 .32651 L
.36142 .32074 L
.36235 .31408 L
.36328 .30743 L
.36421 .30179 L
.36514 .29694 L
.36607 .29548 L
.367 .29652 L
.36793 .30091 L
.36886 .30591 L
.36979 .31217 L
.37072 .31859 L
.37165 .32449 L
.37258 .32949 L
.37351 .33162 L
.37444 .33166 L
.37537 .32877 L
.3763 .32547 L
.37723 .32054 L
.37816 .3152 L
.37909 .30958 L
.38002 .3047 L
.38095 .30138 L
.38188 .2992 L
.38281 .29884 L
.38374 .29859 L
.38467 .30015 L
.3856 .30233 L
.38653 .30591 L
.38746 .30926 L
.38839 .31322 L
.38932 .31761 L
.39025 .32214 L
.39118 .32715 L
.39211 .3306 L
.39304 .33331 L
.39397 .33351 L
.3949 .33328 L
Mistroke
.39583 .32982 L
.39676 .32413 L
.39769 .31571 L
.39862 .30613 L
.39955 .29729 L
.40048 .28927 L
.40141 .28442 L
.40234 .28058 L
.40327 .2824 L
.4042 .28839 L
.40513 .29957 L
.40606 .31245 L
.40699 .32554 L
.40792 .33806 L
.40885 .34709 L
.40978 .3546 L
.41071 .35447 L
.41164 .34886 L
.41257 .33596 L
.4135 .32117 L
.41443 .30495 L
.41536 .28914 L
.41629 .27644 L
.41722 .26579 L
.41815 .2637 L
.41908 .26803 L
.42001 .28067 L
.42094 .29522 L
.42188 .31224 L
.42281 .32946 L
.42374 .34437 L
.42467 .35705 L
.4256 .36145 L
.42653 .35994 L
.42746 .35016 L
.42839 .33896 L
.42932 .32404 L
.43025 .30855 L
.43118 .29345 L
.43211 .28045 L
.43304 .27332 L
.43397 .2706 L
.4349 .27408 L
.43583 .27814 L
.43676 .28661 L
.43769 .2965 L
.43862 .30852 L
.43955 .31923 L
.44048 .3285 L
.44141 .33692 L
Mistroke
.44234 .34315 L
.44327 .35027 L
.4442 .35268 L
.44513 .35319 L
.44606 .34815 L
.44699 .34314 L
.44792 .33273 L
.44885 .31844 L
.44978 .2999 L
.45071 .27857 L
.45164 .2611 L
.45257 .24623 L
.4535 .24032 L
.45443 .23624 L
.45536 .24588 L
.45629 .26583 L
.45722 .2981 L
.45815 .33547 L
.45908 .37059 L
.46001 .40294 L
.46094 .42292 L
.46187 .43894 L
.4628 .4318 L
.46373 .40752 L
.46466 .36159 L
.46559 .30822 L
.46652 .25447 L
.46745 .20367 L
.46838 .16799 L
.46931 .13862 L
.47024 .1418 L
.47117 .16937 L
.4721 .22802 L
.47303 .29634 L
.47396 .36811 L
.47489 .43722 L
.47582 .4891 L
.47675 .53232 L
.47768 .53428 L
.47861 .50532 L
.47954 .43644 L
.48047 .35602 L
.4814 .26862 L
.48233 .1834 L
.48326 .11646 L
.48419 .0603 L
.48512 .05245 L
.48605 .08093 L
.48698 .15667 L
.48791 .24527 L
Mistroke
.48884 .34447 L
.48977 .44221 L
.4907 .52185 L
.49163 .58902 L
.49256 .60332 L
.49349 .57776 L
.49442 .49992 L
.49535 .40853 L
.49628 .30319 L
.49721 .19833 L
.49814 .11009 L
.49907 .03526 L
.5 .01472 L
.50093 .03526 L
.50186 .11009 L
.50279 .19833 L
.50372 .30319 L
.50465 .40853 L
.50558 .49992 L
.50651 .57776 L
.50744 .60332 L
.50837 .58902 L
.5093 .52185 L
.51023 .44221 L
.51116 .34447 L
.51209 .24527 L
.51302 .15667 L
.51395 .08093 L
.51488 .05245 L
.51581 .0603 L
.51674 .11646 L
.51767 .1834 L
.5186 .26862 L
.51953 .35602 L
.52046 .43644 L
.52139 .50532 L
.52232 .53428 L
.52325 .53232 L
.52418 .4891 L
.52511 .43722 L
.52604 .36811 L
.52697 .29634 L
.5279 .22802 L
.52883 .16937 L
.52976 .1418 L
.53069 .13862 L
.53162 .16799 L
.53255 .20367 L
.53348 .25447 L
.53441 .30822 L
Mistroke
.53534 .36159 L
.53627 .40752 L
.5372 .4318 L
.53813 .43894 L
.53906 .42292 L
.53999 .40294 L
.54092 .37059 L
.54185 .33547 L
.54278 .2981 L
.54371 .26583 L
.54464 .24588 L
.54557 .23624 L
.5465 .24032 L
.54743 .24623 L
.54836 .2611 L
.54929 .27857 L
.55022 .2999 L
.55115 .31844 L
.55208 .33273 L
.55301 .34314 L
.55394 .34815 L
.55487 .35319 L
.5558 .35268 L
.55673 .35027 L
.55766 .34315 L
.55859 .33692 L
.55952 .3285 L
.56045 .31923 L
.56138 .30852 L
.56231 .2965 L
.56324 .28661 L
.56417 .27814 L
.5651 .27408 L
.56603 .2706 L
.56696 .27332 L
.56789 .28045 L
.56882 .29345 L
.56975 .30855 L
.57068 .32404 L
.57161 .33896 L
.57254 .35016 L
.57347 .35994 L
.5744 .36145 L
.57533 .35705 L
.57626 .34437 L
.57719 .32946 L
.57813 .31224 L
.57906 .29522 L
.57999 .28067 L
.58092 .26803 L
Mistroke
.58185 .2637 L
.58278 .26579 L
.58371 .27644 L
.58464 .28914 L
.58557 .30495 L
.5865 .32117 L
.58743 .33596 L
.58836 .34886 L
.58929 .35447 L
.59022 .3546 L
.59115 .34709 L
.59208 .33806 L
.59301 .32554 L
.59394 .31245 L
.59487 .29957 L
.5958 .28839 L
.59673 .2824 L
.59766 .28058 L
.59859 .28442 L
.59952 .28927 L
.60045 .29729 L
.60138 .30613 L
.60231 .31571 L
.60324 .32413 L
.60417 .32982 L
.6051 .33328 L
.60603 .33351 L
.60696 .33331 L
.60789 .3306 L
.60882 .32715 L
.60975 .32214 L
.61068 .31761 L
.61161 .31322 L
.61254 .30926 L
.61347 .30591 L
.6144 .30233 L
.61533 .30015 L
.61626 .29859 L
.61719 .29884 L
.61812 .2992 L
.61905 .30138 L
.61998 .3047 L
.62091 .30958 L
.62184 .3152 L
.62277 .32054 L
.6237 .32547 L
.62463 .32877 L
.62556 .33166 L
.62649 .33162 L
.62742 .32949 L
Mistroke
.62835 .32449 L
.62928 .31859 L
.63021 .31217 L
.63114 .30591 L
.63207 .30091 L
.633 .29652 L
.63393 .29548 L
.63486 .29694 L
.63579 .30179 L
.63672 .30743 L
.63765 .31408 L
.63858 .32074 L
.63951 .32651 L
.64044 .33145 L
.64137 .33309 L
.6423 .3322 L
.64323 .32796 L
.64416 .32297 L
.64509 .3167 L
.64602 .31023 L
.64695 .30426 L
.64788 .29913 L
.64881 .29682 L
.64974 .29662 L
.65067 .29938 L
.6516 .30278 L
.65253 .30761 L
.65346 .3127 L
.65439 .31783 L
.65532 .32234 L
.65625 .32502 L
.65718 .32624 L
.65811 .3254 L
.65904 .3242 L
.65997 .32173 L
.6609 .31892 L
.66183 .31563 L
.66276 .31265 L
.66369 .31037 L
.66462 .30873 L
.66555 .30801 L
.66648 .3073 L
.66741 .30748 L
.66834 .30797 L
.66927 .3092 L
.6702 .31031 L
.67113 .31172 L
.67206 .31321 L
.67299 .31485 L
.67392 .31669 L
Mistroke
.67485 .31812 L
.67578 .31931 L
.67671 .31974 L
.67764 .32011 L
.67857 .31949 L
.6795 .3182 L
.68043 .31599 L
.68136 .31346 L
.68229 .31096 L
.68322 .3086 L
.68415 .30693 L
.68508 .3055 L
.68601 .30549 L
.68694 .30653 L
.68787 .30895 L
.6888 .31176 L
.68973 .31486 L
.69066 .3179 L
.69159 .32037 L
.69252 .32248 L
.69345 .32298 L
.69438 .3223 L
.69531 .32 L
.69624 .3173 L
.69717 .3141 L
.6981 .31088 L
.69903 .30805 L
.69996 .30562 L
.70089 .30471 L
.70182 .30494 L
.70275 .30675 L
.70368 .30889 L
.70461 .31168 L
.70554 .31458 L
.70647 .31732 L
.7074 .3197 L
.70833 .32089 L
.70926 .32117 L
.71019 .32016 L
.71112 .3189 L
.71205 .31697 L
.71298 .31489 L
.71391 .31271 L
.71484 .31078 L
.71577 .30955 L
.7167 .30888 L
.71763 .30903 L
.71856 .30929 L
.71949 .31012 L
.72042 .31112 L
Mistroke
.72135 .31239 L
.72228 .31355 L
.72321 .31454 L
.72414 .31534 L
.72507 .31587 L
.726 .31641 L
.72693 .3166 L
.72786 .31667 L
.72879 .31638 L
.72972 .3161 L
.73065 .31557 L
.73158 .31491 L
.73251 .31407 L
.73344 .31312 L
.73438 .31227 L
.73531 .31149 L
.73624 .31101 L
.73717 .31059 L
.7381 .31064 L
.73903 .31101 L
.73996 .31184 L
.74089 .3128 L
.74182 .31388 L
.74275 .31495 L
.74368 .31584 L
.74461 .31665 L
.74554 .31696 L
.74647 .31691 L
.7474 .31634 L
.74833 .31565 L
.74926 .31473 L
.75019 .31377 L
.75112 .31285 L
.75205 .31202 L
.75298 .31155 L
.75391 .31138 L
.75484 .31163 L
.75577 .31196 L
.7567 .31253 L
.75763 .31315 L
.75856 .31384 L
.75949 .31445 L
.76042 .31489 L
.76135 .31514 L
.76228 .31516 L
.76321 .31515 L
.76414 .31496 L
.76507 .31472 L
.766 .31438 L
.76693 .31408 L
Mistroke
.76786 .3138 L
.76879 .31357 L
.76972 .31341 L
.77065 .31324 L
.77158 .31316 L
.77251 .3131 L
.77344 .31313 L
.77437 .31315 L
.7753 .31324 L
.77623 .31334 L
.77716 .31351 L
.77809 .31369 L
.77902 .31389 L
.77995 .31407 L
.78088 .31422 L
.78181 .31436 L
.78274 .31442 L
.78367 .31444 L
.7846 .31437 L
.78553 .31427 L
.78646 .31413 L
.78739 .31397 L
.78832 .3138 L
.78925 .31363 L
.79018 .3135 L
.79111 .31339 L
.79204 .31334 L
.79297 .31331 L
.7939 .31332 L
.79483 .31335 L
.79576 .31342 L
.79669 .31349 L
.79762 .31359 L
.79855 .31369 L
.79948 .31379 L
.80041 .3139 L
.80134 .31399 L
.80227 .31407 L
.8032 .31411 L
.80413 .31415 L
.80506 .31413 L
.80599 .31409 L
.80692 .31401 L
.80785 .31391 L
.80878 .3138 L
.80971 .31369 L
.81064 .31359 L
.81157 .3135 L
.8125 .31344 L
.81343 .31342 L
Mistroke
.81436 .31344 L
.81529 .31347 L
.81622 .31354 L
.81715 .31361 L
.81808 .3137 L
.81901 .31378 L
.81994 .31385 L
.82087 .31391 L
.8218 .31394 L
.82273 .31397 L
.82366 .31398 L
.82459 .31398 L
.82552 .31395 L
.82645 .31393 L
.82738 .3139 L
.82831 .31386 L
.82924 .31382 L
.83017 .31377 L
.8311 .31373 L
.83203 .31369 L
.83296 .31366 L
.83389 .31363 L
.83482 .31363 L
.83575 .31363 L
.83668 .31365 L
.83761 .31368 L
.83854 .31371 L
.83947 .31375 L
.8404 .31379 L
.84133 .31382 L
.84226 .31385 L
.84319 .31386 L
.84412 .31387 L
.84505 .31386 L
.84598 .31385 L
.84691 .31384 L
.84784 .31381 L
.84877 .31379 L
.8497 .31377 L
.85063 .31376 L
.85156 .31375 L
.85249 .31374 L
.85342 .31374 L
.85435 .31374 L
.85528 .31374 L
.85621 .31375 L
.85714 .31375 L
.85807 .31375 L
.859 .31376 L
.85993 .31377 L
Mistroke
.86086 .31377 L
.86179 .31378 L
.86272 .31378 L
.86365 .31379 L
.86458 .31379 L
.86551 .31379 L
.86644 .31379 L
.86737 .31379 L
.8683 .31379 L
.86923 .31378 L
.87016 .31378 L
.87109 .31377 L
.87202 .31377 L
.87295 .31377 L
.87388 .31377 L
.87481 .31377 L
.87574 .31377 L
.87667 .31377 L
.8776 .31377 L
.87853 .31377 L
.87946 .31377 L
.88039 .31377 L
.88132 .31377 L
.88225 .31377 L
.88318 .31377 L
.88411 .31377 L
.88504 .31377 L
.88597 .31377 L
.8869 .31377 L
.88783 .31377 L
.88876 .31377 L
.88969 .31377 L
.89063 .31378 L
.89156 .31378 L
.89249 .31378 L
.89342 .31378 L
.89435 .31378 L
.89528 .31378 L
.89621 .31378 L
.89714 .31378 L
.89807 .31378 L
.899 .31378 L
.89993 .31378 L
.90086 .31378 L
.90179 .31378 L
.90272 .31378 L
.90365 .31377 L
.90458 .31377 L
.90551 .31377 L
.90644 .31377 L
Mistroke
.90737 .31377 L
.9083 .31377 L
.90923 .31377 L
.91016 .31377 L
.91109 .31377 L
.91202 .31377 L
.91295 .31377 L
.91388 .31377 L
.91481 .31377 L
.91574 .31377 L
.91667 .31377 L
.9176 .31377 L
.91853 .31377 L
.91946 .31377 L
.92039 .31377 L
.92132 .31377 L
.92225 .31377 L
.92318 .31377 L
.92411 .31377 L
.92504 .31377 L
.92597 .31377 L
.9269 .31377 L
.92783 .31377 L
.92876 .31377 L
.92969 .31377 L
.93062 .31377 L
.93155 .31377 L
.93248 .31377 L
.93341 .31377 L
.93434 .31377 L
.93527 .31377 L
.9362 .31377 L
.93713 .31377 L
.93806 .31377 L
.93899 .31377 L
.93992 .31377 L
.94085 .31377 L
.94178 .31377 L
.94271 .31377 L
.94364 .31377 L
.94457 .31377 L
.9455 .31377 L
.94643 .31377 L
.94736 .31377 L
.94829 .31377 L
.94922 .31377 L
.95015 .31377 L
.95108 .31377 L
.95201 .31377 L
.95294 .31377 L
Mistroke
.95387 .31377 L
.9548 .31377 L
.95573 .31377 L
.95666 .31377 L
.95759 .31377 L
.95852 .31377 L
.95945 .31377 L
.96038 .31377 L
.96131 .31377 L
.96224 .31377 L
.96317 .31377 L
.9641 .31377 L
.96503 .31377 L
.96596 .31377 L
.96689 .31377 L
.96782 .31377 L
.96875 .31377 L
.96968 .31377 L
.97061 .31377 L
.97154 .31377 L
.97247 .31377 L
.9734 .31377 L
.97433 .31377 L
.97526 .31377 L
.97619 .31377 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.470238 0.0595238 0.361739 0.275355 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .36174 m
1 .36174 L
s
.47024 0 m
.47024 .61803 L
s
[(w[1, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .36174 m
.02474 .36174 L
.02567 .36174 L
.0266 .36174 L
.02753 .36174 L
.02846 .36174 L
.02939 .36174 L
.03032 .36174 L
.03125 .36174 L
.03218 .36174 L
.03311 .36174 L
.03404 .36174 L
.03497 .36174 L
.0359 .36174 L
.03683 .36174 L
.03776 .36174 L
.03869 .36174 L
.03962 .36174 L
.04055 .36174 L
.04148 .36174 L
.04241 .36174 L
.04334 .36174 L
.04427 .36174 L
.0452 .36174 L
.04613 .36174 L
.04706 .36174 L
.04799 .36174 L
.04892 .36174 L
.04985 .36174 L
.05078 .36174 L
.05171 .36174 L
.05264 .36174 L
.05357 .36174 L
.0545 .36174 L
.05543 .36174 L
.05636 .36174 L
.05729 .36174 L
.05822 .36174 L
.05915 .36174 L
.06008 .36174 L
.06101 .36174 L
.06194 .36174 L
.06287 .36174 L
.0638 .36174 L
.06473 .36174 L
.06566 .36174 L
.06659 .36174 L
.06752 .36174 L
.06845 .36174 L
.06938 .36174 L
Mistroke
.07031 .36174 L
.07124 .36174 L
.07217 .36174 L
.0731 .36174 L
.07403 .36174 L
.07496 .36174 L
.07589 .36174 L
.07682 .36174 L
.07775 .36174 L
.07868 .36174 L
.07961 .36174 L
.08054 .36174 L
.08147 .36174 L
.0824 .36174 L
.08333 .36174 L
.08426 .36174 L
.08519 .36174 L
.08612 .36174 L
.08705 .36174 L
.08798 .36174 L
.08891 .36174 L
.08984 .36174 L
.09077 .36174 L
.0917 .36174 L
.09263 .36174 L
.09356 .36174 L
.09449 .36174 L
.09542 .36174 L
.09635 .36174 L
.09728 .36174 L
.09821 .36174 L
.09914 .36174 L
.10007 .36174 L
.101 .36174 L
.10193 .36174 L
.10286 .36174 L
.10379 .36174 L
.10472 .36173 L
.10565 .36173 L
.10658 .36173 L
.10751 .36173 L
.10844 .36173 L
.10938 .36173 L
.11031 .36173 L
.11124 .36173 L
.11217 .36173 L
.1131 .36173 L
.11403 .36174 L
.11496 .36174 L
.11589 .36174 L
Mistroke
.11682 .36174 L
.11775 .36174 L
.11868 .36175 L
.11961 .36175 L
.12054 .36175 L
.12147 .36175 L
.1224 .36175 L
.12333 .36175 L
.12426 .36175 L
.12519 .36175 L
.12612 .36175 L
.12705 .36175 L
.12798 .36175 L
.12891 .36174 L
.12984 .36174 L
.13077 .36173 L
.1317 .36172 L
.13263 .36172 L
.13356 .36171 L
.13449 .36171 L
.13542 .3617 L
.13635 .3617 L
.13728 .36169 L
.13821 .36169 L
.13914 .36169 L
.14007 .36168 L
.141 .36168 L
.14193 .36169 L
.14286 .36169 L
.14379 .36169 L
.14472 .3617 L
.14565 .36171 L
.14658 .36172 L
.14751 .36173 L
.14844 .36174 L
.14937 .36175 L
.1503 .36176 L
.15123 .36177 L
.15216 .36179 L
.15309 .3618 L
.15402 .36181 L
.15495 .36181 L
.15588 .36182 L
.15681 .36183 L
.15774 .36183 L
.15867 .36183 L
.1596 .36184 L
.16053 .36183 L
.16146 .36183 L
.16239 .36183 L
Mistroke
.16332 .36182 L
.16425 .36181 L
.16518 .36181 L
.16611 .3618 L
.16704 .36179 L
.16797 .36178 L
.1689 .36177 L
.16983 .36176 L
.17076 .36175 L
.17169 .36174 L
.17262 .36173 L
.17355 .36172 L
.17448 .36172 L
.17541 .36171 L
.17634 .36171 L
.17727 .3617 L
.1782 .3617 L
.17913 .3617 L
.18006 .36169 L
.18099 .36169 L
.18192 .36168 L
.18285 .36168 L
.18378 .36168 L
.18471 .36168 L
.18564 .36168 L
.18657 .36168 L
.1875 .36169 L
.18843 .36171 L
.18936 .36172 L
.19029 .36174 L
.19122 .36176 L
.19215 .36179 L
.19308 .3618 L
.19401 .36182 L
.19494 .36183 L
.19587 .36184 L
.1968 .36184 L
.19773 .36184 L
.19866 .36183 L
.19959 .36183 L
.20052 .36183 L
.20145 .36182 L
.20238 .36182 L
.20331 .36182 L
.20424 .36183 L
.20517 .36183 L
.2061 .36184 L
.20703 .36184 L
.20796 .36183 L
.20889 .36182 L
Mistroke
.20982 .36181 L
.21075 .36179 L
.21168 .36176 L
.21261 .36173 L
.21354 .3617 L
.21447 .36167 L
.2154 .36164 L
.21633 .36161 L
.21726 .36161 L
.21819 .36162 L
.21912 .36165 L
.22005 .36168 L
.22098 .36171 L
.22191 .36173 L
.22284 .36174 L
.22377 .36175 L
.2247 .36176 L
.22563 .36178 L
.22656 .3618 L
.22749 .3618 L
.22842 .36178 L
.22935 .36176 L
.23028 .36172 L
.23121 .36167 L
.23214 .36164 L
.23307 .36165 L
.234 .36166 L
.23493 .36166 L
.23586 .36163 L
.23679 .36162 L
.23772 .36157 L
.23865 .3615 L
.23958 .36141 L
.24051 .36142 L
.24144 .36139 L
.24237 .36134 L
.2433 .36123 L
.24423 .36117 L
.24516 .36103 L
.24609 .36088 L
.24702 .36069 L
.24795 .36065 L
.24888 .36055 L
.24981 .36043 L
.25074 .36023 L
.25167 .36013 L
.2526 .35993 L
.25353 .35974 L
.25446 .35948 L
.25539 .35945 L
Mistroke
.25632 .35934 L
.25725 .35925 L
.25818 .35902 L
.25911 .35898 L
.26004 .35876 L
.26097 .35858 L
.2619 .35825 L
.26283 .35823 L
.26376 .35804 L
.26469 .3579 L
.26563 .35757 L
.26656 .35753 L
.26749 .35728 L
.26842 .3571 L
.26935 .35673 L
.27028 .35679 L
.27121 .35663 L
.27214 .35657 L
.27307 .35626 L
.274 .35636 L
.27493 .35616 L
.27586 .35606 L
.27679 .35566 L
.27772 .3557 L
.27865 .35543 L
.27958 .35529 L
.28051 .35485 L
.28144 .3549 L
.28237 .35466 L
.2833 .35458 L
.28423 .35422 L
.28516 .35435 L
.28609 .3542 L
.28702 .35425 L
.28795 .35403 L
.28888 .35431 L
.28981 .35433 L
.29074 .35454 L
.29167 .35444 L
.2926 .35474 L
.29353 .35476 L
.29446 .35499 L
.29539 .35497 L
.29632 .35538 L
.29725 .35558 L
.29818 .35598 L
.29911 .35615 L
.30004 .35659 L
.30097 .35685 L
.3019 .35729 L
Mistroke
.30283 .3576 L
.30376 .35817 L
.30469 .35868 L
.30562 .3593 L
.30655 .35983 L
.30748 .36038 L
.30841 .36091 L
.30934 .36149 L
.31027 .36211 L
.3112 .3627 L
.31213 .36338 L
.31306 .36405 L
.31399 .36475 L
.31492 .36516 L
.31585 .36568 L
.31678 .36612 L
.31771 .36677 L
.31864 .36709 L
.31957 .36771 L
.3205 .36823 L
.32143 .369 L
.32236 .36922 L
.32329 .36979 L
.32422 .3702 L
.32515 .37099 L
.32608 .37114 L
.32701 .37173 L
.32794 .37215 L
.32887 .37297 L
.3298 .37291 L
.33073 .37333 L
.33166 .37352 L
.33259 .37426 L
.33352 .37405 L
.33445 .37449 L
.33538 .37471 L
.33631 .37563 L
.33724 .37555 L
.33817 .37621 L
.3391 .37657 L
.34003 .37762 L
.34096 .3775 L
.34189 .37804 L
.34282 .37821 L
.34375 .37907 L
.34468 .37879 L
.34561 .37918 L
.34654 .37911 L
.34747 .37971 L
.3484 .37911 L
Mistroke
.34933 .37916 L
.35026 .37874 L
.35119 .3791 L
.35212 .37854 L
.35305 .37868 L
.35398 .3783 L
.35491 .3785 L
.35584 .37772 L
.35677 .37738 L
.3577 .37649 L
.35863 .37605 L
.35956 .3749 L
.36049 .3741 L
.36142 .37285 L
.36235 .37187 L
.36328 .37037 L
.36421 .36905 L
.36514 .36744 L
.36607 .36606 L
.367 .36459 L
.36793 .36322 L
.36886 .36174 L
.36979 .36024 L
.37072 .35886 L
.37165 .35731 L
.37258 .35586 L
.37351 .35422 L
.37444 .3531 L
.37537 .35166 L
.3763 .35053 L
.37723 .34891 L
.37816 .34796 L
.37909 .34639 L
.38002 .34533 L
.38095 .34371 L
.38188 .34317 L
.38281 .34198 L
.38374 .3413 L
.38467 .33994 L
.3856 .33974 L
.38653 .33881 L
.38746 .33852 L
.38839 .3378 L
.38932 .33892 L
.39025 .3394 L
.39118 .34039 L
.39211 .34034 L
.39304 .34169 L
.39397 .34171 L
.3949 .342 L
Mistroke
.39583 .34111 L
.39676 .34214 L
.39769 .34185 L
.39862 .34163 L
.39955 .34009 L
.40048 .34037 L
.40141 .33931 L
.40234 .3383 L
.40327 .33644 L
.4042 .3373 L
.40513 .33713 L
.40606 .33704 L
.40699 .33557 L
.40792 .33665 L
.40885 .336 L
.40978 .33523 L
.41071 .33245 L
.41164 .33233 L
.41257 .33009 L
.4135 .32828 L
.41443 .32446 L
.41536 .324 L
.41629 .32151 L
.41722 .31968 L
.41815 .31531 L
.41908 .31368 L
.42001 .30978 L
.42094 .30734 L
.42187 .30328 L
.42281 .30333 L
.42374 .30206 L
.42467 .30271 L
.4256 .30099 L
.42653 .30146 L
.42746 .30002 L
.42839 .30129 L
.42932 .30125 L
.43025 .30447 L
.43118 .30682 L
.43211 .31194 L
.43304 .31475 L
.43397 .31726 L
.4349 .31835 L
.43583 .32216 L
.43676 .32608 L
.43769 .33053 L
.43862 .33642 L
.43955 .34506 L
.44048 .35487 L
.44141 .362 L
Mistroke
.44234 .37126 L
.44327 .38186 L
.4442 .39524 L
.44513 .40435 L
.44606 .41707 L
.44699 .42994 L
.44792 .44656 L
.44885 .45618 L
.44978 .47019 L
.45071 .48186 L
.45164 .49815 L
.45257 .50448 L
.4535 .51627 L
.45443 .52432 L
.45536 .53971 L
.45629 .54541 L
.45722 .5587 L
.45815 .56559 L
.45908 .57931 L
.46001 .57952 L
.46094 .5866 L
.46187 .58608 L
.4628 .59474 L
.46373 .59336 L
.46466 .60044 L
.46559 .59875 L
.46652 .60332 L
.46745 .59468 L
.46838 .59106 L
.46931 .57835 L
.47024 .57218 L
.47117 .55829 L
.4721 .54971 L
.47303 .53343 L
.47396 .52057 L
.47489 .50026 L
.47582 .48199 L
.47675 .45786 L
.47768 .4365 L
.47861 .4142 L
.47954 .39323 L
.48047 .3702 L
.4814 .3468 L
.48233 .32574 L
.48326 .30231 L
.48419 .27946 L
.48512 .25266 L
.48605 .2322 L
.48698 .20631 L
.48791 .18564 L
Mistroke
.48884 .15927 L
.48977 .14515 L
.4907 .12386 L
.49163 .1104 L
.49256 .08727 L
.49349 .07669 L
.49442 .05576 L
.49535 .04581 L
.49628 .02723 L
.49721 .0275 L
.49814 .01883 L
.49907 .02242 L
.5 .01472 L
.50093 .02242 L
.50186 .01883 L
.50279 .0275 L
.50372 .02723 L
.50465 .04581 L
.50558 .05576 L
.50651 .07669 L
.50744 .08727 L
.50837 .1104 L
.5093 .12386 L
.51023 .14515 L
.51116 .15927 L
.51209 .18564 L
.51302 .20631 L
.51395 .2322 L
.51488 .25266 L
.51581 .27946 L
.51674 .30231 L
.51767 .32574 L
.5186 .3468 L
.51953 .3702 L
.52046 .39323 L
.52139 .4142 L
.52232 .4365 L
.52325 .45786 L
.52418 .48199 L
.52511 .50026 L
.52604 .52057 L
.52697 .53343 L
.5279 .54971 L
.52883 .55829 L
.52976 .57218 L
.53069 .57835 L
.53162 .59106 L
.53255 .59468 L
.53348 .60332 L
.53441 .59875 L
Mistroke
.53534 .60044 L
.53627 .59336 L
.5372 .59474 L
.53813 .58608 L
.53906 .5866 L
.53999 .57952 L
.54092 .57931 L
.54185 .56559 L
.54278 .5587 L
.54371 .54541 L
.54464 .53971 L
.54557 .52432 L
.5465 .51627 L
.54743 .50448 L
.54836 .49815 L
.54929 .48186 L
.55022 .47019 L
.55115 .45618 L
.55208 .44656 L
.55301 .42994 L
.55394 .41707 L
.55487 .40435 L
.5558 .39524 L
.55673 .38186 L
.55766 .37126 L
.55859 .362 L
.55952 .35487 L
.56045 .34506 L
.56138 .33642 L
.56231 .33053 L
.56324 .32608 L
.56417 .32216 L
.5651 .31835 L
.56603 .31726 L
.56696 .31475 L
.56789 .31194 L
.56882 .30682 L
.56975 .30447 L
.57068 .30125 L
.57161 .30129 L
.57254 .30002 L
.57347 .30146 L
.5744 .30099 L
.57533 .30271 L
.57626 .30206 L
.57719 .30333 L
.57812 .30328 L
.57906 .30734 L
.57999 .30978 L
.58092 .31368 L
Mistroke
.58185 .31531 L
.58278 .31968 L
.58371 .32151 L
.58464 .324 L
.58557 .32446 L
.5865 .32828 L
.58743 .33009 L
.58836 .33233 L
.58929 .33245 L
.59022 .33523 L
.59115 .336 L
.59208 .33665 L
.59301 .33557 L
.59394 .33704 L
.59487 .33713 L
.5958 .3373 L
.59673 .33644 L
.59766 .3383 L
.59859 .33931 L
.59952 .34037 L
.60045 .34009 L
.60138 .34163 L
.60231 .34185 L
.60324 .34214 L
.60417 .34111 L
.6051 .342 L
.60603 .34171 L
.60696 .34169 L
.60789 .34034 L
.60882 .34039 L
.60975 .3394 L
.61068 .33892 L
.61161 .3378 L
.61254 .33852 L
.61347 .33881 L
.6144 .33974 L
.61533 .33994 L
.61626 .3413 L
.61719 .34198 L
.61812 .34317 L
.61905 .34371 L
.61998 .34533 L
.62091 .34639 L
.62184 .34796 L
.62277 .34891 L
.6237 .35053 L
.62463 .35166 L
.62556 .3531 L
.62649 .35422 L
.62742 .35586 L
Mistroke
.62835 .35731 L
.62928 .35886 L
.63021 .36024 L
.63114 .36174 L
.63207 .36322 L
.633 .36459 L
.63393 .36606 L
.63486 .36744 L
.63579 .36905 L
.63672 .37037 L
.63765 .37187 L
.63858 .37285 L
.63951 .3741 L
.64044 .3749 L
.64137 .37605 L
.6423 .37649 L
.64323 .37738 L
.64416 .37772 L
.64509 .3785 L
.64602 .3783 L
.64695 .37868 L
.64788 .37854 L
.64881 .3791 L
.64974 .37874 L
.65067 .37916 L
.6516 .37911 L
.65253 .37971 L
.65346 .37911 L
.65439 .37918 L
.65532 .37879 L
.65625 .37907 L
.65718 .37821 L
.65811 .37804 L
.65904 .3775 L
.65997 .37762 L
.6609 .37657 L
.66183 .37621 L
.66276 .37555 L
.66369 .37563 L
.66462 .37471 L
.66555 .37449 L
.66648 .37405 L
.66741 .37426 L
.66834 .37352 L
.66927 .37333 L
.6702 .37291 L
.67113 .37297 L
.67206 .37215 L
.67299 .37173 L
.67392 .37114 L
Mistroke
.67485 .37099 L
.67578 .3702 L
.67671 .36979 L
.67764 .36922 L
.67857 .369 L
.6795 .36823 L
.68043 .36771 L
.68136 .36709 L
.68229 .36677 L
.68322 .36612 L
.68415 .36568 L
.68508 .36516 L
.68601 .36475 L
.68694 .36405 L
.68787 .36338 L
.6888 .3627 L
.68973 .36211 L
.69066 .36149 L
.69159 .36091 L
.69252 .36038 L
.69345 .35983 L
.69438 .3593 L
.69531 .35868 L
.69624 .35817 L
.69717 .3576 L
.6981 .35729 L
.69903 .35685 L
.69996 .35659 L
.70089 .35615 L
.70182 .35598 L
.70275 .35558 L
.70368 .35538 L
.70461 .35497 L
.70554 .35499 L
.70647 .35476 L
.7074 .35474 L
.70833 .35444 L
.70926 .35454 L
.71019 .35433 L
.71112 .35431 L
.71205 .35403 L
.71298 .35425 L
.71391 .3542 L
.71484 .35435 L
.71577 .35422 L
.7167 .35458 L
.71763 .35466 L
.71856 .3549 L
.71949 .35485 L
.72042 .35529 L
Mistroke
.72135 .35543 L
.72228 .3557 L
.72321 .35566 L
.72414 .35606 L
.72507 .35616 L
.726 .35636 L
.72693 .35626 L
.72786 .35657 L
.72879 .35663 L
.72972 .35679 L
.73065 .35673 L
.73158 .3571 L
.73251 .35728 L
.73344 .35753 L
.73437 .35757 L
.73531 .3579 L
.73624 .35804 L
.73717 .35823 L
.7381 .35825 L
.73903 .35858 L
.73996 .35876 L
.74089 .35898 L
.74182 .35902 L
.74275 .35925 L
.74368 .35934 L
.74461 .35945 L
.74554 .35948 L
.74647 .35974 L
.7474 .35993 L
.74833 .36013 L
.74926 .36023 L
.75019 .36043 L
.75112 .36055 L
.75205 .36065 L
.75298 .36069 L
.75391 .36088 L
.75484 .36103 L
.75577 .36117 L
.7567 .36123 L
.75763 .36134 L
.75856 .36139 L
.75949 .36142 L
.76042 .36141 L
.76135 .3615 L
.76228 .36157 L
.76321 .36162 L
.76414 .36163 L
.76507 .36166 L
.766 .36166 L
.76693 .36165 L
Mistroke
.76786 .36164 L
.76879 .36167 L
.76972 .36172 L
.77065 .36176 L
.77158 .36178 L
.77251 .3618 L
.77344 .3618 L
.77437 .36178 L
.7753 .36176 L
.77623 .36175 L
.77716 .36174 L
.77809 .36173 L
.77902 .36171 L
.77995 .36168 L
.78088 .36165 L
.78181 .36162 L
.78274 .36161 L
.78367 .36161 L
.7846 .36164 L
.78553 .36167 L
.78646 .3617 L
.78739 .36173 L
.78832 .36176 L
.78925 .36179 L
.79018 .36181 L
.79111 .36182 L
.79204 .36183 L
.79297 .36184 L
.7939 .36184 L
.79483 .36183 L
.79576 .36183 L
.79669 .36182 L
.79762 .36182 L
.79855 .36182 L
.79948 .36183 L
.80041 .36183 L
.80134 .36183 L
.80227 .36184 L
.8032 .36184 L
.80413 .36184 L
.80506 .36183 L
.80599 .36182 L
.80692 .3618 L
.80785 .36179 L
.80878 .36176 L
.80971 .36174 L
.81064 .36172 L
.81157 .36171 L
.8125 .36169 L
.81343 .36168 L
Mistroke
.81436 .36168 L
.81529 .36168 L
.81622 .36168 L
.81715 .36168 L
.81808 .36168 L
.81901 .36169 L
.81994 .36169 L
.82087 .3617 L
.8218 .3617 L
.82273 .3617 L
.82366 .36171 L
.82459 .36171 L
.82552 .36172 L
.82645 .36172 L
.82738 .36173 L
.82831 .36174 L
.82924 .36175 L
.83017 .36176 L
.8311 .36177 L
.83203 .36178 L
.83296 .36179 L
.83389 .3618 L
.83482 .36181 L
.83575 .36181 L
.83668 .36182 L
.83761 .36183 L
.83854 .36183 L
.83947 .36183 L
.8404 .36184 L
.84133 .36183 L
.84226 .36183 L
.84319 .36183 L
.84412 .36182 L
.84505 .36181 L
.84598 .36181 L
.84691 .3618 L
.84784 .36179 L
.84877 .36177 L
.8497 .36176 L
.85063 .36175 L
.85156 .36174 L
.85249 .36173 L
.85342 .36172 L
.85435 .36171 L
.85528 .3617 L
.85621 .36169 L
.85714 .36169 L
.85807 .36169 L
.859 .36168 L
.85993 .36168 L
Mistroke
.86086 .36169 L
.86179 .36169 L
.86272 .36169 L
.86365 .3617 L
.86458 .3617 L
.86551 .36171 L
.86644 .36171 L
.86737 .36172 L
.8683 .36172 L
.86923 .36173 L
.87016 .36174 L
.87109 .36174 L
.87202 .36175 L
.87295 .36175 L
.87388 .36175 L
.87481 .36175 L
.87574 .36175 L
.87667 .36175 L
.8776 .36175 L
.87853 .36175 L
.87946 .36175 L
.88039 .36175 L
.88132 .36175 L
.88225 .36174 L
.88318 .36174 L
.88411 .36174 L
.88504 .36174 L
.88597 .36174 L
.8869 .36173 L
.88783 .36173 L
.88876 .36173 L
.88969 .36173 L
.89062 .36173 L
.89156 .36173 L
.89249 .36173 L
.89342 .36173 L
.89435 .36173 L
.89528 .36173 L
.89621 .36174 L
.89714 .36174 L
.89807 .36174 L
.899 .36174 L
.89993 .36174 L
.90086 .36174 L
.90179 .36174 L
.90272 .36174 L
.90365 .36174 L
.90458 .36174 L
.90551 .36174 L
.90644 .36174 L
Mistroke
.90737 .36174 L
.9083 .36174 L
.90923 .36174 L
.91016 .36174 L
.91109 .36174 L
.91202 .36174 L
.91295 .36174 L
.91388 .36174 L
.91481 .36174 L
.91574 .36174 L
.91667 .36174 L
.9176 .36174 L
.91853 .36174 L
.91946 .36174 L
.92039 .36174 L
.92132 .36174 L
.92225 .36174 L
.92318 .36174 L
.92411 .36174 L
.92504 .36174 L
.92597 .36174 L
.9269 .36174 L
.92783 .36174 L
.92876 .36174 L
.92969 .36174 L
.93062 .36174 L
.93155 .36174 L
.93248 .36174 L
.93341 .36174 L
.93434 .36174 L
.93527 .36174 L
.9362 .36174 L
.93713 .36174 L
.93806 .36174 L
.93899 .36174 L
.93992 .36174 L
.94085 .36174 L
.94178 .36174 L
.94271 .36174 L
.94364 .36174 L
.94457 .36174 L
.9455 .36174 L
.94643 .36174 L
.94736 .36174 L
.94829 .36174 L
.94922 .36174 L
.95015 .36174 L
.95108 .36174 L
.95201 .36174 L
.95294 .36174 L
Mistroke
.95387 .36174 L
.9548 .36174 L
.95573 .36174 L
.95666 .36174 L
.95759 .36174 L
.95852 .36174 L
.95945 .36174 L
.96038 .36174 L
.96131 .36174 L
.96224 .36174 L
.96317 .36174 L
.9641 .36174 L
.96503 .36174 L
.96596 .36174 L
.96689 .36174 L
.96782 .36174 L
.96875 .36174 L
.96968 .36174 L
.97061 .36174 L
.97154 .36174 L
.97247 .36174 L
.9734 .36174 L
.97433 .36174 L
.97526 .36174 L
.97619 .36174 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.485119 0.0595238 0.323998 0.222657 [
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .324 m
1 .324 L
s
.48512 0 m
.48512 .61803 L
s
[(w[2, t])] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .324 m
.02474 .324 L
.02567 .324 L
.0266 .324 L
.02753 .324 L
.02846 .324 L
.02939 .324 L
.03032 .324 L
.03125 .324 L
.03218 .324 L
.03311 .324 L
.03404 .324 L
.03497 .324 L
.0359 .324 L
.03683 .324 L
.03776 .324 L
.03869 .324 L
.03962 .324 L
.04055 .324 L
.04148 .324 L
.04241 .324 L
.04334 .324 L
.04427 .324 L
.0452 .324 L
.04613 .324 L
.04706 .324 L
.04799 .324 L
.04892 .324 L
.04985 .324 L
.05078 .324 L
.05171 .324 L
.05264 .324 L
.05357 .324 L
.0545 .324 L
.05543 .324 L
.05636 .324 L
.05729 .324 L
.05822 .324 L
.05915 .324 L
.06008 .324 L
.06101 .324 L
.06194 .324 L
.06287 .324 L
.0638 .324 L
.06473 .324 L
.06566 .324 L
.06659 .324 L
.06752 .324 L
.06845 .324 L
.06938 .324 L
Mistroke
.07031 .324 L
.07124 .324 L
.07217 .324 L
.0731 .324 L
.07403 .324 L
.07496 .324 L
.07589 .324 L
.07682 .324 L
.07775 .324 L
.07868 .324 L
.07961 .324 L
.08054 .324 L
.08147 .324 L
.0824 .324 L
.08333 .324 L
.08426 .324 L
.08519 .324 L
.08612 .324 L
.08705 .324 L
.08798 .324 L
.08891 .324 L
.08984 .324 L
.09077 .324 L
.0917 .324 L
.09263 .324 L
.09356 .324 L
.09449 .324 L
.09542 .324 L
.09635 .324 L
.09728 .324 L
.09821 .324 L
.09914 .324 L
.10007 .324 L
.101 .324 L
.10193 .324 L
.10286 .324 L
.10379 .324 L
.10472 .324 L
.10565 .324 L
.10658 .324 L
.10751 .324 L
.10844 .324 L
.10938 .324 L
.11031 .324 L
.11124 .324 L
.11217 .324 L
.1131 .324 L
.11403 .324 L
.11496 .324 L
.11589 .324 L
Mistroke
.11682 .324 L
.11775 .324 L
.11868 .324 L
.11961 .324 L
.12054 .324 L
.12147 .324 L
.1224 .324 L
.12333 .324 L
.12426 .324 L
.12519 .324 L
.12612 .324 L
.12705 .324 L
.12798 .324 L
.12891 .324 L
.12984 .324 L
.13077 .324 L
.1317 .324 L
.13263 .324 L
.13356 .32399 L
.13449 .32399 L
.13542 .32399 L
.13635 .32399 L
.13728 .32398 L
.13821 .32398 L
.13914 .32397 L
.14007 .32397 L
.141 .32397 L
.14193 .32397 L
.14286 .32396 L
.14379 .32396 L
.14472 .32396 L
.14565 .32395 L
.14658 .32395 L
.14751 .32395 L
.14844 .32394 L
.14937 .32394 L
.1503 .32394 L
.15123 .32394 L
.15216 .32393 L
.15309 .32393 L
.15402 .32392 L
.15495 .32392 L
.15588 .32392 L
.15681 .32392 L
.15774 .32393 L
.15867 .32393 L
.1596 .32393 L
.16053 .32394 L
.16146 .32395 L
.16239 .32396 L
Mistroke
.16332 .32397 L
.16425 .32398 L
.16518 .324 L
.16611 .32401 L
.16704 .32403 L
.16797 .32405 L
.1689 .32407 L
.16983 .32408 L
.17076 .3241 L
.17169 .32411 L
.17262 .32414 L
.17355 .32415 L
.17448 .32417 L
.17541 .32419 L
.17634 .32421 L
.17727 .32422 L
.1782 .32424 L
.17913 .32424 L
.18006 .32427 L
.18099 .32428 L
.18192 .3243 L
.18285 .32431 L
.18378 .32432 L
.18471 .32433 L
.18564 .32433 L
.18657 .32432 L
.1875 .32432 L
.18843 .32431 L
.18936 .3243 L
.19029 .32428 L
.19122 .32426 L
.19215 .32423 L
.19308 .32419 L
.19401 .32414 L
.19494 .3241 L
.19587 .32405 L
.1968 .32401 L
.19773 .32396 L
.19866 .32391 L
.19959 .32387 L
.20052 .32383 L
.20145 .32378 L
.20238 .32374 L
.20331 .32371 L
.20424 .32368 L
.20517 .32366 L
.2061 .32364 L
.20703 .32364 L
.20796 .32364 L
.20889 .32365 L
Mistroke
.20982 .32363 L
.21075 .32363 L
.21168 .3236 L
.21261 .32358 L
.21354 .32355 L
.21447 .32355 L
.2154 .32353 L
.21633 .32353 L
.21726 .3235 L
.21819 .32347 L
.21912 .32342 L
.22005 .32339 L
.22098 .32334 L
.22191 .32331 L
.22284 .32327 L
.22377 .32328 L
.2247 .3233 L
.22563 .32332 L
.22656 .32336 L
.22749 .32343 L
.22842 .32353 L
.22935 .32359 L
.23028 .32369 L
.23121 .32381 L
.23214 .324 L
.23307 .32417 L
.234 .3244 L
.23493 .32461 L
.23586 .32486 L
.23679 .32505 L
.23772 .32526 L
.23865 .32541 L
.23958 .32559 L
.24051 .32575 L
.24144 .32593 L
.24237 .32601 L
.2433 .32611 L
.24423 .32616 L
.24516 .32619 L
.24609 .32609 L
.24702 .32598 L
.24795 .32584 L
.24888 .32567 L
.24981 .32541 L
.25074 .32513 L
.25167 .32489 L
.2526 .32464 L
.25353 .32432 L
.25446 .32396 L
.25539 .32361 L
Mistroke
.25632 .32323 L
.25725 .32286 L
.25818 .32246 L
.25911 .32215 L
.26004 .32182 L
.26097 .3216 L
.2619 .32129 L
.26283 .32104 L
.26376 .32073 L
.26469 .32059 L
.26563 .32038 L
.26656 .32023 L
.26749 .32004 L
.26842 .32011 L
.26935 .32015 L
.27028 .32024 L
.27121 .32034 L
.27214 .32066 L
.27307 .32101 L
.274 .32133 L
.27493 .3217 L
.27586 .32223 L
.27679 .32291 L
.27772 .3236 L
.27865 .32442 L
.27958 .32524 L
.28051 .32619 L
.28144 .32706 L
.28237 .32798 L
.2833 .32867 L
.28423 .32943 L
.28516 .3301 L
.28609 .33077 L
.28702 .33107 L
.28795 .33136 L
.28888 .33159 L
.28981 .33173 L
.29074 .33143 L
.29167 .33096 L
.2926 .33036 L
.29353 .32963 L
.29446 .32857 L
.29539 .32739 L
.29632 .32622 L
.29725 .32503 L
.29818 .3238 L
.29911 .32249 L
.30004 .3212 L
.30097 .31994 L
.3019 .31889 L
Mistroke
.30283 .31786 L
.30376 .31689 L
.30469 .31605 L
.30562 .31569 L
.30655 .31545 L
.30748 .31535 L
.30841 .31538 L
.30934 .31594 L
.31027 .31654 L
.3112 .31714 L
.31213 .31774 L
.31306 .31875 L
.31399 .31983 L
.31492 .32094 L
.31585 .32205 L
.31678 .32332 L
.31771 .32463 L
.31864 .32583 L
.31957 .32697 L
.3205 .32796 L
.32143 .32902 L
.32236 .33002 L
.32329 .33103 L
.32422 .33163 L
.32515 .33234 L
.32608 .333 L
.32701 .33368 L
.32794 .33373 L
.32887 .33378 L
.3298 .33374 L
.33073 .33365 L
.33166 .33295 L
.33259 .33217 L
.33352 .33147 L
.33445 .33066 L
.33538 .32941 L
.33631 .32786 L
.33724 .32628 L
.33817 .32446 L
.3391 .32257 L
.34003 .32038 L
.34096 .31835 L
.34189 .31621 L
.34282 .31453 L
.34375 .3127 L
.34468 .31108 L
.34561 .30948 L
.34654 .30867 L
.34747 .30785 L
.3484 .30717 L
Mistroke
.34933 .30664 L
.35026 .30711 L
.35119 .30791 L
.35212 .30905 L
.35305 .31046 L
.35398 .31265 L
.35491 .31503 L
.35584 .31741 L
.35677 .31977 L
.3577 .32235 L
.35863 .32507 L
.35956 .32784 L
.36049 .33053 L
.36142 .33286 L
.36235 .33514 L
.36328 .33731 L
.36421 .3392 L
.36514 .34013 L
.36607 .34084 L
.367 .34138 L
.36793 .34164 L
.36886 .34079 L
.36979 .33984 L
.37072 .339 L
.37165 .33809 L
.37258 .33618 L
.37351 .33406 L
.37444 .33198 L
.37537 .32978 L
.3763 .32705 L
.37723 .32412 L
.37816 .32158 L
.37909 .31898 L
.38002 .31656 L
.38095 .31371 L
.38188 .31115 L
.38281 .30832 L
.38374 .30632 L
.38467 .30385 L
.3856 .30169 L
.38653 .29935 L
.38746 .29851 L
.38839 .29752 L
.38932 .29695 L
.39025 .29644 L
.39118 .29753 L
.39211 .29868 L
.39304 .29987 L
.39397 .30128 L
.3949 .30405 L
Mistroke
.39583 .30757 L
.39676 .31146 L
.39769 .31592 L
.39862 .32087 L
.39955 .32639 L
.40048 .33167 L
.40141 .33703 L
.40234 .34153 L
.40327 .34636 L
.4042 .35094 L
.40513 .35537 L
.40606 .35804 L
.40699 .3606 L
.40792 .36288 L
.40885 .36463 L
.40978 .36387 L
.41071 .36231 L
.41164 .36011 L
.41257 .35719 L
.4135 .35223 L
.41443 .34688 L
.41536 .34191 L
.41629 .33692 L
.41722 .33096 L
.41815 .32448 L
.41908 .31811 L
.42001 .31168 L
.42094 .30562 L
.42188 .29941 L
.42281 .29402 L
.42374 .28894 L
.42467 .28596 L
.4256 .28276 L
.42653 .28029 L
.42746 .2778 L
.42839 .27808 L
.42932 .2776 L
.43025 .27688 L
.43118 .27585 L
.43211 .27826 L
.43304 .28098 L
.43397 .28401 L
.4349 .28758 L
.43583 .29382 L
.43676 .30066 L
.43769 .30618 L
.43862 .31238 L
.43955 .31939 L
.44048 .32889 L
.44141 .33819 L
Mistroke
.44234 .34944 L
.44327 .35931 L
.4442 .372 L
.44513 .38453 L
.44606 .398 L
.44699 .40615 L
.44792 .41477 L
.44885 .42241 L
.44978 .42888 L
.45071 .42878 L
.45164 .42765 L
.45257 .42781 L
.4535 .42564 L
.45443 .41728 L
.45536 .40348 L
.45629 .38838 L
.45722 .36862 L
.45815 .34607 L
.45908 .31831 L
.46001 .29083 L
.46094 .26185 L
.46187 .23791 L
.4628 .21252 L
.46373 .1883 L
.46466 .16618 L
.46559 .1535 L
.46652 .14247 L
.46745 .13017 L
.46838 .12255 L
.46931 .12717 L
.47024 .14043 L
.47117 .1567 L
.4721 .18082 L
.47303 .21369 L
.47396 .25399 L
.47489 .2938 L
.47582 .33568 L
.47675 .37538 L
.47768 .41759 L
.47861 .45878 L
.47954 .49708 L
.48047 .52555 L
.4814 .55189 L
.48233 .57924 L
.48326 .59963 L
.48419 .60332 L
.48512 .59608 L
.48605 .58435 L
.48698 .56217 L
.48791 .52552 L
Mistroke
.48884 .48021 L
.48977 .43556 L
.4907 .38849 L
.49163 .3389 L
.49256 .28607 L
.49349 .23372 L
.49442 .18464 L
.49535 .14282 L
.49628 .10332 L
.49721 .0632 L
.49814 .03144 L
.49907 .01732 L
.5 .01472 L
.50093 .01732 L
.50186 .03144 L
.50279 .0632 L
.50372 .10332 L
.50465 .14282 L
.50558 .18464 L
.50651 .23372 L
.50744 .28607 L
.50837 .3389 L
.5093 .38849 L
.51023 .43556 L
.51116 .48021 L
.51209 .52552 L
.51302 .56217 L
.51395 .58435 L
.51488 .59608 L
.51581 .60332 L
.51674 .59963 L
.51767 .57924 L
.5186 .55189 L
.51953 .52555 L
.52046 .49708 L
.52139 .45878 L
.52232 .41759 L
.52325 .37538 L
.52418 .33568 L
.52511 .2938 L
.52604 .25399 L
.52697 .21369 L
.5279 .18082 L
.52883 .1567 L
.52976 .14043 L
.53069 .12717 L
.53162 .12255 L
.53255 .13017 L
.53348 .14247 L
.53441 .1535 L
Mistroke
.53534 .16618 L
.53627 .1883 L
.5372 .21252 L
.53813 .23791 L
.53906 .26185 L
.53999 .29083 L
.54092 .31831 L
.54185 .34607 L
.54278 .36862 L
.54371 .38838 L
.54464 .40348 L
.54557 .41728 L
.5465 .42564 L
.54743 .42781 L
.54836 .42765 L
.54929 .42878 L
.55022 .42888 L
.55115 .42241 L
.55208 .41477 L
.55301 .40615 L
.55394 .398 L
.55487 .38453 L
.5558 .372 L
.55673 .35931 L
.55766 .34944 L
.55859 .33819 L
.55952 .32889 L
.56045 .31939 L
.56138 .31238 L
.56231 .30618 L
.56324 .30066 L
.56417 .29382 L
.5651 .28758 L
.56603 .28401 L
.56696 .28098 L
.56789 .27826 L
.56882 .27585 L
.56975 .27688 L
.57068 .2776 L
.57161 .27808 L
.57254 .2778 L
.57347 .28029 L
.5744 .28276 L
.57533 .28596 L
.57626 .28894 L
.57719 .29402 L
.57812 .29941 L
.57906 .30562 L
.57999 .31168 L
.58092 .31811 L
Mistroke
.58185 .32448 L
.58278 .33096 L
.58371 .33692 L
.58464 .34191 L
.58557 .34688 L
.5865 .35223 L
.58743 .35719 L
.58836 .36011 L
.58929 .36231 L
.59022 .36387 L
.59115 .36463 L
.59208 .36288 L
.59301 .3606 L
.59394 .35804 L
.59487 .35537 L
.5958 .35094 L
.59673 .34636 L
.59766 .34153 L
.59859 .33703 L
.59952 .33167 L
.60045 .32639 L
.60138 .32087 L
.60231 .31592 L
.60324 .31146 L
.60417 .30757 L
.6051 .30405 L
.60603 .30128 L
.60696 .29987 L
.60789 .29868 L
.60882 .29753 L
.60975 .29644 L
.61068 .29695 L
.61161 .29752 L
.61254 .29851 L
.61347 .29935 L
.6144 .30169 L
.61533 .30385 L
.61626 .30632 L
.61719 .30832 L
.61812 .31115 L
.61905 .31371 L
.61998 .31656 L
.62091 .31898 L
.62184 .32158 L
.62277 .32412 L
.6237 .32705 L
.62463 .32978 L
.62556 .33198 L
.62649 .33406 L
.62742 .33618 L
Mistroke
.62835 .33809 L
.62928 .339 L
.63021 .33984 L
.63114 .34079 L
.63207 .34164 L
.633 .34138 L
.63393 .34084 L
.63486 .34013 L
.63579 .3392 L
.63672 .33731 L
.63765 .33514 L
.63858 .33286 L
.63951 .33053 L
.64044 .32784 L
.64137 .32507 L
.6423 .32235 L
.64323 .31977 L
.64416 .31741 L
.64509 .31503 L
.64602 .31265 L
.64695 .31046 L
.64788 .30905 L
.64881 .30791 L
.64974 .30711 L
.65067 .30664 L
.6516 .30717 L
.65253 .30785 L
.65346 .30867 L
.65439 .30948 L
.65532 .31108 L
.65625 .3127 L
.65718 .31453 L
.65811 .31621 L
.65904 .31835 L
.65997 .32038 L
.6609 .32257 L
.66183 .32446 L
.66276 .32628 L
.66369 .32786 L
.66462 .32941 L
.66555 .33066 L
.66648 .33147 L
.66741 .33217 L
.66834 .33295 L
.66927 .33365 L
.6702 .33374 L
.67113 .33378 L
.67206 .33373 L
.67299 .33368 L
.67392 .333 L
Mistroke
.67485 .33234 L
.67578 .33163 L
.67671 .33103 L
.67764 .33002 L
.67857 .32902 L
.6795 .32796 L
.68043 .32697 L
.68136 .32583 L
.68229 .32463 L
.68322 .32332 L
.68415 .32205 L
.68508 .32094 L
.68601 .31983 L
.68694 .31875 L
.68787 .31774 L
.6888 .31714 L
.68973 .31654 L
.69066 .31594 L
.69159 .31538 L
.69252 .31535 L
.69345 .31545 L
.69438 .31569 L
.69531 .31605 L
.69624 .31689 L
.69717 .31786 L
.6981 .31889 L
.69903 .31994 L
.69996 .3212 L
.70089 .32249 L
.70182 .3238 L
.70275 .32503 L
.70368 .32622 L
.70461 .32739 L
.70554 .32857 L
.70647 .32963 L
.7074 .33036 L
.70833 .33096 L
.70926 .33143 L
.71019 .33173 L
.71112 .33159 L
.71205 .33136 L
.71298 .33107 L
.71391 .33077 L
.71484 .3301 L
.71577 .32943 L
.7167 .32867 L
.71763 .32798 L
.71856 .32706 L
.71949 .32619 L
.72042 .32524 L
Mistroke
.72135 .32442 L
.72228 .3236 L
.72321 .32291 L
.72414 .32223 L
.72507 .3217 L
.726 .32133 L
.72693 .32101 L
.72786 .32066 L
.72879 .32034 L
.72972 .32024 L
.73065 .32015 L
.73158 .32011 L
.73251 .32004 L
.73344 .32023 L
.73437 .32038 L
.73531 .32059 L
.73624 .32073 L
.73717 .32104 L
.7381 .32129 L
.73903 .3216 L
.73996 .32182 L
.74089 .32215 L
.74182 .32246 L
.74275 .32286 L
.74368 .32323 L
.74461 .32361 L
.74554 .32396 L
.74647 .32432 L
.7474 .32464 L
.74833 .32489 L
.74926 .32513 L
.75019 .32541 L
.75112 .32567 L
.75205 .32584 L
.75298 .32598 L
.75391 .32609 L
.75484 .32619 L
.75577 .32616 L
.7567 .32611 L
.75763 .32601 L
.75856 .32593 L
.75949 .32575 L
.76042 .32559 L
.76135 .32541 L
.76228 .32526 L
.76321 .32505 L
.76414 .32486 L
.76507 .32461 L
.766 .3244 L
.76693 .32417 L
Mistroke
.76786 .324 L
.76879 .32381 L
.76972 .32369 L
.77065 .32359 L
.77158 .32353 L
.77251 .32343 L
.77344 .32336 L
.77437 .32332 L
.7753 .3233 L
.77623 .32328 L
.77716 .32327 L
.77809 .32331 L
.77902 .32334 L
.77995 .32339 L
.78088 .32342 L
.78181 .32347 L
.78274 .3235 L
.78367 .32353 L
.7846 .32353 L
.78553 .32355 L
.78646 .32355 L
.78739 .32358 L
.78832 .3236 L
.78925 .32363 L
.79018 .32363 L
.79111 .32365 L
.79204 .32364 L
.79297 .32364 L
.7939 .32364 L
.79483 .32366 L
.79576 .32368 L
.79669 .32371 L
.79762 .32374 L
.79855 .32378 L
.79948 .32383 L
.80041 .32387 L
.80134 .32391 L
.80227 .32396 L
.8032 .32401 L
.80413 .32405 L
.80506 .3241 L
.80599 .32414 L
.80692 .32419 L
.80785 .32423 L
.80878 .32426 L
.80971 .32428 L
.81064 .3243 L
.81157 .32431 L
.8125 .32432 L
.81343 .32432 L
Mistroke
.81436 .32433 L
.81529 .32433 L
.81622 .32432 L
.81715 .32431 L
.81808 .3243 L
.81901 .32428 L
.81994 .32427 L
.82087 .32424 L
.8218 .32424 L
.82273 .32422 L
.82366 .32421 L
.82459 .32419 L
.82552 .32417 L
.82645 .32415 L
.82738 .32414 L
.82831 .32411 L
.82924 .3241 L
.83017 .32408 L
.8311 .32407 L
.83203 .32405 L
.83296 .32403 L
.83389 .32401 L
.83482 .324 L
.83575 .32398 L
.83668 .32397 L
.83761 .32396 L
.83854 .32395 L
.83947 .32394 L
.8404 .32393 L
.84133 .32393 L
.84226 .32393 L
.84319 .32392 L
.84412 .32392 L
.84505 .32392 L
.84598 .32392 L
.84691 .32393 L
.84784 .32393 L
.84877 .32394 L
.8497 .32394 L
.85063 .32394 L
.85156 .32394 L
.85249 .32395 L
.85342 .32395 L
.85435 .32395 L
.85528 .32396 L
.85621 .32396 L
.85714 .32396 L
.85807 .32397 L
.859 .32397 L
.85993 .32397 L
Mistroke
.86086 .32397 L
.86179 .32398 L
.86272 .32398 L
.86365 .32399 L
.86458 .32399 L
.86551 .32399 L
.86644 .32399 L
.86737 .324 L
.8683 .324 L
.86923 .324 L
.87016 .324 L
.87109 .324 L
.87202 .324 L
.87295 .324 L
.87388 .324 L
.87481 .324 L
.87574 .324 L
.87667 .324 L
.8776 .324 L
.87853 .324 L
.87946 .324 L
.88039 .324 L
.88132 .324 L
.88225 .324 L
.88318 .324 L
.88411 .324 L
.88504 .324 L
.88597 .324 L
.8869 .324 L
.88783 .324 L
.88876 .324 L
.88969 .324 L
.89062 .324 L
.89156 .324 L
.89249 .324 L
.89342 .324 L
.89435 .324 L
.89528 .324 L
.89621 .324 L
.89714 .324 L
.89807 .324 L
.899 .324 L
.89993 .324 L
.90086 .324 L
.90179 .324 L
.90272 .324 L
.90365 .324 L
.90458 .324 L
.90551 .324 L
.90644 .324 L
Mistroke
.90737 .324 L
.9083 .324 L
.90923 .324 L
.91016 .324 L
.91109 .324 L
.91202 .324 L
.91295 .324 L
.91388 .324 L
.91481 .324 L
.91574 .324 L
.91667 .324 L
.9176 .324 L
.91853 .324 L
.91946 .324 L
.92039 .324 L
.92132 .324 L
.92225 .324 L
.92318 .324 L
.92411 .324 L
.92504 .324 L
.92597 .324 L
.9269 .324 L
.92783 .324 L
.92876 .324 L
.92969 .324 L
.93062 .324 L
.93155 .324 L
.93248 .324 L
.93341 .324 L
.93434 .324 L
.93527 .324 L
.9362 .324 L
.93713 .324 L
.93806 .324 L
.93899 .324 L
.93992 .324 L
.94085 .324 L
.94178 .324 L
.94271 .324 L
.94364 .324 L
.94457 .324 L
.9455 .324 L
.94643 .324 L
.94736 .324 L
.94829 .324 L
.94922 .324 L
.95015 .324 L
.95108 .324 L
.95201 .324 L
.95294 .324 L
Mistroke
.95387 .324 L
.9548 .324 L
.95573 .324 L
.95666 .324 L
.95759 .324 L
.95852 .324 L
.95945 .324 L
.96038 .324 L
.96131 .324 L
.96224 .324 L
.96317 .324 L
.9641 .324 L
.96503 .324 L
.96596 .324 L
.96689 .324 L
.96782 .324 L
.96875 .324 L
.96968 .324 L
.97061 .324 L
.97154 .324 L
.97247 .324 L
.9734 .324 L
.97433 .324 L
.97526 .324 L
.97619 .324 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],

Cell[TextData[{
  "1.5.8 Zooming in on Details of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.5.8"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.5.8"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`w\)], "InlineFormula",
    CellTags->"S1.5.8"]
}], "Subsection",
  CellTags->{"S1.5.8", "8.1"}],

Cell[TextData[{
  "Sometimes we are interested in the details of a scaling function or \
wavelet. Of course, we can always obtain finer details by using sufficiently \
large values for the argument ",
  StyleBox["jmax", "TI"],
  " in ",
  StyleBox["ScalingFunction", "MR"],
  ", ",
  StyleBox["Wavelet", "MR"],
  ", or ",
  StyleBox["WaveletPacket", "MR"],
  ". However, it may happen that we are interested in these functions only in \
a particular, small interval. In this case, calculating these functions on \
their entire support is clearly wasteful. Using the inverse wavelet transform \
method, we can easily concentrate on a particular region and \"zoom in\" or \
\"blow up\" the function.\nWe introduce the function "
}], "Text",
  CellTags->{"S1.5.8", "8.2"}],

Cell[TextData[{
  StyleBox["Zoom[", "MR"],
  StyleBox["flist", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["j", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.5.8"],
  StyleBox["tmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["tmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.5.8"],
  StyleBox["]", "MR"],
  ", "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.5.8", "8.3"}],

Cell[TextData[{
  "where ",
  StyleBox["flist", "TI"],
  " is a list of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"k", "/", 
            SuperscriptBox["2", 
              StyleBox[\("jmax"\),
                "TI"]], ",", "f", 
            RowBox[{"(", 
              RowBox[{"k", "/", 
                SuperscriptBox["2", 
                  StyleBox[\("jmax"\),
                    "TI"]]}], ")"}]}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.8"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.5.8"],
  " is the additional number of times we want to perform the recombination so \
as to get to the scale ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["2", 
          RowBox[{"-", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\("jmax"\),
                  "TI"], "+", "j"}], ")"}]}]], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.8"],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox[\("tmin"\),
              "TI"], ",", 
            StyleBox[\("tmax"\),
              "TI"]}], "}"}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.5.8"],
  " is the interval we are interested in. "
}], "Text",
  CellTags->{"S1.5.8", "8.4"}],

Cell[TextData[{
  "The second\[Hyphen]order coiflet scaling function is calculated to scale ",
  
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-5\)\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.5"}],

Cell["\<\
(c2 = CoifletFilter[2];
 s = ScalingFunction[c2, 5, InverseTransform -> True];)\
\>", "Input",
  CellLabel->"In[42]:= ",
  CellTags->"S1.5.8"],

Cell["This shows its graph.", "MathCaption",
  CellTags->{"S1.5.8", "8.6"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[s, PlotRange -> All,
PlotJoined -> True, AxesLabel -> {\"t\", \"phi(t)\"}]\
\>", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.106472 0.318457 [
[.02381 .09397 -6 -9 ]
[.02381 .09397 6 0 ]
[.21429 .09397 -6 -9 ]
[.21429 .09397 6 0 ]
[.59524 .09397 -3 -9 ]
[.59524 .09397 3 0 ]
[.78571 .09397 -3 -9 ]
[.78571 .09397 3 0 ]
[.97619 .09397 -3 -9 ]
[.97619 .09397 3 0 ]
[1.025 .10647 0 -4.5 ]
[1.025 .10647 6 4.5 ]
[.39226 .02686 -30 -4.5 ]
[.39226 .02686 0 4.5 ]
[.39226 .18609 -24 -4.5 ]
[.39226 .18609 0 4.5 ]
[.39226 .2657 -18 -4.5 ]
[.39226 .2657 0 4.5 ]
[.39226 .34531 -24 -4.5 ]
[.39226 .34531 0 4.5 ]
[.39226 .42493 -6 -4.5 ]
[.39226 .42493 0 4.5 ]
[.39226 .50454 -24 -4.5 ]
[.39226 .50454 0 4.5 ]
[.39226 .58416 -18 -4.5 ]
[.39226 .58416 0 4.5 ]
[.40476 .64303 -18 0 ]
[.40476 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .10647 m
.02381 .11272 L
s
[(-2)] .02381 .09397 0 1 Mshowa
.21429 .10647 m
.21429 .11272 L
s
[(-1)] .21429 .09397 0 1 Mshowa
.59524 .10647 m
.59524 .11272 L
s
[(1)] .59524 .09397 0 1 Mshowa
.78571 .10647 m
.78571 .11272 L
s
[(2)] .78571 .09397 0 1 Mshowa
.97619 .10647 m
.97619 .11272 L
s
[(3)] .97619 .09397 0 1 Mshowa
.125 Mabswid
.0619 .10647 m
.0619 .11022 L
s
.1 .10647 m
.1 .11022 L
s
.1381 .10647 m
.1381 .11022 L
s
.17619 .10647 m
.17619 .11022 L
s
.25238 .10647 m
.25238 .11022 L
s
.29048 .10647 m
.29048 .11022 L
s
.32857 .10647 m
.32857 .11022 L
s
.36667 .10647 m
.36667 .11022 L
s
.44286 .10647 m
.44286 .11022 L
s
.48095 .10647 m
.48095 .11022 L
s
.51905 .10647 m
.51905 .11022 L
s
.55714 .10647 m
.55714 .11022 L
s
.63333 .10647 m
.63333 .11022 L
s
.67143 .10647 m
.67143 .11022 L
s
.70952 .10647 m
.70952 .11022 L
s
.74762 .10647 m
.74762 .11022 L
s
.82381 .10647 m
.82381 .11022 L
s
.8619 .10647 m
.8619 .11022 L
s
.9 .10647 m
.9 .11022 L
s
.9381 .10647 m
.9381 .11022 L
s
.25 Mabswid
0 .10647 m
1 .10647 L
s
[(t)] 1.025 .10647 -1 0 Mshowa
.40476 .02686 m
.41101 .02686 L
s
[(-0.25)] .39226 .02686 1 0 Mshowa
.40476 .18609 m
.41101 .18609 L
s
[(0.25)] .39226 .18609 1 0 Mshowa
.40476 .2657 m
.41101 .2657 L
s
[(0.5)] .39226 .2657 1 0 Mshowa
.40476 .34531 m
.41101 .34531 L
s
[(0.75)] .39226 .34531 1 0 Mshowa
.40476 .42493 m
.41101 .42493 L
s
[(1)] .39226 .42493 1 0 Mshowa
.40476 .50454 m
.41101 .50454 L
s
[(1.25)] .39226 .50454 1 0 Mshowa
.40476 .58416 m
.41101 .58416 L
s
[(1.5)] .39226 .58416 1 0 Mshowa
.125 Mabswid
.40476 .04278 m
.40851 .04278 L
s
.40476 .0587 m
.40851 .0587 L
s
.40476 .07463 m
.40851 .07463 L
s
.40476 .09055 m
.40851 .09055 L
s
.40476 .12239 m
.40851 .12239 L
s
.40476 .13832 m
.40851 .13832 L
s
.40476 .15424 m
.40851 .15424 L
s
.40476 .17016 m
.40851 .17016 L
s
.40476 .20201 m
.40851 .20201 L
s
.40476 .21793 m
.40851 .21793 L
s
.40476 .23385 m
.40851 .23385 L
s
.40476 .24978 m
.40851 .24978 L
s
.40476 .28162 m
.40851 .28162 L
s
.40476 .29755 m
.40851 .29755 L
s
.40476 .31347 m
.40851 .31347 L
s
.40476 .32939 m
.40851 .32939 L
s
.40476 .36124 m
.40851 .36124 L
s
.40476 .37716 m
.40851 .37716 L
s
.40476 .39308 m
.40851 .39308 L
s
.40476 .40901 m
.40851 .40901 L
s
.40476 .44085 m
.40851 .44085 L
s
.40476 .45677 m
.40851 .45677 L
s
.40476 .4727 m
.40851 .4727 L
s
.40476 .48862 m
.40851 .48862 L
s
.40476 .52047 m
.40851 .52047 L
s
.40476 .53639 m
.40851 .53639 L
s
.40476 .55231 m
.40851 .55231 L
s
.40476 .56823 m
.40851 .56823 L
s
.40476 .01093 m
.40851 .01093 L
s
.40476 .60008 m
.40851 .60008 L
s
.40476 .616 m
.40851 .616 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(phi\\(t\\))] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .10647 m
.02976 .10647 L
.03571 .10647 L
.04167 .10649 L
.04762 .10653 L
.05357 .10641 L
.05952 .10633 L
.06548 .1061 L
.07143 .10573 L
.07738 .10644 L
.08333 .10709 L
.08929 .10747 L
.09524 .10772 L
.10119 .10894 L
.10714 .10992 L
.1131 .11186 L
.11905 .11481 L
.125 .11051 L
.13095 .10677 L
.1369 .10364 L
.14286 .1002 L
.14881 .09858 L
.15476 .09668 L
.16071 .09553 L
.16667 .09527 L
.17262 .08862 L
.17857 .08229 L
.18452 .0777 L
.19048 .07395 L
.19643 .06372 L
.20238 .05505 L
.20833 .03993 L
.21429 .01813 L
.22024 .04474 L
.22619 .06776 L
.23214 .0856 L
.2381 .10447 L
.24405 .11866 L
.25 .13305 L
.25595 .14896 L
.2619 .16581 L
.26786 .17556 L
.27381 .18581 L
.27976 .19702 L
.28571 .20826 L
.29167 .21888 L
.29762 .22974 L
.30357 .23935 L
.30952 .24774 L
.31548 .26506 L
Mistroke
.32143 .28168 L
.32738 .29767 L
.33333 .31415 L
.33929 .32755 L
.34524 .34149 L
.35119 .35375 L
.35714 .36414 L
.3631 .38805 L
.36905 .41129 L
.375 .43092 L
.38095 .44888 L
.3869 .47991 L
.39286 .50781 L
.39881 .54878 L
.40476 .60332 L
.41071 .55961 L
.41667 .52318 L
.42262 .4972 L
.42857 .46905 L
.43452 .45091 L
.44048 .43224 L
.44643 .41093 L
.45238 .38816 L
.45833 .3765 L
.46429 .36401 L
.47024 .3504 L
.47619 .33711 L
.48214 .32215 L
.4881 .30742 L
.49405 .29227 L
.5 .27657 L
.50595 .26479 L
.5119 .25274 L
.51786 .24012 L
.52381 .22743 L
.52976 .21544 L
.53571 .20322 L
.54167 .19209 L
.54762 .18205 L
.55357 .16411 L
.55952 .14658 L
.56548 .13103 L
.57143 .11634 L
.57738 .09489 L
.58333 .07508 L
.58929 .04844 L
.59524 .01472 L
.60119 .03227 L
.60714 .04603 L
.6131 .05434 L
Mistroke
.61905 .0638 L
.625 .06795 L
.63095 .0724 L
.6369 .07816 L
.64286 .0846 L
.64881 .08578 L
.65476 .08735 L
.66071 .08938 L
.66667 .09118 L
.67262 .09433 L
.67857 .09725 L
.68452 .10086 L
.69048 .10526 L
.69643 .104 L
.70238 .10316 L
.70833 .10293 L
.71429 .10257 L
.72024 .10278 L
.72619 .10296 L
.73214 .10298 L
.7381 .10289 L
.74405 .10356 L
.75 .10418 L
.75595 .10469 L
.7619 .10518 L
.76786 .10582 L
.77381 .10641 L
.77976 .10719 L
.78571 .10818 L
.79167 .10773 L
.79762 .10738 L
.80357 .10719 L
.80952 .10697 L
.81548 .10689 L
.82143 .1068 L
.82738 .10667 L
.83333 .10652 L
.83929 .10654 L
.84524 .10656 L
.85119 .10655 L
.85714 .10655 L
.8631 .10652 L
.86905 .1065 L
.875 .10647 L
.88095 .10644 L
.8869 .10645 L
.89286 .10646 L
.89881 .10646 L
.90476 .10647 L
.91071 .10647 L
Mistroke
.91667 .10647 L
.92262 .10647 L
.92857 .10647 L
.93452 .10647 L
.94048 .10647 L
.94643 .10647 L
.95238 .10647 L
.95833 .10647 L
.96429 .10647 L
.97024 .10647 L
.97619 .10647 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "This is the second\[Hyphen]order coiflet scaling function with intervals \
between data points being ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]], "=", "1", "/", "32"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.5.8"],
  ". Suppose we want to look at the details around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)], "InlineFormula",
    CellTags->"S1.5.8"],
  ", say in the region of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([1 - 1/32, 1 + 1/32]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.8"],
  ", we need to increase ",
  StyleBox["jmax", "TI"],
  " to generate more data points in this region. But we can ignore the rest \
of the graph and only concentrate on this given region using ",
  StyleBox["Zoom", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.5.8", "8.7"}],

Cell[TextData[{
  "The scaling function around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)], "InlineFormula",
    CellTags->"S1.5.8"],
  " is calculated to a finer scale."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.8"}],

Cell["s1 = Zoom[s, c2, 3, {1-1/32, 1+1/32}];", "Input",
  CellLabel->"In[44]:= ",
  CellTags->"S1.5.8"],

Cell[TextData[{
  "Here is the blown\[Hyphen]up view of the scaling function around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.9"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[s1, Frame -> True, PlotJoined -> True,
PlotLabel -> \"phi(t)\"]\
\>", "Input",
  CellLabel->"In[45]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-11.6905 12.1905 1.17906 3.59503 [
[.01238 -0.0125 -12 -9 ]
[.01238 -0.0125 12 0 ]
[.25619 -0.0125 -12 -9 ]
[.25619 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.74381 -0.0125 -12 -9 ]
[.74381 -0.0125 12 0 ]
[.98762 -0.0125 -12 -9 ]
[.98762 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01067 -36 -4.5 ]
[-0.0125 .01067 0 4.5 ]
[-0.0125 .10055 -24 -4.5 ]
[-0.0125 .10055 0 4.5 ]
[-0.0125 .19042 -36 -4.5 ]
[-0.0125 .19042 0 4.5 ]
[-0.0125 .2803 -30 -4.5 ]
[-0.0125 .2803 0 4.5 ]
[-0.0125 .37018 -36 -4.5 ]
[-0.0125 .37018 0 4.5 ]
[-0.0125 .46005 -24 -4.5 ]
[-0.0125 .46005 0 4.5 ]
[-0.0125 .54993 -36 -4.5 ]
[-0.0125 .54993 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01238 0 m
.01238 .00625 L
s
[(0.96)] .01238 -0.0125 0 1 Mshowa
.25619 0 m
.25619 .00625 L
s
[(0.98)] .25619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.74381 0 m
.74381 .00625 L
s
[(1.02)] .74381 -0.0125 0 1 Mshowa
.98762 0 m
.98762 .00625 L
s
[(1.04)] .98762 -0.0125 0 1 Mshowa
.125 Mabswid
.07333 0 m
.07333 .00375 L
s
.13429 0 m
.13429 .00375 L
s
.19524 0 m
.19524 .00375 L
s
.31714 0 m
.31714 .00375 L
s
.3781 0 m
.3781 .00375 L
s
.43905 0 m
.43905 .00375 L
s
.56095 0 m
.56095 .00375 L
s
.6219 0 m
.6219 .00375 L
s
.68286 0 m
.68286 .00375 L
s
.80476 0 m
.80476 .00375 L
s
.86571 0 m
.86571 .00375 L
s
.92667 0 m
.92667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01067 m
.00625 .01067 L
s
[(-0.325)] -0.0125 .01067 1 0 Mshowa
0 .10055 m
.00625 .10055 L
s
[(-0.3)] -0.0125 .10055 1 0 Mshowa
0 .19042 m
.00625 .19042 L
s
[(-0.275)] -0.0125 .19042 1 0 Mshowa
0 .2803 m
.00625 .2803 L
s
[(-0.25)] -0.0125 .2803 1 0 Mshowa
0 .37018 m
.00625 .37018 L
s
[(-0.225)] -0.0125 .37018 1 0 Mshowa
0 .46005 m
.00625 .46005 L
s
[(-0.2)] -0.0125 .46005 1 0 Mshowa
0 .54993 m
.00625 .54993 L
s
[(-0.175)] -0.0125 .54993 1 0 Mshowa
.125 Mabswid
0 .02865 m
.00375 .02865 L
s
0 .04662 m
.00375 .04662 L
s
0 .0646 m
.00375 .0646 L
s
0 .08257 m
.00375 .08257 L
s
0 .11852 m
.00375 .11852 L
s
0 .1365 m
.00375 .1365 L
s
0 .15447 m
.00375 .15447 L
s
0 .17245 m
.00375 .17245 L
s
0 .2084 m
.00375 .2084 L
s
0 .22638 m
.00375 .22638 L
s
0 .24435 m
.00375 .24435 L
s
0 .26233 m
.00375 .26233 L
s
0 .29828 m
.00375 .29828 L
s
0 .31625 m
.00375 .31625 L
s
0 .33423 m
.00375 .33423 L
s
0 .3522 m
.00375 .3522 L
s
0 .38815 m
.00375 .38815 L
s
0 .40613 m
.00375 .40613 L
s
0 .4241 m
.00375 .4241 L
s
0 .44208 m
.00375 .44208 L
s
0 .47803 m
.00375 .47803 L
s
0 .496 m
.00375 .496 L
s
0 .51398 m
.00375 .51398 L
s
0 .53195 m
.00375 .53195 L
s
0 .5679 m
.00375 .5679 L
s
0 .58588 m
.00375 .58588 L
s
0 .60385 m
.00375 .60385 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.01238 .61178 m
.01238 .61803 L
s
.25619 .61178 m
.25619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74381 .61178 m
.74381 .61803 L
s
.98762 .61178 m
.98762 .61803 L
s
.125 Mabswid
.07333 .61428 m
.07333 .61803 L
s
.13429 .61428 m
.13429 .61803 L
s
.19524 .61428 m
.19524 .61803 L
s
.31714 .61428 m
.31714 .61803 L
s
.3781 .61428 m
.3781 .61803 L
s
.43905 .61428 m
.43905 .61803 L
s
.56095 .61428 m
.56095 .61803 L
s
.6219 .61428 m
.6219 .61803 L
s
.68286 .61428 m
.68286 .61803 L
s
.80476 .61428 m
.80476 .61803 L
s
.86571 .61428 m
.86571 .61803 L
s
.92667 .61428 m
.92667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01067 m
1 .01067 L
s
.99375 .10055 m
1 .10055 L
s
.99375 .19042 m
1 .19042 L
s
.99375 .2803 m
1 .2803 L
s
.99375 .37018 m
1 .37018 L
s
.99375 .46005 m
1 .46005 L
s
.99375 .54993 m
1 .54993 L
s
.125 Mabswid
.99625 .02865 m
1 .02865 L
s
.99625 .04662 m
1 .04662 L
s
.99625 .0646 m
1 .0646 L
s
.99625 .08257 m
1 .08257 L
s
.99625 .11852 m
1 .11852 L
s
.99625 .1365 m
1 .1365 L
s
.99625 .15447 m
1 .15447 L
s
.99625 .17245 m
1 .17245 L
s
.99625 .2084 m
1 .2084 L
s
.99625 .22638 m
1 .22638 L
s
.99625 .24435 m
1 .24435 L
s
.99625 .26233 m
1 .26233 L
s
.99625 .29828 m
1 .29828 L
s
.99625 .31625 m
1 .31625 L
s
.99625 .33423 m
1 .33423 L
s
.99625 .3522 m
1 .3522 L
s
.99625 .38815 m
1 .38815 L
s
.99625 .40613 m
1 .40613 L
s
.99625 .4241 m
1 .4241 L
s
.99625 .44208 m
1 .44208 L
s
.99625 .47803 m
1 .47803 L
s
.99625 .496 m
1 .496 L
s
.99625 .51398 m
1 .51398 L
s
.99625 .53195 m
1 .53195 L
s
.99625 .5679 m
1 .5679 L
s
.99625 .58588 m
1 .58588 L
s
.99625 .60385 m
1 .60385 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(phi\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.07143 .57059 L
.11905 .54133 L
.16667 .48705 L
.21429 .43401 L
.2619 .38776 L
.30952 .34472 L
.35714 .27666 L
.40476 .2146 L
.45238 .12759 L
.5 .01472 L
.54762 .08925 L
.59524 .14988 L
.64286 .19063 L
.69048 .23553 L
.7381 .26109 L
.78571 .28773 L
.83333 .31915 L
.88095 .35311 L
.92857 .36767 L
.97619 .38373 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "We see that the interval between the points is now ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^\((5 + 3)\) = 1/256\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.10"}],

Cell[CellGroupData[{

Cell["s1[[2, 1]]-s1[[1, 1]]", "Input",
  CellLabel->"In[46]:= ",
  CellTags->"S1.5.8"],

Cell[BoxData[
    \(1\/256\)], "Output",
  CellLabel->"Out[46]= ",
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "Note that in order to guarantee that we generate correctly the scaling \
function in the given region, we need to include enough neighboring points so \
that the boundary condition will not affect the function values inside the \
region. This is why the output ",
  StyleBox["s1", "MR"],
  " contains some points outside the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([1 - 1/32, 1 + 1/32]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.5.8"],
  ". The output of ",
  StyleBox["Zoom", "MR"],
  " can be used again as the input to ",
  StyleBox["Zoom", "MR"],
  " to produce even finer details. "
}], "Text",
  CellTags->{"S1.5.8", "8.11"}],

Cell[TextData[{
  "This time the interval between points is ",
  Cell[BoxData[
      \(TraditionalForm\`2\^\(-\((8 + 5)\)\) = 1/8192\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.12"}],

Cell["Zoom[s1, c2, 5, {1-1/256, 1+1/256}];", "Input",
  CellLabel->"In[47]:= ",
  CellTags->"S1.5.8"],

Cell[TextData[{
  "This shows even finer details around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.13"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, Frame->True, PlotJoined -> True,
PlotLabel -> \"phi(t)\"]\
\>", "Input",
  CellLabel->"In[48]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-114.234 114.734 4.11506 12.1177 [
[.04106 -0.0125 -15 -9 ]
[.04106 -0.0125 15 0 ]
[.27053 -0.0125 -15 -9 ]
[.27053 -0.0125 15 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.72947 -0.0125 -15 -9 ]
[.72947 -0.0125 15 0 ]
[.95894 -0.0125 -15 -9 ]
[.95894 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11621 -30 -4.5 ]
[-0.0125 .11621 0 4.5 ]
[-0.0125 .23739 -30 -4.5 ]
[-0.0125 .23739 0 4.5 ]
[-0.0125 .35856 -30 -4.5 ]
[-0.0125 .35856 0 4.5 ]
[-0.0125 .47974 -24 -4.5 ]
[-0.0125 .47974 0 4.5 ]
[-0.0125 .60092 -30 -4.5 ]
[-0.0125 .60092 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04106 0 m
.04106 .00625 L
s
[(0.996)] .04106 -0.0125 0 1 Mshowa
.27053 0 m
.27053 .00625 L
s
[(0.998)] .27053 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.72947 0 m
.72947 .00625 L
s
[(1.002)] .72947 -0.0125 0 1 Mshowa
.95894 0 m
.95894 .00625 L
s
[(1.004)] .95894 -0.0125 0 1 Mshowa
.125 Mabswid
.09843 0 m
.09843 .00375 L
s
.1558 0 m
.1558 .00375 L
s
.21317 0 m
.21317 .00375 L
s
.3279 0 m
.3279 .00375 L
s
.38527 0 m
.38527 .00375 L
s
.44263 0 m
.44263 .00375 L
s
.55737 0 m
.55737 .00375 L
s
.61473 0 m
.61473 .00375 L
s
.6721 0 m
.6721 .00375 L
s
.78683 0 m
.78683 .00375 L
s
.8442 0 m
.8442 .00375 L
s
.90157 0 m
.90157 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11621 m
.00625 .11621 L
s
[(-0.33)] -0.0125 .11621 1 0 Mshowa
0 .23739 m
.00625 .23739 L
s
[(-0.32)] -0.0125 .23739 1 0 Mshowa
0 .35856 m
.00625 .35856 L
s
[(-0.31)] -0.0125 .35856 1 0 Mshowa
0 .47974 m
.00625 .47974 L
s
[(-0.3)] -0.0125 .47974 1 0 Mshowa
0 .60092 m
.00625 .60092 L
s
[(-0.29)] -0.0125 .60092 1 0 Mshowa
.125 Mabswid
0 .01927 m
.00375 .01927 L
s
0 .0435 m
.00375 .0435 L
s
0 .06774 m
.00375 .06774 L
s
0 .09197 m
.00375 .09197 L
s
0 .14044 m
.00375 .14044 L
s
0 .16468 m
.00375 .16468 L
s
0 .18891 m
.00375 .18891 L
s
0 .21315 m
.00375 .21315 L
s
0 .26162 m
.00375 .26162 L
s
0 .28586 m
.00375 .28586 L
s
0 .31009 m
.00375 .31009 L
s
0 .33433 m
.00375 .33433 L
s
0 .3828 m
.00375 .3828 L
s
0 .40703 m
.00375 .40703 L
s
0 .43127 m
.00375 .43127 L
s
0 .4555 m
.00375 .4555 L
s
0 .50398 m
.00375 .50398 L
s
0 .52821 m
.00375 .52821 L
s
0 .55245 m
.00375 .55245 L
s
0 .57668 m
.00375 .57668 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.04106 .61178 m
.04106 .61803 L
s
.27053 .61178 m
.27053 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.72947 .61178 m
.72947 .61803 L
s
.95894 .61178 m
.95894 .61803 L
s
.125 Mabswid
.09843 .61428 m
.09843 .61803 L
s
.1558 .61428 m
.1558 .61803 L
s
.21317 .61428 m
.21317 .61803 L
s
.3279 .61428 m
.3279 .61803 L
s
.38527 .61428 m
.38527 .61803 L
s
.44263 .61428 m
.44263 .61803 L
s
.55737 .61428 m
.55737 .61803 L
s
.61473 .61428 m
.61473 .61803 L
s
.6721 .61428 m
.6721 .61803 L
s
.78683 .61428 m
.78683 .61803 L
s
.8442 .61428 m
.8442 .61803 L
s
.90157 .61428 m
.90157 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11621 m
1 .11621 L
s
.99375 .23739 m
1 .23739 L
s
.99375 .35856 m
1 .35856 L
s
.99375 .47974 m
1 .47974 L
s
.99375 .60092 m
1 .60092 L
s
.125 Mabswid
.99625 .01927 m
1 .01927 L
s
.99625 .0435 m
1 .0435 L
s
.99625 .06774 m
1 .06774 L
s
.99625 .09197 m
1 .09197 L
s
.99625 .14044 m
1 .14044 L
s
.99625 .16468 m
1 .16468 L
s
.99625 .18891 m
1 .18891 L
s
.99625 .21315 m
1 .21315 L
s
.99625 .26162 m
1 .26162 L
s
.99625 .28586 m
1 .28586 L
s
.99625 .31009 m
1 .31009 L
s
.99625 .33433 m
1 .33433 L
s
.99625 .3828 m
1 .3828 L
s
.99625 .40703 m
1 .40703 L
s
.99625 .43127 m
1 .43127 L
s
.99625 .4555 m
1 .4555 L
s
.99625 .50398 m
1 .50398 L
s
.99625 .52821 m
1 .52821 L
s
.99625 .55245 m
1 .55245 L
s
.99625 .57668 m
1 .57668 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(phi\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03782 .59809 L
.05182 .59463 L
.06583 .5783 L
.07983 .56292 L
.09384 .54895 L
.10784 .53474 L
.12185 .52154 L
.13585 .50833 L
.14986 .49452 L
.16387 .48024 L
.17787 .46942 L
.19188 .45838 L
.20588 .44669 L
.21989 .43482 L
.23389 .4245 L
.2479 .41377 L
.2619 .40478 L
.27591 .39756 L
.28992 .37747 L
.30392 .35838 L
.31793 .34034 L
.33193 .32172 L
.34594 .30656 L
.35994 .29085 L
.37395 .27668 L
.38796 .2643 L
.40196 .23904 L
.41597 .21442 L
.42997 .19329 L
.44398 .17382 L
.45798 .14147 L
.47199 .11221 L
.48599 .07012 L
.5 .01472 L
.51401 .05573 L
.52801 .08959 L
.54202 .11321 L
.55602 .13899 L
.57003 .1548 L
.58403 .17117 L
.59804 .19 L
.61204 .21014 L
.62605 .2203 L
.64006 .23123 L
.65406 .24303 L
.66807 .25441 L
.68207 .26822 L
.69608 .28163 L
.71008 .29626 L
Mistroke
.72409 .31228 L
.7381 .31832 L
.7521 .3251 L
.76611 .33296 L
.78011 .34062 L
.79412 .34913 L
.80812 .35762 L
.82213 .36567 L
.83613 .3734 L
.85014 .38356 L
.86415 .39357 L
.87815 .4031 L
.89216 .41248 L
.90616 .42309 L
.92017 .43339 L
.93417 .44503 L
.94818 .45805 L
.96218 .46109 L
.97619 .46487 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "As a second example, we look at the Daubechies wavelet of order 3. We \
concentrate around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.5.8"],
  " where there is an apparent discontinuity in the first derivative. "
}], "Text",
  CellTags->{"S1.5.8", "8.14"}],

Cell["This generates the wavelet.", "MathCaption",
  CellTags->{"S1.5.8", "8.15"}],

Cell["\<\
(d3 = DaubechiesFilter[3];
w = Wavelet[d3, 6, InverseTransform -> True];)\
\>", "Input",
  CellLabel->"In[49]:= ",
  CellTags->"S1.5.8"],

Cell["Here is its graph.", "MathCaption",
  CellTags->{"S1.5.8", "8.16"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[w, PlotJoined -> True,
PlotRange -> All, AxesLabel -> {\"t\", \"psi(t)\"}]\
\>", "Input",
  CellLabel->"In[50]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.245748 0.212489 [
[.02381 .23325 -6 -9 ]
[.02381 .23325 6 0 ]
[.21429 .23325 -6 -9 ]
[.21429 .23325 6 0 ]
[.59524 .23325 -3 -9 ]
[.59524 .23325 3 0 ]
[.78571 .23325 -3 -9 ]
[.78571 .23325 3 0 ]
[.97619 .23325 -3 -9 ]
[.97619 .23325 3 0 ]
[1.025 .24575 0 -4.5 ]
[1.025 .24575 6 4.5 ]
[.39226 .03326 -12 -4.5 ]
[.39226 .03326 0 4.5 ]
[.39226 .1395 -24 -4.5 ]
[.39226 .1395 0 4.5 ]
[.39226 .35199 -18 -4.5 ]
[.39226 .35199 0 4.5 ]
[.39226 .45824 -6 -4.5 ]
[.39226 .45824 0 4.5 ]
[.39226 .56448 -18 -4.5 ]
[.39226 .56448 0 4.5 ]
[.40476 .64303 -18 0 ]
[.40476 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24575 m
.02381 .252 L
s
[(-2)] .02381 .23325 0 1 Mshowa
.21429 .24575 m
.21429 .252 L
s
[(-1)] .21429 .23325 0 1 Mshowa
.59524 .24575 m
.59524 .252 L
s
[(1)] .59524 .23325 0 1 Mshowa
.78571 .24575 m
.78571 .252 L
s
[(2)] .78571 .23325 0 1 Mshowa
.97619 .24575 m
.97619 .252 L
s
[(3)] .97619 .23325 0 1 Mshowa
.125 Mabswid
.0619 .24575 m
.0619 .2495 L
s
.1 .24575 m
.1 .2495 L
s
.1381 .24575 m
.1381 .2495 L
s
.17619 .24575 m
.17619 .2495 L
s
.25238 .24575 m
.25238 .2495 L
s
.29048 .24575 m
.29048 .2495 L
s
.32857 .24575 m
.32857 .2495 L
s
.36667 .24575 m
.36667 .2495 L
s
.44286 .24575 m
.44286 .2495 L
s
.48095 .24575 m
.48095 .2495 L
s
.51905 .24575 m
.51905 .2495 L
s
.55714 .24575 m
.55714 .2495 L
s
.63333 .24575 m
.63333 .2495 L
s
.67143 .24575 m
.67143 .2495 L
s
.70952 .24575 m
.70952 .2495 L
s
.74762 .24575 m
.74762 .2495 L
s
.82381 .24575 m
.82381 .2495 L
s
.8619 .24575 m
.8619 .2495 L
s
.9 .24575 m
.9 .2495 L
s
.9381 .24575 m
.9381 .2495 L
s
.25 Mabswid
0 .24575 m
1 .24575 L
s
[(t)] 1.025 .24575 -1 0 Mshowa
.40476 .03326 m
.41101 .03326 L
s
[(-1)] .39226 .03326 1 0 Mshowa
.40476 .1395 m
.41101 .1395 L
s
[(-0.5)] .39226 .1395 1 0 Mshowa
.40476 .35199 m
.41101 .35199 L
s
[(0.5)] .39226 .35199 1 0 Mshowa
.40476 .45824 m
.41101 .45824 L
s
[(1)] .39226 .45824 1 0 Mshowa
.40476 .56448 m
.41101 .56448 L
s
[(1.5)] .39226 .56448 1 0 Mshowa
.125 Mabswid
.40476 .05451 m
.40851 .05451 L
s
.40476 .07576 m
.40851 .07576 L
s
.40476 .09701 m
.40851 .09701 L
s
.40476 .11825 m
.40851 .11825 L
s
.40476 .16075 m
.40851 .16075 L
s
.40476 .182 m
.40851 .182 L
s
.40476 .20325 m
.40851 .20325 L
s
.40476 .2245 m
.40851 .2245 L
s
.40476 .267 m
.40851 .267 L
s
.40476 .28825 m
.40851 .28825 L
s
.40476 .30949 m
.40851 .30949 L
s
.40476 .33074 m
.40851 .33074 L
s
.40476 .37324 m
.40851 .37324 L
s
.40476 .39449 m
.40851 .39449 L
s
.40476 .41574 m
.40851 .41574 L
s
.40476 .43699 m
.40851 .43699 L
s
.40476 .47949 m
.40851 .47949 L
s
.40476 .50074 m
.40851 .50074 L
s
.40476 .52198 m
.40851 .52198 L
s
.40476 .54323 m
.40851 .54323 L
s
.40476 .01201 m
.40851 .01201 L
s
.40476 .58573 m
.40851 .58573 L
s
.40476 .60698 m
.40851 .60698 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(psi\\(t\\))] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .24599 m
.02679 .24634 L
.02976 .24668 L
.03274 .24708 L
.03571 .24743 L
.03869 .24779 L
.04167 .24822 L
.04464 .24868 L
.04762 .24904 L
.0506 .24939 L
.05357 .24977 L
.05655 .25015 L
.05952 .2506 L
.0625 .25109 L
.06548 .25156 L
.06845 .25206 L
.07143 .25245 L
.0744 .25281 L
.07738 .25319 L
.08036 .25355 L
.08333 .25396 L
.08631 .25438 L
.08929 .25478 L
.09226 .25518 L
.09524 .25566 L
.09821 .25616 L
.10119 .25667 L
.10417 .25719 L
.10714 .2577 L
.11012 .2582 L
.1131 .25873 L
.11607 .25927 L
.11905 .25969 L
.12202 .26007 L
.125 .26046 L
.12798 .26082 L
.13095 .26123 L
.13393 .26164 L
.1369 .26203 L
.13988 .26241 L
.14286 .26284 L
.14583 .26329 L
.14881 .26373 L
.15179 .26418 L
.15476 .2646 L
.15774 .26502 L
.16071 .26545 L
.16369 .26588 L
.16667 .26638 L
.16964 .26691 L
Mistroke
.17262 .26744 L
.1756 .26799 L
.17857 .26852 L
.18155 .26905 L
.18452 .26961 L
.1875 .27018 L
.19048 .27071 L
.19345 .27124 L
.19643 .27178 L
.1994 .27232 L
.20238 .27288 L
.20536 .27345 L
.20833 .27401 L
.21131 .27459 L
.21429 .27318 L
.21726 .27092 L
.22024 .26876 L
.22321 .26604 L
.22619 .2638 L
.22917 .26151 L
.23214 .25862 L
.23512 .25549 L
.2381 .25313 L
.24107 .25091 L
.24405 .24842 L
.24702 .24597 L
.25 .24293 L
.25298 .23964 L
.25595 .2364 L
.25893 .233 L
.2619 .23046 L
.26488 .22822 L
.26786 .22577 L
.27083 .22347 L
.27381 .22083 L
.27679 .2181 L
.27976 .21552 L
.28274 .21293 L
.28571 .20975 L
.28869 .20633 L
.29167 .20293 L
.29464 .19935 L
.29762 .19595 L
.3006 .19256 L
.30357 .18897 L
.30655 .18533 L
.30952 .18264 L
.3125 .18031 L
.31548 .17787 L
.31845 .17566 L
Mistroke
.32143 .1731 L
.3244 .1705 L
.32738 .16814 L
.33036 .16582 L
.33333 .16309 L
.33631 .16023 L
.33929 .15744 L
.34226 .15457 L
.34524 .15192 L
.34821 .14933 L
.35119 .14665 L
.35417 .14398 L
.35714 .14073 L
.36012 .13723 L
.3631 .13376 L
.36607 .13013 L
.36905 .12663 L
.37202 .12311 L
.375 .11942 L
.37798 .11566 L
.38095 .11217 L
.38393 .10874 L
.3869 .10522 L
.38988 .10173 L
.39286 .09805 L
.39583 .0943 L
.39881 .09058 L
.40179 .08682 L
.40476 .09484 L
.40774 .10787 L
.41071 .12034 L
.41369 .13616 L
.41667 .1491 L
.41964 .16232 L
.42262 .17914 L
.4256 .19731 L
.42857 .21097 L
.43155 .22372 L
.43452 .2381 L
.4375 .25227 L
.44048 .26989 L
.44345 .28906 L
.44643 .30787 L
.4494 .32762 L
.45238 .34228 L
.45536 .35517 L
.45833 .36925 L
.46131 .38246 L
.46429 .39769 L
.46726 .4135 L
Mistroke
.47024 .42834 L
.47321 .44325 L
.47619 .46167 L
.47917 .48151 L
.48214 .50128 L
.48512 .52204 L
.4881 .54173 L
.49107 .56142 L
.49405 .58219 L
.49702 .60332 L
.5 .59794 L
.50298 .58157 L
.50595 .5667 L
.50893 .54452 L
.5119 .52942 L
.51488 .51407 L
.51786 .49085 L
.52083 .46491 L
.52381 .44928 L
.52679 .43593 L
.52976 .41925 L
.53274 .40332 L
.53571 .37997 L
.53869 .35345 L
.54167 .32799 L
.54464 .30073 L
.54762 .28597 L
.5506 .27579 L
.55357 .26321 L
.55655 .25308 L
.55952 .23852 L
.5625 .22298 L
.56548 .21014 L
.56845 .19752 L
.57143 .17703 L
.5744 .15359 L
.57738 .13073 L
.58036 .1059 L
.58333 .084 L
.58631 .06249 L
.58929 .03882 L
.59226 .01472 L
.59524 .01507 L
.59821 .02541 L
.60119 .03423 L
.60417 .04967 L
.60714 .05812 L
.61012 .06655 L
.6131 .08211 L
.61607 .09997 L
Mistroke
.61905 .1084 L
.62202 .11467 L
.625 .12375 L
.62798 .13203 L
.63095 .14689 L
.63393 .16447 L
.6369 .18095 L
.63988 .19894 L
.64286 .20442 L
.64583 .20518 L
.64881 .20802 L
.65179 .2082 L
.65476 .2125 L
.65774 .21753 L
.66071 .21965 L
.66369 .22131 L
.66667 .23035 L
.66964 .242 L
.67262 .25283 L
.6756 .26532 L
.67857 .27471 L
.68155 .28347 L
.68452 .29408 L
.6875 .30484 L
.69048 .30519 L
.69345 .30138 L
.69643 .2982 L
.6994 .29223 L
.70238 .2895 L
.70536 .28691 L
.70833 .2813 L
.71131 .27481 L
.71429 .27209 L
.71726 .27024 L
.72024 .2673 L
.72321 .26471 L
.72619 .25946 L
.72917 .25313 L
.73214 .24727 L
.73512 .24081 L
.7381 .24036 L
.74107 .24224 L
.74405 .24325 L
.74702 .24563 L
.75 .24612 L
.75298 .24637 L
.75595 .24809 L
.75893 .25013 L
.7619 .24884 L
.76488 .24645 L
Mistroke
.76786 .24453 L
.77083 .24195 L
.77381 .24091 L
.77679 .24027 L
.77976 .23887 L
.78274 .2375 L
.78571 .23757 L
.78869 .23819 L
.79167 .23876 L
.79464 .23973 L
.79762 .24015 L
.8006 .24051 L
.80357 .2413 L
.80655 .24219 L
.80952 .24276 L
.8125 .24327 L
.81548 .24391 L
.81845 .24454 L
.82143 .24547 L
.8244 .24654 L
.82738 .24759 L
.83036 .24874 L
.83333 .2487 L
.83631 .2482 L
.83929 .24785 L
.84226 .24722 L
.84524 .24694 L
.84821 .24671 L
.85119 .24618 L
.85417 .24557 L
.85714 .24555 L
.86012 .24572 L
.8631 .24578 L
.86607 .24595 L
.86905 .24581 L
.87202 .24558 L
.875 .24548 L
.87798 .24535 L
.88095 .24536 L
.88393 .24544 L
.8869 .24548 L
.88988 .24556 L
.89286 .24562 L
.89583 .24568 L
.89881 .24578 L
.90179 .24589 L
.90476 .24588 L
.90774 .24583 L
.91071 .2458 L
.91369 .24575 L
Mistroke
.91667 .24574 L
.91964 .24576 L
.92262 .24574 L
.9256 .24573 L
.92857 .24573 L
.93155 .24574 L
.93452 .24574 L
.9375 .24575 L
.94048 .24575 L
.94345 .24575 L
.94643 .24575 L
.9494 .24575 L
.95238 .24575 L
.95536 .24575 L
.95833 .24575 L
.96131 .24575 L
.96429 .24575 L
.96726 .24575 L
.97024 .24575 L
.97321 .24575 L
.97619 .24575 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "We blow up the region near ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.17"}],

Cell["Zoom[w, d3, 5, {-1/64, 1/64}];", "Input",
  CellLabel->"In[51]:= ",
  CellTags->"S1.5.8"],

Cell["The result is blown up further.", "MathCaption",
  CellTags->{"S1.5.8", "8.18"}],

Cell["\<\
Zoom[Zoom[%, d3, 5, {-1/2^11, 1/2^11}],
d3, 5, {-1/2^16, 1/2^16}];\
\>", "Input",
  CellLabel->"In[52]:= ",
  CellTags->"S1.5.8"],

Cell[TextData[{
  "This is a zoom\[Hyphen]in view of the wavelet around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.5.8"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.19"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, Axes -> False, PlotJoined -> True,
FrameTicks -> {{-0.00001, 0, 0.00001}, Automatic},
Frame -> True]\
\>", "Input",
  CellLabel->"In[53]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.528011 29371.9 21085 28068.5 [
[.23429 -0.0125 -24 -9 ]
[.23429 -0.0125 24 0 ]
[.52801 -0.0125 -3 -9 ]
[.52801 -0.0125 3 0 ]
[.82173 -0.0125 -21 -9 ]
[.82173 -0.0125 21 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02374 -54 -4.5 ]
[-0.0125 .02374 0 4.5 ]
[-0.0125 .16408 -48 -4.5 ]
[-0.0125 .16408 0 4.5 ]
[-0.0125 .30443 -54 -4.5 ]
[-0.0125 .30443 0 4.5 ]
[-0.0125 .44477 -48 -4.5 ]
[-0.0125 .44477 0 4.5 ]
[-0.0125 .58511 -54 -4.5 ]
[-0.0125 .58511 0 4.5 ]
[ 0 0 -0.125 0 ]
[.23429 .63053 -24 0 ]
[.23429 .63053 24 9 ]
[.52801 .63053 -3 0 ]
[.52801 .63053 3 9 ]
[.82173 .63053 -21 0 ]
[.82173 .63053 21 9 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23429 0 m
.23429 .00625 L
s
[(-0.00001)] .23429 -0.0125 0 1 Mshowa
.52801 0 m
.52801 .00625 L
s
[(0)] .52801 -0.0125 0 1 Mshowa
.82173 0 m
.82173 .00625 L
s
[(0.00001)] .82173 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
0 .02374 m
.00625 .02374 L
s
[(-0.751195)] -0.0125 .02374 1 0 Mshowa
0 .16408 m
.00625 .16408 L
s
[(-0.75119)] -0.0125 .16408 1 0 Mshowa
0 .30443 m
.00625 .30443 L
s
[(-0.751185)] -0.0125 .30443 1 0 Mshowa
0 .44477 m
.00625 .44477 L
s
[(-0.75118)] -0.0125 .44477 1 0 Mshowa
0 .58511 m
.00625 .58511 L
s
[(-0.751175)] -0.0125 .58511 1 0 Mshowa
.125 Mabswid
0 .05181 m
.00375 .05181 L
s
0 .07988 m
.00375 .07988 L
s
0 .10795 m
.00375 .10795 L
s
0 .13602 m
.00375 .13602 L
s
0 .19215 m
.00375 .19215 L
s
0 .22022 m
.00375 .22022 L
s
0 .24829 m
.00375 .24829 L
s
0 .27636 m
.00375 .27636 L
s
0 .3325 m
.00375 .3325 L
s
0 .36056 m
.00375 .36056 L
s
0 .38863 m
.00375 .38863 L
s
0 .4167 m
.00375 .4167 L
s
0 .47284 m
.00375 .47284 L
s
0 .50091 m
.00375 .50091 L
s
0 .52898 m
.00375 .52898 L
s
0 .55704 m
.00375 .55704 L
s
0 .61318 m
.00375 .61318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.23429 .61178 m
.23429 .61803 L
s
[(-0.00001)] .23429 .63053 0 -1 Mshowa
.52801 .61178 m
.52801 .61803 L
s
[(0)] .52801 .63053 0 -1 Mshowa
.82173 .61178 m
.82173 .61803 L
s
[(0.00001)] .82173 .63053 0 -1 Mshowa
0 .61803 m
1 .61803 L
s
.99375 .02374 m
1 .02374 L
s
.99375 .16408 m
1 .16408 L
s
.99375 .30443 m
1 .30443 L
s
.99375 .44477 m
1 .44477 L
s
.99375 .58511 m
1 .58511 L
s
.125 Mabswid
.99625 .05181 m
1 .05181 L
s
.99625 .07988 m
1 .07988 L
s
.99625 .10795 m
1 .10795 L
s
.99625 .13602 m
1 .13602 L
s
.99625 .19215 m
1 .19215 L
s
.99625 .22022 m
1 .22022 L
s
.99625 .24829 m
1 .24829 L
s
.99625 .27636 m
1 .27636 L
s
.99625 .3325 m
1 .3325 L
s
.99625 .36056 m
1 .36056 L
s
.99625 .38863 m
1 .38863 L
s
.99625 .4167 m
1 .4167 L
s
.99625 .47284 m
1 .47284 L
s
.99625 .50091 m
1 .50091 L
s
.99625 .52898 m
1 .52898 L
s
.99625 .55704 m
1 .55704 L
s
.99625 .61318 m
1 .61318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54931 m
.03782 .53403 L
.05182 .51876 L
.06583 .50349 L
.07983 .48821 L
.09384 .47294 L
.10784 .45766 L
.12185 .44239 L
.13585 .42712 L
.14986 .41184 L
.16387 .39657 L
.17787 .38129 L
.19188 .36602 L
.20588 .35074 L
.21989 .33547 L
.23389 .3202 L
.2479 .30492 L
.2619 .28965 L
.27591 .27437 L
.28992 .2591 L
.30392 .24383 L
.31793 .22855 L
.33193 .21328 L
.34594 .198 L
.35994 .18273 L
.37395 .16746 L
.38796 .15218 L
.40196 .13691 L
.41597 .12163 L
.42997 .10636 L
.44398 .09109 L
.45798 .07581 L
.47199 .06054 L
.48599 .04526 L
.5 .02999 L
.51401 .01472 L
.52801 .01857 L
.54202 .03056 L
.55602 .04172 L
.57003 .05837 L
.58403 .07039 L
.59804 .08291 L
.61204 .10131 L
.62605 .12196 L
.64006 .1354 L
.65406 .14744 L
.66807 .16217 L
.68207 .17663 L
.69608 .19672 L
.71008 .21936 L
Mistroke
.72409 .2415 L
.7381 .26522 L
.7521 .28067 L
.76611 .2933 L
.78011 .30791 L
.79412 .32116 L
.80812 .33775 L
.82213 .35534 L
.83613 .37139 L
.85014 .38762 L
.86415 .4096 L
.87815 .43396 L
.89216 .45822 L
.90616 .48417 L
.92017 .50842 L
.93417 .53273 L
.94818 .55885 L
.96218 .58558 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "We iterate the zooming procedure using ",
  StyleBox["Fold", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.5.8", "8.20"}],

Cell["\<\
Fold[Zoom[#, d3, 5, #2]&, %%,
Table[{-1/2^i, 1/2^i}, {i, 21, 31, 5}]];\
\>", "Input",
  CellLabel->"In[54]:= ",
  CellTags->"S1.5.8"],

Cell["\<\
We see that the slope discontinuity is disappearing. In fact, the \
first derivative of this function does exist.\
\>", "MathCaption",
  CellTags->{"S1.5.8", "8.21"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, Axes -> False, Frame -> True,
PlotJoined -> True, FrameTicks -> None]\
\>", "Input",
  CellLabel->"In[55]:= ",
  CellTags->"S1.5.8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.528011 9.62458e+08 6.72413e+08 8.95125e+08 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03782 .58845 L
.05182 .57359 L
.06583 .55872 L
.07983 .54386 L
.09384 .52899 L
.10784 .51413 L
.12185 .49926 L
.13585 .4844 L
.14986 .46953 L
.16387 .45467 L
.17787 .4398 L
.19188 .42494 L
.20588 .41007 L
.21989 .39521 L
.23389 .38034 L
.2479 .36548 L
.2619 .35061 L
.27591 .33575 L
.28992 .32088 L
.30392 .30602 L
.31793 .29115 L
.33193 .27629 L
.34594 .26142 L
.35994 .24655 L
.37395 .23169 L
.38796 .21682 L
.40196 .20196 L
.41597 .18709 L
.42997 .17223 L
.44398 .15736 L
.45798 .1425 L
.47199 .12763 L
.48599 .11277 L
.5 .0979 L
.51401 .08304 L
.52801 .07564 L
.54202 .07142 L
.55602 .06688 L
.57003 .06448 L
.58403 .06027 L
.59804 .05626 L
.61204 .05455 L
.62605 .05371 L
.64006 .05006 L
.65406 .04586 L
.66807 .04271 L
.68207 .03945 L
.69608 .0384 L
.71008 .03834 L
Mistroke
.72409 .03808 L
.7381 .03844 L
.7521 .03558 L
.76611 .03161 L
.78011 .02841 L
.79412 .02468 L
.80812 .02226 L
.82213 .02023 L
.83613 .0176 L
.85014 .01503 L
.86415 .01472 L
.87815 .01532 L
.89216 .0159 L
.90616 .01713 L
.92017 .0177 L
.93417 .01829 L
.94818 .01959 L
.96218 .02113 L
.97619 .01915 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],

Cell[TextData[{
  "The reader is encouraged to use the function ",
  StyleBox["Zoom", "MR"],
  " to check that the Daubechies wavelet of order 2 is not differentiable. "
}], "Text",
  CellTags->{"S1.5.8", "8.22"}]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{520, 600},
WindowMargins->{{179, Automatic}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1717, 49, 115, 4, 82, "Section",
      CellTags->"Contents"],
    Cell[1835, 55, 1571, 50, 178, "Contents",
      CellTags->"Contents"]},
  "S1.5.0"->{
    Cell[3409, 107, 122, 4, 82, "Section",
      CellTags->{"S1.5.0", "0.1"}],
    Cell[3534, 113, 2032, 52, 189, "Text",
      CellTags->{"S1.5.0", "0.2"}]},
  "0.1"->{
    Cell[3409, 107, 122, 4, 82, "Section",
      CellTags->{"S1.5.0", "0.1"}]},
  "0.2"->{
    Cell[3534, 113, 2032, 52, 189, "Text",
      CellTags->{"S1.5.0", "0.2"}]},
  "S1.5.1"->{
    Cell[5569, 167, 77, 1, 39, "Subsection",
      CellTags->{"S1.5.1", "1.1"}],
    Cell[5649, 170, 4000, 112, 192, "Text",
      CellTags->{"S1.5.1", "1.2"}],
    Cell[9652, 284, 502, 12, 46, "DisplayFormula",
      CellTags->{"S1.5.1", "1.3"}],
    Cell[10157, 298, 1422, 44, 88, "Text",
      CellTags->{"S1.5.1", "1.4"}],
    Cell[11582, 344, 386, 8, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.5"}],
    Cell[11971, 354, 83, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.6"}],
    Cell[12057, 357, 646, 13, 77, "DisplayFormula",
      CellTags->{"S1.5.1", "1.7"}],
    Cell[12706, 372, 379, 11, 42, "Text",
      CellTags->{"S1.5.1", "1.8"}],
    Cell[13088, 385, 311, 7, 33, "DisplayFormula",
      CellTags->{"S1.5.1", "1.9"}],
    Cell[13402, 394, 67, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.10"}],
    Cell[13472, 397, 392, 8, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.11"}],
    Cell[13867, 407, 216, 7, 25, "Text",
      CellTags->{"S1.5.1", "1.12"}],
    Cell[14086, 416, 312, 7, 33, "DisplayFormula",
      CellTags->{"S1.5.1", "1.13"}],
    Cell[14401, 425, 78, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.14"}],
    Cell[14482, 428, 479, 9, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.15"}],
    Cell[14964, 439, 478, 15, 44, "Text",
      CellTags->{"S1.5.1", "1.16"}],
    Cell[15445, 456, 681, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.17"}],
    Cell[16129, 473, 52, 1, 70, "Text",
      CellTags->{"S1.5.1", "1.18"}],
    Cell[16184, 476, 681, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.19"}],
    Cell[16868, 493, 1046, 28, 70, "Text",
      CellTags->{"S1.5.1", "1.20"}],
    Cell[17917, 523, 645, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.21"}],
    Cell[18565, 540, 2175, 54, 70, "Text",
      CellTags->{"S1.5.1", "1.22"}],
    Cell[20743, 596, 140, 3, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.23"}],
    Cell[20886, 601, 1474, 39, 70, "Text",
      CellTags->{"S1.5.1", "1.24"}]},
  "1.1"->{
    Cell[5569, 167, 77, 1, 39, "Subsection",
      CellTags->{"S1.5.1", "1.1"}]},
  "1.2"->{
    Cell[5649, 170, 4000, 112, 192, "Text",
      CellTags->{"S1.5.1", "1.2"}]},
  "1.3"->{
    Cell[9652, 284, 502, 12, 46, "DisplayFormula",
      CellTags->{"S1.5.1", "1.3"}]},
  "1.4"->{
    Cell[10157, 298, 1422, 44, 88, "Text",
      CellTags->{"S1.5.1", "1.4"}]},
  "1.5"->{
    Cell[11582, 344, 386, 8, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.5"}]},
  "1.6"->{
    Cell[11971, 354, 83, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.6"}]},
  "1.7"->{
    Cell[12057, 357, 646, 13, 77, "DisplayFormula",
      CellTags->{"S1.5.1", "1.7"}]},
  "1.8"->{
    Cell[12706, 372, 379, 11, 42, "Text",
      CellTags->{"S1.5.1", "1.8"}]},
  "1.9"->{
    Cell[13088, 385, 311, 7, 33, "DisplayFormula",
      CellTags->{"S1.5.1", "1.9"}]},
  "1.10"->{
    Cell[13402, 394, 67, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.10"}]},
  "1.11"->{
    Cell[13472, 397, 392, 8, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.11"}]},
  "1.12"->{
    Cell[13867, 407, 216, 7, 25, "Text",
      CellTags->{"S1.5.1", "1.12"}]},
  "1.13"->{
    Cell[14086, 416, 312, 7, 33, "DisplayFormula",
      CellTags->{"S1.5.1", "1.13"}]},
  "1.14"->{
    Cell[14401, 425, 78, 1, 25, "Text",
      CellTags->{"S1.5.1", "1.14"}]},
  "1.15"->{
    Cell[14482, 428, 479, 9, 45, "DisplayFormula",
      CellTags->{"S1.5.1", "1.15"}]},
  "1.16"->{
    Cell[14964, 439, 478, 15, 44, "Text",
      CellTags->{"S1.5.1", "1.16"}]},
  "1.17"->{
    Cell[15445, 456, 681, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.17"}]},
  "1.18"->{
    Cell[16129, 473, 52, 1, 70, "Text",
      CellTags->{"S1.5.1", "1.18"}]},
  "1.19"->{
    Cell[16184, 476, 681, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.19"}]},
  "1.20"->{
    Cell[16868, 493, 1046, 28, 70, "Text",
      CellTags->{"S1.5.1", "1.20"}]},
  "1.21"->{
    Cell[17917, 523, 645, 15, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.21"}]},
  "1.22"->{
    Cell[18565, 540, 2175, 54, 70, "Text",
      CellTags->{"S1.5.1", "1.22"}]},
  "1.23"->{
    Cell[20743, 596, 140, 3, 70, "DisplayFormula",
      CellTags->{"S1.5.1", "1.23"}]},
  "1.24"->{
    Cell[20886, 601, 1474, 39, 70, "Text",
      CellTags->{"S1.5.1", "1.24"}]},
  "S1.5.2"->{
    Cell[22363, 642, 85, 1, 70, "Subsection",
      CellTags->{"S1.5.2", "2.1"}],
    Cell[22451, 645, 1283, 35, 70, "Text",
      CellTags->{"S1.5.2", "2.2"}],
    Cell[23737, 682, 633, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.3"}],
    Cell[24373, 696, 876, 29, 70, "Text",
      CellTags->{"S1.5.2", "2.4"}],
    Cell[25252, 727, 434, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.5"}],
    Cell[25689, 739, 270, 8, 70, "Text",
      CellTags->{"S1.5.2", "2.6"}],
    Cell[25962, 749, 1625, 39, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.7"}],
    Cell[27590, 790, 199, 5, 70, "Text",
      CellTags->{"S1.5.2", "2.8"}]},
  "2.1"->{
    Cell[22363, 642, 85, 1, 70, "Subsection",
      CellTags->{"S1.5.2", "2.1"}]},
  "2.2"->{
    Cell[22451, 645, 1283, 35, 70, "Text",
      CellTags->{"S1.5.2", "2.2"}]},
  "2.3"->{
    Cell[23737, 682, 633, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.3"}]},
  "2.4"->{
    Cell[24373, 696, 876, 29, 70, "Text",
      CellTags->{"S1.5.2", "2.4"}]},
  "2.5"->{
    Cell[25252, 727, 434, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.5"}]},
  "2.6"->{
    Cell[25689, 739, 270, 8, 70, "Text",
      CellTags->{"S1.5.2", "2.6"}]},
  "2.7"->{
    Cell[25962, 749, 1625, 39, 70, "DisplayFormula",
      CellTags->{"S1.5.2", "2.7"}]},
  "2.8"->{
    Cell[27590, 790, 199, 5, 70, "Text",
      CellTags->{"S1.5.2", "2.8"}]},
  "S1.5.3"->{
    Cell[27792, 797, 90, 1, 70, "Subsection",
      CellTags->{"S1.5.3", "3.1"}],
    Cell[27885, 800, 1393, 27, 70, "Text",
      CellTags->{"S1.5.3", "3.2"}],
    Cell[29281, 829, 342, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.3"}],
    Cell[29626, 839, 2660, 71, 70, "Text",
      CellTags->{"S1.5.3", "3.4"}],
    Cell[32289, 912, 151, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.5"}],
    Cell[32443, 918, 1908, 49, 70, "Text",
      CellTags->{"S1.5.3", "3.6"}],
    Cell[34354, 969, 394, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.7"}],
    Cell[34751, 980, 2676, 76, 70, "Text",
      CellTags->{"S1.5.3", "3.8"}],
    Cell[37430, 1058, 285, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.9"}],
    Cell[37718, 1067, 2102, 66, 70, "Text",
      CellTags->{"S1.5.3", "3.10"}],
    Cell[39823, 1135, 297, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.11"}],
    Cell[40123, 1144, 52, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.12"}],
    Cell[40178, 1147, 287, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.13"}],
    Cell[40468, 1156, 681, 13, 70, "Text",
      CellTags->{"S1.5.3", "3.14"}],
    Cell[41152, 1171, 484, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.15"}],
    Cell[41639, 1183, 52, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.16"}],
    Cell[41694, 1186, 489, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.17"}],
    Cell[42186, 1198, 2581, 71, 70, "Text",
      CellTags->{"S1.5.3", "3.18"}],
    Cell[44770, 1271, 311, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.19"}],
    Cell[45084, 1281, 359, 11, 70, "Text",
      CellTags->{"S1.5.3", "3.20"}],
    Cell[45446, 1294, 1516, 37, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.21"}],
    Cell[46965, 1333, 123, 4, 70, "Text",
      CellTags->{"S1.5.3", "3.22"}],
    Cell[47091, 1339, 353, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.23"}],
    Cell[47447, 1349, 84, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.24"}],
    Cell[47534, 1352, 430, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.25"}],
    Cell[47967, 1364, 1526, 45, 70, "Text",
      CellTags->{"S1.5.3", "3.26"}],
    Cell[49496, 1411, 415, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.27"}],
    Cell[49914, 1423, 227, 7, 25, "Text",
      CellTags->{"S1.5.3", "3.28"}],
    Cell[50144, 1432, 449, 10, 45, "DisplayFormula",
      CellTags->{"S1.5.3", "3.29"}],
    Cell[50596, 1444, 385, 9, 59, "Text",
      CellTags->{"S1.5.3", "3.30"}],
    Cell[50984, 1455, 414, 8, 32, "DisplayFormula",
      CellTags->{"S1.5.3", "3.31"}],
    Cell[51401, 1465, 2063, 63, 112, "Text",
      CellTags->{"S1.5.3", "3.32"}],
    Cell[53467, 1530, 262, 5, 33, "DisplayFormula",
      CellTags->{"S1.5.3", "3.33"}],
    Cell[53732, 1537, 448, 10, 59, "Text",
      CellTags->{"S1.5.3", "3.34"}]},
  "3.1"->{
    Cell[27792, 797, 90, 1, 70, "Subsection",
      CellTags->{"S1.5.3", "3.1"}]},
  "3.2"->{
    Cell[27885, 800, 1393, 27, 70, "Text",
      CellTags->{"S1.5.3", "3.2"}]},
  "3.3"->{
    Cell[29281, 829, 342, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.3"}]},
  "3.4"->{
    Cell[29626, 839, 2660, 71, 70, "Text",
      CellTags->{"S1.5.3", "3.4"}]},
  "3.5"->{
    Cell[32289, 912, 151, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.5"}]},
  "3.6"->{
    Cell[32443, 918, 1908, 49, 70, "Text",
      CellTags->{"S1.5.3", "3.6"}]},
  "3.7"->{
    Cell[34354, 969, 394, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.7"}]},
  "3.8"->{
    Cell[34751, 980, 2676, 76, 70, "Text",
      CellTags->{"S1.5.3", "3.8"}]},
  "3.9"->{
    Cell[37430, 1058, 285, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.9"}]},
  "3.10"->{
    Cell[37718, 1067, 2102, 66, 70, "Text",
      CellTags->{"S1.5.3", "3.10"}]},
  "3.11"->{
    Cell[39823, 1135, 297, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.11"}]},
  "3.12"->{
    Cell[40123, 1144, 52, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.12"}]},
  "3.13"->{
    Cell[40178, 1147, 287, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.13"}]},
  "3.14"->{
    Cell[40468, 1156, 681, 13, 70, "Text",
      CellTags->{"S1.5.3", "3.14"}]},
  "3.15"->{
    Cell[41152, 1171, 484, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.15"}]},
  "3.16"->{
    Cell[41639, 1183, 52, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.16"}]},
  "3.17"->{
    Cell[41694, 1186, 489, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.17"}]},
  "3.18"->{
    Cell[42186, 1198, 2581, 71, 70, "Text",
      CellTags->{"S1.5.3", "3.18"}]},
  "3.19"->{
    Cell[44770, 1271, 311, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.19"}]},
  "3.20"->{
    Cell[45084, 1281, 359, 11, 70, "Text",
      CellTags->{"S1.5.3", "3.20"}]},
  "3.21"->{
    Cell[45446, 1294, 1516, 37, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.21"}]},
  "3.22"->{
    Cell[46965, 1333, 123, 4, 70, "Text",
      CellTags->{"S1.5.3", "3.22"}]},
  "3.23"->{
    Cell[47091, 1339, 353, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.23"}]},
  "3.24"->{
    Cell[47447, 1349, 84, 1, 70, "Text",
      CellTags->{"S1.5.3", "3.24"}]},
  "3.25"->{
    Cell[47534, 1352, 430, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.25"}]},
  "3.26"->{
    Cell[47967, 1364, 1526, 45, 70, "Text",
      CellTags->{"S1.5.3", "3.26"}]},
  "3.27"->{
    Cell[49496, 1411, 415, 10, 70, "DisplayFormula",
      CellTags->{"S1.5.3", "3.27"}]},
  "3.28"->{
    Cell[49914, 1423, 227, 7, 25, "Text",
      CellTags->{"S1.5.3", "3.28"}]},
  "3.29"->{
    Cell[50144, 1432, 449, 10, 45, "DisplayFormula",
      CellTags->{"S1.5.3", "3.29"}]},
  "3.30"->{
    Cell[50596, 1444, 385, 9, 59, "Text",
      CellTags->{"S1.5.3", "3.30"}]},
  "3.31"->{
    Cell[50984, 1455, 414, 8, 32, "DisplayFormula",
      CellTags->{"S1.5.3", "3.31"}]},
  "3.32"->{
    Cell[51401, 1465, 2063, 63, 112, "Text",
      CellTags->{"S1.5.3", "3.32"}]},
  "3.33"->{
    Cell[53467, 1530, 262, 5, 33, "DisplayFormula",
      CellTags->{"S1.5.3", "3.33"}]},
  "3.34"->{
    Cell[53732, 1537, 448, 10, 59, "Text",
      CellTags->{"S1.5.3", "3.34"}]},
  "S1.5.4"->{
    Cell[54183, 1549, 108, 1, 39, "Subsection",
      CellTags->{"S1.5.4", "4.1"}],
    Cell[54294, 1552, 311, 6, 59, "Text",
      CellTags->{"S1.5.4", "4.2"}],
    Cell[54608, 1560, 144, 3, 31, "DisplayFormula",
      CellTags->{"S1.5.4", "4.3"}],
    Cell[54755, 1565, 89, 1, 25, "Text",
      CellTags->{"S1.5.4", "4.4"}],
    Cell[54847, 1568, 289, 6, 46, "DisplayFormula",
      CellTags->{"S1.5.4", "4.5"}],
    Cell[55139, 1576, 1084, 27, 96, "Text",
      CellTags->{"S1.5.4", "4.6"}],
    Cell[56226, 1605, 938, 26, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.7"}],
    Cell[57167, 1633, 158, 5, 70, "Text",
      CellTags->{"S1.5.4", "4.8"}],
    Cell[57328, 1640, 1455, 38, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.9"}],
    Cell[58786, 1680, 847, 25, 70, "Text",
      CellTags->{"S1.5.4", "4.10"}],
    Cell[59636, 1707, 78, 1, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.11"}],
    Cell[59717, 1710, 93, 2, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[59813, 1714, 147, 4, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.12"}],
    Cell[59963, 1720, 199, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[60165, 1728, 116, 2, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.13"}],
    Cell[60306, 1734, 199, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[60508, 1742, 67997, 1721, 70, 67924, 1718, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.4"],
    Cell[128520, 3466, 204, 7, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.14"}],
    Cell[128749, 3477, 199, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[128951, 3485, 67896, 1721, 70, 67823, 1718, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.4"],
    Cell[196862, 5209, 347, 12, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.15"}],
    Cell[197234, 5225, 199, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[197436, 5233, 67906, 1721, 70, 67833, 1718, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.4"],
    Cell[265357, 6957, 215, 8, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.16"}],
    Cell[265597, 6969, 199, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[265799, 6977, 67871, 1721, 70, 67798, 1718, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.4"],
    Cell[333685, 8701, 125, 4, 70, "Text",
      CellTags->{"S1.5.4", "4.17"}],
    Cell[333813, 8707, 226, 7, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.18"}],
    Cell[334042, 8716, 149, 5, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[334194, 8723, 276, 8, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.19"}],
    Cell[334495, 8735, 194, 6, 70, "Input",
      CellTags->"S1.5.4"],
    Cell[334692, 8743, 379704, 9538, 70, 379631, 9535, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.4"],
    Cell[714411, 18284, 313, 6, 70, "Text",
      CellTags->{"S1.5.4", "4.20"}],
    Cell[714727, 18292, 406, 11, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.21"}],
    Cell[715136, 18305, 300, 11, 70, "Text",
      CellTags->{"S1.5.4", "4.22"}],
    Cell[715439, 18318, 443, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.23"}],
    Cell[715885, 18332, 96, 1, 70, "Text",
      CellTags->{"S1.5.4", "4.24"}],
    Cell[715984, 18335, 505, 11, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.25"}],
    Cell[716492, 18348, 82, 1, 70, "Text",
      CellTags->{"S1.5.4", "4.26"}],
    Cell[716577, 18351, 817, 17, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.27"}],
    Cell[717397, 18370, 1180, 34, 70, "Text",
      CellTags->{"S1.5.4", "4.28"}]},
  "4.1"->{
    Cell[54183, 1549, 108, 1, 39, "Subsection",
      CellTags->{"S1.5.4", "4.1"}]},
  "4.2"->{
    Cell[54294, 1552, 311, 6, 59, "Text",
      CellTags->{"S1.5.4", "4.2"}]},
  "4.3"->{
    Cell[54608, 1560, 144, 3, 31, "DisplayFormula",
      CellTags->{"S1.5.4", "4.3"}]},
  "4.4"->{
    Cell[54755, 1565, 89, 1, 25, "Text",
      CellTags->{"S1.5.4", "4.4"}]},
  "4.5"->{
    Cell[54847, 1568, 289, 6, 46, "DisplayFormula",
      CellTags->{"S1.5.4", "4.5"}]},
  "4.6"->{
    Cell[55139, 1576, 1084, 27, 96, "Text",
      CellTags->{"S1.5.4", "4.6"}]},
  "4.7"->{
    Cell[56226, 1605, 938, 26, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.7"}]},
  "4.8"->{
    Cell[57167, 1633, 158, 5, 70, "Text",
      CellTags->{"S1.5.4", "4.8"}]},
  "4.9"->{
    Cell[57328, 1640, 1455, 38, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.9"}]},
  "4.10"->{
    Cell[58786, 1680, 847, 25, 70, "Text",
      CellTags->{"S1.5.4", "4.10"}]},
  "4.11"->{
    Cell[59636, 1707, 78, 1, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.11"}]},
  "4.12"->{
    Cell[59813, 1714, 147, 4, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.12"}]},
  "4.13"->{
    Cell[60165, 1728, 116, 2, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.13"}]},
  "4.14"->{
    Cell[128520, 3466, 204, 7, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.14"}]},
  "4.15"->{
    Cell[196862, 5209, 347, 12, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.15"}]},
  "4.16"->{
    Cell[265357, 6957, 215, 8, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.16"}]},
  "4.17"->{
    Cell[333685, 8701, 125, 4, 70, "Text",
      CellTags->{"S1.5.4", "4.17"}]},
  "4.18"->{
    Cell[333813, 8707, 226, 7, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.18"}]},
  "4.19"->{
    Cell[334194, 8723, 276, 8, 70, "MathCaption",
      CellTags->{"S1.5.4", "4.19"}]},
  "4.20"->{
    Cell[714411, 18284, 313, 6, 70, "Text",
      CellTags->{"S1.5.4", "4.20"}]},
  "4.21"->{
    Cell[714727, 18292, 406, 11, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.21"}]},
  "4.22"->{
    Cell[715136, 18305, 300, 11, 70, "Text",
      CellTags->{"S1.5.4", "4.22"}]},
  "4.23"->{
    Cell[715439, 18318, 443, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.23"}]},
  "4.24"->{
    Cell[715885, 18332, 96, 1, 70, "Text",
      CellTags->{"S1.5.4", "4.24"}]},
  "4.25"->{
    Cell[715984, 18335, 505, 11, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.25"}]},
  "4.26"->{
    Cell[716492, 18348, 82, 1, 70, "Text",
      CellTags->{"S1.5.4", "4.26"}]},
  "4.27"->{
    Cell[716577, 18351, 817, 17, 70, "DisplayFormula",
      CellTags->{"S1.5.4", "4.27"}]},
  "4.28"->{
    Cell[717397, 18370, 1180, 34, 70, "Text",
      CellTags->{"S1.5.4", "4.28"}]},
  "S1.5.5"->{
    Cell[718580, 18406, 154, 5, 70, "Subsection",
      CellTags->{"S1.5.5", "5.1"}],
    Cell[718737, 18413, 148, 5, 70, "Text",
      CellTags->{"S1.5.5", "5.2"}],
    Cell[718888, 18420, 236, 10, 70, "Text",
      CellTags->{"S1.5.5", "5.3"}],
    Cell[719127, 18432, 282, 9, 70, "Text",
      CellTags->{"S1.5.5", "5.4"}],
    Cell[719412, 18443, 170, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.5"}],
    Cell[719585, 18449, 4183, 111, 70, "Text",
      CellTags->{"S1.5.5", "5.6"}],
    Cell[723771, 18562, 515, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.7"}],
    Cell[724289, 18576, 692, 23, 70, "Text",
      CellTags->{"S1.5.5", "5.8"}],
    Cell[724984, 18601, 1375, 34, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.9"}],
    Cell[726362, 18637, 197, 7, 70, "Text",
      CellTags->{"S1.5.5", "5.10"}],
    Cell[726562, 18646, 269, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.11"}],
    Cell[726834, 18655, 605, 19, 70, "Text",
      CellTags->{"S1.5.5", "5.12"}],
    Cell[727442, 18676, 192, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.13"}],
    Cell[727637, 18682, 1777, 45, 70, "Text",
      CellTags->{"S1.5.5", "5.14"}],
    Cell[729417, 18729, 290, 13, 70, "Text",
      CellTags->{"S1.5.5", "5.15"}],
    Cell[729710, 18744, 1383, 38, 70, "Text",
      CellTags->{"S1.5.5", "5.16"}],
    Cell[731096, 18784, 477, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.17"}],
    Cell[731576, 18795, 2628, 65, 70, "Text",
      CellTags->{"S1.5.5", "5.18"}],
    Cell[734207, 18862, 178, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.19"}],
    Cell[734388, 18868, 1031, 29, 70, "Text",
      CellTags->{"S1.5.5", "5.20"}],
    Cell[735422, 18899, 245, 10, 70, "Text",
      CellTags->{"S1.5.5", "5.21"}],
    Cell[735670, 18911, 168, 7, 70, "Text",
      CellTags->{"S1.5.5", "5.22"}],
    Cell[735841, 18920, 189, 5, 70, "MathCaption",
      CellTags->{"S1.5.5", "5.23"}],
    Cell[736033, 18927, 124, 5, 51, "Input",
      CellTags->"S1.5.5"],
    Cell[736160, 18934, 179, 5, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.24"}],
    Cell[736364, 18943, 126, 5, 51, "Input",
      CellTags->"S1.5.5"],
    Cell[736493, 18950, 434, 8, 61, "Output",
      CellTags->"S1.5.5"],
    Cell[736942, 18961, 89, 1, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.25"}],
    Cell[737056, 18966, 93, 2, 31, "Input",
      CellTags->"S1.5.5"],
    Cell[737152, 18970, 425, 8, 61, "Output",
      CellTags->"S1.5.5"],
    Cell[737592, 18981, 146, 4, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.26"}],
    Cell[737763, 18989, 100, 2, 31, "Input",
      CellTags->"S1.5.5"],
    Cell[737866, 18993, 86, 3, 23, "Output",
      CellTags->"S1.5.5"]},
  "5.1"->{
    Cell[718580, 18406, 154, 5, 70, "Subsection",
      CellTags->{"S1.5.5", "5.1"}]},
  "5.2"->{
    Cell[718737, 18413, 148, 5, 70, "Text",
      CellTags->{"S1.5.5", "5.2"}]},
  "5.3"->{
    Cell[718888, 18420, 236, 10, 70, "Text",
      CellTags->{"S1.5.5", "5.3"}]},
  "5.4"->{
    Cell[719127, 18432, 282, 9, 70, "Text",
      CellTags->{"S1.5.5", "5.4"}]},
  "5.5"->{
    Cell[719412, 18443, 170, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.5"}]},
  "5.6"->{
    Cell[719585, 18449, 4183, 111, 70, "Text",
      CellTags->{"S1.5.5", "5.6"}]},
  "5.7"->{
    Cell[723771, 18562, 515, 12, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.7"}]},
  "5.8"->{
    Cell[724289, 18576, 692, 23, 70, "Text",
      CellTags->{"S1.5.5", "5.8"}]},
  "5.9"->{
    Cell[724984, 18601, 1375, 34, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.9"}]},
  "5.10"->{
    Cell[726362, 18637, 197, 7, 70, "Text",
      CellTags->{"S1.5.5", "5.10"}]},
  "5.11"->{
    Cell[726562, 18646, 269, 7, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.11"}]},
  "5.12"->{
    Cell[726834, 18655, 605, 19, 70, "Text",
      CellTags->{"S1.5.5", "5.12"}]},
  "5.13"->{
    Cell[727442, 18676, 192, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.13"}]},
  "5.14"->{
    Cell[727637, 18682, 1777, 45, 70, "Text",
      CellTags->{"S1.5.5", "5.14"}]},
  "5.15"->{
    Cell[729417, 18729, 290, 13, 70, "Text",
      CellTags->{"S1.5.5", "5.15"}]},
  "5.16"->{
    Cell[729710, 18744, 1383, 38, 70, "Text",
      CellTags->{"S1.5.5", "5.16"}]},
  "5.17"->{
    Cell[731096, 18784, 477, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.17"}]},
  "5.18"->{
    Cell[731576, 18795, 2628, 65, 70, "Text",
      CellTags->{"S1.5.5", "5.18"}]},
  "5.19"->{
    Cell[734207, 18862, 178, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.5", "5.19"}]},
  "5.20"->{
    Cell[734388, 18868, 1031, 29, 70, "Text",
      CellTags->{"S1.5.5", "5.20"}]},
  "5.21"->{
    Cell[735422, 18899, 245, 10, 70, "Text",
      CellTags->{"S1.5.5", "5.21"}]},
  "5.22"->{
    Cell[735670, 18911, 168, 7, 70, "Text",
      CellTags->{"S1.5.5", "5.22"}]},
  "5.23"->{
    Cell[735841, 18920, 189, 5, 70, "MathCaption",
      CellTags->{"S1.5.5", "5.23"}]},
  "5.24"->{
    Cell[736160, 18934, 179, 5, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.24"}]},
  "5.25"->{
    Cell[736942, 18961, 89, 1, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.25"}]},
  "5.26"->{
    Cell[737592, 18981, 146, 4, 31, "MathCaption",
      CellTags->{"S1.5.5", "5.26"}]},
  "S1.5.6"->{
    Cell[737967, 18999, 104, 1, 39, "Subsection",
      CellTags->{"S1.5.6", "6.1"}],
    Cell[738074, 19002, 1234, 32, 96, "Text",
      CellTags->{"S1.5.6", "6.2"}],
    Cell[739311, 19036, 307, 7, 35, "DisplayFormula",
      CellTags->{"S1.5.6", "6.3"}],
    Cell[739621, 19045, 1479, 43, 101, "Text",
      CellTags->{"S1.5.6", "6.4"}],
    Cell[741103, 19090, 430, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.5"}],
    Cell[741536, 19101, 533, 13, 70, "Text",
      CellTags->{"S1.5.6", "6.6"}],
    Cell[742072, 19116, 430, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.7"}],
    Cell[742505, 19127, 661, 20, 70, "Text",
      CellTags->{"S1.5.6", "6.8"}],
    Cell[743169, 19149, 371, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.9"}],
    Cell[743543, 19159, 52, 1, 70, "Text",
      CellTags->{"S1.5.6", "6.10"}],
    Cell[743598, 19162, 381, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.11"}],
    Cell[743982, 19172, 2552, 75, 70, "Text",
      CellTags->{"S1.5.6", "6.12"}],
    Cell[746537, 19249, 33322, 487, 70, "Text",
      CellTags->{"S1.5.6", "6.13"}],
    Cell[779862, 19738, 560, 17, 70, "Text",
      CellTags->{"S1.5.6", "6.14"}],
    Cell[780425, 19757, 174, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.15"}],
    Cell[780602, 19763, 52, 1, 70, "Text",
      CellTags->{"S1.5.6", "6.16"}],
    Cell[780657, 19766, 178, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.17"}],
    Cell[780838, 19772, 314, 10, 70, "Text",
      CellTags->{"S1.5.6", "6.18"}],
    Cell[781155, 19784, 198, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.19"}],
    Cell[781356, 19793, 139, 5, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[781498, 19800, 425, 14, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.20"}],
    Cell[781926, 19816, 186, 6, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[782115, 19824, 220, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.21"}],
    Cell[782360, 19835, 164, 5, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[782527, 19842, 3689, 265, 70, 3616, 262, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[786231, 20110, 190, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.22"}],
    Cell[786446, 20121, 164, 5, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[786613, 20128, 4235, 302, 70, 4162, 299, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[790863, 20433, 209, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.23"}],
    Cell[791097, 20444, 164, 5, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[791264, 20451, 4379, 311, 70, 4306, 308, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[795658, 20765, 337, 9, 70, "Text",
      CellTags->{"S1.5.6", "6.24"}],
    Cell[795998, 20776, 342, 11, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.25"}],
    Cell[796365, 20791, 170, 6, 70, "Input",
      CellTags->"S1.5.6"],
    Cell[796538, 20799, 4373, 313, 70, 4300, 310, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[800926, 21115, 1693, 34, 221, "Text",
      CellTags->{"S1.5.6", "6.26"}],
    Cell[802622, 21151, 245, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.27"}],
    Cell[802870, 21163, 51, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.28"}],
    Cell[802924, 21166, 298, 13, 25, "Text",
      CellTags->{"S1.5.6", "6.29"}],
    Cell[803225, 21181, 655, 18, 101, "Text",
      CellTags->{"S1.5.6", "6.30"}],
    Cell[803883, 21201, 97, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.31"}],
    Cell[804005, 21206, 121, 5, 51, "Input",
      CellTags->"S1.5.6"],
    Cell[804129, 21213, 282, 5, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[804426, 21221, 79, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.32"}],
    Cell[804530, 21226, 88, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[804621, 21230, 131, 3, 23, "Output",
      CellTags->"S1.5.6"],
    Cell[804767, 21236, 106, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.33"}],
    Cell[804898, 21241, 108, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[805009, 21245, 1068, 18, 156, "Output",
      CellTags->"S1.5.6"],
    Cell[806092, 21266, 2312, 44, 330, "Text",
      CellTags->{"S1.5.6", "6.34"}],
    Cell[808407, 21312, 535, 11, 60, "DisplayFormula",
      CellTags->{"S1.5.6", "6.35"}],
    Cell[808945, 21325, 1530, 35, 189, "Text",
      CellTags->{"S1.5.6", "6.36"}],
    Cell[810478, 21362, 242, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.37"}],
    Cell[810723, 21374, 51, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.38"}],
    Cell[810777, 21377, 295, 13, 25, "Text",
      CellTags->{"S1.5.6", "6.39"}],
    Cell[811075, 21392, 421, 11, 59, "Text",
      CellTags->{"S1.5.6", "6.40"}],
    Cell[811499, 21405, 143, 4, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.41"}],
    Cell[811667, 21413, 96, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[811766, 21417, 328, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[812109, 21426, 199, 5, 42, "Text",
      CellTags->{"S1.5.6", "6.42"}],
    Cell[812311, 21433, 181, 7, 25, "Text",
      CellTags->{"S1.5.6", "6.43"}],
    Cell[812495, 21442, 202, 6, 25, "Text",
      CellTags->{"S1.5.6", "6.44"}],
    Cell[812700, 21450, 288, 6, 65, "MathCaption",
      CellTags->{"S1.5.6", "6.45"}],
    Cell[813013, 21460, 85, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[813101, 21464, 2360, 187, 186, 2287, 184, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[815476, 21654, 373, 7, 59, "Text",
      CellTags->{"S1.5.6", "6.46"}],
    Cell[815852, 21663, 310, 7, 45, "DisplayFormula",
      CellTags->{"S1.5.6", "6.47"}],
    Cell[816165, 21672, 831, 27, 42, "Text",
      CellTags->{"S1.5.6", "6.48"}],
    Cell[816999, 21701, 171, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.49"}],
    Cell[817195, 21709, 147, 5, 51, "Input",
      CellTags->"S1.5.6"],
    Cell[817345, 21716, 323, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[817683, 21725, 115, 2, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.50"}],
    Cell[817823, 21731, 85, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[817911, 21735, 2004, 157, 186, 1931, 154, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[819930, 21895, 1061, 25, 152, "Text",
      CellTags->{"S1.5.6", "6.51"}],
    Cell[820994, 21922, 132, 4, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.52"}],
    Cell[821151, 21930, 167, 5, 51, "Input",
      CellTags->"S1.5.6"],
    Cell[821321, 21937, 329, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[821665, 21946, 242, 5, 42, "Text",
      CellTags->{"S1.5.6", "6.53"}],
    Cell[821910, 21953, 99, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.54"}],
    Cell[822034, 21958, 85, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[822122, 21962, 2540, 202, 186, 2467, 199, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[824677, 22167, 266, 6, 59, "Text",
      CellTags->{"S1.5.6", "6.55"}],
    Cell[824946, 22175, 158, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.56"}],
    Cell[825129, 22183, 121, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[825253, 22187, 317, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[825585, 22196, 91, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.57"}],
    Cell[825701, 22201, 90, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[825794, 22205, 317, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[826126, 22214, 162, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.58"}],
    Cell[826313, 22222, 85, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[826401, 22226, 1824, 142, 186, 1751, 139, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.6"],
    Cell[828240, 22371, 165, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.59"}],
    Cell[828430, 22379, 154, 6, 71, "Input",
      CellTags->"S1.5.6"],
    Cell[828587, 22387, 327, 6, 42, "Output",
      CellTags->"S1.5.6"],
    Cell[828929, 22396, 111, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.60"}],
    Cell[829065, 22401, 93, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[829161, 22405, 86, 3, 23, "Output",
      CellTags->"S1.5.6"],
    Cell[829262, 22411, 84, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.61"}],
    Cell[829349, 22414, 250, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.62"}],
    Cell[829602, 22426, 103, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.63"}],
    Cell[829708, 22429, 102, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[829813, 22433, 181, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.64"}],
    Cell[830019, 22441, 79, 2, 31, "Input",
      CellTags->"S1.5.6"],
    Cell[830101, 22445, 106, 3, 23, "Output",
      CellTags->"S1.5.6"]},
  "6.1"->{
    Cell[737967, 18999, 104, 1, 39, "Subsection",
      CellTags->{"S1.5.6", "6.1"}]},
  "6.2"->{
    Cell[738074, 19002, 1234, 32, 96, "Text",
      CellTags->{"S1.5.6", "6.2"}]},
  "6.3"->{
    Cell[739311, 19036, 307, 7, 35, "DisplayFormula",
      CellTags->{"S1.5.6", "6.3"}]},
  "6.4"->{
    Cell[739621, 19045, 1479, 43, 101, "Text",
      CellTags->{"S1.5.6", "6.4"}]},
  "6.5"->{
    Cell[741103, 19090, 430, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.5"}]},
  "6.6"->{
    Cell[741536, 19101, 533, 13, 70, "Text",
      CellTags->{"S1.5.6", "6.6"}]},
  "6.7"->{
    Cell[742072, 19116, 430, 9, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.7"}]},
  "6.8"->{
    Cell[742505, 19127, 661, 20, 70, "Text",
      CellTags->{"S1.5.6", "6.8"}]},
  "6.9"->{
    Cell[743169, 19149, 371, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.9"}]},
  "6.10"->{
    Cell[743543, 19159, 52, 1, 70, "Text",
      CellTags->{"S1.5.6", "6.10"}]},
  "6.11"->{
    Cell[743598, 19162, 381, 8, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.11"}]},
  "6.12"->{
    Cell[743982, 19172, 2552, 75, 70, "Text",
      CellTags->{"S1.5.6", "6.12"}]},
  "6.13"->{
    Cell[746537, 19249, 33322, 487, 70, "Text",
      CellTags->{"S1.5.6", "6.13"}]},
  "6.14"->{
    Cell[779862, 19738, 560, 17, 70, "Text",
      CellTags->{"S1.5.6", "6.14"}]},
  "6.15"->{
    Cell[780425, 19757, 174, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.15"}]},
  "6.16"->{
    Cell[780602, 19763, 52, 1, 70, "Text",
      CellTags->{"S1.5.6", "6.16"}]},
  "6.17"->{
    Cell[780657, 19766, 178, 4, 70, "DisplayFormula",
      CellTags->{"S1.5.6", "6.17"}]},
  "6.18"->{
    Cell[780838, 19772, 314, 10, 70, "Text",
      CellTags->{"S1.5.6", "6.18"}]},
  "6.19"->{
    Cell[781155, 19784, 198, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.19"}]},
  "6.20"->{
    Cell[781498, 19800, 425, 14, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.20"}]},
  "6.21"->{
    Cell[782115, 19824, 220, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.21"}]},
  "6.22"->{
    Cell[786231, 20110, 190, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.22"}]},
  "6.23"->{
    Cell[790863, 20433, 209, 7, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.23"}]},
  "6.24"->{
    Cell[795658, 20765, 337, 9, 70, "Text",
      CellTags->{"S1.5.6", "6.24"}]},
  "6.25"->{
    Cell[795998, 20776, 342, 11, 70, "MathCaption",
      CellTags->{"S1.5.6", "6.25"}]},
  "6.26"->{
    Cell[800926, 21115, 1693, 34, 221, "Text",
      CellTags->{"S1.5.6", "6.26"}]},
  "6.27"->{
    Cell[802622, 21151, 245, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.27"}]},
  "6.28"->{
    Cell[802870, 21163, 51, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.28"}]},
  "6.29"->{
    Cell[802924, 21166, 298, 13, 25, "Text",
      CellTags->{"S1.5.6", "6.29"}]},
  "6.30"->{
    Cell[803225, 21181, 655, 18, 101, "Text",
      CellTags->{"S1.5.6", "6.30"}]},
  "6.31"->{
    Cell[803883, 21201, 97, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.31"}]},
  "6.32"->{
    Cell[804426, 21221, 79, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.32"}]},
  "6.33"->{
    Cell[804767, 21236, 106, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.33"}]},
  "6.34"->{
    Cell[806092, 21266, 2312, 44, 330, "Text",
      CellTags->{"S1.5.6", "6.34"}]},
  "6.35"->{
    Cell[808407, 21312, 535, 11, 60, "DisplayFormula",
      CellTags->{"S1.5.6", "6.35"}]},
  "6.36"->{
    Cell[808945, 21325, 1530, 35, 189, "Text",
      CellTags->{"S1.5.6", "6.36"}]},
  "6.37"->{
    Cell[810478, 21362, 242, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.37"}]},
  "6.38"->{
    Cell[810723, 21374, 51, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.38"}]},
  "6.39"->{
    Cell[810777, 21377, 295, 13, 25, "Text",
      CellTags->{"S1.5.6", "6.39"}]},
  "6.40"->{
    Cell[811075, 21392, 421, 11, 59, "Text",
      CellTags->{"S1.5.6", "6.40"}]},
  "6.41"->{
    Cell[811499, 21405, 143, 4, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.41"}]},
  "6.42"->{
    Cell[812109, 21426, 199, 5, 42, "Text",
      CellTags->{"S1.5.6", "6.42"}]},
  "6.43"->{
    Cell[812311, 21433, 181, 7, 25, "Text",
      CellTags->{"S1.5.6", "6.43"}]},
  "6.44"->{
    Cell[812495, 21442, 202, 6, 25, "Text",
      CellTags->{"S1.5.6", "6.44"}]},
  "6.45"->{
    Cell[812700, 21450, 288, 6, 65, "MathCaption",
      CellTags->{"S1.5.6", "6.45"}]},
  "6.46"->{
    Cell[815476, 21654, 373, 7, 59, "Text",
      CellTags->{"S1.5.6", "6.46"}]},
  "6.47"->{
    Cell[815852, 21663, 310, 7, 45, "DisplayFormula",
      CellTags->{"S1.5.6", "6.47"}]},
  "6.48"->{
    Cell[816165, 21672, 831, 27, 42, "Text",
      CellTags->{"S1.5.6", "6.48"}]},
  "6.49"->{
    Cell[816999, 21701, 171, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.49"}]},
  "6.50"->{
    Cell[817683, 21725, 115, 2, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.50"}]},
  "6.51"->{
    Cell[819930, 21895, 1061, 25, 152, "Text",
      CellTags->{"S1.5.6", "6.51"}]},
  "6.52"->{
    Cell[820994, 21922, 132, 4, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.52"}]},
  "6.53"->{
    Cell[821665, 21946, 242, 5, 42, "Text",
      CellTags->{"S1.5.6", "6.53"}]},
  "6.54"->{
    Cell[821910, 21953, 99, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.54"}]},
  "6.55"->{
    Cell[824677, 22167, 266, 6, 59, "Text",
      CellTags->{"S1.5.6", "6.55"}]},
  "6.56"->{
    Cell[824946, 22175, 158, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.56"}]},
  "6.57"->{
    Cell[825585, 22196, 91, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.57"}]},
  "6.58"->{
    Cell[826126, 22214, 162, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.58"}]},
  "6.59"->{
    Cell[828240, 22371, 165, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.59"}]},
  "6.60"->{
    Cell[828929, 22396, 111, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.60"}]},
  "6.61"->{
    Cell[829262, 22411, 84, 1, 25, "Text",
      CellTags->{"S1.5.6", "6.61"}]},
  "6.62"->{
    Cell[829349, 22414, 250, 10, 25, "Text",
      CellTags->{"S1.5.6", "6.62"}]},
  "6.63"->{
    Cell[829602, 22426, 103, 1, 31, "MathCaption",
      CellTags->{"S1.5.6", "6.63"}]},
  "6.64"->{
    Cell[829813, 22433, 181, 4, 48, "MathCaption",
      CellTags->{"S1.5.6", "6.64"}]},
  "S1.5.7"->{
    Cell[830222, 22451, 85, 1, 39, "Subsection",
      CellTags->{"S1.5.7", "7.1"}],
    Cell[830310, 22454, 412, 10, 59, "Text",
      CellTags->{"S1.5.7", "7.2"}],
    Cell[830725, 22466, 285, 13, 25, "Text",
      CellTags->{"S1.5.7", "7.3"}],
    Cell[831013, 22481, 1178, 40, 59, "Text",
      CellTags->{"S1.5.7", "7.4"}],
    Cell[832194, 22523, 107, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.5"}],
    Cell[832304, 22526, 90, 2, 31, "Input",
      CellTags->"S1.5.7"],
    Cell[832397, 22530, 176, 4, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.6"}],
    Cell[832598, 22538, 320, 9, 131, "Input",
      CellTags->"S1.5.7"],
    Cell[832921, 22549, 34562, 2231, 186, 34489, 2228, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.7"],
    Cell[867498, 24783, 4799, 140, 383, "Text",
      CellTags->{"S1.5.7", "7.7"}],
    Cell[872300, 24925, 94, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.8"}],
    Cell[872397, 24928, 89, 2, 31, "Input",
      CellTags->"S1.5.7"],
    Cell[872489, 24932, 135, 4, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.9"}],
    Cell[872649, 24940, 87, 2, 31, "Input",
      CellTags->"S1.5.7"],
    Cell[872739, 24944, 192, 5, 57, "Message",
      CellTags->"S1.5.7"],
    Cell[872934, 24951, 645, 11, 99, "Output",
      CellTags->"S1.5.7"],
    Cell[873594, 24965, 418, 14, 59, "Text",
      CellTags->{"S1.5.7", "7.10"}],
    Cell[874015, 24981, 284, 8, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.11"}],
    Cell[874302, 24991, 114, 2, 31, "Input",
      CellTags->"S1.5.7"],
    Cell[874419, 24995, 102, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.12"}],
    Cell[874546, 25000, 162, 5, 51, "Input",
      CellTags->"S1.5.7"],
    Cell[874711, 25007, 20042, 1313, 186, 19969, 1310, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.7"],
    Cell[894768, 26323, 181, 4, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.13"}],
    Cell[894974, 26331, 354, 10, 151, "Input",
      CellTags->"S1.5.7"],
    Cell[895331, 26343, 67933, 4373, 70, 67860, 4370, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.7"]},
  "7.1"->{
    Cell[830222, 22451, 85, 1, 39, "Subsection",
      CellTags->{"S1.5.7", "7.1"}]},
  "7.2"->{
    Cell[830310, 22454, 412, 10, 59, "Text",
      CellTags->{"S1.5.7", "7.2"}]},
  "7.3"->{
    Cell[830725, 22466, 285, 13, 25, "Text",
      CellTags->{"S1.5.7", "7.3"}]},
  "7.4"->{
    Cell[831013, 22481, 1178, 40, 59, "Text",
      CellTags->{"S1.5.7", "7.4"}]},
  "7.5"->{
    Cell[832194, 22523, 107, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.5"}]},
  "7.6"->{
    Cell[832397, 22530, 176, 4, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.6"}]},
  "7.7"->{
    Cell[867498, 24783, 4799, 140, 383, "Text",
      CellTags->{"S1.5.7", "7.7"}]},
  "7.8"->{
    Cell[872300, 24925, 94, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.8"}]},
  "7.9"->{
    Cell[872489, 24932, 135, 4, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.9"}]},
  "7.10"->{
    Cell[873594, 24965, 418, 14, 59, "Text",
      CellTags->{"S1.5.7", "7.10"}]},
  "7.11"->{
    Cell[874015, 24981, 284, 8, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.11"}]},
  "7.12"->{
    Cell[874419, 24995, 102, 1, 31, "MathCaption",
      CellTags->{"S1.5.7", "7.12"}]},
  "7.13"->{
    Cell[894768, 26323, 181, 4, 48, "MathCaption",
      CellTags->{"S1.5.7", "7.13"}]},
  "S1.5.8"->{
    Cell[963279, 30719, 397, 14, 70, "Subsection",
      CellTags->{"S1.5.8", "8.1"}],
    Cell[963679, 30735, 769, 17, 70, "Text",
      CellTags->{"S1.5.8", "8.2"}],
    Cell[964451, 30754, 568, 25, 70, "Text",
      CellTags->{"S1.5.8", "8.3"}],
    Cell[965022, 30781, 1347, 46, 70, "Text",
      CellTags->{"S1.5.8", "8.4"}],
    Cell[966372, 30829, 250, 8, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.5"}],
    Cell[966625, 30839, 152, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[966780, 30846, 75, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.6"}],
    Cell[966880, 30851, 156, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[967039, 30858, 6544, 447, 70, 6471, 444, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[973598, 31308, 941, 27, 70, "Text",
      CellTags->{"S1.5.8", "8.7"}],
    Cell[974542, 31337, 229, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.8"}],
    Cell[974774, 31346, 103, 2, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[974880, 31350, 235, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.9"}],
    Cell[975140, 31361, 145, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[975288, 31368, 5291, 432, 70, 5218, 429, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[980594, 31803, 241, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.10"}],
    Cell[980860, 31814, 86, 2, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[980949, 31818, 88, 3, 70, "Output",
      CellTags->"S1.5.8"],
    Cell[981052, 31824, 686, 17, 70, "Text",
      CellTags->{"S1.5.8", "8.11"}],
    Cell[981741, 31843, 235, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.12"}],
    Cell[981979, 31852, 101, 2, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[982083, 31856, 208, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.13"}],
    Cell[982316, 31867, 142, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[982461, 31874, 5387, 421, 70, 5314, 418, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[987863, 32298, 321, 8, 70, "Text",
      CellTags->{"S1.5.8", "8.14"}],
    Cell[988187, 32308, 82, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.15"}],
    Cell[988272, 32311, 146, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[988421, 32318, 73, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.16"}],
    Cell[988519, 32323, 156, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[988678, 32330, 8547, 574, 70, 8474, 571, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[997240, 32907, 198, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.17"}],
    Cell[997441, 32916, 95, 2, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[997539, 32920, 86, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.18"}],
    Cell[997628, 32923, 139, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[997770, 32930, 224, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.19"}],
    Cell[998019, 32941, 185, 6, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[998207, 32949, 4354, 315, 70, 4281, 312, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[1002576, 33267, 143, 5, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.20"}],
    Cell[1002722, 33274, 143, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[1002868, 33281, 176, 4, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.21"}],
    Cell[1003069, 33289, 154, 5, 70, "Input",
      CellTags->"S1.5.8"],
    Cell[1003226, 33296, 1915, 128, 70, 1842, 125, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.5.8"],
    Cell[1005156, 33427, 213, 5, 70, "Text",
      CellTags->{"S1.5.8", "8.22"}]},
  "8.1"->{
    Cell[963279, 30719, 397, 14, 70, "Subsection",
      CellTags->{"S1.5.8", "8.1"}]},
  "8.2"->{
    Cell[963679, 30735, 769, 17, 70, "Text",
      CellTags->{"S1.5.8", "8.2"}]},
  "8.3"->{
    Cell[964451, 30754, 568, 25, 70, "Text",
      CellTags->{"S1.5.8", "8.3"}]},
  "8.4"->{
    Cell[965022, 30781, 1347, 46, 70, "Text",
      CellTags->{"S1.5.8", "8.4"}]},
  "8.5"->{
    Cell[966372, 30829, 250, 8, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.5"}]},
  "8.6"->{
    Cell[966780, 30846, 75, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.6"}]},
  "8.7"->{
    Cell[973598, 31308, 941, 27, 70, "Text",
      CellTags->{"S1.5.8", "8.7"}]},
  "8.8"->{
    Cell[974542, 31337, 229, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.8"}]},
  "8.9"->{
    Cell[974880, 31350, 235, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.9"}]},
  "8.10"->{
    Cell[980594, 31803, 241, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.10"}]},
  "8.11"->{
    Cell[981052, 31824, 686, 17, 70, "Text",
      CellTags->{"S1.5.8", "8.11"}]},
  "8.12"->{
    Cell[981741, 31843, 235, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.12"}]},
  "8.13"->{
    Cell[982083, 31856, 208, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.13"}]},
  "8.14"->{
    Cell[987863, 32298, 321, 8, 70, "Text",
      CellTags->{"S1.5.8", "8.14"}]},
  "8.15"->{
    Cell[988187, 32308, 82, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.15"}]},
  "8.16"->{
    Cell[988421, 32318, 73, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.16"}]},
  "8.17"->{
    Cell[997240, 32907, 198, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.17"}]},
  "8.18"->{
    Cell[997539, 32920, 86, 1, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.18"}]},
  "8.19"->{
    Cell[997770, 32930, 224, 7, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.19"}]},
  "8.20"->{
    Cell[1002576, 33267, 143, 5, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.20"}]},
  "8.21"->{
    Cell[1002868, 33281, 176, 4, 70, "MathCaption",
      CellTags->{"S1.5.8", "8.21"}]},
  "8.22"->{
    Cell[1005156, 33427, 213, 5, 70, "Text",
      CellTags->{"S1.5.8", "8.22"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 1006031, 33452},
  {"S1.5.0", 1006192, 33457},
  {"0.1", 1006362, 33462},
  {"0.2", 1006453, 33465},
  {"S1.5.1", 1006547, 33468},
  {"1.1", 1008549, 33517},
  {"1.2", 1008642, 33520},
  {"1.3", 1008734, 33523},
  {"1.4", 1008833, 33526},
  {"1.5", 1008924, 33529},
  {"1.6", 1009023, 33532},
  {"1.7", 1009111, 33535},
  {"1.8", 1009211, 33538},
  {"1.9", 1009301, 33541},
  {"1.10", 1009401, 33544},
  {"1.11", 1009491, 33547},
  {"1.12", 1009592, 33550},
  {"1.13", 1009683, 33553},
  {"1.14", 1009784, 33556},
  {"1.15", 1009874, 33559},
  {"1.16", 1009975, 33562},
  {"1.17", 1010067, 33565},
  {"1.18", 1010169, 33568},
  {"1.19", 1010259, 33571},
  {"1.20", 1010361, 33574},
  {"1.21", 1010454, 33577},
  {"1.22", 1010556, 33580},
  {"1.23", 1010649, 33583},
  {"1.24", 1010750, 33586},
  {"S1.5.2", 1010845, 33589},
  {"2.1", 1011515, 33606},
  {"2.2", 1011609, 33609},
  {"2.3", 1011700, 33612},
  {"2.4", 1011800, 33615},
  {"2.5", 1011890, 33618},
  {"2.6", 1011990, 33621},
  {"2.7", 1012079, 33624},
  {"2.8", 1012180, 33627},
  {"S1.5.3", 1012272, 33630},
  {"3.1", 1015142, 33699},
  {"3.2", 1015236, 33702},
  {"3.3", 1015327, 33705},
  {"3.4", 1015426, 33708},
  {"3.5", 1015517, 33711},
  {"3.6", 1015616, 33714},
  {"3.7", 1015707, 33717},
  {"3.8", 1015806, 33720},
  {"3.9", 1015897, 33723},
  {"3.10", 1015998, 33726},
  {"3.11", 1016092, 33729},
  {"3.12", 1016194, 33732},
  {"3.13", 1016285, 33735},
  {"3.14", 1016387, 33738},
  {"3.15", 1016480, 33741},
  {"3.16", 1016583, 33744},
  {"3.17", 1016674, 33747},
  {"3.18", 1016777, 33750},
  {"3.19", 1016871, 33753},
  {"3.20", 1016973, 33756},
  {"3.21", 1017066, 33759},
  {"3.22", 1017170, 33762},
  {"3.23", 1017262, 33765},
  {"3.24", 1017364, 33768},
  {"3.25", 1017455, 33771},
  {"3.26", 1017558, 33774},
  {"3.27", 1017652, 33777},
  {"3.28", 1017755, 33780},
  {"3.29", 1017847, 33783},
  {"3.30", 1017950, 33786},
  {"3.31", 1018042, 33789},
  {"3.32", 1018144, 33792},
  {"3.33", 1018239, 33795},
  {"3.34", 1018341, 33798},
  {"S1.5.4", 1018436, 33801},
  {"4.1", 1022177, 33894},
  {"4.2", 1022273, 33897},
  {"4.3", 1022363, 33900},
  {"4.4", 1022463, 33903},
  {"4.5", 1022552, 33906},
  {"4.6", 1022652, 33909},
  {"4.7", 1022744, 33912},
  {"4.8", 1022845, 33915},
  {"4.9", 1022935, 33918},
  {"4.10", 1023038, 33921},
  {"4.11", 1023131, 33924},
  {"4.12", 1023229, 33927},
  {"4.13", 1023328, 33930},
  {"4.14", 1023427, 33933},
  {"4.15", 1023527, 33936},
  {"4.16", 1023628, 33939},
  {"4.17", 1023728, 33942},
  {"4.18", 1023821, 33945},
  {"4.19", 1023921, 33948},
  {"4.20", 1024021, 33951},
  {"4.21", 1024115, 33954},
  {"4.22", 1024220, 33957},
  {"4.23", 1024315, 33960},
  {"4.24", 1024420, 33963},
  {"4.25", 1024513, 33966},
  {"4.26", 1024618, 33969},
  {"4.27", 1024711, 33972},
  {"4.28", 1024816, 33975},
  {"S1.5.5", 1024914, 33978},
  {"5.1", 1027650, 34045},
  {"5.2", 1027748, 34048},
  {"5.3", 1027840, 34051},
  {"5.4", 1027933, 34054},
  {"5.5", 1028025, 34057},
  {"5.6", 1028127, 34060},
  {"5.7", 1028222, 34063},
  {"5.8", 1028325, 34066},
  {"5.9", 1028418, 34069},
  {"5.10", 1028523, 34072},
  {"5.11", 1028617, 34075},
  {"5.12", 1028721, 34078},
  {"5.13", 1028816, 34081},
  {"5.14", 1028920, 34084},
  {"5.15", 1029016, 34087},
  {"5.16", 1029111, 34090},
  {"5.17", 1029207, 34093},
  {"5.18", 1029311, 34096},
  {"5.19", 1029407, 34099},
  {"5.20", 1029511, 34102},
  {"5.21", 1029607, 34105},
  {"5.22", 1029702, 34108},
  {"5.23", 1029796, 34111},
  {"5.24", 1029897, 34114},
  {"5.25", 1029998, 34117},
  {"5.26", 1030098, 34120},
  {"S1.5.6", 1030201, 34123},
  {"6.1", 1039284, 34350},
  {"6.2", 1039382, 34353},
  {"6.3", 1039476, 34356},
  {"6.4", 1039578, 34359},
  {"6.5", 1039673, 34362},
  {"6.6", 1039775, 34365},
  {"6.7", 1039868, 34368},
  {"6.8", 1039970, 34371},
  {"6.9", 1040063, 34374},
  {"6.10", 1040166, 34377},
  {"6.11", 1040259, 34380},
  {"6.12", 1040363, 34383},
  {"6.13", 1040459, 34386},
  {"6.14", 1040557, 34389},
  {"6.15", 1040652, 34392},
  {"6.16", 1040756, 34395},
  {"6.17", 1040849, 34398},
  {"6.18", 1040953, 34401},
  {"6.19", 1041048, 34404},
  {"6.20", 1041149, 34407},
  {"6.21", 1041251, 34410},
  {"6.22", 1041352, 34413},
  {"6.23", 1041453, 34416},
  {"6.24", 1041554, 34419},
  {"6.25", 1041648, 34422},
  {"6.26", 1041750, 34425},
  {"6.27", 1041847, 34428},
  {"6.28", 1041942, 34431},
  {"6.29", 1042035, 34434},
  {"6.30", 1042130, 34437},
  {"6.31", 1042226, 34440},
  {"6.32", 1042326, 34443},
  {"6.33", 1042426, 34446},
  {"6.34", 1042527, 34449},
  {"6.35", 1042624, 34452},
  {"6.36", 1042729, 34455},
  {"6.37", 1042826, 34458},
  {"6.38", 1042921, 34461},
  {"6.39", 1043014, 34464},
  {"6.40", 1043109, 34467},
  {"6.41", 1043204, 34470},
  {"6.42", 1043305, 34473},
  {"6.43", 1043399, 34476},
  {"6.44", 1043493, 34479},
  {"6.45", 1043587, 34482},
  {"6.46", 1043688, 34485},
  {"6.47", 1043782, 34488},
  {"6.48", 1043886, 34491},
  {"6.49", 1043981, 34494},
  {"6.50", 1044082, 34497},
  {"6.51", 1044183, 34500},
  {"6.52", 1044280, 34503},
  {"6.53", 1044381, 34506},
  {"6.54", 1044475, 34509},
  {"6.55", 1044575, 34512},
  {"6.56", 1044669, 34515},
  {"6.57", 1044770, 34518},
  {"6.58", 1044870, 34521},
  {"6.59", 1044971, 34524},
  {"6.60", 1045072, 34527},
  {"6.61", 1045173, 34530},
  {"6.62", 1045266, 34533},
  {"6.63", 1045361, 34536},
  {"6.64", 1045462, 34539},
  {"S1.5.7", 1045565, 34542},
  {"7.1", 1047811, 34599},
  {"7.2", 1047908, 34602},
  {"7.3", 1048001, 34605},
  {"7.4", 1048094, 34608},
  {"7.5", 1048188, 34611},
  {"7.6", 1048287, 34614},
  {"7.7", 1048386, 34617},
  {"7.8", 1048482, 34620},
  {"7.9", 1048580, 34623},
  {"7.10", 1048680, 34626},
  {"7.11", 1048775, 34629},
  {"7.12", 1048876, 34632},
  {"7.13", 1048977, 34635},
  {"S1.5.8", 1049080, 34638},
  {"8.1", 1052980, 34737},
  {"8.2", 1053079, 34740},
  {"8.3", 1053172, 34743},
  {"8.4", 1053265, 34746},
  {"8.5", 1053359, 34749},
  {"8.6", 1053458, 34752},
  {"8.7", 1053556, 34755},
  {"8.8", 1053649, 34758},
  {"8.9", 1053748, 34761},
  {"8.10", 1053848, 34764},
  {"8.11", 1053949, 34767},
  {"8.12", 1054044, 34770},
  {"8.13", 1054145, 34773},
  {"8.14", 1054246, 34776},
  {"8.15", 1054340, 34779},
  {"8.16", 1054440, 34782},
  {"8.17", 1054540, 34785},
  {"8.18", 1054641, 34788},
  {"8.19", 1054741, 34791},
  {"8.20", 1054842, 34794},
  {"8.21", 1054944, 34797},
  {"8.22", 1055046, 34800}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 115, 4, 82, "Section",
  CellTags->"Contents"],
Cell[1835, 55, 1571, 50, 178, "Contents",
  CellTags->"Contents"],
Cell[3409, 107, 122, 4, 82, "Section",
  CellTags->{"S1.5.0", "0.1"}],
Cell[3534, 113, 2032, 52, 189, "Text",
  CellTags->{"S1.5.0", "0.2"}],
Cell[5569, 167, 77, 1, 39, "Subsection",
  CellTags->{"S1.5.1", "1.1"}],
Cell[5649, 170, 4000, 112, 192, "Text",
  CellTags->{"S1.5.1", "1.2"}],
Cell[9652, 284, 502, 12, 46, "DisplayFormula",
  CellTags->{"S1.5.1", "1.3"}],
Cell[10157, 298, 1422, 44, 88, "Text",
  CellTags->{"S1.5.1", "1.4"}],
Cell[11582, 344, 386, 8, 45, "DisplayFormula",
  CellTags->{"S1.5.1", "1.5"}],
Cell[11971, 354, 83, 1, 25, "Text",
  CellTags->{"S1.5.1", "1.6"}],
Cell[12057, 357, 646, 13, 77, "DisplayFormula",
  CellTags->{"S1.5.1", "1.7"}],
Cell[12706, 372, 379, 11, 42, "Text",
  CellTags->{"S1.5.1", "1.8"}],
Cell[13088, 385, 311, 7, 33, "DisplayFormula",
  CellTags->{"S1.5.1", "1.9"}],
Cell[13402, 394, 67, 1, 25, "Text",
  CellTags->{"S1.5.1", "1.10"}],
Cell[13472, 397, 392, 8, 45, "DisplayFormula",
  CellTags->{"S1.5.1", "1.11"}],
Cell[13867, 407, 216, 7, 25, "Text",
  CellTags->{"S1.5.1", "1.12"}],
Cell[14086, 416, 312, 7, 33, "DisplayFormula",
  CellTags->{"S1.5.1", "1.13"}],
Cell[14401, 425, 78, 1, 25, "Text",
  CellTags->{"S1.5.1", "1.14"}],
Cell[14482, 428, 479, 9, 45, "DisplayFormula",
  CellTags->{"S1.5.1", "1.15"}],
Cell[14964, 439, 478, 15, 44, "Text",
  CellTags->{"S1.5.1", "1.16"}],
Cell[15445, 456, 681, 15, 70, "DisplayFormula",
  CellTags->{"S1.5.1", "1.17"}],
Cell[16129, 473, 52, 1, 70, "Text",
  CellTags->{"S1.5.1", "1.18"}],
Cell[16184, 476, 681, 15, 70, "DisplayFormula",
  CellTags->{"S1.5.1", "1.19"}],
Cell[16868, 493, 1046, 28, 70, "Text",
  CellTags->{"S1.5.1", "1.20"}],
Cell[17917, 523, 645, 15, 70, "DisplayFormula",
  CellTags->{"S1.5.1", "1.21"}],
Cell[18565, 540, 2175, 54, 70, "Text",
  CellTags->{"S1.5.1", "1.22"}],
Cell[20743, 596, 140, 3, 70, "DisplayFormula",
  CellTags->{"S1.5.1", "1.23"}],
Cell[20886, 601, 1474, 39, 70, "Text",
  CellTags->{"S1.5.1", "1.24"}],
Cell[22363, 642, 85, 1, 70, "Subsection",
  CellTags->{"S1.5.2", "2.1"}],
Cell[22451, 645, 1283, 35, 70, "Text",
  CellTags->{"S1.5.2", "2.2"}],
Cell[23737, 682, 633, 12, 70, "DisplayFormula",
  CellTags->{"S1.5.2", "2.3"}],
Cell[24373, 696, 876, 29, 70, "Text",
  CellTags->{"S1.5.2", "2.4"}],
Cell[25252, 727, 434, 10, 70, "DisplayFormula",
  CellTags->{"S1.5.2", "2.5"}],
Cell[25689, 739, 270, 8, 70, "Text",
  CellTags->{"S1.5.2", "2.6"}],
Cell[25962, 749, 1625, 39, 70, "DisplayFormula",
  CellTags->{"S1.5.2", "2.7"}],
Cell[27590, 790, 199, 5, 70, "Text",
  CellTags->{"S1.5.2", "2.8"}],
Cell[27792, 797, 90, 1, 70, "Subsection",
  CellTags->{"S1.5.3", "3.1"}],
Cell[27885, 800, 1393, 27, 70, "Text",
  CellTags->{"S1.5.3", "3.2"}],
Cell[29281, 829, 342, 8, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.3"}],
Cell[29626, 839, 2660, 71, 70, "Text",
  CellTags->{"S1.5.3", "3.4"}],
Cell[32289, 912, 151, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.5"}],
Cell[32443, 918, 1908, 49, 70, "Text",
  CellTags->{"S1.5.3", "3.6"}],
Cell[34354, 969, 394, 9, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.7"}],
Cell[34751, 980, 2676, 76, 70, "Text",
  CellTags->{"S1.5.3", "3.8"}],
Cell[37430, 1058, 285, 7, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.9"}],
Cell[37718, 1067, 2102, 66, 70, "Text",
  CellTags->{"S1.5.3", "3.10"}],
Cell[39823, 1135, 297, 7, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.11"}],
Cell[40123, 1144, 52, 1, 70, "Text",
  CellTags->{"S1.5.3", "3.12"}],
Cell[40178, 1147, 287, 7, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.13"}],
Cell[40468, 1156, 681, 13, 70, "Text",
  CellTags->{"S1.5.3", "3.14"}],
Cell[41152, 1171, 484, 10, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.15"}],
Cell[41639, 1183, 52, 1, 70, "Text",
  CellTags->{"S1.5.3", "3.16"}],
Cell[41694, 1186, 489, 10, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.17"}],
Cell[42186, 1198, 2581, 71, 70, "Text",
  CellTags->{"S1.5.3", "3.18"}],
Cell[44770, 1271, 311, 8, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.19"}],
Cell[45084, 1281, 359, 11, 70, "Text",
  CellTags->{"S1.5.3", "3.20"}],
Cell[45446, 1294, 1516, 37, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.21"}],
Cell[46965, 1333, 123, 4, 70, "Text",
  CellTags->{"S1.5.3", "3.22"}],
Cell[47091, 1339, 353, 8, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.23"}],
Cell[47447, 1349, 84, 1, 70, "Text",
  CellTags->{"S1.5.3", "3.24"}],
Cell[47534, 1352, 430, 10, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.25"}],
Cell[47967, 1364, 1526, 45, 70, "Text",
  CellTags->{"S1.5.3", "3.26"}],
Cell[49496, 1411, 415, 10, 70, "DisplayFormula",
  CellTags->{"S1.5.3", "3.27"}],
Cell[49914, 1423, 227, 7, 25, "Text",
  CellTags->{"S1.5.3", "3.28"}],
Cell[50144, 1432, 449, 10, 45, "DisplayFormula",
  CellTags->{"S1.5.3", "3.29"}],
Cell[50596, 1444, 385, 9, 59, "Text",
  CellTags->{"S1.5.3", "3.30"}],
Cell[50984, 1455, 414, 8, 32, "DisplayFormula",
  CellTags->{"S1.5.3", "3.31"}],
Cell[51401, 1465, 2063, 63, 112, "Text",
  CellTags->{"S1.5.3", "3.32"}],
Cell[53467, 1530, 262, 5, 33, "DisplayFormula",
  CellTags->{"S1.5.3", "3.33"}],
Cell[53732, 1537, 448, 10, 59, "Text",
  CellTags->{"S1.5.3", "3.34"}],
Cell[54183, 1549, 108, 1, 39, "Subsection",
  CellTags->{"S1.5.4", "4.1"}],
Cell[54294, 1552, 311, 6, 59, "Text",
  CellTags->{"S1.5.4", "4.2"}],
Cell[54608, 1560, 144, 3, 31, "DisplayFormula",
  CellTags->{"S1.5.4", "4.3"}],
Cell[54755, 1565, 89, 1, 25, "Text",
  CellTags->{"S1.5.4", "4.4"}],
Cell[54847, 1568, 289, 6, 46, "DisplayFormula",
  CellTags->{"S1.5.4", "4.5"}],
Cell[55139, 1576, 1084, 27, 96, "Text",
  CellTags->{"S1.5.4", "4.6"}],
Cell[56226, 1605, 938, 26, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.7"}],
Cell[57167, 1633, 158, 5, 70, "Text",
  CellTags->{"S1.5.4", "4.8"}],
Cell[57328, 1640, 1455, 38, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.9"}],
Cell[58786, 1680, 847, 25, 70, "Text",
  CellTags->{"S1.5.4", "4.10"}],
Cell[59636, 1707, 78, 1, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.11"}],
Cell[59717, 1710, 93, 2, 70, "Input",
  CellTags->"S1.5.4"],
Cell[59813, 1714, 147, 4, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.12"}],
Cell[59963, 1720, 199, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[60165, 1728, 116, 2, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.13"}],

Cell[CellGroupData[{
Cell[60306, 1734, 199, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[60508, 1742, 67997, 1721, 70, 67924, 1718, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],
Cell[128520, 3466, 204, 7, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.14"}],

Cell[CellGroupData[{
Cell[128749, 3477, 199, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[128951, 3485, 67896, 1721, 70, 67823, 1718, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],
Cell[196862, 5209, 347, 12, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.15"}],

Cell[CellGroupData[{
Cell[197234, 5225, 199, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[197436, 5233, 67906, 1721, 70, 67833, 1718, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],
Cell[265357, 6957, 215, 8, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.16"}],

Cell[CellGroupData[{
Cell[265597, 6969, 199, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[265799, 6977, 67871, 1721, 70, 67798, 1718, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],
Cell[333685, 8701, 125, 4, 70, "Text",
  CellTags->{"S1.5.4", "4.17"}],
Cell[333813, 8707, 226, 7, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.18"}],
Cell[334042, 8716, 149, 5, 70, "Input",
  CellTags->"S1.5.4"],
Cell[334194, 8723, 276, 8, 70, "MathCaption",
  CellTags->{"S1.5.4", "4.19"}],

Cell[CellGroupData[{
Cell[334495, 8735, 194, 6, 70, "Input",
  CellTags->"S1.5.4"],
Cell[334692, 8743, 379704, 9538, 70, 379631, 9535, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.4"]
}, Open  ]],
Cell[714411, 18284, 313, 6, 70, "Text",
  CellTags->{"S1.5.4", "4.20"}],
Cell[714727, 18292, 406, 11, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.21"}],
Cell[715136, 18305, 300, 11, 70, "Text",
  CellTags->{"S1.5.4", "4.22"}],
Cell[715439, 18318, 443, 12, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.23"}],
Cell[715885, 18332, 96, 1, 70, "Text",
  CellTags->{"S1.5.4", "4.24"}],
Cell[715984, 18335, 505, 11, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.25"}],
Cell[716492, 18348, 82, 1, 70, "Text",
  CellTags->{"S1.5.4", "4.26"}],
Cell[716577, 18351, 817, 17, 70, "DisplayFormula",
  CellTags->{"S1.5.4", "4.27"}],
Cell[717397, 18370, 1180, 34, 70, "Text",
  CellTags->{"S1.5.4", "4.28"}],
Cell[718580, 18406, 154, 5, 70, "Subsection",
  CellTags->{"S1.5.5", "5.1"}],
Cell[718737, 18413, 148, 5, 70, "Text",
  CellTags->{"S1.5.5", "5.2"}],
Cell[718888, 18420, 236, 10, 70, "Text",
  CellTags->{"S1.5.5", "5.3"}],
Cell[719127, 18432, 282, 9, 70, "Text",
  CellTags->{"S1.5.5", "5.4"}],
Cell[719412, 18443, 170, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.5"}],
Cell[719585, 18449, 4183, 111, 70, "Text",
  CellTags->{"S1.5.5", "5.6"}],
Cell[723771, 18562, 515, 12, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.7"}],
Cell[724289, 18576, 692, 23, 70, "Text",
  CellTags->{"S1.5.5", "5.8"}],
Cell[724984, 18601, 1375, 34, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.9"}],
Cell[726362, 18637, 197, 7, 70, "Text",
  CellTags->{"S1.5.5", "5.10"}],
Cell[726562, 18646, 269, 7, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.11"}],
Cell[726834, 18655, 605, 19, 70, "Text",
  CellTags->{"S1.5.5", "5.12"}],
Cell[727442, 18676, 192, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.13"}],
Cell[727637, 18682, 1777, 45, 70, "Text",
  CellTags->{"S1.5.5", "5.14"}],
Cell[729417, 18729, 290, 13, 70, "Text",
  CellTags->{"S1.5.5", "5.15"}],
Cell[729710, 18744, 1383, 38, 70, "Text",
  CellTags->{"S1.5.5", "5.16"}],
Cell[731096, 18784, 477, 9, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.17"}],
Cell[731576, 18795, 2628, 65, 70, "Text",
  CellTags->{"S1.5.5", "5.18"}],
Cell[734207, 18862, 178, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.5", "5.19"}],
Cell[734388, 18868, 1031, 29, 70, "Text",
  CellTags->{"S1.5.5", "5.20"}],
Cell[735422, 18899, 245, 10, 70, "Text",
  CellTags->{"S1.5.5", "5.21"}],
Cell[735670, 18911, 168, 7, 70, "Text",
  CellTags->{"S1.5.5", "5.22"}],
Cell[735841, 18920, 189, 5, 70, "MathCaption",
  CellTags->{"S1.5.5", "5.23"}],
Cell[736033, 18927, 124, 5, 51, "Input",
  CellTags->"S1.5.5"],
Cell[736160, 18934, 179, 5, 31, "MathCaption",
  CellTags->{"S1.5.5", "5.24"}],

Cell[CellGroupData[{
Cell[736364, 18943, 126, 5, 51, "Input",
  CellTags->"S1.5.5"],
Cell[736493, 18950, 434, 8, 61, "Output",
  CellTags->"S1.5.5"]
}, Open  ]],
Cell[736942, 18961, 89, 1, 31, "MathCaption",
  CellTags->{"S1.5.5", "5.25"}],

Cell[CellGroupData[{
Cell[737056, 18966, 93, 2, 31, "Input",
  CellTags->"S1.5.5"],
Cell[737152, 18970, 425, 8, 61, "Output",
  CellTags->"S1.5.5"]
}, Open  ]],
Cell[737592, 18981, 146, 4, 31, "MathCaption",
  CellTags->{"S1.5.5", "5.26"}],

Cell[CellGroupData[{
Cell[737763, 18989, 100, 2, 31, "Input",
  CellTags->"S1.5.5"],
Cell[737866, 18993, 86, 3, 23, "Output",
  CellTags->"S1.5.5"]
}, Open  ]],
Cell[737967, 18999, 104, 1, 39, "Subsection",
  CellTags->{"S1.5.6", "6.1"}],
Cell[738074, 19002, 1234, 32, 96, "Text",
  CellTags->{"S1.5.6", "6.2"}],
Cell[739311, 19036, 307, 7, 35, "DisplayFormula",
  CellTags->{"S1.5.6", "6.3"}],
Cell[739621, 19045, 1479, 43, 101, "Text",
  CellTags->{"S1.5.6", "6.4"}],
Cell[741103, 19090, 430, 9, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.5"}],
Cell[741536, 19101, 533, 13, 70, "Text",
  CellTags->{"S1.5.6", "6.6"}],
Cell[742072, 19116, 430, 9, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.7"}],
Cell[742505, 19127, 661, 20, 70, "Text",
  CellTags->{"S1.5.6", "6.8"}],
Cell[743169, 19149, 371, 8, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.9"}],
Cell[743543, 19159, 52, 1, 70, "Text",
  CellTags->{"S1.5.6", "6.10"}],
Cell[743598, 19162, 381, 8, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.11"}],
Cell[743982, 19172, 2552, 75, 70, "Text",
  CellTags->{"S1.5.6", "6.12"}],
Cell[746537, 19249, 33322, 487, 70, "Text",
  CellTags->{"S1.5.6", "6.13"}],
Cell[779862, 19738, 560, 17, 70, "Text",
  CellTags->{"S1.5.6", "6.14"}],
Cell[780425, 19757, 174, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.15"}],
Cell[780602, 19763, 52, 1, 70, "Text",
  CellTags->{"S1.5.6", "6.16"}],
Cell[780657, 19766, 178, 4, 70, "DisplayFormula",
  CellTags->{"S1.5.6", "6.17"}],
Cell[780838, 19772, 314, 10, 70, "Text",
  CellTags->{"S1.5.6", "6.18"}],
Cell[781155, 19784, 198, 7, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.19"}],
Cell[781356, 19793, 139, 5, 70, "Input",
  CellTags->"S1.5.6"],
Cell[781498, 19800, 425, 14, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.20"}],
Cell[781926, 19816, 186, 6, 70, "Input",
  CellTags->"S1.5.6"],
Cell[782115, 19824, 220, 7, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.21"}],

Cell[CellGroupData[{
Cell[782360, 19835, 164, 5, 70, "Input",
  CellTags->"S1.5.6"],
Cell[782527, 19842, 3689, 265, 70, 3616, 262, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[786231, 20110, 190, 7, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.22"}],

Cell[CellGroupData[{
Cell[786446, 20121, 164, 5, 70, "Input",
  CellTags->"S1.5.6"],
Cell[786613, 20128, 4235, 302, 70, 4162, 299, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[790863, 20433, 209, 7, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.23"}],

Cell[CellGroupData[{
Cell[791097, 20444, 164, 5, 70, "Input",
  CellTags->"S1.5.6"],
Cell[791264, 20451, 4379, 311, 70, 4306, 308, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[795658, 20765, 337, 9, 70, "Text",
  CellTags->{"S1.5.6", "6.24"}],
Cell[795998, 20776, 342, 11, 70, "MathCaption",
  CellTags->{"S1.5.6", "6.25"}],

Cell[CellGroupData[{
Cell[796365, 20791, 170, 6, 70, "Input",
  CellTags->"S1.5.6"],
Cell[796538, 20799, 4373, 313, 70, 4300, 310, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[800926, 21115, 1693, 34, 221, "Text",
  CellTags->{"S1.5.6", "6.26"}],
Cell[802622, 21151, 245, 10, 25, "Text",
  CellTags->{"S1.5.6", "6.27"}],
Cell[802870, 21163, 51, 1, 25, "Text",
  CellTags->{"S1.5.6", "6.28"}],
Cell[802924, 21166, 298, 13, 25, "Text",
  CellTags->{"S1.5.6", "6.29"}],
Cell[803225, 21181, 655, 18, 101, "Text",
  CellTags->{"S1.5.6", "6.30"}],
Cell[803883, 21201, 97, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.31"}],

Cell[CellGroupData[{
Cell[804005, 21206, 121, 5, 51, "Input",
  CellTags->"S1.5.6"],
Cell[804129, 21213, 282, 5, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[804426, 21221, 79, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.32"}],

Cell[CellGroupData[{
Cell[804530, 21226, 88, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[804621, 21230, 131, 3, 23, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[804767, 21236, 106, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.33"}],

Cell[CellGroupData[{
Cell[804898, 21241, 108, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[805009, 21245, 1068, 18, 156, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[806092, 21266, 2312, 44, 330, "Text",
  CellTags->{"S1.5.6", "6.34"}],
Cell[808407, 21312, 535, 11, 60, "DisplayFormula",
  CellTags->{"S1.5.6", "6.35"}],
Cell[808945, 21325, 1530, 35, 189, "Text",
  CellTags->{"S1.5.6", "6.36"}],
Cell[810478, 21362, 242, 10, 25, "Text",
  CellTags->{"S1.5.6", "6.37"}],
Cell[810723, 21374, 51, 1, 25, "Text",
  CellTags->{"S1.5.6", "6.38"}],
Cell[810777, 21377, 295, 13, 25, "Text",
  CellTags->{"S1.5.6", "6.39"}],
Cell[811075, 21392, 421, 11, 59, "Text",
  CellTags->{"S1.5.6", "6.40"}],
Cell[811499, 21405, 143, 4, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.41"}],

Cell[CellGroupData[{
Cell[811667, 21413, 96, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[811766, 21417, 328, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[812109, 21426, 199, 5, 42, "Text",
  CellTags->{"S1.5.6", "6.42"}],
Cell[812311, 21433, 181, 7, 25, "Text",
  CellTags->{"S1.5.6", "6.43"}],
Cell[812495, 21442, 202, 6, 25, "Text",
  CellTags->{"S1.5.6", "6.44"}],
Cell[812700, 21450, 288, 6, 65, "MathCaption",
  CellTags->{"S1.5.6", "6.45"}],

Cell[CellGroupData[{
Cell[813013, 21460, 85, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[813101, 21464, 2360, 187, 186, 2287, 184, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[815476, 21654, 373, 7, 59, "Text",
  CellTags->{"S1.5.6", "6.46"}],
Cell[815852, 21663, 310, 7, 45, "DisplayFormula",
  CellTags->{"S1.5.6", "6.47"}],
Cell[816165, 21672, 831, 27, 42, "Text",
  CellTags->{"S1.5.6", "6.48"}],
Cell[816999, 21701, 171, 4, 48, "MathCaption",
  CellTags->{"S1.5.6", "6.49"}],

Cell[CellGroupData[{
Cell[817195, 21709, 147, 5, 51, "Input",
  CellTags->"S1.5.6"],
Cell[817345, 21716, 323, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[817683, 21725, 115, 2, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.50"}],

Cell[CellGroupData[{
Cell[817823, 21731, 85, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[817911, 21735, 2004, 157, 186, 1931, 154, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[819930, 21895, 1061, 25, 152, "Text",
  CellTags->{"S1.5.6", "6.51"}],
Cell[820994, 21922, 132, 4, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.52"}],

Cell[CellGroupData[{
Cell[821151, 21930, 167, 5, 51, "Input",
  CellTags->"S1.5.6"],
Cell[821321, 21937, 329, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[821665, 21946, 242, 5, 42, "Text",
  CellTags->{"S1.5.6", "6.53"}],
Cell[821910, 21953, 99, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.54"}],

Cell[CellGroupData[{
Cell[822034, 21958, 85, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[822122, 21962, 2540, 202, 186, 2467, 199, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[824677, 22167, 266, 6, 59, "Text",
  CellTags->{"S1.5.6", "6.55"}],
Cell[824946, 22175, 158, 4, 48, "MathCaption",
  CellTags->{"S1.5.6", "6.56"}],

Cell[CellGroupData[{
Cell[825129, 22183, 121, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[825253, 22187, 317, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[825585, 22196, 91, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.57"}],

Cell[CellGroupData[{
Cell[825701, 22201, 90, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[825794, 22205, 317, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[826126, 22214, 162, 4, 48, "MathCaption",
  CellTags->{"S1.5.6", "6.58"}],

Cell[CellGroupData[{
Cell[826313, 22222, 85, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[826401, 22226, 1824, 142, 186, 1751, 139, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[828240, 22371, 165, 4, 48, "MathCaption",
  CellTags->{"S1.5.6", "6.59"}],

Cell[CellGroupData[{
Cell[828430, 22379, 154, 6, 71, "Input",
  CellTags->"S1.5.6"],
Cell[828587, 22387, 327, 6, 42, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[828929, 22396, 111, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.60"}],

Cell[CellGroupData[{
Cell[829065, 22401, 93, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[829161, 22405, 86, 3, 23, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[829262, 22411, 84, 1, 25, "Text",
  CellTags->{"S1.5.6", "6.61"}],
Cell[829349, 22414, 250, 10, 25, "Text",
  CellTags->{"S1.5.6", "6.62"}],
Cell[829602, 22426, 103, 1, 31, "MathCaption",
  CellTags->{"S1.5.6", "6.63"}],
Cell[829708, 22429, 102, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[829813, 22433, 181, 4, 48, "MathCaption",
  CellTags->{"S1.5.6", "6.64"}],

Cell[CellGroupData[{
Cell[830019, 22441, 79, 2, 31, "Input",
  CellTags->"S1.5.6"],
Cell[830101, 22445, 106, 3, 23, "Output",
  CellTags->"S1.5.6"]
}, Open  ]],
Cell[830222, 22451, 85, 1, 39, "Subsection",
  CellTags->{"S1.5.7", "7.1"}],
Cell[830310, 22454, 412, 10, 59, "Text",
  CellTags->{"S1.5.7", "7.2"}],
Cell[830725, 22466, 285, 13, 25, "Text",
  CellTags->{"S1.5.7", "7.3"}],
Cell[831013, 22481, 1178, 40, 59, "Text",
  CellTags->{"S1.5.7", "7.4"}],
Cell[832194, 22523, 107, 1, 31, "MathCaption",
  CellTags->{"S1.5.7", "7.5"}],
Cell[832304, 22526, 90, 2, 31, "Input",
  CellTags->"S1.5.7"],
Cell[832397, 22530, 176, 4, 48, "MathCaption",
  CellTags->{"S1.5.7", "7.6"}],

Cell[CellGroupData[{
Cell[832598, 22538, 320, 9, 131, "Input",
  CellTags->"S1.5.7"],
Cell[832921, 22549, 34562, 2231, 186, 34489, 2228, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],
Cell[867498, 24783, 4799, 140, 383, "Text",
  CellTags->{"S1.5.7", "7.7"}],
Cell[872300, 24925, 94, 1, 31, "MathCaption",
  CellTags->{"S1.5.7", "7.8"}],
Cell[872397, 24928, 89, 2, 31, "Input",
  CellTags->"S1.5.7"],
Cell[872489, 24932, 135, 4, 31, "MathCaption",
  CellTags->{"S1.5.7", "7.9"}],

Cell[CellGroupData[{
Cell[872649, 24940, 87, 2, 31, "Input",
  CellTags->"S1.5.7"],
Cell[872739, 24944, 192, 5, 57, "Message",
  CellTags->"S1.5.7"],
Cell[872934, 24951, 645, 11, 99, "Output",
  CellTags->"S1.5.7"]
}, Open  ]],
Cell[873594, 24965, 418, 14, 59, "Text",
  CellTags->{"S1.5.7", "7.10"}],
Cell[874015, 24981, 284, 8, 48, "MathCaption",
  CellTags->{"S1.5.7", "7.11"}],
Cell[874302, 24991, 114, 2, 31, "Input",
  CellTags->"S1.5.7"],
Cell[874419, 24995, 102, 1, 31, "MathCaption",
  CellTags->{"S1.5.7", "7.12"}],

Cell[CellGroupData[{
Cell[874546, 25000, 162, 5, 51, "Input",
  CellTags->"S1.5.7"],
Cell[874711, 25007, 20042, 1313, 186, 19969, 1310, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],
Cell[894768, 26323, 181, 4, 48, "MathCaption",
  CellTags->{"S1.5.7", "7.13"}],

Cell[CellGroupData[{
Cell[894974, 26331, 354, 10, 151, "Input",
  CellTags->"S1.5.7"],
Cell[895331, 26343, 67933, 4373, 70, 67860, 4370, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.7"]
}, Open  ]],
Cell[963279, 30719, 397, 14, 70, "Subsection",
  CellTags->{"S1.5.8", "8.1"}],
Cell[963679, 30735, 769, 17, 70, "Text",
  CellTags->{"S1.5.8", "8.2"}],
Cell[964451, 30754, 568, 25, 70, "Text",
  CellTags->{"S1.5.8", "8.3"}],
Cell[965022, 30781, 1347, 46, 70, "Text",
  CellTags->{"S1.5.8", "8.4"}],
Cell[966372, 30829, 250, 8, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.5"}],
Cell[966625, 30839, 152, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[966780, 30846, 75, 1, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.6"}],

Cell[CellGroupData[{
Cell[966880, 30851, 156, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[967039, 30858, 6544, 447, 70, 6471, 444, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[973598, 31308, 941, 27, 70, "Text",
  CellTags->{"S1.5.8", "8.7"}],
Cell[974542, 31337, 229, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.8"}],
Cell[974774, 31346, 103, 2, 70, "Input",
  CellTags->"S1.5.8"],
Cell[974880, 31350, 235, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.9"}],

Cell[CellGroupData[{
Cell[975140, 31361, 145, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[975288, 31368, 5291, 432, 70, 5218, 429, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[980594, 31803, 241, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.10"}],

Cell[CellGroupData[{
Cell[980860, 31814, 86, 2, 70, "Input",
  CellTags->"S1.5.8"],
Cell[980949, 31818, 88, 3, 70, "Output",
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[981052, 31824, 686, 17, 70, "Text",
  CellTags->{"S1.5.8", "8.11"}],
Cell[981741, 31843, 235, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.12"}],
Cell[981979, 31852, 101, 2, 70, "Input",
  CellTags->"S1.5.8"],
Cell[982083, 31856, 208, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.13"}],

Cell[CellGroupData[{
Cell[982316, 31867, 142, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[982461, 31874, 5387, 421, 70, 5314, 418, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[987863, 32298, 321, 8, 70, "Text",
  CellTags->{"S1.5.8", "8.14"}],
Cell[988187, 32308, 82, 1, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.15"}],
Cell[988272, 32311, 146, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[988421, 32318, 73, 1, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.16"}],

Cell[CellGroupData[{
Cell[988519, 32323, 156, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[988678, 32330, 8547, 574, 70, 8474, 571, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[997240, 32907, 198, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.17"}],
Cell[997441, 32916, 95, 2, 70, "Input",
  CellTags->"S1.5.8"],
Cell[997539, 32920, 86, 1, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.18"}],
Cell[997628, 32923, 139, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[997770, 32930, 224, 7, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.19"}],

Cell[CellGroupData[{
Cell[998019, 32941, 185, 6, 70, "Input",
  CellTags->"S1.5.8"],
Cell[998207, 32949, 4354, 315, 70, 4281, 312, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[1002576, 33267, 143, 5, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.20"}],
Cell[1002722, 33274, 143, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[1002868, 33281, 176, 4, 70, "MathCaption",
  CellTags->{"S1.5.8", "8.21"}],

Cell[CellGroupData[{
Cell[1003069, 33289, 154, 5, 70, "Input",
  CellTags->"S1.5.8"],
Cell[1003226, 33296, 1915, 128, 70, 1842, 125, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False,
  CellTags->"S1.5.8"]
}, Open  ]],
Cell[1005156, 33427, 213, 5, 70, "Text",
  CellTags->{"S1.5.8", "8.22"}]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

