(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    214302,      11972]*)
(*NotebookOutlinePosition[    238772,      12691]*)
(*  CellTagsIndexPosition[    235915,      12581]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.6 Biorthogonal Wavelets", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 1.6.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.6.1 Dual Bases",
    ButtonData:>{"Wavelets 1.6.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.6.2 Biorthogonal Wavelets",
    ButtonData:>{"Wavelets 1.6.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.6.3 Biorthogonal Spline Wavelets",
    ButtonData:>{"Wavelets 1.6.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.6.4 Biorthogonal Wavelet Transforms",
    ButtonData:>{"Wavelets 1.6.4"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["1.6 Biorthogonal Wavelets", "Section",
  CellTags->{"S1.6.0", "0.1"}],

Cell["\<\
As we know, a basis that spans a space does not have to be \
orthogonal. In order to gain greater flexibility in the construction of \
wavelet bases, we resort to relaxing the orthogonality condition and allowing \
nonorthogonal wavelet bases. For example, it is well\[Hyphen]known that the \
Haar wavelet is the only known wavelet that is compactly supported, \
orthogonal, and symmetric. In many applications, the symmetry of the filter \
coefficients is often desirable since it results in linear phase of the \
transfer function. So in order to construct more families of compactly \
supported, symmetric wavelets, in this section we forego the requirement of \
orthogonality, and, in particular, we introduce the so\[Hyphen]called \
biorthogonal wavelets. 
We begin this section with a brief review of the concepts of dual bases and \
dual space. Then we show how a biorthogonal wavelet basis arises from two \
multiresolution analyses. A particular biorthogonal wavelet basis called the \
biorthogonal spline wavelets is constructed and wavelet transforms using \
biorthogonal wavelets are demonstrated. \
\>", "Text",
  CellTags->{"S1.6.0", "0.2"}],

Cell["1.6.1 Dual Bases", "Subsection",
  CellTags->{"S1.6.1", "1.1"}],

Cell[TextData[{
  "Before we plunge into a discussion of biorthogonal wavelets, let us first \
review the concept of a dual basis. For simplicity, let us consider a two\
\[Hyphen]dimensional coordinate space. Any two vectors ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1, e\_2}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " that are not parallel can form a basis for the space. If the angle \
between the two vectors happens to be 90 degrees, we have an orthogonal \
basis. \nAny vector ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\& \[RightVector] \)\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " in this space can be written uniquely as a superposition of the two basis \
vectors: ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(A\& \[RightVector] \) = \(A\_1\) e\_1 + \(A\_2\) e\_2\)], 
    "InlineFormula",
    CellTags->"S1.6.1"],
  ". If the basis is orthogonal, we have ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\[CenterDot]e\_j = \[Delta]\_\(i  j\)\)], 
    "InlineFormula",
    CellTags->"S1.6.1"],
  ", and the component ",
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " along ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " is given by the inner product ",
  Cell[BoxData[
      \(TraditionalForm
      \`e\_i\[CenterDot]\(A\& \[RightVector] \) = \(A\_1\) 
        e\_i\[CenterDot]e\_1 + \(A\_2\) e\_i\[CenterDot]e\_2 = A\_i\)], 
    "InlineFormula",
    CellTags->"S1.6.1"],
  ". However, if the basis is not orthogonal, ",
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " is no longer given by the inner product of ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\& \[RightVector] \)\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ". In order to calculate the component ",
  Cell[BoxData[
      \(TraditionalForm\`A\_i\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ", we introduce another set of basis vectors ",
  Cell[BoxData[
      \(TraditionalForm\`{\(e\&~\)\_1, \(e\&~\)\_2}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ", called the dual of ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1, e\_2}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ". The dual basis satisfies "
}], "Text",
  CellTags->{"S1.6.1", "1.2"}],

Cell[BoxData[
    \(TraditionalForm\`\(e\&~\)\_i\[CenterDot]e\_j = \[Delta]\_\(i  j\)\)], 
  "DisplayFormula",
  CellTags->{"S1.6.1", "1.3"}],

Cell[TextData[{
  "and the space spanned by the dual basis is called the dual space of the \
original space. \nIn terms of the dual basis, the components of a vector \
along the basis ",
  Cell[BoxData[
      \(TraditionalForm\`{e\_1, e\_2}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " can be calculated as "
}], "Text",
  CellTags->{"S1.6.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(e\&~\)\_i\), "\[CenterDot]", \(A\& \[RightVector] \), "=", 
        UnderscriptBox["\[Sum]", "j",
          LimitsPositioning->True], \(A\_j\), \(\(e\&~\)\_i\), "\[CenterDot]",
         \(e\_j\), "=", \(A\_i\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.1", "1.5"}],

Cell[TextData[{
  "So we see that the introduction of the dual basis and dual space enables \
us to decompose a vector as a linear combination or superposition of \
nonorthogonal basis. Similarly, for a nonorthogonal basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_i\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " of a function space, we can introduce dual basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\(\[Phi]\&~\)\_i\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " by "
}], "Text",
  CellTags->{"S1.6.1", "1.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "\[LeftAngleBracket]", \(\(\[Phi]\&~\)\_i\), \(, \ \), \(\[Phi]\_j\), 
        "\[RightAngleBracket]", "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\(\(\(\[Phi]\&~\)\_i\) \((t)\)\)\&_\), \(\[Phi]\_j\), \((t)\), " ", 
        
        StyleBox[\("dt"\),
          "TI"], "=", \(\[Delta]\_\(i  j\)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.6.1", "1.7"}],

Cell[TextData[{
  "A function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " can be decomposed as a superposition of the nonorthogonal basis ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_i\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " using a set of dual basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\(\[Phi]\&~\)\_i\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ": "
}], "Text",
  CellTags->{"S1.6.1", "1.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "i",
          LimitsPositioning->True], \(f\_i\), " ", \(\[Phi]\_i\), \((t)\), 
        "=", 
        UnderscriptBox["\[Sum]", "i",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\(\[Phi]\&~\)\_i\), \(, \ \ \), "f", "\[RightAngleBracket]", 
        \(\[Phi]\_i\), \((t)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.1", "1.9"}],

Cell[TextData[{
  "We will tacitly assume that the function space and its dual are the same, \
a condition satisfied by ",
  Cell[BoxData[
      \(TraditionalForm\`L\^2\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ". Therefore, the roles of dual basis and the original basis can be \
interchanged and we obtain "
}], "Text",
  CellTags->{"S1.6.1", "1.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{"f", \((t)\), "=", 
        UnderscriptBox["\[Sum]", "i",
          LimitsPositioning->True], "\[LeftAngleBracket]", \(\[Phi]\_i\), \(, 
        \ \ \), "f", "\[RightAngleBracket]", \(\(\[Phi]\&~\)\_i\), \((t)\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.1", "1.11"}],

Cell[TextData[{
  "When ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_i\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.1"],
  " is orthogonal, we have the obvious relation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\) = \[Phi]\)], "InlineFormula",
    CellTags->"S1.6.1"],
  ". "
}], "Text",
  CellTags->{"S1.6.1", "1.12"}],

Cell["1.6.2 Biorthogonal Wavelets", "Subsection",
  CellTags->{"S1.6.2", "2.1"}],

Cell[TextData[{
  "Recall that the dilations and translations of the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Phi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " constitute a basis for ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and, similarly, ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_\(j  k\)\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`W\_j\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ". We will now focus our attention on the case that they are not \
orthogonal. We seek to define a dual multiresolution analysis with dual \
subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{\(V\&~\)\_j}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(W\&~\)\_j}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " generated from a dual scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and a dual mother wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ", respectively. This is to be done so that instead of ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Phi]\_\(j  k\)\) , \  
        \[Phi]\_\(j  l\)\[RightAngleBracket] = \[Delta]\_\(k  l\)\)], 
    "InlineFormula",
    CellTags->"S1.6.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Psi]\_\(j  k\)\) , \  
        \[Psi]\_\(\(j\^\[Prime]\) l\)\[RightAngleBracket] = 
        \(\[Delta]\_\(j  j\^\[Prime]\)\) \[Delta]\_\(k  l\)\)], 
    "InlineFormula",
    CellTags->"S1.6.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftAngleBracket]\(\[Phi]\_\(j  k\)\) , \  
        \[Psi]\_\(j  l\)\[RightAngleBracket] = 0\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " as in an orthogonal case, we now have (see Cohen (1992), Daubechies \
(1992), and Jawerth and Sweldens (1994)) "
}], "Text",
  CellTags->{"S1.6.2", "2.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\(\(\[Phi]\&~\)\_\(j  k\)\) , \  
      \[Phi]\_\(j  l\)\[RightAngleBracket] = \(\[Delta]\_\(k  l\)\) "and" 
      \[LeftAngleBracket]\(\(\[Psi]\&~\)\_\(j  k\)\) , \  
      \[Psi]\_\(\(j\^\[Prime]\) l\)\[RightAngleBracket] = 
      \(\[Delta]\_\(j  j\^\[Prime]\)\) \[Delta]\_\(k  l\), \)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.3"}],

Cell["and ", "Text",
  CellTags->{"S1.6.2", "2.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftAngleBracket]\(\(\[Psi]\&~\)\_\(j  k\)\) , \  
      \[Phi]\_\(j  l\)\[RightAngleBracket] = 0\ \ \  " and "\ \ \ 
      \[LeftAngleBracket]\(\(\[Phi]\&~\)\_\(j  k\)\) , \  
      \[Psi]\_\(j  l\)\[RightAngleBracket] = 0, \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.5"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Phi]\&~\)\_\(j  k\) = \(2\^\(j/2\)\) \(\[Phi]\&~\) \((
        \(2\^j\) t - k)\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[Psi]\&~\)\_\(j  k\) = \(2\^\(j/2\)\) \(\[Psi]\&~\) \((
        \(2\^j\) t - k)\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ". These sets constitute bases for the dual subspaces ",
  Cell[BoxData[
      \(TraditionalForm\`{\(V\&~\)\_j}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(W\&~\)\_j}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ". The conditions displayed above are referred to as biorthogonality \
conditions and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " biorthogonal wavelets. In terms of subspaces, the above biorthogonality \
conditions can be expressed as "
}], "Text",
  CellTags->{"S1.6.2", "2.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`V\_j \[UpTee] \(\(W\&~\)\_j\) \(, \ \ \ \) \(V\&~\)\_j \[UpTee] 
      W\_j\ \ \ " and "\ \ \ W\_j \[UpTee] \(W\&~\)\_\(j\^\[Prime]\)\ \ 
      " for "\ \ j \[NotEqual] j\^\[Prime].\)], "DisplayFormula",
  CellTags->{"S1.6.2", "2.7"}],

Cell["\<\
By definition, a scaling function and a mother wavelet satisfy the \
dilation equation and the wavelet equation, respectively. So we have \
\>", 
  "Text",
  CellTags->{"S1.6.2", "2.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  t - k)\), "   ",
         \(" and "\), "   ", "\[Psi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\), ","}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.9"}],

Cell["and ", "Text",
  CellTags->{"S1.6.2", "2.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\&~\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(\(h\&~\)\_k\), \(\[Phi]\&~\), \((
        2  t - k)\), "   ", \(" and "\), "   ", \(\[Psi]\&~\), \((t)\), "=", 
        \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(\(g\&~\)\_k\), \(\[Phi]\&~\), \((
        2  t - k)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.11"}],

Cell["\<\
The coefficients in the above equations can be obtained by taking \
the inner product with the appropriate dual function. For example, \
\>", 
  "Text",
  CellTags->{"S1.6.2", "2.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(h\_k\), "=", "\[LeftAngleBracket]", \(\(\[Phi]\&~\)\_\(1, k\)\), \(, 
        \ \), "\[Phi]", "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\(\(\[Phi]\&~\) \((2  t - k)\)\)\&_\), "\[Phi]", \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], \("and"\), \(g\_k\), "=", "\[LeftAngleBracket]", 
        \(\(\[Phi]\&~\)\_\(1, k\)\), \(, \ \), "\[Psi]", 
        "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\(\(\[Phi]\&~\) \((2  t - k)\)\)\&_\), "\[Psi]", \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.2", "2.13"}],

Cell[TextData[{
  "The roles of the two functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " can be interchanged. Or if we \"take the dual\" of the above equations \
(define ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\&~\)\&~\) = a\)], "InlineFormula",
    CellTags->"S1.6.2"],
  "), we obtain the following relations, "
}], "Text",
  CellTags->{"S1.6.2", "2.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\(h\&~\)\_k\), "=", "\[LeftAngleBracket]", \(\[Phi]\_\(1, k\)\), \(, 
        \ \), \(\[Phi]\&~\), "\[RightAngleBracket]", "=", \(\@2\), 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\(\[Phi] \((2  t - k)\)\)\&_\), \(\[Phi]\&~\), \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], \("and"\), \(\(g\&~\)\_k\), "=", "\[LeftAngleBracket]", 
        \(\[Phi]\_\(1, k\)\), \(, \ \), \(\[Psi]\&~\), "\[RightAngleBracket]",
         "=", \(\@2\), \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
        \(\(\[Phi] \((2  t - k)\)\)\&_\), \(\[Psi]\&~\), \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.2", "2.15"}],

Cell[TextData[{
  "In frequency space, the above dilation and wavelet equations (",
  ButtonBox["6.3",
    ButtonData:>{"Wavelets 1.6.2", "2.9"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["6.4",
    ButtonData:>{"Wavelets 1.6.2", "2.11"},
    ButtonStyle->"AddOnsLink"],
  ") assume the form "
}], "Text",
  CellTags->{"S1.6.2", "2.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\[Phi]\&^\) \((\[Omega])\) = H \((\[Omega]\/2)\) \(\[Phi]\&^\) \((
      \[Omega]\/2)\)\ \ \ " and "\ \ \ \(\[Psi]\&^\) \((\[Omega])\) = G \((
      \[Omega]\/2)\) \(\[Phi]\&^\) \((\[Omega]\/2)\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.17"}],

Cell["and ", "Text",
  CellTags->{"S1.6.2", "2.18"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Phi]\&~\)\&^\) \((\[Omega])\) = \(H\&~\) \((\[Omega]\/2)\) 
      \(\(\[Phi]\&~\)\&^\) \((\[Omega]\/2)\)\ \ \ " and "\ \ \ 
      \(\(\[Psi]\&~\)\&^\) \((\[Omega])\) = \(G\&~\) \((\[Omega]\/2)\) 
      \(\(\[Phi]\&~\)\&^\) \((\[Omega]\/2)\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.19"}],

Cell[TextData[{
  "As before, ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " is defined by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"H", \((\[Omega])\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(h\_k\), \(e\^\(-i  k  \[Omega]\)\), 
          "/", \(\@2\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.6.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`G \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\&~\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(G\&~\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " are defined analogously. Following the same derivations as in Section ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.1"},
    ButtonStyle->"AddOnsLink"],
  ", the biorthogonality conditions (",
  ButtonBox["6.1",
    ButtonData:>{"Wavelets 1.6.2", "2.3"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.5"},
    ButtonStyle->"AddOnsLink"],
  ") in frequency space can be shown to be "
}], "Text",
  CellTags->{"S1.6.2", "2.20"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(\(\[Phi]\&~\)\&^\), \((
        \[Omega] + 2  \[Pi]  l)\), 
        \(\(\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\), "=", \(1\ \ \ 
        \), \(" and "\), "   ", 
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(\(\[Psi]\&~\)\&^\), \((
        \[Omega] + 2  \[Pi]  l)\), 
        \(\(\(\[Psi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\), "=", "1", 
        ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.2", "2.21"}],

Cell["and ", "Text",
  CellTags->{"S1.6.2", "2.22"}],

Cell[BoxData[
    FormBox[
      RowBox[{
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(\(\[Psi]\&~\)\&^\), \((
        \[Omega] + 2  \[Pi]  l)\), 
        \(\(\(\[Phi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\), "=", \(0\ \ \ 
        \), \(" and "\), "   ", 
        UnderoverscriptBox["\[Sum]", \(l = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(\(\[Phi]\&~\)\&^\), \((
        \[Omega] + 2  \[Pi]  l)\), 
        \(\(\(\[Psi]\&^\) \((\[Omega] + 2  \[Pi]  l)\)\)\&_\), "=", "0."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.2", "2.23"}],

Cell[TextData[{
  "Again, these biorthogonality conditions can be translated into conditions \
on the filter coefficients using the dilation and wavelet equations (",
  ButtonBox["6.5",
    ButtonData:>{"Wavelets 1.6.2", "2.17"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["6.6",
    ButtonData:>{"Wavelets 1.6.2", "2.19"},
    ButtonStyle->"AddOnsLink"],
  "). These conditions are "
}], "Text",
  CellTags->{"S1.6.2", "2.24"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(H\&~\) \((\[Omega])\) \(H \((\[Omega])\)\)\&_ + \(H\&~\) \((
      \[Omega] + \[Pi])\) \(H \((\[Omega] + \[Pi])\)\)\&_ = \(1\ \ \ \) 
      " and "\ \ \ \(G\&~\) \((\[Omega])\) \(G \((\[Omega])\)\)\&_ + \(G\&~\) 
      \((\[Omega] + \[Pi])\) \(G \((\[Omega] + \[Pi])\)\)\&_ = 1, \)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.25"}],

Cell["and ", "Text",
  CellTags->{"S1.6.2", "2.26"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(G\&~\) \((\[Omega])\) \(H \((\[Omega])\)\)\&_ + \(G\&~\) \((
      \[Omega] + \[Pi])\) \(H \((\[Omega] + \[Pi])\)\)\&_ = \(0\ \ \ \) 
      " and "\ \ \ \(H\&~\) \((\[Omega])\) \(G \((\[Omega])\)\)\&_ + \(H\&~\) 
      \((\[Omega] + \[Pi])\) \(G \((\[Omega] + \[Pi])\)\)\&_ = 0.\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.27"}],

Cell[TextData[{
  "The above equations (",
  ButtonBox["6.8",
    ButtonData:>{"Wavelets 1.6.2", "2.27"},
    ButtonStyle->"AddOnsLink"],
  ") can be satisfied if we choose "
}], "Text",
  CellTags->{"S1.6.2", "2.28"}],

Cell[BoxData[
    \(TraditionalForm
    \`G \((\[Omega])\) = -\(e\^\(-i  \[Omega]\)\) 
      \(\(H\&~\) \((\[Omega] + \[Pi])\)\)\&_\ \ \ " and "\ \ \ \(G\&~\) \((
      \[Omega])\) = -\(e\^\(-i  \[Omega]\)\) \(H \((\[Omega] + \[Pi])\)\)\&_, 
      \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.29"}],

Cell["or ", "Text",
  CellTags->{"S1.6.2", "2.30"}],

Cell[BoxData[
    \(TraditionalForm
    \`g\_n = \(\((\(-1\))\)\^n\) \(h\&~\)\_\(1 - n\)\ \ \ " and "\ \ \ 
      \(g\&~\)\_n = \(\((\(-1\))\)\^n\) h\_\(1 - n\).\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.10) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.31"}],

Cell[TextData[{
  "Note that in the case of orthogonal wavelets, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\) = \[Phi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\) = \[Psi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and the biorthogonality conditions reduce to the familiar orthogonality \
conditions. \nIn Section ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ", we saw that the orthogonal wavelets are constructed by solving the \
filter coefficients such that the orthogonality and moment conditions are \
satisfied. Here we can analogously construct biorthogonal wavelets by solving \
for the filter coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_n}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(h\&~\)\_n}\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " such that the biorthogonality condition (",
  ButtonBox["6.7",
    ButtonData:>{"Wavelets 1.6.2", "2.25"},
    ButtonStyle->"AddOnsLink"],
  ") and certain moment conditions are satisfied. In addition, we will also \
use our new freedom to require that the filter be symmetric, say, about 0 \
(when the filter length is odd) or 1/2 (when the filter length is even), that \
is, ",
  Cell[BoxData[
      \(TraditionalForm\`h\_n = h\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\_\(1 + n\) = h\_\(-n\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] 0\)], "InlineFormula",
    CellTags->"S1.6.2"],
  "), respectively. This symmetry condition implies that the transfer \
function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " (or ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\&~\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ") is real and a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`cos  \[Omega]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " for odd\[Hyphen]length filters and ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\^\(i  \[Omega]/2\)\) cos  \[Omega]/2\)], 
    "InlineFormula",
    CellTags->"S1.6.2"],
  " times a real polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`cos  \[Omega]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " for even\[Hyphen]length filters. Furthermore, if we require that the \
first ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2  l\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " moments of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " vanish, the polynomial should contain a factor ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((1 + cos  \[Omega])\)\^l = \(cos\^\(2  l\)\) \[Omega]/2\)], 
    "InlineFormula",
    CellTags->"S1.6.2"],
  ". Therefore, we look for ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\&~\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " that satisfy the biorthogonality condition (",
  ButtonBox["6.7",
    ButtonData:>{"Wavelets 1.6.2", "2.25"},
    ButtonStyle->"AddOnsLink"],
  ") and are of the form (see Daubechies (1992)) "
}], "Text",
  CellTags->{"S1.6.2", "2.32"}],

Cell[BoxData[
    \(TraditionalForm
    \`H \((\[Omega])\) = \(e\^\(-i  \[Kappa]\[Omega]/2\)\) 
      \(\((cos  \[Omega]\/2)\)\^\(N + \[Kappa]\)\) \(q\_0\) \((cos  \[Omega])
      \)\ \ \ " and "\ \ \ \(H\&~\) \((\[Omega])\) = 
      \(e\^\(-i  \[Kappa]\[Omega]/2\)\) 
      \(\((cos  \[Omega]\/2)\)\^\(\(N\&~\) + \[Kappa]\)\) \(\(q\&~\)\_0\) \((
      cos  \[Omega])\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.11) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.2", "2.33"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2  l\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) = 2 \( l\&~\)\)], "InlineFormula",
    CellTags->"S1.6.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 0\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " if the length of the filter is odd and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " if it is even. Both ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(q\&~\)\_0\)], "InlineFormula",
    CellTags->"S1.6.2"],
  " are polynomials of their arguments. As in the orthogonal case, we \
substitute (",
  ButtonBox["6.11",
    ButtonData:>{"Wavelets 1.6.2", "2.33"},
    ButtonStyle->"AddOnsLink"],
  ") into the first equation of (",
  ButtonBox["6.7",
    ButtonData:>{"Wavelets 1.6.2", "2.25"},
    ButtonStyle->"AddOnsLink"],
  ") and solve for the filter coefficients. (It can be shown that the second \
equations of (",
  ButtonBox["6.7",
    ButtonData:>{"Wavelets 1.6.2", "2.25"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["6.8",
    ButtonData:>{"Wavelets 1.6.2", "2.27"},
    ButtonStyle->"AddOnsLink"],
  ") do not impose any more constraints once we choose the filter \
coefficients to satisfy (",
  ButtonBox["6.9",
    ButtonData:>{"Wavelets 1.6.2", "2.29"},
    ButtonStyle->"AddOnsLink"],
  ").) In contrast to the construction of orthogonal wavelets, here we do not \
need to do spectral factorization. We have two filters to solve and we have \
the freedom to choose one filter and solve for the other. This renders the \
solving for biorthogonal wavelet filters easier. "
}], "Text",
  CellTags->{"S1.6.2", "2.34"}],

Cell["1.6.3 Biorthogonal Spline Wavelets", "Subsection",
  CellTags->{"S1.6.3", "3.1"}],

Cell[TextData[{
  "We illustrate the procedure outlined above by explicitly constructing an \
example of biorthogonal wavelets. We choose the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(q\&~\)\_0\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " in (",
  ButtonBox["6.11",
    ButtonData:>{"Wavelets 1.6.2", "2.33"},
    ButtonStyle->"AddOnsLink"],
  ") to be the simplest possible ",
  Cell[BoxData[
      \(TraditionalForm\`\(q\&~\)\_0 = 1\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and obtain"
}], "Text",
  CellTags->{"S1.6.3", "3.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(H\&~\), \((\[Omega])\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox[\(\((cos \[Omega]\/2)\)\^\(N\&~\)\),
                  "DisplayFormula"], 
                StyleBox[\(\ \ \ \(N\&~\) = 2 \(l\&~\)\),
                  "DisplayFormula"]},
              {
                
                StyleBox[
                  \(\(e\^\(-i \(\[Omega]\/2\)\)\) 
                    \((cos \[Omega]\/2)\)\^\(N\&~\)\),
                  "DisplayFormula"], 
                StyleBox[\(\ \ \ \(N\&~\) = 2 \(l\&~\) + 1.\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.12) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.3", "3.3"}],

Cell[TextData[{
  "This, in fact, amounts to choosing ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " to be a ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) - 1\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " since the Fourier transform of a ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "\[Hyphen]spline function is given by (see (",
  ButtonBox["3.4",
    ButtonData:>{"Wavelets 1.3.1", "1.34"},
    ButtonStyle->"AddOnsLink"],
  ")) "
}], "Text",
  CellTags->{"S1.6.3", "3.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\[Phi]\&~\)\&^\) \((\[Omega])\) = \(e\^\(-i  \[Kappa]\[Omega]/2\)\) 
      \((\(sin  \[Omega]/2\)\/\(\[Omega]/2\))\)\^\(N\&~\) = 
      \(e\^\(-i  \[Kappa]\[Omega]/4\)\) \(\((cos  \[Omega]\/2)\)\^\(N\&~\)\) 
      \(e\^\(-i  \[Kappa]\[Omega]/4\)\) 
      \((\(sin  \[Omega]/4\)\/\(\[Omega]/4\))\)\^\(N\&~\) = \(H\&~\) \((
      \[Omega]\/2)\) \(\(\[Phi]\&~\)\&^\) \((\[Omega]\/2)\)\)], 
  "DisplayFormula",
  CellTags->{"S1.6.3", "3.5"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 0\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is even and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is odd, and we see that the transfer function is precisely (",
  ButtonBox["6.12",
    ButtonData:>{"Wavelets 1.6.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "). \nWith the form of ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " given in (",
  ButtonBox["6.12",
    ButtonData:>{"Wavelets 1.6.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  "), we can solve for ",
  Cell[BoxData[
      \(TraditionalForm\`H\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " using (",
  ButtonBox["6.7",
    ButtonData:>{"Wavelets 1.6.2", "2.25"},
    ButtonStyle->"AddOnsLink"],
  "). As in Section ",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 1.4"},
    ButtonStyle->"AddOnsLink"],
  ", the solution is "
}], "Text",
  CellTags->{"S1.6.3", "3.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{"H", \((\[Omega])\), "=", \(\((cos  \[Omega]\/2)\)\^N\), 
        UnderoverscriptBox["\[Sum]", \(m = 0\), \(l + \(l\&~\) - 1\),
          LimitsPositioning->True], 
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(l + \(l\&~\) - 1 + m\),
                  "DisplayFormula"]},
              {
                StyleBox["m",
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], ")"}], 
        \(\((\(sin\^2\) \[Omega]\/2)\)\^m\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.6.3", "3.7"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`N \((\( = 2  l\))\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) \((\( = 2 \( l\&~\)\))\)\)], 
    "InlineFormula",
    CellTags->"S1.6.3"],
  " are even and "
}], "Text",
  CellTags->{"S1.6.3", "3.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      "H", \((\[Omega])\), "=", \(e\^\(-i  \[Omega]/2\)\), 
        \(\((cos  \[Omega]\/2)\)\^N\), 
        UnderoverscriptBox["\[Sum]", \(m = 0\), \(l + \(l\&~\)\),
          LimitsPositioning->True], 
        RowBox[{"(", GridBox[{
              {
                StyleBox[\(l + \(l\&~\) + m\),
                  "DisplayFormula"]},
              {
                StyleBox["m",
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Center}], ")"}], 
        \(\((\(sin\^2\) \[Omega]\/2)\)\^m\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.6.3", "3.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`N \((\( = 2  l + 1\))\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) \((\( = 2 \( l\&~\) + 1\))\)\)], 
    "InlineFormula",
    CellTags->"S1.6.3"],
  " are odd. The filters so obtained are called biorthogonal spline filters. \
\nTherefore, for a given ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " (",
  StyleBox["i.e.", "TI"],
  ", for a given ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "), we can choose different ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " (subject to certain technical requirements, see Daubechies (1992)) and \
thereby obtain corresponding ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ". Once the transfer function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is known, the filter coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`h\_k\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is obtained by extracting the coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(-i  k  \[Omega]\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ". The function "
}], "Text",
  CellTags->{"S1.6.3", "3.10"}],

Cell[TextData[{
  StyleBox["BiorthogonalSplineFilter[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["nt", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.6.3", "3.11"}],

Cell[TextData[{
  "gives the biorthogonal spline filter coefficients of order ",
  Cell[BoxData[
      \(TraditionalForm\`{N, \(N\&~\)}\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("nt"\),
            "TI"], "=", \(N\&~\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S1.6.3"],
  "). The output is in the form "
}], "Text",
  CellTags->{"S1.6.3", "3.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{{h\_\(-m\), h\_\(-m + 1\), h\_\(-m + 2\), \[Ellipsis]}, -
          m}, {{\(h\&~\)\_\(-\(m\&~\)\), \(h\&~\)\_\(-\(m\&~\) + 1\), 
            \(h\&~\)\_\(-\(m\&~\) + 2\), \[Ellipsis]}, -\(m\&~\)}}.\)\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(6.13) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.6.3", "3.13"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S1.6.3", "3.14"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.6.3"],

Cell[TextData[{
  "This is the biorthogonal spline filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`{3, 1}\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.15"}],

Cell[CellGroupData[{

Cell["b31 = BiorthogonalSplineFilter[3, 1]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.6.3"],

Cell[BoxData[
    \({{{\(-\(1\/\(8\ \@2\)\)\), 1\/\(8\ \@2\), 1\/\@2, 1\/\@2, 
          1\/\(8\ \@2\), \(-\(1\/\(8\ \@2\)\)\)}, \(-2\)}, {{1\/\@2, 1\/\@2}, 
        0}}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "We can use the functions ",
  StyleBox["ScalingFunction", "MR"],
  " and ",
  StyleBox["Wavelet", "MR"],
  " as before to plot the biorthogonal scaling functions and wavelets. For \
example, here we plot the biorthogonal spline scaling functions and wavelets \
of order ",
  Cell[BoxData[
      \(TraditionalForm\`{3, 1}\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ". "
}], "Text",
  CellTags->{"S1.6.3", "3.16"}],

Cell[TextData[{
  "We use the approximate numerical values for the filter to speed up the \
calculation. (We can also simply use ",
  StyleBox["N[b31]", "MR"],
  " to get the numerical values of the filter.)"
}], "MathCaption",
  CellTags->{"S1.6.3", "3.17"}],

Cell[CellGroupData[{

Cell["b31 = MapAt[N, #, 1]& /@ b31", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.6.3"],

Cell[BoxData[
    \({{{\(-0.0883883476483184438`\), 0.0883883476483184438`, 
          0.70710678118654755`, 0.70710678118654755`, 0.0883883476483184438`, 
          \(-0.0883883476483184438`\)}, 
        \(-2\)}, {{0.70710678118654755`, 0.70710678118654755`}, 0}}\)], 
  "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "This gives the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " at dyadic points."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.18"}],

Cell["phi = ScalingFunction[b31, 5];", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.6.3"],

Cell[TextData[{
  "The function is symmetric about ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.19"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[phi, AxesLabel -> {\"t\", \"phi(t)\"},
PlotJoined -> True, PlotRange -> All];\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.6.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.084748 0.452571 [
[.02381 .07225 -6 -9 ]
[.02381 .07225 6 0 ]
[.21429 .07225 -6 -9 ]
[.21429 .07225 6 0 ]
[.59524 .07225 -3 -9 ]
[.59524 .07225 3 0 ]
[.78571 .07225 -3 -9 ]
[.78571 .07225 3 0 ]
[.97619 .07225 -3 -9 ]
[.97619 .07225 3 0 ]
[1.025 .08475 0 -4.5 ]
[1.025 .08475 6 4.5 ]
[.39226 .17526 -18 -4.5 ]
[.39226 .17526 0 4.5 ]
[.39226 .26578 -18 -4.5 ]
[.39226 .26578 0 4.5 ]
[.39226 .35629 -18 -4.5 ]
[.39226 .35629 0 4.5 ]
[.39226 .4468 -18 -4.5 ]
[.39226 .4468 0 4.5 ]
[.39226 .53732 -6 -4.5 ]
[.39226 .53732 0 4.5 ]
[.40476 .64303 -18 0 ]
[.40476 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .08475 m
.02381 .091 L
s
[(-2)] .02381 .07225 0 1 Mshowa
.21429 .08475 m
.21429 .091 L
s
[(-1)] .21429 .07225 0 1 Mshowa
.59524 .08475 m
.59524 .091 L
s
[(1)] .59524 .07225 0 1 Mshowa
.78571 .08475 m
.78571 .091 L
s
[(2)] .78571 .07225 0 1 Mshowa
.97619 .08475 m
.97619 .091 L
s
[(3)] .97619 .07225 0 1 Mshowa
.125 Mabswid
.0619 .08475 m
.0619 .0885 L
s
.1 .08475 m
.1 .0885 L
s
.1381 .08475 m
.1381 .0885 L
s
.17619 .08475 m
.17619 .0885 L
s
.25238 .08475 m
.25238 .0885 L
s
.29048 .08475 m
.29048 .0885 L
s
.32857 .08475 m
.32857 .0885 L
s
.36667 .08475 m
.36667 .0885 L
s
.44286 .08475 m
.44286 .0885 L
s
.48095 .08475 m
.48095 .0885 L
s
.51905 .08475 m
.51905 .0885 L
s
.55714 .08475 m
.55714 .0885 L
s
.63333 .08475 m
.63333 .0885 L
s
.67143 .08475 m
.67143 .0885 L
s
.70952 .08475 m
.70952 .0885 L
s
.74762 .08475 m
.74762 .0885 L
s
.82381 .08475 m
.82381 .0885 L
s
.8619 .08475 m
.8619 .0885 L
s
.9 .08475 m
.9 .0885 L
s
.9381 .08475 m
.9381 .0885 L
s
.25 Mabswid
0 .08475 m
1 .08475 L
s
[(t)] 1.025 .08475 -1 0 Mshowa
.40476 .17526 m
.41101 .17526 L
s
[(0.2)] .39226 .17526 1 0 Mshowa
.40476 .26578 m
.41101 .26578 L
s
[(0.4)] .39226 .26578 1 0 Mshowa
.40476 .35629 m
.41101 .35629 L
s
[(0.6)] .39226 .35629 1 0 Mshowa
.40476 .4468 m
.41101 .4468 L
s
[(0.8)] .39226 .4468 1 0 Mshowa
.40476 .53732 m
.41101 .53732 L
s
[(1)] .39226 .53732 1 0 Mshowa
.125 Mabswid
.40476 .10738 m
.40851 .10738 L
s
.40476 .13001 m
.40851 .13001 L
s
.40476 .15263 m
.40851 .15263 L
s
.40476 .19789 m
.40851 .19789 L
s
.40476 .22052 m
.40851 .22052 L
s
.40476 .24315 m
.40851 .24315 L
s
.40476 .2884 m
.40851 .2884 L
s
.40476 .31103 m
.40851 .31103 L
s
.40476 .33366 m
.40851 .33366 L
s
.40476 .37892 m
.40851 .37892 L
s
.40476 .40155 m
.40851 .40155 L
s
.40476 .42418 m
.40851 .42418 L
s
.40476 .46943 m
.40851 .46943 L
s
.40476 .49206 m
.40851 .49206 L
s
.40476 .51469 m
.40851 .51469 L
s
.40476 .06212 m
.40851 .06212 L
s
.40476 .03949 m
.40851 .03949 L
s
.40476 .01686 m
.40851 .01686 L
s
.40476 .55995 m
.40851 .55995 L
s
.40476 .58258 m
.40851 .58258 L
s
.40476 .6052 m
.40851 .6052 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(phi\\(t\\))] .40476 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .08475 m
.02976 .08475 L
.03571 .08474 L
.04167 .08474 L
.04762 .08482 L
.05357 .08487 L
.05952 .08483 L
.06548 .08469 L
.07143 .08416 L
.07738 .08368 L
.08333 .08374 L
.08929 .08398 L
.09524 .08409 L
.10119 .08446 L
.10714 .08524 L
.1131 .08652 L
.11905 .08946 L
.125 .09229 L
.13095 .09328 L
.1369 .09351 L
.14286 .09278 L
.14881 .09168 L
.15476 .09087 L
.16071 .09007 L
.16667 .09005 L
.17262 .08956 L
.17857 .08706 L
.18452 .08374 L
.19048 .08084 L
.19643 .07667 L
.20238 .07058 L
.20833 .06223 L
.21429 .04703 L
.22024 .03206 L
.22619 .0244 L
.23214 .01942 L
.2381 .01654 L
.24405 .01547 L
.25 .01472 L
.25595 .01552 L
.2619 .01993 L
.26786 .02509 L
.27381 .02831 L
.27976 .03142 L
.28571 .0351 L
.29167 .03877 L
.29762 .04263 L
.30357 .04618 L
.30952 .04703 L
.31548 .04879 L
Mistroke
.32143 .05482 L
.32738 .06309 L
.33333 .07429 L
.33929 .08675 L
.34524 .09891 L
.35119 .11131 L
.35714 .12128 L
.3631 .13307 L
.36905 .15169 L
.375 .1733 L
.38095 .19421 L
.3869 .21941 L
.39286 .25072 L
.39881 .28924 L
.40476 .34875 L
.41071 .40804 L
.41667 .44587 L
.42262 .47607 L
.42857 .4999 L
.43452 .51892 L
.44048 .53802 L
.44643 .55347 L
.45238 .56089 L
.45833 .56615 L
.46429 .57448 L
.47024 .58248 L
.47619 .59006 L
.48214 .59648 L
.4881 .60034 L
.49405 .60253 L
.5 .60332 L
.50595 .60253 L
.5119 .60034 L
.51786 .59648 L
.52381 .59006 L
.52976 .58248 L
.53571 .57448 L
.54167 .56615 L
.54762 .56089 L
.55357 .55347 L
.55952 .53802 L
.56548 .51892 L
.57143 .4999 L
.57738 .47607 L
.58333 .44587 L
.58929 .40804 L
.59524 .34875 L
.60119 .28924 L
.60714 .25072 L
.6131 .21941 L
Mistroke
.61905 .19421 L
.625 .1733 L
.63095 .15169 L
.6369 .13307 L
.64286 .12128 L
.64881 .11131 L
.65476 .09891 L
.66071 .08675 L
.66667 .07429 L
.67262 .06309 L
.67857 .05482 L
.68452 .04879 L
.69048 .04703 L
.69643 .04618 L
.70238 .04263 L
.70833 .03877 L
.71429 .0351 L
.72024 .03142 L
.72619 .02831 L
.73214 .02509 L
.7381 .01993 L
.74405 .01552 L
.75 .01472 L
.75595 .01547 L
.7619 .01654 L
.76786 .01942 L
.77381 .0244 L
.77976 .03206 L
.78571 .04703 L
.79167 .06223 L
.79762 .07058 L
.80357 .07667 L
.80952 .08084 L
.81548 .08374 L
.82143 .08706 L
.82738 .08956 L
.83333 .09005 L
.83929 .09007 L
.84524 .09087 L
.85119 .09168 L
.85714 .09278 L
.8631 .09351 L
.86905 .09328 L
.875 .09229 L
.88095 .08946 L
.8869 .08652 L
.89286 .08524 L
.89881 .08446 L
.90476 .08409 L
.91071 .08398 L
Mistroke
.91667 .08374 L
.92262 .08368 L
.92857 .08416 L
.93452 .08469 L
.94048 .08483 L
.94643 .08487 L
.95238 .08482 L
.95833 .08474 L
.96429 .08474 L
.97024 .08475 L
.97619 .08475 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "We could have just used ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " as our input and get the same result."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.20"}],

Cell[CellGroupData[{

Cell["ScalingFunction[b31[[1]], 5] == phi", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.6.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "Note that in calculating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ", only the filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is used. In contrast, the calculation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " requires both the filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "; this is evident since ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", \((t)\), "=", 
          UnderscriptBox["\[Sum]", "k",
            LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\)}], 
        TraditionalForm]], "InlineFormula",
    CellTags->"S1.6.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is used to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and the highpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " is obtained from the filter ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " as can be seen from (",
  ButtonBox["6.10",
    ButtonData:>{"Wavelets 1.6.2", "2.31"},
    ButtonStyle->"AddOnsLink"],
  "). Therefore, we must provide both ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " to calculate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ". "
}], "Text",
  CellTags->{"S1.6.3", "3.21"}],

Cell[TextData[{
  "This gives the biorthogonal wavelet function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.22"}],

Cell["psi = Wavelet[b31, 5, Interpolation -> True];", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.6.3"],

Cell["\<\
This plots of the basic wavelet and its translated and dilated \
version.\
\>", "MathCaption",
  CellTags->{"S1.6.3", "3.23"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{psi[t], psi[2t-2]}, {t, -1, 2}, PlotRange -> All,
AxesLabel -> {\"t\", \"psi(t), psi(2t-2)\"}]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.6.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.30899 0.238845 [
[.02381 .29649 -6 -9 ]
[.02381 .29649 6 0 ]
[.18254 .29649 -12 -9 ]
[.18254 .29649 12 0 ]
[.5 .29649 -9 -9 ]
[.5 .29649 9 0 ]
[.65873 .29649 -3 -9 ]
[.65873 .29649 3 0 ]
[.81746 .29649 -9 -9 ]
[.81746 .29649 9 0 ]
[.97619 .29649 -3 -9 ]
[.97619 .29649 3 0 ]
[1.025 .30899 0 -4.5 ]
[1.025 .30899 6 4.5 ]
[.32877 .07014 -12 -4.5 ]
[.32877 .07014 0 4.5 ]
[.32877 .18957 -24 -4.5 ]
[.32877 .18957 0 4.5 ]
[.32877 .42841 -18 -4.5 ]
[.32877 .42841 0 4.5 ]
[.32877 .54784 -6 -4.5 ]
[.32877 .54784 0 4.5 ]
[.34127 .64303 -51 0 ]
[.34127 .64303 51 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30899 m
.02381 .31524 L
s
[(-1)] .02381 .29649 0 1 Mshowa
.18254 .30899 m
.18254 .31524 L
s
[(-0.5)] .18254 .29649 0 1 Mshowa
.5 .30899 m
.5 .31524 L
s
[(0.5)] .5 .29649 0 1 Mshowa
.65873 .30899 m
.65873 .31524 L
s
[(1)] .65873 .29649 0 1 Mshowa
.81746 .30899 m
.81746 .31524 L
s
[(1.5)] .81746 .29649 0 1 Mshowa
.97619 .30899 m
.97619 .31524 L
s
[(2)] .97619 .29649 0 1 Mshowa
.125 Mabswid
.05556 .30899 m
.05556 .31274 L
s
.0873 .30899 m
.0873 .31274 L
s
.11905 .30899 m
.11905 .31274 L
s
.15079 .30899 m
.15079 .31274 L
s
.21429 .30899 m
.21429 .31274 L
s
.24603 .30899 m
.24603 .31274 L
s
.27778 .30899 m
.27778 .31274 L
s
.30952 .30899 m
.30952 .31274 L
s
.37302 .30899 m
.37302 .31274 L
s
.40476 .30899 m
.40476 .31274 L
s
.43651 .30899 m
.43651 .31274 L
s
.46825 .30899 m
.46825 .31274 L
s
.53175 .30899 m
.53175 .31274 L
s
.56349 .30899 m
.56349 .31274 L
s
.59524 .30899 m
.59524 .31274 L
s
.62698 .30899 m
.62698 .31274 L
s
.69048 .30899 m
.69048 .31274 L
s
.72222 .30899 m
.72222 .31274 L
s
.75397 .30899 m
.75397 .31274 L
s
.78571 .30899 m
.78571 .31274 L
s
.84921 .30899 m
.84921 .31274 L
s
.88095 .30899 m
.88095 .31274 L
s
.9127 .30899 m
.9127 .31274 L
s
.94444 .30899 m
.94444 .31274 L
s
.25 Mabswid
0 .30899 m
1 .30899 L
s
[(t)] 1.025 .30899 -1 0 Mshowa
.34127 .07014 m
.34752 .07014 L
s
[(-1)] .32877 .07014 1 0 Mshowa
.34127 .18957 m
.34752 .18957 L
s
[(-0.5)] .32877 .18957 1 0 Mshowa
.34127 .42841 m
.34752 .42841 L
s
[(0.5)] .32877 .42841 1 0 Mshowa
.34127 .54784 m
.34752 .54784 L
s
[(1)] .32877 .54784 1 0 Mshowa
.125 Mabswid
.34127 .09403 m
.34502 .09403 L
s
.34127 .11791 m
.34502 .11791 L
s
.34127 .1418 m
.34502 .1418 L
s
.34127 .16568 m
.34502 .16568 L
s
.34127 .21345 m
.34502 .21345 L
s
.34127 .23734 m
.34502 .23734 L
s
.34127 .26122 m
.34502 .26122 L
s
.34127 .28511 m
.34502 .28511 L
s
.34127 .33287 m
.34502 .33287 L
s
.34127 .35676 m
.34502 .35676 L
s
.34127 .38064 m
.34502 .38064 L
s
.34127 .40453 m
.34502 .40453 L
s
.34127 .4523 m
.34502 .4523 L
s
.34127 .47618 m
.34502 .47618 L
s
.34127 .50007 m
.34502 .50007 L
s
.34127 .52395 m
.34502 .52395 L
s
.34127 .04626 m
.34502 .04626 L
s
.34127 .02238 m
.34502 .02238 L
s
.34127 .57172 m
.34502 .57172 L
s
.34127 .5956 m
.34502 .5956 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi\\(t\\), psi\\(2t-2\\))] .34127 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .30899 m
.02846 .30899 L
.03068 .30899 L
.03178 .30899 L
.03279 .30899 L
.03398 .30899 L
.03527 .30899 L
.03754 .309 L
.04016 .30901 L
.04144 .30902 L
.04262 .30902 L
.04375 .30903 L
.04482 .30903 L
.0472 .30903 L
.04981 .30903 L
.05109 .30903 L
.05224 .30903 L
.05346 .30903 L
.0546 .309 L
.05712 .30891 L
.05966 .30882 L
.06244 .30872 L
.0651 .30864 L
.06757 .30859 L
.0704 .30853 L
.07164 .3085 L
.07229 .30848 L
.07299 .30847 L
.07423 .30848 L
.07539 .3085 L
.07767 .30854 L
.08028 .30858 L
.08143 .30861 L
.08269 .30863 L
.08394 .30868 L
.08463 .30872 L
.08527 .30876 L
.08805 .30893 L
.09065 .30909 L
.09192 .30917 L
.09309 .30924 L
.09377 .30936 L
.09449 .30952 L
.096 .30987 L
.09865 .31046 L
.10458 .31176 L
.10942 .31275 L
.11058 .31298 L
.11181 .31323 L
.11297 .31347 L
Mistroke
.11402 .31347 L
.11532 .31343 L
.11655 .3134 L
.11931 .31333 L
.12164 .31326 L
.12295 .31323 L
.12415 .31311 L
.1287 .31265 L
.13093 .31242 L
.13192 .31232 L
.133 .31222 L
.13415 .31217 L
.13537 .31212 L
.13795 .312 L
.14031 .3119 L
.14134 .31185 L
.14247 .31181 L
.14365 .31166 L
.14489 .31146 L
.1475 .31105 L
.14979 .31069 L
.15096 .3105 L
.15223 .3103 L
.1535 .30997 L
.1547 .30957 L
.15695 .30883 L
.16133 .30738 L
.16382 .30632 L
.16656 .30482 L
.16923 .30336 L
.1707 .30256 L
.17142 .30216 L
.17209 .3018 L
.17338 .30056 L
.17477 .29881 L
.17722 .29575 L
.18201 .28975 L
.18663 .28416 L
.18906 .28124 L
.19038 .27965 L
.19162 .27816 L
.1927 .27704 L
.19387 .27655 L
.19633 .27551 L
.20065 .27369 L
.20194 .27314 L
.20259 .27293 L
.20331 .27286 L
.20481 .27272 L
.20619 .27258 L
Mistroke
.20872 .27234 L
.21011 .2722 L
.21143 .27207 L
.2127 .27211 L
.21341 .27233 L
.21408 .27254 L
.2165 .2733 L
.22124 .27478 L
.24005 .28245 L
.24521 .2842 L
.24802 .28516 L
.24939 .28563 L
.25065 .28605 L
.2518 .28644 L
.25289 .28651 L
.25404 .28652 L
.25529 .28654 L
.25792 .28656 L
.26039 .28658 L
.26163 .2866 L
.26232 .28669 L
.26296 .28682 L
.26579 .28742 L
.26853 .288 L
.26998 .2883 L
.27077 .28847 L
.27152 .28863 L
.27218 .28907 L
.27289 .28982 L
.27412 .29113 L
.27654 .2937 L
.28182 .29933 L
.29143 .31289 L
.29652 .31922 L
.30199 .32619 L
.30737 .33574 L
.31227 .34508 L
.32188 .37043 L
.32705 .3888 L
.32978 .39849 L
.33268 .41269 L
.338 .44709 L
.34293 .47881 L
.34796 .51081 L
.34928 .51925 L
.35001 .52389 L
.3507 .52828 L
.35134 .53191 L
.35204 .5342 L
.35325 .53821 L
Mistroke
.35603 .54734 L
.35906 .55734 L
.3644 .57107 L
.36949 .58189 L
.37073 .58452 L
.37143 .58553 L
.37206 .58613 L
.37352 .58751 L
.37489 .58879 L
.37751 .59125 L
.37879 .59246 L
.37998 .59357 L
.38105 .59451 L
.38219 .59483 L
.38459 .59549 L
.38935 .59681 L
.39177 .59765 L
.39442 .59889 L
.39688 .60004 L
.3992 .60113 L
.40022 .6016 L
.40129 .60194 L
.40247 .60212 L
.40356 .60228 L
.40623 .60266 L
.40873 .60303 L
.41 .60321 L
.41071 .60332 L
.41137 .60327 L
.41428 .60305 L
.4168 .60286 L
.41915 .60268 L
.42033 .60259 L
.4216 .60202 L
.42428 .60048 L
.42687 .599 L
.42828 .59819 L
.42961 .59743 L
.43073 .5966 L
.43195 .59469 L
.43452 .59062 L
.44562 .57019 L
.45607 .54912 L
.46577 .52555 L
.46829 .51839 L
.47067 .51102 L
.47341 .49927 L
.47589 .48862 L
.48164 .46158 L
.48693 .43048 L
Mistroke
.49163 .39586 L
.49659 .34436 L
.50206 .28765 L
.50703 .23599 L
.50937 .21172 L
.51069 .20147 L
.51191 .1943 L
.51653 .16714 L
.52137 .14112 L
.5267 .11824 L
.5356 .08856 L
.54047 .07547 L
.54504 .06673 L
.55489 .04669 L
.56027 .03562 L
.56526 .02772 L
.56746 .02424 L
.56854 .02253 L
.56954 .02104 L
.57069 .02038 L
.57193 .01967 L
.5741 .01842 L
.57653 .01703 L
.57772 .01635 L
.5788 .01573 L
.57994 .01537 L
.58117 .01527 L
.58377 .01508 L
.58624 .01489 L
.58745 .0148 L
.58856 .01472 L
.58973 .01473 L
.59099 .01491 L
.59366 .0153 L
.59597 .01564 L
.59812 .01595 L
.59921 .01611 L
.60037 .01665 L
.60282 .0178 L
.60806 .02025 L
.6107 .02118 L
.61361 .02199 L
.61609 .02267 L
.61746 .02305 L
.61875 .02341 L
.61996 .02435 L
.62127 .02558 L
.62357 .02774 L
.62614 .03016 L
.62755 .03148 L
Mistroke
.62824 .03213 L
.62887 .03272 L
.63011 .03524 L
.63145 .03809 L
.63379 .04306 L
.63634 .04849 L
.63775 .05147 L
.63844 .05294 L
.63908 .05452 L
.63983 .057 L
.64065 .05969 L
.64208 .0644 L
.64488 .07363 L
.64733 .0817 L
.64853 .08565 L
.64963 .0918 L
.65079 .09916 L
.65203 .10708 L
.65468 .12394 L
.66502 .19047 L
.66746 .20624 L
.66866 .21396 L
.66977 .21788 L
.67104 .22241 L
.67242 .22731 L
.67483 .23587 L
.68395 .26312 L
.69401 .28469 L
.69908 .29333 L
.70466 .30021 L
.71464 .31364 L
.72411 .32497 L
.72664 .32766 L
.72737 .32843 L
.72805 .32916 L
.72933 .32953 L
.73229 .33016 L
.73503 .33073 L
.73624 .33099 L
.73753 .33126 L
.73862 .33139 L
.73982 .3314 L
.745 .33145 L
.74623 .33146 L
.74753 .33147 L
.7482 .33154 L
.74895 .33179 L
.75026 .33224 L
.75524 .33393 L
.76456 .33711 L
Mistroke
.77548 .34182 L
.78027 .34367 L
.78279 .34446 L
.78549 .3453 L
.78616 .34551 L
.78688 .34574 L
.78819 .34595 L
.78947 .34582 L
.79064 .34571 L
.79292 .34548 L
.79543 .34524 L
.79657 .34513 L
.7978 .34495 L
.79896 .34446 L
.80002 .34401 L
.80488 .34196 L
.80617 .34141 L
.80688 .34111 L
.80754 .34083 L
.80871 .33942 L
.81001 .33786 L
.81559 .33114 L
.82044 .32516 L
.82301 .32194 L
.82575 .31851 L
.82641 .31769 L
.82712 .31679 L
.82841 .3159 L
.83084 .31458 L
.83557 .312 L
.84095 .30984 L
.84351 .309 L
.84591 .3082 L
.84697 .30785 L
.84798 .30765 L
.84913 .30747 L
.85019 .3073 L
.85263 .30691 L
.8549 .30655 L
.85603 .30637 L
.8571 .3062 L
.85833 .30614 L
.85945 .30609 L
.86202 .30598 L
.86441 .30587 L
.86557 .30582 L
.86666 .30578 L
.86793 .30567 L
.86908 .30555 L
.87173 .30528 L
Mistroke
.87419 .30504 L
.87543 .30491 L
.87659 .30479 L
.8778 .30473 L
.87844 .30471 L
.87914 .30469 L
.8817 .30463 L
.88451 .30455 L
.88569 .30452 L
.88695 .30449 L
.88813 .30474 L
.88921 .30495 L
.89416 .30596 L
.90299 .30789 L
.9042 .30816 L
.9055 .30845 L
.90673 .30873 L
.90785 .3088 L
.9103 .30895 L
.91299 .30911 L
.91525 .30925 L
.91653 .30933 L
.91771 .30936 L
.9222 .30944 L
.92351 .30946 L
.92492 .30949 L
.92558 .3095 L
.92626 .30951 L
.92749 .3095 L
.92867 .30947 L
.92977 .30945 L
.93228 .30939 L
.93477 .30934 L
.93742 .30927 L
.94032 .30916 L
.943 .30907 L
.94505 .309 L
.9462 .30895 L
.94725 .30895 L
.94849 .30895 L
.94967 .30895 L
.95193 .30895 L
.95389 .30895 L
.95496 .30895 L
.95597 .30895 L
.95717 .30895 L
.95826 .30896 L
.96038 .30897 L
.96407 .30899 L
.96497 .30899 L
Mistroke
.96593 .30899 L
.96699 .30899 L
.96797 .30899 L
.97225 .30899 L
.97619 .30899 L
Mfstroke
.02381 .30899 m
.06244 .30899 L
.10458 .30899 L
.14415 .30899 L
.18221 .30899 L
.22272 .30899 L
.26171 .30899 L
.30316 .30899 L
.34309 .30899 L
.3815 .30899 L
.42237 .30899 L
.46172 .30899 L
.48147 .30899 L
.49012 .30899 L
.49468 .30899 L
.49719 .30899 L
.49842 .30899 L
.49955 .30899 L
.50085 .30899 L
.50154 .30899 L
.50226 .30899 L
.50353 .30899 L
.50471 .30899 L
.50581 .30899 L
.507 .309 L
.5083 .30901 L
.5095 .30903 L
.51072 .30903 L
.51136 .30903 L
.51204 .30903 L
.51328 .30903 L
.51445 .30903 L
.51548 .30899 L
.51659 .30891 L
.51896 .30874 L
.52149 .30861 L
.52295 .30854 L
.52427 .30848 L
.52499 .30847 L
.52567 .30849 L
.52716 .30855 L
.52847 .30859 L
.52918 .30862 L
.52985 .30865 L
.53104 .3088 L
.53235 .30896 L
.53353 .3091 L
.53464 .30924 L
.53595 .3098 L
.53715 .31034 L
Mistroke
.53984 .31154 L
.54244 .3126 L
.54371 .31312 L
.54488 .31348 L
.54595 .31342 L
.54708 .31336 L
.54832 .3133 L
.54945 .31324 L
.55067 .31301 L
.55198 .31275 L
.5532 .3125 L
.55433 .31227 L
.55565 .31213 L
.55708 .312 L
.55834 .31189 L
.55899 .31184 L
.55968 .31174 L
.56083 .31137 L
.56188 .31104 L
.56287 .31072 L
.56393 .31039 L
.56509 .30981 L
.56617 .3091 L
.56861 .30748 L
.56984 .3065 L
.57117 .30505 L
.57234 .30377 L
.57358 .30241 L
.5747 .30078 L
.57592 .29771 L
.57808 .29229 L
.58059 .28614 L
.58191 .28296 L
.58331 .27958 L
.58454 .27697 L
.58523 .27638 L
.58589 .27582 L
.58705 .27484 L
.58827 .27381 L
.58939 .27293 L
.59061 .2727 L
.59275 .27228 L
.59395 .27204 L
.59524 .27261 L
.59646 .27337 L
.59757 .27407 L
.60285 .2785 L
.60844 .28267 L
.61074 .28424 L
.61201 .2851 L
Mistroke
.61322 .28592 L
.6139 .28638 L
.61464 .28652 L
.61593 .28654 L
.61724 .28656 L
.61848 .28659 L
.61969 .28687 L
.621 .28742 L
.62209 .28788 L
.62329 .28839 L
.62459 .28992 L
.6253 .29143 L
.62596 .29284 L
.62842 .29806 L
.63764 .32238 L
.64033 .33061 L
.64289 .33968 L
.64767 .36293 L
.65017 .3785 L
.65282 .39735 L
.65349 .40208 L
.65421 .40974 L
.655 .41992 L
.65574 .42948 L
.65843 .46429 L
.66081 .49472 L
.66306 .52338 L
.6643 .53546 L
.66501 .54008 L
.66565 .54434 L
.66801 .55984 L
.67064 .57255 L
.67209 .57868 L
.67279 .58168 L
.67343 .58441 L
.67459 .58701 L
.67584 .58935 L
.67723 .59196 L
.67848 .59432 L
.67978 .59516 L
.68117 .59593 L
.68247 .59665 L
.68366 .59736 L
.68435 .598 L
.68506 .59867 L
.68657 .60008 L
.6879 .60131 L
.68864 .60191 L
.68931 .60211 L
.69062 .60249 L
Mistroke
.69185 .60285 L
.69298 .60318 L
.69421 .6032 L
.69486 .60311 L
.69557 .603 L
.69701 .60278 L
.69765 .60269 L
.69834 .60258 L
.69959 .60123 L
.70212 .59832 L
.70285 .59749 L
.70354 .59637 L
.70482 .5923 L
.70968 .57541 L
.71543 .55181 L
.71795 .54218 L
.71938 .53464 L
.72071 .52707 L
.7254 .49411 L
.72779 .47359 L
.73036 .44463 L
.7317 .42884 L
.73241 .42051 L
.73316 .41142 L
.73382 .39781 L
.73454 .38278 L
.73582 .35627 L
.7408 .25287 L
.74571 .17477 L
.74818 .14624 L
.75088 .12305 L
.75208 .11283 L
.7532 .10383 L
.7545 .09648 L
.75568 .0898 L
.76014 .06857 L
.76499 .04903 L
.77014 .02957 L
.77144 .02547 L
.77215 .02321 L
.77283 .02108 L
.77363 .02017 L
.77435 .01933 L
.77578 .01769 L
.77699 .01631 L
.77827 .01533 L
.77901 .01522 L
.77968 .01512 L
.78099 .01492 L
.78219 .01474 L
Mistroke
.78332 .01483 L
.78455 .01519 L
.78588 .01558 L
.78654 .01577 L
.78726 .01598 L
.78857 .01693 L
.79103 .01923 L
.79542 .02228 L
.79663 .02294 L
.79792 .02406 L
.79914 .02636 L
.80026 .02847 L
.80159 .03096 L
.80282 .03386 L
.80411 .03932 L
.80552 .0453 L
.80844 .05981 L
.81109 .07727 L
.81358 .10033 L
.81593 .13026 L
.8186 .1645 L
.8211 .19677 L
.82224 .21163 L
.82333 .2204 L
.82459 .22933 L
.82574 .23748 L
.82838 .25436 L
.83084 .26708 L
.83577 .28706 L
.83837 .29515 L
.84114 .30198 L
.84536 .31348 L
.84991 .32446 L
.85118 .32715 L
.85187 .32862 L
.85251 .32943 L
.85366 .32991 L
.85491 .33044 L
.85607 .33093 L
.85717 .33138 L
.85845 .33141 L
.8596 .33143 L
.86075 .33145 L
.86198 .33147 L
.86315 .33219 L
.86422 .33291 L
.8693 .33638 L
.87422 .3403 L
.87681 .34273 L
.87826 .34369 L
Mistroke
.87958 .34451 L
.88079 .34527 L
.88211 .34596 L
.88334 .34572 L
.88448 .3455 L
.88563 .34528 L
.8867 .34507 L
.88781 .34426 L
.88904 .34322 L
.8902 .34224 L
.89131 .34131 L
.8923 .3398 L
.89337 .3372 L
.89802 .32589 L
.90036 .32005 L
.90158 .31698 L
.90287 .31528 L
.90525 .31269 L
.90639 .31144 L
.90743 .3106 L
.90867 .30978 L
.90999 .3089 L
.91124 .30808 L
.91238 .30755 L
.91303 .30735 L
.91372 .30713 L
.91517 .30667 L
.91642 .30627 L
.91714 .30615 L
.9178 .30609 L
.9231 .30546 L
.92431 .30521 L
.92561 .30495 L
.92683 .30474 L
.92793 .30468 L
.92922 .30461 L
.9306 .30454 L
.93139 .30449 L
.9321 .30471 L
.93351 .30528 L
.93881 .30754 L
.93991 .30803 L
.9411 .30857 L
.94223 .30883 L
.94327 .30895 L
.94448 .3091 L
.94577 .30926 L
.94685 .30936 L
.94804 .3094 L
.95018 .30948 L
Mistroke
.95138 .30952 L
.95248 .30947 L
.95665 .30928 L
.95896 .30911 L
.96023 .30902 L
.96143 .30895 L
.96212 .30895 L
.96285 .30895 L
.96414 .30895 L
.96546 .30895 L
.96666 .30895 L
.97619 .30899 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "The dual scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and dual wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " can be obtained by interchanging the role of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.3"],
  " and\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  ". "
}], "Text",
  CellTags->{"S1.6.3", "3.24"}],

Cell["\<\
The dual functions are obtained by reversing the order of the two \
filters.\
\>", "MathCaption",
  CellTags->{"S1.6.3", "3.25"}],

Cell["phitilde = ScalingFunction[Reverse[b31], 7];", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.6.3"],

Cell[TextData[{
  "This is, of course, just the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "\[Hyphen]spline function of order 0."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.26"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[phitilde, AxesLabel -> {\"t\", \"phitilde(t)\"},
PlotJoined -> True, PlotRange -> All]\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.6.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -33 0 ]
[.02381 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(t)] 1.025 .01472 -1 0 Mshowa
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phitilde\\(t\\))] .02381 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .60332 m
.03125 .60332 L
.03869 .60332 L
.04613 .60332 L
.05357 .60332 L
.06101 .60332 L
.06845 .60332 L
.07589 .60332 L
.08333 .60332 L
.09077 .60332 L
.09821 .60332 L
.10565 .60332 L
.1131 .60332 L
.12054 .60332 L
.12798 .60332 L
.13542 .60332 L
.14286 .60332 L
.1503 .60332 L
.15774 .60332 L
.16518 .60332 L
.17262 .60332 L
.18006 .60332 L
.1875 .60332 L
.19494 .60332 L
.20238 .60332 L
.20982 .60332 L
.21726 .60332 L
.2247 .60332 L
.23214 .60332 L
.23958 .60332 L
.24702 .60332 L
.25446 .60332 L
.2619 .60332 L
.26935 .60332 L
.27679 .60332 L
.28423 .60332 L
.29167 .60332 L
.29911 .60332 L
.30655 .60332 L
.31399 .60332 L
.32143 .60332 L
.32887 .60332 L
.33631 .60332 L
.34375 .60332 L
.35119 .60332 L
.35863 .60332 L
.36607 .60332 L
.37351 .60332 L
.38095 .60332 L
.38839 .60332 L
Mistroke
.39583 .60332 L
.40327 .60332 L
.41071 .60332 L
.41815 .60332 L
.4256 .60332 L
.43304 .60332 L
.44048 .60332 L
.44792 .60332 L
.45536 .60332 L
.4628 .60332 L
.47024 .60332 L
.47768 .60332 L
.48512 .60332 L
.49256 .60332 L
.5 .60332 L
.50744 .60332 L
.51488 .60332 L
.52232 .60332 L
.52976 .60332 L
.5372 .60332 L
.54464 .60332 L
.55208 .60332 L
.55952 .60332 L
.56696 .60332 L
.5744 .60332 L
.58185 .60332 L
.58929 .60332 L
.59673 .60332 L
.60417 .60332 L
.61161 .60332 L
.61905 .60332 L
.62649 .60332 L
.63393 .60332 L
.64137 .60332 L
.64881 .60332 L
.65625 .60332 L
.66369 .60332 L
.67113 .60332 L
.67857 .60332 L
.68601 .60332 L
.69345 .60332 L
.70089 .60332 L
.70833 .60332 L
.71577 .60332 L
.72321 .60332 L
.73065 .60332 L
.7381 .60332 L
.74554 .60332 L
.75298 .60332 L
.76042 .60332 L
Mistroke
.76786 .60332 L
.7753 .60332 L
.78274 .60332 L
.79018 .60332 L
.79762 .60332 L
.80506 .60332 L
.8125 .60332 L
.81994 .60332 L
.82738 .60332 L
.83482 .60332 L
.84226 .60332 L
.8497 .60332 L
.85714 .60332 L
.86458 .60332 L
.87202 .60332 L
.87946 .60332 L
.8869 .60332 L
.89435 .60332 L
.90179 .60332 L
.90923 .60332 L
.91667 .60332 L
.92411 .60332 L
.93155 .60332 L
.93899 .60332 L
.94643 .60332 L
.95387 .60332 L
.96131 .60332 L
.96875 .60332 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],

Cell[TextData[{
  "This is the dual wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.3", "3.27"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[Reverse[b31], 7],
AxesLabel -> {\"t\", \"psitilde(t)\"},
PlotJoined -> True, PlotRange -> All]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.6.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -12 -9 ]
[.18254 .29652 12 0 ]
[.5 .29652 -9 -9 ]
[.5 .29652 9 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -9 -9 ]
[.81746 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.32877 .01472 -12 -4.5 ]
[.32877 .01472 0 4.5 ]
[.32877 .16187 -24 -4.5 ]
[.32877 .16187 0 4.5 ]
[.32877 .45617 -18 -4.5 ]
[.32877 .45617 0 4.5 ]
[.32877 .60332 -6 -4.5 ]
[.32877 .60332 0 4.5 ]
[.34127 .64303 -33 0 ]
[.34127 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-0.5)] .18254 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(0.5)] .5 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(1.5)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(t)] 1.025 .30902 -1 0 Mshowa
.34127 .01472 m
.34752 .01472 L
s
[(-1)] .32877 .01472 1 0 Mshowa
.34127 .16187 m
.34752 .16187 L
s
[(-0.5)] .32877 .16187 1 0 Mshowa
.34127 .45617 m
.34752 .45617 L
s
[(0.5)] .32877 .45617 1 0 Mshowa
.34127 .60332 m
.34752 .60332 L
s
[(1)] .32877 .60332 1 0 Mshowa
.125 Mabswid
.34127 .04415 m
.34502 .04415 L
s
.34127 .07358 m
.34502 .07358 L
s
.34127 .10301 m
.34502 .10301 L
s
.34127 .13244 m
.34502 .13244 L
s
.34127 .1913 m
.34502 .1913 L
s
.34127 .22073 m
.34502 .22073 L
s
.34127 .25016 m
.34502 .25016 L
s
.34127 .27959 m
.34502 .27959 L
s
.34127 .33845 m
.34502 .33845 L
s
.34127 .36788 m
.34502 .36788 L
s
.34127 .39731 m
.34502 .39731 L
s
.34127 .42674 m
.34502 .42674 L
s
.34127 .4856 m
.34502 .4856 L
s
.34127 .51503 m
.34502 .51503 L
s
.34127 .54446 m
.34502 .54446 L
s
.34127 .57389 m
.34502 .57389 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psitilde\\(t\\))] .34127 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .27223 m
.02629 .27223 L
.02877 .27223 L
.03125 .27223 L
.03373 .27223 L
.03621 .27223 L
.03869 .27223 L
.04117 .27223 L
.04365 .27223 L
.04613 .27223 L
.04861 .27223 L
.05109 .27223 L
.05357 .27223 L
.05605 .27223 L
.05853 .27223 L
.06101 .27223 L
.06349 .27223 L
.06597 .27223 L
.06845 .27223 L
.07093 .27223 L
.07341 .27223 L
.07589 .27223 L
.07837 .27223 L
.08085 .27223 L
.08333 .27223 L
.08581 .27223 L
.08829 .27223 L
.09077 .27223 L
.09325 .27223 L
.09573 .27223 L
.09821 .27223 L
.10069 .27223 L
.10317 .27223 L
.10565 .27223 L
.10813 .27223 L
.11062 .27223 L
.1131 .27223 L
.11558 .27223 L
.11806 .27223 L
.12054 .27223 L
.12302 .27223 L
.1255 .27223 L
.12798 .27223 L
.13046 .27223 L
.13294 .27223 L
.13542 .27223 L
.1379 .27223 L
.14038 .27223 L
.14286 .27223 L
.14534 .27223 L
Mistroke
.14782 .27223 L
.1503 .27223 L
.15278 .27223 L
.15526 .27223 L
.15774 .27223 L
.16022 .27223 L
.1627 .27223 L
.16518 .27223 L
.16766 .27223 L
.17014 .27223 L
.17262 .27223 L
.1751 .27223 L
.17758 .27223 L
.18006 .27223 L
.18254 .27223 L
.18502 .27223 L
.1875 .27223 L
.18998 .27223 L
.19246 .27223 L
.19494 .27223 L
.19742 .27223 L
.1999 .27223 L
.20238 .27223 L
.20486 .27223 L
.20734 .27223 L
.20982 .27223 L
.2123 .27223 L
.21478 .27223 L
.21726 .27223 L
.21974 .27223 L
.22222 .27223 L
.2247 .27223 L
.22718 .27223 L
.22966 .27223 L
.23214 .27223 L
.23462 .27223 L
.2371 .27223 L
.23958 .27223 L
.24206 .27223 L
.24454 .27223 L
.24702 .27223 L
.2495 .27223 L
.25198 .27223 L
.25446 .27223 L
.25694 .27223 L
.25942 .27223 L
.2619 .27223 L
.26438 .27223 L
.26687 .27223 L
.26935 .27223 L
Mistroke
.27183 .27223 L
.27431 .27223 L
.27679 .27223 L
.27927 .27223 L
.28175 .27223 L
.28423 .27223 L
.28671 .27223 L
.28919 .27223 L
.29167 .27223 L
.29415 .27223 L
.29663 .27223 L
.29911 .27223 L
.30159 .27223 L
.30407 .27223 L
.30655 .27223 L
.30903 .27223 L
.31151 .27223 L
.31399 .27223 L
.31647 .27223 L
.31895 .27223 L
.32143 .27223 L
.32391 .27223 L
.32639 .27223 L
.32887 .27223 L
.33135 .27223 L
.33383 .27223 L
.33631 .27223 L
.33879 .27223 L
.34127 .60332 L
.34375 .60332 L
.34623 .60332 L
.34871 .60332 L
.35119 .60332 L
.35367 .60332 L
.35615 .60332 L
.35863 .60332 L
.36111 .60332 L
.36359 .60332 L
.36607 .60332 L
.36855 .60332 L
.37103 .60332 L
.37351 .60332 L
.37599 .60332 L
.37847 .60332 L
.38095 .60332 L
.38343 .60332 L
.38591 .60332 L
.38839 .60332 L
.39087 .60332 L
.39335 .60332 L
Mistroke
.39583 .60332 L
.39831 .60332 L
.40079 .60332 L
.40327 .60332 L
.40575 .60332 L
.40823 .60332 L
.41071 .60332 L
.41319 .60332 L
.41567 .60332 L
.41815 .60332 L
.42063 .60332 L
.42312 .60332 L
.4256 .60332 L
.42808 .60332 L
.43056 .60332 L
.43304 .60332 L
.43552 .60332 L
.438 .60332 L
.44048 .60332 L
.44296 .60332 L
.44544 .60332 L
.44792 .60332 L
.4504 .60332 L
.45288 .60332 L
.45536 .60332 L
.45784 .60332 L
.46032 .60332 L
.4628 .60332 L
.46528 .60332 L
.46776 .60332 L
.47024 .60332 L
.47272 .60332 L
.4752 .60332 L
.47768 .60332 L
.48016 .60332 L
.48264 .60332 L
.48512 .60332 L
.4876 .60332 L
.49008 .60332 L
.49256 .60332 L
.49504 .60332 L
.49752 .60332 L
.5 .01472 L
.50248 .01472 L
.50496 .01472 L
.50744 .01472 L
.50992 .01472 L
.5124 .01472 L
.51488 .01472 L
.51736 .01472 L
Mistroke
.51984 .01472 L
.52232 .01472 L
.5248 .01472 L
.52728 .01472 L
.52976 .01472 L
.53224 .01472 L
.53472 .01472 L
.5372 .01472 L
.53968 .01472 L
.54216 .01472 L
.54464 .01472 L
.54712 .01472 L
.5496 .01472 L
.55208 .01472 L
.55456 .01472 L
.55704 .01472 L
.55952 .01472 L
.562 .01472 L
.56448 .01472 L
.56696 .01472 L
.56944 .01472 L
.57192 .01472 L
.5744 .01472 L
.57688 .01472 L
.57937 .01472 L
.58185 .01472 L
.58433 .01472 L
.58681 .01472 L
.58929 .01472 L
.59177 .01472 L
.59425 .01472 L
.59673 .01472 L
.59921 .01472 L
.60169 .01472 L
.60417 .01472 L
.60665 .01472 L
.60913 .01472 L
.61161 .01472 L
.61409 .01472 L
.61657 .01472 L
.61905 .01472 L
.62153 .01472 L
.62401 .01472 L
.62649 .01472 L
.62897 .01472 L
.63145 .01472 L
.63393 .01472 L
.63641 .01472 L
.63889 .01472 L
.64137 .01472 L
Mistroke
.64385 .01472 L
.64633 .01472 L
.64881 .01472 L
.65129 .01472 L
.65377 .01472 L
.65625 .01472 L
.65873 .3458 L
.66121 .3458 L
.66369 .3458 L
.66617 .3458 L
.66865 .3458 L
.67113 .3458 L
.67361 .3458 L
.67609 .3458 L
.67857 .3458 L
.68105 .3458 L
.68353 .3458 L
.68601 .3458 L
.68849 .3458 L
.69097 .3458 L
.69345 .3458 L
.69593 .3458 L
.69841 .3458 L
.70089 .3458 L
.70337 .3458 L
.70585 .3458 L
.70833 .3458 L
.71081 .3458 L
.71329 .3458 L
.71577 .3458 L
.71825 .3458 L
.72073 .3458 L
.72321 .3458 L
.72569 .3458 L
.72817 .3458 L
.73065 .3458 L
.73313 .3458 L
.73562 .3458 L
.7381 .3458 L
.74058 .3458 L
.74306 .3458 L
.74554 .3458 L
.74802 .3458 L
.7505 .3458 L
.75298 .3458 L
.75546 .3458 L
.75794 .3458 L
.76042 .3458 L
.7629 .3458 L
.76538 .3458 L
Mistroke
.76786 .3458 L
.77034 .3458 L
.77282 .3458 L
.7753 .3458 L
.77778 .3458 L
.78026 .3458 L
.78274 .3458 L
.78522 .3458 L
.7877 .3458 L
.79018 .3458 L
.79266 .3458 L
.79514 .3458 L
.79762 .3458 L
.8001 .3458 L
.80258 .3458 L
.80506 .3458 L
.80754 .3458 L
.81002 .3458 L
.8125 .3458 L
.81498 .3458 L
.81746 .3458 L
.81994 .3458 L
.82242 .3458 L
.8249 .3458 L
.82738 .3458 L
.82986 .3458 L
.83234 .3458 L
.83482 .3458 L
.8373 .3458 L
.83978 .3458 L
.84226 .3458 L
.84474 .3458 L
.84722 .3458 L
.8497 .3458 L
.85218 .3458 L
.85466 .3458 L
.85714 .3458 L
.85962 .3458 L
.8621 .3458 L
.86458 .3458 L
.86706 .3458 L
.86954 .3458 L
.87202 .3458 L
.8745 .3458 L
.87698 .3458 L
.87946 .3458 L
.88194 .3458 L
.88442 .3458 L
.8869 .3458 L
.88938 .3458 L
Mistroke
.89187 .3458 L
.89435 .3458 L
.89683 .3458 L
.89931 .3458 L
.90179 .3458 L
.90427 .3458 L
.90675 .3458 L
.90923 .3458 L
.91171 .3458 L
.91419 .3458 L
.91667 .3458 L
.91915 .3458 L
.92163 .3458 L
.92411 .3458 L
.92659 .3458 L
.92907 .3458 L
.93155 .3458 L
.93403 .3458 L
.93651 .3458 L
.93899 .3458 L
.94147 .3458 L
.94395 .3458 L
.94643 .3458 L
.94891 .3458 L
.95139 .3458 L
.95387 .3458 L
.95635 .3458 L
.95883 .3458 L
.96131 .3458 L
.96379 .3458 L
.96627 .3458 L
.96875 .3458 L
.97123 .3458 L
.97371 .3458 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],

Cell["1.6.4 Biorthogonal Wavelet Transforms", "Subsection",
  CellTags->{"S1.6.4", "4.1"}],

Cell[TextData[{
  "The orthogonal wavelet transform (see Section ",
  ButtonBox["1.5.1",
    ButtonData:>{"Wavelets 1.5.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  ") can be easily generalized to the case of biorthogonal wavelets. Instead \
of one set of lowpass and highpass filters, we now have two sets, one for \
decomposition or analysis and one for reconstruction or synthesis; one is the \
dual of the other. Here we write ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " as a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\&~\)\_\(j  k\)\) \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.6.4"],
  ","
}], "Text",
  CellTags->{"S1.6.4", "4.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_j\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], "<", \(\[Phi]\_\(j  k\)\), \(, \ \ \), 
        "f", ">", \(\(\[Phi]\&~\)\_\(j  k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%j\), \(\(\[Phi]\&~\)\_\(j  k\)\), 
        \((t)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.4", "4.3"}],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " as a superposition of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi]\&~\)\_\(j  k\)\) \((t)\)\)], 
    "InlineFormula",
    CellTags->"S1.6.4"],
  ", "
}], "Text",
  CellTags->{"S1.6.4", "4.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(d\_j\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\[Psi]\_\(j  k\)\), \(, \ \ \), "f", "\[RightAngleBracket]", 
        \(\(\[Psi]\&~\)\_\(j  k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(d\_k\%j\), \(\(\[Psi]\&~\)\_\(j  k\)\), 
        \((t)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.4", "4.5"}],

Cell[TextData[{
  "Using ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(j - 1, k\)\), \((t)\), "=", 
          UnderscriptBox["\[Sum]", "l",
            LimitsPositioning->True], \(h\_\(l - 2  k\)\), 
          \(\[Phi]\_\(j  l\)\), \((t)\)}], TraditionalForm]], "InlineFormula",
    
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi]\_\(j - 1, k\)\), \((t)\), "=", 
          UnderscriptBox["\[Sum]", "l",
            LimitsPositioning->True], \(g\_\(l - 2  k\)\), 
          \(\[Phi]\_\(j  l\)\), \((t)\)}], TraditionalForm]], "InlineFormula",
    
    CellTags->"S1.6.4"],
  ", we immediately get the relations for wavelet decomposition: "
}], "Text",
  CellTags->{"S1.6.4", "4.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_k\%\(j - 1\)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(l - 2  k\)\), \(f\_l\%j\), "   ", 
        \(" and "\), "   ", \(d\_k\%\(j - 1\)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(l - 2  k\)\), \(f\_l\%j\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.4", "4.7"}],

Cell["The reconstruction formula can be worked out using ", "Text",
  CellTags->{"S1.6.4", "4.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\_\(j  k\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\(\[Phi]\&~\)\_\(j - 1, l\)\), \(, \ \), \(\[Phi]\_\(j  k\)\), 
        "\[RightAngleBracket]", \(\[Phi]\_\(j - 1, l\)\), \((t)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], "\[LeftAngleBracket]", 
        \(\(\[Psi]\&~\)\_\(j - 1, l\)\), \(, \ \), \(\[Phi]\_\(j  k\)\), 
        "\[RightAngleBracket]", \(\[Psi]\_\(j - 1, l\)\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(h\&~\)\_\(k - 2  l\)\), 
        \(\[Phi]\_\(j - 1, l\)\), \((t)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(g\&~\)\_\(k - 2  l\)\), 
        \(\[Psi]\_\(j - 1, l\)\), \((t)\), ","}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.6.4", "4.9"}],

Cell["and we have ", "Text",
  CellTags->{"S1.6.4", "4.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_k\%j\), "=", "\[LeftAngleBracket]", \(\[Phi]\_\(j  k\)\), \(, \ \ 
        \), "f", "\[RightAngleBracket]", "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(h\&~\)\_\(k - 2  l\)\), 
        "\[LeftAngleBracket]", \(\[Phi]\_\(j - 1, l\)\), \(, \ \ \), "f", 
        "\[RightAngleBracket]", "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(g\&~\)\_\(k - 2  l\)\), 
        "\[LeftAngleBracket]", \(\[Psi]\_\(j - 1, l\)\), \(, \ \ \), "f", 
        "\[RightAngleBracket]", "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(h\&~\)\_\(k - 2  l\)\), 
        \(f\_l\%\(j - 1\)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(\(g\&~\)\_\(k - 2  l\)\), 
        \(d\_l\%\(j - 1\)\), "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.6.4", "4.11"}],

Cell[TextData[{
  "We see that the decomposition and the reconstruction formulas are the same \
as those for the orthogonal filter case (",
  ButtonBox["5.3",
    ButtonData:>{"Wavelets 1.5.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  "), (",
  ButtonBox["5.4",
    ButtonData:>{"Wavelets 1.5.1", "1.19"},
    ButtonStyle->"AddOnsLink"],
  "), and (",
  ButtonBox["5.5",
    ButtonData:>{"Wavelets 1.5.2", "2.7"},
    ButtonStyle->"AddOnsLink"],
  ") except that the dual filters ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " are used in place of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " in reconstruction. In addition, using the relations (see Section ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.1"},
    ButtonStyle->"AddOnsLink"],
  ") "
}], "Text",
  CellTags->{"S1.6.4", "4.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\@2\ \(H \((\[Omega])\)\)\&_ = C \((\[Omega])\), \@2\ 
      \(G \((\[Omega])\)\)\&_ = D \((\[Omega])\), \(\@2\) \(H\&~\) \((
      \[Omega])\) = \(C\&~\) \((\[Omega])\) \(, \ \) " and "\ \(\@2\) 
      \(G\&~\) \((\[Omega])\) = \(D\&~\) \((\[Omega])\), \)], "DisplayFormula",\

  CellTags->{"S1.6.4", "4.13"}],

Cell[TextData[{
  "it is easy to check that the perfect reconstruction conditions (",
  ButtonBox["5.11",
    ButtonData:>{"Wavelets 1.5.3", "3.31"},
    ButtonStyle->"AddOnsLink"],
  ") are satisfied by the biorthogonal filters. \nThe function ",
  StyleBox["WaveletTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["filter", "TI"],
  StyleBox["]", "MR"],
  " can again be employed to do a wavelet transform using biorthogonal \
wavelets. Note that now the argument ",
  StyleBox["filter", "TI"],
  " should be in the form of (",
  ButtonBox["6.13",
    ButtonData:>{"Wavelets 1.6.3", "3.13"},
    ButtonStyle->"AddOnsLink"],
  "). "
}], "Text",
  CellTags->{"S1.6.4", "4.14"}],

Cell[TextData[{
  "This gives the biorthogonal spline filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`{10, 4}\)], "InlineFormula",
    CellTags->"S1.6.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.15"}],

Cell["b = BiorthogonalSplineFilter[10, 4];", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S1.6.4"],

Cell["We generate a set of random data of length 40.", "MathCaption",
  CellTags->{"S1.6.4", "4.16"}],

Cell["\<\
(SeedRandom[38437];
data = Table[Random[],{40}];)\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S1.6.4"],

Cell[TextData[{
  "The wavelet transform is done as for the case of an orthogonal filter. \
Note that now the filter ",
  StyleBox["b", "MR"],
  " contains filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.17"}],

Cell["wtdata = WaveletTransform[data, N[b]];", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S1.6.4"],

Cell["\<\
Nonorthogonal wavelet transforms do not preserve the \"norm\" of \
the data.\
\>", "MathCaption",
  CellTags->{"S1.6.4", "4.18"}],

Cell[CellGroupData[{

Cell["Flatten[wtdata].Flatten[wtdata]-data.data", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S1.6.4"],

Cell[BoxData[
    \(4.61902831313558337`\)], "Output",
  CellLabel->"Out[15]= ",
  CellTags->"S1.6.4"]
}, Open  ]],

Cell["However, biorthogonal filters give perfect reconstruction.", 
  "MathCaption",
  CellTags->{"S1.6.4", "4.19"}],

Cell[CellGroupData[{

Cell["Chop[InverseWaveletTransform[wtdata, N[b]]-data]", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S1.6.4"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[16]= ",
  CellTags->"S1.6.4"]
}, Open  ]],

Cell[TextData[{
  "We can also use the inverse wavelet transform to generate the \
corresponding scaling functions and basic wavelets. Here are examples that \
illustrate the use of the inverse wavelet transform to get the scaling \
functions and wavelets for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 10\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) = 4\)], "InlineFormula",
    CellTags->"S1.6.4"],
  ". "
}], "Text",
  CellTags->{"S1.6.4", "4.20"}],

Cell[TextData[{
  "This is the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  ". Again, to speed up the calculation, we use the approximate numerical \
values for the filter coefficients."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.21"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[N[b], 7,
InverseTransform -> True],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"phi(t)\"}]\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S1.6.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.04329 0.205426 0.137785 [
[.0671 .19293 -9 -9 ]
[.0671 .19293 9 0 ]
[.28355 .19293 -6 -9 ]
[.28355 .19293 6 0 ]
[.71645 .19293 -3 -9 ]
[.71645 .19293 3 0 ]
[.9329 .19293 -6 -9 ]
[.9329 .19293 6 0 ]
[1.025 .20543 0 -4.5 ]
[1.025 .20543 6 4.5 ]
[.4875 .06764 -12 -4.5 ]
[.4875 .06764 0 4.5 ]
[.4875 .34321 -6 -4.5 ]
[.4875 .34321 0 4.5 ]
[.4875 .481 -6 -4.5 ]
[.4875 .481 0 4.5 ]
[.5 .64303 -18 0 ]
[.5 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0671 .20543 m
.0671 .21168 L
s
[(-10)] .0671 .19293 0 1 Mshowa
.28355 .20543 m
.28355 .21168 L
s
[(-5)] .28355 .19293 0 1 Mshowa
.71645 .20543 m
.71645 .21168 L
s
[(5)] .71645 .19293 0 1 Mshowa
.9329 .20543 m
.9329 .21168 L
s
[(10)] .9329 .19293 0 1 Mshowa
.125 Mabswid
.11039 .20543 m
.11039 .20918 L
s
.15368 .20543 m
.15368 .20918 L
s
.19697 .20543 m
.19697 .20918 L
s
.24026 .20543 m
.24026 .20918 L
s
.32684 .20543 m
.32684 .20918 L
s
.37013 .20543 m
.37013 .20918 L
s
.41342 .20543 m
.41342 .20918 L
s
.45671 .20543 m
.45671 .20918 L
s
.54329 .20543 m
.54329 .20918 L
s
.58658 .20543 m
.58658 .20918 L
s
.62987 .20543 m
.62987 .20918 L
s
.67316 .20543 m
.67316 .20918 L
s
.75974 .20543 m
.75974 .20918 L
s
.80303 .20543 m
.80303 .20918 L
s
.84632 .20543 m
.84632 .20918 L
s
.88961 .20543 m
.88961 .20918 L
s
.02381 .20543 m
.02381 .20918 L
s
.97619 .20543 m
.97619 .20918 L
s
.25 Mabswid
0 .20543 m
1 .20543 L
s
[(t)] 1.025 .20543 -1 0 Mshowa
.5 .06764 m
.50625 .06764 L
s
[(-1)] .4875 .06764 1 0 Mshowa
.5 .34321 m
.50625 .34321 L
s
[(1)] .4875 .34321 1 0 Mshowa
.5 .481 m
.50625 .481 L
s
[(2)] .4875 .481 1 0 Mshowa
.125 Mabswid
.5 .0952 m
.50375 .0952 L
s
.5 .12275 m
.50375 .12275 L
s
.5 .15031 m
.50375 .15031 L
s
.5 .17787 m
.50375 .17787 L
s
.5 .23298 m
.50375 .23298 L
s
.5 .26054 m
.50375 .26054 L
s
.5 .2881 m
.50375 .2881 L
s
.5 .31565 m
.50375 .31565 L
s
.5 .37077 m
.50375 .37077 L
s
.5 .39833 m
.50375 .39833 L
s
.5 .42588 m
.50375 .42588 L
s
.5 .45344 m
.50375 .45344 L
s
.5 .50855 m
.50375 .50855 L
s
.5 .53611 m
.50375 .53611 L
s
.5 .56367 m
.50375 .56367 L
s
.5 .59122 m
.50375 .59122 L
s
.5 .04008 m
.50375 .04008 L
s
.5 .01253 m
.50375 .01253 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(phi\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .20543 m
.02415 .20543 L
.02449 .20543 L
.02482 .20543 L
.02516 .20543 L
.0255 .20543 L
.02584 .20543 L
.02618 .20543 L
.02652 .20543 L
.02685 .20543 L
.02719 .20543 L
.02753 .20543 L
.02787 .20543 L
.02821 .20543 L
.02854 .20543 L
.02888 .20543 L
.02922 .20543 L
.02956 .20543 L
.0299 .20543 L
.03024 .20543 L
.03057 .20543 L
.03091 .20543 L
.03125 .20543 L
.03159 .20543 L
.03193 .20543 L
.03226 .20543 L
.0326 .20543 L
.03294 .20543 L
.03328 .20543 L
.03362 .20543 L
.03396 .20543 L
.03429 .20543 L
.03463 .20543 L
.03497 .20543 L
.03531 .20543 L
.03565 .20543 L
.03598 .20543 L
.03632 .20543 L
.03666 .20543 L
.037 .20543 L
.03734 .20543 L
.03768 .20543 L
.03801 .20543 L
.03835 .20543 L
.03869 .20543 L
.03903 .20543 L
.03937 .20543 L
.03971 .20543 L
.04004 .20543 L
.04038 .20543 L
Mistroke
.04072 .20543 L
.04106 .20543 L
.0414 .20543 L
.04173 .20543 L
.04207 .20543 L
.04241 .20543 L
.04275 .20543 L
.04309 .20543 L
.04343 .20543 L
.04376 .20543 L
.0441 .20543 L
.04444 .20543 L
.04478 .20543 L
.04512 .20543 L
.04545 .20543 L
.04579 .20543 L
.04613 .20543 L
.04647 .20543 L
.04681 .20543 L
.04715 .20543 L
.04748 .20543 L
.04782 .20543 L
.04816 .20543 L
.0485 .20543 L
.04884 .20543 L
.04917 .20543 L
.04951 .20543 L
.04985 .20543 L
.05019 .20543 L
.05053 .20543 L
.05087 .20543 L
.0512 .20543 L
.05154 .20543 L
.05188 .20543 L
.05222 .20543 L
.05256 .20543 L
.0529 .20543 L
.05323 .20543 L
.05357 .20543 L
.05391 .20543 L
.05425 .20543 L
.05459 .20543 L
.05492 .20543 L
.05526 .20543 L
.0556 .20543 L
.05594 .20543 L
.05628 .20543 L
.05662 .20543 L
.05695 .20543 L
.05729 .20543 L
Mistroke
.05763 .20543 L
.05797 .20543 L
.05831 .20543 L
.05864 .20543 L
.05898 .20543 L
.05932 .20543 L
.05966 .20543 L
.06 .20543 L
.06034 .20543 L
.06067 .20543 L
.06101 .20543 L
.06135 .20543 L
.06169 .20543 L
.06203 .20543 L
.06236 .20543 L
.0627 .20543 L
.06304 .20543 L
.06338 .20543 L
.06372 .20543 L
.06406 .20543 L
.06439 .20543 L
.06473 .20543 L
.06507 .20543 L
.06541 .20543 L
.06575 .20543 L
.06608 .20543 L
.06642 .20543 L
.06676 .20543 L
.0671 .20543 L
.06744 .20543 L
.06778 .20543 L
.06811 .20543 L
.06845 .20543 L
.06879 .20543 L
.06913 .20543 L
.06947 .20543 L
.06981 .20543 L
.07014 .20543 L
.07048 .20543 L
.07082 .20543 L
.07116 .20543 L
.0715 .20543 L
.07183 .20543 L
.07217 .20543 L
.07251 .20543 L
.07285 .20543 L
.07319 .20543 L
.07353 .20543 L
.07386 .20543 L
.0742 .20543 L
Mistroke
.07454 .20543 L
.07488 .20543 L
.07522 .20543 L
.07555 .20543 L
.07589 .20543 L
.07623 .20543 L
.07657 .20543 L
.07691 .20543 L
.07725 .20543 L
.07758 .20543 L
.07792 .20543 L
.07826 .20543 L
.0786 .20543 L
.07894 .20543 L
.07927 .20543 L
.07961 .20543 L
.07995 .20543 L
.08029 .20543 L
.08063 .20543 L
.08097 .20543 L
.0813 .20543 L
.08164 .20543 L
.08198 .20543 L
.08232 .20543 L
.08266 .20543 L
.083 .20543 L
.08333 .20543 L
.08367 .20543 L
.08401 .20543 L
.08435 .20543 L
.08469 .20543 L
.08502 .20543 L
.08536 .20543 L
.0857 .20543 L
.08604 .20543 L
.08638 .20543 L
.08672 .20543 L
.08705 .20543 L
.08739 .20543 L
.08773 .20543 L
.08807 .20543 L
.08841 .20543 L
.08874 .20543 L
.08908 .20543 L
.08942 .20543 L
.08976 .20543 L
.0901 .20543 L
.09044 .20543 L
.09077 .20543 L
.09111 .20543 L
Mistroke
.09145 .20543 L
.09179 .20543 L
.09213 .20543 L
.09246 .20543 L
.0928 .20543 L
.09314 .20543 L
.09348 .20543 L
.09382 .20543 L
.09416 .20543 L
.09449 .20543 L
.09483 .20543 L
.09517 .20543 L
.09551 .20543 L
.09585 .20543 L
.09619 .20543 L
.09652 .20543 L
.09686 .20543 L
.0972 .20543 L
.09754 .20543 L
.09788 .20543 L
.09821 .20543 L
.09855 .20543 L
.09889 .20543 L
.09923 .20543 L
.09957 .20543 L
.09991 .20543 L
.10024 .20543 L
.10058 .20543 L
.10092 .20543 L
.10126 .20543 L
.1016 .20543 L
.10193 .20543 L
.10227 .20543 L
.10261 .20543 L
.10295 .20543 L
.10329 .20543 L
.10363 .20543 L
.10396 .20543 L
.1043 .20543 L
.10464 .20543 L
.10498 .20543 L
.10532 .20543 L
.10565 .20543 L
.10599 .20543 L
.10633 .20543 L
.10667 .20543 L
.10701 .20543 L
.10735 .20543 L
.10768 .20543 L
.10802 .20543 L
Mistroke
.10836 .20543 L
.1087 .20543 L
.10904 .20543 L
.10938 .20543 L
.10971 .20543 L
.11005 .20543 L
.11039 .20543 L
.11073 .20543 L
.11107 .20543 L
.1114 .20543 L
.11174 .20543 L
.11208 .20543 L
.11242 .20543 L
.11276 .20543 L
.1131 .20543 L
.11343 .20543 L
.11377 .20543 L
.11411 .20543 L
.11445 .20543 L
.11479 .20543 L
.11512 .20543 L
.11546 .20543 L
.1158 .20543 L
.11614 .20543 L
.11648 .20543 L
.11682 .20543 L
.11715 .20543 L
.11749 .20543 L
.11783 .20543 L
.11817 .20543 L
.11851 .20543 L
.11884 .20543 L
.11918 .20543 L
.11952 .20543 L
.11986 .20543 L
.1202 .20543 L
.12054 .20543 L
.12087 .20543 L
.12121 .20543 L
.12155 .20543 L
.12189 .20543 L
.12223 .20543 L
.12256 .20543 L
.1229 .20543 L
.12324 .20543 L
.12358 .20543 L
.12392 .20543 L
.12426 .20543 L
.12459 .20543 L
.12493 .20543 L
Mistroke
.12527 .20543 L
.12561 .20543 L
.12595 .20543 L
.12629 .20543 L
.12662 .20543 L
.12696 .20543 L
.1273 .20543 L
.12764 .20543 L
.12798 .20543 L
.12831 .20543 L
.12865 .20543 L
.12899 .20543 L
.12933 .20543 L
.12967 .20543 L
.13001 .20543 L
.13034 .20543 L
.13068 .20543 L
.13102 .20543 L
.13136 .20543 L
.1317 .20543 L
.13203 .20543 L
.13237 .20543 L
.13271 .20543 L
.13305 .20543 L
.13339 .20543 L
.13373 .20543 L
.13406 .20543 L
.1344 .20543 L
.13474 .20543 L
.13508 .20543 L
.13542 .20543 L
.13575 .20543 L
.13609 .20543 L
.13643 .20543 L
.13677 .20543 L
.13711 .20543 L
.13745 .20543 L
.13778 .20543 L
.13812 .20543 L
.13846 .20543 L
.1388 .20543 L
.13914 .20543 L
.13948 .20543 L
.13981 .20543 L
.14015 .20543 L
.14049 .20543 L
.14083 .20543 L
.14117 .20543 L
.1415 .20543 L
.14184 .20543 L
Mistroke
.14218 .20543 L
.14252 .20543 L
.14286 .20543 L
.1432 .20543 L
.14353 .20543 L
.14387 .20543 L
.14421 .20543 L
.14455 .20543 L
.14489 .20543 L
.14522 .20543 L
.14556 .20543 L
.1459 .20543 L
.14624 .20543 L
.14658 .20543 L
.14692 .20543 L
.14725 .20543 L
.14759 .20543 L
.14793 .20543 L
.14827 .20543 L
.14861 .20543 L
.14894 .20543 L
.14928 .20543 L
.14962 .20543 L
.14996 .20543 L
.1503 .20543 L
.15064 .20543 L
.15097 .20543 L
.15131 .20543 L
.15165 .20543 L
.15199 .20543 L
.15233 .20543 L
.15267 .20543 L
.153 .20543 L
.15334 .20543 L
.15368 .20543 L
.15402 .20543 L
.15436 .20543 L
.15469 .20543 L
.15503 .20543 L
.15537 .20543 L
.15571 .20543 L
.15605 .20543 L
.15639 .20543 L
.15672 .20543 L
.15706 .20543 L
.1574 .20543 L
.15774 .20543 L
.15808 .20543 L
.15841 .20542 L
.15875 .20542 L
Mistroke
.15909 .20542 L
.15943 .20542 L
.15977 .20542 L
.16011 .20542 L
.16044 .20542 L
.16078 .20543 L
.16112 .20543 L
.16146 .20543 L
.1618 .20543 L
.16213 .20543 L
.16247 .20543 L
.16281 .20543 L
.16315 .20542 L
.16349 .20542 L
.16383 .20542 L
.16416 .20542 L
.1645 .20542 L
.16484 .20543 L
.16518 .20543 L
.16552 .20543 L
.16585 .20543 L
.16619 .20543 L
.16653 .20543 L
.16687 .20543 L
.16721 .20543 L
.16755 .20543 L
.16788 .20543 L
.16822 .20543 L
.16856 .20543 L
.1689 .20543 L
.16924 .20543 L
.16958 .20543 L
.16991 .20543 L
.17025 .20543 L
.17059 .20543 L
.17093 .20543 L
.17127 .20543 L
.1716 .20543 L
.17194 .20543 L
.17228 .20543 L
.17262 .20543 L
.17296 .20543 L
.1733 .20542 L
.17363 .20542 L
.17397 .20542 L
.17431 .20542 L
.17465 .20542 L
.17499 .20542 L
.17532 .20542 L
.17566 .20542 L
Mistroke
.176 .20543 L
.17634 .20543 L
.17668 .20543 L
.17702 .20543 L
.17735 .20543 L
.17769 .20543 L
.17803 .20543 L
.17837 .20543 L
.17871 .20543 L
.17904 .20543 L
.17938 .20543 L
.17972 .20543 L
.18006 .20543 L
.1804 .20543 L
.18074 .20543 L
.18107 .20543 L
.18141 .20543 L
.18175 .20543 L
.18209 .20543 L
.18243 .20543 L
.18277 .20543 L
.1831 .20543 L
.18344 .20543 L
.18378 .20543 L
.18412 .20543 L
.18446 .20543 L
.18479 .20544 L
.18513 .20544 L
.18547 .20544 L
.18581 .20544 L
.18615 .20544 L
.18649 .20544 L
.18682 .20543 L
.18716 .20543 L
.1875 .20543 L
.18784 .20543 L
.18818 .20543 L
.18851 .20543 L
.18885 .20543 L
.18919 .20542 L
.18953 .20542 L
.18987 .20542 L
.19021 .20542 L
.19054 .20542 L
.19088 .20542 L
.19122 .20541 L
.19156 .20541 L
.1919 .20541 L
.19223 .20541 L
.19257 .20541 L
Mistroke
.19291 .20541 L
.19325 .20541 L
.19359 .20542 L
.19393 .20542 L
.19426 .20542 L
.1946 .20542 L
.19494 .20541 L
.19528 .20541 L
.19562 .20541 L
.19596 .20541 L
.19629 .20541 L
.19663 .20541 L
.19697 .20541 L
.19731 .20541 L
.19765 .20541 L
.19798 .20541 L
.19832 .20541 L
.19866 .20541 L
.199 .20541 L
.19934 .20541 L
.19968 .20541 L
.20001 .20541 L
.20035 .20542 L
.20069 .20542 L
.20103 .20542 L
.20137 .20542 L
.2017 .20542 L
.20204 .20542 L
.20238 .20542 L
.20272 .20542 L
.20306 .20542 L
.2034 .20542 L
.20373 .20541 L
.20407 .20541 L
.20441 .20541 L
.20475 .20541 L
.20509 .20541 L
.20542 .20541 L
.20576 .20541 L
.2061 .20541 L
.20644 .2054 L
.20678 .2054 L
.20712 .2054 L
.20745 .2054 L
.20779 .2054 L
.20813 .20541 L
.20847 .20541 L
.20881 .20541 L
.20915 .20542 L
.20948 .20542 L
Mistroke
.20982 .20543 L
.21016 .20543 L
.2105 .20544 L
.21084 .20544 L
.21117 .20544 L
.21151 .20545 L
.21185 .20545 L
.21219 .20545 L
.21253 .20546 L
.21287 .20546 L
.2132 .20546 L
.21354 .20547 L
.21388 .20547 L
.21422 .20547 L
.21456 .20548 L
.21489 .20548 L
.21523 .20548 L
.21557 .20548 L
.21591 .20549 L
.21625 .20549 L
.21659 .2055 L
.21692 .2055 L
.21726 .2055 L
.2176 .20551 L
.21794 .20551 L
.21828 .20551 L
.21861 .20551 L
.21895 .20551 L
.21929 .20551 L
.21963 .2055 L
.21997 .20549 L
.22031 .20549 L
.22064 .20548 L
.22098 .20547 L
.22132 .20547 L
.22166 .20546 L
.222 .20545 L
.22233 .20545 L
.22267 .20544 L
.22301 .20543 L
.22335 .20542 L
.22369 .20541 L
.22403 .20541 L
.22436 .20541 L
.2247 .20541 L
.22504 .20541 L
.22538 .20541 L
.22572 .20541 L
.22606 .20541 L
.22639 .20541 L
Mistroke
.22673 .20541 L
.22707 .20541 L
.22741 .2054 L
.22775 .20539 L
.22808 .20539 L
.22842 .20539 L
.22876 .20538 L
.2291 .20538 L
.22944 .20538 L
.22978 .20538 L
.23011 .20537 L
.23045 .20537 L
.23079 .20537 L
.23113 .20537 L
.23147 .20536 L
.2318 .20536 L
.23214 .20536 L
.23248 .20536 L
.23282 .20537 L
.23316 .20537 L
.2335 .20537 L
.23383 .20538 L
.23417 .20538 L
.23451 .20538 L
.23485 .20538 L
.23519 .20537 L
.23552 .20536 L
.23586 .20535 L
.2362 .20533 L
.23654 .20532 L
.23688 .20532 L
.23722 .20531 L
.23755 .2053 L
.23789 .20529 L
.23823 .20528 L
.23857 .20528 L
.23891 .20528 L
.23925 .20527 L
.23958 .20526 L
.23992 .20526 L
.24026 .20526 L
.2406 .20527 L
.24094 .20528 L
.24127 .2053 L
.24161 .20531 L
.24195 .20533 L
.24229 .20535 L
.24263 .20538 L
.24297 .20539 L
.2433 .2054 L
Mistroke
.24364 .20541 L
.24398 .20541 L
.24432 .20542 L
.24466 .20543 L
.24499 .20545 L
.24533 .20546 L
.24567 .20548 L
.24601 .20549 L
.24635 .20551 L
.24669 .20553 L
.24702 .20556 L
.24736 .20557 L
.2477 .20558 L
.24804 .20559 L
.24838 .2056 L
.24871 .20562 L
.24905 .20565 L
.24939 .20567 L
.24973 .20569 L
.25007 .20571 L
.25041 .20572 L
.25074 .20574 L
.25108 .20575 L
.25142 .20573 L
.25176 .20571 L
.2521 .20568 L
.25244 .20566 L
.25277 .20564 L
.25311 .20562 L
.25345 .20559 L
.25379 .20556 L
.25413 .20554 L
.25446 .20552 L
.2548 .2055 L
.25514 .20548 L
.25548 .20545 L
.25582 .20542 L
.25616 .20539 L
.25649 .20537 L
.25683 .20537 L
.25717 .20537 L
.25751 .20537 L
.25785 .20537 L
.25818 .20538 L
.25852 .20539 L
.25886 .2054 L
.2592 .2054 L
.25954 .20539 L
.25988 .20537 L
.26021 .20534 L
Mistroke
.26055 .20533 L
.26089 .20532 L
.26123 .20532 L
.26157 .20531 L
.2619 .20531 L
.26224 .20531 L
.26258 .20532 L
.26292 .20533 L
.26326 .20534 L
.2636 .20534 L
.26393 .20533 L
.26427 .20533 L
.26461 .20534 L
.26495 .20536 L
.26529 .2054 L
.26563 .20542 L
.26596 .20544 L
.2663 .20547 L
.26664 .2055 L
.26698 .20552 L
.26732 .20553 L
.26765 .20551 L
.26799 .20547 L
.26833 .20543 L
.26867 .20539 L
.26901 .20537 L
.26935 .20535 L
.26968 .20532 L
.27002 .20529 L
.27036 .20527 L
.2707 .20526 L
.27104 .20525 L
.27137 .20525 L
.27171 .20523 L
.27205 .20521 L
.27239 .2052 L
.27273 .2052 L
.27307 .20524 L
.2734 .20529 L
.27374 .20534 L
.27408 .20539 L
.27442 .20546 L
.27476 .20553 L
.27509 .2056 L
.27543 .20567 L
.27577 .20569 L
.27611 .20571 L
.27645 .20572 L
.27679 .20574 L
.27712 .20577 L
Mistroke
.27746 .20582 L
.2778 .20585 L
.27814 .20589 L
.27848 .20594 L
.27881 .206 L
.27915 .20608 L
.27949 .20614 L
.27983 .20617 L
.28017 .20619 L
.28051 .20622 L
.28084 .20626 L
.28118 .20632 L
.28152 .20639 L
.28186 .20644 L
.2822 .20648 L
.28254 .20653 L
.28287 .20656 L
.28321 .20659 L
.28355 .20659 L
.28389 .20653 L
.28423 .20643 L
.28456 .20632 L
.2849 .2062 L
.28524 .2061 L
.28558 .206 L
.28592 .20587 L
.28626 .20575 L
.28659 .20564 L
.28693 .20554 L
.28727 .20545 L
.28761 .20536 L
.28795 .20522 L
.28828 .20508 L
.28862 .20496 L
.28896 .20485 L
.2893 .20478 L
.28964 .20473 L
.28998 .20466 L
.29031 .20461 L
.29065 .20458 L
.29099 .20454 L
.29133 .20452 L
.29167 .20448 L
.292 .20438 L
.29234 .20426 L
.29268 .20414 L
.29302 .20403 L
.29336 .20396 L
.2937 .20389 L
.29403 .20381 L
Mistroke
.29437 .20375 L
.29471 .20373 L
.29505 .20372 L
.29539 .20374 L
.29573 .20375 L
.29606 .20371 L
.2964 .20367 L
.29674 .20366 L
.29708 .20366 L
.29742 .2037 L
.29775 .20376 L
.29809 .20379 L
.29843 .20384 L
.29877 .2039 L
.29911 .20395 L
.29945 .20401 L
.29978 .20403 L
.30012 .20395 L
.30046 .20384 L
.3008 .20372 L
.30114 .20361 L
.30147 .20352 L
.30181 .20345 L
.30215 .20335 L
.30249 .20327 L
.30283 .20323 L
.30317 .20321 L
.3035 .20322 L
.30384 .20323 L
.30418 .20318 L
.30452 .20314 L
.30486 .20312 L
.30519 .20315 L
.30553 .20324 L
.30587 .20336 L
.30621 .20347 L
.30655 .2036 L
.30689 .20378 L
.30722 .20397 L
.30756 .20417 L
.3079 .20434 L
.30824 .20441 L
.30858 .20444 L
.30892 .2045 L
.30925 .20456 L
.30959 .20466 L
.30993 .20479 L
.31027 .20489 L
.31061 .20503 L
.31094 .20525 L
Mistroke
.31128 .20549 L
.31162 .20578 L
.31196 .20604 L
.3123 .20622 L
.31264 .20638 L
.31297 .20657 L
.31331 .20678 L
.31365 .20703 L
.31399 .20729 L
.31433 .20749 L
.31466 .2077 L
.315 .20794 L
.31534 .20815 L
.31568 .20834 L
.31602 .20845 L
.31636 .20838 L
.31669 .20823 L
.31703 .20807 L
.31737 .20788 L
.31771 .20771 L
.31805 .20755 L
.31838 .20732 L
.31872 .20712 L
.31906 .207 L
.3194 .2069 L
.31974 .20684 L
.32008 .20675 L
.32041 .20657 L
.32075 .20636 L
.32109 .20621 L
.32143 .20608 L
.32177 .20601 L
.3221 .20597 L
.32244 .20589 L
.32278 .20585 L
.32312 .20588 L
.32346 .20594 L
.3238 .206 L
.32413 .20601 L
.32447 .20587 L
.32481 .20569 L
.32515 .20555 L
.32549 .20542 L
.32583 .20535 L
.32616 .20532 L
.3265 .20527 L
.32684 .20529 L
.32718 .20546 L
.32752 .2057 L
.32785 .20601 L
Mistroke
.32819 .2063 L
.32853 .2065 L
.32887 .20668 L
.32921 .20692 L
.32955 .2072 L
.32988 .20755 L
.33022 .20792 L
.33056 .20823 L
.3309 .20855 L
.33124 .20895 L
.33157 .20935 L
.33191 .20972 L
.33225 .20999 L
.33259 .21003 L
.33293 .20997 L
.33327 .20991 L
.3336 .20983 L
.33394 .20978 L
.33428 .20975 L
.33462 .20966 L
.33496 .20961 L
.33529 .2097 L
.33563 .20984 L
.33597 .21003 L
.33631 .2102 L
.33665 .21023 L
.33699 .21023 L
.33732 .21031 L
.33766 .21043 L
.338 .21064 L
.33834 .2109 L
.33868 .21109 L
.33902 .21133 L
.33935 .21168 L
.33969 .21206 L
.34003 .21243 L
.34037 .21271 L
.34071 .21275 L
.34104 .2127 L
.34138 .21269 L
.34172 .21268 L
.34206 .21273 L
.3424 .21281 L
.34274 .21284 L
.34307 .21296 L
.34341 .21328 L
.34375 .2137 L
.34409 .21416 L
.34443 .21459 L
.34476 .21482 L
Mistroke
.3451 .21499 L
.34544 .21522 L
.34578 .21546 L
.34612 .21573 L
.34646 .21599 L
.34679 .21611 L
.34713 .21621 L
.34747 .21641 L
.34781 .21656 L
.34815 .21663 L
.34848 .21648 L
.34882 .21596 L
.34916 .21524 L
.3495 .2145 L
.34984 .21367 L
.35018 .21283 L
.35051 .21196 L
.35085 .21097 L
.35119 .21004 L
.35153 .20932 L
.35187 .20867 L
.35221 .20805 L
.35254 .20737 L
.35288 .20647 L
.35322 .20551 L
.35356 .20464 L
.3539 .20377 L
.35423 .20294 L
.35457 .20212 L
.35491 .2012 L
.35525 .20034 L
.35559 .19969 L
.35593 .19908 L
.35626 .19845 L
.3566 .19772 L
.35694 .19671 L
.35728 .1956 L
.35762 .19461 L
.35795 .19363 L
.35829 .19272 L
.35863 .19189 L
.35897 .19105 L
.35931 .19041 L
.35965 .19016 L
.35998 .19011 L
.36032 .19018 L
.36066 .19026 L
.361 .19016 L
.36134 .19005 L
.36167 .1901 L
Mistroke
.36201 .19018 L
.36235 .19029 L
.36269 .19041 L
.36303 .19041 L
.36337 .19048 L
.3637 .19076 L
.36404 .19107 L
.36438 .1913 L
.36472 .19136 L
.36506 .19105 L
.3654 .19056 L
.36573 .19012 L
.36607 .18963 L
.36641 .18913 L
.36675 .18864 L
.36709 .18806 L
.36742 .18762 L
.36776 .18753 L
.3681 .18759 L
.36844 .18769 L
.36878 .18776 L
.36912 .18759 L
.36945 .18737 L
.36979 .18728 L
.37013 .1872 L
.37047 .18711 L
.37081 .18702 L
.37114 .1868 L
.37148 .18667 L
.37182 .18684 L
.37216 .18707 L
.3725 .18725 L
.37284 .18729 L
.37317 .18696 L
.37351 .18649 L
.37385 .18618 L
.37419 .18587 L
.37453 .18558 L
.37486 .18538 L
.3752 .18515 L
.37554 .18518 L
.37588 .18576 L
.37622 .1866 L
.37656 .18753 L
.37689 .18846 L
.37723 .18911 L
.37757 .18969 L
.37791 .19046 L
.37825 .19121 L
.37858 .1919 L
Mistroke
.37892 .19255 L
.37926 .19297 L
.3796 .19344 L
.37994 .19421 L
.38028 .19497 L
.38061 .19556 L
.38095 .19586 L
.38129 .19557 L
.38163 .195 L
.38197 .19449 L
.38231 .19385 L
.38264 .19309 L
.38298 .19232 L
.38332 .1914 L
.38366 .19069 L
.384 .19053 L
.38433 .1906 L
.38467 .19068 L
.38501 .19071 L
.38535 .19042 L
.38569 .19002 L
.38603 .18983 L
.38636 .18959 L
.3867 .1892 L
.38704 .18877 L
.38738 .18817 L
.38772 .18772 L
.38805 .18777 L
.38839 .18795 L
.38873 .18807 L
.38907 .18807 L
.38941 .18767 L
.38975 .18718 L
.39008 .187 L
.39042 .18688 L
.39076 .18677 L
.3911 .18683 L
.39144 .18699 L
.39177 .18763 L
.39211 .18918 L
.39245 .19121 L
.39279 .19343 L
.39313 .19576 L
.39347 .1979 L
.3938 .20004 L
.39414 .20253 L
.39448 .20502 L
.39482 .20734 L
.39516 .20962 L
.3955 .21173 L
Mistroke
.39583 .21397 L
.39617 .21671 L
.39651 .21953 L
.39685 .22218 L
.39719 .2246 L
.39752 .22647 L
.39786 .2281 L
.3982 .22988 L
.39854 .23152 L
.39888 .23295 L
.39922 .23434 L
.39955 .23562 L
.39989 .23714 L
.40023 .23935 L
.40057 .24181 L
.40091 .24421 L
.40124 .24652 L
.40158 .24846 L
.40192 .25022 L
.40226 .25215 L
.4026 .25387 L
.40294 .25521 L
.40327 .25636 L
.40361 .25722 L
.40395 .25814 L
.40429 .25952 L
.40463 .26095 L
.40496 .26215 L
.4053 .26311 L
.40564 .26356 L
.40598 .2638 L
.40632 .26428 L
.40666 .26465 L
.40699 .26482 L
.40733 .26502 L
.40767 .26519 L
.40801 .26576 L
.40835 .26722 L
.40869 .26908 L
.40902 .27095 L
.40936 .2728 L
.4097 .27428 L
.41004 .27563 L
.41038 .2772 L
.41071 .27858 L
.41105 .27954 L
.41139 .28026 L
.41173 .28064 L
.41207 .28103 L
.41241 .28189 L
Mistroke
.41274 .28272 L
.41308 .28318 L
.41342 .28324 L
.41376 .2826 L
.4141 .28156 L
.41443 .28062 L
.41477 .2794 L
.41511 .27773 L
.41545 .27593 L
.41579 .27394 L
.41613 .27221 L
.41646 .27131 L
.4168 .27068 L
.41714 .26988 L
.41748 .26896 L
.41782 .26759 L
.41815 .26597 L
.41849 .26453 L
.41883 .26275 L
.41917 .26031 L
.41951 .25755 L
.41985 .25448 L
.42018 .2515 L
.42052 .24919 L
.42086 .24701 L
.4212 .24454 L
.42154 .24191 L
.42188 .23886 L
.42221 .23568 L
.42255 .23294 L
.42289 .23016 L
.42323 .22708 L
.42357 .22413 L
.4239 .22136 L
.42424 .21926 L
.42458 .2185 L
.42492 .21841 L
.42526 .2184 L
.4256 .21858 L
.42593 .21861 L
.42627 .21863 L
.42661 .21906 L
.42695 .21927 L
.42729 .2188 L
.42762 .21807 L
.42796 .21713 L
.4283 .21632 L
.42864 .21625 L
.42898 .21632 L
.42932 .21603 L
Mistroke
.42965 .21553 L
.42999 .21462 L
.43033 .21349 L
.43067 .21263 L
.43101 .2115 L
.43134 .20971 L
.43168 .20777 L
.43202 .20575 L
.43236 .20407 L
.4327 .20336 L
.43304 .20297 L
.43337 .20224 L
.43371 .20139 L
.43405 .20019 L
.43439 .19867 L
.43473 .19722 L
.43506 .19516 L
.4354 .19197 L
.43574 .18819 L
.43608 .18399 L
.43642 .17976 L
.43676 .17615 L
.43709 .1726 L
.43743 .16856 L
.43777 .16434 L
.43811 .15982 L
.43845 .15517 L
.43879 .15093 L
.43912 .14653 L
.43946 .14154 L
.4398 .13656 L
.44014 .13175 L
.44048 .12756 L
.44081 .12469 L
.44115 .12245 L
.44149 .12015 L
.44183 .11802 L
.44217 .1158 L
.44251 .11355 L
.44284 .11168 L
.44318 .1095 L
.44352 .10646 L
.44386 .10307 L
.4442 .0995 L
.44453 .09609 L
.44487 .0935 L
.44521 .09111 L
.44555 .08835 L
.44589 .0855 L
.44623 .08241 L
Mistroke
.44656 .07922 L
.4469 .07645 L
.44724 .07348 L
.44758 .06986 L
.44792 .06618 L
.44825 .06262 L
.44859 .05959 L
.44893 .05781 L
.44927 .05654 L
.44961 .05506 L
.44995 .05366 L
.45028 .05213 L
.45062 .05048 L
.45096 .04913 L
.4513 .0473 L
.45164 .04433 L
.45198 .04091 L
.45231 .03732 L
.45265 .03394 L
.45299 .03155 L
.45333 .02951 L
.45367 .02717 L
.454 .02494 L
.45434 .02277 L
.45468 .02078 L
.45502 .01956 L
.45536 .01843 L
.4557 .01683 L
.45603 .0155 L
.45637 .01472 L
.45671 .01494 L
.45705 .01698 L
.45739 .02003 L
.45772 .02322 L
.45806 .02691 L
.4584 .03089 L
.45874 .03508 L
.45908 .03991 L
.45942 .0445 L
.45975 .04808 L
.46009 .05137 L
.46043 .0547 L
.46077 .05837 L
.46111 .06309 L
.46144 .06822 L
.46178 .07304 L
.46212 .07801 L
.46246 .08316 L
.4628 .08842 L
.46314 .09423 L
Mistroke
.46347 .09985 L
.46381 .10459 L
.46415 .10922 L
.46449 .11406 L
.46483 .11939 L
.46517 .12591 L
.4655 .13286 L
.46584 .13935 L
.46618 .14586 L
.46652 .15235 L
.46686 .15856 L
.46719 .1648 L
.46753 .17019 L
.46787 .17386 L
.46821 .17668 L
.46855 .17918 L
.46889 .18158 L
.46922 .18463 L
.46956 .18777 L
.4699 .19031 L
.47024 .19289 L
.47058 .19572 L
.47091 .19866 L
.47125 .20208 L
.47159 .2053 L
.47193 .20762 L
.47227 .20986 L
.47261 .21249 L
.47294 .21573 L
.47328 .22024 L
.47362 .22538 L
.47396 .2303 L
.4743 .23553 L
.47463 .24112 L
.47497 .24678 L
.47531 .25277 L
.47565 .25829 L
.47599 .26252 L
.47633 .26626 L
.47666 .27006 L
.477 .27403 L
.47734 .27879 L
.47768 .28388 L
.47802 .28861 L
.47835 .29363 L
.47869 .29919 L
.47903 .30502 L
.47937 .31137 L
.47971 .31754 L
.48005 .32279 L
Mistroke
.48038 .3279 L
.48072 .33333 L
.48106 .33918 L
.4814 .346 L
.48174 .35318 L
.48208 .35987 L
.48241 .36664 L
.48275 .37362 L
.48309 .38042 L
.48343 .38722 L
.48377 .39319 L
.4841 .39743 L
.48444 .40085 L
.48478 .40408 L
.48512 .40724 L
.48546 .41099 L
.4858 .41489 L
.48613 .41821 L
.48647 .4217 L
.48681 .42565 L
.48715 .42982 L
.48749 .4345 L
.48782 .43899 L
.48816 .44251 L
.4885 .44594 L
.48884 .44983 L
.48918 .4543 L
.48952 .45998 L
.48985 .46624 L
.49019 .47219 L
.49053 .47843 L
.49087 .48514 L
.49121 .49188 L
.49154 .49882 L
.49188 .50511 L
.49222 .5098 L
.49256 .51382 L
.4929 .51785 L
.49324 .5219 L
.49357 .52656 L
.49391 .53143 L
.49425 .53575 L
.49459 .54032 L
.49493 .54556 L
.49527 .551 L
.4956 .55677 L
.49594 .56213 L
.49628 .56615 L
.49662 .56971 L
.49696 .57345 L
Mistroke
.49729 .5773 L
.49763 .58176 L
.49797 .58624 L
.49831 .58979 L
.49865 .59315 L
.49899 .59663 L
.49932 .5996 L
.49966 .60212 L
.5 .60332 L
.50034 .60212 L
.50068 .5996 L
.50101 .59663 L
.50135 .59315 L
.50169 .58979 L
.50203 .58624 L
.50237 .58176 L
.50271 .5773 L
.50304 .57345 L
.50338 .56971 L
.50372 .56615 L
.50406 .56213 L
.5044 .55677 L
.50473 .551 L
.50507 .54556 L
.50541 .54032 L
.50575 .53575 L
.50609 .53143 L
.50643 .52656 L
.50676 .5219 L
.5071 .51785 L
.50744 .51382 L
.50778 .5098 L
.50812 .50511 L
.50846 .49882 L
.50879 .49188 L
.50913 .48514 L
.50947 .47843 L
.50981 .47219 L
.51015 .46624 L
.51048 .45998 L
.51082 .4543 L
.51116 .44983 L
.5115 .44594 L
.51184 .44251 L
.51218 .43899 L
.51251 .4345 L
.51285 .42982 L
.51319 .42565 L
.51353 .4217 L
.51387 .41821 L
Mistroke
.5142 .41489 L
.51454 .41099 L
.51488 .40724 L
.51522 .40408 L
.51556 .40085 L
.5159 .39743 L
.51623 .39319 L
.51657 .38722 L
.51691 .38042 L
.51725 .37362 L
.51759 .36664 L
.51792 .35987 L
.51826 .35318 L
.5186 .346 L
.51894 .33918 L
.51928 .33333 L
.51962 .3279 L
.51995 .32279 L
.52029 .31754 L
.52063 .31137 L
.52097 .30502 L
.52131 .29919 L
.52165 .29363 L
.52198 .28861 L
.52232 .28388 L
.52266 .27879 L
.523 .27403 L
.52334 .27006 L
.52367 .26626 L
.52401 .26252 L
.52435 .25829 L
.52469 .25277 L
.52503 .24678 L
.52537 .24112 L
.5257 .23553 L
.52604 .2303 L
.52638 .22538 L
.52672 .22024 L
.52706 .21573 L
.52739 .21249 L
.52773 .20986 L
.52807 .20762 L
.52841 .2053 L
.52875 .20208 L
.52909 .19866 L
.52942 .19572 L
.52976 .19289 L
.5301 .19031 L
.53044 .18777 L
.53078 .18463 L
Mistroke
.53111 .18158 L
.53145 .17918 L
.53179 .17668 L
.53213 .17386 L
.53247 .17019 L
.53281 .1648 L
.53314 .15856 L
.53348 .15235 L
.53382 .14586 L
.53416 .13935 L
.5345 .13286 L
.53483 .12591 L
.53517 .11939 L
.53551 .11406 L
.53585 .10922 L
.53619 .10459 L
.53653 .09985 L
.53686 .09423 L
.5372 .08842 L
.53754 .08316 L
.53788 .07801 L
.53822 .07304 L
.53856 .06822 L
.53889 .06309 L
.53923 .05837 L
.53957 .0547 L
.53991 .05137 L
.54025 .04808 L
.54058 .0445 L
.54092 .03991 L
.54126 .03508 L
.5416 .03089 L
.54194 .02691 L
.54228 .02322 L
.54261 .02003 L
.54295 .01698 L
.54329 .01494 L
.54363 .01472 L
.54397 .0155 L
.5443 .01683 L
.54464 .01843 L
.54498 .01956 L
.54532 .02078 L
.54566 .02277 L
.546 .02494 L
.54633 .02717 L
.54667 .02951 L
.54701 .03155 L
.54735 .03394 L
.54769 .03732 L
Mistroke
.54802 .04091 L
.54836 .04433 L
.5487 .0473 L
.54904 .04913 L
.54938 .05048 L
.54972 .05213 L
.55005 .05366 L
.55039 .05506 L
.55073 .05654 L
.55107 .05781 L
.55141 .05959 L
.55175 .06262 L
.55208 .06618 L
.55242 .06986 L
.55276 .07348 L
.5531 .07645 L
.55344 .07922 L
.55377 .08241 L
.55411 .0855 L
.55445 .08835 L
.55479 .09111 L
.55513 .0935 L
.55547 .09609 L
.5558 .0995 L
.55614 .10307 L
.55648 .10646 L
.55682 .1095 L
.55716 .11168 L
.55749 .11355 L
.55783 .1158 L
.55817 .11802 L
.55851 .12015 L
.55885 .12245 L
.55919 .12469 L
.55952 .12756 L
.55986 .13175 L
.5602 .13656 L
.56054 .14154 L
.56088 .14653 L
.56121 .15093 L
.56155 .15517 L
.56189 .15982 L
.56223 .16434 L
.56257 .16856 L
.56291 .1726 L
.56324 .17615 L
.56358 .17976 L
.56392 .18399 L
.56426 .18819 L
.5646 .19197 L
Mistroke
.56494 .19516 L
.56527 .19722 L
.56561 .19867 L
.56595 .20019 L
.56629 .20139 L
.56663 .20224 L
.56696 .20297 L
.5673 .20336 L
.56764 .20407 L
.56798 .20575 L
.56832 .20777 L
.56866 .20971 L
.56899 .2115 L
.56933 .21263 L
.56967 .21349 L
.57001 .21462 L
.57035 .21553 L
.57068 .21603 L
.57102 .21632 L
.57136 .21625 L
.5717 .21632 L
.57204 .21713 L
.57238 .21807 L
.57271 .2188 L
.57305 .21927 L
.57339 .21906 L
.57373 .21863 L
.57407 .21861 L
.5744 .21858 L
.57474 .2184 L
.57508 .21841 L
.57542 .2185 L
.57576 .21926 L
.5761 .22136 L
.57643 .22413 L
.57677 .22708 L
.57711 .23016 L
.57745 .23294 L
.57779 .23568 L
.57812 .23886 L
.57846 .24191 L
.5788 .24454 L
.57914 .24701 L
.57948 .24919 L
.57982 .2515 L
.58015 .25448 L
.58049 .25755 L
.58083 .26031 L
.58117 .26275 L
.58151 .26453 L
Mistroke
.58185 .26597 L
.58218 .26759 L
.58252 .26896 L
.58286 .26988 L
.5832 .27068 L
.58354 .27131 L
.58387 .27221 L
.58421 .27394 L
.58455 .27593 L
.58489 .27773 L
.58523 .2794 L
.58557 .28062 L
.5859 .28156 L
.58624 .2826 L
.58658 .28324 L
.58692 .28318 L
.58726 .28272 L
.58759 .28189 L
.58793 .28103 L
.58827 .28064 L
.58861 .28026 L
.58895 .27954 L
.58929 .27858 L
.58962 .2772 L
.58996 .27563 L
.5903 .27428 L
.59064 .2728 L
.59098 .27095 L
.59131 .26908 L
.59165 .26722 L
.59199 .26576 L
.59233 .26519 L
.59267 .26502 L
.59301 .26482 L
.59334 .26465 L
.59368 .26428 L
.59402 .2638 L
.59436 .26356 L
.5947 .26311 L
.59504 .26215 L
.59537 .26095 L
.59571 .25952 L
.59605 .25814 L
.59639 .25722 L
.59673 .25636 L
.59706 .25521 L
.5974 .25387 L
.59774 .25215 L
.59808 .25022 L
.59842 .24846 L
Mistroke
.59876 .24652 L
.59909 .24421 L
.59943 .24181 L
.59977 .23935 L
.60011 .23714 L
.60045 .23562 L
.60078 .23434 L
.60112 .23295 L
.60146 .23152 L
.6018 .22988 L
.60214 .2281 L
.60248 .22647 L
.60281 .2246 L
.60315 .22218 L
.60349 .21953 L
.60383 .21671 L
.60417 .21397 L
.6045 .21173 L
.60484 .20962 L
.60518 .20734 L
.60552 .20502 L
.60586 .20253 L
.6062 .20004 L
.60653 .1979 L
.60687 .19576 L
.60721 .19343 L
.60755 .19121 L
.60789 .18918 L
.60823 .18763 L
.60856 .18699 L
.6089 .18683 L
.60924 .18677 L
.60958 .18688 L
.60992 .187 L
.61025 .18718 L
.61059 .18767 L
.61093 .18807 L
.61127 .18807 L
.61161 .18795 L
.61195 .18777 L
.61228 .18772 L
.61262 .18817 L
.61296 .18877 L
.6133 .1892 L
.61364 .18959 L
.61397 .18983 L
.61431 .19002 L
.61465 .19042 L
.61499 .19071 L
.61533 .19068 L
Mistroke
.61567 .1906 L
.616 .19053 L
.61634 .19069 L
.61668 .1914 L
.61702 .19232 L
.61736 .19309 L
.61769 .19385 L
.61803 .19449 L
.61837 .195 L
.61871 .19557 L
.61905 .19586 L
.61939 .19556 L
.61972 .19497 L
.62006 .19421 L
.6204 .19344 L
.62074 .19297 L
.62108 .19255 L
.62142 .1919 L
.62175 .19121 L
.62209 .19046 L
.62243 .18969 L
.62277 .18911 L
.62311 .18846 L
.62344 .18753 L
.62378 .1866 L
.62412 .18576 L
.62446 .18518 L
.6248 .18515 L
.62514 .18538 L
.62547 .18558 L
.62581 .18587 L
.62615 .18618 L
.62649 .18649 L
.62683 .18696 L
.62716 .18729 L
.6275 .18725 L
.62784 .18707 L
.62818 .18684 L
.62852 .18667 L
.62886 .1868 L
.62919 .18702 L
.62953 .18711 L
.62987 .1872 L
.63021 .18728 L
.63055 .18737 L
.63088 .18759 L
.63122 .18776 L
.63156 .18769 L
.6319 .18759 L
.63224 .18753 L
Mistroke
.63258 .18762 L
.63291 .18806 L
.63325 .18864 L
.63359 .18913 L
.63393 .18963 L
.63427 .19012 L
.6346 .19056 L
.63494 .19105 L
.63528 .19136 L
.63562 .1913 L
.63596 .19107 L
.6363 .19076 L
.63663 .19048 L
.63697 .19041 L
.63731 .19041 L
.63765 .19029 L
.63799 .19018 L
.63833 .1901 L
.63866 .19005 L
.639 .19016 L
.63934 .19026 L
.63968 .19018 L
.64002 .19011 L
.64035 .19016 L
.64069 .19041 L
.64103 .19105 L
.64137 .19189 L
.64171 .19272 L
.64205 .19363 L
.64238 .19461 L
.64272 .1956 L
.64306 .19671 L
.6434 .19772 L
.64374 .19845 L
.64407 .19908 L
.64441 .19969 L
.64475 .20034 L
.64509 .2012 L
.64543 .20212 L
.64577 .20294 L
.6461 .20377 L
.64644 .20464 L
.64678 .20551 L
.64712 .20647 L
.64746 .20737 L
.64779 .20805 L
.64813 .20867 L
.64847 .20932 L
.64881 .21004 L
.64915 .21097 L
Mistroke
.64949 .21196 L
.64982 .21283 L
.65016 .21367 L
.6505 .2145 L
.65084 .21524 L
.65118 .21596 L
.65152 .21648 L
.65185 .21663 L
.65219 .21656 L
.65253 .21641 L
.65287 .21621 L
.65321 .21611 L
.65354 .21599 L
.65388 .21573 L
.65422 .21546 L
.65456 .21522 L
.6549 .21499 L
.65524 .21482 L
.65557 .21459 L
.65591 .21416 L
.65625 .2137 L
.65659 .21328 L
.65693 .21296 L
.65726 .21284 L
.6576 .21281 L
.65794 .21273 L
.65828 .21268 L
.65862 .21269 L
.65896 .2127 L
.65929 .21275 L
.65963 .21271 L
.65997 .21243 L
.66031 .21206 L
.66065 .21168 L
.66098 .21133 L
.66132 .21109 L
.66166 .2109 L
.662 .21064 L
.66234 .21043 L
.66268 .21031 L
.66301 .21023 L
.66335 .21023 L
.66369 .2102 L
.66403 .21003 L
.66437 .20984 L
.66471 .2097 L
.66504 .20961 L
.66538 .20966 L
.66572 .20975 L
.66606 .20978 L
Mistroke
.6664 .20983 L
.66673 .20991 L
.66707 .20997 L
.66741 .21003 L
.66775 .20999 L
.66809 .20972 L
.66843 .20935 L
.66876 .20895 L
.6691 .20855 L
.66944 .20823 L
.66978 .20792 L
.67012 .20755 L
.67045 .2072 L
.67079 .20692 L
.67113 .20668 L
.67147 .2065 L
.67181 .2063 L
.67215 .20601 L
.67248 .2057 L
.67282 .20546 L
.67316 .20529 L
.6735 .20527 L
.67384 .20532 L
.67417 .20535 L
.67451 .20542 L
.67485 .20555 L
.67519 .20569 L
.67553 .20587 L
.67587 .20601 L
.6762 .206 L
.67654 .20594 L
.67688 .20588 L
.67722 .20585 L
.67756 .20589 L
.6779 .20597 L
.67823 .20601 L
.67857 .20608 L
.67891 .20621 L
.67925 .20636 L
.67959 .20657 L
.67992 .20675 L
.68026 .20684 L
.6806 .2069 L
.68094 .207 L
.68128 .20712 L
.68162 .20732 L
.68195 .20755 L
.68229 .20771 L
.68263 .20788 L
.68297 .20807 L
Mistroke
.68331 .20823 L
.68364 .20838 L
.68398 .20845 L
.68432 .20834 L
.68466 .20815 L
.685 .20794 L
.68534 .2077 L
.68567 .20749 L
.68601 .20729 L
.68635 .20703 L
.68669 .20678 L
.68703 .20657 L
.68736 .20638 L
.6877 .20622 L
.68804 .20604 L
.68838 .20578 L
.68872 .20549 L
.68906 .20525 L
.68939 .20503 L
.68973 .20489 L
.69007 .20479 L
.69041 .20466 L
.69075 .20456 L
.69108 .2045 L
.69142 .20444 L
.69176 .20441 L
.6921 .20434 L
.69244 .20417 L
.69278 .20397 L
.69311 .20378 L
.69345 .2036 L
.69379 .20347 L
.69413 .20336 L
.69447 .20324 L
.69481 .20315 L
.69514 .20312 L
.69548 .20314 L
.69582 .20318 L
.69616 .20323 L
.6965 .20322 L
.69683 .20321 L
.69717 .20323 L
.69751 .20327 L
.69785 .20335 L
.69819 .20345 L
.69853 .20352 L
.69886 .20361 L
.6992 .20372 L
.69954 .20384 L
.69988 .20395 L
Mistroke
.70022 .20403 L
.70055 .20401 L
.70089 .20395 L
.70123 .2039 L
.70157 .20384 L
.70191 .20379 L
.70225 .20376 L
.70258 .2037 L
.70292 .20366 L
.70326 .20366 L
.7036 .20367 L
.70394 .20371 L
.70427 .20375 L
.70461 .20374 L
.70495 .20372 L
.70529 .20373 L
.70563 .20375 L
.70597 .20381 L
.7063 .20389 L
.70664 .20396 L
.70698 .20403 L
.70732 .20414 L
.70766 .20426 L
.708 .20438 L
.70833 .20448 L
.70867 .20452 L
.70901 .20454 L
.70935 .20458 L
.70969 .20461 L
.71002 .20466 L
.71036 .20473 L
.7107 .20478 L
.71104 .20485 L
.71138 .20496 L
.71172 .20508 L
.71205 .20522 L
.71239 .20536 L
.71273 .20545 L
.71307 .20554 L
.71341 .20564 L
.71374 .20575 L
.71408 .20587 L
.71442 .206 L
.71476 .2061 L
.7151 .2062 L
.71544 .20632 L
.71577 .20643 L
.71611 .20653 L
.71645 .20659 L
.71679 .20659 L
Mistroke
.71713 .20656 L
.71746 .20653 L
.7178 .20648 L
.71814 .20644 L
.71848 .20639 L
.71882 .20632 L
.71916 .20626 L
.71949 .20622 L
.71983 .20619 L
.72017 .20617 L
.72051 .20614 L
.72085 .20608 L
.72119 .206 L
.72152 .20594 L
.72186 .20589 L
.7222 .20585 L
.72254 .20582 L
.72288 .20577 L
.72321 .20574 L
.72355 .20572 L
.72389 .20571 L
.72423 .20569 L
.72457 .20567 L
.72491 .2056 L
.72524 .20553 L
.72558 .20546 L
.72592 .20539 L
.72626 .20534 L
.7266 .20529 L
.72693 .20524 L
.72727 .2052 L
.72761 .2052 L
.72795 .20521 L
.72829 .20523 L
.72863 .20525 L
.72896 .20525 L
.7293 .20526 L
.72964 .20527 L
.72998 .20529 L
.73032 .20532 L
.73065 .20535 L
.73099 .20537 L
.73133 .20539 L
.73167 .20543 L
.73201 .20547 L
.73235 .20551 L
.73268 .20553 L
.73302 .20552 L
.73336 .2055 L
.7337 .20547 L
Mistroke
.73404 .20544 L
.73437 .20542 L
.73471 .2054 L
.73505 .20536 L
.73539 .20534 L
.73573 .20533 L
.73607 .20533 L
.7364 .20534 L
.73674 .20534 L
.73708 .20533 L
.73742 .20532 L
.73776 .20531 L
.7381 .20531 L
.73843 .20531 L
.73877 .20532 L
.73911 .20532 L
.73945 .20533 L
.73979 .20534 L
.74012 .20537 L
.74046 .20539 L
.7408 .2054 L
.74114 .2054 L
.74148 .20539 L
.74182 .20538 L
.74215 .20537 L
.74249 .20537 L
.74283 .20537 L
.74317 .20537 L
.74351 .20537 L
.74384 .20539 L
.74418 .20542 L
.74452 .20545 L
.74486 .20548 L
.7452 .2055 L
.74554 .20552 L
.74587 .20554 L
.74621 .20556 L
.74655 .20559 L
.74689 .20562 L
.74723 .20564 L
.74756 .20566 L
.7479 .20568 L
.74824 .20571 L
.74858 .20573 L
.74892 .20575 L
.74926 .20574 L
.74959 .20572 L
.74993 .20571 L
.75027 .20569 L
.75061 .20567 L
Mistroke
.75095 .20565 L
.75129 .20562 L
.75162 .2056 L
.75196 .20559 L
.7523 .20558 L
.75264 .20557 L
.75298 .20556 L
.75331 .20553 L
.75365 .20551 L
.75399 .20549 L
.75433 .20548 L
.75467 .20546 L
.75501 .20545 L
.75534 .20543 L
.75568 .20542 L
.75602 .20541 L
.75636 .20541 L
.7567 .2054 L
.75703 .20539 L
.75737 .20538 L
.75771 .20535 L
.75805 .20533 L
.75839 .20531 L
.75873 .2053 L
.75906 .20528 L
.7594 .20527 L
.75974 .20526 L
.76008 .20526 L
.76042 .20526 L
.76075 .20527 L
.76109 .20528 L
.76143 .20528 L
.76177 .20528 L
.76211 .20529 L
.76245 .2053 L
.76278 .20531 L
.76312 .20532 L
.76346 .20532 L
.7638 .20533 L
.76414 .20535 L
.76448 .20536 L
.76481 .20537 L
.76515 .20538 L
.76549 .20538 L
.76583 .20538 L
.76617 .20538 L
.7665 .20537 L
.76684 .20537 L
.76718 .20537 L
.76752 .20536 L
Mistroke
.76786 .20536 L
.7682 .20536 L
.76853 .20536 L
.76887 .20537 L
.76921 .20537 L
.76955 .20537 L
.76989 .20537 L
.77022 .20538 L
.77056 .20538 L
.7709 .20538 L
.77124 .20538 L
.77158 .20539 L
.77192 .20539 L
.77225 .20539 L
.77259 .2054 L
.77293 .20541 L
.77327 .20541 L
.77361 .20541 L
.77394 .20541 L
.77428 .20541 L
.77462 .20541 L
.77496 .20541 L
.7753 .20541 L
.77564 .20541 L
.77597 .20541 L
.77631 .20541 L
.77665 .20542 L
.77699 .20543 L
.77733 .20544 L
.77767 .20545 L
.778 .20545 L
.77834 .20546 L
.77868 .20547 L
.77902 .20547 L
.77936 .20548 L
.77969 .20549 L
.78003 .20549 L
.78037 .2055 L
.78071 .20551 L
.78105 .20551 L
.78139 .20551 L
.78172 .20551 L
.78206 .20551 L
.7824 .20551 L
.78274 .2055 L
.78308 .2055 L
.78341 .2055 L
.78375 .20549 L
.78409 .20549 L
.78443 .20548 L
Mistroke
.78477 .20548 L
.78511 .20548 L
.78544 .20548 L
.78578 .20547 L
.78612 .20547 L
.78646 .20547 L
.7868 .20546 L
.78713 .20546 L
.78747 .20546 L
.78781 .20545 L
.78815 .20545 L
.78849 .20545 L
.78883 .20544 L
.78916 .20544 L
.7895 .20544 L
.78984 .20543 L
.79018 .20543 L
.79052 .20542 L
.79085 .20542 L
.79119 .20541 L
.79153 .20541 L
.79187 .20541 L
.79221 .2054 L
.79255 .2054 L
.79288 .2054 L
.79322 .2054 L
.79356 .2054 L
.7939 .20541 L
.79424 .20541 L
.79458 .20541 L
.79491 .20541 L
.79525 .20541 L
.79559 .20541 L
.79593 .20541 L
.79627 .20541 L
.7966 .20542 L
.79694 .20542 L
.79728 .20542 L
.79762 .20542 L
.79796 .20542 L
.7983 .20542 L
.79863 .20542 L
.79897 .20542 L
.79931 .20542 L
.79965 .20542 L
.79999 .20541 L
.80032 .20541 L
.80066 .20541 L
.801 .20541 L
.80134 .20541 L
Mistroke
.80168 .20541 L
.80202 .20541 L
.80235 .20541 L
.80269 .20541 L
.80303 .20541 L
.80337 .20541 L
.80371 .20541 L
.80404 .20541 L
.80438 .20541 L
.80472 .20541 L
.80506 .20541 L
.8054 .20542 L
.80574 .20542 L
.80607 .20542 L
.80641 .20542 L
.80675 .20541 L
.80709 .20541 L
.80743 .20541 L
.80777 .20541 L
.8081 .20541 L
.80844 .20541 L
.80878 .20541 L
.80912 .20542 L
.80946 .20542 L
.80979 .20542 L
.81013 .20542 L
.81047 .20542 L
.81081 .20542 L
.81115 .20543 L
.81149 .20543 L
.81182 .20543 L
.81216 .20543 L
.8125 .20543 L
.81284 .20543 L
.81318 .20543 L
.81351 .20544 L
.81385 .20544 L
.81419 .20544 L
.81453 .20544 L
.81487 .20544 L
.81521 .20544 L
.81554 .20543 L
.81588 .20543 L
.81622 .20543 L
.81656 .20543 L
.8169 .20543 L
.81723 .20543 L
.81757 .20543 L
.81791 .20543 L
.81825 .20543 L
Mistroke
.81859 .20543 L
.81893 .20543 L
.81926 .20543 L
.8196 .20543 L
.81994 .20543 L
.82028 .20543 L
.82062 .20543 L
.82096 .20543 L
.82129 .20543 L
.82163 .20543 L
.82197 .20543 L
.82231 .20543 L
.82265 .20543 L
.82298 .20543 L
.82332 .20543 L
.82366 .20543 L
.824 .20543 L
.82434 .20542 L
.82468 .20542 L
.82501 .20542 L
.82535 .20542 L
.82569 .20542 L
.82603 .20542 L
.82637 .20542 L
.8267 .20542 L
.82704 .20543 L
.82738 .20543 L
.82772 .20543 L
.82806 .20543 L
.8284 .20543 L
.82873 .20543 L
.82907 .20543 L
.82941 .20543 L
.82975 .20543 L
.83009 .20543 L
.83042 .20543 L
.83076 .20543 L
.8311 .20543 L
.83144 .20543 L
.83178 .20543 L
.83212 .20543 L
.83245 .20543 L
.83279 .20543 L
.83313 .20543 L
.83347 .20543 L
.83381 .20543 L
.83415 .20543 L
.83448 .20543 L
.83482 .20543 L
.83516 .20543 L
Mistroke
.8355 .20542 L
.83584 .20542 L
.83617 .20542 L
.83651 .20542 L
.83685 .20542 L
.83719 .20543 L
.83753 .20543 L
.83787 .20543 L
.8382 .20543 L
.83854 .20543 L
.83888 .20543 L
.83922 .20543 L
.83956 .20542 L
.83989 .20542 L
.84023 .20542 L
.84057 .20542 L
.84091 .20542 L
.84125 .20542 L
.84159 .20542 L
.84192 .20543 L
.84226 .20543 L
.8426 .20543 L
.84294 .20543 L
.84328 .20543 L
.84361 .20543 L
.84395 .20543 L
.84429 .20543 L
.84463 .20543 L
.84497 .20543 L
.84531 .20543 L
.84564 .20543 L
.84598 .20543 L
.84632 .20543 L
.84666 .20543 L
.847 .20543 L
.84733 .20543 L
.84767 .20543 L
.84801 .20543 L
.84835 .20543 L
.84869 .20543 L
.84903 .20543 L
.84936 .20543 L
.8497 .20543 L
.85004 .20543 L
.85038 .20543 L
.85072 .20543 L
.85106 .20543 L
.85139 .20543 L
.85173 .20543 L
.85207 .20543 L
Mistroke
.85241 .20543 L
.85275 .20543 L
.85308 .20543 L
.85342 .20543 L
.85376 .20543 L
.8541 .20543 L
.85444 .20543 L
.85478 .20543 L
.85511 .20543 L
.85545 .20543 L
.85579 .20543 L
.85613 .20543 L
.85647 .20543 L
.8568 .20543 L
.85714 .20543 L
.85748 .20543 L
.85782 .20543 L
.85816 .20543 L
.8585 .20543 L
.85883 .20543 L
.85917 .20543 L
.85951 .20543 L
.85985 .20543 L
.86019 .20543 L
.86052 .20543 L
.86086 .20543 L
.8612 .20543 L
.86154 .20543 L
.86188 .20543 L
.86222 .20543 L
.86255 .20543 L
.86289 .20543 L
.86323 .20543 L
.86357 .20543 L
.86391 .20543 L
.86425 .20543 L
.86458 .20543 L
.86492 .20543 L
.86526 .20543 L
.8656 .20543 L
.86594 .20543 L
.86627 .20543 L
.86661 .20543 L
.86695 .20543 L
.86729 .20543 L
.86763 .20543 L
.86797 .20543 L
.8683 .20543 L
.86864 .20543 L
.86898 .20543 L
Mistroke
.86932 .20543 L
.86966 .20543 L
.86999 .20543 L
.87033 .20543 L
.87067 .20543 L
.87101 .20543 L
.87135 .20543 L
.87169 .20543 L
.87202 .20543 L
.87236 .20543 L
.8727 .20543 L
.87304 .20543 L
.87338 .20543 L
.87371 .20543 L
.87405 .20543 L
.87439 .20543 L
.87473 .20543 L
.87507 .20543 L
.87541 .20543 L
.87574 .20543 L
.87608 .20543 L
.87642 .20543 L
.87676 .20543 L
.8771 .20543 L
.87744 .20543 L
.87777 .20543 L
.87811 .20543 L
.87845 .20543 L
.87879 .20543 L
.87913 .20543 L
.87946 .20543 L
.8798 .20543 L
.88014 .20543 L
.88048 .20543 L
.88082 .20543 L
.88116 .20543 L
.88149 .20543 L
.88183 .20543 L
.88217 .20543 L
.88251 .20543 L
.88285 .20543 L
.88318 .20543 L
.88352 .20543 L
.88386 .20543 L
.8842 .20543 L
.88454 .20543 L
.88488 .20543 L
.88521 .20543 L
.88555 .20543 L
.88589 .20543 L
Mistroke
.88623 .20543 L
.88657 .20543 L
.8869 .20543 L
.88724 .20543 L
.88758 .20543 L
.88792 .20543 L
.88826 .20543 L
.8886 .20543 L
.88893 .20543 L
.88927 .20543 L
.88961 .20543 L
.88995 .20543 L
.89029 .20543 L
.89062 .20543 L
.89096 .20543 L
.8913 .20543 L
.89164 .20543 L
.89198 .20543 L
.89232 .20543 L
.89265 .20543 L
.89299 .20543 L
.89333 .20543 L
.89367 .20543 L
.89401 .20543 L
.89435 .20543 L
.89468 .20543 L
.89502 .20543 L
.89536 .20543 L
.8957 .20543 L
.89604 .20543 L
.89637 .20543 L
.89671 .20543 L
.89705 .20543 L
.89739 .20543 L
.89773 .20543 L
.89807 .20543 L
.8984 .20543 L
.89874 .20543 L
.89908 .20543 L
.89942 .20543 L
.89976 .20543 L
.90009 .20543 L
.90043 .20543 L
.90077 .20543 L
.90111 .20543 L
.90145 .20543 L
.90179 .20543 L
.90212 .20543 L
.90246 .20543 L
.9028 .20543 L
Mistroke
.90314 .20543 L
.90348 .20543 L
.90381 .20543 L
.90415 .20543 L
.90449 .20543 L
.90483 .20543 L
.90517 .20543 L
.90551 .20543 L
.90584 .20543 L
.90618 .20543 L
.90652 .20543 L
.90686 .20543 L
.9072 .20543 L
.90754 .20543 L
.90787 .20543 L
.90821 .20543 L
.90855 .20543 L
.90889 .20543 L
.90923 .20543 L
.90956 .20543 L
.9099 .20543 L
.91024 .20543 L
.91058 .20543 L
.91092 .20543 L
.91126 .20543 L
.91159 .20543 L
.91193 .20543 L
.91227 .20543 L
.91261 .20543 L
.91295 .20543 L
.91328 .20543 L
.91362 .20543 L
.91396 .20543 L
.9143 .20543 L
.91464 .20543 L
.91498 .20543 L
.91531 .20543 L
.91565 .20543 L
.91599 .20543 L
.91633 .20543 L
.91667 .20543 L
.917 .20543 L
.91734 .20543 L
.91768 .20543 L
.91802 .20543 L
.91836 .20543 L
.9187 .20543 L
.91903 .20543 L
.91937 .20543 L
.91971 .20543 L
Mistroke
.92005 .20543 L
.92039 .20543 L
.92073 .20543 L
.92106 .20543 L
.9214 .20543 L
.92174 .20543 L
.92208 .20543 L
.92242 .20543 L
.92275 .20543 L
.92309 .20543 L
.92343 .20543 L
.92377 .20543 L
.92411 .20543 L
.92445 .20543 L
.92478 .20543 L
.92512 .20543 L
.92546 .20543 L
.9258 .20543 L
.92614 .20543 L
.92647 .20543 L
.92681 .20543 L
.92715 .20543 L
.92749 .20543 L
.92783 .20543 L
.92817 .20543 L
.9285 .20543 L
.92884 .20543 L
.92918 .20543 L
.92952 .20543 L
.92986 .20543 L
.93019 .20543 L
.93053 .20543 L
.93087 .20543 L
.93121 .20543 L
.93155 .20543 L
.93189 .20543 L
.93222 .20543 L
.93256 .20543 L
.9329 .20543 L
.93324 .20543 L
.93358 .20543 L
.93392 .20543 L
.93425 .20543 L
.93459 .20543 L
.93493 .20543 L
.93527 .20543 L
.93561 .20543 L
.93594 .20543 L
.93628 .20543 L
.93662 .20543 L
Mistroke
.93696 .20543 L
.9373 .20543 L
.93764 .20543 L
.93797 .20543 L
.93831 .20543 L
.93865 .20543 L
.93899 .20543 L
.93933 .20543 L
.93966 .20543 L
.94 .20543 L
.94034 .20543 L
.94068 .20543 L
.94102 .20543 L
.94136 .20543 L
.94169 .20543 L
.94203 .20543 L
.94237 .20543 L
.94271 .20543 L
.94305 .20543 L
.94338 .20543 L
.94372 .20543 L
.94406 .20543 L
.9444 .20543 L
.94474 .20543 L
.94508 .20543 L
.94541 .20543 L
.94575 .20543 L
.94609 .20543 L
.94643 .20543 L
.94677 .20543 L
.9471 .20543 L
.94744 .20543 L
.94778 .20543 L
.94812 .20543 L
.94846 .20543 L
.9488 .20543 L
.94913 .20543 L
.94947 .20543 L
.94981 .20543 L
.95015 .20543 L
.95049 .20543 L
.95083 .20543 L
.95116 .20543 L
.9515 .20543 L
.95184 .20543 L
.95218 .20543 L
.95252 .20543 L
.95285 .20543 L
.95319 .20543 L
.95353 .20543 L
Mistroke
.95387 .20543 L
.95421 .20543 L
.95455 .20543 L
.95488 .20543 L
.95522 .20543 L
.95556 .20543 L
.9559 .20543 L
.95624 .20543 L
.95657 .20543 L
.95691 .20543 L
.95725 .20543 L
.95759 .20543 L
.95793 .20543 L
.95827 .20543 L
.9586 .20543 L
.95894 .20543 L
.95928 .20543 L
.95962 .20543 L
.95996 .20543 L
.96029 .20543 L
.96063 .20543 L
.96097 .20543 L
.96131 .20543 L
.96165 .20543 L
.96199 .20543 L
.96232 .20543 L
.96266 .20543 L
.963 .20543 L
.96334 .20543 L
.96368 .20543 L
.96402 .20543 L
.96435 .20543 L
.96469 .20543 L
.96503 .20543 L
.96537 .20543 L
.96571 .20543 L
.96604 .20543 L
.96638 .20543 L
.96672 .20543 L
.96706 .20543 L
.9674 .20543 L
.96774 .20543 L
.96807 .20543 L
.96841 .20543 L
.96875 .20543 L
.96909 .20543 L
.96943 .20543 L
.96976 .20543 L
.9701 .20543 L
.97044 .20543 L
Mistroke
.97078 .20543 L
.97112 .20543 L
.97146 .20543 L
.97179 .20543 L
.97213 .20543 L
.97247 .20543 L
.97281 .20543 L
.97315 .20543 L
.97348 .20543 L
.97382 .20543 L
.97416 .20543 L
.9745 .20543 L
.97484 .20543 L
.97518 .20543 L
.97551 .20543 L
.97585 .20543 L
.97619 .20543 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],

Cell[TextData[{
  "This is the basic wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.22"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[N[b], 7, InverseTransform -> True],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"psi(t)\"}]\
\>", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S1.6.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.46337 0.0732601 0.341691 0.0889174 [
[.02381 .32919 -6 -9 ]
[.02381 .32919 6 0 ]
[.17033 .32919 -6 -9 ]
[.17033 .32919 6 0 ]
[.31685 .32919 -6 -9 ]
[.31685 .32919 6 0 ]
[.60989 .32919 -3 -9 ]
[.60989 .32919 3 0 ]
[.75641 .32919 -3 -9 ]
[.75641 .32919 3 0 ]
[.90293 .32919 -3 -9 ]
[.90293 .32919 3 0 ]
[1.025 .34169 0 -4.5 ]
[1.025 .34169 6 4.5 ]
[.45087 .07494 -12 -4.5 ]
[.45087 .07494 0 4.5 ]
[.45087 .16386 -12 -4.5 ]
[.45087 .16386 0 4.5 ]
[.45087 .25277 -12 -4.5 ]
[.45087 .25277 0 4.5 ]
[.45087 .43061 -6 -4.5 ]
[.45087 .43061 0 4.5 ]
[.45087 .51953 -6 -4.5 ]
[.45087 .51953 0 4.5 ]
[.45087 .60844 -6 -4.5 ]
[.45087 .60844 0 4.5 ]
[.46337 .64303 -18 0 ]
[.46337 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .34169 m
.02381 .34794 L
s
[(-6)] .02381 .32919 0 1 Mshowa
.17033 .34169 m
.17033 .34794 L
s
[(-4)] .17033 .32919 0 1 Mshowa
.31685 .34169 m
.31685 .34794 L
s
[(-2)] .31685 .32919 0 1 Mshowa
.60989 .34169 m
.60989 .34794 L
s
[(2)] .60989 .32919 0 1 Mshowa
.75641 .34169 m
.75641 .34794 L
s
[(4)] .75641 .32919 0 1 Mshowa
.90293 .34169 m
.90293 .34794 L
s
[(6)] .90293 .32919 0 1 Mshowa
.125 Mabswid
.06044 .34169 m
.06044 .34544 L
s
.09707 .34169 m
.09707 .34544 L
s
.1337 .34169 m
.1337 .34544 L
s
.20696 .34169 m
.20696 .34544 L
s
.24359 .34169 m
.24359 .34544 L
s
.28022 .34169 m
.28022 .34544 L
s
.35348 .34169 m
.35348 .34544 L
s
.39011 .34169 m
.39011 .34544 L
s
.42674 .34169 m
.42674 .34544 L
s
.5 .34169 m
.5 .34544 L
s
.53663 .34169 m
.53663 .34544 L
s
.57326 .34169 m
.57326 .34544 L
s
.64652 .34169 m
.64652 .34544 L
s
.68315 .34169 m
.68315 .34544 L
s
.71978 .34169 m
.71978 .34544 L
s
.79304 .34169 m
.79304 .34544 L
s
.82967 .34169 m
.82967 .34544 L
s
.8663 .34169 m
.8663 .34544 L
s
.93956 .34169 m
.93956 .34544 L
s
.97619 .34169 m
.97619 .34544 L
s
.25 Mabswid
0 .34169 m
1 .34169 L
s
[(t)] 1.025 .34169 -1 0 Mshowa
.46337 .07494 m
.46962 .07494 L
s
[(-3)] .45087 .07494 1 0 Mshowa
.46337 .16386 m
.46962 .16386 L
s
[(-2)] .45087 .16386 1 0 Mshowa
.46337 .25277 m
.46962 .25277 L
s
[(-1)] .45087 .25277 1 0 Mshowa
.46337 .43061 m
.46962 .43061 L
s
[(1)] .45087 .43061 1 0 Mshowa
.46337 .51953 m
.46962 .51953 L
s
[(2)] .45087 .51953 1 0 Mshowa
.46337 .60844 m
.46962 .60844 L
s
[(3)] .45087 .60844 1 0 Mshowa
.125 Mabswid
.46337 .09272 m
.46712 .09272 L
s
.46337 .11051 m
.46712 .11051 L
s
.46337 .12829 m
.46712 .12829 L
s
.46337 .14607 m
.46712 .14607 L
s
.46337 .18164 m
.46712 .18164 L
s
.46337 .19942 m
.46712 .19942 L
s
.46337 .21721 m
.46712 .21721 L
s
.46337 .23499 m
.46712 .23499 L
s
.46337 .27056 m
.46712 .27056 L
s
.46337 .28834 m
.46712 .28834 L
s
.46337 .30612 m
.46712 .30612 L
s
.46337 .32391 m
.46712 .32391 L
s
.46337 .35947 m
.46712 .35947 L
s
.46337 .37726 m
.46712 .37726 L
s
.46337 .39504 m
.46712 .39504 L
s
.46337 .41283 m
.46712 .41283 L
s
.46337 .44839 m
.46712 .44839 L
s
.46337 .46618 m
.46712 .46618 L
s
.46337 .48396 m
.46712 .48396 L
s
.46337 .50174 m
.46712 .50174 L
s
.46337 .53731 m
.46712 .53731 L
s
.46337 .55509 m
.46712 .55509 L
s
.46337 .57288 m
.46712 .57288 L
s
.46337 .59066 m
.46712 .59066 L
s
.46337 .05716 m
.46712 .05716 L
s
.46337 .03937 m
.46712 .03937 L
s
.46337 .02159 m
.46712 .02159 L
s
.46337 .00381 m
.46712 .00381 L
s
.25 Mabswid
.46337 0 m
.46337 .61803 L
s
[(psi\\(t\\))] .46337 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .34169 m
.02438 .34169 L
.02495 .34169 L
.02553 .34169 L
.0261 .34169 L
.02667 .34169 L
.02724 .34169 L
.02782 .34169 L
.02839 .34169 L
.02896 .34169 L
.02953 .34169 L
.03011 .34169 L
.03068 .34169 L
.03125 .34169 L
.03182 .34169 L
.03239 .34169 L
.03297 .34169 L
.03354 .34169 L
.03411 .34169 L
.03468 .34169 L
.03526 .34169 L
.03583 .34169 L
.0364 .34169 L
.03697 .34169 L
.03755 .34169 L
.03812 .34169 L
.03869 .34169 L
.03926 .34169 L
.03984 .34169 L
.04041 .34169 L
.04098 .34169 L
.04155 .34169 L
.04212 .34169 L
.0427 .34169 L
.04327 .34169 L
.04384 .34169 L
.04441 .34169 L
.04499 .34169 L
.04556 .34169 L
.04613 .34169 L
.0467 .34169 L
.04728 .34169 L
.04785 .34169 L
.04842 .34169 L
.04899 .34169 L
.04957 .34169 L
.05014 .34169 L
.05071 .34169 L
.05128 .34169 L
.05185 .34169 L
Mistroke
.05243 .34169 L
.053 .34169 L
.05357 .34169 L
.05414 .34169 L
.05472 .34169 L
.05529 .34169 L
.05586 .34169 L
.05643 .34169 L
.05701 .34169 L
.05758 .34169 L
.05815 .34169 L
.05872 .34169 L
.05929 .34169 L
.05987 .34169 L
.06044 .34169 L
.06101 .34169 L
.06158 .34169 L
.06216 .34169 L
.06273 .34169 L
.0633 .34169 L
.06387 .34169 L
.06445 .34169 L
.06502 .34169 L
.06559 .34169 L
.06616 .34169 L
.06674 .34169 L
.06731 .34169 L
.06788 .34169 L
.06845 .34169 L
.06902 .34169 L
.0696 .34169 L
.07017 .34169 L
.07074 .34169 L
.07131 .34169 L
.07189 .34169 L
.07246 .34169 L
.07303 .34169 L
.0736 .34169 L
.07418 .34169 L
.07475 .34169 L
.07532 .34169 L
.07589 .34169 L
.07647 .34169 L
.07704 .34169 L
.07761 .34169 L
.07818 .34169 L
.07875 .34169 L
.07933 .34169 L
.0799 .34169 L
.08047 .34169 L
Mistroke
.08104 .34169 L
.08162 .34169 L
.08219 .34169 L
.08276 .34169 L
.08333 .34169 L
.08391 .34169 L
.08448 .34169 L
.08505 .34169 L
.08562 .34169 L
.0862 .34169 L
.08677 .34169 L
.08734 .34169 L
.08791 .34169 L
.08848 .34169 L
.08906 .34169 L
.08963 .34169 L
.0902 .34169 L
.09077 .34169 L
.09135 .34169 L
.09192 .34169 L
.09249 .34169 L
.09306 .34169 L
.09364 .34169 L
.09421 .34169 L
.09478 .34169 L
.09535 .34169 L
.09592 .34169 L
.0965 .34169 L
.09707 .34169 L
.09764 .34169 L
.09821 .34169 L
.09879 .34169 L
.09936 .34169 L
.09993 .34169 L
.1005 .34169 L
.10108 .34169 L
.10165 .34169 L
.10222 .34169 L
.10279 .34169 L
.10337 .34169 L
.10394 .34169 L
.10451 .34169 L
.10508 .34169 L
.10565 .34169 L
.10623 .34169 L
.1068 .34169 L
.10737 .34169 L
.10794 .34169 L
.10852 .34169 L
.10909 .34169 L
Mistroke
.10966 .34169 L
.11023 .34169 L
.11081 .34169 L
.11138 .34169 L
.11195 .34169 L
.11252 .34169 L
.1131 .34169 L
.11367 .34169 L
.11424 .34169 L
.11481 .34169 L
.11538 .34169 L
.11596 .34169 L
.11653 .34169 L
.1171 .34169 L
.11767 .34169 L
.11825 .34169 L
.11882 .34169 L
.11939 .34169 L
.11996 .34169 L
.12054 .34169 L
.12111 .34169 L
.12168 .34169 L
.12225 .34169 L
.12283 .34169 L
.1234 .34169 L
.12397 .34169 L
.12454 .34169 L
.12511 .34169 L
.12569 .34169 L
.12626 .34169 L
.12683 .34169 L
.1274 .34169 L
.12798 .34169 L
.12855 .34169 L
.12912 .34169 L
.12969 .34169 L
.13027 .34169 L
.13084 .34169 L
.13141 .34169 L
.13198 .34169 L
.13255 .34169 L
.13313 .34169 L
.1337 .34169 L
.13427 .34169 L
.13484 .34169 L
.13542 .34169 L
.13599 .34169 L
.13656 .34169 L
.13713 .34169 L
.13771 .34169 L
Mistroke
.13828 .34169 L
.13885 .34169 L
.13942 .34169 L
.14 .34169 L
.14057 .34169 L
.14114 .34169 L
.14171 .34169 L
.14228 .34169 L
.14286 .34169 L
.14343 .34169 L
.144 .34169 L
.14457 .34169 L
.14515 .34169 L
.14572 .34169 L
.14629 .34169 L
.14686 .34169 L
.14744 .34169 L
.14801 .34169 L
.14858 .34169 L
.14915 .34169 L
.14973 .34169 L
.1503 .34169 L
.15087 .34169 L
.15144 .34169 L
.15201 .34169 L
.15259 .34169 L
.15316 .34169 L
.15373 .34169 L
.1543 .34169 L
.15488 .34169 L
.15545 .34169 L
.15602 .34169 L
.15659 .34169 L
.15717 .34169 L
.15774 .34169 L
.15831 .34169 L
.15888 .34169 L
.15946 .34169 L
.16003 .34169 L
.1606 .34169 L
.16117 .34169 L
.16174 .34169 L
.16232 .34169 L
.16289 .34169 L
.16346 .34169 L
.16403 .34169 L
.16461 .34169 L
.16518 .34169 L
.16575 .34169 L
.16632 .34169 L
Mistroke
.1669 .34169 L
.16747 .34169 L
.16804 .34169 L
.16861 .34169 L
.16918 .34169 L
.16976 .34169 L
.17033 .34169 L
.1709 .34169 L
.17147 .34169 L
.17205 .34169 L
.17262 .34169 L
.17319 .34169 L
.17376 .34169 L
.17434 .34169 L
.17491 .34169 L
.17548 .34169 L
.17605 .34169 L
.17663 .34169 L
.1772 .34169 L
.17777 .34169 L
.17834 .34169 L
.17891 .34169 L
.17949 .34169 L
.18006 .34169 L
.18063 .34169 L
.1812 .34169 L
.18178 .34169 L
.18235 .34169 L
.18292 .34169 L
.18349 .34169 L
.18407 .34169 L
.18464 .34169 L
.18521 .34169 L
.18578 .34169 L
.18636 .34169 L
.18693 .34169 L
.1875 .34168 L
.18807 .34168 L
.18864 .34168 L
.18922 .34168 L
.18979 .34169 L
.19036 .34169 L
.19093 .34169 L
.19151 .34169 L
.19208 .34169 L
.19265 .34169 L
.19322 .34169 L
.1938 .34169 L
.19437 .34169 L
.19494 .34169 L
Mistroke
.19551 .34169 L
.19609 .3417 L
.19666 .3417 L
.19723 .3417 L
.1978 .3417 L
.19837 .3417 L
.19895 .3417 L
.19952 .3417 L
.20009 .3417 L
.20066 .3417 L
.20124 .34169 L
.20181 .34169 L
.20238 .34169 L
.20295 .34169 L
.20353 .34169 L
.2041 .3417 L
.20467 .3417 L
.20524 .3417 L
.20582 .3417 L
.20639 .3417 L
.20696 .3417 L
.20753 .3417 L
.2081 .3417 L
.20868 .34169 L
.20925 .34169 L
.20982 .34169 L
.21039 .34169 L
.21097 .34169 L
.21154 .34169 L
.21211 .34168 L
.21268 .34168 L
.21326 .34167 L
.21383 .34167 L
.2144 .34167 L
.21497 .34166 L
.21554 .34166 L
.21612 .34166 L
.21669 .34166 L
.21726 .34167 L
.21783 .34168 L
.21841 .34168 L
.21898 .34169 L
.21955 .34169 L
.22012 .3417 L
.2207 .34171 L
.22127 .34171 L
.22184 .34171 L
.22241 .34171 L
.22299 .34171 L
.22356 .34172 L
Mistroke
.22413 .34172 L
.2247 .34173 L
.22527 .34173 L
.22585 .34173 L
.22642 .34172 L
.22699 .34172 L
.22756 .34171 L
.22814 .3417 L
.22871 .34169 L
.22928 .34168 L
.22985 .34168 L
.23043 .34168 L
.231 .34168 L
.23157 .34169 L
.23214 .34169 L
.23272 .34169 L
.23329 .34169 L
.23386 .34169 L
.23443 .34169 L
.235 .34168 L
.23558 .34167 L
.23615 .34166 L
.23672 .34165 L
.23729 .34165 L
.23787 .34165 L
.23844 .34165 L
.23901 .34164 L
.23958 .34163 L
.24016 .34161 L
.24073 .3416 L
.2413 .34159 L
.24187 .34157 L
.24245 .34156 L
.24302 .34155 L
.24359 .34155 L
.24416 .34157 L
.24473 .3416 L
.24531 .34163 L
.24588 .34166 L
.24645 .34168 L
.24702 .3417 L
.2476 .34173 L
.24817 .34175 L
.24874 .34178 L
.24931 .3418 L
.24989 .34182 L
.25046 .34184 L
.25103 .34187 L
.2516 .3419 L
.25217 .34192 L
Mistroke
.25275 .34194 L
.25332 .34193 L
.25389 .34191 L
.25446 .34189 L
.25504 .34187 L
.25561 .34185 L
.25618 .34182 L
.25675 .3418 L
.25733 .34178 L
.2579 .34178 L
.25847 .3418 L
.25904 .34181 L
.25962 .34182 L
.26019 .34182 L
.26076 .3418 L
.26133 .3418 L
.2619 .34179 L
.26248 .34179 L
.26305 .34178 L
.26362 .34175 L
.26419 .34174 L
.26477 .34175 L
.26534 .34176 L
.26591 .34177 L
.26648 .34176 L
.26706 .34171 L
.26763 .34165 L
.2682 .3416 L
.26877 .34155 L
.26935 .3415 L
.26992 .34147 L
.27049 .34143 L
.27106 .34141 L
.27163 .34145 L
.27221 .34151 L
.27278 .34159 L
.27335 .34166 L
.27392 .34169 L
.2745 .34171 L
.27507 .34176 L
.27564 .34181 L
.27621 .34186 L
.27679 .34192 L
.27736 .34195 L
.27793 .34198 L
.2785 .34204 L
.27908 .3421 L
.27965 .34214 L
.28022 .34214 L
.28079 .34205 L
Mistroke
.28136 .34193 L
.28194 .3418 L
.28251 .34166 L
.28308 .34154 L
.28365 .34141 L
.28423 .34126 L
.2848 .34113 L
.28537 .34106 L
.28594 .34101 L
.28652 .34098 L
.28709 .34094 L
.28766 .34084 L
.28823 .34073 L
.2888 .34065 L
.28938 .34059 L
.28995 .34056 L
.29052 .34055 L
.29109 .3405 L
.29167 .34048 L
.29224 .34052 L
.29281 .34058 L
.29338 .34063 L
.29396 .34065 L
.29453 .34055 L
.2951 .34042 L
.29567 .34031 L
.29625 .34023 L
.29682 .34018 L
.29739 .34017 L
.29796 .34014 L
.29853 .34017 L
.29911 .34031 L
.29968 .34051 L
.30025 .34076 L
.30082 .341 L
.3014 .34114 L
.30197 .34126 L
.30254 .34144 L
.30311 .34166 L
.30369 .34196 L
.30426 .34229 L
.30483 .34255 L
.3054 .34282 L
.30598 .34315 L
.30655 .34345 L
.30712 .34375 L
.30769 .34393 L
.30826 .34387 L
.30884 .34371 L
.30941 .34353 L
Mistroke
.30998 .34335 L
.31055 .34323 L
.31113 .34313 L
.3117 .34296 L
.31227 .34282 L
.31284 .34276 L
.31342 .34275 L
.31399 .34281 L
.31456 .34283 L
.31513 .34271 L
.31571 .34257 L
.31628 .34251 L
.31685 .34254 L
.31742 .34275 L
.31799 .34305 L
.31857 .34329 L
.31914 .34358 L
.31971 .34395 L
.32028 .34433 L
.32086 .34474 L
.32143 .34503 L
.322 .34504 L
.32257 .34492 L
.32315 .34482 L
.32372 .34474 L
.32429 .34481 L
.32486 .34492 L
.32543 .34494 L
.32601 .34502 L
.32658 .3452 L
.32715 .34545 L
.32772 .34579 L
.3283 .34607 L
.32887 .34608 L
.32944 .34602 L
.33001 .34602 L
.33059 .34611 L
.33116 .34646 L
.33173 .34689 L
.3323 .34714 L
.33288 .34737 L
.33345 .34759 L
.33402 .34771 L
.33459 .34782 L
.33516 .34765 L
.33574 .34695 L
.33631 .34597 L
.33688 .34488 L
.33745 .34376 L
.33803 .34287 L
Mistroke
.3386 .342 L
.33917 .34093 L
.33974 .33984 L
.34032 .33876 L
.34089 .33769 L
.34146 .33682 L
.34203 .33588 L
.34261 .33466 L
.34318 .33343 L
.34375 .33233 L
.34432 .33152 L
.34489 .33128 L
.34547 .33131 L
.34604 .3313 L
.34661 .33138 L
.34718 .33149 L
.34776 .33161 L
.34833 .3319 L
.3489 .33203 L
.34947 .33169 L
.35005 .33118 L
.35062 .33061 L
.35119 .33014 L
.35176 .3301 L
.35234 .33019 L
.35291 .33009 L
.35348 .32997 L
.35405 .32978 L
.35462 .32958 L
.3552 .32965 L
.35577 .32961 L
.35634 .32918 L
.35691 .32872 L
.35749 .32834 L
.35806 .32829 L
.35863 .32901 L
.3592 .33004 L
.35978 .33091 L
.36035 .33179 L
.36092 .33251 L
.36149 .33313 L
.36207 .33391 L
.36264 .33436 L
.36321 .33406 L
.36378 .33344 L
.36435 .33259 L
.36493 .33187 L
.3655 .33183 L
.36607 .33196 L
.36664 .33183 L
Mistroke
.36722 .33161 L
.36779 .33112 L
.36836 .3306 L
.36893 .33058 L
.36951 .33056 L
.37008 .33025 L
.37065 .33011 L
.37122 .33017 L
.37179 .33096 L
.37237 .33315 L
.37294 .33604 L
.37351 .33906 L
.37408 .34223 L
.37466 .34518 L
.37523 .34811 L
.3758 .3515 L
.37637 .35471 L
.37695 .35735 L
.37752 .35974 L
.37809 .36181 L
.37866 .36403 L
.37924 .36704 L
.37981 .37014 L
.38038 .37283 L
.38095 .3751 L
.38152 .37656 L
.3821 .37759 L
.38267 .37888 L
.38324 .37987 L
.38381 .38031 L
.38439 .3806 L
.38496 .38066 L
.38553 .38114 L
.3861 .38283 L
.38668 .38492 L
.38725 .3868 L
.38782 .38844 L
.38839 .3893 L
.38897 .38976 L
.38954 .39047 L
.39011 .39071 L
.39068 .39015 L
.39125 .38911 L
.39183 .3874 L
.3924 .38577 L
.39297 .38508 L
.39354 .38444 L
.39412 .3833 L
.39469 .38153 L
.39526 .3785 L
Mistroke
.39583 .37494 L
.39641 .37187 L
.39698 .36865 L
.39755 .36517 L
.39812 .36182 L
.3987 .35833 L
.39927 .35576 L
.39984 .35518 L
.40041 .35551 L
.40098 .35608 L
.40156 .35655 L
.40213 .35593 L
.4027 .355 L
.40327 .35471 L
.40385 .35429 L
.40442 .3536 L
.40499 .35267 L
.40556 .35082 L
.40614 .34906 L
.40671 .3483 L
.40728 .34742 L
.40785 .3459 L
.40842 .3432 L
.409 .33817 L
.40957 .33198 L
.41014 .3259 L
.41071 .3194 L
.41129 .31274 L
.41186 .30604 L
.41243 .29869 L
.413 .292 L
.41358 .2871 L
.41415 .28294 L
.41472 .27909 L
.41529 .27503 L
.41587 .26961 L
.41644 .26391 L
.41701 .25906 L
.41758 .25445 L
.41815 .25023 L
.41873 .24628 L
.4193 .24174 L
.41987 .23782 L
.42044 .2355 L
.42102 .23363 L
.42159 .23187 L
.42216 .22944 L
.42273 .22504 L
.42331 .22009 L
.42388 .21604 L
Mistroke
.42445 .21239 L
.42502 .2096 L
.4256 .20762 L
.42617 .20559 L
.42674 .20509 L
.42731 .20732 L
.42788 .21107 L
.42846 .21599 L
.42903 .22108 L
.4296 .22475 L
.43017 .22844 L
.43075 .23341 L
.43132 .23915 L
.43189 .24613 L
.43246 .25367 L
.43304 .26033 L
.43361 .26746 L
.43418 .27586 L
.43475 .2843 L
.43533 .29262 L
.4359 .29941 L
.43647 .30281 L
.43704 .30469 L
.43761 .30657 L
.43819 .3084 L
.43876 .31124 L
.43933 .31445 L
.4399 .31668 L
.44048 .31956 L
.44105 .32401 L
.44162 .32926 L
.44219 .33562 L
.44277 .34175 L
.44334 .34598 L
.44391 .3501 L
.44448 .35534 L
.44505 .36181 L
.44563 .37067 L
.4462 .38069 L
.44677 .39011 L
.44734 .40018 L
.44792 .4113 L
.44849 .42258 L
.44906 .43433 L
.44963 .44481 L
.45021 .45208 L
.45078 .45803 L
.45135 .46399 L
.45192 .4701 L
.4525 .4777 L
Mistroke
.45307 .48575 L
.45364 .49265 L
.45421 .49994 L
.45478 .50826 L
.45536 .51694 L
.45593 .52647 L
.4565 .53517 L
.45707 .54109 L
.45765 .54619 L
.45822 .5516 L
.45879 .55762 L
.45936 .56572 L
.45994 .5742 L
.46051 .58089 L
.46108 .58708 L
.46165 .59293 L
.46223 .59765 L
.4628 .60186 L
.46337 .60332 L
.46394 .5998 L
.46451 .59353 L
.46509 .58587 L
.46566 .57754 L
.46623 .57056 L
.4668 .56338 L
.46738 .55412 L
.46795 .54428 L
.46852 .53414 L
.46909 .52373 L
.46967 .51436 L
.47024 .50415 L
.47081 .49141 L
.47138 .47825 L
.47196 .46563 L
.47253 .45471 L
.4731 .44765 L
.47367 .44232 L
.47424 .43644 L
.47482 .43087 L
.47539 .42506 L
.47596 .41898 L
.47653 .41387 L
.47711 .4075 L
.47768 .39801 L
.47825 .38714 L
.47882 .37546 L
.4794 .36409 L
.47997 .3551 L
.48054 .34658 L
.48111 .33668 L
Mistroke
.48168 .32622 L
.48226 .31474 L
.48283 .30276 L
.4834 .29196 L
.48397 .28045 L
.48455 .26694 L
.48512 .25314 L
.48569 .23948 L
.48626 .22741 L
.48684 .21919 L
.48741 .21254 L
.48798 .20533 L
.48855 .19816 L
.48913 .19016 L
.4897 .18168 L
.49027 .17425 L
.49084 .16558 L
.49141 .15405 L
.49199 .14132 L
.49256 .12774 L
.49313 .11493 L
.4937 .10532 L
.49428 .09673 L
.49485 .08733 L
.49542 .0777 L
.49599 .06695 L
.49657 .05627 L
.49714 .04793 L
.49771 .04001 L
.49828 .03147 L
.49886 .02403 L
.49943 .01772 L
.5 .01472 L
.50057 .01772 L
.50114 .02403 L
.50172 .03147 L
.50229 .04001 L
.50286 .04793 L
.50343 .05627 L
.50401 .06695 L
.50458 .0777 L
.50515 .08733 L
.50572 .09673 L
.5063 .10532 L
.50687 .11493 L
.50744 .12774 L
.50801 .14132 L
.50859 .15405 L
.50916 .16558 L
.50973 .17425 L
Mistroke
.5103 .18168 L
.51087 .19016 L
.51145 .19816 L
.51202 .20533 L
.51259 .21254 L
.51316 .21919 L
.51374 .22741 L
.51431 .23948 L
.51488 .25314 L
.51545 .26694 L
.51603 .28045 L
.5166 .29196 L
.51717 .30276 L
.51774 .31474 L
.51832 .32622 L
.51889 .33668 L
.51946 .34658 L
.52003 .3551 L
.5206 .36409 L
.52118 .37546 L
.52175 .38714 L
.52232 .39801 L
.52289 .4075 L
.52347 .41387 L
.52404 .41898 L
.52461 .42506 L
.52518 .43087 L
.52576 .43644 L
.52633 .44232 L
.5269 .44765 L
.52747 .45471 L
.52804 .46563 L
.52862 .47825 L
.52919 .49141 L
.52976 .50415 L
.53033 .51436 L
.53091 .52373 L
.53148 .53414 L
.53205 .54428 L
.53262 .55412 L
.5332 .56338 L
.53377 .57056 L
.53434 .57754 L
.53491 .58587 L
.53549 .59353 L
.53606 .5998 L
.53663 .60332 L
.5372 .60186 L
.53777 .59765 L
.53835 .59293 L
Mistroke
.53892 .58708 L
.53949 .58089 L
.54006 .5742 L
.54064 .56572 L
.54121 .55762 L
.54178 .5516 L
.54235 .54619 L
.54293 .54109 L
.5435 .53517 L
.54407 .52647 L
.54464 .51694 L
.54522 .50826 L
.54579 .49994 L
.54636 .49265 L
.54693 .48575 L
.5475 .4777 L
.54808 .4701 L
.54865 .46399 L
.54922 .45803 L
.54979 .45208 L
.55037 .44481 L
.55094 .43433 L
.55151 .42258 L
.55208 .4113 L
.55266 .40018 L
.55323 .39011 L
.5538 .38069 L
.55437 .37067 L
.55495 .36181 L
.55552 .35534 L
.55609 .3501 L
.55666 .34598 L
.55723 .34175 L
.55781 .33562 L
.55838 .32926 L
.55895 .32401 L
.55952 .31956 L
.5601 .31668 L
.56067 .31445 L
.56124 .31124 L
.56181 .3084 L
.56239 .30657 L
.56296 .30469 L
.56353 .30281 L
.5641 .29941 L
.56467 .29262 L
.56525 .2843 L
.56582 .27586 L
.56639 .26746 L
.56696 .26033 L
Mistroke
.56754 .25367 L
.56811 .24613 L
.56868 .23915 L
.56925 .23341 L
.56983 .22844 L
.5704 .22475 L
.57097 .22108 L
.57154 .21599 L
.57212 .21107 L
.57269 .20732 L
.57326 .20509 L
.57383 .20559 L
.5744 .20762 L
.57498 .2096 L
.57555 .21239 L
.57612 .21604 L
.57669 .22009 L
.57727 .22504 L
.57784 .22944 L
.57841 .23187 L
.57898 .23363 L
.57956 .2355 L
.58013 .23782 L
.5807 .24174 L
.58127 .24628 L
.58185 .25023 L
.58242 .25445 L
.58299 .25906 L
.58356 .26391 L
.58413 .26961 L
.58471 .27503 L
.58528 .27909 L
.58585 .28294 L
.58642 .2871 L
.587 .292 L
.58757 .29869 L
.58814 .30604 L
.58871 .31274 L
.58929 .3194 L
.58986 .3259 L
.59043 .33198 L
.591 .33817 L
.59158 .3432 L
.59215 .3459 L
.59272 .34742 L
.59329 .3483 L
.59386 .34906 L
.59444 .35082 L
.59501 .35267 L
.59558 .3536 L
Mistroke
.59615 .35429 L
.59673 .35471 L
.5973 .355 L
.59787 .35593 L
.59844 .35655 L
.59902 .35608 L
.59959 .35551 L
.60016 .35518 L
.60073 .35576 L
.6013 .35833 L
.60188 .36182 L
.60245 .36517 L
.60302 .36865 L
.60359 .37187 L
.60417 .37494 L
.60474 .3785 L
.60531 .38153 L
.60588 .3833 L
.60646 .38444 L
.60703 .38508 L
.6076 .38577 L
.60817 .3874 L
.60875 .38911 L
.60932 .39015 L
.60989 .39071 L
.61046 .39047 L
.61103 .38976 L
.61161 .3893 L
.61218 .38844 L
.61275 .3868 L
.61332 .38492 L
.6139 .38283 L
.61447 .38114 L
.61504 .38066 L
.61561 .3806 L
.61619 .38031 L
.61676 .37987 L
.61733 .37888 L
.6179 .37759 L
.61848 .37656 L
.61905 .3751 L
.61962 .37283 L
.62019 .37014 L
.62076 .36704 L
.62134 .36403 L
.62191 .36181 L
.62248 .35974 L
.62305 .35735 L
.62363 .35471 L
.6242 .3515 L
Mistroke
.62477 .34811 L
.62534 .34518 L
.62592 .34223 L
.62649 .33906 L
.62706 .33604 L
.62763 .33315 L
.62821 .33096 L
.62878 .33017 L
.62935 .33011 L
.62992 .33025 L
.63049 .33056 L
.63107 .33058 L
.63164 .3306 L
.63221 .33112 L
.63278 .33161 L
.63336 .33183 L
.63393 .33196 L
.6345 .33183 L
.63507 .33187 L
.63565 .33259 L
.63622 .33344 L
.63679 .33406 L
.63736 .33436 L
.63793 .33391 L
.63851 .33313 L
.63908 .33251 L
.63965 .33179 L
.64022 .33091 L
.6408 .33004 L
.64137 .32901 L
.64194 .32829 L
.64251 .32834 L
.64309 .32872 L
.64366 .32918 L
.64423 .32961 L
.6448 .32965 L
.64538 .32958 L
.64595 .32978 L
.64652 .32997 L
.64709 .33009 L
.64766 .33019 L
.64824 .3301 L
.64881 .33014 L
.64938 .33061 L
.64995 .33118 L
.65053 .33169 L
.6511 .33203 L
.65167 .3319 L
.65224 .33161 L
.65282 .33149 L
Mistroke
.65339 .33138 L
.65396 .3313 L
.65453 .33131 L
.65511 .33128 L
.65568 .33152 L
.65625 .33233 L
.65682 .33343 L
.65739 .33466 L
.65797 .33588 L
.65854 .33682 L
.65911 .33769 L
.65968 .33876 L
.66026 .33984 L
.66083 .34093 L
.6614 .342 L
.66197 .34287 L
.66255 .34376 L
.66312 .34488 L
.66369 .34597 L
.66426 .34695 L
.66484 .34765 L
.66541 .34782 L
.66598 .34771 L
.66655 .34759 L
.66712 .34737 L
.6677 .34714 L
.66827 .34689 L
.66884 .34646 L
.66941 .34611 L
.66999 .34602 L
.67056 .34602 L
.67113 .34608 L
.6717 .34607 L
.67228 .34579 L
.67285 .34545 L
.67342 .3452 L
.67399 .34502 L
.67457 .34494 L
.67514 .34492 L
.67571 .34481 L
.67628 .34474 L
.67685 .34482 L
.67743 .34492 L
.678 .34504 L
.67857 .34503 L
.67914 .34474 L
.67972 .34433 L
.68029 .34395 L
.68086 .34358 L
.68143 .34329 L
Mistroke
.68201 .34305 L
.68258 .34275 L
.68315 .34254 L
.68372 .34251 L
.68429 .34257 L
.68487 .34271 L
.68544 .34283 L
.68601 .34281 L
.68658 .34275 L
.68716 .34276 L
.68773 .34282 L
.6883 .34296 L
.68887 .34313 L
.68945 .34323 L
.69002 .34335 L
.69059 .34353 L
.69116 .34371 L
.69174 .34387 L
.69231 .34393 L
.69288 .34375 L
.69345 .34345 L
.69402 .34315 L
.6946 .34282 L
.69517 .34255 L
.69574 .34229 L
.69631 .34196 L
.69689 .34166 L
.69746 .34144 L
.69803 .34126 L
.6986 .34114 L
.69918 .341 L
.69975 .34076 L
.70032 .34051 L
.70089 .34031 L
.70147 .34017 L
.70204 .34014 L
.70261 .34017 L
.70318 .34018 L
.70375 .34023 L
.70433 .34031 L
.7049 .34042 L
.70547 .34055 L
.70604 .34065 L
.70662 .34063 L
.70719 .34058 L
.70776 .34052 L
.70833 .34048 L
.70891 .3405 L
.70948 .34055 L
.71005 .34056 L
Mistroke
.71062 .34059 L
.7112 .34065 L
.71177 .34073 L
.71234 .34084 L
.71291 .34094 L
.71348 .34098 L
.71406 .34101 L
.71463 .34106 L
.7152 .34113 L
.71577 .34126 L
.71635 .34141 L
.71692 .34154 L
.71749 .34166 L
.71806 .3418 L
.71864 .34193 L
.71921 .34205 L
.71978 .34214 L
.72035 .34214 L
.72092 .3421 L
.7215 .34204 L
.72207 .34198 L
.72264 .34195 L
.72321 .34192 L
.72379 .34186 L
.72436 .34181 L
.72493 .34176 L
.7255 .34171 L
.72608 .34169 L
.72665 .34166 L
.72722 .34159 L
.72779 .34151 L
.72837 .34145 L
.72894 .34141 L
.72951 .34143 L
.73008 .34147 L
.73065 .3415 L
.73123 .34155 L
.7318 .3416 L
.73237 .34165 L
.73294 .34171 L
.73352 .34176 L
.73409 .34177 L
.73466 .34176 L
.73523 .34175 L
.73581 .34174 L
.73638 .34175 L
.73695 .34178 L
.73752 .34179 L
.7381 .34179 L
.73867 .3418 L
Mistroke
.73924 .3418 L
.73981 .34182 L
.74038 .34182 L
.74096 .34181 L
.74153 .3418 L
.7421 .34178 L
.74267 .34178 L
.74325 .3418 L
.74382 .34182 L
.74439 .34185 L
.74496 .34187 L
.74554 .34189 L
.74611 .34191 L
.74668 .34193 L
.74725 .34194 L
.74783 .34192 L
.7484 .3419 L
.74897 .34187 L
.74954 .34184 L
.75011 .34182 L
.75069 .3418 L
.75126 .34178 L
.75183 .34175 L
.7524 .34173 L
.75298 .3417 L
.75355 .34168 L
.75412 .34166 L
.75469 .34163 L
.75527 .3416 L
.75584 .34157 L
.75641 .34155 L
.75698 .34155 L
.75755 .34156 L
.75813 .34157 L
.7587 .34159 L
.75927 .3416 L
.75984 .34161 L
.76042 .34163 L
.76099 .34164 L
.76156 .34165 L
.76213 .34165 L
.76271 .34165 L
.76328 .34165 L
.76385 .34166 L
.76442 .34167 L
.765 .34168 L
.76557 .34169 L
.76614 .34169 L
.76671 .34169 L
.76728 .34169 L
Mistroke
.76786 .34169 L
.76843 .34169 L
.769 .34168 L
.76957 .34168 L
.77015 .34168 L
.77072 .34168 L
.77129 .34169 L
.77186 .3417 L
.77244 .34171 L
.77301 .34172 L
.77358 .34172 L
.77415 .34173 L
.77473 .34173 L
.7753 .34173 L
.77587 .34172 L
.77644 .34172 L
.77701 .34171 L
.77759 .34171 L
.77816 .34171 L
.77873 .34171 L
.7793 .34171 L
.77988 .3417 L
.78045 .34169 L
.78102 .34169 L
.78159 .34168 L
.78217 .34168 L
.78274 .34167 L
.78331 .34166 L
.78388 .34166 L
.78446 .34166 L
.78503 .34166 L
.7856 .34167 L
.78617 .34167 L
.78674 .34167 L
.78732 .34168 L
.78789 .34168 L
.78846 .34169 L
.78903 .34169 L
.78961 .34169 L
.79018 .34169 L
.79075 .34169 L
.79132 .34169 L
.7919 .3417 L
.79247 .3417 L
.79304 .3417 L
.79361 .3417 L
.79418 .3417 L
.79476 .3417 L
.79533 .3417 L
.7959 .3417 L
Mistroke
.79647 .34169 L
.79705 .34169 L
.79762 .34169 L
.79819 .34169 L
.79876 .34169 L
.79934 .3417 L
.79991 .3417 L
.80048 .3417 L
.80105 .3417 L
.80163 .3417 L
.8022 .3417 L
.80277 .3417 L
.80334 .3417 L
.80391 .3417 L
.80449 .34169 L
.80506 .34169 L
.80563 .34169 L
.8062 .34169 L
.80678 .34169 L
.80735 .34169 L
.80792 .34169 L
.80849 .34169 L
.80907 .34169 L
.80964 .34169 L
.81021 .34169 L
.81078 .34168 L
.81136 .34168 L
.81193 .34168 L
.8125 .34168 L
.81307 .34169 L
.81364 .34169 L
.81422 .34169 L
.81479 .34169 L
.81536 .34169 L
.81593 .34169 L
.81651 .34169 L
.81708 .34169 L
.81765 .34169 L
.81822 .34169 L
.8188 .34169 L
.81937 .34169 L
.81994 .34169 L
.82051 .34169 L
.82109 .34169 L
.82166 .34169 L
.82223 .34169 L
.8228 .34169 L
.82337 .34169 L
.82395 .34169 L
.82452 .34169 L
Mistroke
.82509 .34169 L
.82566 .34169 L
.82624 .34169 L
.82681 .34169 L
.82738 .34169 L
.82795 .34169 L
.82853 .34169 L
.8291 .34169 L
.82967 .34169 L
.83024 .34169 L
.83082 .34169 L
.83139 .34169 L
.83196 .34169 L
.83253 .34169 L
.8331 .34169 L
.83368 .34169 L
.83425 .34169 L
.83482 .34169 L
.83539 .34169 L
.83597 .34169 L
.83654 .34169 L
.83711 .34169 L
.83768 .34169 L
.83826 .34169 L
.83883 .34169 L
.8394 .34169 L
.83997 .34169 L
.84054 .34169 L
.84112 .34169 L
.84169 .34169 L
.84226 .34169 L
.84283 .34169 L
.84341 .34169 L
.84398 .34169 L
.84455 .34169 L
.84512 .34169 L
.8457 .34169 L
.84627 .34169 L
.84684 .34169 L
.84741 .34169 L
.84799 .34169 L
.84856 .34169 L
.84913 .34169 L
.8497 .34169 L
.85027 .34169 L
.85085 .34169 L
.85142 .34169 L
.85199 .34169 L
.85256 .34169 L
.85314 .34169 L
Mistroke
.85371 .34169 L
.85428 .34169 L
.85485 .34169 L
.85543 .34169 L
.856 .34169 L
.85657 .34169 L
.85714 .34169 L
.85772 .34169 L
.85829 .34169 L
.85886 .34169 L
.85943 .34169 L
.86 .34169 L
.86058 .34169 L
.86115 .34169 L
.86172 .34169 L
.86229 .34169 L
.86287 .34169 L
.86344 .34169 L
.86401 .34169 L
.86458 .34169 L
.86516 .34169 L
.86573 .34169 L
.8663 .34169 L
.86687 .34169 L
.86745 .34169 L
.86802 .34169 L
.86859 .34169 L
.86916 .34169 L
.86973 .34169 L
.87031 .34169 L
.87088 .34169 L
.87145 .34169 L
.87202 .34169 L
.8726 .34169 L
.87317 .34169 L
.87374 .34169 L
.87431 .34169 L
.87489 .34169 L
.87546 .34169 L
.87603 .34169 L
.8766 .34169 L
.87717 .34169 L
.87775 .34169 L
.87832 .34169 L
.87889 .34169 L
.87946 .34169 L
.88004 .34169 L
.88061 .34169 L
.88118 .34169 L
.88175 .34169 L
Mistroke
.88233 .34169 L
.8829 .34169 L
.88347 .34169 L
.88404 .34169 L
.88462 .34169 L
.88519 .34169 L
.88576 .34169 L
.88633 .34169 L
.8869 .34169 L
.88748 .34169 L
.88805 .34169 L
.88862 .34169 L
.88919 .34169 L
.88977 .34169 L
.89034 .34169 L
.89091 .34169 L
.89148 .34169 L
.89206 .34169 L
.89263 .34169 L
.8932 .34169 L
.89377 .34169 L
.89435 .34169 L
.89492 .34169 L
.89549 .34169 L
.89606 .34169 L
.89663 .34169 L
.89721 .34169 L
.89778 .34169 L
.89835 .34169 L
.89892 .34169 L
.8995 .34169 L
.90007 .34169 L
.90064 .34169 L
.90121 .34169 L
.90179 .34169 L
.90236 .34169 L
.90293 .34169 L
.9035 .34169 L
.90408 .34169 L
.90465 .34169 L
.90522 .34169 L
.90579 .34169 L
.90636 .34169 L
.90694 .34169 L
.90751 .34169 L
.90808 .34169 L
.90865 .34169 L
.90923 .34169 L
.9098 .34169 L
.91037 .34169 L
Mistroke
.91094 .34169 L
.91152 .34169 L
.91209 .34169 L
.91266 .34169 L
.91323 .34169 L
.9138 .34169 L
.91438 .34169 L
.91495 .34169 L
.91552 .34169 L
.91609 .34169 L
.91667 .34169 L
.91724 .34169 L
.91781 .34169 L
.91838 .34169 L
.91896 .34169 L
.91953 .34169 L
.9201 .34169 L
.92067 .34169 L
.92125 .34169 L
.92182 .34169 L
.92239 .34169 L
.92296 .34169 L
.92353 .34169 L
.92411 .34169 L
.92468 .34169 L
.92525 .34169 L
.92582 .34169 L
.9264 .34169 L
.92697 .34169 L
.92754 .34169 L
.92811 .34169 L
.92869 .34169 L
.92926 .34169 L
.92983 .34169 L
.9304 .34169 L
.93098 .34169 L
.93155 .34169 L
.93212 .34169 L
.93269 .34169 L
.93326 .34169 L
.93384 .34169 L
.93441 .34169 L
.93498 .34169 L
.93555 .34169 L
.93613 .34169 L
.9367 .34169 L
.93727 .34169 L
.93784 .34169 L
.93842 .34169 L
.93899 .34169 L
Mistroke
.93956 .34169 L
.94013 .34169 L
.94071 .34169 L
.94128 .34169 L
.94185 .34169 L
.94242 .34169 L
.94299 .34169 L
.94357 .34169 L
.94414 .34169 L
.94471 .34169 L
.94528 .34169 L
.94586 .34169 L
.94643 .34169 L
.947 .34169 L
.94757 .34169 L
.94815 .34169 L
.94872 .34169 L
.94929 .34169 L
.94986 .34169 L
.95043 .34169 L
.95101 .34169 L
.95158 .34169 L
.95215 .34169 L
.95272 .34169 L
.9533 .34169 L
.95387 .34169 L
.95444 .34169 L
.95501 .34169 L
.95559 .34169 L
.95616 .34169 L
.95673 .34169 L
.9573 .34169 L
.95788 .34169 L
.95845 .34169 L
.95902 .34169 L
.95959 .34169 L
.96016 .34169 L
.96074 .34169 L
.96131 .34169 L
.96188 .34169 L
.96245 .34169 L
.96303 .34169 L
.9636 .34169 L
.96417 .34169 L
.96474 .34169 L
.96532 .34169 L
.96589 .34169 L
.96646 .34169 L
.96703 .34169 L
.96761 .34169 L
Mistroke
.96818 .34169 L
.96875 .34169 L
.96932 .34169 L
.96989 .34169 L
.97047 .34169 L
.97104 .34169 L
.97161 .34169 L
.97218 .34169 L
.97276 .34169 L
.97333 .34169 L
.9739 .34169 L
.97447 .34169 L
.97505 .34169 L
.97562 .34169 L
.97619 .34169 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],

Cell[TextData[{
  "To get the corresponding dual function, the order of the filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  " has to be reversed."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.23"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[Reverse[N[b]], 7, InverseTransform -> \
True],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"phitilde(t)\"}]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S1.6.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0147151 0.882879 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -4.5 ]
[1.025 .01472 6 4.5 ]
[.4875 .103 -18 -4.5 ]
[.4875 .103 0 4.5 ]
[.4875 .19129 -18 -4.5 ]
[.4875 .19129 0 4.5 ]
[.4875 .27958 -18 -4.5 ]
[.4875 .27958 0 4.5 ]
[.4875 .36787 -18 -4.5 ]
[.4875 .36787 0 4.5 ]
[.4875 .45615 -18 -4.5 ]
[.4875 .45615 0 4.5 ]
[.4875 .54444 -18 -4.5 ]
[.4875 .54444 0 4.5 ]
[.5 .64303 -33 0 ]
[.5 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-1)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(t)] 1.025 .01472 -1 0 Mshowa
.5 .103 m
.50625 .103 L
s
[(0.1)] .4875 .103 1 0 Mshowa
.5 .19129 m
.50625 .19129 L
s
[(0.2)] .4875 .19129 1 0 Mshowa
.5 .27958 m
.50625 .27958 L
s
[(0.3)] .4875 .27958 1 0 Mshowa
.5 .36787 m
.50625 .36787 L
s
[(0.4)] .4875 .36787 1 0 Mshowa
.5 .45615 m
.50625 .45615 L
s
[(0.5)] .4875 .45615 1 0 Mshowa
.5 .54444 m
.50625 .54444 L
s
[(0.6)] .4875 .54444 1 0 Mshowa
.125 Mabswid
.5 .03237 m
.50375 .03237 L
s
.5 .05003 m
.50375 .05003 L
s
.5 .06769 m
.50375 .06769 L
s
.5 .08535 m
.50375 .08535 L
s
.5 .12066 m
.50375 .12066 L
s
.5 .13832 m
.50375 .13832 L
s
.5 .15598 m
.50375 .15598 L
s
.5 .17363 m
.50375 .17363 L
s
.5 .20895 m
.50375 .20895 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24426 m
.50375 .24426 L
s
.5 .26192 m
.50375 .26192 L
s
.5 .29724 m
.50375 .29724 L
s
.5 .31489 m
.50375 .31489 L
s
.5 .33255 m
.50375 .33255 L
s
.5 .35021 m
.50375 .35021 L
s
.5 .38552 m
.50375 .38552 L
s
.5 .40318 m
.50375 .40318 L
s
.5 .42084 m
.50375 .42084 L
s
.5 .4385 m
.50375 .4385 L
s
.5 .47381 m
.50375 .47381 L
s
.5 .49147 m
.50375 .49147 L
s
.5 .50913 m
.50375 .50913 L
s
.5 .52678 m
.50375 .52678 L
s
.5 .5621 m
.50375 .5621 L
s
.5 .57976 m
.50375 .57976 L
s
.5 .59742 m
.50375 .59742 L
s
.5 .61507 m
.50375 .61507 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(phitilde\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02567 .01472 L
.02753 .01472 L
.02939 .01472 L
.03125 .01472 L
.03311 .01472 L
.03497 .01473 L
.03683 .01474 L
.03869 .01475 L
.04055 .01477 L
.04241 .01478 L
.04427 .01481 L
.04613 .01484 L
.04799 .01487 L
.04985 .01491 L
.05171 .01495 L
.05357 .015 L
.05543 .01506 L
.05729 .01512 L
.05915 .0152 L
.06101 .01528 L
.06287 .01536 L
.06473 .01546 L
.06659 .01557 L
.06845 .01568 L
.07031 .01581 L
.07217 .01595 L
.07403 .01609 L
.07589 .01625 L
.07775 .01642 L
.07961 .01661 L
.08147 .0168 L
.08333 .01701 L
.08519 .01723 L
.08705 .01747 L
.08891 .01772 L
.09077 .01799 L
.09263 .01827 L
.09449 .01856 L
.09635 .01887 L
.09821 .0192 L
.10007 .01955 L
.10193 .01991 L
.10379 .02029 L
.10565 .02069 L
.10751 .02111 L
.10938 .02154 L
.11124 .022 L
.1131 .02247 L
.11496 .02297 L
Mistroke
.11682 .02348 L
.11868 .02402 L
.12054 .02458 L
.1224 .02516 L
.12426 .02576 L
.12612 .02638 L
.12798 .02703 L
.12984 .02771 L
.1317 .0284 L
.13356 .02912 L
.13542 .02987 L
.13728 .03064 L
.13914 .03143 L
.141 .03226 L
.14286 .0331 L
.14472 .03398 L
.14658 .03488 L
.14844 .03581 L
.1503 .03677 L
.15216 .03776 L
.15402 .03878 L
.15588 .03982 L
.15774 .0409 L
.1596 .04201 L
.16146 .04314 L
.16332 .04431 L
.16518 .04551 L
.16704 .04674 L
.1689 .04801 L
.17076 .0493 L
.17262 .05063 L
.17448 .052 L
.17634 .0534 L
.1782 .05483 L
.18006 .0563 L
.18192 .0578 L
.18378 .05934 L
.18564 .06091 L
.1875 .06252 L
.18936 .06417 L
.19122 .06586 L
.19308 .06758 L
.19494 .06935 L
.1968 .07115 L
.19866 .07299 L
.20052 .07487 L
.20238 .07679 L
.20424 .07875 L
.2061 .08075 L
.20796 .08279 L
Mistroke
.20982 .08487 L
.21168 .087 L
.21354 .08917 L
.2154 .09138 L
.21726 .09363 L
.21912 .09593 L
.22098 .09828 L
.22284 .10066 L
.2247 .1031 L
.22656 .10557 L
.22842 .1081 L
.23028 .11067 L
.23214 .11328 L
.234 .11595 L
.23586 .11866 L
.23772 .12142 L
.23958 .12423 L
.24144 .12708 L
.2433 .12999 L
.24516 .13295 L
.24702 .13595 L
.24888 .13901 L
.25074 .14212 L
.2526 .14527 L
.25446 .14848 L
.25632 .15175 L
.25818 .15506 L
.26004 .15843 L
.2619 .16185 L
.26376 .16533 L
.26563 .16886 L
.26749 .17244 L
.26935 .17607 L
.27121 .17974 L
.27307 .18347 L
.27493 .18724 L
.27679 .19106 L
.27865 .19492 L
.28051 .19883 L
.28237 .20277 L
.28423 .20676 L
.28609 .21078 L
.28795 .21484 L
.28981 .21894 L
.29167 .22307 L
.29353 .22724 L
.29539 .23144 L
.29725 .23567 L
.29911 .23993 L
.30097 .24421 L
Mistroke
.30283 .24853 L
.30469 .25287 L
.30655 .25724 L
.30841 .26163 L
.31027 .26604 L
.31213 .27047 L
.31399 .27493 L
.31585 .2794 L
.31771 .28389 L
.31957 .28839 L
.32143 .29291 L
.32329 .29744 L
.32515 .30199 L
.32701 .30655 L
.32887 .31111 L
.33073 .31569 L
.33259 .32027 L
.33445 .32486 L
.33631 .32945 L
.33817 .33404 L
.34003 .33864 L
.34189 .34324 L
.34375 .34784 L
.34561 .35243 L
.34747 .35703 L
.34933 .36162 L
.35119 .3662 L
.35305 .37078 L
.35491 .37535 L
.35677 .37991 L
.35863 .38446 L
.36049 .38899 L
.36235 .39352 L
.36421 .39803 L
.36607 .40252 L
.36793 .407 L
.36979 .41146 L
.37165 .4159 L
.37351 .42032 L
.37537 .42472 L
.37723 .42909 L
.37909 .43344 L
.38095 .43777 L
.38281 .44206 L
.38467 .44633 L
.38653 .45057 L
.38839 .45478 L
.39025 .45896 L
.39211 .4631 L
.39397 .46721 L
Mistroke
.39583 .47128 L
.39769 .47532 L
.39955 .47932 L
.40141 .48328 L
.40327 .4872 L
.40513 .49107 L
.40699 .4949 L
.40885 .49869 L
.41071 .50243 L
.41257 .50613 L
.41443 .50977 L
.41629 .51337 L
.41815 .51692 L
.42001 .52041 L
.42188 .52385 L
.42374 .52723 L
.4256 .53056 L
.42746 .53384 L
.42932 .53705 L
.43118 .5402 L
.43304 .5433 L
.4349 .54633 L
.43676 .54929 L
.43862 .55219 L
.44048 .55503 L
.44234 .5578 L
.4442 .5605 L
.44606 .56313 L
.44792 .56569 L
.44978 .56817 L
.45164 .57059 L
.4535 .57292 L
.45536 .57519 L
.45722 .57737 L
.45908 .57947 L
.46094 .5815 L
.4628 .58344 L
.46466 .58531 L
.46652 .58708 L
.46838 .58878 L
.47024 .59038 L
.4721 .5919 L
.47396 .59333 L
.47582 .59467 L
.47768 .59592 L
.47954 .59708 L
.4814 .59814 L
.48326 .59911 L
.48512 .59998 L
.48698 .60075 L
Mistroke
.48884 .60142 L
.4907 .602 L
.49256 .60247 L
.49442 .60284 L
.49628 .6031 L
.49814 .60327 L
.5 .60332 L
.50186 .60327 L
.50372 .6031 L
.50558 .60284 L
.50744 .60247 L
.5093 .602 L
.51116 .60142 L
.51302 .60075 L
.51488 .59998 L
.51674 .59911 L
.5186 .59814 L
.52046 .59708 L
.52232 .59592 L
.52418 .59467 L
.52604 .59333 L
.5279 .5919 L
.52976 .59038 L
.53162 .58878 L
.53348 .58708 L
.53534 .58531 L
.5372 .58344 L
.53906 .5815 L
.54092 .57947 L
.54278 .57737 L
.54464 .57519 L
.5465 .57292 L
.54836 .57059 L
.55022 .56817 L
.55208 .56569 L
.55394 .56313 L
.5558 .5605 L
.55766 .5578 L
.55952 .55503 L
.56138 .55219 L
.56324 .54929 L
.5651 .54633 L
.56696 .5433 L
.56882 .5402 L
.57068 .53705 L
.57254 .53384 L
.5744 .53056 L
.57626 .52723 L
.57812 .52385 L
.57999 .52041 L
Mistroke
.58185 .51692 L
.58371 .51337 L
.58557 .50977 L
.58743 .50613 L
.58929 .50243 L
.59115 .49869 L
.59301 .4949 L
.59487 .49107 L
.59673 .4872 L
.59859 .48328 L
.60045 .47932 L
.60231 .47532 L
.60417 .47128 L
.60603 .46721 L
.60789 .4631 L
.60975 .45896 L
.61161 .45478 L
.61347 .45057 L
.61533 .44633 L
.61719 .44206 L
.61905 .43777 L
.62091 .43344 L
.62277 .42909 L
.62463 .42472 L
.62649 .42032 L
.62835 .4159 L
.63021 .41146 L
.63207 .407 L
.63393 .40252 L
.63579 .39803 L
.63765 .39352 L
.63951 .38899 L
.64137 .38446 L
.64323 .37991 L
.64509 .37535 L
.64695 .37078 L
.64881 .3662 L
.65067 .36162 L
.65253 .35703 L
.65439 .35243 L
.65625 .34784 L
.65811 .34324 L
.65997 .33864 L
.66183 .33404 L
.66369 .32945 L
.66555 .32486 L
.66741 .32027 L
.66927 .31569 L
.67113 .31111 L
.67299 .30655 L
Mistroke
.67485 .30199 L
.67671 .29744 L
.67857 .29291 L
.68043 .28839 L
.68229 .28389 L
.68415 .2794 L
.68601 .27493 L
.68787 .27047 L
.68973 .26604 L
.69159 .26163 L
.69345 .25724 L
.69531 .25287 L
.69717 .24853 L
.69903 .24421 L
.70089 .23993 L
.70275 .23567 L
.70461 .23144 L
.70647 .22724 L
.70833 .22307 L
.71019 .21894 L
.71205 .21484 L
.71391 .21078 L
.71577 .20676 L
.71763 .20277 L
.71949 .19883 L
.72135 .19492 L
.72321 .19106 L
.72507 .18724 L
.72693 .18347 L
.72879 .17974 L
.73065 .17607 L
.73251 .17244 L
.73437 .16886 L
.73624 .16533 L
.7381 .16185 L
.73996 .15843 L
.74182 .15506 L
.74368 .15175 L
.74554 .14848 L
.7474 .14527 L
.74926 .14212 L
.75112 .13901 L
.75298 .13595 L
.75484 .13295 L
.7567 .12999 L
.75856 .12708 L
.76042 .12423 L
.76228 .12142 L
.76414 .11866 L
.766 .11595 L
Mistroke
.76786 .11328 L
.76972 .11067 L
.77158 .1081 L
.77344 .10557 L
.7753 .1031 L
.77716 .10066 L
.77902 .09828 L
.78088 .09593 L
.78274 .09363 L
.7846 .09138 L
.78646 .08917 L
.78832 .087 L
.79018 .08487 L
.79204 .08279 L
.7939 .08075 L
.79576 .07875 L
.79762 .07679 L
.79948 .07487 L
.80134 .07299 L
.8032 .07115 L
.80506 .06935 L
.80692 .06758 L
.80878 .06586 L
.81064 .06417 L
.8125 .06252 L
.81436 .06091 L
.81622 .05934 L
.81808 .0578 L
.81994 .0563 L
.8218 .05483 L
.82366 .0534 L
.82552 .052 L
.82738 .05063 L
.82924 .0493 L
.8311 .04801 L
.83296 .04674 L
.83482 .04551 L
.83668 .04431 L
.83854 .04314 L
.8404 .04201 L
.84226 .0409 L
.84412 .03982 L
.84598 .03878 L
.84784 .03776 L
.8497 .03677 L
.85156 .03581 L
.85342 .03488 L
.85528 .03398 L
.85714 .0331 L
.859 .03226 L
Mistroke
.86086 .03143 L
.86272 .03064 L
.86458 .02987 L
.86644 .02912 L
.8683 .0284 L
.87016 .02771 L
.87202 .02703 L
.87388 .02638 L
.87574 .02576 L
.8776 .02516 L
.87946 .02458 L
.88132 .02402 L
.88318 .02348 L
.88504 .02297 L
.8869 .02247 L
.88876 .022 L
.89062 .02154 L
.89249 .02111 L
.89435 .02069 L
.89621 .02029 L
.89807 .01991 L
.89993 .01955 L
.90179 .0192 L
.90365 .01887 L
.90551 .01856 L
.90737 .01827 L
.90923 .01799 L
.91109 .01772 L
.91295 .01747 L
.91481 .01723 L
.91667 .01701 L
.91853 .0168 L
.92039 .01661 L
.92225 .01642 L
.92411 .01625 L
.92597 .01609 L
.92783 .01595 L
.92969 .01581 L
.93155 .01568 L
.93341 .01557 L
.93527 .01546 L
.93713 .01536 L
.93899 .01528 L
.94085 .0152 L
.94271 .01512 L
.94457 .01506 L
.94643 .015 L
.94829 .01495 L
.95015 .01491 L
.95201 .01487 L
Mistroke
.95387 .01484 L
.95573 .01481 L
.95759 .01478 L
.95945 .01477 L
.96131 .01475 L
.96317 .01474 L
.96503 .01473 L
.96689 .01472 L
.96875 .01472 L
.97061 .01472 L
.97247 .01472 L
.97433 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],

Cell[TextData[{
  "This is the dual wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.6.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.6.4", "4.24"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[Reverse[N[b]], 7,
InverseTransform -> True],
PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"psitilde(t)\"}]\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S1.6.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.46337 0.0732601 0.382847 0.353067 [
[.02381 .37035 -6 -9 ]
[.02381 .37035 6 0 ]
[.17033 .37035 -6 -9 ]
[.17033 .37035 6 0 ]
[.31685 .37035 -6 -9 ]
[.31685 .37035 6 0 ]
[.60989 .37035 -3 -9 ]
[.60989 .37035 3 0 ]
[.75641 .37035 -3 -9 ]
[.75641 .37035 3 0 ]
[.90293 .37035 -3 -9 ]
[.90293 .37035 3 0 ]
[1.025 .38285 0 -4.5 ]
[1.025 .38285 6 4.5 ]
[.45087 .02978 -12 -4.5 ]
[.45087 .02978 0 4.5 ]
[.45087 .11805 -30 -4.5 ]
[.45087 .11805 0 4.5 ]
[.45087 .20631 -24 -4.5 ]
[.45087 .20631 0 4.5 ]
[.45087 .29458 -30 -4.5 ]
[.45087 .29458 0 4.5 ]
[.45087 .47111 -24 -4.5 ]
[.45087 .47111 0 4.5 ]
[.45087 .55938 -18 -4.5 ]
[.45087 .55938 0 4.5 ]
[.46337 .64303 -33 0 ]
[.46337 .64303 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .38285 m
.02381 .3891 L
s
[(-6)] .02381 .37035 0 1 Mshowa
.17033 .38285 m
.17033 .3891 L
s
[(-4)] .17033 .37035 0 1 Mshowa
.31685 .38285 m
.31685 .3891 L
s
[(-2)] .31685 .37035 0 1 Mshowa
.60989 .38285 m
.60989 .3891 L
s
[(2)] .60989 .37035 0 1 Mshowa
.75641 .38285 m
.75641 .3891 L
s
[(4)] .75641 .37035 0 1 Mshowa
.90293 .38285 m
.90293 .3891 L
s
[(6)] .90293 .37035 0 1 Mshowa
.125 Mabswid
.06044 .38285 m
.06044 .3866 L
s
.09707 .38285 m
.09707 .3866 L
s
.1337 .38285 m
.1337 .3866 L
s
.20696 .38285 m
.20696 .3866 L
s
.24359 .38285 m
.24359 .3866 L
s
.28022 .38285 m
.28022 .3866 L
s
.35348 .38285 m
.35348 .3866 L
s
.39011 .38285 m
.39011 .3866 L
s
.42674 .38285 m
.42674 .3866 L
s
.5 .38285 m
.5 .3866 L
s
.53663 .38285 m
.53663 .3866 L
s
.57326 .38285 m
.57326 .3866 L
s
.64652 .38285 m
.64652 .3866 L
s
.68315 .38285 m
.68315 .3866 L
s
.71978 .38285 m
.71978 .3866 L
s
.79304 .38285 m
.79304 .3866 L
s
.82967 .38285 m
.82967 .3866 L
s
.8663 .38285 m
.8663 .3866 L
s
.93956 .38285 m
.93956 .3866 L
s
.97619 .38285 m
.97619 .3866 L
s
.25 Mabswid
0 .38285 m
1 .38285 L
s
[(t)] 1.025 .38285 -1 0 Mshowa
.46337 .02978 m
.46962 .02978 L
s
[(-1)] .45087 .02978 1 0 Mshowa
.46337 .11805 m
.46962 .11805 L
s
[(-0.75)] .45087 .11805 1 0 Mshowa
.46337 .20631 m
.46962 .20631 L
s
[(-0.5)] .45087 .20631 1 0 Mshowa
.46337 .29458 m
.46962 .29458 L
s
[(-0.25)] .45087 .29458 1 0 Mshowa
.46337 .47111 m
.46962 .47111 L
s
[(0.25)] .45087 .47111 1 0 Mshowa
.46337 .55938 m
.46962 .55938 L
s
[(0.5)] .45087 .55938 1 0 Mshowa
.125 Mabswid
.46337 .04743 m
.46712 .04743 L
s
.46337 .06509 m
.46712 .06509 L
s
.46337 .08274 m
.46712 .08274 L
s
.46337 .10039 m
.46712 .10039 L
s
.46337 .1357 m
.46712 .1357 L
s
.46337 .15335 m
.46712 .15335 L
s
.46337 .17101 m
.46712 .17101 L
s
.46337 .18866 m
.46712 .18866 L
s
.46337 .22397 m
.46712 .22397 L
s
.46337 .24162 m
.46712 .24162 L
s
.46337 .25927 m
.46712 .25927 L
s
.46337 .27693 m
.46712 .27693 L
s
.46337 .31223 m
.46712 .31223 L
s
.46337 .32989 m
.46712 .32989 L
s
.46337 .34754 m
.46712 .34754 L
s
.46337 .36519 m
.46712 .36519 L
s
.46337 .4005 m
.46712 .4005 L
s
.46337 .41815 m
.46712 .41815 L
s
.46337 .43581 m
.46712 .43581 L
s
.46337 .45346 m
.46712 .45346 L
s
.46337 .48877 m
.46712 .48877 L
s
.46337 .50642 m
.46712 .50642 L
s
.46337 .52407 m
.46712 .52407 L
s
.46337 .54173 m
.46712 .54173 L
s
.46337 .01213 m
.46712 .01213 L
s
.46337 .57703 m
.46712 .57703 L
s
.46337 .59469 m
.46712 .59469 L
s
.46337 .61234 m
.46712 .61234 L
s
.25 Mabswid
.46337 0 m
.46337 .61803 L
s
[(psitilde\\(t\\))] .46337 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .38285 m
.02438 .38285 L
.02495 .38285 L
.02553 .38285 L
.0261 .38285 L
.02667 .38285 L
.02724 .38285 L
.02782 .38285 L
.02839 .38285 L
.02896 .38285 L
.02953 .38285 L
.03011 .38285 L
.03068 .38285 L
.03125 .38285 L
.03182 .38285 L
.03239 .38285 L
.03297 .38285 L
.03354 .38285 L
.03411 .38285 L
.03468 .38285 L
.03526 .38285 L
.03583 .38285 L
.0364 .38285 L
.03697 .38285 L
.03755 .38285 L
.03812 .38285 L
.03869 .38285 L
.03926 .38285 L
.03984 .38285 L
.04041 .38285 L
.04098 .38285 L
.04155 .38285 L
.04212 .38285 L
.0427 .38285 L
.04327 .38285 L
.04384 .38285 L
.04441 .38285 L
.04499 .38285 L
.04556 .38285 L
.04613 .38285 L
.0467 .38285 L
.04728 .38285 L
.04785 .38285 L
.04842 .38285 L
.04899 .38286 L
.04957 .38286 L
.05014 .38286 L
.05071 .38286 L
.05128 .38286 L
.05185 .38286 L
Mistroke
.05243 .38286 L
.053 .38286 L
.05357 .38286 L
.05414 .38286 L
.05472 .38286 L
.05529 .38286 L
.05586 .38286 L
.05643 .38286 L
.05701 .38287 L
.05758 .38287 L
.05815 .38287 L
.05872 .38287 L
.05929 .38287 L
.05987 .38287 L
.06044 .38287 L
.06101 .38287 L
.06158 .38288 L
.06216 .38288 L
.06273 .38288 L
.0633 .38288 L
.06387 .38288 L
.06445 .38288 L
.06502 .38288 L
.06559 .38289 L
.06616 .38289 L
.06674 .38289 L
.06731 .38289 L
.06788 .38289 L
.06845 .38289 L
.06902 .3829 L
.0696 .3829 L
.07017 .3829 L
.07074 .3829 L
.07131 .3829 L
.07189 .38291 L
.07246 .38291 L
.07303 .38291 L
.0736 .38291 L
.07418 .38291 L
.07475 .38292 L
.07532 .38292 L
.07589 .38292 L
.07647 .38292 L
.07704 .38293 L
.07761 .38293 L
.07818 .38293 L
.07875 .38293 L
.07933 .38294 L
.0799 .38294 L
.08047 .38294 L
Mistroke
.08104 .38295 L
.08162 .38295 L
.08219 .38295 L
.08276 .38295 L
.08333 .38296 L
.08391 .38296 L
.08448 .38296 L
.08505 .38297 L
.08562 .38297 L
.0862 .38297 L
.08677 .38298 L
.08734 .38298 L
.08791 .38299 L
.08848 .38299 L
.08906 .38299 L
.08963 .383 L
.0902 .383 L
.09077 .38301 L
.09135 .38301 L
.09192 .38301 L
.09249 .38302 L
.09306 .38302 L
.09364 .38303 L
.09421 .38303 L
.09478 .38304 L
.09535 .38304 L
.09592 .38304 L
.0965 .38305 L
.09707 .38305 L
.09764 .38306 L
.09821 .38306 L
.09879 .38307 L
.09936 .38307 L
.09993 .38308 L
.1005 .38308 L
.10108 .38309 L
.10165 .38309 L
.10222 .3831 L
.10279 .38311 L
.10337 .38311 L
.10394 .38312 L
.10451 .38312 L
.10508 .38313 L
.10565 .38313 L
.10623 .38314 L
.1068 .38314 L
.10737 .38315 L
.10794 .38315 L
.10852 .38316 L
.10909 .38316 L
Mistroke
.10966 .38316 L
.11023 .38317 L
.11081 .38317 L
.11138 .38318 L
.11195 .38318 L
.11252 .38319 L
.1131 .38319 L
.11367 .38319 L
.11424 .3832 L
.11481 .3832 L
.11538 .3832 L
.11596 .3832 L
.11653 .38321 L
.1171 .38321 L
.11767 .38321 L
.11825 .38321 L
.11882 .38322 L
.11939 .38322 L
.11996 .38322 L
.12054 .38322 L
.12111 .38322 L
.12168 .38322 L
.12225 .38322 L
.12283 .38322 L
.1234 .38322 L
.12397 .38322 L
.12454 .38322 L
.12511 .38322 L
.12569 .38321 L
.12626 .38321 L
.12683 .38321 L
.1274 .38321 L
.12798 .3832 L
.12855 .3832 L
.12912 .3832 L
.12969 .38319 L
.13027 .38319 L
.13084 .38318 L
.13141 .38318 L
.13198 .38317 L
.13255 .38316 L
.13313 .38316 L
.1337 .38315 L
.13427 .38314 L
.13484 .38313 L
.13542 .38312 L
.13599 .38311 L
.13656 .3831 L
.13713 .38309 L
.13771 .38308 L
Mistroke
.13828 .38307 L
.13885 .38306 L
.13942 .38305 L
.14 .38303 L
.14057 .38302 L
.14114 .38301 L
.14171 .38299 L
.14228 .38297 L
.14286 .38296 L
.14343 .38294 L
.144 .38292 L
.14457 .38291 L
.14515 .38289 L
.14572 .38287 L
.14629 .38285 L
.14686 .38283 L
.14744 .38281 L
.14801 .38279 L
.14858 .38276 L
.14915 .38274 L
.14973 .38272 L
.1503 .38269 L
.15087 .38267 L
.15144 .38264 L
.15201 .38261 L
.15259 .38259 L
.15316 .38256 L
.15373 .38253 L
.1543 .3825 L
.15488 .38247 L
.15545 .38244 L
.15602 .38241 L
.15659 .38237 L
.15717 .38234 L
.15774 .3823 L
.15831 .38227 L
.15888 .38223 L
.15946 .3822 L
.16003 .38216 L
.1606 .38212 L
.16117 .38208 L
.16174 .38204 L
.16232 .382 L
.16289 .38195 L
.16346 .38191 L
.16403 .38187 L
.16461 .38182 L
.16518 .38178 L
.16575 .38173 L
.16632 .38168 L
Mistroke
.1669 .38163 L
.16747 .38158 L
.16804 .38153 L
.16861 .38148 L
.16918 .38143 L
.16976 .38137 L
.17033 .38132 L
.1709 .38126 L
.17147 .38121 L
.17205 .38115 L
.17262 .38109 L
.17319 .38103 L
.17376 .38097 L
.17434 .38091 L
.17491 .38085 L
.17548 .38079 L
.17605 .38073 L
.17663 .38066 L
.1772 .3806 L
.17777 .38054 L
.17834 .38047 L
.17891 .38041 L
.17949 .38035 L
.18006 .38028 L
.18063 .38022 L
.1812 .38015 L
.18178 .38009 L
.18235 .38003 L
.18292 .37996 L
.18349 .3799 L
.18407 .37984 L
.18464 .37977 L
.18521 .37971 L
.18578 .37965 L
.18636 .37959 L
.18693 .37953 L
.1875 .37947 L
.18807 .37941 L
.18864 .37935 L
.18922 .37929 L
.18979 .37924 L
.19036 .37918 L
.19093 .37913 L
.19151 .37907 L
.19208 .37902 L
.19265 .37897 L
.19322 .37892 L
.1938 .37887 L
.19437 .37882 L
.19494 .37878 L
Mistroke
.19551 .37873 L
.19609 .37869 L
.19666 .37865 L
.19723 .37861 L
.1978 .37857 L
.19837 .37854 L
.19895 .3785 L
.19952 .37847 L
.20009 .37844 L
.20066 .37841 L
.20124 .37839 L
.20181 .37836 L
.20238 .37834 L
.20295 .37832 L
.20353 .3783 L
.2041 .37829 L
.20467 .37828 L
.20524 .37827 L
.20582 .37826 L
.20639 .37826 L
.20696 .37825 L
.20753 .37825 L
.2081 .37826 L
.20868 .37826 L
.20925 .37827 L
.20982 .37828 L
.21039 .3783 L
.21097 .37832 L
.21154 .37834 L
.21211 .37836 L
.21268 .37839 L
.21326 .37842 L
.21383 .37846 L
.2144 .37849 L
.21497 .37854 L
.21554 .37858 L
.21612 .37863 L
.21669 .37868 L
.21726 .37874 L
.21783 .3788 L
.21841 .37886 L
.21898 .37893 L
.21955 .379 L
.22012 .37907 L
.2207 .37915 L
.22127 .37924 L
.22184 .37932 L
.22241 .37942 L
.22299 .37951 L
.22356 .37961 L
Mistroke
.22413 .37972 L
.2247 .37983 L
.22527 .37994 L
.22585 .38006 L
.22642 .38018 L
.22699 .38031 L
.22756 .38044 L
.22814 .38058 L
.22871 .38072 L
.22928 .38087 L
.22985 .38102 L
.23043 .38118 L
.231 .38134 L
.23157 .38151 L
.23214 .38168 L
.23272 .38186 L
.23329 .38204 L
.23386 .38223 L
.23443 .38242 L
.235 .38262 L
.23558 .38283 L
.23615 .38304 L
.23672 .38326 L
.23729 .38348 L
.23787 .38371 L
.23844 .38394 L
.23901 .38418 L
.23958 .38443 L
.24016 .38468 L
.24073 .38494 L
.2413 .3852 L
.24187 .38547 L
.24245 .38575 L
.24302 .38603 L
.24359 .38632 L
.24416 .38662 L
.24473 .38692 L
.24531 .38723 L
.24588 .38754 L
.24645 .38786 L
.24702 .38818 L
.2476 .38851 L
.24817 .38885 L
.24874 .38919 L
.24931 .38953 L
.24989 .38987 L
.25046 .39022 L
.25103 .39058 L
.2516 .39093 L
.25217 .39129 L
Mistroke
.25275 .39166 L
.25332 .39202 L
.25389 .39239 L
.25446 .39275 L
.25504 .39312 L
.25561 .3935 L
.25618 .39387 L
.25675 .39424 L
.25733 .39461 L
.2579 .39499 L
.25847 .39536 L
.25904 .39573 L
.25962 .39611 L
.26019 .39648 L
.26076 .39685 L
.26133 .39722 L
.2619 .39759 L
.26248 .39796 L
.26305 .39832 L
.26362 .39868 L
.26419 .39904 L
.26477 .3994 L
.26534 .39975 L
.26591 .40011 L
.26648 .40045 L
.26706 .4008 L
.26763 .40114 L
.2682 .40147 L
.26877 .4018 L
.26935 .40213 L
.26992 .40245 L
.27049 .40276 L
.27106 .40307 L
.27163 .40337 L
.27221 .40367 L
.27278 .40396 L
.27335 .40425 L
.27392 .40453 L
.2745 .4048 L
.27507 .40506 L
.27564 .40531 L
.27621 .40556 L
.27679 .4058 L
.27736 .40603 L
.27793 .40625 L
.2785 .40647 L
.27908 .40667 L
.27965 .40686 L
.28022 .40705 L
.28079 .40722 L
Mistroke
.28136 .40739 L
.28194 .40754 L
.28251 .40768 L
.28308 .40782 L
.28365 .40794 L
.28423 .40805 L
.2848 .40814 L
.28537 .40823 L
.28594 .4083 L
.28652 .40836 L
.28709 .40841 L
.28766 .40845 L
.28823 .40847 L
.2888 .40847 L
.28938 .40847 L
.28995 .40845 L
.29052 .40841 L
.29109 .40836 L
.29167 .4083 L
.29224 .40822 L
.29281 .40813 L
.29338 .40802 L
.29396 .40789 L
.29453 .40775 L
.2951 .40759 L
.29567 .40742 L
.29625 .40722 L
.29682 .40701 L
.29739 .40679 L
.29796 .40654 L
.29853 .40628 L
.29911 .406 L
.29968 .4057 L
.30025 .40538 L
.30082 .40505 L
.3014 .40469 L
.30197 .40431 L
.30254 .40392 L
.30311 .4035 L
.30369 .40307 L
.30426 .40261 L
.30483 .40214 L
.3054 .40164 L
.30598 .40112 L
.30655 .40058 L
.30712 .40002 L
.30769 .39943 L
.30826 .39882 L
.30884 .39819 L
.30941 .39754 L
Mistroke
.30998 .39687 L
.31055 .39617 L
.31113 .39545 L
.3117 .3947 L
.31227 .39393 L
.31284 .39314 L
.31342 .39232 L
.31399 .39147 L
.31456 .3906 L
.31513 .38971 L
.31571 .38879 L
.31628 .38784 L
.31685 .38687 L
.31742 .38587 L
.31799 .38485 L
.31857 .3838 L
.31914 .38272 L
.31971 .38163 L
.32028 .38051 L
.32086 .37937 L
.32143 .37821 L
.322 .37703 L
.32257 .37583 L
.32315 .37461 L
.32372 .37338 L
.32429 .37213 L
.32486 .37087 L
.32543 .36959 L
.32601 .36829 L
.32658 .36699 L
.32715 .36567 L
.32772 .36434 L
.3283 .363 L
.32887 .36165 L
.32944 .36029 L
.33001 .35892 L
.33059 .35755 L
.33116 .35617 L
.33173 .35479 L
.3323 .3534 L
.33288 .35201 L
.33345 .35061 L
.33402 .34921 L
.33459 .34782 L
.33516 .34642 L
.33574 .34502 L
.33631 .34362 L
.33688 .34223 L
.33745 .34084 L
.33803 .33945 L
Mistroke
.3386 .33807 L
.33917 .3367 L
.33974 .33533 L
.34032 .33396 L
.34089 .33261 L
.34146 .33127 L
.34203 .32993 L
.34261 .32861 L
.34318 .3273 L
.34375 .326 L
.34432 .32471 L
.34489 .32344 L
.34547 .32218 L
.34604 .32094 L
.34661 .31972 L
.34718 .31851 L
.34776 .31732 L
.34833 .31615 L
.3489 .315 L
.34947 .31387 L
.35005 .31277 L
.35062 .31168 L
.35119 .31062 L
.35176 .30959 L
.35234 .30858 L
.35291 .30759 L
.35348 .30664 L
.35405 .30571 L
.35462 .30481 L
.3552 .30393 L
.35577 .30309 L
.35634 .30228 L
.35691 .3015 L
.35749 .30076 L
.35806 .30005 L
.35863 .29937 L
.3592 .29873 L
.35978 .29812 L
.36035 .29755 L
.36092 .29702 L
.36149 .29653 L
.36207 .29608 L
.36264 .29567 L
.36321 .29529 L
.36378 .29497 L
.36435 .29468 L
.36493 .29444 L
.3655 .29424 L
.36607 .29409 L
.36664 .29398 L
Mistroke
.36722 .29393 L
.36779 .29392 L
.36836 .29395 L
.36893 .29404 L
.36951 .29418 L
.37008 .29437 L
.37065 .29461 L
.37122 .29491 L
.37179 .29526 L
.37237 .29567 L
.37294 .29613 L
.37351 .29664 L
.37408 .29722 L
.37466 .29785 L
.37523 .29854 L
.3758 .29929 L
.37637 .3001 L
.37695 .30098 L
.37752 .30191 L
.37809 .30291 L
.37866 .30398 L
.37924 .30511 L
.37981 .3063 L
.38038 .30756 L
.38095 .30889 L
.38152 .31029 L
.3821 .31175 L
.38267 .31329 L
.38324 .3149 L
.38381 .31658 L
.38439 .31833 L
.38496 .32015 L
.38553 .32205 L
.3861 .32402 L
.38668 .32608 L
.38725 .3282 L
.38782 .33041 L
.38839 .33269 L
.38897 .33505 L
.38954 .3375 L
.39011 .34002 L
.39068 .34263 L
.39125 .34531 L
.39183 .34807 L
.3924 .35091 L
.39297 .35382 L
.39354 .3568 L
.39412 .35984 L
.39469 .36295 L
.39526 .36612 L
Mistroke
.39583 .36936 L
.39641 .37265 L
.39698 .37599 L
.39755 .37939 L
.39812 .38283 L
.3987 .38633 L
.39927 .38987 L
.39984 .39345 L
.40041 .39707 L
.40098 .40073 L
.40156 .40442 L
.40213 .40815 L
.4027 .4119 L
.40327 .41569 L
.40385 .4195 L
.40442 .42333 L
.40499 .42718 L
.40556 .43105 L
.40614 .43494 L
.40671 .43884 L
.40728 .44275 L
.40785 .44667 L
.40842 .45059 L
.409 .45452 L
.40957 .45844 L
.41014 .46237 L
.41071 .46629 L
.41129 .4702 L
.41186 .47411 L
.41243 .478 L
.413 .48188 L
.41358 .48574 L
.41415 .48958 L
.41472 .4934 L
.41529 .4972 L
.41587 .50097 L
.41644 .50471 L
.41701 .50842 L
.41758 .5121 L
.41815 .51574 L
.41873 .51934 L
.4193 .5229 L
.41987 .52642 L
.42044 .52989 L
.42102 .53331 L
.42159 .53668 L
.42216 .54 L
.42273 .54326 L
.42331 .54646 L
.42388 .54961 L
Mistroke
.42445 .55268 L
.42502 .5557 L
.4256 .55864 L
.42617 .56151 L
.42674 .56431 L
.42731 .56704 L
.42788 .56968 L
.42846 .57225 L
.42903 .57473 L
.4296 .57713 L
.43017 .57944 L
.43075 .58165 L
.43132 .58378 L
.43189 .58581 L
.43246 .58774 L
.43304 .58957 L
.43361 .5913 L
.43418 .59292 L
.43475 .59444 L
.43533 .59584 L
.4359 .59713 L
.43647 .59831 L
.43704 .59937 L
.43761 .60031 L
.43819 .60113 L
.43876 .60182 L
.43933 .60238 L
.4399 .60282 L
.44048 .60312 L
.44105 .60329 L
.44162 .60332 L
.44219 .60321 L
.44277 .60296 L
.44334 .60256 L
.44391 .60202 L
.44448 .60132 L
.44505 .60048 L
.44563 .59948 L
.4462 .59832 L
.44677 .597 L
.44734 .59552 L
.44792 .59388 L
.44849 .59207 L
.44906 .59009 L
.44963 .58794 L
.45021 .58562 L
.45078 .58311 L
.45135 .58043 L
.45192 .57757 L
.4525 .57452 L
Mistroke
.45307 .57129 L
.45364 .56787 L
.45421 .56425 L
.45478 .56044 L
.45536 .55644 L
.45593 .55224 L
.4565 .54783 L
.45707 .54322 L
.45765 .53841 L
.45822 .53338 L
.45879 .52815 L
.45936 .5227 L
.45994 .51704 L
.46051 .51115 L
.46108 .50505 L
.46165 .49872 L
.46223 .49217 L
.4628 .48538 L
.46337 .47837 L
.46394 .47112 L
.46451 .46365 L
.46509 .45597 L
.46566 .44809 L
.46623 .44002 L
.4668 .43177 L
.46738 .42334 L
.46795 .41477 L
.46852 .40604 L
.46909 .39718 L
.46967 .38819 L
.47024 .37909 L
.47081 .36988 L
.47138 .36058 L
.47196 .3512 L
.47253 .34174 L
.4731 .33223 L
.47367 .32266 L
.47424 .31306 L
.47482 .30342 L
.47539 .29377 L
.47596 .28411 L
.47653 .27446 L
.47711 .26482 L
.47768 .2552 L
.47825 .24562 L
.47882 .23609 L
.4794 .22661 L
.47997 .21721 L
.48054 .20788 L
.48111 .19864 L
Mistroke
.48168 .1895 L
.48226 .18048 L
.48283 .17157 L
.4834 .1628 L
.48397 .15417 L
.48455 .1457 L
.48512 .13739 L
.48569 .12926 L
.48626 .12132 L
.48684 .11357 L
.48741 .10603 L
.48798 .09871 L
.48855 .09162 L
.48913 .08478 L
.4897 .07818 L
.49027 .07184 L
.49084 .06578 L
.49141 .06 L
.49199 .05452 L
.49256 .04934 L
.49313 .04448 L
.4937 .03994 L
.49428 .03575 L
.49485 .0319 L
.49542 .02841 L
.49599 .02529 L
.49657 .02255 L
.49714 .0202 L
.49771 .01826 L
.49828 .01672 L
.49886 .01562 L
.49943 .01494 L
.5 .01472 L
.50057 .01494 L
.50114 .01562 L
.50172 .01672 L
.50229 .01826 L
.50286 .0202 L
.50343 .02255 L
.50401 .02529 L
.50458 .02841 L
.50515 .0319 L
.50572 .03575 L
.5063 .03994 L
.50687 .04448 L
.50744 .04934 L
.50801 .05452 L
.50859 .06 L
.50916 .06578 L
.50973 .07184 L
Mistroke
.5103 .07818 L
.51087 .08478 L
.51145 .09162 L
.51202 .09871 L
.51259 .10603 L
.51316 .11357 L
.51374 .12132 L
.51431 .12926 L
.51488 .13739 L
.51545 .1457 L
.51603 .15417 L
.5166 .1628 L
.51717 .17157 L
.51774 .18048 L
.51832 .1895 L
.51889 .19864 L
.51946 .20788 L
.52003 .21721 L
.5206 .22661 L
.52118 .23609 L
.52175 .24562 L
.52232 .2552 L
.52289 .26482 L
.52347 .27446 L
.52404 .28411 L
.52461 .29377 L
.52518 .30342 L
.52576 .31306 L
.52633 .32266 L
.5269 .33223 L
.52747 .34174 L
.52804 .3512 L
.52862 .36058 L
.52919 .36988 L
.52976 .37909 L
.53033 .38819 L
.53091 .39718 L
.53148 .40604 L
.53205 .41477 L
.53262 .42334 L
.5332 .43177 L
.53377 .44002 L
.53434 .44809 L
.53491 .45597 L
.53549 .46365 L
.53606 .47112 L
.53663 .47837 L
.5372 .48538 L
.53777 .49217 L
.53835 .49872 L
Mistroke
.53892 .50505 L
.53949 .51115 L
.54006 .51704 L
.54064 .5227 L
.54121 .52815 L
.54178 .53338 L
.54235 .53841 L
.54293 .54322 L
.5435 .54783 L
.54407 .55224 L
.54464 .55644 L
.54522 .56044 L
.54579 .56425 L
.54636 .56787 L
.54693 .57129 L
.5475 .57452 L
.54808 .57757 L
.54865 .58043 L
.54922 .58311 L
.54979 .58562 L
.55037 .58794 L
.55094 .59009 L
.55151 .59207 L
.55208 .59388 L
.55266 .59552 L
.55323 .597 L
.5538 .59832 L
.55437 .59948 L
.55495 .60048 L
.55552 .60132 L
.55609 .60202 L
.55666 .60256 L
.55723 .60296 L
.55781 .60321 L
.55838 .60332 L
.55895 .60329 L
.55952 .60312 L
.5601 .60282 L
.56067 .60238 L
.56124 .60182 L
.56181 .60113 L
.56239 .60031 L
.56296 .59937 L
.56353 .59831 L
.5641 .59713 L
.56467 .59584 L
.56525 .59444 L
.56582 .59292 L
.56639 .5913 L
.56696 .58957 L
Mistroke
.56754 .58774 L
.56811 .58581 L
.56868 .58378 L
.56925 .58165 L
.56983 .57944 L
.5704 .57713 L
.57097 .57473 L
.57154 .57225 L
.57212 .56968 L
.57269 .56704 L
.57326 .56431 L
.57383 .56151 L
.5744 .55864 L
.57498 .5557 L
.57555 .55268 L
.57612 .54961 L
.57669 .54646 L
.57727 .54326 L
.57784 .54 L
.57841 .53668 L
.57898 .53331 L
.57956 .52989 L
.58013 .52642 L
.5807 .5229 L
.58127 .51934 L
.58185 .51574 L
.58242 .5121 L
.58299 .50842 L
.58356 .50471 L
.58413 .50097 L
.58471 .4972 L
.58528 .4934 L
.58585 .48958 L
.58642 .48574 L
.587 .48188 L
.58757 .478 L
.58814 .47411 L
.58871 .4702 L
.58929 .46629 L
.58986 .46237 L
.59043 .45844 L
.591 .45452 L
.59158 .45059 L
.59215 .44667 L
.59272 .44275 L
.59329 .43884 L
.59386 .43494 L
.59444 .43105 L
.59501 .42718 L
.59558 .42333 L
Mistroke
.59615 .4195 L
.59673 .41569 L
.5973 .4119 L
.59787 .40815 L
.59844 .40442 L
.59902 .40073 L
.59959 .39707 L
.60016 .39345 L
.60073 .38987 L
.6013 .38633 L
.60188 .38283 L
.60245 .37939 L
.60302 .37599 L
.60359 .37265 L
.60417 .36936 L
.60474 .36612 L
.60531 .36295 L
.60588 .35984 L
.60646 .3568 L
.60703 .35382 L
.6076 .35091 L
.60817 .34807 L
.60875 .34531 L
.60932 .34263 L
.60989 .34002 L
.61046 .3375 L
.61103 .33505 L
.61161 .33269 L
.61218 .33041 L
.61275 .3282 L
.61332 .32608 L
.6139 .32402 L
.61447 .32205 L
.61504 .32015 L
.61561 .31833 L
.61619 .31658 L
.61676 .3149 L
.61733 .31329 L
.6179 .31175 L
.61848 .31029 L
.61905 .30889 L
.61962 .30756 L
.62019 .3063 L
.62076 .30511 L
.62134 .30398 L
.62191 .30291 L
.62248 .30191 L
.62305 .30098 L
.62363 .3001 L
.6242 .29929 L
Mistroke
.62477 .29854 L
.62534 .29785 L
.62592 .29722 L
.62649 .29664 L
.62706 .29613 L
.62763 .29567 L
.62821 .29526 L
.62878 .29491 L
.62935 .29461 L
.62992 .29437 L
.63049 .29418 L
.63107 .29404 L
.63164 .29395 L
.63221 .29392 L
.63278 .29393 L
.63336 .29398 L
.63393 .29409 L
.6345 .29424 L
.63507 .29444 L
.63565 .29468 L
.63622 .29497 L
.63679 .29529 L
.63736 .29567 L
.63793 .29608 L
.63851 .29653 L
.63908 .29702 L
.63965 .29755 L
.64022 .29812 L
.6408 .29873 L
.64137 .29937 L
.64194 .30005 L
.64251 .30076 L
.64309 .3015 L
.64366 .30228 L
.64423 .30309 L
.6448 .30393 L
.64538 .30481 L
.64595 .30571 L
.64652 .30664 L
.64709 .30759 L
.64766 .30858 L
.64824 .30959 L
.64881 .31062 L
.64938 .31168 L
.64995 .31277 L
.65053 .31387 L
.6511 .315 L
.65167 .31615 L
.65224 .31732 L
.65282 .31851 L
Mistroke
.65339 .31972 L
.65396 .32094 L
.65453 .32218 L
.65511 .32344 L
.65568 .32471 L
.65625 .326 L
.65682 .3273 L
.65739 .32861 L
.65797 .32993 L
.65854 .33127 L
.65911 .33261 L
.65968 .33396 L
.66026 .33533 L
.66083 .3367 L
.6614 .33807 L
.66197 .33945 L
.66255 .34084 L
.66312 .34223 L
.66369 .34362 L
.66426 .34502 L
.66484 .34642 L
.66541 .34782 L
.66598 .34921 L
.66655 .35061 L
.66712 .35201 L
.6677 .3534 L
.66827 .35479 L
.66884 .35617 L
.66941 .35755 L
.66999 .35892 L
.67056 .36029 L
.67113 .36165 L
.6717 .363 L
.67228 .36434 L
.67285 .36567 L
.67342 .36699 L
.67399 .36829 L
.67457 .36959 L
.67514 .37087 L
.67571 .37213 L
.67628 .37338 L
.67685 .37461 L
.67743 .37583 L
.678 .37703 L
.67857 .37821 L
.67914 .37937 L
.67972 .38051 L
.68029 .38163 L
.68086 .38272 L
.68143 .3838 L
Mistroke
.68201 .38485 L
.68258 .38587 L
.68315 .38687 L
.68372 .38784 L
.68429 .38879 L
.68487 .38971 L
.68544 .3906 L
.68601 .39147 L
.68658 .39232 L
.68716 .39314 L
.68773 .39393 L
.6883 .3947 L
.68887 .39545 L
.68945 .39617 L
.69002 .39687 L
.69059 .39754 L
.69116 .39819 L
.69174 .39882 L
.69231 .39943 L
.69288 .40002 L
.69345 .40058 L
.69402 .40112 L
.6946 .40164 L
.69517 .40214 L
.69574 .40261 L
.69631 .40307 L
.69689 .4035 L
.69746 .40392 L
.69803 .40431 L
.6986 .40469 L
.69918 .40505 L
.69975 .40538 L
.70032 .4057 L
.70089 .406 L
.70147 .40628 L
.70204 .40654 L
.70261 .40679 L
.70318 .40701 L
.70375 .40722 L
.70433 .40742 L
.7049 .40759 L
.70547 .40775 L
.70604 .40789 L
.70662 .40802 L
.70719 .40813 L
.70776 .40822 L
.70833 .4083 L
.70891 .40836 L
.70948 .40841 L
.71005 .40845 L
Mistroke
.71062 .40847 L
.7112 .40847 L
.71177 .40847 L
.71234 .40845 L
.71291 .40841 L
.71348 .40836 L
.71406 .4083 L
.71463 .40823 L
.7152 .40814 L
.71577 .40805 L
.71635 .40794 L
.71692 .40782 L
.71749 .40768 L
.71806 .40754 L
.71864 .40739 L
.71921 .40722 L
.71978 .40705 L
.72035 .40686 L
.72092 .40667 L
.7215 .40647 L
.72207 .40625 L
.72264 .40603 L
.72321 .4058 L
.72379 .40556 L
.72436 .40531 L
.72493 .40506 L
.7255 .4048 L
.72608 .40453 L
.72665 .40425 L
.72722 .40396 L
.72779 .40367 L
.72837 .40337 L
.72894 .40307 L
.72951 .40276 L
.73008 .40245 L
.73065 .40213 L
.73123 .4018 L
.7318 .40147 L
.73237 .40114 L
.73294 .4008 L
.73352 .40045 L
.73409 .40011 L
.73466 .39975 L
.73523 .3994 L
.73581 .39904 L
.73638 .39868 L
.73695 .39832 L
.73752 .39796 L
.7381 .39759 L
.73867 .39722 L
Mistroke
.73924 .39685 L
.73981 .39648 L
.74038 .39611 L
.74096 .39573 L
.74153 .39536 L
.7421 .39499 L
.74267 .39461 L
.74325 .39424 L
.74382 .39387 L
.74439 .3935 L
.74496 .39312 L
.74554 .39275 L
.74611 .39239 L
.74668 .39202 L
.74725 .39166 L
.74783 .39129 L
.7484 .39093 L
.74897 .39058 L
.74954 .39022 L
.75011 .38987 L
.75069 .38953 L
.75126 .38919 L
.75183 .38885 L
.7524 .38851 L
.75298 .38818 L
.75355 .38786 L
.75412 .38754 L
.75469 .38723 L
.75527 .38692 L
.75584 .38662 L
.75641 .38632 L
.75698 .38603 L
.75755 .38575 L
.75813 .38547 L
.7587 .3852 L
.75927 .38494 L
.75984 .38468 L
.76042 .38443 L
.76099 .38418 L
.76156 .38394 L
.76213 .38371 L
.76271 .38348 L
.76328 .38326 L
.76385 .38304 L
.76442 .38283 L
.765 .38262 L
.76557 .38242 L
.76614 .38223 L
.76671 .38204 L
.76728 .38186 L
Mistroke
.76786 .38168 L
.76843 .38151 L
.769 .38134 L
.76957 .38118 L
.77015 .38102 L
.77072 .38087 L
.77129 .38072 L
.77186 .38058 L
.77244 .38044 L
.77301 .38031 L
.77358 .38018 L
.77415 .38006 L
.77473 .37994 L
.7753 .37983 L
.77587 .37972 L
.77644 .37961 L
.77701 .37951 L
.77759 .37942 L
.77816 .37932 L
.77873 .37924 L
.7793 .37915 L
.77988 .37907 L
.78045 .379 L
.78102 .37893 L
.78159 .37886 L
.78217 .3788 L
.78274 .37874 L
.78331 .37868 L
.78388 .37863 L
.78446 .37858 L
.78503 .37854 L
.7856 .37849 L
.78617 .37846 L
.78674 .37842 L
.78732 .37839 L
.78789 .37836 L
.78846 .37834 L
.78903 .37832 L
.78961 .3783 L
.79018 .37828 L
.79075 .37827 L
.79132 .37826 L
.7919 .37826 L
.79247 .37825 L
.79304 .37825 L
.79361 .37826 L
.79418 .37826 L
.79476 .37827 L
.79533 .37828 L
.7959 .37829 L
Mistroke
.79647 .3783 L
.79705 .37832 L
.79762 .37834 L
.79819 .37836 L
.79876 .37839 L
.79934 .37841 L
.79991 .37844 L
.80048 .37847 L
.80105 .3785 L
.80163 .37854 L
.8022 .37857 L
.80277 .37861 L
.80334 .37865 L
.80391 .37869 L
.80449 .37873 L
.80506 .37878 L
.80563 .37882 L
.8062 .37887 L
.80678 .37892 L
.80735 .37897 L
.80792 .37902 L
.80849 .37907 L
.80907 .37913 L
.80964 .37918 L
.81021 .37924 L
.81078 .37929 L
.81136 .37935 L
.81193 .37941 L
.8125 .37947 L
.81307 .37953 L
.81364 .37959 L
.81422 .37965 L
.81479 .37971 L
.81536 .37977 L
.81593 .37984 L
.81651 .3799 L
.81708 .37996 L
.81765 .38003 L
.81822 .38009 L
.8188 .38015 L
.81937 .38022 L
.81994 .38028 L
.82051 .38035 L
.82109 .38041 L
.82166 .38047 L
.82223 .38054 L
.8228 .3806 L
.82337 .38066 L
.82395 .38073 L
.82452 .38079 L
Mistroke
.82509 .38085 L
.82566 .38091 L
.82624 .38097 L
.82681 .38103 L
.82738 .38109 L
.82795 .38115 L
.82853 .38121 L
.8291 .38126 L
.82967 .38132 L
.83024 .38137 L
.83082 .38143 L
.83139 .38148 L
.83196 .38153 L
.83253 .38158 L
.8331 .38163 L
.83368 .38168 L
.83425 .38173 L
.83482 .38178 L
.83539 .38182 L
.83597 .38187 L
.83654 .38191 L
.83711 .38195 L
.83768 .382 L
.83826 .38204 L
.83883 .38208 L
.8394 .38212 L
.83997 .38216 L
.84054 .3822 L
.84112 .38223 L
.84169 .38227 L
.84226 .3823 L
.84283 .38234 L
.84341 .38237 L
.84398 .38241 L
.84455 .38244 L
.84512 .38247 L
.8457 .3825 L
.84627 .38253 L
.84684 .38256 L
.84741 .38259 L
.84799 .38261 L
.84856 .38264 L
.84913 .38267 L
.8497 .38269 L
.85027 .38272 L
.85085 .38274 L
.85142 .38276 L
.85199 .38279 L
.85256 .38281 L
.85314 .38283 L
Mistroke
.85371 .38285 L
.85428 .38287 L
.85485 .38289 L
.85543 .38291 L
.856 .38292 L
.85657 .38294 L
.85714 .38296 L
.85772 .38297 L
.85829 .38299 L
.85886 .38301 L
.85943 .38302 L
.86 .38303 L
.86058 .38305 L
.86115 .38306 L
.86172 .38307 L
.86229 .38308 L
.86287 .38309 L
.86344 .3831 L
.86401 .38311 L
.86458 .38312 L
.86516 .38313 L
.86573 .38314 L
.8663 .38315 L
.86687 .38316 L
.86745 .38316 L
.86802 .38317 L
.86859 .38318 L
.86916 .38318 L
.86973 .38319 L
.87031 .38319 L
.87088 .3832 L
.87145 .3832 L
.87202 .3832 L
.8726 .38321 L
.87317 .38321 L
.87374 .38321 L
.87431 .38321 L
.87489 .38322 L
.87546 .38322 L
.87603 .38322 L
.8766 .38322 L
.87717 .38322 L
.87775 .38322 L
.87832 .38322 L
.87889 .38322 L
.87946 .38322 L
.88004 .38322 L
.88061 .38322 L
.88118 .38322 L
.88175 .38321 L
Mistroke
.88233 .38321 L
.8829 .38321 L
.88347 .38321 L
.88404 .3832 L
.88462 .3832 L
.88519 .3832 L
.88576 .3832 L
.88633 .38319 L
.8869 .38319 L
.88748 .38319 L
.88805 .38318 L
.88862 .38318 L
.88919 .38317 L
.88977 .38317 L
.89034 .38316 L
.89091 .38316 L
.89148 .38316 L
.89206 .38315 L
.89263 .38315 L
.8932 .38314 L
.89377 .38314 L
.89435 .38313 L
.89492 .38313 L
.89549 .38312 L
.89606 .38312 L
.89663 .38311 L
.89721 .38311 L
.89778 .3831 L
.89835 .38309 L
.89892 .38309 L
.8995 .38308 L
.90007 .38308 L
.90064 .38307 L
.90121 .38307 L
.90179 .38306 L
.90236 .38306 L
.90293 .38305 L
.9035 .38305 L
.90408 .38304 L
.90465 .38304 L
.90522 .38304 L
.90579 .38303 L
.90636 .38303 L
.90694 .38302 L
.90751 .38302 L
.90808 .38301 L
.90865 .38301 L
.90923 .38301 L
.9098 .383 L
.91037 .383 L
Mistroke
.91094 .38299 L
.91152 .38299 L
.91209 .38299 L
.91266 .38298 L
.91323 .38298 L
.9138 .38297 L
.91438 .38297 L
.91495 .38297 L
.91552 .38296 L
.91609 .38296 L
.91667 .38296 L
.91724 .38295 L
.91781 .38295 L
.91838 .38295 L
.91896 .38295 L
.91953 .38294 L
.9201 .38294 L
.92067 .38294 L
.92125 .38293 L
.92182 .38293 L
.92239 .38293 L
.92296 .38293 L
.92353 .38292 L
.92411 .38292 L
.92468 .38292 L
.92525 .38292 L
.92582 .38291 L
.9264 .38291 L
.92697 .38291 L
.92754 .38291 L
.92811 .38291 L
.92869 .3829 L
.92926 .3829 L
.92983 .3829 L
.9304 .3829 L
.93098 .3829 L
.93155 .38289 L
.93212 .38289 L
.93269 .38289 L
.93326 .38289 L
.93384 .38289 L
.93441 .38289 L
.93498 .38288 L
.93555 .38288 L
.93613 .38288 L
.9367 .38288 L
.93727 .38288 L
.93784 .38288 L
.93842 .38288 L
.93899 .38287 L
Mistroke
.93956 .38287 L
.94013 .38287 L
.94071 .38287 L
.94128 .38287 L
.94185 .38287 L
.94242 .38287 L
.94299 .38287 L
.94357 .38286 L
.94414 .38286 L
.94471 .38286 L
.94528 .38286 L
.94586 .38286 L
.94643 .38286 L
.947 .38286 L
.94757 .38286 L
.94815 .38286 L
.94872 .38286 L
.94929 .38286 L
.94986 .38286 L
.95043 .38286 L
.95101 .38286 L
.95158 .38285 L
.95215 .38285 L
.95272 .38285 L
.9533 .38285 L
.95387 .38285 L
.95444 .38285 L
.95501 .38285 L
.95559 .38285 L
.95616 .38285 L
.95673 .38285 L
.9573 .38285 L
.95788 .38285 L
.95845 .38285 L
.95902 .38285 L
.95959 .38285 L
.96016 .38285 L
.96074 .38285 L
.96131 .38285 L
.96188 .38285 L
.96245 .38285 L
.96303 .38285 L
.9636 .38285 L
.96417 .38285 L
.96474 .38285 L
.96532 .38285 L
.96589 .38285 L
.96646 .38285 L
.96703 .38285 L
.96761 .38285 L
Mistroke
.96818 .38285 L
.96875 .38285 L
.96932 .38285 L
.96989 .38285 L
.97047 .38285 L
.97104 .38285 L
.97161 .38285 L
.97218 .38285 L
.97276 .38285 L
.97333 .38285 L
.9739 .38285 L
.97447 .38285 L
.97505 .38285 L
.97562 .38285 L
.97619 .38285 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{211, Automatic}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 68, 1, 58, "Section",
      CellTags->"Contents"],
    Cell[1780, 52, 642, 22, 99, "Contents",
      CellTags->"Contents"]},
  "S1.6.0"->{
    Cell[2425, 76, 75, 1, 58, "Section",
      CellTags->{"S1.6.0", "0.1"}],
    Cell[2503, 79, 1165, 18, 208, "Text",
      CellTags->{"S1.6.0", "0.2"}]},
  "0.1"->{
    Cell[2425, 76, 75, 1, 58, "Section",
      CellTags->{"S1.6.0", "0.1"}]},
  "0.2"->{
    Cell[2503, 79, 1165, 18, 208, "Text",
      CellTags->{"S1.6.0", "0.2"}]},
  "S1.6.1"->{
    Cell[3671, 99, 69, 1, 41, "Subsection",
      CellTags->{"S1.6.1", "1.1"}],
    Cell[3743, 102, 2419, 66, 185, "Text",
      CellTags->{"S1.6.1", "1.2"}],
    Cell[6165, 170, 141, 3, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.3"}],
    Cell[6309, 175, 356, 9, 70, "Text",
      CellTags->{"S1.6.1", "1.4"}],
    Cell[6668, 186, 330, 6, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.5"}],
    Cell[7001, 194, 562, 13, 70, "Text",
      CellTags->{"S1.6.1", "1.6"}],
    Cell[7566, 209, 452, 11, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.7"}],
    Cell[8021, 222, 522, 15, 70, "Text",
      CellTags->{"S1.6.1", "1.8"}],
    Cell[8546, 239, 465, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.9"}],
    Cell[9014, 251, 359, 9, 70, "Text",
      CellTags->{"S1.6.1", "1.10"}],
    Cell[9376, 262, 338, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.11"}],
    Cell[9717, 271, 349, 11, 70, "Text",
      CellTags->{"S1.6.1", "1.12"}]},
  "1.1"->{
    Cell[3671, 99, 69, 1, 41, "Subsection",
      CellTags->{"S1.6.1", "1.1"}]},
  "1.2"->{
    Cell[3743, 102, 2419, 66, 185, "Text",
      CellTags->{"S1.6.1", "1.2"}]},
  "1.3"->{
    Cell[6165, 170, 141, 3, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.3"}]},
  "1.4"->{
    Cell[6309, 175, 356, 9, 70, "Text",
      CellTags->{"S1.6.1", "1.4"}]},
  "1.5"->{
    Cell[6668, 186, 330, 6, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.5"}]},
  "1.6"->{
    Cell[7001, 194, 562, 13, 70, "Text",
      CellTags->{"S1.6.1", "1.6"}]},
  "1.7"->{
    Cell[7566, 209, 452, 11, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.7"}]},
  "1.8"->{
    Cell[8021, 222, 522, 15, 70, "Text",
      CellTags->{"S1.6.1", "1.8"}]},
  "1.9"->{
    Cell[8546, 239, 465, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.9"}]},
  "1.10"->{
    Cell[9014, 251, 359, 9, 70, "Text",
      CellTags->{"S1.6.1", "1.10"}]},
  "1.11"->{
    Cell[9376, 262, 338, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.1", "1.11"}]},
  "1.12"->{
    Cell[9717, 271, 349, 11, 70, "Text",
      CellTags->{"S1.6.1", "1.12"}]},
  "S1.6.2"->{
    Cell[10069, 284, 80, 1, 70, "Subsection",
      CellTags->{"S1.6.2", "2.1"}],
    Cell[10152, 287, 2128, 59, 70, "Text",
      CellTags->{"S1.6.2", "2.2"}],
    Cell[12283, 348, 505, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.3"}],
    Cell[12791, 360, 51, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.4"}],
    Cell[12845, 363, 424, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.5"}],
    Cell[13272, 373, 1119, 33, 70, "Text",
      CellTags->{"S1.6.2", "2.6"}],
    Cell[14394, 408, 276, 5, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.7"}],
    Cell[14673, 415, 196, 5, 70, "Text",
      CellTags->{"S1.6.2", "2.8"}],
    Cell[14872, 422, 548, 11, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.9"}],
    Cell[15423, 435, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.10"}],
    Cell[15478, 438, 594, 12, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.11"}],
    Cell[16075, 452, 194, 5, 70, "Text",
      CellTags->{"S1.6.2", "2.12"}],
    Cell[16272, 459, 763, 15, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.13"}],
    Cell[17038, 476, 756, 24, 70, "Text",
      CellTags->{"S1.6.2", "2.14"}],
    Cell[17797, 502, 760, 14, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.15"}],
    Cell[18560, 518, 352, 11, 70, "Text",
      CellTags->{"S1.6.2", "2.16"}],
    Cell[18915, 531, 395, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.17"}],
    Cell[19313, 540, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.18"}],
    Cell[19368, 543, 445, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.19"}],
    Cell[19816, 553, 1296, 39, 70, "Text",
      CellTags->{"S1.6.2", "2.20"}],
    Cell[21115, 594, 654, 13, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.21"}],
    Cell[21772, 609, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.22"}],
    Cell[21827, 612, 648, 13, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.23"}],
    Cell[22478, 627, 442, 12, 70, "Text",
      CellTags->{"S1.6.2", "2.24"}],
    Cell[22923, 641, 482, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.25"}],
    Cell[23408, 652, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.26"}],
    Cell[23463, 655, 481, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.27"}],
    Cell[23947, 666, 218, 7, 70, "Text",
      CellTags->{"S1.6.2", "2.28"}],
    Cell[24168, 675, 404, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.29"}],
    Cell[24575, 685, 51, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.30"}],
    Cell[24629, 688, 318, 6, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.31"}],
    Cell[24950, 696, 3440, 95, 70, "Text",
      CellTags->{"S1.6.2", "2.32"}],
    Cell[28393, 793, 526, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.33"}],
    Cell[28922, 805, 1862, 53, 70, "Text",
      CellTags->{"S1.6.2", "2.34"}]},
  "2.1"->{
    Cell[10069, 284, 80, 1, 70, "Subsection",
      CellTags->{"S1.6.2", "2.1"}]},
  "2.2"->{
    Cell[10152, 287, 2128, 59, 70, "Text",
      CellTags->{"S1.6.2", "2.2"}]},
  "2.3"->{
    Cell[12283, 348, 505, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.3"}]},
  "2.4"->{
    Cell[12791, 360, 51, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.4"}]},
  "2.5"->{
    Cell[12845, 363, 424, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.5"}]},
  "2.6"->{
    Cell[13272, 373, 1119, 33, 70, "Text",
      CellTags->{"S1.6.2", "2.6"}]},
  "2.7"->{
    Cell[14394, 408, 276, 5, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.7"}]},
  "2.8"->{
    Cell[14673, 415, 196, 5, 70, "Text",
      CellTags->{"S1.6.2", "2.8"}]},
  "2.9"->{
    Cell[14872, 422, 548, 11, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.9"}]},
  "2.10"->{
    Cell[15423, 435, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.10"}]},
  "2.11"->{
    Cell[15478, 438, 594, 12, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.11"}]},
  "2.12"->{
    Cell[16075, 452, 194, 5, 70, "Text",
      CellTags->{"S1.6.2", "2.12"}]},
  "2.13"->{
    Cell[16272, 459, 763, 15, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.13"}]},
  "2.14"->{
    Cell[17038, 476, 756, 24, 70, "Text",
      CellTags->{"S1.6.2", "2.14"}]},
  "2.15"->{
    Cell[17797, 502, 760, 14, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.15"}]},
  "2.16"->{
    Cell[18560, 518, 352, 11, 70, "Text",
      CellTags->{"S1.6.2", "2.16"}]},
  "2.17"->{
    Cell[18915, 531, 395, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.17"}]},
  "2.18"->{
    Cell[19313, 540, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.18"}]},
  "2.19"->{
    Cell[19368, 543, 445, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.19"}]},
  "2.20"->{
    Cell[19816, 553, 1296, 39, 70, "Text",
      CellTags->{"S1.6.2", "2.20"}]},
  "2.21"->{
    Cell[21115, 594, 654, 13, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.21"}]},
  "2.22"->{
    Cell[21772, 609, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.22"}]},
  "2.23"->{
    Cell[21827, 612, 648, 13, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.23"}]},
  "2.24"->{
    Cell[22478, 627, 442, 12, 70, "Text",
      CellTags->{"S1.6.2", "2.24"}]},
  "2.25"->{
    Cell[22923, 641, 482, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.25"}]},
  "2.26"->{
    Cell[23408, 652, 52, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.26"}]},
  "2.27"->{
    Cell[23463, 655, 481, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.27"}]},
  "2.28"->{
    Cell[23947, 666, 218, 7, 70, "Text",
      CellTags->{"S1.6.2", "2.28"}]},
  "2.29"->{
    Cell[24168, 675, 404, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.29"}]},
  "2.30"->{
    Cell[24575, 685, 51, 1, 70, "Text",
      CellTags->{"S1.6.2", "2.30"}]},
  "2.31"->{
    Cell[24629, 688, 318, 6, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.31"}]},
  "2.32"->{
    Cell[24950, 696, 3440, 95, 70, "Text",
      CellTags->{"S1.6.2", "2.32"}]},
  "2.33"->{
    Cell[28393, 793, 526, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.2", "2.33"}]},
  "2.34"->{
    Cell[28922, 805, 1862, 53, 70, "Text",
      CellTags->{"S1.6.2", "2.34"}]},
  "S1.6.3"->{
    Cell[30787, 860, 87, 1, 70, "Subsection",
      CellTags->{"S1.6.3", "3.1"}],
    Cell[30877, 863, 559, 16, 70, "Text",
      CellTags->{"S1.6.3", "3.2"}],
    Cell[31439, 881, 851, 22, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.3"}],
    Cell[32293, 905, 725, 23, 70, "Text",
      CellTags->{"S1.6.3", "3.4"}],
    Cell[33021, 930, 483, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.5"}],
    Cell[33507, 941, 1254, 43, 70, "Text",
      CellTags->{"S1.6.3", "3.6"}],
    Cell[34764, 986, 608, 16, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.7"}],
    Cell[35375, 1004, 333, 12, 70, "Text",
      CellTags->{"S1.6.3", "3.8"}],
    Cell[35711, 1018, 643, 18, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.9"}],
    Cell[36357, 1038, 1469, 44, 70, "Text",
      CellTags->{"S1.6.3", "3.10"}],
    Cell[37829, 1084, 237, 10, 70, "Text",
      CellTags->{"S1.6.3", "3.11"}],
    Cell[38069, 1096, 441, 14, 70, "Text",
      CellTags->{"S1.6.3", "3.12"}],
    Cell[38513, 1112, 404, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.13"}],
    Cell[38920, 1122, 78, 1, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.14"}],
    Cell[39001, 1125, 93, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[39097, 1129, 220, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.15"}],
    Cell[39342, 1140, 100, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[39445, 1144, 230, 5, 70, "Output",
      CellTags->"S1.6.3"],
    Cell[39690, 1152, 436, 13, 70, "Text",
      CellTags->{"S1.6.3", "3.16"}],
    Cell[40129, 1167, 259, 6, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.17"}],
    Cell[40413, 1177, 92, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[40508, 1181, 328, 7, 70, "Output",
      CellTags->"S1.6.3"],
    Cell[40851, 1191, 221, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.18"}],
    Cell[41075, 1200, 94, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[41172, 1204, 205, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.19"}],
    Cell[41402, 1215, 158, 5, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[41563, 1222, 5947, 405, 70, 5874, 402, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.3"],
    Cell[47525, 1630, 228, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.20"}],
    Cell[47778, 1641, 99, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[47880, 1645, 85, 3, 70, "Output",
      CellTags->"S1.6.3"],
    Cell[47980, 1651, 1908, 63, 70, "Text",
      CellTags->{"S1.6.3", "3.21"}],
    Cell[49891, 1716, 217, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.22"}],
    Cell[50111, 1725, 109, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[50223, 1729, 136, 4, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.23"}],
    Cell[50384, 1737, 172, 5, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[50559, 1744, 14975, 982, 70, 14902, 979, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.3"],
    Cell[65549, 2729, 590, 19, 70, "Text",
      CellTags->{"S1.6.3", "3.24"}],
    Cell[66142, 2750, 139, 4, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.25"}],
    Cell[66284, 2756, 108, 2, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[66395, 2760, 231, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.26"}],
    Cell[66651, 2771, 168, 5, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[66822, 2778, 5131, 339, 70, 5058, 336, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.3"],
    Cell[71968, 3120, 212, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.27"}],
    Cell[72205, 3131, 184, 6, 70, "Input",
      CellTags->"S1.6.3"],
    Cell[72392, 3139, 9440, 630, 70, 9367, 627, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.3"]},
  "3.1"->{
    Cell[30787, 860, 87, 1, 70, "Subsection",
      CellTags->{"S1.6.3", "3.1"}]},
  "3.2"->{
    Cell[30877, 863, 559, 16, 70, "Text",
      CellTags->{"S1.6.3", "3.2"}]},
  "3.3"->{
    Cell[31439, 881, 851, 22, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.3"}]},
  "3.4"->{
    Cell[32293, 905, 725, 23, 70, "Text",
      CellTags->{"S1.6.3", "3.4"}]},
  "3.5"->{
    Cell[33021, 930, 483, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.5"}]},
  "3.6"->{
    Cell[33507, 941, 1254, 43, 70, "Text",
      CellTags->{"S1.6.3", "3.6"}]},
  "3.7"->{
    Cell[34764, 986, 608, 16, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.7"}]},
  "3.8"->{
    Cell[35375, 1004, 333, 12, 70, "Text",
      CellTags->{"S1.6.3", "3.8"}]},
  "3.9"->{
    Cell[35711, 1018, 643, 18, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.9"}]},
  "3.10"->{
    Cell[36357, 1038, 1469, 44, 70, "Text",
      CellTags->{"S1.6.3", "3.10"}]},
  "3.11"->{
    Cell[37829, 1084, 237, 10, 70, "Text",
      CellTags->{"S1.6.3", "3.11"}]},
  "3.12"->{
    Cell[38069, 1096, 441, 14, 70, "Text",
      CellTags->{"S1.6.3", "3.12"}]},
  "3.13"->{
    Cell[38513, 1112, 404, 8, 70, "DisplayFormula",
      CellTags->{"S1.6.3", "3.13"}]},
  "3.14"->{
    Cell[38920, 1122, 78, 1, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.14"}]},
  "3.15"->{
    Cell[39097, 1129, 220, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.15"}]},
  "3.16"->{
    Cell[39690, 1152, 436, 13, 70, "Text",
      CellTags->{"S1.6.3", "3.16"}]},
  "3.17"->{
    Cell[40129, 1167, 259, 6, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.17"}]},
  "3.18"->{
    Cell[40851, 1191, 221, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.18"}]},
  "3.19"->{
    Cell[41172, 1204, 205, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.19"}]},
  "3.20"->{
    Cell[47525, 1630, 228, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.20"}]},
  "3.21"->{
    Cell[47980, 1651, 1908, 63, 70, "Text",
      CellTags->{"S1.6.3", "3.21"}]},
  "3.22"->{
    Cell[49891, 1716, 217, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.22"}]},
  "3.23"->{
    Cell[50223, 1729, 136, 4, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.23"}]},
  "3.24"->{
    Cell[65549, 2729, 590, 19, 70, "Text",
      CellTags->{"S1.6.3", "3.24"}]},
  "3.25"->{
    Cell[66142, 2750, 139, 4, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.25"}]},
  "3.26"->{
    Cell[66395, 2760, 231, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.26"}]},
  "3.27"->{
    Cell[71968, 3120, 212, 7, 70, "MathCaption",
      CellTags->{"S1.6.3", "3.27"}]},
  "S1.6.4"->{
    Cell[81847, 3772, 90, 1, 70, "Subsection",
      CellTags->{"S1.6.4", "4.1"}],
    Cell[81940, 3775, 744, 19, 70, "Text",
      CellTags->{"S1.6.4", "4.2"}],
    Cell[82687, 3796, 445, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.3"}],
    Cell[83135, 3807, 336, 12, 70, "Text",
      CellTags->{"S1.6.4", "4.4"}],
    Cell[83474, 3821, 496, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.5"}],
    Cell[83973, 3833, 742, 21, 70, "Text",
      CellTags->{"S1.6.4", "4.6"}],
    Cell[84718, 3856, 428, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.7"}],
    Cell[85149, 3867, 98, 1, 70, "Text",
      CellTags->{"S1.6.4", "4.8"}],
    Cell[85250, 3870, 943, 18, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.9"}],
    Cell[86196, 3890, 60, 1, 70, "Text",
      CellTags->{"S1.6.4", "4.10"}],
    Cell[86259, 3893, 944, 19, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.11"}],
    Cell[87206, 3914, 1123, 36, 70, "Text",
      CellTags->{"S1.6.4", "4.12"}],
    Cell[88332, 3952, 352, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.13"}],
    Cell[88687, 3961, 715, 21, 70, "Text",
      CellTags->{"S1.6.4", "4.14"}],
    Cell[89405, 3984, 224, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.15"}],
    Cell[89632, 3993, 101, 2, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[89736, 3997, 101, 1, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.16"}],
    Cell[89840, 4000, 122, 5, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[89965, 4007, 419, 14, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.17"}],
    Cell[90387, 4023, 103, 2, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[90493, 4027, 139, 4, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.18"}],
    Cell[90657, 4035, 106, 2, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[90766, 4039, 102, 3, 70, "Output",
      CellTags->"S1.6.4"],
    Cell[90883, 4045, 116, 2, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.19"}],
    Cell[91024, 4051, 113, 2, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[91140, 4055, 209, 4, 70, "Output",
      CellTags->"S1.6.4"],
    Cell[91364, 4062, 518, 14, 70, "Text",
      CellTags->{"S1.6.4", "4.20"}],
    Cell[91885, 4078, 316, 8, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.21"}],
    Cell[92226, 4090, 205, 7, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[92434, 4099, 47849, 3081, 70, 47776, 3078, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.4"],
    Cell[140298, 7183, 206, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.22"}],
    Cell[140529, 7194, 197, 6, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[140729, 7202, 30490, 1972, 70, 30417, 1969, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.4"],
    Cell[171234, 9177, 358, 11, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.23"}],
    Cell[171617, 9192, 221, 7, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[171841, 9201, 11528, 773, 70, 11455, 770, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.4"],
    Cell[183384, 9977, 212, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.24"}],
    Cell[183621, 9988, 211, 7, 70, "Input",
      CellTags->"S1.6.4"],
    Cell[183835, 9997, 30451, 1972, 70, 30378, 1969, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.6.4"]},
  "4.1"->{
    Cell[81847, 3772, 90, 1, 70, "Subsection",
      CellTags->{"S1.6.4", "4.1"}]},
  "4.2"->{
    Cell[81940, 3775, 744, 19, 70, "Text",
      CellTags->{"S1.6.4", "4.2"}]},
  "4.3"->{
    Cell[82687, 3796, 445, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.3"}]},
  "4.4"->{
    Cell[83135, 3807, 336, 12, 70, "Text",
      CellTags->{"S1.6.4", "4.4"}]},
  "4.5"->{
    Cell[83474, 3821, 496, 10, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.5"}]},
  "4.6"->{
    Cell[83973, 3833, 742, 21, 70, "Text",
      CellTags->{"S1.6.4", "4.6"}]},
  "4.7"->{
    Cell[84718, 3856, 428, 9, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.7"}]},
  "4.8"->{
    Cell[85149, 3867, 98, 1, 70, "Text",
      CellTags->{"S1.6.4", "4.8"}]},
  "4.9"->{
    Cell[85250, 3870, 943, 18, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.9"}]},
  "4.10"->{
    Cell[86196, 3890, 60, 1, 70, "Text",
      CellTags->{"S1.6.4", "4.10"}]},
  "4.11"->{
    Cell[86259, 3893, 944, 19, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.11"}]},
  "4.12"->{
    Cell[87206, 3914, 1123, 36, 70, "Text",
      CellTags->{"S1.6.4", "4.12"}]},
  "4.13"->{
    Cell[88332, 3952, 352, 7, 70, "DisplayFormula",
      CellTags->{"S1.6.4", "4.13"}]},
  "4.14"->{
    Cell[88687, 3961, 715, 21, 70, "Text",
      CellTags->{"S1.6.4", "4.14"}]},
  "4.15"->{
    Cell[89405, 3984, 224, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.15"}]},
  "4.16"->{
    Cell[89736, 3997, 101, 1, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.16"}]},
  "4.17"->{
    Cell[89965, 4007, 419, 14, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.17"}]},
  "4.18"->{
    Cell[90493, 4027, 139, 4, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.18"}]},
  "4.19"->{
    Cell[90883, 4045, 116, 2, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.19"}]},
  "4.20"->{
    Cell[91364, 4062, 518, 14, 70, "Text",
      CellTags->{"S1.6.4", "4.20"}]},
  "4.21"->{
    Cell[91885, 4078, 316, 8, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.21"}]},
  "4.22"->{
    Cell[140298, 7183, 206, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.22"}]},
  "4.23"->{
    Cell[171234, 9177, 358, 11, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.23"}]},
  "4.24"->{
    Cell[183384, 9977, 212, 7, 70, "MathCaption",
      CellTags->{"S1.6.4", "4.24"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 214940, 11990},
  {"S1.6.0", 215098, 11995},
  {"0.1", 215265, 12000},
  {"0.2", 215354, 12003},
  {"S1.6.1", 215447, 12006},
  {"1.1", 216436, 12031},
  {"1.2", 216528, 12034},
  {"1.3", 216619, 12037},
  {"1.4", 216717, 12040},
  {"1.5", 216805, 12043},
  {"1.6", 216903, 12046},
  {"1.7", 216992, 12049},
  {"1.8", 217091, 12052},
  {"1.9", 217180, 12055},
  {"1.10", 217280, 12058},
  {"1.11", 217370, 12061},
  {"1.12", 217470, 12064},
  {"S1.6.2", 217563, 12067},
  {"2.1", 220398, 12136},
  {"2.2", 220492, 12139},
  {"2.3", 220583, 12142},
  {"2.4", 220683, 12145},
  {"2.5", 220771, 12148},
  {"2.6", 220870, 12151},
  {"2.7", 220961, 12154},
  {"2.8", 221060, 12157},
  {"2.9", 221149, 12160},
  {"2.10", 221250, 12163},
  {"2.11", 221340, 12166},
  {"2.12", 221442, 12169},
  {"2.13", 221533, 12172},
  {"2.14", 221635, 12175},
  {"2.15", 221727, 12178},
  {"2.16", 221829, 12181},
  {"2.17", 221921, 12184},
  {"2.18", 222022, 12187},
  {"2.19", 222112, 12190},
  {"2.20", 222213, 12193},
  {"2.21", 222306, 12196},
  {"2.22", 222408, 12199},
  {"2.23", 222498, 12202},
  {"2.24", 222600, 12205},
  {"2.25", 222692, 12208},
  {"2.26", 222793, 12211},
  {"2.27", 222883, 12214},
  {"2.28", 222984, 12217},
  {"2.29", 223075, 12220},
  {"2.30", 223176, 12223},
  {"2.31", 223266, 12226},
  {"2.32", 223367, 12229},
  {"2.33", 223460, 12232},
  {"2.34", 223562, 12235},
  {"S1.6.3", 223657, 12238},
  {"3.1", 227521, 12337},
  {"3.2", 227615, 12340},
  {"3.3", 227705, 12343},
  {"3.4", 227805, 12346},
  {"3.5", 227895, 12349},
  {"3.6", 227994, 12352},
  {"3.7", 228085, 12355},
  {"3.8", 228185, 12358},
  {"3.9", 228276, 12361},
  {"3.10", 228378, 12364},
  {"3.11", 228472, 12367},
  {"3.12", 228565, 12370},
  {"3.13", 228658, 12373},
  {"3.14", 228760, 12376},
  {"3.15", 228858, 12379},
  {"3.16", 228957, 12382},
  {"3.17", 229050, 12385},
  {"3.18", 229149, 12388},
  {"3.19", 229248, 12391},
  {"3.20", 229347, 12394},
  {"3.21", 229446, 12397},
  {"3.22", 229540, 12400},
  {"3.23", 229639, 12403},
  {"3.24", 229738, 12406},
  {"3.25", 229831, 12409},
  {"3.26", 229930, 12412},
  {"3.27", 230029, 12415},
  {"S1.6.4", 230130, 12418},
  {"4.1", 233570, 12505},
  {"4.2", 233665, 12508},
  {"4.3", 233756, 12511},
  {"4.4", 233856, 12514},
  {"4.5", 233947, 12517},
  {"4.6", 234048, 12520},
  {"4.7", 234139, 12523},
  {"4.8", 234239, 12526},
  {"4.9", 234328, 12529},
  {"4.10", 234430, 12532},
  {"4.11", 234521, 12535},
  {"4.12", 234624, 12538},
  {"4.13", 234718, 12541},
  {"4.14", 234820, 12544},
  {"4.15", 234913, 12547},
  {"4.16", 235012, 12550},
  {"4.17", 235111, 12553},
  {"4.18", 235211, 12556},
  {"4.19", 235310, 12559},
  {"4.20", 235409, 12562},
  {"4.21", 235502, 12565},
  {"4.22", 235601, 12568},
  {"4.23", 235701, 12571},
  {"4.24", 235802, 12574}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 68, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1780, 52, 642, 22, 99, "Contents",
  CellTags->"Contents"],
Cell[2425, 76, 75, 1, 58, "Section",
  CellTags->{"S1.6.0", "0.1"}],
Cell[2503, 79, 1165, 18, 208, "Text",
  CellTags->{"S1.6.0", "0.2"}],
Cell[3671, 99, 69, 1, 41, "Subsection",
  CellTags->{"S1.6.1", "1.1"}],
Cell[3743, 102, 2419, 66, 185, "Text",
  CellTags->{"S1.6.1", "1.2"}],
Cell[6165, 170, 141, 3, 70, "DisplayFormula",
  CellTags->{"S1.6.1", "1.3"}],
Cell[6309, 175, 356, 9, 70, "Text",
  CellTags->{"S1.6.1", "1.4"}],
Cell[6668, 186, 330, 6, 70, "DisplayFormula",
  CellTags->{"S1.6.1", "1.5"}],
Cell[7001, 194, 562, 13, 70, "Text",
  CellTags->{"S1.6.1", "1.6"}],
Cell[7566, 209, 452, 11, 70, "DisplayFormula",
  CellTags->{"S1.6.1", "1.7"}],
Cell[8021, 222, 522, 15, 70, "Text",
  CellTags->{"S1.6.1", "1.8"}],
Cell[8546, 239, 465, 10, 70, "DisplayFormula",
  CellTags->{"S1.6.1", "1.9"}],
Cell[9014, 251, 359, 9, 70, "Text",
  CellTags->{"S1.6.1", "1.10"}],
Cell[9376, 262, 338, 7, 70, "DisplayFormula",
  CellTags->{"S1.6.1", "1.11"}],
Cell[9717, 271, 349, 11, 70, "Text",
  CellTags->{"S1.6.1", "1.12"}],
Cell[10069, 284, 80, 1, 70, "Subsection",
  CellTags->{"S1.6.2", "2.1"}],
Cell[10152, 287, 2128, 59, 70, "Text",
  CellTags->{"S1.6.2", "2.2"}],
Cell[12283, 348, 505, 10, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.3"}],
Cell[12791, 360, 51, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.4"}],
Cell[12845, 363, 424, 8, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.5"}],
Cell[13272, 373, 1119, 33, 70, "Text",
  CellTags->{"S1.6.2", "2.6"}],
Cell[14394, 408, 276, 5, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.7"}],
Cell[14673, 415, 196, 5, 70, "Text",
  CellTags->{"S1.6.2", "2.8"}],
Cell[14872, 422, 548, 11, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.9"}],
Cell[15423, 435, 52, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.10"}],
Cell[15478, 438, 594, 12, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.11"}],
Cell[16075, 452, 194, 5, 70, "Text",
  CellTags->{"S1.6.2", "2.12"}],
Cell[16272, 459, 763, 15, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.13"}],
Cell[17038, 476, 756, 24, 70, "Text",
  CellTags->{"S1.6.2", "2.14"}],
Cell[17797, 502, 760, 14, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.15"}],
Cell[18560, 518, 352, 11, 70, "Text",
  CellTags->{"S1.6.2", "2.16"}],
Cell[18915, 531, 395, 7, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.17"}],
Cell[19313, 540, 52, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.18"}],
Cell[19368, 543, 445, 8, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.19"}],
Cell[19816, 553, 1296, 39, 70, "Text",
  CellTags->{"S1.6.2", "2.20"}],
Cell[21115, 594, 654, 13, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.21"}],
Cell[21772, 609, 52, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.22"}],
Cell[21827, 612, 648, 13, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.23"}],
Cell[22478, 627, 442, 12, 70, "Text",
  CellTags->{"S1.6.2", "2.24"}],
Cell[22923, 641, 482, 9, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.25"}],
Cell[23408, 652, 52, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.26"}],
Cell[23463, 655, 481, 9, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.27"}],
Cell[23947, 666, 218, 7, 70, "Text",
  CellTags->{"S1.6.2", "2.28"}],
Cell[24168, 675, 404, 8, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.29"}],
Cell[24575, 685, 51, 1, 70, "Text",
  CellTags->{"S1.6.2", "2.30"}],
Cell[24629, 688, 318, 6, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.31"}],
Cell[24950, 696, 3440, 95, 70, "Text",
  CellTags->{"S1.6.2", "2.32"}],
Cell[28393, 793, 526, 10, 70, "DisplayFormula",
  CellTags->{"S1.6.2", "2.33"}],
Cell[28922, 805, 1862, 53, 70, "Text",
  CellTags->{"S1.6.2", "2.34"}],
Cell[30787, 860, 87, 1, 70, "Subsection",
  CellTags->{"S1.6.3", "3.1"}],
Cell[30877, 863, 559, 16, 70, "Text",
  CellTags->{"S1.6.3", "3.2"}],
Cell[31439, 881, 851, 22, 70, "DisplayFormula",
  CellTags->{"S1.6.3", "3.3"}],
Cell[32293, 905, 725, 23, 70, "Text",
  CellTags->{"S1.6.3", "3.4"}],
Cell[33021, 930, 483, 9, 70, "DisplayFormula",
  CellTags->{"S1.6.3", "3.5"}],
Cell[33507, 941, 1254, 43, 70, "Text",
  CellTags->{"S1.6.3", "3.6"}],
Cell[34764, 986, 608, 16, 70, "DisplayFormula",
  CellTags->{"S1.6.3", "3.7"}],
Cell[35375, 1004, 333, 12, 70, "Text",
  CellTags->{"S1.6.3", "3.8"}],
Cell[35711, 1018, 643, 18, 70, "DisplayFormula",
  CellTags->{"S1.6.3", "3.9"}],
Cell[36357, 1038, 1469, 44, 70, "Text",
  CellTags->{"S1.6.3", "3.10"}],
Cell[37829, 1084, 237, 10, 70, "Text",
  CellTags->{"S1.6.3", "3.11"}],
Cell[38069, 1096, 441, 14, 70, "Text",
  CellTags->{"S1.6.3", "3.12"}],
Cell[38513, 1112, 404, 8, 70, "DisplayFormula",
  CellTags->{"S1.6.3", "3.13"}],
Cell[38920, 1122, 78, 1, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.14"}],
Cell[39001, 1125, 93, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[39097, 1129, 220, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.15"}],

Cell[CellGroupData[{
Cell[39342, 1140, 100, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[39445, 1144, 230, 5, 70, "Output",
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[39690, 1152, 436, 13, 70, "Text",
  CellTags->{"S1.6.3", "3.16"}],
Cell[40129, 1167, 259, 6, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.17"}],

Cell[CellGroupData[{
Cell[40413, 1177, 92, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[40508, 1181, 328, 7, 70, "Output",
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[40851, 1191, 221, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.18"}],
Cell[41075, 1200, 94, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[41172, 1204, 205, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.19"}],

Cell[CellGroupData[{
Cell[41402, 1215, 158, 5, 70, "Input",
  CellTags->"S1.6.3"],
Cell[41563, 1222, 5947, 405, 70, 5874, 402, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[47525, 1630, 228, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.20"}],

Cell[CellGroupData[{
Cell[47778, 1641, 99, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[47880, 1645, 85, 3, 70, "Output",
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[47980, 1651, 1908, 63, 70, "Text",
  CellTags->{"S1.6.3", "3.21"}],
Cell[49891, 1716, 217, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.22"}],
Cell[50111, 1725, 109, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[50223, 1729, 136, 4, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.23"}],

Cell[CellGroupData[{
Cell[50384, 1737, 172, 5, 70, "Input",
  CellTags->"S1.6.3"],
Cell[50559, 1744, 14975, 982, 70, 14902, 979, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[65549, 2729, 590, 19, 70, "Text",
  CellTags->{"S1.6.3", "3.24"}],
Cell[66142, 2750, 139, 4, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.25"}],
Cell[66284, 2756, 108, 2, 70, "Input",
  CellTags->"S1.6.3"],
Cell[66395, 2760, 231, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.26"}],

Cell[CellGroupData[{
Cell[66651, 2771, 168, 5, 70, "Input",
  CellTags->"S1.6.3"],
Cell[66822, 2778, 5131, 339, 70, 5058, 336, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[71968, 3120, 212, 7, 70, "MathCaption",
  CellTags->{"S1.6.3", "3.27"}],

Cell[CellGroupData[{
Cell[72205, 3131, 184, 6, 70, "Input",
  CellTags->"S1.6.3"],
Cell[72392, 3139, 9440, 630, 70, 9367, 627, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.3"]
}, Open  ]],
Cell[81847, 3772, 90, 1, 70, "Subsection",
  CellTags->{"S1.6.4", "4.1"}],
Cell[81940, 3775, 744, 19, 70, "Text",
  CellTags->{"S1.6.4", "4.2"}],
Cell[82687, 3796, 445, 9, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.3"}],
Cell[83135, 3807, 336, 12, 70, "Text",
  CellTags->{"S1.6.4", "4.4"}],
Cell[83474, 3821, 496, 10, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.5"}],
Cell[83973, 3833, 742, 21, 70, "Text",
  CellTags->{"S1.6.4", "4.6"}],
Cell[84718, 3856, 428, 9, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.7"}],
Cell[85149, 3867, 98, 1, 70, "Text",
  CellTags->{"S1.6.4", "4.8"}],
Cell[85250, 3870, 943, 18, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.9"}],
Cell[86196, 3890, 60, 1, 70, "Text",
  CellTags->{"S1.6.4", "4.10"}],
Cell[86259, 3893, 944, 19, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.11"}],
Cell[87206, 3914, 1123, 36, 70, "Text",
  CellTags->{"S1.6.4", "4.12"}],
Cell[88332, 3952, 352, 7, 70, "DisplayFormula",
  CellTags->{"S1.6.4", "4.13"}],
Cell[88687, 3961, 715, 21, 70, "Text",
  CellTags->{"S1.6.4", "4.14"}],
Cell[89405, 3984, 224, 7, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.15"}],
Cell[89632, 3993, 101, 2, 70, "Input",
  CellTags->"S1.6.4"],
Cell[89736, 3997, 101, 1, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.16"}],
Cell[89840, 4000, 122, 5, 70, "Input",
  CellTags->"S1.6.4"],
Cell[89965, 4007, 419, 14, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.17"}],
Cell[90387, 4023, 103, 2, 70, "Input",
  CellTags->"S1.6.4"],
Cell[90493, 4027, 139, 4, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.18"}],

Cell[CellGroupData[{
Cell[90657, 4035, 106, 2, 70, "Input",
  CellTags->"S1.6.4"],
Cell[90766, 4039, 102, 3, 70, "Output",
  CellTags->"S1.6.4"]
}, Open  ]],
Cell[90883, 4045, 116, 2, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.19"}],

Cell[CellGroupData[{
Cell[91024, 4051, 113, 2, 70, "Input",
  CellTags->"S1.6.4"],
Cell[91140, 4055, 209, 4, 70, "Output",
  CellTags->"S1.6.4"]
}, Open  ]],
Cell[91364, 4062, 518, 14, 70, "Text",
  CellTags->{"S1.6.4", "4.20"}],
Cell[91885, 4078, 316, 8, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.21"}],

Cell[CellGroupData[{
Cell[92226, 4090, 205, 7, 70, "Input",
  CellTags->"S1.6.4"],
Cell[92434, 4099, 47849, 3081, 70, 47776, 3078, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],
Cell[140298, 7183, 206, 7, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.22"}],

Cell[CellGroupData[{
Cell[140529, 7194, 197, 6, 70, "Input",
  CellTags->"S1.6.4"],
Cell[140729, 7202, 30490, 1972, 70, 30417, 1969, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],
Cell[171234, 9177, 358, 11, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.23"}],

Cell[CellGroupData[{
Cell[171617, 9192, 221, 7, 70, "Input",
  CellTags->"S1.6.4"],
Cell[171841, 9201, 11528, 773, 70, 11455, 770, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]],
Cell[183384, 9977, 212, 7, 70, "MathCaption",
  CellTags->{"S1.6.4", "4.24"}],

Cell[CellGroupData[{
Cell[183621, 9988, 211, 7, 70, "Input",
  CellTags->"S1.6.4"],
Cell[183835, 9997, 30451, 1972, 70, 30378, 1969, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.6.4"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

