(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    236965,      15675]*)
(*NotebookOutlinePosition[    270954,      16664]*)
(*  CellTagsIndexPosition[    267155,      16519]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["1.7 Local Trigonometric Bases and Transforms", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["1.7.1 Windowed Fourier Transforms",
    ButtonData:>{"Wavelets 1.7.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.7.2 Discrete Sine and Cosine Transforms",
    ButtonData:>{"Wavelets 1.7.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.7.3 Local Sine and Cosine Bases of Coifman and Meyer",
    ButtonData:>{"Wavelets 1.7.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.7.4 Local Trigonometric Transforms",
    ButtonData:>{"Wavelets 1.7.4"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["1.7.5 Local Sine and Cosine Packet Transforms",
    ButtonData:>{"Wavelets 1.7.5"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["1.7 Local Trigonometric Bases and Transforms", "Section",
  CellTags->{"S1.7.0", "0.1"}],

Cell["1.7.1 Windowed Fourier Transforms", "Subsection",
  CellTags->{"S1.7.1", "1.1"}],

Cell[TextData[{
  "It is well known that the Fourier transform of a signal ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ", gives the frequency content of the signal. The amplitude of the \
transform at a particular frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S1.7.1"],
  " comes from the contributions of the signal at ",
  StyleBox["all", "TI"],
  " times to that frequency. However, sometimes we are interested in the \
frequency content of a signal in the neighborhood of some instant of time. \
For example, the change of frequency over time is essential in forming a \
piece of music. The Fourier transform of a signal does not describe the \
frequency content of the signal as a function of time. The absence of a \
particular frequency in an interval of time is reproduced by a delicate \
cancellation of phases in the Fourier transform. \nIt is important in many \
situations to obtain the temporal structure of the frequency content in a \
transparent way. One way to obtain both time and frequency localization is to \
use the so\[Hyphen]called windowed Fourier transform. As the name suggests, \
we multiply the signal by a window function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t - t\_0)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  " is nonzero only in a finite region around 0. Then the Fourier transform \
of ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) b \((t - t\_0)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ","
}], "Text",
  CellTags->{"S1.7.1", "1.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\&^\), \((\[Omega], t\_0)\), "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "f", \((t)\), "b", \((
        t - t\_0)\), \(e\^\(-i  \[Omega]  t\)\), 
        StyleBox[\("dt"\),
          "TI"], ","}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.1", "1.3"}],

Cell[TextData[{
  "gives the frequency content of the signal near ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_0\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ". It is clear that only the signal around ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_0\)], "InlineFormula",
    CellTags->"S1.7.1"],
  " contributes to ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\) \((\[Omega], t\_0)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ", since this is the part of signal \"seen\" through the window and the \
rest is cut off by the function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ". As we move the window along the time axis, different parts of the signal \
are \"seen\" and this accomplishes our aim of finding a \
time\[Hyphen]frequency description of ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  ". \nThe crudest window can be a rectangular window. A rectangular window \
over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, L]\)\)\)], "InlineFormula",
    CellTags->"S1.7.1"],
  " is defined as"
}], "Text",
  CellTags->{"S1.7.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"b", \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["1",
                  "DisplayFormula"], 
                StyleBox[\(" for " 0 \[LessEqual] t < L\),
                  "DisplayFormula"]},
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[\(" otherwise".\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.7.1", "1.5"}],

Cell[TextData[{
  "The effect of the above window is simply to cut the signal into \
nonoverlapping slices of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.7.1"],
  "; and performing a windowed Fourier transform using a rectangular window \
is equivalent to doing Fourier transforms on each slice of the signal \
separately. The abrupt cutoff of the signal leads to unwelcomed features, \
including the Gibbs phenomenon. Coifman and Meyer introduced the smooth local \
cosine and sine bases and transforms to mitigate these problems; we discuss \
the construction of these bases and the transforms and the functions that \
implement them. We also present Malvar wavelets and functions to determine \
the best cosine or sine packet basis using different cost functions. "
}], "Text",
  CellTags->{"S1.7.1", "1.6"}],

Cell["1.7.2 Discrete Sine and Cosine Transforms", "Subsection",
  CellTags->{"S1.7.2", "2.1"}],

Cell[TextData[{
  "We now consider Fourier sine and cosine transforms;these are useful in \
cases where it is desirable to have Fourier transforms that produce real \
coefficients. Commonly used sine and cosine orthonormal bases on an interval \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([a, b]\)\)\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`L = b - a\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " are the so\[Hyphen]called Sin\[Hyphen]II, Sin\[Hyphen]IV, Cos\[Hyphen]II, \
and Cos\[Hyphen]IV bases. They are given by (see Wickerhauser (1994)) "
}], "Text",
  CellTags->{"S1.7.2", "2.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`" Sin\[Hyphen]II basis: " \(\@\(2\/L\)\) sin \(\( k  \[Pi]\)\/L\) 
      \((t - a)\) \(, \ \ \ \) k = 1, 2, \[Ellipsis]\)], "DisplayFormula",
  CellTags->{"S1.7.2", "2.3"}],

Cell["", "Text",
  CellTags->{"S1.7.2", "2.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`" Cos\[Hyphen]II basis: " \(s\_k\) \(\@\(2\/L\)\) cos 
      \(\( k  \[Pi]\)\/L\) \((t - a)\) \(, \ \ \ \) k = 0, 1, 2, 
      \[Ellipsis]\)], "DisplayFormula",
  CellTags->{"S1.7.2", "2.5"}],

Cell["", "Text",
  CellTags->{"S1.7.2", "2.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`" Sin\[Hyphen]IV basis: " \(\@\(2\/L\)\) sin \( \[Pi]\/L\) 
      \((k + 1\/2)\) \((t - a)\) \(, \ \ \ \) k = 0, 1, 2, \[Ellipsis]\)], 
  "DisplayFormula",
  CellTags->{"S1.7.2", "2.7"}],

Cell["", "Text",
  CellTags->{"S1.7.2", "2.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`" Cos\[Hyphen]IV basis: " \(\@\(2\/L\)\) cos \( \[Pi]\/L\) 
      \((k + 1\/2)\) \((t - a)\) \(, \ \ \ \) k = 0, 1, 2, \[Ellipsis]\)], 
  "DisplayFormula",
  CellTags->{"S1.7.2", "2.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\_0 = 1/\@2\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k = 1\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k > 0\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ". \nThe four trigonometric bases listed above are commonly used to do \
\"windowed Fourier transforms\". The ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " coefficient of the transform using the Cos\[Hyphen]IV basis of a signal, \
",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ", restricted to the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([a\_j, a\_\(j + 1\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.2"],
  " of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " is given by "
}], "Text",
  CellTags->{"S1.7.2", "2.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\@\(2\/L\)\), \(\[Integral]\_a\_j\%a\_\(j + 1\)\), "f", \((t)\), 
        "cos", \(\[Pi]\/L\), \((k + 1\/2)\), \((t - a\_j)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(\@\(2\/L\)\), \(\[Integral]\_0\%L\), "f", \((t + a\_j)
        \), "cos", \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.2", "2.11"}],

Cell[TextData[{
  "In practice, the discretized version of the transform is often used. It is \
obtained by dividing ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " into a grid of intervals of size ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`L = N  \[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " and the discrete Cos\[Hyphen]IV transform is defined to be "
}], "Text",
  CellTags->{"S1.7.2", "2.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(c\_k\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "cos", \(\[Pi]\/N\), 
        \((k + 1\/2)\), \((i + 1\/2)\)}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.2", "2.13"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], N - 1\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ", and the inverse transform is "
}], "Text",
  CellTags->{"S1.7.2", "2.14"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_i\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), "cos", \(\[Pi]\/N\), 
        \((k + 1\/2)\), \((i + 1\/2)\)}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.7.2", "2.15"}],

Cell[TextData[{
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, \[Ellipsis], N - 1\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ". Note that we have taken the sample points at the middle of each grid so \
that ",
  Cell[BoxData[
      \(TraditionalForm
      \`f\_i = f \((a\_j + \((i + 1/2)\) \[CapitalDelta])\)\)], 
    "InlineFormula",
    CellTags->"S1.7.2"],
  ". \nSimilarly, the discrete Sin\[Hyphen]IV, Cos\[Hyphen]II, and Sin\
\[Hyphen]II transforms and inverse transforms are defined as follows: "
}], "Text",
  CellTags->{"S1.7.2", "2.16"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(" Sin\[Hyphen]IV: "\), "  ", \(c\_k\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "sin", \(\[Pi]\/N\), 
        \((k + 1\/2)\), \((i + 1\/2)\), "     ", \(f\_i\), "=", 
        \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), "sin", \(\[Pi]\/N\), 
        \((k + 1\/2)\), \((i + 1\/2)\)}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S1.7.2", "2.17"}],

Cell["", "Text",
  CellTags->{"S1.7.2", "2.18"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(" Cos\[Hyphen]II: "\), "  ", \(c\_k\), "=", \(s\_k\), \(\@\(2\/N\)\), 
        
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "cos", \(\[Pi]\/N\), "k", \((
        i + 1\/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), \(s\_k\), "cos", \(\[Pi]\/N\), 
        "k", \((i + 1\/2)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.2", "2.19"}],

Cell["", "Text",
  CellTags->{"S1.7.2", "2.20"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(" Sin\[Hyphen]II: "\), "  ", \(c\_k\), "=", \(s\_\(k + 1\)\), 
        \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "sin", \(\[Pi]\/N\), 
        \((k + 1)\), \((i + 1\/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), \(s\_\(k + 1\)\), "sin", 
        \(\[Pi]\/N\), \((k + 1)\), \((i + 1\/2)\), ","}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.7.2", "2.21"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k = 1/\@2\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k = 1\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " otherwise. "
}], "Text",
  CellTags->{"S1.7.2", "2.22"}],

Cell["Implementation of Discrete Sine and Cosine Transforms", "Subsubsection",
  CellTags->{"S1.7.2", "2.23"}],

Cell[TextData[{
  "We first show how we can implement these transforms numerically. For \
specificity, we look at Cos\[Hyphen]IV transforms, noting that the other \
three transforms can be worked out similarly.\nEquation (",
  ButtonBox["7.1",
    ButtonData:>{"Wavelets 1.7.2", "2.13"},
    ButtonStyle->"AddOnsLink"],
  ") can be written as "
}], "Text",
  CellTags->{"S1.7.2", "2.24"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(c\_k\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(\[InvisibleSpace]\([
        \(f\_i\) \((
          cos \(\( \[Pi] \((2  k + 1)\)\)\/\(4  N\)\) cos 
            \(\( 2  \[Pi]\)\/\(4  N\)\) \((2  k + 1)\) i - sin 
            \(\( \[Pi] \((2  k + 1)\)\)\/\(4  N\)\) sin 
            \(\( 2  \[Pi]\)\/\(4  N\)\) \((2  k + 1)\) i)\)]\)\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.2", "2.25"}],

Cell["Recognizing that ", "Text",
  CellTags->{"S1.7.2", "2.26"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(1\/\@\(4  N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "cos", 
        \(\(2  \[Pi]\)\/\(4  N\)\), \((2  k + 1)\), "i"}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.7.2", "2.27"}],

Cell[TextData[{
  "is simply the real part of the ",
  Cell[BoxData[
      \(TraditionalForm\`\((2  k + 1)\)\^st\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " coefficient of the Fourier transform of the series of length ",
  Cell[BoxData[
      \(TraditionalForm\`4  N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " with the first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " entries given by ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " and last ",
  Cell[BoxData[
      \(TraditionalForm\`3  N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " entries 0, the discrete Cos\[Hyphen]IV transform can be obtained in terms \
of Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{\(f\&^\)\_k}\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " obtained from the fast Fourier transform "
}], "Text",
  CellTags->{"S1.7.2", "2.28"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(c\_k\), "=", "2", \(\@2\), 
        RowBox[{"(", 
          RowBox[{"cos", \(\(\[Pi] \((2  k + 1)\)\)\/\(4  N\)\), 
            StyleBox[\("Re"\),
              "TI"], \((\(f\&^\)\_\(2  k + 1\))\), "-", "sin", 
            \(\(\[Pi] \((2  k + 1)\)\)\/\(4  N\)\), 
            StyleBox[\("Im"\),
              "TI"], \((\(f\&^\)\_\(2  k + 1\))\)}], ")"}], ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.2", "2.29"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&^\)\_k\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " Fourier coefficient of the series obtained by padding ",
  Cell[BoxData[
      \(TraditionalForm\`3  N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " zeros at the end of ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S1.7.2"],
  ". The inverse transform is given by the same formula with ",
  Cell[BoxData[
      \(TraditionalForm\`c\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " interchanged. \nThe functions "
}], "Text",
  CellTags->{"S1.7.2", "2.30"}],

Cell[TextData[{
  StyleBox["CosTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  "  and  ",
  StyleBox["SinTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.2", "2.31"}],

Cell[TextData[{
  "do discrete windowed Fourier transforms using Cos\[Hyphen]IV basis and Sin\
\[Hyphen]IV basis, respectively, by partitioning ",
  StyleBox["data", "TI"],
  " into segments of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.2"],
  " (",
  StyleBox["i.e.", "TI"],
  ", the window length is ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.2"],
  "). The functions that do the inverse transforms are "
}], "Text",
  CellTags->{"S1.7.2", "2.32"}],

Cell[TextData[{
  StyleBox["InverseCosTransform[", "MR"],
  StyleBox["ctdata", "TI"],
  StyleBox["]", "MR"],
  "  and  ",
  StyleBox["InverseSinTransform[", "MR"],
  StyleBox["stdata", "TI"],
  StyleBox["]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.2", "2.33"}],

Cell[TextData[{
  "Note that the argument ",
  StyleBox["ctdata", "TI"],
  " or ",
  StyleBox["stdata", "TI"],
  " should be in the form of the output of ",
  StyleBox["CosTransform", "MR"],
  " or ",
  StyleBox["SinTransform", "MR"],
  ". \nThere are three options to the above functions. First, to do windowed \
Fourier transform using Cos\[Hyphen]II or Sin\[Hyphen]II basis, we need to \
set the option ",
  StyleBox["BasisType", "MR"],
  " from default ",
  StyleBox["IV", "MR"],
  " to ",
  StyleBox["II", "MR"],
  ".The option ",
  StyleBox["Taper", "MR"],
  "specifies the window we use. In Section ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.1"},
    ButtonStyle->"AddOnsLink"],
  ", we will see that we can have smooth windows that overlap with each other \
while maintaining the orthogonality of the basis functions. Different smooth \
windows are obtained by specifying different taper functions. For a \
rectangular window, the abrupt cutoff of the window corresponds to having no \
taper function, so the option ",
  StyleBox["Taper", "MR"],
  " should be set to ",
  StyleBox["False", "MR"],
  ". Finally, the option ",
  StyleBox["BoundaryCondition", "MR"],
  " specifies the boundary condition. As in the case of the function ",
  StyleBox["WaveletTransform", "MR"],
  ", the default boundary condition is ",
  StyleBox["Periodic", "MR"],
  ".\nFor example, if we have one\[Hyphen]dimensional data and want to do \
discrete Cos\[Hyphen]II transforms with a rectangular window of width ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S1.7.2"],
  ", we can use "
}], "Text",
  CellTags->{"S1.7.2", "2.34"}],

Cell[TextData[{
  StyleBox["CosTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["False,", "MR"],
  " ",
  StyleBox["BasisType", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["II]", "MR"],
  ". "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.2", "2.35"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S1.7.2", "2.36"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S1.7.2"],

Cell["We generate a list of 15 random numbers.", "MathCaption",
  CellTags->{"S1.7.2", "2.37"}],

Cell["\<\
(SeedRandom[45847];
data = Table[Random[], {15}];)\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S1.7.2"],

Cell[TextData[{
  "This gives the Cos\[Hyphen]IV transform of ",
  StyleBox["data", "MR"],
  " with a rectangular window of width ",
  Cell[BoxData[
      \(TraditionalForm\`N = 5\)], "InlineFormula",
    CellTags->"S1.7.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.2", "2.38"}],

Cell[CellGroupData[{

Cell["CosTransform[data, 5, Taper -> False]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S1.7.2"],

Cell[BoxData[
    \({{1.18118590089592068`, \(-0.344492825456974394`\), 
        0.495568615498056797`, \(-0.542290889709861012`\), 
        \(-0.339484513377046814`\)}, {1.26341527850652624`, 
        \(-0.111093145736111686`\), 0.203899592707297871`, 
        \(-0.620656008095903999`\), 0.0937068516710342436`}, {
        1.23311673923194775`, \(-0.130535013895473817`\), 
        0.263791936347277822`, \(-0.220841192102460848`\), 
        0.371582725244659561`}}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S1.7.2"]
}, Open  ]],

Cell["This does the inverse transform.", "MathCaption",
  CellTags->{"S1.7.2", "2.39"}],

Cell[CellGroupData[{

Cell["InverseCosTransform[%, Taper -> False]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S1.7.2"],

Cell[BoxData[
    \({0.57605069734594938`, 0.846143913462143792`, 0.0663372979983317101`, 
      0.913625392459984553`, 0.530930233423652353`, 0.648862476438579882`, 
      0.970582928898778796`, 0.2878533575844882`, 0.409133786361365725`, 
      0.65637337356135994`, 0.788055458444160272`, 0.595262758201008068`, 
      0.559285926235871677`, 0.322331250771552113`, 0.634018676809978209`}\)],
   "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S1.7.2"]
}, Open  ]],

Cell["We check that we recover the original data.", "MathCaption",
  CellTags->{"S1.7.2", "2.40"}],

Cell[CellGroupData[{

Cell["Chop[%-data]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S1.7.2"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S1.7.2"]
}, Open  ]],

Cell[TextData[{
  "This does Sin\[Hyphen]II transform with a rectangular window of width ",
  Cell[BoxData[
      \(TraditionalForm\`N = 5\)], "InlineFormula",
    CellTags->"S1.7.2"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.2", "2.41"}],

Cell[CellGroupData[{

Cell["SinTransform[data, 5, Taper -> False, BasisType -> II]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S1.7.2"],

Cell[BoxData[
    \({{1.15871956204376536`, \(-0.0238167302854773588`\), 
        0.868378970289097651`, 0.052226109319558871`, 
        \(-0.26226889479895088`\)}, {1.14310499026470657`, 
        0.334920034181995562`, 0.755443175794916044`, 
        \(-0.213235426979954745`\), 0.0954230794731298814`}, {
        1.10115577162391975`, 0.221431433177546699`, 0.553239438884924439`, 
        \(-0.00880848016990602111`\), 0.475730641117125863`}}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S1.7.2"]
}, Open  ]],

Cell["Again the inverse transform gives back the original data.", 
  "MathCaption",
  CellTags->{"S1.7.2", "2.42"}],

Cell[CellGroupData[{

Cell["\<\
Chop[data - InverseSinTransform[%,
Taper -> False, BasisType -> II]]\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S1.7.2"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"S1.7.2"]
}, Open  ]],

Cell["1.7.3 Local Sine and Cosine Bases of Coifman and Meyer", "Subsection",
  CellTags->{"S1.7.3", "3.1"}],

Cell[TextData[{
  "A rectangular window restricts a signal to a time interval by setting the \
signal outside of the interval to zero. Equivalently, the window cuts the \
sine or cosine basis functions abruptly to zero at the endpoints of the \
interval. Even if the original signal ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " is smooth, multiplication by a rectangular window will, in general, \
produce a function whose Fourier transform converges very slowly and the \
Gibbs phenomenon can occur. In order to overcome this difficulty, a smoother \
window is needed. The idea is to allow the smooth windows at two adjacent \
intervals to overlap while maintaining the orthogonality of the basis \
functions on the two intervals. In the following, we will show how this is \
done and derive the conditions for window functions.\nWe partition the time \
axis with points ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_j} \((a\_j < a\_\(j + 1\))\)\)], "InlineFormula",
    
    CellTags->"S1.7.3"],
  " into intervals, such that the ",
  Cell[BoxData[
      \(TraditionalForm\`j\^th\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " interval is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([a\_j, a\_\(j + 1\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " and has length ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j = a\_\(j + 1\) - a\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". Around each endpoint of an interval, say ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", we allow a transition region ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      a\_j - \[Epsilon]\_j, a\_j + \[Epsilon]\_j]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " of width ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Epsilon]\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "; in this region the window ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " rises smoothly from 0 to 1, and the window ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_\(j - 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`j - 1\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " decreases smoothly from 1 to 0. Now the window or ",
  StyleBox["bell", "TI"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " is nonzero for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " in the region ",
  Cell[BoxData[
      \(TraditionalForm
      \`\((a\_j - \[Epsilon]\_j, a\_\(j + 1\) + \[Epsilon]\_\(j + 1\))\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " and it is 1 for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      a\_j + \[Epsilon]\_j, a\_\(j + 1\) - \[Epsilon]\_\(j + 1\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  ". The windows over the two adjacent intervals overlap in the transition \
region and obviously arbitrary windows ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " do not lead to orthogonality of the functions "
}], "Text",
  CellTags->{"S1.7.3", "3.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({\(\@\(2\/L\_j\)\) \(b\_j\) \((t)\) cos \( \[Pi]\/L\_j\) 
            \((k + 1\/2)\) \((t - a\_j)\)}\_\(j, k\).\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.3"}],

Cell[TextData[{
  "However, it is straightforward to derive the conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`b\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " such that (",
  ButtonBox["7.2",
    ButtonData:>{"Wavelets 1.7.3", "3.3"},
    ButtonStyle->"AddOnsLink"],
  ") is an orthogonal set. First, we consider the inner product of two basis \
functions from the same interval. We have, ignoring the normalization \
constant, "
}], "Text",
  CellTags->{"S1.7.3", "3.4"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(b\_j\%2\), \((
                t)\), "cos", \(\[Pi]\/L\_j\), \((k + 1\/2)\), \((t - a\_j)\), 
                "cos", \(\[Pi]\/L\_j\), \((m + 1\/2)\), \((t - a\_j)\), " ", 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Epsilon]\_j\)\%\(L\_j + 
                      \[Epsilon]\_\(j + 1\)\)\), \(b\_j\%2\), \((a\_j + t)\), 
                "cos", \(\[Pi]\/L\_j\), \((k + 1\/2)\), \(t\ \), "cos", 
                \(\[Pi]\/L\_j\), \((m + 1\/2)\), \(t\ \), 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"\n(7.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.5"}],

Cell[TextData[{
  "The above integral can be split into three regions: from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Epsilon]\_j\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j - \[Epsilon]\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " where the ",
  Cell[BoxData[
      \(TraditionalForm\`b\^2\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " term is identically 1, and from ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j - \[Epsilon]\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j + \[Epsilon]\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". The integral over the first region can be written as "
}], "Text",
  CellTags->{"S1.7.3", "3.6"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Epsilon]\_j\)\%\[Epsilon]\_j\), \(b\_j\%2\),
                 \((a\_j + t)\), "cos", \(\[Pi]\/L\_j\), \((k + 1\/2)\), "t", 
                "cos", \(\[Pi]\/L\_j\), \((m + 1\/2)\), \(t\ \), 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_0\%\[Epsilon]\_j\), \(\[InvisibleSpace]\([
                \(b\_j\%2\) \((a\_j + t)\) + \(b\_j\%2\) \((a\_j - t)\)]\)\), 
                "cos", \(\[Pi]\/L\_j\), \((k + 1\/2)\), "t", "cos", 
                \(\[Pi]\/L\_j\), \((m + 1\/2)\), \(t\ \), 
                StyleBox[\("dt"\),
                  "TI"], "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.7.3", "3.7"}],

Cell[TextData[{
  "Now if we choose ",
  Cell[BoxData[
      \(TraditionalForm\`b\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " such that it satisfies "
}], "Text",
  CellTags->{"S1.7.3", "3.8"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(b\_j\%2\) \((a\_j + t)\) + \(b\_j\%2\) \((a\_j - t)\) = \(1\ \ \ \) 
      " for " \[VerticalSeparator] t \[VerticalSeparator]  < \[Epsilon]\_j, 
      \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.9"}],

Cell[TextData[{
  "the integral over the overlapping region is exactly the same as if we have \
a nonoverlapping rectangular window. If we also require a condition similar \
to (",
  ButtonBox["7.4",
    ButtonData:>{"Wavelets 1.7.3", "3.9"},
    ButtonStyle->"AddOnsLink"],
  ") to be true around ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(j + 1\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", we can show analogously that the integral over the region ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      L\_j - \[Epsilon]\_\(j + 1\), L\_j + \[Epsilon]\_\(j + 1\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " is the same as that over the region ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      L\_j - \[Epsilon]\_\(j + 1\), L\_j]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " with a rectangular window. So the integral in (",
  ButtonBox["7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.5"},
    ButtonStyle->"AddOnsLink"],
  ") can be reduced to "
}], "Text",
  CellTags->{"S1.7.3", "3.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_a\_j\%a\_\(j + 1\)\), "cos", \(\[Pi]\/L\_j\), 
        \((k + 1\/2)\), \((t - a\_j)\), "cos", \(\[Pi]\/L\_j\), 
        \((m + 1\/2)\), \((t - a\_j)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(\[Delta]\_\(k  m\)\), "."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.7.3", "3.11"}],

Cell[TextData[{
  "Now consider the inner product of two basis functions from different \
intervals. Since only the windows from adjacent intervals overlap in a region \
of ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", we have (again ignoring normalization constants) "
}], "Text",
  CellTags->{"S1.7.3", "3.12"}],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(b\_j\), \((t)
                \), \(b\_\(j - 1\)\), \((t)\), "cos", \(\[Pi]\/L\_j\), 
                \((k + 1\/2)\), \((t - a\_j)\), "cos", 
                \(\[Pi]\/L\_\(j - 1\)\), \((m + 1\/2)\), 
                \((t - a\_\(j - 1\))\), " ", 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \(\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\), \(b\_j\), \((
                a\_j + t)\), \(b\_\(j - 1\)\), \((a\_j + t)\), "cos", 
                \(\[Pi]\/L\_j\), \((k + 1\/2)\), "t", "cos", 
                \(\[Pi]\/L\_\(j - 1\)\), \((m + 1\/2)\), 
                \((t + L\_\(j - 1\))\), " ", 
                StyleBox[\("dt"\),
                  "TI"]}],
              "DisplayFormula"]},
          {
            StyleBox["\[Null]",
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
              \("const"\), \(\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\), 
                \(b\_j\), \((a\_j + t)\), \(b\_\(j - 1\)\), \((a\_j + t)\), 
                "cos", \(\[Pi]\/L\_j\), \((k + 1\/2)\), \(t\ \), "sin", 
                \(\[Pi]\/L\_\(j - 1\)\), \((m + 1\/2)\), \(t\ \), 
                StyleBox[\("dt"\),
                  "TI"], "."}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S1.7.3", "3.13"}],

Cell[TextData[{
  "We see that if ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(b\_j\) \((a\_j + t)\) \(b\_\(j - 1\)\) \((a\_j + t)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " is an even function, the integrand will be an odd function and the \
integral vanishes. So if we choose "
}], "Text",
  CellTags->{"S1.7.3", "3.14"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(b\_\(j - 1\)\) \((a\_j + t)\) = \(b\_j\) \((a\_j - t)\)\ \ \ " for " 
      \[VerticalSeparator] t \[VerticalSeparator]  \[LessEqual] 
      \[Epsilon]\_j, \)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.15"}],

Cell[TextData[{
  "the basis functions from different intervals are orthogonal. \nGathering \
the above conditions together, for a given ",
  Cell[BoxData[
      \(TraditionalForm\`{a\_j} \((a\_j < a\_\(j + 1\))\)\)], "InlineFormula",
    
    CellTags->"S1.7.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j = a\_\(j + 1\) - a\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", "
}], "Text",
  CellTags->{"S1.7.3", "3.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`{\(\@\(2\/L\_j\)\) \(b\_j\) \((t)\) cos \( \[Pi]\/L\_j\) \((k + 1\/2)\) 
          \((t - a\_j)\)}\_\(j, k\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.6) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.17"}],

Cell[TextData[{
  "constitutes an orthonormal basis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " is the window or bell over the ",
  Cell[BoxData[
      \(TraditionalForm\`j\^th\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " interval. The window has the following properties:\n(i)  ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \(b\_j\) \((t)\) \[LessEqual] 1\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(b\_j\), \((t)\), "=", 
          RowBox[{"{", GridBox[{
                {
                  StyleBox["1",
                    "InlineFormula"], 
                  
                  StyleBox[
                    \(" if "\ \ \ a\_j + \[Epsilon]\_j \[LessEqual] t 
                      \[LessEqual] a\_\(j + 1\) - \[Epsilon]\_\(j + 1\)\),
                    "InlineFormula"]},
                {
                  StyleBox["0",
                    "InlineFormula"], 
                  
                  StyleBox[
                    \(" if "\ \ \ t \[LessEqual] a\_j - \[Epsilon]\_j\ \ \ 
                      " or"\ \ \ t \[GreaterEqual] a\_\(j + 1\) + 
                      \[Epsilon]\_\(j + 1\)\),
                    "InlineFormula"]}
                },
              ColumnAlignments->{Left}]}]}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_j > 0\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Epsilon]\_j + \[Epsilon]\_\(j + 1\) \[LessEqual] L\_j\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  "; \n(ii)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(b\_j\%2\) \((a\_j + t)\) + \(b\_j\%2\) \((a\_j - t)\) = \(1\ \ \ \) 
        " if " \[VerticalSeparator] t \[VerticalSeparator]  \[LessEqual] 
        \[Epsilon]\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "; \n(iii)  ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(b\_j\) \((a\_j + t)\) = \(b\_\(j - 1\)\) \((a\_j - t)\)\ \ \ " if " 
        \[VerticalSeparator] t \[VerticalSeparator]  \[LessEqual] 
        \[Epsilon]\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ".  \nThe basis given in (",
  ButtonBox["7.6",
    ButtonData:>{"Wavelets 1.7.3", "3.17"},
    ButtonStyle->"AddOnsLink"],
  ") is called the local cosine basis of Coifman and Meyer or the smooth \
local cosine basis (see Coifman and Meyer (1991), Meyer (1993) and Auscher et \
al. (1992)). Repeating the above derivation with the sine function replacing \
cosine function, we arrive at the local sine basis of Coifman and Meyer:"
}], "Text",
  CellTags->{"S1.7.3", "3.18"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({\(\@\(2\/L\_j\)\) \(b\_j\) \((t)\) sin \( \[Pi]\/L\_j\) 
            \((k + 1\/2)\) \((t - a\_j)\)}\_\(j, k\).\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.7) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.3", "3.19"}],

Cell[TextData[{
  "Here is a window over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 4]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.20"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[WindowFunction[t, 4]],
{t, -2, 6}, AspectRatio -> Automatic]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.119048 0.00297619 0.119048 [
[.02381 -0.00952 -6 -9 ]
[.02381 -0.00952 6 0 ]
[.5 -0.00952 -3 -9 ]
[.5 -0.00952 3 0 ]
[.7381 -0.00952 -3 -9 ]
[.7381 -0.00952 3 0 ]
[.97619 -0.00952 -3 -9 ]
[.97619 -0.00952 3 0 ]
[.2494 .02679 -18 -4.5 ]
[.2494 .02679 0 4.5 ]
[.2494 .0506 -18 -4.5 ]
[.2494 .0506 0 4.5 ]
[.2494 .0744 -18 -4.5 ]
[.2494 .0744 0 4.5 ]
[.2494 .09821 -18 -4.5 ]
[.2494 .09821 0 4.5 ]
[.2494 .12202 -6 -4.5 ]
[.2494 .12202 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .00298 m
.02381 .00923 L
s
[(-2)] .02381 -0.00952 0 1 Mshowa
.5 .00298 m
.5 .00923 L
s
[(2)] .5 -0.00952 0 1 Mshowa
.7381 .00298 m
.7381 .00923 L
s
[(4)] .7381 -0.00952 0 1 Mshowa
.97619 .00298 m
.97619 .00923 L
s
[(6)] .97619 -0.00952 0 1 Mshowa
.125 Mabswid
.08333 .00298 m
.08333 .00673 L
s
.14286 .00298 m
.14286 .00673 L
s
.20238 .00298 m
.20238 .00673 L
s
.32143 .00298 m
.32143 .00673 L
s
.38095 .00298 m
.38095 .00673 L
s
.44048 .00298 m
.44048 .00673 L
s
.55952 .00298 m
.55952 .00673 L
s
.61905 .00298 m
.61905 .00673 L
s
.67857 .00298 m
.67857 .00673 L
s
.79762 .00298 m
.79762 .00673 L
s
.85714 .00298 m
.85714 .00673 L
s
.91667 .00298 m
.91667 .00673 L
s
.25 Mabswid
0 .00298 m
1 .00298 L
s
.2619 .02679 m
.26815 .02679 L
s
[(0.2)] .2494 .02679 1 0 Mshowa
.2619 .0506 m
.26815 .0506 L
s
[(0.4)] .2494 .0506 1 0 Mshowa
.2619 .0744 m
.26815 .0744 L
s
[(0.6)] .2494 .0744 1 0 Mshowa
.2619 .09821 m
.26815 .09821 L
s
[(0.8)] .2494 .09821 1 0 Mshowa
.2619 .12202 m
.26815 .12202 L
s
[(1)] .2494 .12202 1 0 Mshowa
.125 Mabswid
.2619 .00893 m
.26565 .00893 L
s
.2619 .01488 m
.26565 .01488 L
s
.2619 .02083 m
.26565 .02083 L
s
.2619 .03274 m
.26565 .03274 L
s
.2619 .03869 m
.26565 .03869 L
s
.2619 .04464 m
.26565 .04464 L
s
.2619 .05655 m
.26565 .05655 L
s
.2619 .0625 m
.26565 .0625 L
s
.2619 .06845 m
.26565 .06845 L
s
.2619 .08036 m
.26565 .08036 L
s
.2619 .08631 m
.26565 .08631 L
s
.2619 .09226 m
.26565 .09226 L
s
.2619 .10417 m
.26565 .10417 L
s
.2619 .11012 m
.26565 .11012 L
s
.2619 .11607 m
.26565 .11607 L
s
.25 Mabswid
.2619 0 m
.2619 .125 L
s
0 0 m
1 0 L
1 .125 L
0 .125 L
closepath
clip
newpath
.5 Mabswid
.02381 .00298 m
.06244 .00298 L
.08255 .00298 L
.10458 .00298 L
.11448 .00298 L
.12507 .00298 L
.1302 .00298 L
.13506 .00298 L
.13942 .00298 L
.14061 .00298 L
.14188 .00298 L
.14296 .00298 L
.14415 .00313 L
.14544 .0034 L
.14664 .00372 L
.14935 .00464 L
.15429 .00679 L
.16356 .012 L
.18444 .02687 L
.22357 .0586 L
.26515 .08928 L
.28602 .10149 L
.30522 .11026 L
.31491 .11373 L
.32396 .11638 L
.33341 .11854 L
.34377 .12024 L
.34877 .12083 L
.35422 .12131 L
.35671 .12149 L
.35936 .12164 L
.36165 .12174 L
.36412 .12184 L
.36649 .1219 L
.36867 .12195 L
.37075 .12198 L
.3718 .12199 L
.37294 .122 L
.37422 .12201 L
.37538 .12202 L
.37602 .12202 L
.37672 .12202 L
.37798 .12202 L
.37917 .12202 L
.38043 .12202 L
.3815 .12202 L
.38268 .12202 L
.42302 .12202 L
.46184 .12202 L
.50312 .12202 L
Mistroke
.54288 .12202 L
.58112 .12202 L
.60084 .12202 L
.60651 .12202 L
.61185 .12202 L
.61418 .12202 L
.61664 .12202 L
.61793 .12202 L
.61866 .12202 L
.61934 .12202 L
.62054 .12202 L
.62182 .12202 L
.62304 .12202 L
.62374 .12202 L
.62439 .12202 L
.62571 .12201 L
.62645 .12201 L
.62712 .122 L
.62951 .12198 L
.63071 .12196 L
.63202 .12194 L
.6348 .12187 L
.63776 .12177 L
.64056 .12164 L
.6431 .1215 L
.64808 .12113 L
.65346 .12058 L
.65855 .11992 L
.66323 .11917 L
.67295 .11715 L
.68204 .11469 L
.70269 .10695 L
.72302 .09652 L
.74157 .08482 L
.78138 .05459 L
.81968 .02371 L
.83943 .01019 L
.84423 .00754 L
.8494 .00513 L
.85237 .00403 L
.85367 .00363 L
.85509 .00328 L
.85574 .00315 L
.85643 .00304 L
.85769 .00298 L
.85842 .00298 L
.85912 .00298 L
.86043 .00298 L
.89886 .00298 L
.93975 .00298 L
Mistroke
.97619 .00298 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell["Construction of a Window", "Subsubsection",
  CellTags->{"S1.7.3", "3.21"}],

Cell[TextData[{
  "Let us take a closer look at the conditions on a window function we \
derived earlier and construct some windows with various degrees of \
smoothness. First, we notice that condition (i) says that the windows in the \
smooth local sine or cosine basis are simply smoothed versions of the \
rectangular window and ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " can be specified if it is known in the transition regions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      a\_j - \[Epsilon]\_j, a\_j + \[Epsilon]\_j]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      a\_\(j + 1\) - \[Epsilon]\_\(j + 1\), a\_\(j + 1\) + 
        \[Epsilon]\_\(j + 1\)]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". So we can just consider the window function in the transition regions \
which we refer to as a taper function or simply a taper. Without any loss of \
generality, let us consider a taper function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " over the transition region ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 1]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Epsilon]\_j = 1\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j = 0.5\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", since a taper function in an arbitrary region ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([
      a\_j - \[Epsilon]\_j, a\_j + \[Epsilon]\_j]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " can be obtained by a simple change of variables ",
  Cell[BoxData[
      \(TraditionalForm
      \`b \((\((t - \((a\_j - \[Epsilon]\_j)\))\)/2  \[Epsilon]\_j)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  ". The condition (ii) is"
}], "Text",
  CellTags->{"S1.7.3", "3.22"}],

Cell[BoxData[
    \(TraditionalForm\`\(b\^2\) \((t)\) + \(b\^2\) \((1 - t)\) = 1.\)], 
  "DisplayFormula",
  CellTags->{"S1.7.3", "3.23"}],

Cell[TextData[{
  "We have seen something similar before! Recall that in constructing Meyer \
wavelets we also needed a smooth taper function that satisfied ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((t)\) + \[Nu] \((1 - t)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " and we showed how to obtain a polynomial solution of arbitrary order. So \
the taper function for the window can be obtained simply by taking the square \
root of the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". In fact, the window displayed previously is plotted using the default \
\"polynomial\" taper of order 2, ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\(t\^3\) \((10 - 15  t + 6  t\^2)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 1\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". \nAnother type of commonly used taper function involves trigonometric \
functions. It is easy to see that ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\) = sin  \[Pi]  t/2\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " satisfies condition (ii). In fact, any function of the form ",
  Cell[BoxData[
      \(TraditionalForm\`sin \( \[Pi]\/2\) \[Nu] \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \((t)\) + \[Nu] \((1 - t)\) = 1\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " satisfies condition (ii) and, therefore, can be used as a taper function. \
For example, we can iterate the sine function twice and get ",
  Cell[BoxData[
      \(TraditionalForm
      \`b \((t)\) = sin \( \[Pi]\/2\) \(sin\^2\) \(\[Pi]\/2\) \(sin\^2\) 
        \(\[Pi]\/2\) t\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". Here is a window function using this taper function. "
}], "Text",
  CellTags->{"S1.7.3", "3.24"}],

Cell[TextData[{
  "The first argument in the option ",
  StyleBox["Taper", "MR"],
  " specifies the taper function and the second specifies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " as is explained below."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.25"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[WindowFunction[t, 3,
Taper -> {Trig[2], 1}]], {t, -1, 4},
AspectRatio -> Automatic]\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.00476191 0.190476 [
[.02381 -0.00774 -6 -9 ]
[.02381 -0.00774 6 0 ]
[.40476 -0.00774 -3 -9 ]
[.40476 -0.00774 3 0 ]
[.59524 -0.00774 -3 -9 ]
[.59524 -0.00774 3 0 ]
[.78571 -0.00774 -3 -9 ]
[.78571 -0.00774 3 0 ]
[.97619 -0.00774 -3 -9 ]
[.97619 -0.00774 3 0 ]
[.20179 .04286 -18 -4.5 ]
[.20179 .04286 0 4.5 ]
[.20179 .08095 -18 -4.5 ]
[.20179 .08095 0 4.5 ]
[.20179 .11905 -18 -4.5 ]
[.20179 .11905 0 4.5 ]
[.20179 .15714 -18 -4.5 ]
[.20179 .15714 0 4.5 ]
[.20179 .19524 -6 -4.5 ]
[.20179 .19524 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .00476 m
.02381 .01101 L
s
[(-1)] .02381 -0.00774 0 1 Mshowa
.40476 .00476 m
.40476 .01101 L
s
[(1)] .40476 -0.00774 0 1 Mshowa
.59524 .00476 m
.59524 .01101 L
s
[(2)] .59524 -0.00774 0 1 Mshowa
.78571 .00476 m
.78571 .01101 L
s
[(3)] .78571 -0.00774 0 1 Mshowa
.97619 .00476 m
.97619 .01101 L
s
[(4)] .97619 -0.00774 0 1 Mshowa
.125 Mabswid
.0619 .00476 m
.0619 .00851 L
s
.1 .00476 m
.1 .00851 L
s
.1381 .00476 m
.1381 .00851 L
s
.17619 .00476 m
.17619 .00851 L
s
.25238 .00476 m
.25238 .00851 L
s
.29048 .00476 m
.29048 .00851 L
s
.32857 .00476 m
.32857 .00851 L
s
.36667 .00476 m
.36667 .00851 L
s
.44286 .00476 m
.44286 .00851 L
s
.48095 .00476 m
.48095 .00851 L
s
.51905 .00476 m
.51905 .00851 L
s
.55714 .00476 m
.55714 .00851 L
s
.63333 .00476 m
.63333 .00851 L
s
.67143 .00476 m
.67143 .00851 L
s
.70952 .00476 m
.70952 .00851 L
s
.74762 .00476 m
.74762 .00851 L
s
.82381 .00476 m
.82381 .00851 L
s
.8619 .00476 m
.8619 .00851 L
s
.9 .00476 m
.9 .00851 L
s
.9381 .00476 m
.9381 .00851 L
s
.25 Mabswid
0 .00476 m
1 .00476 L
s
.21429 .04286 m
.22054 .04286 L
s
[(0.2)] .20179 .04286 1 0 Mshowa
.21429 .08095 m
.22054 .08095 L
s
[(0.4)] .20179 .08095 1 0 Mshowa
.21429 .11905 m
.22054 .11905 L
s
[(0.6)] .20179 .11905 1 0 Mshowa
.21429 .15714 m
.22054 .15714 L
s
[(0.8)] .20179 .15714 1 0 Mshowa
.21429 .19524 m
.22054 .19524 L
s
[(1)] .20179 .19524 1 0 Mshowa
.125 Mabswid
.21429 .01429 m
.21804 .01429 L
s
.21429 .02381 m
.21804 .02381 L
s
.21429 .03333 m
.21804 .03333 L
s
.21429 .05238 m
.21804 .05238 L
s
.21429 .0619 m
.21804 .0619 L
s
.21429 .07143 m
.21804 .07143 L
s
.21429 .09048 m
.21804 .09048 L
s
.21429 .1 m
.21804 .1 L
s
.21429 .10952 m
.21804 .10952 L
s
.21429 .12857 m
.21804 .12857 L
s
.21429 .1381 m
.21804 .1381 L
s
.21429 .14762 m
.21804 .14762 L
s
.21429 .16667 m
.21804 .16667 L
s
.21429 .17619 m
.21804 .17619 L
s
.21429 .18571 m
.21804 .18571 L
s
.25 Mabswid
.21429 0 m
.21429 .2 L
s
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
.5 Mabswid
.02381 .00476 m
.02499 .00476 L
.02605 .00476 L
.02729 .00476 L
.02846 .00476 L
.02954 .00476 L
.03053 .00476 L
.03163 .00476 L
.03279 .00476 L
.03395 .00476 L
.0352 .00477 L
.03638 .00477 L
.03746 .00477 L
.03873 .00477 L
.04011 .00478 L
.04141 .00478 L
.04262 .00479 L
.04521 .00481 L
.04765 .00483 L
.04984 .00486 L
.05221 .0049 L
.05481 .00496 L
.05754 .00503 L
.06244 .00523 L
.06507 .00537 L
.06746 .00552 L
.07283 .00596 L
.07781 .00651 L
.08253 .0072 L
.08802 .00821 L
.09309 .00939 L
.09862 .01099 L
.10458 .01311 L
.11421 .01755 L
.12324 .02299 L
.14385 .04058 L
.16389 .06468 L
.18499 .0956 L
.22309 .15093 L
.24271 .17144 L
.25368 .17961 L
.26366 .1851 L
.2685 .18717 L
.27364 .189 L
.28284 .19145 L
.28796 .19243 L
.29274 .19316 L
.298 .19377 L
.30364 .19425 L
.30889 .19457 L
Mistroke
.31377 .19479 L
.31658 .19488 L
.31912 .19495 L
.32209 .19502 L
.32481 .19507 L
.32979 .19513 L
.33241 .19516 L
.33517 .19518 L
.33758 .19519 L
.33982 .1952 L
.34228 .19521 L
.34491 .19522 L
.34749 .19523 L
.35022 .19523 L
.35255 .19523 L
.35511 .19523 L
.35655 .19523 L
.35787 .19524 L
.35928 .19524 L
.36083 .19524 L
.36345 .19524 L
.36487 .19524 L
.36619 .19524 L
.36746 .19524 L
.36882 .19524 L
.37011 .19524 L
.3713 .19524 L
.37237 .19524 L
.37355 .19524 L
.37478 .19524 L
.37593 .19524 L
.37728 .19524 L
.37856 .19524 L
.3797 .19524 L
.38095 .19524 L
.38159 .19524 L
.3823 .19524 L
.38299 .19524 L
.38374 .19524 L
.38444 .19524 L
.38507 .19524 L
.38633 .19524 L
.3876 .19524 L
.3888 .19524 L
.38989 .19524 L
.39106 .19524 L
.39233 .19524 L
.39298 .19524 L
.39369 .19524 L
.39494 .19524 L
Mistroke
.39611 .19524 L
.39729 .19524 L
.39841 .19524 L
.39941 .19524 L
.40051 .19524 L
.40169 .19524 L
.40296 .19524 L
.40415 .19524 L
.40523 .19524 L
.42592 .19524 L
.46601 .19524 L
.50458 .19524 L
.5456 .19524 L
.56604 .19524 L
.57601 .19524 L
.58511 .19524 L
.58962 .19524 L
.592 .19524 L
.59453 .19524 L
.59559 .19524 L
.59673 .19524 L
.59799 .19524 L
.59916 .19524 L
.60025 .19524 L
.6014 .19524 L
.60238 .19524 L
.60345 .19524 L
.60408 .19524 L
.60478 .19524 L
.60603 .19524 L
.60725 .19524 L
.60837 .19524 L
.60959 .19524 L
.61028 .19524 L
.61093 .19524 L
.61223 .19524 L
.61296 .19524 L
.61363 .19524 L
.61484 .19524 L
.61596 .19524 L
.61718 .19524 L
.61849 .19524 L
.61974 .19524 L
.62091 .19524 L
.62196 .19524 L
.6231 .19524 L
.62435 .19524 L
.62548 .19524 L
.6268 .19524 L
.62804 .19524 L
Mistroke
.62918 .19524 L
.63024 .19524 L
.63264 .19524 L
.63388 .19524 L
.63505 .19524 L
.63644 .19524 L
.63771 .19524 L
.6403 .19524 L
.64173 .19524 L
.64309 .19523 L
.64562 .19523 L
.64703 .19523 L
.64832 .19523 L
.65082 .19523 L
.65317 .19522 L
.65592 .19522 L
.65845 .19521 L
.66124 .1952 L
.66417 .19518 L
.66672 .19517 L
.66913 .19515 L
.67365 .19509 L
.67617 .19505 L
.67851 .19501 L
.6838 .19487 L
.68803 .19472 L
.69269 .19449 L
.69756 .19416 L
.70213 .19375 L
.70683 .19321 L
.71196 .19245 L
.71732 .19142 L
.72231 .1902 L
.73125 .18727 L
.74081 .18286 L
.75104 .17638 L
.76214 .16707 L
.78229 .14405 L
.8232 .08316 L
.84355 .05499 L
.8535 .04339 L
.86259 .03428 L
.87132 .02691 L
.88085 .02036 L
.89091 .01503 L
.90047 .01129 L
.90579 .00969 L
.9108 .00846 L
.91536 .00755 L
.92017 .00679 L
Mistroke
.92542 .00614 L
.93025 .00569 L
.93545 .00534 L
.9384 .00519 L
.94115 .00508 L
.94567 .00495 L
.94822 .00489 L
.95057 .00485 L
.95263 .00483 L
.9549 .00481 L
.95604 .0048 L
.95727 .00479 L
.95842 .00478 L
.95949 .00478 L
.96152 .00477 L
.96259 .00477 L
.96374 .00477 L
.96494 .00477 L
.96608 .00476 L
.9671 .00476 L
.96821 .00476 L
.96917 .00476 L
.97023 .00476 L
.97133 .00476 L
.97236 .00476 L
.97333 .00476 L
.97421 .00476 L
.97523 .00476 L
.97619 .00476 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell[TextData[{
  "Condition (iii) involves the adjacent windows. It says that the two \
adjacent windows in the overlapping region are symmetric about the endpoint ",
  
  Cell[BoxData[
      \(TraditionalForm\`a\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". In other words, the tail end of the window ",
  Cell[BoxData[
      \(TraditionalForm\`j - 1\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " is the reflection of the beginning of the window ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". \nTo specify a window as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", we need to specify the following: (i) the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([a\_j, a\_\(j + 1\)]\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  "; since the window can be translated, we need only to specify the interval \
length ",
  Cell[BoxData[
      \(TraditionalForm\`L = a\_\(j + 1\) - a\_j\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ", and (ii) the taper function and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " which we call the \"taper width\". The function"
}], "Text",
  CellTags->{"S1.7.3", "3.26"}],

Cell[TextData[{
  StyleBox["WindowFunction[", "MR"],
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["L", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.3", "3.27"}],

Cell[TextData[{
  "gives the window function over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, L]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " with the default taper. The taper is specified by the option ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["{taperf,", "MR"],
  " ",
  StyleBox["epsilon}", "MR"],
  ", that is, the first argument specifies the taper function, and the second \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". "
}], "Text",
  CellTags->{"S1.7.3", "3.28"}],

Cell[TextData[{
  "The default taper function is ",
  StyleBox["Polynomial[2]", "MR"],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\(t\^3\) \((10 - 15  t + 6  t\^2)\)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " and the default for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " is ",
  StyleBox["Automatic", "MR"],
  ", which is ",
  Cell[BoxData[
      \(TraditionalForm\`L/4\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.29"}],

Cell[CellGroupData[{

Cell["Options[WindowFunction]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S1.7.3"],

Cell[BoxData[
    \({Taper \[Rule] {Polynomial[2], Automatic}}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S1.7.3"]
}, Open  ]],

Cell[TextData[{
  "To use the sine taper function, we set ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.7.3"],
  StyleBox["Trig[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["],", "MR"],
  " ",
  StyleBox["epsilon", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " specifies how many times the sine function is to be iterated. For \
example, ",
  StyleBox["Trig[2]", "MR"],
  " is the function ",
  Cell[BoxData[
      \(TraditionalForm
      \`sin \( \[Pi]\/2\) \(sin\^2\) \(\[Pi]\/2\) \(sin\^2\) \(\[Pi]\/2\) t
        \)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". A rectangular window is obtained by setting ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["False", "MR"],
  ". \nWindows do not have to be symmetric. To get an asymmetric window we \
need to specify both left and right taper functions. This is done by setting \
the option ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.7.3"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.7.3"],
  StyleBox["taperL", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"epsilon\\\\\\\"\\\", \\\"TI\\\"]\
\\)\"\>", "L"], TraditionalForm]], "InlineFormula",
    CellTags->"S1.7.3"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.7.3"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.7.3"],
  StyleBox["taperR", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"epsilon\\\\\\\"\\\", \\\"TI\\\"]\
\\)\"\>", "R"], TraditionalForm]], "InlineFormula",
    CellTags->"S1.7.3"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.7.3"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.7.3"],
  ". "
}], "Text",
  CellTags->{"S1.7.3", "3.30"}],

Cell["\<\
Here we plot an asymmetric window and display parts of its two \
adjacent windows. \
\>", "MathCaption",
  CellTags->{"S1.7.3", "3.31"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{WindowFunction[t, 4,
Taper->{{Trig[2], 1}, {Polynomial[5], 2}}],
WindowFunction[t+4, 3,
Taper->{{Polynomial[2], 1}, {Trig[2], 1}}],
WindowFunction[t-4, 4,
Taper->{{Polynomial[5], 2}, {Trig[3], 1}}]}],
{t, -2, 6}, AspectRatio -> Automatic,
PlotStyle -> {GrayLevel[0], GrayLevel[2/3], GrayLevel[2/3]}]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.119048 0.00297619 0.119048 [
[.02381 -0.00952 -6 -9 ]
[.02381 -0.00952 6 0 ]
[.5 -0.00952 -3 -9 ]
[.5 -0.00952 3 0 ]
[.7381 -0.00952 -3 -9 ]
[.7381 -0.00952 3 0 ]
[.97619 -0.00952 -3 -9 ]
[.97619 -0.00952 3 0 ]
[.2494 .02679 -18 -4.5 ]
[.2494 .02679 0 4.5 ]
[.2494 .0506 -18 -4.5 ]
[.2494 .0506 0 4.5 ]
[.2494 .0744 -18 -4.5 ]
[.2494 .0744 0 4.5 ]
[.2494 .09821 -18 -4.5 ]
[.2494 .09821 0 4.5 ]
[.2494 .12202 -6 -4.5 ]
[.2494 .12202 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .00298 m
.02381 .00923 L
s
[(-2)] .02381 -0.00952 0 1 Mshowa
.5 .00298 m
.5 .00923 L
s
[(2)] .5 -0.00952 0 1 Mshowa
.7381 .00298 m
.7381 .00923 L
s
[(4)] .7381 -0.00952 0 1 Mshowa
.97619 .00298 m
.97619 .00923 L
s
[(6)] .97619 -0.00952 0 1 Mshowa
.125 Mabswid
.08333 .00298 m
.08333 .00673 L
s
.14286 .00298 m
.14286 .00673 L
s
.20238 .00298 m
.20238 .00673 L
s
.32143 .00298 m
.32143 .00673 L
s
.38095 .00298 m
.38095 .00673 L
s
.44048 .00298 m
.44048 .00673 L
s
.55952 .00298 m
.55952 .00673 L
s
.61905 .00298 m
.61905 .00673 L
s
.67857 .00298 m
.67857 .00673 L
s
.79762 .00298 m
.79762 .00673 L
s
.85714 .00298 m
.85714 .00673 L
s
.91667 .00298 m
.91667 .00673 L
s
.25 Mabswid
0 .00298 m
1 .00298 L
s
.2619 .02679 m
.26815 .02679 L
s
[(0.2)] .2494 .02679 1 0 Mshowa
.2619 .0506 m
.26815 .0506 L
s
[(0.4)] .2494 .0506 1 0 Mshowa
.2619 .0744 m
.26815 .0744 L
s
[(0.6)] .2494 .0744 1 0 Mshowa
.2619 .09821 m
.26815 .09821 L
s
[(0.8)] .2494 .09821 1 0 Mshowa
.2619 .12202 m
.26815 .12202 L
s
[(1)] .2494 .12202 1 0 Mshowa
.125 Mabswid
.2619 .00893 m
.26565 .00893 L
s
.2619 .01488 m
.26565 .01488 L
s
.2619 .02083 m
.26565 .02083 L
s
.2619 .03274 m
.26565 .03274 L
s
.2619 .03869 m
.26565 .03869 L
s
.2619 .04464 m
.26565 .04464 L
s
.2619 .05655 m
.26565 .05655 L
s
.2619 .0625 m
.26565 .0625 L
s
.2619 .06845 m
.26565 .06845 L
s
.2619 .08036 m
.26565 .08036 L
s
.2619 .08631 m
.26565 .08631 L
s
.2619 .09226 m
.26565 .09226 L
s
.2619 .10417 m
.26565 .10417 L
s
.2619 .11012 m
.26565 .11012 L
s
.2619 .11607 m
.26565 .11607 L
s
.25 Mabswid
.2619 0 m
.2619 .125 L
s
0 0 m
1 0 L
1 .125 L
0 .125 L
closepath
clip
newpath
.5 Mabswid
.02381 .00298 m
.06244 .00298 L
.08255 .00298 L
.10458 .00298 L
.11448 .00298 L
.12507 .00298 L
.1302 .00298 L
.13506 .00298 L
.13942 .00298 L
.14061 .00298 L
.14188 .00298 L
.14296 .00298 L
.14415 .00298 L
.14544 .00298 L
.14664 .00298 L
.14795 .00298 L
.14868 .00298 L
.14935 .00298 L
.15057 .00298 L
.15189 .00298 L
.15314 .00299 L
.15429 .00299 L
.1554 .003 L
.15644 .00301 L
.15758 .00302 L
.1588 .00303 L
.16008 .00305 L
.16129 .00308 L
.16356 .00313 L
.16608 .00323 L
.16876 .00336 L
.17104 .00351 L
.17356 .00373 L
.17626 .00403 L
.17917 .00444 L
.18444 .00545 L
.1894 .0068 L
.19401 .00847 L
.19907 .01082 L
.20448 .01402 L
.21553 .02301 L
.22558 .03415 L
.24638 .06405 L
.25551 .078 L
.26556 .09201 L
.27457 .10239 L
.28425 .11072 L
.28959 .11407 L
.29447 .11644 L
.29937 .11824 L
Mistroke
.30403 .1195 L
.30663 .12003 L
.30907 .12045 L
.31364 .12104 L
.3162 .12129 L
.31856 .12146 L
.32114 .12161 L
.32387 .12173 L
.32607 .12181 L
.32842 .12187 L
.33063 .12191 L
.33265 .12194 L
.33502 .12197 L
.33636 .12198 L
.33759 .12199 L
.33986 .122 L
.34101 .12201 L
.34227 .12201 L
.34463 .12201 L
.34597 .12202 L
.34721 .12202 L
.34852 .12202 L
.34971 .12202 L
.35109 .12202 L
.35239 .12202 L
.35352 .12202 L
.35471 .12202 L
.35572 .12202 L
.35684 .12202 L
.35804 .12202 L
.35933 .12202 L
.36055 .12202 L
.36166 .12202 L
.36295 .12202 L
.3636 .12202 L
.36432 .12202 L
.36559 .12202 L
.36679 .12202 L
.36747 .12202 L
.36819 .12202 L
.36947 .12202 L
.37019 .12202 L
.37086 .12202 L
.37159 .12202 L
.37237 .12202 L
.37368 .12202 L
.37442 .12202 L
.37511 .12202 L
.37636 .12202 L
.37699 .12202 L
Mistroke
.37769 .12202 L
.37889 .12202 L
.38019 .12202 L
.38141 .12202 L
.38253 .12202 L
.42226 .12202 L
.46047 .12202 L
.4818 .12202 L
.49187 .12202 L
.49629 .12202 L
.4988 .12202 L
.50002 .12202 L
.50113 .12202 L
.5023 .12202 L
.50341 .12202 L
.50458 .12202 L
.50585 .12202 L
.5071 .12202 L
.50773 .12202 L
.50843 .12202 L
.50967 .12202 L
.51082 .12202 L
.51211 .12202 L
.51275 .12202 L
.51345 .12202 L
.5147 .12202 L
.51587 .12202 L
.51657 .12202 L
.51724 .12202 L
.51849 .12202 L
.51984 .12202 L
.5213 .12202 L
.52248 .12202 L
.52359 .12202 L
.5248 .12202 L
.5261 .12202 L
.52746 .12202 L
.52875 .12202 L
.53118 .12202 L
.53344 .12202 L
.53554 .12202 L
.53784 .12202 L
.54028 .12202 L
.5429 .12201 L
.54567 .12201 L
.54802 .12201 L
.55061 .122 L
.55339 .12199 L
.55638 .12198 L
.56175 .12195 L
Mistroke
.56436 .12193 L
.56718 .12191 L
.57232 .12185 L
.57732 .12178 L
.58194 .1217 L
.58659 .12159 L
.5916 .12145 L
.60066 .12111 L
.60617 .12083 L
.61142 .12052 L
.62128 .11977 L
.63086 .11882 L
.64107 .11753 L
.65946 .11437 L
.68086 .1092 L
.70103 .10275 L
.73957 .08645 L
.78056 .06494 L
.82003 .0432 L
.85799 .02467 L
.87913 .01645 L
.8984 .01065 L
.90797 .00841 L
.91837 .00646 L
.9282 .00507 L
.9373 .00414 L
.94189 .00379 L
.94683 .0035 L
.9515 .00329 L
.95578 .00316 L
.95824 .0031 L
.96053 .00306 L
.96304 .00303 L
.96444 .00301 L
.96572 .003 L
.96707 .00299 L
.96831 .00299 L
.96967 .00298 L
.97035 .00298 L
.97111 .00298 L
.97237 .00298 L
.97308 .00298 L
.97373 .00298 L
.97499 .00298 L
.97619 .00298 L
Mfstroke
.667 g
.02381 .12202 m
.02499 .12202 L
.02605 .12202 L
.02729 .12202 L
.02846 .12202 L
.02954 .12202 L
.03053 .12202 L
.03163 .12202 L
.03279 .12202 L
.03395 .12202 L
.0352 .12202 L
.03638 .12202 L
.03746 .12202 L
.03873 .12202 L
.03944 .12202 L
.04011 .12202 L
.04132 .12202 L
.04262 .12202 L
.04327 .12202 L
.04396 .12202 L
.04519 .12202 L
.04588 .12202 L
.04652 .12202 L
.04726 .12202 L
.04797 .12202 L
.04925 .12202 L
.05041 .12202 L
.05166 .12202 L
.05302 .12202 L
.05414 .12202 L
.05539 .12202 L
.05669 .12202 L
.05791 .12202 L
.06009 .12201 L
.06132 .12201 L
.06244 .12201 L
.0649 .122 L
.06627 .12199 L
.06752 .12199 L
.06995 .12197 L
.07225 .12194 L
.07492 .1219 L
.07739 .12184 L
.0801 .12176 L
.08297 .12164 L
.08553 .1215 L
.08829 .12131 L
.09089 .12107 L
.09326 .1208 L
.09604 .1204 L
Mistroke
.09907 .11985 L
.10172 .11926 L
.10458 .11849 L
.10991 .1166 L
.11492 .11421 L
.11981 .11122 L
.12429 .10783 L
.1345 .09772 L
.14528 .08378 L
.16518 .05363 L
.1833 .02925 L
.19335 .01926 L
.20285 .01241 L
.20806 .00964 L
.21288 .00764 L
.21817 .00598 L
.2209 .00532 L
.22378 .00474 L
.22612 .00435 L
.22868 .00401 L
.23104 .00375 L
.23317 .00356 L
.23571 .00338 L
.23842 .00324 L
.24092 .00314 L
.24205 .00311 L
.24329 .00308 L
.24551 .00304 L
.24673 .00302 L
.24786 .00301 L
.2489 .003 L
.24989 .00299 L
.25103 .00299 L
.25207 .00298 L
.25322 .00298 L
.25444 .00298 L
.25548 .00298 L
.25662 .00298 L
.25785 .00298 L
.25855 .00298 L
.25918 .00298 L
.26035 .00298 L
.26158 .00298 L
.26281 .00298 L
.26351 .00298 L
.26415 .00298 L
.26657 .00298 L
.27111 .00298 L
.2813 .00298 L
.29966 .00298 L
Mistroke
.33903 .00298 L
.37688 .00298 L
.41719 .00298 L
.45598 .00298 L
.49723 .00298 L
.53695 .00298 L
.57517 .00298 L
.61583 .00298 L
.65498 .00298 L
.69658 .00298 L
.73667 .00298 L
.77524 .00298 L
.81627 .00298 L
.85577 .00298 L
.89376 .00298 L
.93421 .00298 L
.97314 .00298 L
.97619 .00298 L
Mfstroke
.02381 .00298 m
.06244 .00298 L
.10458 .00298 L
.14415 .00298 L
.18221 .00298 L
.22272 .00298 L
.26171 .00298 L
.30316 .00298 L
.34309 .00298 L
.3815 .00298 L
.42237 .00298 L
.46172 .00298 L
.48147 .00298 L
.49012 .00298 L
.49468 .00298 L
.49719 .00298 L
.49842 .00298 L
.49955 .00298 L
.50085 .00298 L
.50154 .00298 L
.50226 .00298 L
.50343 .00298 L
.50471 .00298 L
.50591 .00298 L
.50719 .00298 L
.5084 .00299 L
.5095 .003 L
.51183 .00301 L
.51314 .00303 L
.51436 .00304 L
.51659 .00308 L
.51896 .00312 L
.52142 .00319 L
.52408 .00327 L
.52888 .00348 L
.5346 .00381 L
.53984 .00422 L
.54964 .00527 L
.55876 .00662 L
.56877 .00853 L
.57946 .01108 L
.60081 .01777 L
.62096 .02587 L
.65943 .04495 L
.70035 .06754 L
.73975 .08794 L
.77764 .10362 L
.79708 .10968 L
.81798 .11462 L
.82811 .11646 L
Mistroke
.83915 .11808 L
.84958 .11928 L
.85925 .12013 L
.86985 .12082 L
.87504 .12109 L
.87982 .12129 L
.88877 .12157 L
.89347 .12168 L
.89843 .12178 L
.90341 .12185 L
.90794 .1219 L
.91317 .12194 L
.91557 .12196 L
.91811 .12197 L
.92029 .12198 L
.92268 .12199 L
.92691 .122 L
.92928 .12201 L
.93184 .12201 L
.93425 .12202 L
.93646 .12202 L
.93895 .12202 L
.94121 .12202 L
.94247 .12202 L
.94383 .12202 L
.945 .12202 L
.94629 .12202 L
.9486 .12202 L
.94986 .12202 L
.95104 .12202 L
.95315 .12202 L
.95434 .12202 L
.95542 .12202 L
.9567 .12202 L
.95806 .12202 L
.95923 .12202 L
.96051 .12202 L
.96123 .12202 L
.96189 .12202 L
.96261 .12202 L
.96337 .12202 L
.96465 .12202 L
.96538 .12202 L
.96605 .12202 L
.96737 .12202 L
.96861 .12202 L
.96972 .12202 L
.97093 .12202 L
.97224 .12202 L
.9729 .12202 L
Mistroke
.97364 .12202 L
.97493 .12202 L
.97614 .12202 L
.97619 .12202 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell[TextData[{
  "Because of their localized nature, the local sine and cosine basis \
functions (",
  ButtonBox["7.7",
    ButtonData:>{"Wavelets 1.7.3", "3.19"},
    ButtonStyle->"AddOnsLink"],
  ") and (",
  ButtonBox["7.6",
    ButtonData:>{"Wavelets 1.7.3", "3.17"},
    ButtonStyle->"AddOnsLink"],
  ") are also called sine packets and cosine packets, respectively. The \
functions "
}], "Text",
  CellTags->{"S1.7.3", "3.32"}],

Cell[TextData[{
  StyleBox["CosPacket[", "MR"],
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["L", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["k", "TI"],
  StyleBox["]", "MR"],
  "  and  ",
  StyleBox["SinPacket[", "MR"],
  StyleBox["t", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["L", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["k", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.3", "3.33"}],

Cell[TextData[{
  "give the cosine packet ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\@\(2\/L\)\) b \((t)\) cos \( \[Pi]\/L\) \((k + 1\/2)\) t}\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " and the sine packet ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\@\(2\/L\)\) b \((t)\) sin \( \[Pi]\/L\) \((k + 1\/2)\) t}\)], 
    "InlineFormula",
    CellTags->"S1.7.3"],
  " with the default window, respectively. "
}], "Text",
  CellTags->{"S1.7.3", "3.34"}],

Cell[TextData[{
  "This is a cosine packet over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 1]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " with the frequency index ",
  Cell[BoxData[
      \(TraditionalForm\`k = 10\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.35"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[CosPacket[t, 1, 10,
Taper -> {Polynomial[2], 0.5}]], {t, -1, 2},
AxesLabel->{\"t\", \"\"}, PlotLabel -> \"cosine packet\"]\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.309206 0.20857 [
[.02381 .29671 -6 -9 ]
[.02381 .29671 6 0 ]
[.18254 .29671 -12 -9 ]
[.18254 .29671 12 0 ]
[.5 .29671 -9 -9 ]
[.5 .29671 9 0 ]
[.65873 .29671 -3 -9 ]
[.65873 .29671 3 0 ]
[.81746 .29671 -9 -9 ]
[.81746 .29671 9 0 ]
[.97619 .29671 -3 -9 ]
[.97619 .29671 3 0 ]
[1.025 .30921 0 -4.5 ]
[1.025 .30921 6 4.5 ]
[.32877 .10064 -12 -4.5 ]
[.32877 .10064 0 4.5 ]
[.32877 .20492 -24 -4.5 ]
[.32877 .20492 0 4.5 ]
[.32877 .41349 -18 -4.5 ]
[.32877 .41349 0 4.5 ]
[.32877 .51778 -6 -4.5 ]
[.32877 .51778 0 4.5 ]
[.5 .63053 -39 0 ]
[.5 .63053 39 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30921 m
.02381 .31546 L
s
[(-1)] .02381 .29671 0 1 Mshowa
.18254 .30921 m
.18254 .31546 L
s
[(-0.5)] .18254 .29671 0 1 Mshowa
.5 .30921 m
.5 .31546 L
s
[(0.5)] .5 .29671 0 1 Mshowa
.65873 .30921 m
.65873 .31546 L
s
[(1)] .65873 .29671 0 1 Mshowa
.81746 .30921 m
.81746 .31546 L
s
[(1.5)] .81746 .29671 0 1 Mshowa
.97619 .30921 m
.97619 .31546 L
s
[(2)] .97619 .29671 0 1 Mshowa
.125 Mabswid
.05556 .30921 m
.05556 .31296 L
s
.0873 .30921 m
.0873 .31296 L
s
.11905 .30921 m
.11905 .31296 L
s
.15079 .30921 m
.15079 .31296 L
s
.21429 .30921 m
.21429 .31296 L
s
.24603 .30921 m
.24603 .31296 L
s
.27778 .30921 m
.27778 .31296 L
s
.30952 .30921 m
.30952 .31296 L
s
.37302 .30921 m
.37302 .31296 L
s
.40476 .30921 m
.40476 .31296 L
s
.43651 .30921 m
.43651 .31296 L
s
.46825 .30921 m
.46825 .31296 L
s
.53175 .30921 m
.53175 .31296 L
s
.56349 .30921 m
.56349 .31296 L
s
.59524 .30921 m
.59524 .31296 L
s
.62698 .30921 m
.62698 .31296 L
s
.69048 .30921 m
.69048 .31296 L
s
.72222 .30921 m
.72222 .31296 L
s
.75397 .30921 m
.75397 .31296 L
s
.78571 .30921 m
.78571 .31296 L
s
.84921 .30921 m
.84921 .31296 L
s
.88095 .30921 m
.88095 .31296 L
s
.9127 .30921 m
.9127 .31296 L
s
.94444 .30921 m
.94444 .31296 L
s
.25 Mabswid
0 .30921 m
1 .30921 L
s
[(t)] 1.025 .30921 -1 0 Mshowa
.34127 .10064 m
.34752 .10064 L
s
[(-1)] .32877 .10064 1 0 Mshowa
.34127 .20492 m
.34752 .20492 L
s
[(-0.5)] .32877 .20492 1 0 Mshowa
.34127 .41349 m
.34752 .41349 L
s
[(0.5)] .32877 .41349 1 0 Mshowa
.34127 .51778 m
.34752 .51778 L
s
[(1)] .32877 .51778 1 0 Mshowa
.125 Mabswid
.34127 .01721 m
.34502 .01721 L
s
.34127 .03806 m
.34502 .03806 L
s
.34127 .05892 m
.34502 .05892 L
s
.34127 .07978 m
.34502 .07978 L
s
.34127 .12149 m
.34502 .12149 L
s
.34127 .14235 m
.34502 .14235 L
s
.34127 .16321 m
.34502 .16321 L
s
.34127 .18406 m
.34502 .18406 L
s
.34127 .22578 m
.34502 .22578 L
s
.34127 .24663 m
.34502 .24663 L
s
.34127 .26749 m
.34502 .26749 L
s
.34127 .28835 m
.34502 .28835 L
s
.34127 .33006 m
.34502 .33006 L
s
.34127 .35092 m
.34502 .35092 L
s
.34127 .37178 m
.34502 .37178 L
s
.34127 .39263 m
.34502 .39263 L
s
.34127 .43435 m
.34502 .43435 L
s
.34127 .45521 m
.34502 .45521 L
s
.34127 .47606 m
.34502 .47606 L
s
.34127 .49692 m
.34502 .49692 L
s
.34127 .53863 m
.34502 .53863 L
s
.34127 .55949 m
.34502 .55949 L
s
.34127 .58035 m
.34502 .58035 L
s
.34127 .6012 m
.34502 .6012 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(cosine packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30921 m
.06244 .30921 L
.10458 .30921 L
.14415 .30921 L
.16408 .30921 L
.17277 .30921 L
.17735 .30921 L
.17986 .30921 L
.18109 .30921 L
.18221 .30921 L
.18341 .3091 L
.1847 .30877 L
.18537 .30852 L
.1861 .3082 L
.18744 .30751 L
.19227 .30444 L
.1935 .30374 L
.19466 .30319 L
.1953 .30296 L
.19599 .30276 L
.1972 .30259 L
.19836 .30268 L
.19959 .30306 L
.20063 .30364 L
.20178 .30456 L
.20318 .30612 L
.20451 .30803 L
.20701 .31268 L
.21261 .32676 L
.21741 .33895 L
.21873 .34159 L
.21942 .34278 L
.22015 .34387 L
.22079 .34466 L
.22149 .34535 L
.22272 .34607 L
.22398 .34609 L
.22513 .34542 L
.22577 .34476 L
.22646 .34381 L
.22772 .34142 L
.22889 .33841 L
.23014 .33442 L
.23237 .32531 L
.23725 .29837 L
.24263 .26445 L
.24498 .25115 L
.24721 .24083 L
.24845 .23643 L
.2491 .23454 L
Mistroke
.24979 .23287 L
.25101 .23087 L
.25214 .23016 L
.2533 .23063 L
.25455 .23253 L
.25573 .2357 L
.25682 .23977 L
.25887 .25052 L
.26105 .26583 L
.27055 .36156 L
.27329 .38895 L
.27587 .41053 L
.277 .41807 L
.2782 .42461 L
.27951 .42987 L
.28072 .4328 L
.28186 .43377 L
.28289 .4331 L
.28403 .43064 L
.28523 .42607 L
.28627 .42042 L
.28725 .41384 L
.28945 .39436 L
.2941 .33613 L
.29907 .26061 L
.30406 .19065 L
.30658 .16431 L
.308 .15325 L
.30864 .14934 L
.30934 .14585 L
.31009 .14302 L
.3108 .14126 L
.31149 .14041 L
.31213 .14042 L
.31282 .14128 L
.31358 .14326 L
.31438 .1465 L
.31513 .15061 L
.31646 .16051 L
.31769 .17236 L
.32046 .20797 L
.3255 .2965 L
.3309 .4017 L
.33352 .4469 L
.33599 .48153 L
.33707 .49346 L
.33821 .50372 L
.33946 .51192 L
.34062 .5165 L
.34179 .51811 L
Mistroke
.34286 .51686 L
.34409 .51217 L
.34527 .5045 L
.34635 .49476 L
.34735 .48349 L
.34962 .45061 L
.35441 .35489 L
.35952 .2357 L
.36221 .17692 L
.36511 .1236 L
.36645 .10411 L
.36785 .08761 L
.36906 .07715 L
.37038 .06977 L
.37166 .06687 L
.37283 .06801 L
.37348 .07019 L
.37418 .07382 L
.37546 .0837 L
.37666 .09667 L
.37793 .1142 L
.38021 .15447 L
.38959 .38775 L
.39452 .50116 L
.39699 .54203 L
.39767 .55072 L
.39839 .55871 L
.3997 .56956 L
.40093 .57547 L
.40163 .57688 L
.40227 .57693 L
.40345 .57392 L
.4047 .56635 L
.40582 .55583 L
.40686 .54291 L
.40924 .50323 L
.41346 .40447 L
.41798 .27674 L
.4229 .14454 L
.42564 .08629 L
.42693 .06467 L
.42812 .04865 L
.4288 .04125 L
.42954 .03467 L
.43029 .0297 L
.43108 .02627 L
.43177 .02482 L
.43252 .02491 L
.43322 .02656 L
.43386 .02938 L
Mistroke
.43517 .03902 L
.43591 .04671 L
.43659 .05521 L
.43917 .09867 L
.44157 .1529 L
.44382 .21285 L
.44893 .36438 L
.45153 .4386 L
.4543 .50761 L
.45564 .53563 L
.45691 .55804 L
.45806 .5747 L
.45928 .58819 L
.46052 .59734 L
.46166 .60154 L
.46289 .60146 L
.46359 .5993 L
.46424 .59589 L
.46494 .59075 L
.4656 .58449 L
.46685 .56922 L
.46819 .5479 L
.46965 .51941 L
.47478 .38623 L
.47952 .24266 L
.48175 .17854 L
.48415 .11727 L
.48627 .07301 L
.48742 .05355 L
.4885 .03874 L
.48963 .02682 L
.49086 .01824 L
.49191 .01472 L
.49303 .01481 L
.49368 .01669 L
.49438 .02022 L
.49565 .03053 L
.49689 .04527 L
.49804 .06274 L
.50048 .11126 L
.50271 .16677 L
.50773 .31435 L
.51243 .45219 L
.51472 .50889 L
.51679 .5506 L
.51797 .56941 L
.51925 .58535 L
.51995 .59207 L
.52059 .59692 L
.52186 .60267 L
Mistroke
.52314 .60332 L
.52386 .60137 L
.52454 .59804 L
.52526 .59297 L
.52591 .58698 L
.52738 .56893 L
.52866 .54812 L
.52985 .5251 L
.53254 .46157 L
.53743 .32027 L
.54207 .18348 L
.54451 .12171 L
.54584 .09295 L
.54708 .06995 L
.54826 .05166 L
.54933 .03845 L
.55052 .02777 L
.5518 .02116 L
.55287 .01952 L
.55402 .02177 L
.55512 .02771 L
.55612 .03639 L
.55731 .05047 L
.55859 .06993 L
.5609 .11532 L
.56614 .25363 L
.57164 .41299 L
.57406 .47459 L
.57535 .50312 L
.57674 .52986 L
.57806 .55095 L
.57927 .56622 L
.58043 .57693 L
.58165 .58395 L
.58295 .58651 L
.58415 .58438 L
.58547 .5771 L
.58621 .57082 L
.58689 .56378 L
.58961 .52321 L
.59115 .49274 L
.59257 .46063 L
.59794 .31813 L
.60298 .18467 L
.60545 .13091 L
.6077 .09251 L
.60892 .07684 L
.61008 .06548 L
.6113 .05741 L
.61199 .05466 L
Mistroke
.61263 .05329 L
.61334 .05311 L
.61401 .05422 L
.61525 .05956 L
.61595 .06439 L
.6166 .06996 L
.61805 .08633 L
.62051 .12494 L
.62275 .17 L
.62779 .29144 L
.63251 .40579 L
.63459 .4489 L
.63688 .488 L
.63807 .50408 L
.63935 .51789 L
.64005 .52387 L
.6407 .5283 L
.64197 .53402 L
.64325 .53577 L
.64398 .53495 L
.64466 .53303 L
.64538 .52979 L
.64603 .52579 L
.6475 .51333 L
.64879 .49856 L
.64998 .4821 L
.65267 .43642 L
.65755 .33495 L
.66222 .2367 L
.6648 .19071 L
.66607 .17151 L
.66724 .15614 L
.66844 .14315 L
.66951 .13376 L
.67071 .12607 L
.67199 .12115 L
.67306 .11964 L
.67422 .12068 L
.67531 .12417 L
.67632 .12944 L
.67751 .13819 L
.6788 .15033 L
.68111 .17856 L
.68636 .26325 L
.69187 .35802 L
.69429 .39367 L
.69557 .40995 L
.69696 .42502 L
.69829 .43692 L
.69951 .44541 L
Mistroke
.70074 .45151 L
.70191 .45502 L
.70321 .45629 L
.70442 .45502 L
.70512 .45324 L
.70575 .45099 L
.70716 .44384 L
.70859 .43387 L
.7099 .42252 L
.71287 .39071 L
.71824 .3216 L
.72069 .29052 L
.7233 .2606 L
.72573 .23778 L
.72803 .22163 L
.72927 .21541 L
.72996 .21268 L
.73061 .21067 L
.73175 .20832 L
.73296 .20749 L
.7336 .20773 L
.73429 .2085 L
.73554 .2112 L
.73626 .21349 L
.73702 .21645 L
.73838 .22303 L
.74095 .2393 L
.74337 .25803 L
.74791 .2966 L
.75049 .31752 L
.75321 .3368 L
.75554 .34991 L
.75688 .3558 L
.7581 .36007 L
.75923 .36302 L
.76029 .36497 L
.76142 .36613 L
.76265 .36637 L
.76372 .36575 L
.76486 .36431 L
.76593 .36225 L
.76691 .35987 L
.76927 .35234 L
.77183 .3422 L
.77646 .32199 L
.78106 .30444 L
.78238 .30046 L
.78363 .29725 L
.78477 .29481 L
.78598 .29276 L
Mistroke
.78662 .29189 L
.78733 .2911 L
.78857 .29015 L
.78927 .28984 L
.79002 .2897 L
.79073 .28972 L
.79138 .28987 L
.79256 .29043 L
.79384 .29141 L
.79518 .29279 L
.79642 .2943 L
.80167 .30168 L
.80424 .30495 L
.80661 .30728 L
.80794 .30825 L
.80935 .30899 L
.81008 .30927 L
.81076 .30946 L
.81151 .3096 L
.81232 .30968 L
.81298 .30969 L
.8137 .30966 L
.81502 .30952 L
.81623 .30934 L
.81749 .30921 L
.81813 .30921 L
.81883 .30921 L
.82006 .30921 L
.82283 .30921 L
.82785 .30921 L
.83723 .30921 L
.85822 .30921 L
.89872 .30921 L
.93771 .30921 L
.97619 .30921 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell["These two cosine packets are orthogonal.", "MathCaption",
  CellTags->{"S1.7.3", "3.36"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{CosPacket[t, 1, 9,
Taper -> {Polynomial[2], 0.5}],
CosPacket[t-1, 2, 8]}], {t, -1, 4},
PlotPoints -> 30, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"cosine packets\",
PlotStyle -> {GrayLevel[1/2], GrayLevel[0]}]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.309648 0.208642 [
[.02381 .29715 -6 -9 ]
[.02381 .29715 6 0 ]
[.40476 .29715 -3 -9 ]
[.40476 .29715 3 0 ]
[.59524 .29715 -3 -9 ]
[.59524 .29715 3 0 ]
[.78571 .29715 -3 -9 ]
[.78571 .29715 3 0 ]
[.97619 .29715 -3 -9 ]
[.97619 .29715 3 0 ]
[1.025 .30965 0 -4.5 ]
[1.025 .30965 6 4.5 ]
[.20179 .10101 -12 -4.5 ]
[.20179 .10101 0 4.5 ]
[.20179 .20533 -24 -4.5 ]
[.20179 .20533 0 4.5 ]
[.20179 .41397 -18 -4.5 ]
[.20179 .41397 0 4.5 ]
[.20179 .51829 -6 -4.5 ]
[.20179 .51829 0 4.5 ]
[.5 .63053 -42 0 ]
[.5 .63053 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30965 m
.02381 .3159 L
s
[(-1)] .02381 .29715 0 1 Mshowa
.40476 .30965 m
.40476 .3159 L
s
[(1)] .40476 .29715 0 1 Mshowa
.59524 .30965 m
.59524 .3159 L
s
[(2)] .59524 .29715 0 1 Mshowa
.78571 .30965 m
.78571 .3159 L
s
[(3)] .78571 .29715 0 1 Mshowa
.97619 .30965 m
.97619 .3159 L
s
[(4)] .97619 .29715 0 1 Mshowa
.125 Mabswid
.0619 .30965 m
.0619 .3134 L
s
.1 .30965 m
.1 .3134 L
s
.1381 .30965 m
.1381 .3134 L
s
.17619 .30965 m
.17619 .3134 L
s
.25238 .30965 m
.25238 .3134 L
s
.29048 .30965 m
.29048 .3134 L
s
.32857 .30965 m
.32857 .3134 L
s
.36667 .30965 m
.36667 .3134 L
s
.44286 .30965 m
.44286 .3134 L
s
.48095 .30965 m
.48095 .3134 L
s
.51905 .30965 m
.51905 .3134 L
s
.55714 .30965 m
.55714 .3134 L
s
.63333 .30965 m
.63333 .3134 L
s
.67143 .30965 m
.67143 .3134 L
s
.70952 .30965 m
.70952 .3134 L
s
.74762 .30965 m
.74762 .3134 L
s
.82381 .30965 m
.82381 .3134 L
s
.8619 .30965 m
.8619 .3134 L
s
.9 .30965 m
.9 .3134 L
s
.9381 .30965 m
.9381 .3134 L
s
.25 Mabswid
0 .30965 m
1 .30965 L
s
[(t)] 1.025 .30965 -1 0 Mshowa
.21429 .10101 m
.22054 .10101 L
s
[(-1)] .20179 .10101 1 0 Mshowa
.21429 .20533 m
.22054 .20533 L
s
[(-0.5)] .20179 .20533 1 0 Mshowa
.21429 .41397 m
.22054 .41397 L
s
[(0.5)] .20179 .41397 1 0 Mshowa
.21429 .51829 m
.22054 .51829 L
s
[(1)] .20179 .51829 1 0 Mshowa
.125 Mabswid
.21429 .01755 m
.21804 .01755 L
s
.21429 .03841 m
.21804 .03841 L
s
.21429 .05928 m
.21804 .05928 L
s
.21429 .08014 m
.21804 .08014 L
s
.21429 .12187 m
.21804 .12187 L
s
.21429 .14273 m
.21804 .14273 L
s
.21429 .1636 m
.21804 .1636 L
s
.21429 .18446 m
.21804 .18446 L
s
.21429 .22619 m
.21804 .22619 L
s
.21429 .24706 m
.21804 .24706 L
s
.21429 .26792 m
.21804 .26792 L
s
.21429 .28878 m
.21804 .28878 L
s
.21429 .33051 m
.21804 .33051 L
s
.21429 .35138 m
.21804 .35138 L
s
.21429 .37224 m
.21804 .37224 L
s
.21429 .3931 m
.21804 .3931 L
s
.21429 .43483 m
.21804 .43483 L
s
.21429 .4557 m
.21804 .4557 L
s
.21429 .47656 m
.21804 .47656 L
s
.21429 .49743 m
.21804 .49743 L
s
.21429 .53915 m
.21804 .53915 L
s
.21429 .56002 m
.21804 .56002 L
s
.21429 .58088 m
.21804 .58088 L
s
.21429 .60175 m
.21804 .60175 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
[(cosine packets)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 g
.5 Mabswid
.02381 .30965 m
.05578 .30965 L
.07243 .30965 L
.09065 .30965 L
.09885 .30965 L
.10761 .30965 L
.11186 .30965 L
.11395 .30965 L
.11588 .30965 L
.11763 .30965 L
.11851 .30965 L
.11949 .30958 L
.12047 .30933 L
.12152 .30912 L
.12251 .30911 L
.1234 .30932 L
.12446 .30992 L
.12546 .31087 L
.12654 .31232 L
.1277 .31437 L
.13179 .32401 L
.13373 .32845 L
.13471 .3302 L
.13579 .33156 L
.13671 .33212 L
.13769 .33201 L
.13862 .33116 L
.13947 .32968 L
.14054 .32685 L
.14167 .32262 L
.14372 .31207 L
.14834 .27901 L
.15026 .26503 L
.15127 .25854 L
.15233 .25272 L
.1529 .25014 L
.15352 .24779 L
.15461 .24504 L
.15514 .24438 L
.15572 .24421 L
.15674 .24539 L
.15776 .24852 L
.15834 .25117 L
.15889 .25424 L
.15998 .26209 L
.16115 .27289 L
.16522 .32475 L
.16748 .35781 L
.16994 .39083 L
.17106 .40328 L
Mistroke
.17168 .40911 L
.17226 .41386 L
.1728 .41759 L
.17339 .4208 L
.17441 .42421 L
.17546 .42461 L
.17606 .42338 L
.17662 .42125 L
.17721 .41798 L
.17775 .41408 L
.17895 .40222 L
.17998 .38888 L
.1811 .37133 L
.18312 .33278 L
.18723 .24264 L
.18925 .20194 L
.19013 .18654 L
.19109 .172 L
.19197 .16108 L
.19292 .15236 L
.19392 .14676 L
.19484 .14509 L
.19593 .14767 L
.19696 .15465 L
.19789 .16463 L
.19889 .17924 L
.20106 .22325 L
.20336 .2837 L
.20748 .40364 L
.20955 .45615 L
.21069 .4797 L
.21177 .49746 L
.21277 .50941 L
.21386 .51697 L
.21486 .51862 L
.21577 .51559 L
.21686 .50639 L
.21787 .49233 L
.21899 .4712 L
.22019 .44232 L
.22488 .28918 L
.2287 .15974 L
.2298 .12925 L
.23084 .10498 L
.23178 .08756 L
.23279 .07385 L
.23333 .06891 L
.23392 .06544 L
.23454 .06406 L
.23512 .06488 L
Mistroke
.23616 .07145 L
.23674 .07797 L
.23727 .08569 L
.2383 .10503 L
.23941 .13246 L
.24145 .19674 L
.24583 .36943 L
.24824 .46086 L
.24942 .49932 L
.2505 .52932 L
.25153 .55214 L
.25262 .56955 L
.25371 .57953 L
.25433 .5817 L
.25491 .58142 L
.25592 .57554 L
.25684 .56432 L
.2579 .54468 L
.2589 .5199 L
.2669 .20197 L
.26884 .12746 L
.26986 .09444 L
.27094 .0655 L
.27151 .0528 L
.27214 .04126 L
.27271 .03299 L
.27323 .02727 L
.27428 .0217 L
.27486 .02194 L
.27539 .02425 L
.27634 .03336 L
.27735 .04974 L
.27821 .06893 L
.27916 .09513 L
.28324 .25396 L
.28678 .41373 L
.28865 .48867 L
.29064 .55169 L
.29125 .5665 L
.29182 .57832 L
.29288 .5946 L
.29388 .60267 L
.29496 .60332 L
.296 .59601 L
.29652 .58943 L
.2971 .58006 L
.29811 .55814 L
.29906 .53204 L
.30277 .38907 L
.30675 .20844 L
Mistroke
.30898 .11963 L
.31015 .0815 L
.3114 .04952 L
.31249 .02966 L
.31311 .02196 L
.31369 .01721 L
.3147 .01472 L
.31528 .0166 L
.3158 .0204 L
.31685 .03378 L
.31782 .05286 L
.31889 .08063 L
.32002 .11724 L
.32404 .28563 L
.32818 .46734 L
.33026 .53821 L
.33144 .56797 L
.33197 .57844 L
.33255 .58772 L
.33317 .59518 L
.33376 .59975 L
.33433 .60181 L
.33486 .60161 L
.33543 .59914 L
.33606 .59372 L
.33672 .5851 L
.33734 .57433 L
.33845 .54897 L
.33946 .51943 L
.34175 .43508 L
.34596 .24926 L
.34802 .16416 L
.34988 .10021 L
.3509 .0728 L
.35186 .05254 L
.35287 .03759 L
.35344 .03219 L
.35397 .02921 L
.355 .02895 L
.35559 .03211 L
.35614 .03718 L
.35672 .04471 L
.35725 .05348 L
.35844 .07945 L
.36052 .14257 L
.3624 .21427 L
.36661 .39068 L
.36848 .46058 L
.36947 .49202 L
.37051 .52019 L
Mistroke
.37142 .54008 L
.37242 .55629 L
.37333 .56563 L
.37418 .56958 L
.37525 .56798 L
.37585 .56388 L
.37641 .55809 L
.37743 .54266 L
.37852 .51995 L
.38039 .46746 L
.38246 .39548 L
.38679 .23224 L
.38915 .1572 L
.3903 .12845 L
.39134 .10781 L
.39233 .09342 L
.39327 .08486 L
.39426 .08124 L
.39534 .08359 L
.39586 .08708 L
.39644 .09264 L
.39705 .1003 L
.39761 .10909 L
.39971 .15396 L
.40341 .26505 L
.40737 .39051 L
.40959 .44593 L
.41085 .46928 L
.41144 .47806 L
.41201 .48486 L
.41302 .49339 L
.41356 .49597 L
.41414 .49721 L
.41471 .49689 L
.41532 .4949 L
.4164 .48726 L
.41739 .47604 L
.41844 .45998 L
.42034 .4222 L
.42464 .314 L
.42678 .2614 L
.42904 .21513 L
.42997 .20017 L
.43097 .1872 L
.43155 .18131 L
.43207 .17695 L
.4331 .17127 L
.43367 .16977 L
.43427 .16944 L
.43535 .17203 L
Mistroke
.43601 .17555 L
.43664 .18014 L
.43781 .19176 L
.43996 .2217 L
.44228 .26216 L
.4465 .33758 L
.44863 .36779 L
.44984 .38091 L
.45038 .38571 L
.45096 .39013 L
.452 .39589 L
.45298 .39892 L
.45393 .39963 L
.45482 .3984 L
.45577 .39518 L
.45682 .38954 L
.45792 .38163 L
.45895 .37267 L
.46317 .328 L
.46522 .30661 L
.46709 .29013 L
.46804 .28326 L
.46907 .27713 L
.47015 .27224 L
.47118 .26914 L
.47172 .26809 L
.47231 .2674 L
.47293 .26716 L
.47351 .26736 L
.47454 .26869 L
.47513 .26993 L
.47566 .27133 L
.47948 .28668 L
.48308 .30293 L
.48507 .30997 L
.48619 .31294 L
.48722 .31498 L
.48809 .31619 L
.48905 .317 L
.49004 .31731 L
.49097 .31716 L
.49203 .31657 L
.49304 .3157 L
.49492 .31363 L
.49599 .31242 L
.49712 .31127 L
.49808 .31048 L
.49914 .30987 L
.50005 .30965 L
.50102 .30965 L
Mistroke
.50278 .30965 L
.50672 .30965 L
.52388 .30965 L
.55798 .30965 L
.59082 .30965 L
.62241 .30965 L
.65603 .30965 L
.68839 .30965 L
.72278 .30965 L
.75592 .30965 L
.7878 .30965 L
.82172 .30965 L
.85438 .30965 L
.88578 .30965 L
.91921 .30965 L
.95139 .30965 L
.97619 .30965 L
Mfstroke
0 g
.02381 .30965 m
.05578 .30965 L
.09065 .30965 L
.1234 .30965 L
.1549 .30965 L
.18842 .30965 L
.22069 .30965 L
.25499 .30965 L
.27217 .30965 L
.28804 .30965 L
.29601 .30965 L
.30347 .30965 L
.30722 .30965 L
.3083 .30965 L
.30933 .30965 L
.31025 .30979 L
.31125 .31019 L
.31238 .31083 L
.31341 .31152 L
.3157 .3134 L
.31983 .31719 L
.32191 .31891 L
.32386 .32017 L
.32484 .32064 L
.32589 .32098 L
.32649 .32109 L
.32706 .32115 L
.32812 .32109 L
.32905 .32085 L
.33002 .32041 L
.33086 .31987 L
.33178 .31909 L
.33383 .31663 L
.33576 .31341 L
.33786 .30887 L
.34008 .30302 L
.34405 .29024 L
.35299 .25691 L
.35494 .25033 L
.35705 .24406 L
.35891 .23952 L
.35993 .2375 L
.36089 .23595 L
.36198 .23459 L
.36256 .23406 L
.36319 .23365 L
.36375 .23343 L
.36429 .23334 L
.36531 .23355 L
.3663 .23422 L
Mistroke
.36723 .23526 L
.36824 .23689 L
.36932 .23919 L
.3713 .24491 L
.37343 .25328 L
.3773 .27389 L
.38452 .32717 L
.39308 .39821 L
.39726 .42747 L
.39908 .43781 L
.40106 .44694 L
.40213 .45088 L
.40312 .45383 L
.40407 .456 L
.40508 .4576 L
.40613 .45847 L
.40712 .45851 L
.40821 .45767 L
.40882 .45679 L
.40938 .45573 L
.41048 .45291 L
.4115 .44943 L
.41383 .43849 L
.41609 .42393 L
.4185 .40445 L
.43501 .21348 L
.43954 .16624 L
.44201 .14562 L
.44432 .13055 L
.44533 .12537 L
.44629 .1213 L
.44682 .11941 L
.44739 .11766 L
.4484 .11534 L
.44894 .11451 L
.44953 .11392 L
.45015 .11366 L
.45073 .11377 L
.45177 .11479 L
.45235 .11584 L
.45289 .11709 L
.4539 .12022 L
.45482 .12392 L
.45688 .13515 L
.45879 .14901 L
.46059 .16493 L
.46902 .26728 L
.47727 .38466 L
.48179 .44149 L
.484 .46488 L
Mistroke
.48602 .48303 L
.48783 .49637 L
.48981 .50747 L
.4909 .51195 L
.49191 .51504 L
.49287 .51704 L
.49389 .51813 L
.49448 .51826 L
.49502 .51807 L
.49561 .51752 L
.49624 .51655 L
.49729 .51402 L
.49788 .51209 L
.49844 .50996 L
.50043 .49991 L
.50256 .48504 L
.50666 .44579 L
.51055 .39826 L
.51783 .29474 L
.52582 .18637 L
.52986 .14427 L
.53216 .12601 L
.53319 .11934 L
.53432 .11319 L
.53522 .10914 L
.53618 .1057 L
.5372 .10308 L
.53815 .10159 L
.53909 .10101 L
.53999 .10131 L
.54079 .10227 L
.54166 .10405 L
.54261 .10688 L
.54366 .11103 L
.54577 .12265 L
.54773 .13709 L
.54956 .15354 L
.56495 .35783 L
.56913 .41448 L
.57307 .45965 L
.57525 .47999 L
.57761 .49747 L
.57865 .5036 L
.57975 .50894 L
.58068 .51257 L
.58171 .51553 L
.58232 .51679 L
.5829 .51764 L
.58399 .51829 L
.58459 .51813 L
Mistroke
.58516 .51765 L
.58577 .51675 L
.58642 .51537 L
.5875 .51216 L
.58851 .50809 L
.59081 .49517 L
.59293 .47898 L
.59488 .46087 L
.59925 .41046 L
.60788 .28872 L
.61208 .22937 L
.61589 .18138 L
.61777 .16088 L
.6198 .14161 L
.62156 .12768 L
.62349 .11558 L
.62455 .11042 L
.62554 .1066 L
.62659 .10363 L
.62717 .10245 L
.62771 .10168 L
.62866 .10102 L
.6297 .10138 L
.63068 .10273 L
.63159 .10485 L
.63257 .10806 L
.63363 .1126 L
.63554 .12354 L
.63782 .14088 L
.63991 .16057 L
.64874 .27298 L
.65631 .38193 L
.66047 .43513 L
.66439 .47572 L
.66662 .49336 L
.6678 .50087 L
.66904 .50741 L
.67009 .51175 L
.67064 .51361 L
.67124 .51527 L
.67229 .51731 L
.67327 .51821 L
.67432 .51807 L
.67492 .51749 L
.67548 .51662 L
.6765 .51421 L
.67758 .5105 L
.67865 .50573 L
.67965 .50023 L
.68152 .48747 L
Mistroke
.68538 .45181 L
.68962 .40093 L
.69816 .27927 L
.70193 .22653 L
.70602 .17603 L
.7079 .15641 L
.70989 .13856 L
.71161 .12587 L
.71346 .11526 L
.71454 .1106 L
.71554 .10735 L
.71649 .10519 L
.71748 .10391 L
.71802 .10364 L
.71858 .10368 L
.7196 .10458 L
.72023 .10566 L
.72082 .10704 L
.72192 .11056 L
.72286 .11448 L
.72385 .11955 L
.72562 .13089 L
.72963 .16616 L
.73788 .26817 L
.74253 .33194 L
.74695 .38841 L
.75098 .43181 L
.75311 .45031 L
.75537 .46607 L
.75727 .47592 L
.75835 .48011 L
.75937 .48308 L
.76029 .48498 L
.76115 .48603 L
.76208 .48643 L
.76307 .48601 L
.76415 .48455 L
.76513 .48234 L
.76627 .47877 L
.76734 .47443 L
.76925 .46451 L
.77132 .45084 L
.78036 .36645 L
.78884 .27855 L
.79299 .24295 L
.79679 .21814 L
.79883 .20837 L
.80078 .20158 L
.80184 .19891 L
.80283 .19709 L
Mistroke
.80391 .19582 L
.80452 .19543 L
.80507 .19528 L
.80564 .19533 L
.80625 .19559 L
.80733 .19661 L
.80793 .19747 L
.80849 .19846 L
.80977 .20134 L
.8119 .20798 L
.81419 .21733 L
.82214 .26126 L
.83059 .30995 L
.835 .32939 L
.8375 .33766 L
.83865 .3407 L
.83986 .34339 L
.84088 .34527 L
.84201 .3469 L
.84303 .34799 L
.84398 .34869 L
.84456 .34898 L
.84511 .34914 L
.84613 .34921 L
.8467 .34911 L
.84723 .34893 L
.84781 .34865 L
.84843 .34825 L
.84948 .34736 L
.85047 .34628 L
.85234 .34372 L
.85654 .33615 L
.86413 .32109 L
.86621 .31764 L
.86842 .31459 L
.87051 .31235 L
.8724 .31089 L
.87356 .31026 L
.87463 .30984 L
.87519 .30969 L
.87581 .30956 L
.87645 .30947 L
.87704 .30942 L
.87761 .30941 L
.87815 .30942 L
.87915 .30949 L
.88024 .3096 L
.88085 .30965 L
.88141 .30965 L
.88242 .30965 L
Mistroke
.88338 .30965 L
.88522 .30965 L
.88942 .30965 L
.89792 .30965 L
.91318 .30965 L
.94477 .30965 L
.97619 .30965 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell[TextData[{
  "You can also plot the envelopes of the window function together with the \
cosine or sine packets. Note that the window function is multiplied by the \
factor ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2/L\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " to get the right envelope. This is a sine packet over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 3]\)\)\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.37"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[{SinPacket[t, 3, 25],
 Sqrt[2/3] WindowFunction[t, 3],
-Sqrt[2/3] WindowFunction[t, 3]}],
{t, -1, 4}, AxesLabel->{\"t\", \"\"},
PlotLabel -> \"sine packet\", PlotPoints -> 40,
PlotStyle -> (GrayLevel[#]& /@ {0, 1/2, 1/2})]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.309017 0.360445 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.20179 .03868 -30 -4.5 ]
[.20179 .03868 0 4.5 ]
[.20179 .12879 -24 -4.5 ]
[.20179 .12879 0 4.5 ]
[.20179 .21891 -30 -4.5 ]
[.20179 .21891 0 4.5 ]
[.20179 .39913 -24 -4.5 ]
[.20179 .39913 0 4.5 ]
[.20179 .48924 -18 -4.5 ]
[.20179 .48924 0 4.5 ]
[.20179 .57935 -24 -4.5 ]
[.20179 .57935 0 4.5 ]
[.5 .63053 -33 0 ]
[.5 .63053 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(2)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(3)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(4)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(t)] 1.025 .30902 -1 0 Mshowa
.21429 .03868 m
.22054 .03868 L
s
[(-0.75)] .20179 .03868 1 0 Mshowa
.21429 .12879 m
.22054 .12879 L
s
[(-0.5)] .20179 .12879 1 0 Mshowa
.21429 .21891 m
.22054 .21891 L
s
[(-0.25)] .20179 .21891 1 0 Mshowa
.21429 .39913 m
.22054 .39913 L
s
[(0.25)] .20179 .39913 1 0 Mshowa
.21429 .48924 m
.22054 .48924 L
s
[(0.5)] .20179 .48924 1 0 Mshowa
.21429 .57935 m
.22054 .57935 L
s
[(0.75)] .20179 .57935 1 0 Mshowa
.125 Mabswid
.21429 .05671 m
.21804 .05671 L
s
.21429 .07473 m
.21804 .07473 L
s
.21429 .09275 m
.21804 .09275 L
s
.21429 .11077 m
.21804 .11077 L
s
.21429 .14682 m
.21804 .14682 L
s
.21429 .16484 m
.21804 .16484 L
s
.21429 .18286 m
.21804 .18286 L
s
.21429 .20088 m
.21804 .20088 L
s
.21429 .23693 m
.21804 .23693 L
s
.21429 .25495 m
.21804 .25495 L
s
.21429 .27297 m
.21804 .27297 L
s
.21429 .29099 m
.21804 .29099 L
s
.21429 .32704 m
.21804 .32704 L
s
.21429 .34506 m
.21804 .34506 L
s
.21429 .36308 m
.21804 .36308 L
s
.21429 .38111 m
.21804 .38111 L
s
.21429 .41715 m
.21804 .41715 L
s
.21429 .43517 m
.21804 .43517 L
s
.21429 .45319 m
.21804 .45319 L
s
.21429 .47122 m
.21804 .47122 L
s
.21429 .50726 m
.21804 .50726 L
s
.21429 .52528 m
.21804 .52528 L
s
.21429 .54331 m
.21804 .54331 L
s
.21429 .56133 m
.21804 .56133 L
s
.21429 .02066 m
.21804 .02066 L
s
.21429 .00264 m
.21804 .00264 L
s
.21429 .59737 m
.21804 .59737 L
s
.21429 .6154 m
.21804 .6154 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
[(sine packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.03538 .30902 L
.04759 .30902 L
.05996 .30902 L
.06335 .30902 L
.06698 .30902 L
.06874 .30902 L
.0696 .30902 L
.0704 .30902 L
.07112 .30902 L
.07189 .30896 L
.07266 .30879 L
.07351 .30857 L
.07425 .30838 L
.07504 .3082 L
.0755 .30812 L
.07591 .30807 L
.07671 .30804 L
.07746 .3081 L
.07828 .30828 L
.07905 .30858 L
.07975 .30897 L
.08107 .30999 L
.08253 .31157 L
.08546 .31594 L
.08867 .32146 L
.09043 .32413 L
.0913 .32519 L
.0921 .32596 L
.09286 .32647 L
.09366 .32677 L
.09446 .32677 L
.09492 .32663 L
.09535 .3264 L
.09609 .32578 L
.09677 .32494 L
.09752 .32372 L
.09831 .3221 L
.10463 .29797 L
.10773 .28247 L
.10909 .2761 L
.11059 .26996 L
.11124 .2677 L
.11194 .26558 L
.11254 .26404 L
.1132 .26271 L
.11393 .26166 L
.11464 .26114 L
.11532 .26111 L
.11595 .26152 L
Mistroke
.11671 .26258 L
.11743 .26415 L
.11807 .26605 L
.11876 .26861 L
.12032 .27626 L
.12176 .28545 L
.12752 .33603 L
.13078 .36543 L
.13237 .37714 L
.13383 .38535 L
.13457 .38849 L
.13538 .39096 L
.13615 .39235 L
.13686 .39277 L
.1376 .39229 L
.13803 .39158 L
.13843 .39062 L
.13923 .38784 L
.13969 .38578 L
.1401 .38357 L
.14164 .3728 L
.14333 .35673 L
.14672 .31384 L
.14971 .27046 L
.15294 .22694 L
.15443 .21088 L
.15524 .20362 L
.156 .19795 L
.1567 .19375 L
.15734 .19084 L
.15805 .1887 L
.15881 .18771 L
.15923 .18777 L
.15967 .1883 L
.16047 .19048 L
.16092 .19237 L
.16133 .19459 L
.16228 .20123 L
.16311 .20874 L
.16387 .21699 L
.16557 .23996 L
.17171 .35331 L
.17462 .40687 L
.17622 .43123 L
.17701 .44128 L
.17773 .44925 L
.1784 .45542 L
.17914 .46078 L
.17989 .46458 L
.18067 .46679 L
Mistroke
.18134 .46717 L
.18205 .46603 L
.18273 .46346 L
.18334 .45985 L
.18413 .45354 L
.18496 .44476 L
.18646 .42391 L
.18987 .35682 L
.19608 .20805 L
.19768 .17509 L
.19938 .14686 L
.20007 .13762 L
.20082 .12946 L
.20125 .12563 L
.20164 .1227 L
.20241 .11858 L
.20284 .11723 L
.20329 .11654 L
.2041 .11724 L
.20455 .11871 L
.20497 .1208 L
.20543 .12387 L
.20593 .12808 L
.20678 .13735 L
.20767 .14987 L
.20926 .17877 L
.21527 .3377 L
.21856 .42974 L
.22018 .46796 L
.22168 .49655 L
.22244 .5083 L
.22316 .51728 L
.22391 .52445 L
.22431 .52731 L
.22473 .52964 L
.22516 .53118 L
.22562 .53197 L
.22606 .53184 L
.22647 .53097 L
.22723 .52734 L
.22766 .52419 L
.22805 .52065 L
.22948 .50204 L
.23029 .48792 L
.23103 .4728 L
.23383 .39995 L
.2393 .22368 L
.24074 .17974 L
.2423 .13744 L
.24368 .10648 L
Mistroke
.24514 .08158 L
.24592 .07206 L
.24636 .06788 L
.24678 .06479 L
.24751 .06136 L
.24829 .06056 L
.24906 .06268 L
.24978 .06737 L
.25044 .07377 L
.25115 .08307 L
.25256 .10807 L
.25406 .14366 L
.25676 .22598 L
.25998 .34085 L
.26338 .45749 L
.26479 .49785 L
.26629 .53334 L
.26716 .54941 L
.26794 .56107 L
.26873 .56973 L
.26948 .575 L
.27025 .57736 L
.27106 .57649 L
.27175 .573 L
.27251 .56624 L
.27294 .56116 L
.27333 .55569 L
.27421 .54062 L
.27581 .5043 L
.27914 .39853 L
.28266 .26486 L
.28552 .16063 L
.28709 .11199 L
.28858 .07456 L
.28943 .05767 L
.29034 .04329 L
.29075 .03831 L
.29117 .03398 L
.29194 .02869 L
.29271 .02664 L
.29343 .0277 L
.29422 .03216 L
.29466 .03616 L
.29507 .04075 L
.29586 .05228 L
.29661 .06608 L
.29801 .09898 L
.30114 .20015 L
.30677 .42096 L
.30832 .47602 L
Mistroke
.30996 .52568 L
.31136 .55924 L
.31216 .5741 L
.3129 .58501 L
.31331 .5898 L
.31376 .59394 L
.31418 .59682 L
.31457 .59858 L
.31531 .59953 L
.3161 .59712 L
.3165 .5945 L
.31694 .59065 L
.31773 .58101 L
.31867 .56521 L
.31953 .54682 L
.32565 .33703 L
.32901 .20158 L
.33066 .14181 L
.33218 .09452 L
.33362 .05865 L
.33435 .04418 L
.33514 .03176 L
.33593 .0227 L
.33666 .01739 L
.33711 .01568 L
.33754 .01514 L
.33834 .01697 L
.33901 .02136 L
.33973 .02885 L
.34034 .03748 L
.34102 .04935 L
.34252 .08392 L
.34394 .12554 L
.34943 .33756 L
.35243 .45466 L
.35523 .54126 L
.35669 .57325 L
.35751 .58638 L
.35826 .59514 L
.35868 .59874 L
.35908 .60115 L
.35951 .60277 L
.35997 .60332 L
.36073 .60152 L
.36117 .59898 L
.36158 .59561 L
.36233 .58698 L
.36305 .5759 L
.36439 .54799 L
.36583 .50854 L
Mistroke
.36741 .45624 L
.37365 .20799 L
.37514 .15294 L
.37671 .10219 L
.37816 .06405 L
.37952 .0376 L
.38027 .02717 L
.38107 .01945 L
.38153 .01667 L
.38196 .01516 L
.38277 .01523 L
.3832 .01678 L
.38365 .01956 L
.38446 .02745 L
.38491 .0334 L
.38533 .03998 L
.38629 .05845 L
.38783 .09737 L
.38925 .14174 L
.39243 .26264 L
.39533 .38126 L
.39806 .48274 L
.39957 .52886 L
.40037 .54929 L
.40121 .56765 L
.40192 .58032 L
.4027 .59115 L
.40341 .59808 L
.40408 .60197 L
.40449 .6031 L
.40493 .60324 L
.40574 .60055 L
.40653 .59433 L
.40726 .58546 L
.40813 .57114 L
.40892 .55481 L
.41068 .50777 L
.41384 .39539 L
.41682 .27398 L
.41994 .15354 L
.42146 .10415 L
.42284 .06722 L
.42355 .0519 L
.42431 .03808 L
.42511 .02686 L
.42588 .01954 L
.42628 .01703 L
.42672 .01531 L
.42717 .01472 L
.42761 .01526 L
Mistroke
.42837 .01889 L
.42881 .02241 L
.4292 .02656 L
.4299 .036 L
.43065 .04896 L
.43199 .07932 L
.43503 .17607 L
.44058 .39846 L
.44365 .50738 L
.4452 .54954 L
.44609 .56876 L
.4469 .58279 L
.44733 .58874 L
.44779 .59409 L
.44828 .59843 L
.44874 .60129 L
.44917 .60284 L
.44964 .60331 L
.45003 .60274 L
.45046 .60107 L
.45128 .59504 L
.45173 .59 L
.45215 .58437 L
.45374 .55461 L
.45524 .51552 L
.45663 .47098 L
.45979 .35009 L
.4631 .21527 L
.46615 .10787 L
.46766 .06731 L
.46843 .05064 L
.46925 .03608 L
.46969 .02991 L
.47008 .02517 L
.47086 .01842 L
.47129 .01613 L
.47176 .01487 L
.47221 .01485 L
.47262 .01586 L
.47342 .02061 L
.47417 .02839 L
.47485 .03803 L
.47558 .05119 L
.47722 .09036 L
.47873 .13662 L
.48425 .35246 L
.48729 .46884 L
.48878 .51675 L
.49016 .55299 L
.49088 .56824 L
Mistroke
.49167 .58204 L
.49246 .59254 L
.4929 .59682 L
.4933 .59986 L
.49402 .60291 L
.49468 .60309 L
.4954 .6004 L
.49616 .59434 L
.49683 .58632 L
.49755 .57505 L
.49884 .54812 L
.50037 .50605 L
.50176 .45995 L
.50498 .33474 L
.50838 .19723 L
.51129 .09851 L
.51208 .07691 L
.51294 .05695 L
.51374 .04151 L
.51448 .03022 L
.51522 .022 L
.516 .0166 L
.51645 .01509 L
.51687 .01473 L
.51765 .01678 L
.51841 .02208 L
.5191 .02977 L
.51986 .04123 L
.52066 .0566 L
.52205 .09078 L
.52335 .13013 L
.5263 .23908 L
.52946 .36819 L
.53112 .43319 L
.53288 .49469 L
.53442 .53928 L
.53524 .55871 L
.53612 .57596 L
.53692 .58822 L
.53766 .59633 L
.5384 .60139 L
.5391 .60328 L
.53989 .60199 L
.54061 .59771 L
.54101 .59408 L
.54144 .58916 L
.54222 .57765 L
.54372 .5465 L
.54511 .50847 L
.55166 .25793 L
Mistroke
.55454 .14836 L
.55594 .10325 L
.55722 .069 L
.55857 .04123 L
.55932 .02997 L
.56002 .02211 L
.56079 .01674 L
.56149 .01476 L
.56227 .01592 L
.56266 .01783 L
.5631 .02095 L
.56384 .02884 L
.56454 .03895 L
.56612 .07126 L
.56766 .11392 L
.56931 .16946 L
.575 .39718 L
.57666 .45953 L
.57846 .51788 L
.57928 .54042 L
.58016 .5609 L
.58091 .57557 L
.58172 .58801 L
.58251 .59661 L
.58323 .60143 L
.58395 .6033 L
.58463 .60228 L
.58543 .59772 L
.58616 .5903 L
.58697 .5787 L
.58783 .56255 L
.59382 .36696 L
.5971 .23322 L
.60015 .1221 L
.60174 .07629 L
.60256 .05717 L
.60345 .04017 L
.60396 .03235 L
.60443 .02636 L
.60488 .02178 L
.60535 .01815 L
.60578 .016 L
.60617 .01492 L
.60661 .0148 L
.60708 .01589 L
.60785 .02046 L
.60829 .02457 L
.6087 .02934 L
.60953 .04178 L
.61041 .05898 L
Mistroke
.612 .09968 L
.61345 .14571 L
.61955 .38666 L
.62276 .50242 L
.62438 .54734 L
.62531 .56775 L
.62616 .58256 L
.62695 .59298 L
.62771 .59957 L
.62851 .60298 L
.62896 .60328 L
.62938 .60251 L
.63007 .59901 L
.63084 .59195 L
.63164 .5811 L
.63239 .56778 L
.63383 .5344 L
.63516 .49566 L
.63814 .38725 L
.64376 .1631 L
.64537 .10936 L
.6469 .06794 L
.64828 .04011 L
.64905 .02874 L
.64977 .02117 L
.65055 .01619 L
.65129 .01475 L
.6521 .01679 L
.65255 .01957 L
.65297 .02315 L
.6538 .03322 L
.65471 .04847 L
.65636 .08684 L
.65954 .1919 L
.6625 .31038 L
.66562 .43489 L
.66727 .49209 L
.66901 .54185 L
.67053 .5742 L
.67095 .581 L
.67139 .58725 L
.6722 .59575 L
.67299 .60051 L
.67373 .60173 L
.67441 .60009 L
.67513 .59539 L
.67584 .58796 L
.67651 .5785 L
.67802 .54839 L
.6795 .50876 L
Mistroke
.68108 .45666 L
.68659 .24 L
.68944 .13627 L
.691 .09022 L
.69248 .05651 L
.69332 .04215 L
.69376 .03607 L
.69423 .03079 L
.69463 .02728 L
.69506 .02442 L
.69582 .02195 L
.6966 .02279 L
.69703 .02475 L
.69743 .02745 L
.6982 .03518 L
.69893 .04544 L
.70049 .07643 L
.70215 .12141 L
.70514 .22521 L
.70867 .3635 L
.71022 .42138 L
.71191 .47827 L
.71341 .5203 L
.715 .55474 L
.71589 .56849 L
.71669 .57752 L
.7175 .58312 L
.71826 .58516 L
.71866 .58497 L
.71909 .58378 L
.71955 .58145 L
.71997 .57827 L
.72073 .57022 L
.72155 .55827 L
.72251 .54025 L
.72342 .51934 L
.72512 .47144 L
.73113 .25537 L
.73272 .1995 L
.73443 .14575 L
.73592 .10722 L
.73676 .08927 L
.73754 .07536 L
.73832 .06442 L
.73872 .05996 L
.73916 .05601 L
.73962 .0529 L
.74005 .05093 L
.74048 .04994 L
.74087 .04984 L
Mistroke
.74157 .05164 L
.74235 .05654 L
.74317 .06484 L
.74393 .07548 L
.74538 .10283 L
.74672 .13519 L
.74972 .22698 L
.75519 .41201 L
.75677 .45721 L
.75825 .49278 L
.75959 .51759 L
.76034 .52828 L
.76104 .53591 L
.76176 .54149 L
.76243 .54453 L
.76317 .54543 L
.76396 .54356 L
.76436 .54153 L
.76479 .5385 L
.76558 .53086 L
.76635 .52087 L
.76706 .50947 L
.76978 .44974 L
.77267 .3663 L
.7759 .26611 L
.77767 .21533 L
.77931 .17396 L
.78083 .14269 L
.78222 .12123 L
.78301 .11228 L
.78376 .10612 L
.78455 .10211 L
.785 .10099 L
.78541 .10069 L
.78617 .10195 L
.78687 .10522 L
.78765 .11109 L
.78849 .11997 L
.79019 .14558 L
.79175 .17667 L
.7986 .35343 L
.80012 .39041 L
.80174 .42484 L
.80324 .45069 L
.80466 .46881 L
.80542 .47586 L
.80585 .47894 L
.80625 .48121 L
.80695 .48387 L
.8077 .48479 L
Mistroke
.80809 .4845 L
.80852 .48358 L
.80928 .48038 L
.80975 .47747 L
.81019 .47407 L
.81102 .46604 L
.8164 .37378 L
.82221 .24879 L
.82383 .22022 L
.82553 .1961 L
.82624 .18822 L
.82699 .18124 L
.82742 .17792 L
.82782 .17536 L
.82859 .1716 L
.82935 .16951 L
.83006 .16906 L
.83084 .17018 L
.83123 .17137 L
.83167 .17316 L
.83239 .17723 L
.83317 .18305 L
.83458 .19706 L
.83783 .24273 L
.84092 .29509 L
.84373 .3414 L
.84672 .38131 L
.84759 .39011 L
.8484 .39709 L
.8492 .4026 L
.84993 .40651 L
.85062 .4092 L
.85136 .41092 L
.85209 .41152 L
.8529 .41087 L
.85335 .40994 L
.85378 .40869 L
.85459 .40541 L
.85545 .4006 L
.85639 .39398 L
.85964 .36239 L
.86267 .32661 L
.86592 .28931 L
.86742 .2747 L
.869 .26196 L
.87034 .25357 L
.87111 .24992 L
.87181 .24727 L
.87262 .24514 L
.87337 .24396 L
Mistroke
.87405 .24358 L
.87479 .24388 L
.87559 .24501 L
.87599 .24589 L
.87644 .24708 L
.87796 .25279 L
.87965 .26164 L
.88146 .27326 L
.88474 .29658 L
.88776 .31658 L
.88942 .32558 L
.89098 .33229 L
.89187 .33528 L
.89283 .33778 L
.89325 .33865 L
.8937 .3394 L
.89451 .34035 L
.89531 .3408 L
.89607 .34078 L
.8965 .34058 L
.89689 .3403 L
.89735 .33984 L
.89778 .3393 L
.89927 .33661 L
.90086 .33267 L
.9037 .32404 L
.90707 .31378 L
.90854 .30999 L
.91015 .30662 L
.91085 .30543 L
.91161 .30436 L
.91226 .3036 L
.91296 .30295 L
.91376 .30244 L
.91452 .30215 L
.91525 .30204 L
.91593 .30208 L
.91667 .30226 L
.91737 .30254 L
.91813 .30295 L
.91895 .3035 L
.92215 .30606 L
.9236 .30715 L
.92436 .30765 L
.92518 .3081 L
.92588 .30843 L
.92666 .30871 L
.92737 .30888 L
.92804 .30898 L
.9287 .30902 L
Mistroke
.92939 .30902 L
.93062 .30902 L
.93341 .30902 L
.95684 .30902 L
.97619 .30902 L
Mfstroke
.5 g
.02381 .30902 m
.03538 .30902 L
.04759 .30902 L
.05996 .30902 L
.06335 .30902 L
.06698 .30902 L
.06874 .30902 L
.0696 .30902 L
.0704 .30902 L
.07112 .30902 L
.07189 .30908 L
.07266 .30928 L
.07351 .30959 L
.07504 .31033 L
.07671 .31132 L
.07975 .31354 L
.08546 .31877 L
.09831 .33398 L
.12332 .37129 L
.1474 .41138 L
.17299 .4543 L
.19764 .49323 L
.22137 .52656 L
.2466 .55612 L
.25917 .56823 L
.2709 .57786 L
.2829 .58601 L
.29427 .59215 L
.30027 .59478 L
.30679 .59718 L
.31268 .59896 L
.31821 .6003 L
.324 .6014 L
.32733 .60189 L
.33038 .60227 L
.33335 .60257 L
.3366 .60283 L
.33987 .60302 L
.34165 .6031 L
.34331 .60316 L
.34482 .60321 L
.34642 .60325 L
.34725 .60326 L
.34817 .60328 L
.34901 .60329 L
.34978 .60329 L
.35051 .6033 L
.35131 .60331 L
.35215 .60331 L
.35294 .60331 L
Mistroke
.35369 .60332 L
.35448 .60332 L
.35522 .60332 L
.3559 .60332 L
.35662 .60332 L
.35737 .60332 L
.35802 .60332 L
.35873 .60332 L
.36179 .60332 L
.36734 .60332 L
.39224 .60332 L
.41622 .60332 L
.44171 .60332 L
.46626 .60332 L
.48988 .60332 L
.51501 .60332 L
.5392 .60332 L
.56247 .60332 L
.58724 .60332 L
.61108 .60332 L
.62319 .60332 L
.6296 .60332 L
.63311 .60332 L
.63643 .60332 L
.63961 .60332 L
.64049 .60332 L
.64141 .60332 L
.6422 .60332 L
.64264 .60332 L
.64306 .60332 L
.64384 .60332 L
.64458 .60332 L
.64524 .60332 L
.64597 .60332 L
.64675 .60332 L
.64715 .60331 L
.64759 .60331 L
.64836 .60331 L
.64908 .6033 L
.65052 .60329 L
.65124 .60328 L
.65203 .60327 L
.65343 .60325 L
.65474 .60322 L
.65769 .60313 L
.65934 .60306 L
.66084 .60299 L
.66382 .6028 L
.66698 .60254 L
.67263 .6019 L
Mistroke
.67872 .60092 L
.68543 .59945 L
.69167 .59768 L
.69738 .5957 L
.71023 .5899 L
.72192 .58294 L
.73468 .57348 L
.75971 .54936 L
.7838 .51972 L
.8094 .48248 L
.83407 .44262 L
.8578 .40259 L
.88305 .36117 L
.89562 .34232 L
.90736 .3268 L
.91316 .32021 L
.91865 .31489 L
.92168 .31244 L
.92328 .31133 L
.92497 .31032 L
.9264 .30963 L
.92721 .30932 L
.92797 .30911 L
.92867 .30902 L
.9293 .30902 L
.93074 .30902 L
.95514 .30902 L
.97619 .30902 L
Mfstroke
.02381 .30902 m
.03538 .30902 L
.04759 .30902 L
.05996 .30902 L
.06335 .30902 L
.06698 .30902 L
.06874 .30902 L
.0696 .30902 L
.0704 .30902 L
.07112 .30902 L
.07189 .30896 L
.07266 .30875 L
.07351 .30844 L
.07504 .30771 L
.07671 .30671 L
.07975 .30449 L
.08546 .29926 L
.09831 .28405 L
.12332 .24674 L
.1474 .20665 L
.17299 .16373 L
.19764 .12481 L
.22137 .09147 L
.2466 .06192 L
.25917 .04981 L
.2709 .04017 L
.2829 .03203 L
.29427 .02589 L
.30027 .02326 L
.30679 .02085 L
.31268 .01908 L
.31821 .01773 L
.324 .01664 L
.32733 .01614 L
.33038 .01576 L
.33335 .01546 L
.3366 .01521 L
.33987 .01501 L
.34165 .01493 L
.34331 .01487 L
.34482 .01483 L
.34642 .01479 L
.34725 .01477 L
.34817 .01476 L
.34901 .01475 L
.34978 .01474 L
.35051 .01473 L
.35131 .01473 L
.35215 .01472 L
.35294 .01472 L
Mistroke
.35369 .01472 L
.35448 .01472 L
.35522 .01472 L
.3559 .01472 L
.35662 .01472 L
.35737 .01472 L
.35802 .01472 L
.35873 .01472 L
.36179 .01472 L
.36734 .01472 L
.39224 .01472 L
.41622 .01472 L
.44171 .01472 L
.46626 .01472 L
.48988 .01472 L
.51501 .01472 L
.5392 .01472 L
.56247 .01472 L
.58724 .01472 L
.61108 .01472 L
.62319 .01472 L
.6296 .01472 L
.63311 .01472 L
.63643 .01472 L
.63961 .01472 L
.64049 .01472 L
.64141 .01472 L
.6422 .01472 L
.64264 .01472 L
.64306 .01472 L
.64384 .01472 L
.64458 .01472 L
.64524 .01472 L
.64597 .01472 L
.64675 .01472 L
.64715 .01472 L
.64759 .01472 L
.64836 .01473 L
.64908 .01473 L
.65052 .01474 L
.65124 .01475 L
.65203 .01476 L
.65343 .01479 L
.65474 .01481 L
.65769 .01491 L
.65934 .01497 L
.66084 .01505 L
.66382 .01523 L
.66698 .01549 L
.67263 .01613 L
Mistroke
.67872 .01712 L
.68543 .01858 L
.69167 .02036 L
.69738 .02234 L
.71023 .02814 L
.72192 .03509 L
.73468 .04455 L
.75971 .06867 L
.7838 .09831 L
.8094 .13555 L
.83407 .17541 L
.8578 .21544 L
.88305 .25687 L
.89562 .27572 L
.90736 .29124 L
.91316 .29783 L
.91865 .30315 L
.92168 .30559 L
.92328 .3067 L
.92497 .30771 L
.9264 .3084 L
.92721 .30871 L
.92797 .30893 L
.92867 .30902 L
.9293 .30902 L
.93074 .30902 L
.95514 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell[TextData[{
  "Note that the Cos\[Hyphen]IV or Sin\[Hyphen]IV basis are obtained by \
setting the option ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["False", "MR"],
  ". Similarly, we can plot the Sin\[Hyphen]II and Cos\[Hyphen]II basis using \
",
  StyleBox["SinPacket", "MR"],
  " and ",
  StyleBox["CosPacket", "MR"],
  " by setting the frequency index ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S1.7.3"],
  " to half integers and setting ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["False", "MR"],
  ". "
}], "Text",
  CellTags->{"S1.7.3", "3.38"}],

Cell[TextData[{
  "This gives the Cos\[Hyphen]II packet with the frequency index ",
  Cell[BoxData[
      \(TraditionalForm\`k = 15\)], "InlineFormula",
    CellTags->"S1.7.3"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.3", "3.39"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[CosPacket[t, 2, 15-1/2, Taper -> False]],
{t, -1, 4}, AxesLabel -> {\"t\",\"\"},
PlotLabel -> \"Cos-II packet\"]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S1.7.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.309029 0.294314 [
[.02381 .29653 -6 -9 ]
[.02381 .29653 6 0 ]
[.40476 .29653 -3 -9 ]
[.40476 .29653 3 0 ]
[.59524 .29653 -3 -9 ]
[.59524 .29653 3 0 ]
[.78571 .29653 -3 -9 ]
[.78571 .29653 3 0 ]
[.97619 .29653 -3 -9 ]
[.97619 .29653 3 0 ]
[1.025 .30903 0 -4.5 ]
[1.025 .30903 6 4.5 ]
[.20179 .01471 -12 -4.5 ]
[.20179 .01471 0 4.5 ]
[.20179 .16187 -24 -4.5 ]
[.20179 .16187 0 4.5 ]
[.20179 .45619 -18 -4.5 ]
[.20179 .45619 0 4.5 ]
[.20179 .60334 -6 -4.5 ]
[.20179 .60334 0 4.5 ]
[.5 .63053 -39 0 ]
[.5 .63053 39 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30903 m
.02381 .31528 L
s
[(-1)] .02381 .29653 0 1 Mshowa
.40476 .30903 m
.40476 .31528 L
s
[(1)] .40476 .29653 0 1 Mshowa
.59524 .30903 m
.59524 .31528 L
s
[(2)] .59524 .29653 0 1 Mshowa
.78571 .30903 m
.78571 .31528 L
s
[(3)] .78571 .29653 0 1 Mshowa
.97619 .30903 m
.97619 .31528 L
s
[(4)] .97619 .29653 0 1 Mshowa
.125 Mabswid
.0619 .30903 m
.0619 .31278 L
s
.1 .30903 m
.1 .31278 L
s
.1381 .30903 m
.1381 .31278 L
s
.17619 .30903 m
.17619 .31278 L
s
.25238 .30903 m
.25238 .31278 L
s
.29048 .30903 m
.29048 .31278 L
s
.32857 .30903 m
.32857 .31278 L
s
.36667 .30903 m
.36667 .31278 L
s
.44286 .30903 m
.44286 .31278 L
s
.48095 .30903 m
.48095 .31278 L
s
.51905 .30903 m
.51905 .31278 L
s
.55714 .30903 m
.55714 .31278 L
s
.63333 .30903 m
.63333 .31278 L
s
.67143 .30903 m
.67143 .31278 L
s
.70952 .30903 m
.70952 .31278 L
s
.74762 .30903 m
.74762 .31278 L
s
.82381 .30903 m
.82381 .31278 L
s
.8619 .30903 m
.8619 .31278 L
s
.9 .30903 m
.9 .31278 L
s
.9381 .30903 m
.9381 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
[(t)] 1.025 .30903 -1 0 Mshowa
.21429 .01471 m
.22054 .01471 L
s
[(-1)] .20179 .01471 1 0 Mshowa
.21429 .16187 m
.22054 .16187 L
s
[(-0.5)] .20179 .16187 1 0 Mshowa
.21429 .45619 m
.22054 .45619 L
s
[(0.5)] .20179 .45619 1 0 Mshowa
.21429 .60334 m
.22054 .60334 L
s
[(1)] .20179 .60334 1 0 Mshowa
.125 Mabswid
.21429 .04415 m
.21804 .04415 L
s
.21429 .07358 m
.21804 .07358 L
s
.21429 .10301 m
.21804 .10301 L
s
.21429 .13244 m
.21804 .13244 L
s
.21429 .1913 m
.21804 .1913 L
s
.21429 .22073 m
.21804 .22073 L
s
.21429 .25017 m
.21804 .25017 L
s
.21429 .2796 m
.21804 .2796 L
s
.21429 .33846 m
.21804 .33846 L
s
.21429 .36789 m
.21804 .36789 L
s
.21429 .39732 m
.21804 .39732 L
s
.21429 .42675 m
.21804 .42675 L
s
.21429 .48562 m
.21804 .48562 L
s
.21429 .51505 m
.21804 .51505 L
s
.21429 .54448 m
.21804 .54448 L
s
.21429 .57391 m
.21804 .57391 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
[(Cos-II packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30903 m
.06244 .30903 L
.10458 .30903 L
.14415 .30903 L
.18221 .30903 L
.20178 .30903 L
.20742 .30903 L
.21019 .30903 L
.2114 .30903 L
.21274 .30903 L
.21394 .30903 L
.21506 .60198 L
.21625 .5947 L
.21753 .58003 L
.21819 .56968 L
.21892 .55639 L
.22024 .52714 L
.22272 .45727 L
.22758 .28725 L
.23014 .19694 L
.23285 .11381 L
.23522 .0585 L
.23587 .04692 L
.23656 .03638 L
.23782 .02252 L
.23905 .01563 L
.24021 .01534 L
.24125 .02025 L
.24239 .03107 L
.24371 .05043 L
.24516 .07973 L
.2481 .16046 L
.25339 .34564 L
.25815 .50174 L
.25946 .53499 L
.26085 .56399 L
.26217 .58445 L
.26336 .59673 L
.26458 .60277 L
.26589 .60186 L
.26713 .59389 L
.26828 .58059 L
.26948 .56088 L
.27079 .53284 L
.27346 .45901 L
.27829 .29037 L
.28271 .14042 L
.28398 .10463 L
.28537 .07141 L
.28669 .04646 L
Mistroke
.2879 .02949 L
.28863 .02232 L
.28932 .01771 L
.29061 .01475 L
.29133 .01635 L
.29199 .01986 L
.29272 .02595 L
.29348 .03486 L
.29469 .05373 L
.29597 .08017 L
.29829 .14192 L
.30357 .32325 L
.30851 .4896 L
.31101 .55172 L
.3117 .56492 L
.31243 .57709 L
.31312 .58648 L
.31377 .59339 L
.31447 .59889 L
.31523 .60241 L
.31598 .60332 L
.31677 .60153 L
.31751 .5973 L
.31821 .59108 L
.31952 .57383 L
.32085 .54921 L
.32208 .52078 L
.32485 .43992 L
.3299 .26071 L
.33238 .17556 L
.33463 .10849 L
.33577 .08023 L
.33701 .05464 L
.33832 .03409 L
.33956 .02126 L
.34021 .01724 L
.34093 .01498 L
.34167 .01508 L
.34237 .01746 L
.34363 .02714 L
.34433 .03558 L
.34498 .04515 L
.34746 .09676 L
.34971 .16102 L
.35477 .33802 L
.35707 .4191 L
.35951 .49522 L
.36159 .54713 L
.36277 .56982 L
.36388 .58602 L
Mistroke
.36516 .59827 L
.36634 .6031 L
.36699 .60311 L
.36769 .60097 L
.36898 .59136 L
.36971 .58272 L
.37037 .57296 L
.37185 .54481 L
.37452 .4751 L
.37941 .30748 L
.38208 .21209 L
.38457 .13234 L
.38688 .07317 L
.38818 .04811 L
.38936 .03108 L
.39065 .01922 L
.39138 .01578 L
.39205 .01472 L
.39329 .01809 L
.3946 .02914 L
.39569 .0439 L
.39687 .06518 L
.39899 .11634 L
.40383 .27524 L
.40913 .46033 L
.41179 .53382 L
.4133 .56515 L
.41397 .57632 L
.4147 .58633 L
.416 .59853 L
.41722 .60322 L
.41842 .60129 L
.41951 .59389 L
.4207 .57996 L
.42201 .55789 L
.42338 .52792 L
.42466 .49422 L
.42964 .32781 L
.43227 .23289 L
.43507 .14089 L
.43646 .10209 L
.43777 .07114 L
.43904 .04695 L
.4402 .03041 L
.44132 .02004 L
.44249 .01502 L
.44367 .0162 L
.44496 .02461 L
.44621 .03962 L
.44739 .05972 L
Mistroke
.4496 .11118 L
.45456 .27277 L
.45917 .43641 L
.46143 .50466 L
.4635 .55392 L
.46464 .57441 L
.46572 .58902 L
.46686 .599 L
.46811 .6033 L
.46939 .60046 L
.4701 .59572 L
.47074 .58949 L
.472 .57225 L
.47319 .55016 L
.47576 .48533 L
.47813 .40987 L
.48347 .21901 L
.48553 .15123 L
.48774 .08999 L
.48901 .06196 L
.49016 .04167 L
.49133 .02679 L
.49243 .01807 L
.49357 .01473 L
.49479 .01761 L
.49582 .02526 L
.49697 .03912 L
.49819 .05992 L
.49951 .08874 L
.5019 .15518 L
.50692 .32972 L
.50967 .42672 L
.51228 .50604 L
.51346 .53572 L
.5147 .56189 L
.51536 .57319 L
.51607 .58365 L
.51734 .59677 L
.51848 .60262 L
.51971 .60235 L
.52087 .59588 L
.52193 .58478 L
.52322 .56507 L
.52441 .54103 L
.5271 .46899 L
.53201 .29951 L
.53459 .20778 L
.53731 .12221 L
.53873 .08528 L
.54029 .05276 L
Mistroke
.54097 .04143 L
.54171 .03143 L
.5424 .02408 L
.54303 .01921 L
.54369 .016 L
.54439 .01472 L
.54564 .01791 L
.54633 .02271 L
.54698 .02912 L
.5477 .03826 L
.54847 .05046 L
.55116 .11049 L
.55362 .18474 L
.55838 .35389 L
.5609 .44084 L
.56358 .51947 L
.56485 .54904 L
.56605 .57154 L
.56712 .58685 L
.56829 .59791 L
.56939 .60289 L
.57056 .60218 L
.57156 .59672 L
.57266 .58567 L
.5739 .56701 L
.57504 .54464 L
.57759 .4782 L
.5822 .3214 L
.58699 .15498 L
.58941 .08783 L
.59079 .05808 L
.59209 .03674 L
.59321 .02394 L
.59439 .01634 L
.59539 .30903 L
.5965 .30903 L
.60125 .30903 L
.622 .30903 L
.66252 .30903 L
.70152 .30903 L
.74297 .30903 L
.78291 .30903 L
.82133 .30903 L
.8622 .30903 L
.90156 .30903 L
.93941 .30903 L
.97619 .30903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],

Cell["1.7.4 Local Trigonometric Transforms", "Subsection",
  CellTags->{"S1.7.4", "4.1"}],

Cell[TextData[{
  "We have seen how to do discrete sine and cosine transforms using the basis \
functions Cos\[Hyphen]II, Cos\[Hyphen]IV, Sin\[Hyphen]II and Sin\[Hyphen]IV. \
They correspond to windowed Fourier transforms using a rectangular window. \
The basis of Coifman and Meyer are in fact Cos\[Hyphen]IV or Sin\[Hyphen]IV \
basis multiplied by a set of smooth windows ",
  Cell[BoxData[
      \(TraditionalForm\`{\(b\_j\) \((t)\)}\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". They are also called ",
  StyleBox["smooth local sine and cosine bases", "TI"],
  " or sometimes simply local sine and cosine bases. (They are also called \
Malvar basis of the first kind.) In this section we see how these transforms \
are implemented.\nIn Coifman and Meyer's general formulation, the intervals \
and windows do not have to be equal. But in our implementation we choose them \
to be the same, that is, ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j = L\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_j\) \((t)\) = b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". The transform coefficients as always are given by the inner product \
(without any loss of generality, we choose ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j = 0\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " and ignore the normalization constant): "
}], "Text",
  CellTags->{"S1.7.4", "4.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Epsilon]\)\%\(L + \[Epsilon]\)\), "f", \((t)\), "b",
         \((t)\), "cos", \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.4", "4.3"}],

Cell[TextData[{
  "Again we split the domain of integration of this integral into three \
parts: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-\[Epsilon], \[Epsilon]\)]
      \)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\[Epsilon], L - \[Epsilon]]
      \)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([L - \[Epsilon], L + \[Epsilon]]
      \)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". Because ",
  Cell[BoxData[
      \(TraditionalForm\`cos \( \[Pi]\/L\) \((k + 1\/2)\) t\)], 
    "InlineFormula",
    CellTags->"S1.7.4"],
  " is even around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ", the integral over the first region can be written as "
}], "Text",
  CellTags->{"S1.7.4", "4.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\), "f", \((t)\), "b", \((t)
        \), "cos", \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], "=", \(\[Integral]\_0\%\[Epsilon]\), \(\[InvisibleSpace]\([
        f \((t)\) b \((t)\) + f \((\(-t\))\) b \((\(-t\))\)]\)\), "cos", 
        \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], ";"}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.4", "4.5"}],

Cell["similarly, the integral over the third region is, ", "Text",
  CellTags->{"S1.7.4", "4.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(L - \[Epsilon]\)\%\(L + \[Epsilon]\)\), "f", \((t)\), 
        "b", \((t)\), "cos", \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], "=", \(\[Integral]\_\(L - \[Epsilon]\)\%L\), 
        \(\[InvisibleSpace]\([
        f \((t)\) b \((t)\) - f \((2  L - t)\) b \((2  L - t)\)]\)\), "cos", 
        \(\[Pi]\/L\), \((k + 1\/2)\), \(t\ \), 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S1.7.4", "4.7"}],

Cell["So if we define the following function ", "Text",
  CellTags->{"S1.7.4", "4.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\&~\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                
                StyleBox[
                  \(f \((t)\) b \((t)\) + f \((\(-t\))\) b \((\(-t\))\)\),
                  "DisplayFormula"], 
                
                StyleBox[\(" for " 0 \[LessEqual] t \[LessEqual] \[Epsilon]\),
                  
                  "DisplayFormula"]},
              {
                StyleBox[\(f \((t)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" for " \[Epsilon] \[LessEqual] t \[LessEqual] L - 
                    \[Epsilon]\),
                  "DisplayFormula"]},
              {
                
                StyleBox[
                  \(f \((t)\) b \((t)\) - f \((2 L - t)\) b \((2 L - t)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" for " L - \[Epsilon] \[LessEqual] t \[LessEqual] L, \),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.8) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.4", "4.9"}],

Cell[TextData[{
  "we see that the local cosine transform of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " with smooth window ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " is equivalent to a Cos\[Hyphen]IV transform (",
  StyleBox["i.e.", "TI"],
  ", with rectangular window) of the corresponding function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". So all we need to do to get local cosine transform using a window ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " is to first \"modify\" the function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " in the regions where windows overlap to ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\) \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " according to (",
  ButtonBox["7.8",
    ButtonData:>{"Wavelets 1.7.4", "4.9"},
    ButtonStyle->"AddOnsLink"],
  "). This process is called \"folding\" since around the endpoints of the \
interval the function outside the interval is folded back in, added to or \
subtracted from the function values inside the interval.For local cosine \
transforms, we see from (",
  ButtonBox["7.8",
    ButtonData:>{"Wavelets 1.7.4", "4.9"},
    ButtonStyle->"AddOnsLink"],
  ") that the values are added at the left endpoint, and hence, we say it has \
a positive polarity; whereas at the right endpoint they are subtracted, and \
hence, it has a negative polarity. So we say that the Cos\[Hyphen]IV basis \
has ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+, -\))\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " polarity. For local sine transforms the polarities are reversed, that is, \
the Sin\[Hyphen]IV basis has ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-, +\))\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " polarity, and it is equivalent to doing Sine\[Hyphen]IV transform of the \
following ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " function: "
}], "Text",
  CellTags->{"S1.7.4", "4.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\&~\), \((t)\), "=", 
        RowBox[{"{", GridBox[{
              {
                
                StyleBox[
                  \(f \((t)\) b \((t)\) - f \((\(-t\))\) b \((\(-t\))\)\),
                  "DisplayFormula"], 
                
                StyleBox[\(" for " 0 \[LessEqual] t \[LessEqual] \[Epsilon]\),
                  
                  "DisplayFormula"]},
              {
                StyleBox[\(f \((t)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" for " \[Epsilon] \[LessEqual] t \[LessEqual] L - 
                    \[Epsilon]\),
                  "DisplayFormula"]},
              {
                
                StyleBox[
                  \(f \((t)\) b \((t)\) + f \((2 L - t)\) b \((2 L - t)\)\),
                  "DisplayFormula"], 
                
                StyleBox[
                  \(" for " L - \[Epsilon] \[LessEqual] t \[LessEqual] L.\),
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(7.9) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S1.7.4", "4.11"}],

Cell[TextData[{
  "In practice, we again use the discretized version of the transform. Apart \
from the complication of folding, it can be done following exactly the case \
of discrete cosine or sine transform presented in Section ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.1"},
    ButtonStyle->"AddOnsLink"],
  ". We have designed the functions ",
  StyleBox["CosTransform", "MR"],
  ", ",
  StyleBox["SinTransform", "MR"],
  ", ",
  StyleBox["InverseSinTransform", "MR"],
  ", and ",
  StyleBox["InverseCosTransform", "MR"],
  " to do this case also. However, we need to specify the taper function and \
the taper width ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". This is done again by setting the option ",
  StyleBox["Taper", "MR"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S1.7.4"],
  StyleBox["taperfunction", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["epsilon", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ", where ",
  StyleBox["taperfunction", "TI"],
  " can be ",
  StyleBox["Polynomial[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", ",
  StyleBox["Trig[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", or other taper functions of your choice which must be input as a pure \
function. The second argument, ",
  StyleBox["epsilon", "TI"],
  ", specifies the taper width, that is, the number of sites to be affected \
by folding. The transform assumes that the intervals are all equal in length \
and that the windows are equal and symmetric. \nIt turns out that the bases \
of different intervals can be orthogonal only if they have opposite \
polarities in the overlapping region. Since Cos\[Hyphen]II (Sin\[Hyphen]II) \
basis has polarity ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(+, +\))\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-, -\))\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  "), it does not form a smooth orthonormal basis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\^2\) \((R)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " by itself as Cos\[Hyphen]IV does. However, we can alternate the cosine \
and sine bases according to whether the interval label ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " is even or odd. This leads to what is called Malvar wavelets or Malvar \
basis of the second kind. That is, the Malvar basis of the second kind is \
defined to be: for ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " even the basis functions are"
}], "Text",
  CellTags->{"S1.7.4", "4.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`{\(s\_k\) \(\@\(2\/L\_j\)\) cos \(\( k  \[Pi]\)\/L\_j\) \((t - a\_j)\)}
        \ \ \ k = 0, 1, 2, \[Ellipsis]\)], "DisplayFormula",
  CellTags->{"S1.7.4", "4.13"}],

Cell[TextData[{
  "and for ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " odd the basis functions are "
}], "Text",
  CellTags->{"S1.7.4", "4.14"}],

Cell[BoxData[
    \(TraditionalForm
    \`{\(\@\(2\/L\_j\)\) sin \(\( k  \[Pi]\)\/L\_j\) \((t - a\_j)\)} \(, 
      \ \ \ \) k = 1, 2, \[Ellipsis].\)], "DisplayFormula",
  CellTags->{"S1.7.4", "4.15"}],

Cell["\<\
The discretized version of the transform using Malvar basis of the \
second kind is accomplished using the function \
\>", "Text",
  CellTags->{"S1.7.4", "4.16"}],

Cell[TextData[{
  StyleBox["MalvarTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.4", "4.17"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " is the width of the window. The inverse transforms can be done using ",
  StyleBox["InverseMalvarTransform", "MR"],
  ". \nAs an example, let us consider the following signal: ",
  Cell[BoxData[
      \(TraditionalForm
      \`f \((t)\) = sin \((512  \[Pi] \((1 - 1.5  t)\) t)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.4"],
  ". "
}], "Text",
  CellTags->{"S1.7.4", "4.18"}],

Cell[TextData[{
  "The signal is sampled uniformly on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 1]\)\)\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " 1024 times."
}], "MathCaption",
  CellTags->{"S1.7.4", "4.19"}],

Cell["\<\
data=Table[Sin[N[512 Pi](1-1.5t)t],
{t, 0, 1.-1/1024, 1/1024}];\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S1.7.4"],

Cell[TextData[{
  "This gives the local cosine transform of ",
  StyleBox["data", "TI"],
  " using the default taper function ",
  StyleBox["Polynomial[2]", "MR"],
  " and default taper width ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 4\)], "InlineFormula",
    CellTags->"S1.7.4"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.4", "4.20"}],

Cell["cosdata = CosTransform[data, 64];", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S1.7.4"],

Cell["\<\
The output is a list of 16 blocks, each of which has a size of \
64.\
\>", "MathCaption",
  CellTags->{"S1.7.4", "4.21"}],

Cell[CellGroupData[{

Cell["Dimensions[cosdata]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S1.7.4"],

Cell[BoxData[
    \({16, 64}\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S1.7.4"]
}, Open  ]],

Cell[TextData[{
  "These are the coefficients of the local cosine transform. The data are \
first partitioned into blocks of size 64, then the discrete smooth cosine \
transform is preformed on each block. The output is a list of ",
  Cell[BoxData[
      \(TraditionalForm\`1024/64 = 16\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " blocks, each containing the coefficients of the basis function ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(\@\(2/N\)\) cos \( \[Pi]\/N\) \((k + 1\/2)\) \((i + 1\/2)\)\)], 
    "InlineFormula",
    CellTags->"S1.7.4"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N = 64\)], "InlineFormula",
    CellTags->"S1.7.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], 63\)], "InlineFormula",
    CellTags->"S1.7.4"],
  ". The default window function is used and it has been taken care of by the \
folding procedure as explained earlier. \nWe can plot the coefficients using \
",
  StyleBox["PlotCoefficients", "MR"],
  ". Instead of stacking all 16 graphs together, we separate them into three \
groups and plot them one by one."
}], "Text",
  CellTags->{"S1.7.4", "4.22"}],

Cell["\<\
These are plots of the first 4 blocks of coefficients. Each block \
represents a particular time range, with the bottom plot corresponding to the \
earliest time. We see that as time increases, the frequencies of significant \
coefficients shift toward the left, that is, they decrease.\
\>", 
  "MathCaption",
  CellTags->{"S1.7.4", "4.23"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[Take[cosdata, 4], Frame -> True,
FrameTicks -> {Automatic, None}]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S1.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0147151 0.0175586 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -6 -9 ]
[.17262 -0.0125 6 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(10)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(20)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(30)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(40)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(50)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(60)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17262 .61178 m
.17262 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.47024 .61178 m
.47024 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.91667 .61178 m
.91667 .61803 L
s
.125 Mabswid
.05357 .61428 m
.05357 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.35119 .61428 m
.35119 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.64881 .61428 m
.64881 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.94643 .61428 m
.94643 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .14538 m
.02381 .14667 L
s
.03869 .14538 m
.03869 .14657 L
s
.05357 .14538 m
.05357 .14678 L
s
.06845 .14538 m
.06845 .14649 L
s
.08333 .14538 m
.08333 .1469 L
s
.09821 .14538 m
.09821 .14645 L
s
.1131 .14538 m
.1131 .14702 L
s
.12798 .14538 m
.12798 .14646 L
s
.14286 .14538 m
.14286 .14712 L
s
.15774 .14538 m
.15774 .14653 L
s
.17262 .14538 m
.17262 .14719 L
s
.1875 .14538 m
.1875 .14668 L
s
.20238 .14538 m
.20238 .14723 L
s
.21726 .14538 m
.21726 .14694 L
s
.23214 .14538 m
.23214 .1472 L
s
.24702 .14538 m
.24702 .14733 L
s
.2619 .14538 m
.2619 .14709 L
s
.27679 .14538 m
.27679 .14793 L
s
.29167 .14538 m
.29167 .14685 L
s
.30655 .14538 m
.30655 .14882 L
s
.32143 .14538 m
.32143 .14639 L
s
.33631 .14538 m
.33631 .15018 L
s
.35119 .14538 m
.35119 .14566 L
s
.36607 .14538 m
.36607 .15199 L
s
.38095 .14538 m
.38095 .14586 L
s
.39583 .14538 m
.39583 .14947 L
s
.41071 .14538 m
.41071 .16331 L
s
.4256 .14538 m
.4256 .1089 L
s
.44048 .14538 m
.44048 .21527 L
s
.45536 .14538 m
.45536 .15771 L
s
.47024 .14538 m
.47024 .1182 L
s
.48512 .14538 m
.48512 .10773 L
s
.5 .14538 m
.5 .12585 L
s
.51488 .14538 m
.51488 .12857 L
s
.52976 .14538 m
.52976 .1388 L
s
.54464 .14538 m
.54464 .13711 L
s
.55952 .14538 m
.55952 .14265 L
s
.5744 .14538 m
.5744 .14035 L
s
.58929 .14538 m
.58929 .14394 L
s
.60417 .14538 m
.60417 .14201 L
s
.61905 .14538 m
.61905 .14446 L
s
.63393 .14538 m
.63393 .14304 L
s
.64881 .14538 m
.64881 .1447 L
s
.66369 .14538 m
.66369 .14375 L
s
.67857 .14538 m
.67857 .14482 L
s
.69345 .14538 m
.69345 .14426 L
s
.70833 .14538 m
.70833 .14489 L
s
.72321 .14538 m
.72321 .14463 L
s
.7381 .14538 m
.7381 .14495 L
s
.75298 .14538 m
.75298 .1449 L
s
.76786 .14538 m
.76786 .145 L
s
.78274 .14538 m
.78274 .14509 L
s
.79762 .14538 m
.79762 .14505 L
s
.8125 .14538 m
.8125 .14521 L
s
.82738 .14538 m
.82738 .14511 L
s
.84226 .14538 m
.84226 .1453 L
s
.85714 .14538 m
.85714 .14516 L
s
.87202 .14538 m
.87202 .14535 L
s
.8869 .14538 m
.8869 .14521 L
s
.90179 .14538 m
.90179 .14538 L
s
.91667 .14538 m
.91667 .14525 L
s
.93155 .14538 m
.93155 .14541 L
s
.94643 .14538 m
.94643 .14529 L
s
.96131 .14538 m
.96131 .14543 L
s
.02381 .29693 m
.02381 .29712 L
s
.03869 .29693 m
.03869 .29723 L
s
.05357 .29693 m
.05357 .29699 L
s
.06845 .29693 m
.06845 .29732 L
s
.08333 .29693 m
.08333 .29689 L
s
.09821 .29693 m
.09821 .29736 L
s
.1131 .29693 m
.1131 .29681 L
s
.12798 .29693 m
.12798 .2973 L
s
.14286 .29693 m
.14286 .29677 L
s
.15774 .29693 m
.15774 .29712 L
s
.17262 .29693 m
.17262 .29678 L
s
.1875 .29693 m
.1875 .29674 L
s
.20238 .29693 m
.20238 .29688 L
s
.21726 .29693 m
.21726 .29608 L
s
.23214 .29693 m
.23214 .29707 L
s
.24702 .29693 m
.24702 .29503 L
s
.2619 .29693 m
.2619 .29729 L
s
.27679 .29693 m
.27679 .29386 L
s
.29167 .29693 m
.29167 .29583 L
s
.30655 .29693 m
.30655 .29809 L
s
.32143 .29693 m
.32143 .27578 L
s
.33631 .29693 m
.33631 .33876 L
s
.35119 .29693 m
.35119 .2316 L
s
.36607 .29693 m
.36607 .27648 L
s
.38095 .29693 m
.38095 .32035 L
s
.39583 .29693 m
.39583 .33412 L
s
.41071 .29693 m
.41071 .3188 L
s
.4256 .29693 m
.4256 .31579 L
s
.44048 .29693 m
.44048 .30596 L
s
.45536 .29693 m
.45536 .30703 L
s
.47024 .29693 m
.47024 .30157 L
s
.48512 .29693 m
.48512 .30342 L
s
.5 .29693 m
.5 .29983 L
s
.51488 .29693 m
.51488 .30145 L
s
.52976 .29693 m
.52976 .29894 L
s
.54464 .29693 m
.54464 .30013 L
s
.55952 .29693 m
.55952 .29839 L
s
.5744 .29693 m
.5744 .29917 L
s
.58929 .29693 m
.58929 .298 L
s
.60417 .29693 m
.60417 .29843 L
s
.61905 .29693 m
.61905 .29771 L
s
.63393 .29693 m
.63393 .29786 L
s
.64881 .29693 m
.64881 .29749 L
s
.66369 .29693 m
.66369 .29744 L
s
.67857 .29693 m
.67857 .2973 L
s
.69345 .29693 m
.69345 .29713 L
s
.70833 .29693 m
.70833 .29715 L
s
.72321 .29693 m
.72321 .29691 L
s
.7381 .29693 m
.7381 .29703 L
s
.75298 .29693 m
.75298 .29678 L
s
.76786 .29693 m
.76786 .29694 L
s
.78274 .29693 m
.78274 .29672 L
s
.79762 .29693 m
.79762 .29687 L
s
.8125 .29693 m
.8125 .2967 L
s
.82738 .29693 m
.82738 .29683 L
s
.84226 .29693 m
.84226 .29673 L
s
.85714 .29693 m
.85714 .29681 L
s
.87202 .29693 m
.87202 .29677 L
s
.8869 .29693 m
.8869 .2968 L
s
.90179 .29693 m
.90179 .29683 L
s
.91667 .29693 m
.91667 .29682 L
s
.93155 .29693 m
.93155 .2969 L
s
.94643 .29693 m
.94643 .29686 L
s
.96131 .29693 m
.96131 .29696 L
s
.02381 .42759 m
.02381 .42737 L
s
.03869 .42759 m
.03869 .42734 L
s
.05357 .42759 m
.05357 .42749 L
s
.06845 .42759 m
.06845 .42743 L
s
.08333 .42759 m
.08333 .42766 L
s
.09821 .42759 m
.09821 .42768 L
s
.1131 .42759 m
.1131 .42785 L
s
.12798 .42759 m
.12798 .42816 L
s
.14286 .42759 m
.14286 .42807 L
s
.15774 .42759 m
.15774 .42891 L
s
.17262 .42759 m
.17262 .42851 L
s
.1875 .42759 m
.1875 .42942 L
s
.20238 .42759 m
.20238 .43131 L
s
.21726 .42759 m
.21726 .42352 L
s
.23214 .42759 m
.23214 .45358 L
s
.24702 .42759 m
.24702 .38353 L
s
.2619 .42759 m
.2619 .48903 L
s
.27679 .42759 m
.27679 .45781 L
s
.29167 .42759 m
.29167 .41045 L
s
.30655 .42759 m
.30655 .39359 L
s
.32143 .42759 m
.32143 .40575 L
s
.33631 .42759 m
.33631 .40881 L
s
.35119 .42759 m
.35119 .41803 L
s
.36607 .42759 m
.36607 .41739 L
s
.38095 .42759 m
.38095 .42266 L
s
.39583 .42759 m
.39583 .42104 L
s
.41071 .42759 m
.41071 .42458 L
s
.4256 .42759 m
.4256 .42305 L
s
.44048 .42759 m
.44048 .42557 L
s
.45536 .42759 m
.45536 .42439 L
s
.47024 .42759 m
.47024 .42618 L
s
.48512 .42759 m
.48512 .42537 L
s
.5 .42759 m
.5 .42658 L
s
.51488 .42759 m
.51488 .42611 L
s
.52976 .42759 m
.52976 .42687 L
s
.54464 .42759 m
.54464 .42668 L
s
.55952 .42759 m
.55952 .42709 L
s
.5744 .42759 m
.5744 .42711 L
s
.58929 .42759 m
.58929 .42725 L
s
.60417 .42759 m
.60417 .42741 L
s
.61905 .42759 m
.61905 .42738 L
s
.63393 .42759 m
.63393 .42762 L
s
.64881 .42759 m
.64881 .42747 L
s
.66369 .42759 m
.66369 .42774 L
s
.67857 .42759 m
.67857 .42754 L
s
.69345 .42759 m
.69345 .4278 L
s
.70833 .42759 m
.70833 .42759 L
s
.72321 .42759 m
.72321 .42782 L
s
.7381 .42759 m
.7381 .42762 L
s
.75298 .42759 m
.75298 .4278 L
s
.76786 .42759 m
.76786 .42764 L
s
.78274 .42759 m
.78274 .42776 L
s
.79762 .42759 m
.79762 .42766 L
s
.8125 .42759 m
.8125 .42771 L
s
.82738 .42759 m
.82738 .42766 L
s
.84226 .42759 m
.84226 .42766 L
s
.85714 .42759 m
.85714 .42767 L
s
.87202 .42759 m
.87202 .42761 L
s
.8869 .42759 m
.8869 .42767 L
s
.90179 .42759 m
.90179 .42758 L
s
.91667 .42759 m
.91667 .42767 L
s
.93155 .42759 m
.93155 .42755 L
s
.94643 .42759 m
.94643 .42766 L
s
.96131 .42759 m
.96131 .42754 L
s
.02381 .55826 m
.02381 .55735 L
s
.03869 .55826 m
.03869 .55726 L
s
.05357 .55826 m
.05357 .55716 L
s
.06845 .55826 m
.06845 .55698 L
s
.08333 .55826 m
.08333 .55639 L
s
.09821 .55826 m
.09821 .55726 L
s
.1131 .55826 m
.1131 .55251 L
s
.12798 .55826 m
.12798 .56481 L
s
.14286 .55826 m
.14286 .52862 L
s
.15774 .55826 m
.15774 .60332 L
s
.17262 .55826 m
.17262 .50268 L
s
.1875 .55826 m
.1875 .51873 L
s
.20238 .55826 m
.20238 .56933 L
s
.21726 .55826 m
.21726 .58819 L
s
.23214 .55826 m
.23214 .58009 L
s
.24702 .55826 m
.24702 .57645 L
s
.2619 .55826 m
.2619 .56852 L
s
.27679 .55826 m
.27679 .56829 L
s
.29167 .55826 m
.29167 .56364 L
s
.30655 .55826 m
.30655 .5647 L
s
.32143 .55826 m
.32143 .56146 L
s
.33631 .55826 m
.33631 .56272 L
s
.35119 .55826 m
.35119 .56028 L
s
.36607 .55826 m
.36607 .5614 L
s
.38095 .55826 m
.38095 .55956 L
s
.39583 .55826 m
.39583 .56044 L
s
.41071 .55826 m
.41071 .55909 L
s
.4256 .55826 m
.4256 .55971 L
s
.44048 .55826 m
.44048 .55877 L
s
.45536 .55826 m
.45536 .55915 L
s
.47024 .55826 m
.47024 .55856 L
s
.48512 .55826 m
.48512 .55873 L
s
.5 .55826 m
.5 .55842 L
s
.51488 .55826 m
.51488 .55842 L
s
.52976 .55826 m
.52976 .55833 L
s
.54464 .55826 m
.54464 .55822 L
s
.55952 .55826 m
.55952 .55828 L
s
.5744 .55826 m
.5744 .55809 L
s
.58929 .55826 m
.58929 .55826 L
s
.60417 .55826 m
.60417 .55804 L
s
.61905 .55826 m
.61905 .55824 L
s
.63393 .55826 m
.63393 .55803 L
s
.64881 .55826 m
.64881 .55824 L
s
.66369 .55826 m
.66369 .55805 L
s
.67857 .55826 m
.67857 .55825 L
s
.69345 .55826 m
.69345 .5581 L
s
.70833 .55826 m
.70833 .55826 L
s
.72321 .55826 m
.72321 .55815 L
s
.7381 .55826 m
.7381 .55827 L
s
.75298 .55826 m
.75298 .55821 L
s
.76786 .55826 m
.76786 .55827 L
s
.78274 .55826 m
.78274 .55825 L
s
.79762 .55826 m
.79762 .55828 L
s
.8125 .55826 m
.8125 .55829 L
s
.82738 .55826 m
.82738 .55827 L
s
.84226 .55826 m
.84226 .55831 L
s
.85714 .55826 m
.85714 .55827 L
s
.87202 .55826 m
.87202 .55832 L
s
.8869 .55826 m
.8869 .55826 L
s
.90179 .55826 m
.90179 .55832 L
s
.91667 .55826 m
.91667 .55825 L
s
.93155 .55826 m
.93155 .55831 L
s
.94643 .55826 m
.94643 .55823 L
s
.96131 .55826 m
.96131 .5583 L
s
0 1 1 r
.02381 .14538 m
.97619 .14538 L
s
.02381 .29693 m
.97619 .29693 L
s
.02381 .42759 m
.97619 .42759 L
s
.02381 .55826 m
.97619 .55826 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],

Cell["\<\
These are the next 6 blocks. The frequencies decrease first and \
then increase.\
\>", "MathCaption",
  CellTags->{"S1.7.4", "4.24"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[Take[cosdata, {5, 10}], Frame -> True,
FrameTicks -> {Automatic, None}]\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S1.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0147151 0.011735 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -6 -9 ]
[.17262 -0.0125 6 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(10)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(20)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(30)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(40)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(50)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(60)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17262 .61178 m
.17262 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.47024 .61178 m
.47024 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.91667 .61178 m
.91667 .61803 L
s
.125 Mabswid
.05357 .61428 m
.05357 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.35119 .61428 m
.35119 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.64881 .61428 m
.64881 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.94643 .61428 m
.94643 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10913 m
.02381 .11448 L
s
.03869 .10913 m
.03869 .10533 L
s
.05357 .10913 m
.05357 .13165 L
s
.06845 .10913 m
.06845 .08035 L
s
.08333 .10913 m
.08333 .14201 L
s
.09821 .10913 m
.09821 .14221 L
s
.1131 .10913 m
.1131 .1061 L
s
.12798 .10913 m
.12798 .09307 L
s
.14286 .10913 m
.14286 .09477 L
s
.15774 .10913 m
.15774 .09824 L
s
.17262 .10913 m
.17262 .10168 L
s
.1875 .10913 m
.1875 .10316 L
s
.20238 .10913 m
.20238 .10493 L
s
.21726 .10913 m
.21726 .10535 L
s
.23214 .10913 m
.23214 .10647 L
s
.24702 .10913 m
.24702 .10653 L
s
.2619 .10913 m
.2619 .10736 L
s
.27679 .10913 m
.27679 .10729 L
s
.29167 .10913 m
.29167 .10795 L
s
.30655 .10913 m
.30655 .10785 L
s
.32143 .10913 m
.32143 .10837 L
s
.33631 .10913 m
.33631 .10827 L
s
.35119 .10913 m
.35119 .10868 L
s
.36607 .10913 m
.36607 .10859 L
s
.38095 .10913 m
.38095 .1089 L
s
.39583 .10913 m
.39583 .10883 L
s
.41071 .10913 m
.41071 .10905 L
s
.4256 .10913 m
.4256 .10901 L
s
.44048 .10913 m
.44048 .10915 L
s
.45536 .10913 m
.45536 .10914 L
s
.47024 .10913 m
.47024 .10921 L
s
.48512 .10913 m
.48512 .10922 L
s
.5 .10913 m
.5 .10924 L
s
.51488 .10913 m
.51488 .10926 L
s
.52976 .10913 m
.52976 .10924 L
s
.54464 .10913 m
.54464 .10927 L
s
.55952 .10913 m
.55952 .10923 L
s
.5744 .10913 m
.5744 .10926 L
s
.58929 .10913 m
.58929 .1092 L
s
.60417 .10913 m
.60417 .10923 L
s
.61905 .10913 m
.61905 .10918 L
s
.63393 .10913 m
.63393 .1092 L
s
.64881 .10913 m
.64881 .10915 L
s
.66369 .10913 m
.66369 .10917 L
s
.67857 .10913 m
.67857 .10913 L
s
.69345 .10913 m
.69345 .10915 L
s
.70833 .10913 m
.70833 .10911 L
s
.72321 .10913 m
.72321 .10912 L
s
.7381 .10913 m
.7381 .1091 L
s
.75298 .10913 m
.75298 .10911 L
s
.76786 .10913 m
.76786 .1091 L
s
.78274 .10913 m
.78274 .1091 L
s
.79762 .10913 m
.79762 .1091 L
s
.8125 .10913 m
.8125 .10909 L
s
.82738 .10913 m
.82738 .1091 L
s
.84226 .10913 m
.84226 .10909 L
s
.85714 .10913 m
.85714 .10911 L
s
.87202 .10913 m
.87202 .1091 L
s
.8869 .10913 m
.8869 .10911 L
s
.90179 .10913 m
.90179 .10911 L
s
.91667 .10913 m
.91667 .10912 L
s
.93155 .10913 m
.93155 .10912 L
s
.94643 .10913 m
.94643 .10913 L
s
.96131 .10913 m
.96131 .10913 L
s
.02381 .20355 m
.02381 .16493 L
s
.03869 .20355 m
.03869 .18904 L
s
.05357 .20355 m
.05357 .24661 L
s
.06845 .20355 m
.06845 .18969 L
s
.08333 .20355 m
.08333 .21864 L
s
.09821 .20355 m
.09821 .20212 L
s
.1131 .20355 m
.1131 .20884 L
s
.12798 .20355 m
.12798 .20386 L
s
.14286 .20355 m
.14286 .20642 L
s
.15774 .20355 m
.15774 .20387 L
s
.17262 .20355 m
.17262 .20552 L
s
.1875 .20355 m
.1875 .20372 L
s
.20238 .20355 m
.20238 .20503 L
s
.21726 .20355 m
.21726 .20358 L
s
.23214 .20355 m
.23214 .20471 L
s
.24702 .20355 m
.24702 .20348 L
s
.2619 .20355 m
.2619 .20446 L
s
.27679 .20355 m
.27679 .20341 L
s
.29167 .20355 m
.29167 .20425 L
s
.30655 .20355 m
.30655 .20337 L
s
.32143 .20355 m
.32143 .20407 L
s
.33631 .20355 m
.33631 .20335 L
s
.35119 .20355 m
.35119 .20392 L
s
.36607 .20355 m
.36607 .20336 L
s
.38095 .20355 m
.38095 .20379 L
s
.39583 .20355 m
.39583 .20338 L
s
.41071 .20355 m
.41071 .20368 L
s
.4256 .20355 m
.4256 .20341 L
s
.44048 .20355 m
.44048 .2036 L
s
.45536 .20355 m
.45536 .20344 L
s
.47024 .20355 m
.47024 .20354 L
s
.48512 .20355 m
.48512 .20348 L
s
.5 .20355 m
.5 .2035 L
s
.51488 .20355 m
.51488 .20351 L
s
.52976 .20355 m
.52976 .20348 L
s
.54464 .20355 m
.54464 .20354 L
s
.55952 .20355 m
.55952 .20348 L
s
.5744 .20355 m
.5744 .20356 L
s
.58929 .20355 m
.58929 .20348 L
s
.60417 .20355 m
.60417 .20358 L
s
.61905 .20355 m
.61905 .20349 L
s
.63393 .20355 m
.63393 .20359 L
s
.64881 .20355 m
.64881 .20351 L
s
.66369 .20355 m
.66369 .20359 L
s
.67857 .20355 m
.67857 .20353 L
s
.69345 .20355 m
.69345 .20359 L
s
.70833 .20355 m
.70833 .20354 L
s
.72321 .20355 m
.72321 .20358 L
s
.7381 .20355 m
.7381 .20356 L
s
.75298 .20355 m
.75298 .20358 L
s
.76786 .20355 m
.76786 .20356 L
s
.78274 .20355 m
.78274 .20357 L
s
.79762 .20355 m
.79762 .20357 L
s
.8125 .20355 m
.8125 .20356 L
s
.82738 .20355 m
.82738 .20357 L
s
.84226 .20355 m
.84226 .20356 L
s
.85714 .20355 m
.85714 .20357 L
s
.87202 .20355 m
.87202 .20355 L
s
.8869 .20355 m
.8869 .20357 L
s
.90179 .20355 m
.90179 .20355 L
s
.91667 .20355 m
.91667 .20357 L
s
.93155 .20355 m
.93155 .20354 L
s
.94643 .20355 m
.94643 .20357 L
s
.96131 .20355 m
.96131 .20354 L
s
.02381 .29797 m
.02381 .28865 L
s
.03869 .29797 m
.03869 .28764 L
s
.05357 .29797 m
.05357 .28611 L
s
.06845 .29797 m
.06845 .28374 L
s
.08333 .29797 m
.08333 .28677 L
s
.09821 .29797 m
.09821 .30287 L
s
.1131 .29797 m
.1131 .33783 L
s
.12798 .29797 m
.12798 .31932 L
s
.14286 .29797 m
.14286 .26854 L
s
.15774 .29797 m
.15774 .3233 L
s
.17262 .29797 m
.17262 .28807 L
s
.1875 .29797 m
.1875 .3065 L
s
.20238 .29797 m
.20238 .29547 L
s
.21726 .29797 m
.21726 .30219 L
s
.23214 .29797 m
.23214 .29686 L
s
.24702 .29797 m
.24702 .30079 L
s
.2619 .29797 m
.2619 .29716 L
s
.27679 .29797 m
.27679 .30006 L
s
.29167 .29797 m
.29167 .29725 L
s
.30655 .29797 m
.30655 .29956 L
s
.32143 .29797 m
.32143 .2973 L
s
.33631 .29797 m
.33631 .29916 L
s
.35119 .29797 m
.35119 .29736 L
s
.36607 .29797 m
.36607 .29883 L
s
.38095 .29797 m
.38095 .29743 L
s
.39583 .29797 m
.39583 .29856 L
s
.41071 .29797 m
.41071 .29751 L
s
.4256 .29797 m
.4256 .29834 L
s
.44048 .29797 m
.44048 .2976 L
s
.45536 .29797 m
.45536 .29817 L
s
.47024 .29797 m
.47024 .2977 L
s
.48512 .29797 m
.48512 .29804 L
s
.5 .29797 m
.5 .29779 L
s
.51488 .29797 m
.51488 .29795 L
s
.52976 .29797 m
.52976 .29787 L
s
.54464 .29797 m
.54464 .2979 L
s
.55952 .29797 m
.55952 .29794 L
s
.5744 .29797 m
.5744 .29787 L
s
.58929 .29797 m
.58929 .29799 L
s
.60417 .29797 m
.60417 .29786 L
s
.61905 .29797 m
.61905 .29802 L
s
.63393 .29797 m
.63393 .29787 L
s
.64881 .29797 m
.64881 .29804 L
s
.66369 .29797 m
.66369 .29789 L
s
.67857 .29797 m
.67857 .29805 L
s
.69345 .29797 m
.69345 .29792 L
s
.70833 .29797 m
.70833 .29805 L
s
.72321 .29797 m
.72321 .29794 L
s
.7381 .29797 m
.7381 .29804 L
s
.75298 .29797 m
.75298 .29796 L
s
.76786 .29797 m
.76786 .29802 L
s
.78274 .29797 m
.78274 .29798 L
s
.79762 .29797 m
.79762 .298 L
s
.8125 .29797 m
.8125 .298 L
s
.82738 .29797 m
.82738 .29799 L
s
.84226 .29797 m
.84226 .298 L
s
.85714 .29797 m
.85714 .29797 L
s
.87202 .29797 m
.87202 .29801 L
s
.8869 .29797 m
.8869 .29796 L
s
.90179 .29797 m
.90179 .29801 L
s
.91667 .29797 m
.91667 .29795 L
s
.93155 .29797 m
.93155 .29801 L
s
.94643 .29797 m
.94643 .29794 L
s
.96131 .29797 m
.96131 .29801 L
s
.02381 .39239 m
.02381 .39454 L
s
.03869 .39239 m
.03869 .39459 L
s
.05357 .39239 m
.05357 .39487 L
s
.06845 .39239 m
.06845 .3951 L
s
.08333 .39239 m
.08333 .39569 L
s
.09821 .39239 m
.09821 .39633 L
s
.1131 .39239 m
.1131 .3974 L
s
.12798 .39239 m
.12798 .39902 L
s
.14286 .39239 m
.14286 .40072 L
s
.15774 .39239 m
.15774 .40282 L
s
.17262 .39239 m
.17262 .39825 L
s
.1875 .39239 m
.1875 .38135 L
s
.20238 .39239 m
.20238 .3485 L
s
.21726 .39239 m
.21726 .37595 L
s
.23214 .39239 m
.23214 .41958 L
s
.24702 .39239 m
.24702 .36536 L
s
.2619 .39239 m
.2619 .40331 L
s
.27679 .39239 m
.27679 .38211 L
s
.29167 .39239 m
.29167 .3956 L
s
.30655 .39239 m
.30655 .38714 L
s
.32143 .39239 m
.32143 .39394 L
s
.33631 .39239 m
.33631 .38899 L
s
.35119 .39239 m
.35119 .39351 L
s
.36607 .39239 m
.36607 .39 L
s
.38095 .39239 m
.38095 .39334 L
s
.39583 .39239 m
.39583 .39069 L
s
.41071 .39239 m
.41071 .39323 L
s
.4256 .39239 m
.4256 .39121 L
s
.44048 .39239 m
.44048 .39312 L
s
.45536 .39239 m
.45536 .3916 L
s
.47024 .39239 m
.47024 .39301 L
s
.48512 .39239 m
.48512 .3919 L
s
.5 .39239 m
.5 .39289 L
s
.51488 .39239 m
.51488 .39213 L
s
.52976 .39239 m
.52976 .39276 L
s
.54464 .39239 m
.54464 .39229 L
s
.55952 .39239 m
.55952 .39265 L
s
.5744 .39239 m
.5744 .39239 L
s
.58929 .39239 m
.58929 .39255 L
s
.60417 .39239 m
.60417 .39245 L
s
.61905 .39239 m
.61905 .39246 L
s
.63393 .39239 m
.63393 .39248 L
s
.64881 .39239 m
.64881 .39239 L
s
.66369 .39239 m
.66369 .39249 L
s
.67857 .39239 m
.67857 .39234 L
s
.69345 .39239 m
.69345 .39248 L
s
.70833 .39239 m
.70833 .39231 L
s
.72321 .39239 m
.72321 .39246 L
s
.7381 .39239 m
.7381 .3923 L
s
.75298 .39239 m
.75298 .39243 L
s
.76786 .39239 m
.76786 .3923 L
s
.78274 .39239 m
.78274 .3924 L
s
.79762 .39239 m
.79762 .39232 L
s
.8125 .39239 m
.8125 .39238 L
s
.82738 .39239 m
.82738 .39234 L
s
.84226 .39239 m
.84226 .39236 L
s
.85714 .39239 m
.85714 .39236 L
s
.87202 .39239 m
.87202 .39235 L
s
.8869 .39239 m
.8869 .39238 L
s
.90179 .39239 m
.90179 .39234 L
s
.91667 .39239 m
.91667 .3924 L
s
.93155 .39239 m
.93155 .39234 L
s
.94643 .39239 m
.94643 .39242 L
s
.96131 .39239 m
.96131 .39235 L
s
.02381 .48681 m
.02381 .4866 L
s
.03869 .48681 m
.03869 .48664 L
s
.05357 .48681 m
.05357 .48643 L
s
.06845 .48681 m
.06845 .48655 L
s
.08333 .48681 m
.08333 .48615 L
s
.09821 .48681 m
.09821 .48628 L
s
.1131 .48681 m
.1131 .48573 L
s
.12798 .48681 m
.12798 .4858 L
s
.14286 .48681 m
.14286 .48512 L
s
.15774 .48681 m
.15774 .48497 L
s
.17262 .48681 m
.17262 .48419 L
s
.1875 .48681 m
.1875 .48351 L
s
.20238 .48681 m
.20238 .48258 L
s
.21726 .48681 m
.21726 .48086 L
s
.23214 .48681 m
.23214 .4799 L
s
.24702 .48681 m
.24702 .4781 L
s
.2619 .48681 m
.2619 .48491 L
s
.27679 .48681 m
.27679 .502 L
s
.29167 .48681 m
.29167 .53279 L
s
.30655 .48681 m
.30655 .49665 L
s
.32143 .48681 m
.32143 .46182 L
s
.33631 .48681 m
.33631 .51397 L
s
.35119 .48681 m
.35119 .47474 L
s
.36607 .48681 m
.36607 .49792 L
s
.38095 .48681 m
.38095 .48279 L
s
.39583 .48681 m
.39583 .49255 L
s
.41071 .48681 m
.41071 .48481 L
s
.4256 .48681 m
.4256 .4905 L
s
.44048 .48681 m
.44048 .48546 L
s
.45536 .48681 m
.45536 .48938 L
s
.47024 .48681 m
.47024 .48575 L
s
.48512 .48681 m
.48512 .48863 L
s
.5 .48681 m
.5 .48594 L
s
.51488 .48681 m
.51488 .48809 L
s
.52976 .48681 m
.52976 .4861 L
s
.54464 .48681 m
.54464 .48767 L
s
.55952 .48681 m
.55952 .48624 L
s
.5744 .48681 m
.5744 .48736 L
s
.58929 .48681 m
.58929 .48637 L
s
.60417 .48681 m
.60417 .48712 L
s
.61905 .48681 m
.61905 .48649 L
s
.63393 .48681 m
.63393 .48695 L
s
.64881 .48681 m
.64881 .48659 L
s
.66369 .48681 m
.66369 .48684 L
s
.67857 .48681 m
.67857 .48669 L
s
.69345 .48681 m
.69345 .48677 L
s
.70833 .48681 m
.70833 .48676 L
s
.72321 .48681 m
.72321 .48673 L
s
.7381 .48681 m
.7381 .48681 L
s
.75298 .48681 m
.75298 .48673 L
s
.76786 .48681 m
.76786 .48685 L
s
.78274 .48681 m
.78274 .48674 L
s
.79762 .48681 m
.79762 .48686 L
s
.8125 .48681 m
.8125 .48675 L
s
.82738 .48681 m
.82738 .48686 L
s
.84226 .48681 m
.84226 .48678 L
s
.85714 .48681 m
.85714 .48686 L
s
.87202 .48681 m
.87202 .4868 L
s
.8869 .48681 m
.8869 .48684 L
s
.90179 .48681 m
.90179 .48681 L
s
.91667 .48681 m
.91667 .48683 L
s
.93155 .48681 m
.93155 .48682 L
s
.94643 .48681 m
.94643 .48681 L
s
.96131 .48681 m
.96131 .48682 L
s
.02381 .58123 m
.02381 .58102 L
s
.03869 .58123 m
.03869 .58097 L
s
.05357 .58123 m
.05357 .5811 L
s
.06845 .58123 m
.06845 .58097 L
s
.08333 .58123 m
.08333 .58122 L
s
.09821 .58123 m
.09821 .58102 L
s
.1131 .58123 m
.1131 .58138 L
s
.12798 .58123 m
.12798 .58114 L
s
.14286 .58123 m
.14286 .58159 L
s
.15774 .58123 m
.15774 .58135 L
s
.17262 .58123 m
.17262 .58185 L
s
.1875 .58123 m
.1875 .58168 L
s
.20238 .58123 m
.20238 .58219 L
s
.21726 .58123 m
.21726 .58221 L
s
.23214 .58123 m
.23214 .58267 L
s
.24702 .58123 m
.24702 .58303 L
s
.2619 .58123 m
.2619 .58341 L
s
.27679 .58123 m
.27679 .58439 L
s
.29167 .58123 m
.29167 .5847 L
s
.30655 .58123 m
.30655 .58674 L
s
.32143 .58123 m
.32143 .58655 L
s
.33631 .58123 m
.33631 .58821 L
s
.35119 .58123 m
.35119 .57903 L
s
.36607 .58123 m
.36607 .56226 L
s
.38095 .58123 m
.38095 .53402 L
s
.39583 .58123 m
.39583 .57813 L
s
.41071 .58123 m
.41071 .60332 L
s
.4256 .58123 m
.4256 .55439 L
s
.44048 .58123 m
.44048 .59405 L
s
.45536 .58123 m
.45536 .56936 L
s
.47024 .58123 m
.47024 .58586 L
s
.48512 .58123 m
.48512 .57497 L
s
.5 .58123 m
.5 .58355 L
s
.51488 .58123 m
.51488 .57719 L
s
.52976 .58123 m
.52976 .58275 L
s
.54464 .58123 m
.54464 .57842 L
s
.55952 .58123 m
.55952 .58236 L
s
.5744 .58123 m
.5744 .57924 L
s
.58929 .58123 m
.58929 .58213 L
s
.60417 .58123 m
.60417 .57984 L
s
.61905 .58123 m
.61905 .58195 L
s
.63393 .58123 m
.63393 .58029 L
s
.64881 .58123 m
.64881 .5818 L
s
.66369 .58123 m
.66369 .58064 L
s
.67857 .58123 m
.67857 .58167 L
s
.69345 .58123 m
.69345 .5809 L
s
.70833 .58123 m
.70833 .58156 L
s
.72321 .58123 m
.72321 .58108 L
s
.7381 .58123 m
.7381 .58146 L
s
.75298 .58123 m
.75298 .58121 L
s
.76786 .58123 m
.76786 .58138 L
s
.78274 .58123 m
.78274 .58129 L
s
.79762 .58123 m
.79762 .58132 L
s
.8125 .58123 m
.8125 .58133 L
s
.82738 .58123 m
.82738 .58127 L
s
.84226 .58123 m
.84226 .58135 L
s
.85714 .58123 m
.85714 .58123 L
s
.87202 .58123 m
.87202 .58135 L
s
.8869 .58123 m
.8869 .5812 L
s
.90179 .58123 m
.90179 .58134 L
s
.91667 .58123 m
.91667 .58118 L
s
.93155 .58123 m
.93155 .58133 L
s
.94643 .58123 m
.94643 .58116 L
s
.96131 .58123 m
.96131 .58131 L
s
0 1 1 r
.02381 .10913 m
.97619 .10913 L
s
.02381 .20355 m
.97619 .20355 L
s
.02381 .29797 m
.97619 .29797 L
s
.02381 .39239 m
.97619 .39239 L
s
.02381 .48681 m
.97619 .48681 L
s
.02381 .58123 m
.97619 .58123 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],

Cell["\<\
These are the last 6 blocks. The frequencies increase \
monotonically.\
\>", "MathCaption",
  CellTags->{"S1.7.4", "4.25"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[Take[cosdata, -6], Frame -> True,
FrameTicks -> {Automatic, None}]\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S1.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0147151 0.0115588 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -6 -9 ]
[.17262 -0.0125 6 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(10)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(20)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(30)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(40)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(50)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(60)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17262 .61178 m
.17262 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.47024 .61178 m
.47024 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.91667 .61178 m
.91667 .61803 L
s
.125 Mabswid
.05357 .61428 m
.05357 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.35119 .61428 m
.35119 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.64881 .61428 m
.64881 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.94643 .61428 m
.94643 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10639 m
.02381 .10649 L
s
.03869 .10639 m
.03869 .10651 L
s
.05357 .10639 m
.05357 .10647 L
s
.06845 .10639 m
.06845 .10654 L
s
.08333 .10639 m
.08333 .10645 L
s
.09821 .10639 m
.09821 .10657 L
s
.1131 .10639 m
.1131 .10643 L
s
.12798 .10639 m
.12798 .10658 L
s
.14286 .10639 m
.14286 .10639 L
s
.15774 .10639 m
.15774 .10658 L
s
.17262 .10639 m
.17262 .10634 L
s
.1875 .10639 m
.1875 .10655 L
s
.20238 .10639 m
.20238 .10627 L
s
.21726 .10639 m
.21726 .10647 L
s
.23214 .10639 m
.23214 .10616 L
s
.24702 .10639 m
.24702 .1063 L
s
.2619 .10639 m
.2619 .106 L
s
.27679 .10639 m
.27679 .10602 L
s
.29167 .10639 m
.29167 .10577 L
s
.30655 .10639 m
.30655 .10557 L
s
.32143 .10639 m
.32143 .10543 L
s
.33631 .10639 m
.33631 .10483 L
s
.35119 .10639 m
.35119 .10487 L
s
.36607 .10639 m
.36607 .10362 L
s
.38095 .10639 m
.38095 .10392 L
s
.39583 .10639 m
.39583 .10166 L
s
.41071 .10639 m
.41071 .10291 L
s
.4256 .10639 m
.4256 .10149 L
s
.44048 .10639 m
.44048 .1126 L
s
.45536 .10639 m
.45536 .12849 L
s
.47024 .10639 m
.47024 .15311 L
s
.48512 .10639 m
.48512 .1028 L
s
.5 .10639 m
.5 .08794 L
s
.51488 .10639 m
.51488 .13197 L
s
.52976 .10639 m
.52976 .09326 L
s
.54464 .10639 m
.54464 .11858 L
s
.55952 .10639 m
.55952 .10127 L
s
.5744 .10639 m
.5744 .11294 L
s
.58929 .10639 m
.58929 .10377 L
s
.60417 .10639 m
.60417 .11061 L
s
.61905 .10639 m
.61905 .1047 L
s
.63393 .10639 m
.63393 .10932 L
s
.64881 .10639 m
.64881 .10516 L
s
.66369 .10639 m
.66369 .10845 L
s
.67857 .10639 m
.67857 .10544 L
s
.69345 .10639 m
.69345 .10782 L
s
.70833 .10639 m
.70833 .10565 L
s
.72321 .10639 m
.72321 .10734 L
s
.7381 .10639 m
.7381 .10581 L
s
.75298 .10639 m
.75298 .10697 L
s
.76786 .10639 m
.76786 .10595 L
s
.78274 .10639 m
.78274 .10669 L
s
.79762 .10639 m
.79762 .10608 L
s
.8125 .10639 m
.8125 .10649 L
s
.82738 .10639 m
.82738 .10619 L
s
.84226 .10639 m
.84226 .10635 L
s
.85714 .10639 m
.85714 .10629 L
s
.87202 .10639 m
.87202 .10626 L
s
.8869 .10639 m
.8869 .10638 L
s
.90179 .10639 m
.90179 .10622 L
s
.91667 .10639 m
.91667 .10646 L
s
.93155 .10639 m
.93155 .10621 L
s
.94643 .10639 m
.94643 .10652 L
s
.96131 .10639 m
.96131 .10623 L
s
.02381 .2104 m
.02381 .21045 L
s
.03869 .2104 m
.03869 .21045 L
s
.05357 .2104 m
.05357 .21044 L
s
.06845 .2104 m
.06845 .21044 L
s
.08333 .2104 m
.08333 .21042 L
s
.09821 .2104 m
.09821 .21041 L
s
.1131 .2104 m
.1131 .21039 L
s
.12798 .2104 m
.12798 .21036 L
s
.14286 .2104 m
.14286 .21036 L
s
.15774 .2104 m
.15774 .21031 L
s
.17262 .2104 m
.17262 .21034 L
s
.1875 .2104 m
.1875 .21025 L
s
.20238 .2104 m
.20238 .21033 L
s
.21726 .2104 m
.21726 .2102 L
s
.23214 .2104 m
.23214 .21032 L
s
.24702 .2104 m
.24702 .21017 L
s
.2619 .2104 m
.2619 .21034 L
s
.27679 .2104 m
.27679 .21018 L
s
.29167 .2104 m
.29167 .21038 L
s
.30655 .2104 m
.30655 .21024 L
s
.32143 .2104 m
.32143 .21044 L
s
.33631 .2104 m
.33631 .21037 L
s
.35119 .2104 m
.35119 .21054 L
s
.36607 .2104 m
.36607 .21062 L
s
.38095 .2104 m
.38095 .21069 L
s
.39583 .2104 m
.39583 .21104 L
s
.41071 .2104 m
.41071 .21093 L
s
.4256 .2104 m
.4256 .2117 L
s
.44048 .2104 m
.44048 .21132 L
s
.45536 .2104 m
.45536 .21278 L
s
.47024 .2104 m
.47024 .21196 L
s
.48512 .2104 m
.48512 .21435 L
s
.5 .2104 m
.5 .21212 L
s
.51488 .2104 m
.51488 .21325 L
s
.52976 .2104 m
.52976 .20037 L
s
.54464 .2104 m
.54464 .18539 L
s
.55952 .2104 m
.55952 .16457 L
s
.5744 .2104 m
.5744 .22058 L
s
.58929 .2104 m
.58929 .22523 L
s
.60417 .2104 m
.60417 .18626 L
s
.61905 .2104 m
.61905 .22382 L
s
.63393 .2104 m
.63393 .19801 L
s
.64881 .2104 m
.64881 .21602 L
s
.66369 .2104 m
.66369 .20366 L
s
.67857 .2104 m
.67857 .21333 L
s
.69345 .2104 m
.69345 .20607 L
s
.70833 .2104 m
.70833 .21225 L
s
.72321 .2104 m
.72321 .20743 L
s
.7381 .2104 m
.7381 .21169 L
s
.75298 .2104 m
.75298 .20834 L
s
.76786 .2104 m
.76786 .21133 L
s
.78274 .2104 m
.78274 .20901 L
s
.79762 .2104 m
.79762 .21106 L
s
.8125 .2104 m
.8125 .20951 L
s
.82738 .2104 m
.82738 .21085 L
s
.84226 .2104 m
.84226 .20989 L
s
.85714 .2104 m
.85714 .21067 L
s
.87202 .2104 m
.87202 .21016 L
s
.8869 .2104 m
.8869 .21053 L
s
.90179 .2104 m
.90179 .21034 L
s
.91667 .2104 m
.91667 .21042 L
s
.93155 .2104 m
.93155 .21045 L
s
.94643 .2104 m
.94643 .21035 L
s
.96131 .2104 m
.96131 .21048 L
s
.02381 .30208 m
.02381 .30203 L
s
.03869 .30208 m
.03869 .30201 L
s
.05357 .30208 m
.05357 .30204 L
s
.06845 .30208 m
.06845 .30201 L
s
.08333 .30208 m
.08333 .30206 L
s
.09821 .30208 m
.09821 .30201 L
s
.1131 .30208 m
.1131 .30208 L
s
.12798 .30208 m
.12798 .30203 L
s
.14286 .30208 m
.14286 .3021 L
s
.15774 .30208 m
.15774 .30206 L
s
.17262 .30208 m
.17262 .30212 L
s
.1875 .30208 m
.1875 .3021 L
s
.20238 .30208 m
.20238 .30214 L
s
.21726 .30208 m
.21726 .30215 L
s
.23214 .30208 m
.23214 .30216 L
s
.24702 .30208 m
.24702 .30221 L
s
.2619 .30208 m
.2619 .30218 L
s
.27679 .30208 m
.27679 .30227 L
s
.29167 .30208 m
.29167 .30219 L
s
.30655 .30208 m
.30655 .30232 L
s
.32143 .30208 m
.32143 .3022 L
s
.33631 .30208 m
.33631 .30236 L
s
.35119 .30208 m
.35119 .3022 L
s
.36607 .30208 m
.36607 .30237 L
s
.38095 .30208 m
.38095 .30219 L
s
.39583 .30208 m
.39583 .30234 L
s
.41071 .30208 m
.41071 .30217 L
s
.4256 .30208 m
.4256 .30222 L
s
.44048 .30208 m
.44048 .30213 L
s
.45536 .30208 m
.45536 .30201 L
s
.47024 .30208 m
.47024 .30206 L
s
.48512 .30208 m
.48512 .30165 L
s
.5 .30208 m
.5 .30194 L
s
.51488 .30208 m
.51488 .30106 L
s
.52976 .30208 m
.52976 .30174 L
s
.54464 .30208 m
.54464 .30015 L
s
.55952 .30208 m
.55952 .30146 L
s
.5744 .30208 m
.5744 .299 L
s
.58929 .30208 m
.58929 .30214 L
s
.60417 .30208 m
.60417 .30134 L
s
.61905 .30208 m
.61905 .31573 L
s
.63393 .30208 m
.63393 .32944 L
s
.64881 .30208 m
.64881 .3461 L
s
.66369 .30208 m
.66369 .2855 L
s
.67857 .30208 m
.67857 .29129 L
s
.69345 .30208 m
.69345 .32423 L
s
.70833 .30208 m
.70833 .28879 L
s
.72321 .30208 m
.72321 .31438 L
s
.7381 .30208 m
.7381 .29625 L
s
.75298 .30208 m
.75298 .30886 L
s
.76786 .30208 m
.76786 .2991 L
s
.78274 .30208 m
.78274 .30642 L
s
.79762 .30208 m
.79762 .30031 L
s
.8125 .30208 m
.8125 .30505 L
s
.82738 .30208 m
.82738 .30094 L
s
.84226 .30208 m
.84226 .30415 L
s
.85714 .30208 m
.85714 .30132 L
s
.87202 .30208 m
.87202 .30352 L
s
.8869 .30208 m
.8869 .30155 L
s
.90179 .30208 m
.90179 .30307 L
s
.91667 .30208 m
.91667 .30167 L
s
.93155 .30208 m
.93155 .30275 L
s
.94643 .30208 m
.94643 .30169 L
s
.96131 .30208 m
.96131 .30256 L
s
.02381 .39376 m
.02381 .39377 L
s
.03869 .39376 m
.03869 .39378 L
s
.05357 .39376 m
.05357 .39376 L
s
.06845 .39376 m
.06845 .39379 L
s
.08333 .39376 m
.08333 .39375 L
s
.09821 .39376 m
.09821 .39381 L
s
.1131 .39376 m
.1131 .39375 L
s
.12798 .39376 m
.12798 .39382 L
s
.14286 .39376 m
.14286 .39375 L
s
.15774 .39376 m
.15774 .39383 L
s
.17262 .39376 m
.17262 .39375 L
s
.1875 .39376 m
.1875 .39383 L
s
.20238 .39376 m
.20238 .39375 L
s
.21726 .39376 m
.21726 .39382 L
s
.23214 .39376 m
.23214 .39375 L
s
.24702 .39376 m
.24702 .39379 L
s
.2619 .39376 m
.2619 .39375 L
s
.27679 .39376 m
.27679 .39376 L
s
.29167 .39376 m
.29167 .39374 L
s
.30655 .39376 m
.30655 .3937 L
s
.32143 .39376 m
.32143 .39373 L
s
.33631 .39376 m
.33631 .39364 L
s
.35119 .39376 m
.35119 .39372 L
s
.36607 .39376 m
.36607 .39357 L
s
.38095 .39376 m
.38095 .3937 L
s
.39583 .39376 m
.39583 .3935 L
s
.41071 .39376 m
.41071 .39368 L
s
.4256 .39376 m
.4256 .39345 L
s
.44048 .39376 m
.44048 .39366 L
s
.45536 .39376 m
.45536 .39342 L
s
.47024 .39376 m
.47024 .39362 L
s
.48512 .39376 m
.48512 .39344 L
s
.5 .39376 m
.5 .39358 L
s
.51488 .39376 m
.51488 .39353 L
s
.52976 .39376 m
.52976 .39353 L
s
.54464 .39376 m
.54464 .39371 L
s
.55952 .39376 m
.55952 .39349 L
s
.5744 .39376 m
.5744 .39402 L
s
.58929 .39376 m
.58929 .39344 L
s
.60417 .39376 m
.60417 .39452 L
s
.61905 .39376 m
.61905 .39341 L
s
.63393 .39376 m
.63393 .39525 L
s
.64881 .39376 m
.64881 .39331 L
s
.66369 .39376 m
.66369 .39596 L
s
.67857 .39376 m
.67857 .39175 L
s
.69345 .39376 m
.69345 .39242 L
s
.70833 .39376 m
.70833 .3766 L
s
.72321 .39376 m
.72321 .36466 L
s
.7381 .39376 m
.7381 .35235 L
s
.75298 .39376 m
.75298 .41637 L
s
.76786 .39376 m
.76786 .40017 L
s
.78274 .39376 m
.78274 .37404 L
s
.79762 .39376 m
.79762 .40661 L
s
.8125 .39376 m
.8125 .38172 L
s
.82738 .39376 m
.82738 .3998 L
s
.84226 .39376 m
.84226 .38695 L
s
.85714 .39376 m
.85714 .39704 L
s
.87202 .39376 m
.87202 .38929 L
s
.8869 .39376 m
.8869 .39597 L
s
.90179 .39376 m
.90179 .39055 L
s
.91667 .39376 m
.91667 .39557 L
s
.93155 .39376 m
.93155 .39132 L
s
.94643 .39376 m
.94643 .39553 L
s
.96131 .39376 m
.96131 .39179 L
s
.02381 .48544 m
.02381 .48548 L
s
.03869 .48544 m
.03869 .48547 L
s
.05357 .48544 m
.05357 .48548 L
s
.06845 .48544 m
.06845 .48546 L
s
.08333 .48544 m
.08333 .48548 L
s
.09821 .48544 m
.09821 .48544 L
s
.1131 .48544 m
.1131 .48547 L
s
.12798 .48544 m
.12798 .48543 L
s
.14286 .48544 m
.14286 .48547 L
s
.15774 .48544 m
.15774 .48541 L
s
.17262 .48544 m
.17262 .48546 L
s
.1875 .48544 m
.1875 .48539 L
s
.20238 .48544 m
.20238 .48544 L
s
.21726 .48544 m
.21726 .48538 L
s
.23214 .48544 m
.23214 .48543 L
s
.24702 .48544 m
.24702 .48537 L
s
.2619 .48544 m
.2619 .48542 L
s
.27679 .48544 m
.27679 .48538 L
s
.29167 .48544 m
.29167 .4854 L
s
.30655 .48544 m
.30655 .48539 L
s
.32143 .48544 m
.32143 .48539 L
s
.33631 .48544 m
.33631 .48541 L
s
.35119 .48544 m
.35119 .48539 L
s
.36607 .48544 m
.36607 .48545 L
s
.38095 .48544 m
.38095 .48539 L
s
.39583 .48544 m
.39583 .48551 L
s
.41071 .48544 m
.41071 .48541 L
s
.4256 .48544 m
.4256 .48557 L
s
.44048 .48544 m
.44048 .48544 L
s
.45536 .48544 m
.45536 .48564 L
s
.47024 .48544 m
.47024 .48549 L
s
.48512 .48544 m
.48512 .48571 L
s
.5 .48544 m
.5 .48556 L
s
.51488 .48544 m
.51488 .48577 L
s
.52976 .48544 m
.52976 .48566 L
s
.54464 .48544 m
.54464 .4858 L
s
.55952 .48544 m
.55952 .48577 L
s
.5744 .48544 m
.5744 .4858 L
s
.58929 .48544 m
.58929 .4859 L
s
.60417 .48544 m
.60417 .48574 L
s
.61905 .48544 m
.61905 .48605 L
s
.63393 .48544 m
.63393 .48561 L
s
.64881 .48544 m
.64881 .4862 L
s
.66369 .48544 m
.66369 .48537 L
s
.67857 .48544 m
.67857 .48636 L
s
.69345 .48544 m
.69345 .485 L
s
.70833 .48544 m
.70833 .48653 L
s
.72321 .48544 m
.72321 .4845 L
s
.7381 .48544 m
.7381 .48689 L
s
.75298 .48544 m
.75298 .4843 L
s
.76786 .48544 m
.76786 .4891 L
s
.78274 .48544 m
.78274 .48903 L
s
.79762 .48544 m
.79762 .50523 L
s
.8125 .48544 m
.8125 .51592 L
s
.82738 .48544 m
.82738 .52256 L
s
.84226 .48544 m
.84226 .45767 L
s
.85714 .48544 m
.85714 .48243 L
s
.87202 .48544 m
.87202 .50284 L
s
.8869 .48544 m
.8869 .47179 L
s
.90179 .48544 m
.90179 .49769 L
s
.91667 .48544 m
.91667 .47734 L
s
.93155 .48544 m
.93155 .4932 L
s
.94643 .48544 m
.94643 .47934 L
s
.96131 .48544 m
.96131 .49157 L
s
.02381 .57712 m
.02381 .57707 L
s
.03869 .57712 m
.03869 .57717 L
s
.05357 .57712 m
.05357 .57698 L
s
.06845 .57712 m
.06845 .57727 L
s
.08333 .57712 m
.08333 .57688 L
s
.09821 .57712 m
.09821 .57737 L
s
.1131 .57712 m
.1131 .57679 L
s
.12798 .57712 m
.12798 .57747 L
s
.14286 .57712 m
.14286 .5767 L
s
.15774 .57712 m
.15774 .57758 L
s
.17262 .57712 m
.17262 .5766 L
s
.1875 .57712 m
.1875 .57769 L
s
.20238 .57712 m
.20238 .57652 L
s
.21726 .57712 m
.21726 .5778 L
s
.23214 .57712 m
.23214 .57644 L
s
.24702 .57712 m
.24702 .5779 L
s
.2619 .57712 m
.2619 .57637 L
s
.27679 .57712 m
.27679 .57799 L
s
.29167 .57712 m
.29167 .57632 L
s
.30655 .57712 m
.30655 .57806 L
s
.32143 .57712 m
.32143 .57628 L
s
.33631 .57712 m
.33631 .5781 L
s
.35119 .57712 m
.35119 .57626 L
s
.36607 .57712 m
.36607 .57812 L
s
.38095 .57712 m
.38095 .57626 L
s
.39583 .57712 m
.39583 .5781 L
s
.41071 .57712 m
.41071 .57627 L
s
.4256 .57712 m
.4256 .57803 L
s
.44048 .57712 m
.44048 .5763 L
s
.45536 .57712 m
.45536 .57793 L
s
.47024 .57712 m
.47024 .57635 L
s
.48512 .57712 m
.48512 .57779 L
s
.5 .57712 m
.5 .5764 L
s
.51488 .57712 m
.51488 .57761 L
s
.52976 .57712 m
.52976 .57647 L
s
.54464 .57712 m
.54464 .5774 L
s
.55952 .57712 m
.55952 .57654 L
s
.5744 .57712 m
.5744 .57718 L
s
.58929 .57712 m
.58929 .57661 L
s
.60417 .57712 m
.60417 .57695 L
s
.61905 .57712 m
.61905 .57669 L
s
.63393 .57712 m
.63393 .57673 L
s
.64881 .57712 m
.64881 .57678 L
s
.66369 .57712 m
.66369 .57654 L
s
.67857 .57712 m
.67857 .57687 L
s
.69345 .57712 m
.69345 .57638 L
s
.70833 .57712 m
.70833 .57698 L
s
.72321 .57712 m
.72321 .57627 L
s
.7381 .57712 m
.7381 .57711 L
s
.75298 .57712 m
.75298 .57621 L
s
.76786 .57712 m
.76786 .57725 L
s
.78274 .57712 m
.78274 .5762 L
s
.79762 .57712 m
.79762 .57739 L
s
.8125 .57712 m
.8125 .57616 L
s
.82738 .57712 m
.82738 .57728 L
s
.84226 .57712 m
.84226 .57544 L
s
.85714 .57712 m
.85714 .57509 L
s
.87202 .57712 m
.87202 .56898 L
s
.8869 .57712 m
.8869 .55922 L
s
.90179 .57712 m
.90179 .54235 L
s
.91667 .57712 m
.91667 .5509 L
s
.93155 .57712 m
.93155 .60332 L
s
.94643 .57712 m
.94643 .58623 L
s
.96131 .57712 m
.96131 .55129 L
s
0 1 1 r
.02381 .10639 m
.97619 .10639 L
s
.02381 .2104 m
.97619 .2104 L
s
.02381 .30208 m
.97619 .30208 L
s
.02381 .39376 m
.97619 .39376 L
s
.02381 .48544 m
.97619 .48544 L
s
.02381 .57712 m
.97619 .57712 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],

Cell[TextData[{
  "So we see from the above plots that as time increases the frequency first \
decreases and then increases. This can be seen also from the phase space plot \
or time\[Hyphen]frequency plot of these coefficients. Note that each sublist \
or block in the output of ",
  StyleBox["CosTransform", "MR"],
  " or ",
  StyleBox["SinTransform", "MR"],
  " represents a certain time range and the coefficients inside each sublist \
are arranged according to increasing frequency. In contrast, each sublist of \
the output of ",
  StyleBox["WaveletTransform", "MR"],
  " represents a certain frequency range and the coefficients inside each \
sublist are arranged according to increasing time. "
}], "Text",
  CellTags->{"S1.7.4", "4.26"}],

Cell[TextData[{
  "The phase plot shows how the frequency changes with time. Note that the \
option ",
  StyleBox["ExchangeAxes", "MR"],
  " is set to ",
  StyleBox["True", "MR"],
  " so that we use the usual convention of plotting time along the horizontal \
axis."
}], "MathCaption",
  CellTags->{"S1.7.4", "4.27"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[cosdata, ExchangeAxes -> True,
AspectRatio -> 1, Frame -> True,
FrameTicks -> {Range[0, 16, 2], Automatic},
FrameLabel -> {\"time\", \"frequency\"}]\
\>", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S1.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.014881 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.38095 -0.0125 -3 -9 ]
[.38095 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.85714 -0.0125 -6 -9 ]
[.85714 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -18 ]
[.5 -0.0125 12 -9 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .17262 -12 -4.5 ]
[-0.0125 .17262 0 4.5 ]
[-0.0125 .32143 -12 -4.5 ]
[-0.0125 .32143 0 4.5 ]
[-0.0125 .47024 -12 -4.5 ]
[-0.0125 .47024 0 4.5 ]
[-0.0125 .61905 -12 -4.5 ]
[-0.0125 .61905 0 4.5 ]
[-0.0125 .76786 -12 -4.5 ]
[-0.0125 .76786 0 4.5 ]
[-0.0125 .91667 -12 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -21 -27 ]
[-0.01875 .5 -12 27 ]
[.02381 1.0125 -3 0 ]
[.02381 1.0125 3 9 ]
[.14286 1.0125 -3 0 ]
[.14286 1.0125 3 9 ]
[.2619 1.0125 -3 0 ]
[.2619 1.0125 3 9 ]
[.38095 1.0125 -3 0 ]
[.38095 1.0125 3 9 ]
[.5 1.0125 -3 0 ]
[.5 1.0125 3 9 ]
[.61905 1.0125 -6 0 ]
[.61905 1.0125 6 9 ]
[.7381 1.0125 -6 0 ]
[.7381 1.0125 6 9 ]
[.85714 1.0125 -6 0 ]
[.85714 1.0125 6 9 ]
[.97619 1.0125 -6 0 ]
[.97619 1.0125 6 9 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.14286 0 m
.14286 .00625 L
s
[(2)] .14286 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(4)] .2619 -0.0125 0 1 Mshowa
.38095 0 m
.38095 .00625 L
s
[(6)] .38095 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(8)] .5 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(10)] .61905 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(12)] .7381 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(14)] .85714 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(16)] .97619 -0.0125 0 1 Mshowa
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .17262 m
.00625 .17262 L
s
[(10)] -0.0125 .17262 1 0 Mshowa
0 .32143 m
.00625 .32143 L
s
[(20)] -0.0125 .32143 1 0 Mshowa
0 .47024 m
.00625 .47024 L
s
[(30)] -0.0125 .47024 1 0 Mshowa
0 .61905 m
.00625 .61905 L
s
[(40)] -0.0125 .61905 1 0 Mshowa
0 .76786 m
.00625 .76786 L
s
[(50)] -0.0125 .76786 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(60)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .05357 m
.00375 .05357 L
s
0 .08333 m
.00375 .08333 L
s
0 .1131 m
.00375 .1131 L
s
0 .14286 m
.00375 .14286 L
s
0 .20238 m
.00375 .20238 L
s
0 .23214 m
.00375 .23214 L
s
0 .2619 m
.00375 .2619 L
s
0 .29167 m
.00375 .29167 L
s
0 .35119 m
.00375 .35119 L
s
0 .38095 m
.00375 .38095 L
s
0 .41071 m
.00375 .41071 L
s
0 .44048 m
.00375 .44048 L
s
0 .5 m
.00375 .5 L
s
0 .52976 m
.00375 .52976 L
s
0 .55952 m
.00375 .55952 L
s
0 .58929 m
.00375 .58929 L
s
0 .64881 m
.00375 .64881 L
s
0 .67857 m
.00375 .67857 L
s
0 .70833 m
.00375 .70833 L
s
0 .7381 m
.00375 .7381 L
s
0 .79762 m
.00375 .79762 L
s
0 .82738 m
.00375 .82738 L
s
0 .85714 m
.00375 .85714 L
s
0 .8869 m
.00375 .8869 L
s
0 .94643 m
.00375 .94643 L
s
0 .97619 m
.00375 .97619 L
s
.25 Mabswid
0 0 m
0 1 L
s
[(frequency)] -0.01875 .5 -12 0 Mabsadd 1 0 90 Mrotshowa
.02381 .99375 m
.02381 1 L
s
[(0)] .02381 1.0125 0 -1 Mshowa
.14286 .99375 m
.14286 1 L
s
[(2)] .14286 1.0125 0 -1 Mshowa
.2619 .99375 m
.2619 1 L
s
[(4)] .2619 1.0125 0 -1 Mshowa
.38095 .99375 m
.38095 1 L
s
[(6)] .38095 1.0125 0 -1 Mshowa
.5 .99375 m
.5 1 L
s
[(8)] .5 1.0125 0 -1 Mshowa
.61905 .99375 m
.61905 1 L
s
[(10)] .61905 1.0125 0 -1 Mshowa
.7381 .99375 m
.7381 1 L
s
[(12)] .7381 1.0125 0 -1 Mshowa
.85714 .99375 m
.85714 1 L
s
[(14)] .85714 1.0125 0 -1 Mshowa
.97619 .99375 m
.97619 1 L
s
[(16)] .97619 1.0125 0 -1 Mshowa
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .17262 m
1 .17262 L
s
.99375 .32143 m
1 .32143 L
s
.99375 .47024 m
1 .47024 L
s
.99375 .61905 m
1 .61905 L
s
.99375 .76786 m
1 .76786 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .05357 m
1 .05357 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .1131 m
1 .1131 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .20238 m
1 .20238 L
s
.99625 .23214 m
1 .23214 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .29167 m
1 .29167 L
s
.99625 .35119 m
1 .35119 L
s
.99625 .38095 m
1 .38095 L
s
.99625 .41071 m
1 .41071 L
s
.99625 .44048 m
1 .44048 L
s
.99625 .5 m
1 .5 L
s
.99625 .52976 m
1 .52976 L
s
.99625 .55952 m
1 .55952 L
s
.99625 .58929 m
1 .58929 L
s
.99625 .64881 m
1 .64881 L
s
.99625 .67857 m
1 .67857 L
s
.99625 .70833 m
1 .70833 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .79762 m
1 .79762 L
s
.99625 .82738 m
1 .82738 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .8869 m
1 .8869 L
s
.99625 .94643 m
1 .94643 L
s
.99625 .97619 m
1 .97619 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FB
FB
FA
FB
FA
FC
FA
FC
F9
FB
F9
FB
F9
FA
F9
F8
F9
F6
FA
F3
FC
EE
FE
E8
FE
F1
BF
7C
03
D3
9D
78
B9
C3
E8
E2
F6
ED
FA
F3
FC
F7
FD
FA
FD
FB
FE
FD
FE
FE
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.08333 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FC
FF
F9
FE
F4
FC
FB
B3
69
14
B6
AB
79
B1
BB
DF
DB
EF
E8
F5
EF
F8
F4
FA
F7
FC
FA
FD
FC
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.14286 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FD
FE
FB
FC
F9
F2
F1
A2
61
22
92
C2
85
B1
BC
DD
DB
EE
E8
F5
EF
F8
F4
FA
F7
FC
FA
FD
FC
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.20238 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FC
FC
FC
FB
F9
FC
EB
E8
95
5D
37
71
D8
94
B1
BE
DA
DB
EC
E8
F4
EF
F8
F4
FB
F8
FC
FA
FE
FC
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.2619 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E3
EB
86
64
4E
4D
EF
A9
B2
C5
D7
DF
E9
EB
F1
F1
F6
F6
F9
F9
FB
FB
FD
FD
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.32143 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2F
B1
17
B5
AE
F8
E3
FE
F0
FE
F5
FF
F8
FF
F9
FF
FB
FF
FC
FF
FD
FE
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.38095 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
CD
C8
BF
B3
C3
E5
28
8C
61
77
CA
D1
F2
E9
FA
F0
FB
F4
FC
F7
FC
F9
FC
FB
FD
FC
FD
FD
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.44048 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F4
F4
F2
F1
EE
EA
E4
DC
D3
C7
E0
C4
13
A7
6D
6E
C5
C8
EE
E3
F7
ED
F9
F3
FA
F6
FB
F9
FC
FB
FC
FD
FD
FE
FD
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.5 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FD
FE
FC
FD
FA
FA
F6
F6
F1
EE
E9
DF
DA
D0
F5
AE
07
CA
79
6D
BE
C4
EA
E1
F5
EC
F8
F2
FA
F6
FB
F9
FC
FB
FC
FD
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.55952 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FE
FF
FE
FF
FE
FF
FF
FE
FF
FC
FD
FA
FA
F8
F6
F4
EE
ED
E2
E3
DA
F4
99
01
EF
88
6F
BA
BF
E7
DE
F3
EA
F7
F0
F9
F5
FB
F8
FC
FA
FC
FC
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.61905 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FF
FF
FF
FE
FF
FD
FD
FC
FB
FA
F7
F7
F0
F2
E6
EC
E5
DD
86
00
EC
9A
73
B8
BD
E3
DC
F1
E8
F6
EF
F9
F4
FA
F8
FB
FA
FC
FC
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FE
FF
FF
pop
P
% End of image
% Start of gray image
p
.67857 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FE
FE
FC
FD
F8
FA
F2
F7
EA
F6
F0
C9
76
04
C8
AE
7B
B6
BC
E1
DB
EF
E8
F5
EF
F8
F4
FA
F8
FC
FB
FD
FD
FE
FE
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.7381 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FD
FF
FA
FE
F5
FC
EF
FF
FB
B5
6A
0E
A5
C4
86
B7
BC
E0
DA
EF
E8
F6
EF
F9
F4
FB
F8
FD
FA
FD
FC
FD
FD
pop
P
% End of image
% Start of gray image
p
.79762 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FF
FE
FF
FE
FE
FE
FE
FF
FE
FE
FE
FB
FE
F7
FD
F3
F4
F8
A1
60
1D
84
DC
93
B9
BD
DE
DA
EE
E7
F3
EE
F6
F2
F6
F5
pop
P
% End of image
% Start of gray image
p
.85714 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FE
FE
FE
FE
FD
FE
FC
FF
FB
FF
FA
FD
FA
FA
F8
F9
EB
EC
93
58
34
67
EF
A0
B5
BC
D3
D5
DE
DE
pop
P
% End of image
% Start of gray image
p
.91667 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FE
FE
FE
FE
FD
FD
FD
FC
FC
FC
FC
FB
FB
FB
FB
FA
FB
FA
FB
FA
FB
FA
FB
FB
FB
FB
FB
FC
FC
FD
FC
FE
FC
FF
FD
FF
FD
FD
FE
FC
FE
FB
FF
FB
FF
FA
FF
FA
FE
FA
FF
F6
F4
D3
9D
41
70
70
CE
72
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],

Cell["\<\
We see that the \"effective frequency\" or \"group velocity\" has \
indeed the same shape as indicated in the above phase space plot.\
\>", 
  "MathCaption",
  CellTags->{"S1.7.4", "4.28"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[Abs[D[(1-1.5t)t, t]]], {t, 0, 1},
AspectRatio -> 1, AxesLabel -> {\"t\", \" \"},
PlotLabel -> \"effective frequency\"]\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S1.7.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.476191 [
[.21429 .01131 -9 -9 ]
[.21429 .01131 9 0 ]
[.40476 .01131 -9 -9 ]
[.40476 .01131 9 0 ]
[.59524 .01131 -9 -9 ]
[.59524 .01131 9 0 ]
[.78571 .01131 -9 -9 ]
[.78571 .01131 9 0 ]
[.97619 .01131 -3 -9 ]
[.97619 .01131 3 0 ]
[1.025 .02381 0 -4.5 ]
[1.025 .02381 6 4.5 ]
[.01131 .2619 -18 -4.5 ]
[.01131 .2619 0 4.5 ]
[.01131 .5 -6 -4.5 ]
[.01131 .5 0 4.5 ]
[.01131 .7381 -18 -4.5 ]
[.01131 .7381 0 4.5 ]
[.01131 .97619 -6 -4.5 ]
[.01131 .97619 0 4.5 ]
[.02381 1.025 -3 0 ]
[.02381 1.025 3 9 ]
[.5 1.0125 -57 0 ]
[.5 1.0125 57 9 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .02381 m
.21429 .03006 L
s
[(0.2)] .21429 .01131 0 1 Mshowa
.40476 .02381 m
.40476 .03006 L
s
[(0.4)] .40476 .01131 0 1 Mshowa
.59524 .02381 m
.59524 .03006 L
s
[(0.6)] .59524 .01131 0 1 Mshowa
.78571 .02381 m
.78571 .03006 L
s
[(0.8)] .78571 .01131 0 1 Mshowa
.97619 .02381 m
.97619 .03006 L
s
[(1)] .97619 .01131 0 1 Mshowa
.125 Mabswid
.07143 .02381 m
.07143 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.16667 .02381 m
.16667 .02756 L
s
.2619 .02381 m
.2619 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.35714 .02381 m
.35714 .02756 L
s
.45238 .02381 m
.45238 .02756 L
s
.5 .02381 m
.5 .02756 L
s
.54762 .02381 m
.54762 .02756 L
s
.64286 .02381 m
.64286 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.7381 .02381 m
.7381 .02756 L
s
.83333 .02381 m
.83333 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.92857 .02381 m
.92857 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
[(t)] 1.025 .02381 -1 0 Mshowa
.02381 .2619 m
.03006 .2619 L
s
[(0.5)] .01131 .2619 1 0 Mshowa
.02381 .5 m
.03006 .5 L
s
[(1)] .01131 .5 1 0 Mshowa
.02381 .7381 m
.03006 .7381 L
s
[(1.5)] .01131 .7381 1 0 Mshowa
.02381 .97619 m
.03006 .97619 L
s
[(2)] .01131 .97619 1 0 Mshowa
.125 Mabswid
.02381 .07143 m
.02756 .07143 L
s
.02381 .11905 m
.02756 .11905 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .21429 m
.02756 .21429 L
s
.02381 .30952 m
.02756 .30952 L
s
.02381 .35714 m
.02756 .35714 L
s
.02381 .40476 m
.02756 .40476 L
s
.02381 .45238 m
.02756 .45238 L
s
.02381 .54762 m
.02756 .54762 L
s
.02381 .59524 m
.02756 .59524 L
s
.02381 .64286 m
.02756 .64286 L
s
.02381 .69048 m
.02756 .69048 L
s
.02381 .78571 m
.02756 .78571 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .88095 m
.02756 .88095 L
s
.02381 .92857 m
.02756 .92857 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
[( )] .02381 1.025 0 -1 Mshowa
[(effective frequency)] .5 1.0125 0 -1 Mshowa
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.02381 .5 m
.06244 .44205 L
.10458 .37884 L
.14415 .31949 L
.18221 .2624 L
.22272 .20164 L
.26171 .14315 L
.30316 .08098 L
.32392 .04984 L
.33304 .03616 L
.33554 .03241 L
.33823 .02838 L
.33953 .02642 L
.34076 .02457 L
.34187 .02471 L
.34309 .02653 L
.36173 .0545 L
.3815 .08415 L
.42214 .14512 L
.46127 .20382 L
.50286 .26619 L
.54292 .32629 L
.58147 .38412 L
.62248 .44562 L
.66196 .50485 L
.69994 .56181 L
.74036 .62245 L
.77927 .68081 L
.82063 .74285 L
.86048 .80262 L
.8988 .86011 L
.93959 .92129 L
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],

Cell[TextData[{
  "The inverse transform is given by the function ",
  StyleBox["InverseCosTransform", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.4", "4.29"}],

Cell[CellGroupData[{

Cell["Max[Abs[data-InverseCosTransform[cosdata]]]", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S1.7.4"],

Cell[BoxData[
    \(9.99200722162640886`*^-16\)], "Output",
  CellLabel->"Out[24]= ",
  CellTags->"S1.7.4"]
}, Open  ]],

Cell["1.7.5 Local Sine and Cosine Packet Transforms", "Subsection",
  CellTags->{"S1.7.5", "5.1"}],

Cell[TextData[{
  "In a local cosine or sine transform, we decompose a function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " according to a local cosine or sine basis (",
  ButtonBox["7.6",
    ButtonData:>{"Wavelets 1.7.3", "3.17"},
    ButtonStyle->"AddOnsLink"],
  ") or (",
  ButtonBox["7.7",
    ButtonData:>{"Wavelets 1.7.3", "3.19"},
    ButtonStyle->"AddOnsLink"],
  "). In the actual implementation, we use the discretized version of the \
transform and partition the data into blocks of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " such that ",
  Cell[BoxData[
      \(TraditionalForm\`L\_j = L = n  \[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " is the sampling interval. So for a given window ",
  Cell[BoxData[
      \(TraditionalForm\`b\_j = b\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ", the size of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " determines the basis completely. By varying ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " we choose to decompose our data in different bases. As in the case of the \
wavelet packet decomposition, we can decompose our data first using a basis \
with a particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_0\)], "InlineFormula",
    CellTags->"S1.7.5"],
  "; then we can decompose the data again using a basis with ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_0/2, n\_0/4, \[Ellipsis]\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ", etc. The function "
}], "Text",
  CellTags->{"S1.7.5", "5.2"}],

Cell[TextData[{
  StyleBox["CosPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  "  or  ",
  StyleBox["SinPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.5", "5.3"}],

Cell[TextData[{
  "generates a table of cosine or sine transform coefficients of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{C\_0, C\_1, \[Ellipsis]}\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " where the \"",
  Cell[BoxData[
      \(TraditionalForm\`j\^\(\ th\)\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " level\" coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`C\_j\)], "InlineFormula",
    CellTags->"S1.7.5"],
  " is the output of ",
  StyleBox["CosTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\"\>", "j"], TraditionalForm]], "InlineFormula",
    CellTags->"S1.7.5"],
  StyleBox["]", "MR"],
  " or ",
  StyleBox["SinTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\"\>", "j"], TraditionalForm]], "InlineFormula",
    CellTags->"S1.7.5"],
  StyleBox["]", "MR"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`n\_j = n/2\^j\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ". Note that in the wavelet packet decomposition, each decomposition splits \
frequency space into finer regions, whereas in the local trigonometric packet \
decomposition, each decomposition splits the time domain into finer regions \
(see Wickerhauser (1994)). "
}], "Text",
  CellTags->{"S1.7.5", "5.4"}],

Cell["As an example, we generate a set of random data of size 32.", 
  "MathCaption",
  CellTags->{"S1.7.5", "5.5"}],

Cell["rdata = Table[Random[], {32}];", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S1.7.5"],

Cell[TextData[{
  "We give the initial block size of ",
  Cell[BoxData[
      \(TraditionalForm\`n\_0 = 32\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ". Since we use the default taper with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 4\)], "InlineFormula",
    CellTags->"S1.7.5"],
  ", the smallest block has length ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] 2  \[Epsilon] = 8\)], 
    "InlineFormula",
    CellTags->"S1.7.5"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.5", "5.6"}],

Cell["coscoef = CosPacketCoefficients[rdata, 32];", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S1.7.5"],

Cell[TextData[{
  "The cosine transform is done for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 32, 16, 8\)], "InlineFormula",
    CellTags->"S1.7.5"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.5", "5.7"}],

Cell[CellGroupData[{

Cell["Dimensions /@ coscoef", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S1.7.5"],

Cell[BoxData[
    \({{1, 32}, {2, 16}, {4, 8}}\)], "Output",
  CellLabel->"Out[27]= ",
  CellTags->"S1.7.5"]
}, Open  ]],

Cell["\<\
Each level contains the output of doing the cosine transform with \
the corresponding block size.\
\>", "MathCaption",
  CellTags->{"S1.7.5", "5.8"}],

Cell[CellGroupData[{

Cell["CosTransform[rdata, 16] == coscoef[[2]]", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S1.7.5"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]= ",
  CellTags->"S1.7.5"]
}, Open  ]],

Cell["\<\
As in the case of a wavelet packet transform, we can choose a best \
basis from among all these possible bases. Again, the best basis criterion is \
based on a cost function and the default is the entropy function. The \
function \
\>", "Text",
  CellTags->{"S1.7.5", "5.9"}],

Cell[TextData[{
  StyleBox["CosPacketTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  "  or  ",
  StyleBox["SinPacketTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " "
}], "Text",
  TextAlignment->Center,
  CellTags->{"S1.7.5", "5.10"}],

Cell["\<\
gives the cosine or sine transform by choosing the best basis \
according to the entropy criterion. \
\>", "Text",
  CellTags->{"S1.7.5", "5.11"}],

Cell["\<\
Here we use the earlier data to find the best basis \
decomposition.\
\>", "MathCaption",
  CellTags->{"S1.7.5", "5.12"}],

Cell["cosdata = CosPacketTransform[data, 512];", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S1.7.5"],

Cell["\<\
We see that in this particular case the best basis consists of \
blocks of various lengths.\
\>", "MathCaption",
  CellTags->{"S1.7.5", "5.13"}],

Cell[CellGroupData[{

Cell["Short[Length /@ cosdata]", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S1.7.5"],

Cell[BoxData[
    TagBox[
      \({64, 64, 16, 16, 32, 8, 8, 16, \[LeftSkeleton]16\[RightSkeleton], 32, 
        32, 32, 32, 32, 16, 8, 8}\),
      Short]], "Output",
  CellLabel->"Out[30]//Short= ",
  CellTags->"S1.7.5"]
}, Open  ]],

Cell["\<\
Here the horizontal axis corresponds to time and each block has \
definite time localization.\
\>", "MathCaption",
  CellTags->{"S1.7.5", "5.14"}],

Cell[CellGroupData[{

Cell["\<\
ShowBasisPosition[cosdata, PlotLabel -> \"best basis \
position\"]\
\>", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S1.7.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.0147151 0.0735755 [
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(best basis position)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .08829 m
.97619 .08829 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .23544 m
.97619 .23544 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .38259 m
.97619 .38259 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .52974 m
.97619 .52974 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.03125 .01472 m
.03125 .08829 L
s
.03869 .01472 m
.03869 .16187 L
s
.04613 .01472 m
.04613 .08829 L
s
.05357 .01472 m
.05357 .23544 L
s
.06101 .01472 m
.06101 .08829 L
s
.06845 .01472 m
.06845 .16187 L
s
.07589 .01472 m
.07589 .08829 L
s
.08333 .01472 m
.08333 .30902 L
s
.09077 .01472 m
.09077 .08829 L
s
.09821 .01472 m
.09821 .16187 L
s
.10565 .01472 m
.10565 .08829 L
s
.1131 .01472 m
.1131 .23544 L
s
.12054 .01472 m
.12054 .08829 L
s
.12798 .01472 m
.12798 .16187 L
s
.13542 .01472 m
.13542 .08829 L
s
.14286 .01472 m
.14286 .38259 L
s
.1503 .01472 m
.1503 .08829 L
s
.15774 .01472 m
.15774 .16187 L
s
.16518 .01472 m
.16518 .08829 L
s
.17262 .01472 m
.17262 .23544 L
s
.18006 .01472 m
.18006 .08829 L
s
.1875 .01472 m
.1875 .16187 L
s
.19494 .01472 m
.19494 .08829 L
s
.20238 .01472 m
.20238 .30902 L
s
.20982 .01472 m
.20982 .08829 L
s
.21726 .01472 m
.21726 .16187 L
s
.2247 .01472 m
.2247 .08829 L
s
.23214 .01472 m
.23214 .23544 L
s
.23958 .01472 m
.23958 .08829 L
s
.24702 .01472 m
.24702 .16187 L
s
.25446 .01472 m
.25446 .08829 L
s
.2619 .01472 m
.2619 .45617 L
s
.26935 .01472 m
.26935 .08829 L
s
.27679 .01472 m
.27679 .16187 L
s
.28423 .01472 m
.28423 .08829 L
s
.29167 .01472 m
.29167 .23544 L
s
.29911 .01472 m
.29911 .08829 L
s
.30655 .01472 m
.30655 .16187 L
s
.31399 .01472 m
.31399 .08829 L
s
.32143 .01472 m
.32143 .30902 L
s
.32887 .01472 m
.32887 .08829 L
s
.33631 .01472 m
.33631 .16187 L
s
.34375 .01472 m
.34375 .08829 L
s
.35119 .01472 m
.35119 .23544 L
s
.35863 .01472 m
.35863 .08829 L
s
.36607 .01472 m
.36607 .16187 L
s
.37351 .01472 m
.37351 .08829 L
s
.38095 .01472 m
.38095 .38259 L
s
.38839 .01472 m
.38839 .08829 L
s
.39583 .01472 m
.39583 .16187 L
s
.40327 .01472 m
.40327 .08829 L
s
.41071 .01472 m
.41071 .23544 L
s
.41815 .01472 m
.41815 .08829 L
s
.4256 .01472 m
.4256 .16187 L
s
.43304 .01472 m
.43304 .08829 L
s
.44048 .01472 m
.44048 .30902 L
s
.44792 .01472 m
.44792 .08829 L
s
.45536 .01472 m
.45536 .16187 L
s
.4628 .01472 m
.4628 .08829 L
s
.47024 .01472 m
.47024 .23544 L
s
.47768 .01472 m
.47768 .08829 L
s
.48512 .01472 m
.48512 .16187 L
s
.49256 .01472 m
.49256 .08829 L
s
.5 .01472 m
.5 .52974 L
s
.50744 .01472 m
.50744 .08829 L
s
.51488 .01472 m
.51488 .16187 L
s
.52232 .01472 m
.52232 .08829 L
s
.52976 .01472 m
.52976 .23544 L
s
.5372 .01472 m
.5372 .08829 L
s
.54464 .01472 m
.54464 .16187 L
s
.55208 .01472 m
.55208 .08829 L
s
.55952 .01472 m
.55952 .30902 L
s
.56696 .01472 m
.56696 .08829 L
s
.5744 .01472 m
.5744 .16187 L
s
.58185 .01472 m
.58185 .08829 L
s
.58929 .01472 m
.58929 .23544 L
s
.59673 .01472 m
.59673 .08829 L
s
.60417 .01472 m
.60417 .16187 L
s
.61161 .01472 m
.61161 .08829 L
s
.61905 .01472 m
.61905 .38259 L
s
.62649 .01472 m
.62649 .08829 L
s
.63393 .01472 m
.63393 .16187 L
s
.64137 .01472 m
.64137 .08829 L
s
.64881 .01472 m
.64881 .23544 L
s
.65625 .01472 m
.65625 .08829 L
s
.66369 .01472 m
.66369 .16187 L
s
.67113 .01472 m
.67113 .08829 L
s
.67857 .01472 m
.67857 .30902 L
s
.68601 .01472 m
.68601 .08829 L
s
.69345 .01472 m
.69345 .16187 L
s
.70089 .01472 m
.70089 .08829 L
s
.70833 .01472 m
.70833 .23544 L
s
.71577 .01472 m
.71577 .08829 L
s
.72321 .01472 m
.72321 .16187 L
s
.73065 .01472 m
.73065 .08829 L
s
.7381 .01472 m
.7381 .45617 L
s
.74554 .01472 m
.74554 .08829 L
s
.75298 .01472 m
.75298 .16187 L
s
.76042 .01472 m
.76042 .08829 L
s
.76786 .01472 m
.76786 .23544 L
s
.7753 .01472 m
.7753 .08829 L
s
.78274 .01472 m
.78274 .16187 L
s
.79018 .01472 m
.79018 .08829 L
s
.79762 .01472 m
.79762 .30902 L
s
.80506 .01472 m
.80506 .08829 L
s
.8125 .01472 m
.8125 .16187 L
s
.81994 .01472 m
.81994 .08829 L
s
.82738 .01472 m
.82738 .23544 L
s
.83482 .01472 m
.83482 .08829 L
s
.84226 .01472 m
.84226 .16187 L
s
.8497 .01472 m
.8497 .08829 L
s
.85714 .01472 m
.85714 .38259 L
s
.86458 .01472 m
.86458 .08829 L
s
.87202 .01472 m
.87202 .16187 L
s
.87946 .01472 m
.87946 .08829 L
s
.8869 .01472 m
.8869 .23544 L
s
.89435 .01472 m
.89435 .08829 L
s
.90179 .01472 m
.90179 .16187 L
s
.90923 .01472 m
.90923 .08829 L
s
.91667 .01472 m
.91667 .30902 L
s
.92411 .01472 m
.92411 .08829 L
s
.93155 .01472 m
.93155 .16187 L
s
.93899 .01472 m
.93899 .08829 L
s
.94643 .01472 m
.94643 .23544 L
s
.95387 .01472 m
.95387 .08829 L
s
.96131 .01472 m
.96131 .16187 L
s
.96875 .01472 m
.96875 .08829 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .23544 translate
.05952 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08333 .23544 translate
.05953 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.15774 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.17262 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20238 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20982 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.21726 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.23214 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .16187 translate
.02977 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.29167 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32143 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32887 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.33631 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.35119 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41071 .16187 translate
.02977 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.44048 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47024 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .23544 translate
.05952 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.55952 .23544 translate
.05953 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .23544 translate
.05952 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.67857 .23544 translate
.05953 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .23544 translate
.05952 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.79762 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.82738 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8869 .16187 translate
.02977 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.91667 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.94643 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.96131 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.96875 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.5"]
}, Open  ]],

Cell["\<\
Again, we get an indication of how frequency varies with time. Note \
that unlike the case of the cosine transform where each coefficient has \
identical shape in the phase plot, here the coefficients from a smaller time \
block are thin and tall, whereas those from a large time block are wide and \
flat.\
\>", "MathCaption",
  CellTags->{"S1.7.5", "5.15"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[cosdata, ExchangeAxes -> True,
AspectRatio -> 1, Frame -> True, FrameTicks -> None,
FrameLabel -> {\"time\", \"frequency\"}]\
\>", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S1.7.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.014881 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -9 -27 ]
[-0.01875 .5 0 27 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 1 Mshowa
0 0 m
0 1 L
s
[(frequency)] -0.01875 .5 1 0 90 Mrotshowa
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FB
FB
FA
FC
FA
FC
FA
FC
F9
FB
F9
FB
F9
FA
F9
F9
F9
F6
FA
F3
FC
EE
FF
E8
FE
F1
C0
7E
06
D4
9F
79
BA
C4
E8
E2
F6
EE
FA
F3
FC
F7
FD
FA
FE
FC
FE
FD
FE
FE
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.08333 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FC
FF
F9
FE
F5
FC
FB
B4
6A
17
B7
AC
7B
B2
BC
DF
DC
EF
E8
F5
EF
F8
F4
FA
F8
FC
FA
FD
FC
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.14286 .02381 translate
.01488 .95238 scale
1 string
1 16 8 [1 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD
FA
FC
C9
EC
6A
F6
E4
FD
FB
FF
FE
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.15774 .02381 translate
.01488 .95238 scale
1 string
1 16 8 [1 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F9
F7
EF
C2
54
CA
EA
F7
F7
FE
FF
FF
FE
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.17262 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FB
FA
F9
F6
EF
EB
EF
19
BA
DB
D6
F7
ED
FE
F7
FF
FD
FE
FF
FF
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.20238 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E0
FC
A8
FE
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.20982 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F3
78
DB
F5
FF
FE
FF
FF
pop
P
% End of image
% Start of gray image
p
.21726 .02381 translate
.01488 .95238 scale
1 string
1 16 8 [1 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E4
FD
52
EE
E6
F7
FE
FF
FD
FE
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.23214 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
EB
E4
FA
0F
D8
DD
DD
F7
EF
FF
F8
FE
FD
FE
FF
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.2619 .02381 translate
.02977 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DA
F4
46
DB
87
DB
DB
EF
F1
F6
FB
FA
FF
FD
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.29167 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
00
FA
E5
EE
F8
F8
FE
FC
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.32143 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
E5
FC
FD
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.32887 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8E
F0
FD
FD
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.33631 .02381 translate
.01488 .95238 scale
1 string
1 16 8 [1 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
32
DA
DF
FF
F8
FD
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.35119 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FA
19
DC
E2
FC
F0
FD
F5
FF
F9
FF
FC
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.38095 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BD
86
F2
47
D5
CD
F5
E9
FB
F5
FD
FB
FE
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.41071 .02381 translate
.02977 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F6
F5
EC
CE
09
D5
D4
FE
EA
FE
F3
FD
F9
FD
FD
FE
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.44048 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
F2
DA
E6
98
BE
48
D9
C8
F5
E7
FA
F4
FC
FB
FD
FF
FF
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.47024 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FC
FC
FF
FE
FD
F4
B4
12
C4
D1
F7
E9
FB
F3
FD
F9
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.5 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FD
FE
FC
FD
FA
FA
F7
F6
F2
EE
E9
E0
DB
D1
F5
AF
0A
CB
7A
6F
BF
C4
EA
E1
F5
EC
F8
F2
FA
F6
FB
F9
FC
FB
FC
FD
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.55952 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FE
FF
FE
FF
FE
FF
FF
FE
FF
FC
FD
FA
FA
F8
F6
F4
EF
ED
E2
E3
DA
F4
9A
04
EF
8A
70
BB
C0
E7
DE
F3
EA
F7
F0
F9
F5
FB
F8
FC
FB
FC
FC
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.61905 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FF
FF
FF
FE
FF
FD
FD
FC
FB
FA
F7
F7
F0
F2
E6
ED
E5
DE
88
03
EC
9C
75
B8
BE
E4
DC
F1
E9
F6
F0
F9
F4
FA
F8
FB
FA
FC
FC
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FE
FF
FF
pop
P
% End of image
% Start of gray image
p
.67857 .02381 translate
.05953 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FE
FE
FC
FD
F8
FB
F3
F7
EA
F6
F0
C9
78
07
C8
AF
7D
B7
BC
E1
DB
F0
E8
F5
EF
F9
F4
FA
F8
FC
FB
FD
FD
FE
FE
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.7381 .02381 translate
.05952 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FD
FF
FA
FE
F5
FC
EF
FF
FB
B6
6B
11
A6
C5
88
B8
BD
E0
DB
EF
E8
F6
EF
F9
F4
FB
F8
FD
FA
FD
FC
FD
FD
pop
P
% End of image
% Start of gray image
p
.79762 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FE
FE
FC
FE
F9
F9
F6
ED
EF
E8
19
BA
E1
D7
FA
EE
FF
F9
FE
pop
P
% End of image
% Start of gray image
p
.82738 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FC
FC
FB
F7
FA
ED
F9
D6
E7
3F
A9
95
D3
E0
EB
EF
F1
pop
P
% End of image
% Start of gray image
p
.85714 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FE
FE
FB
FF
F7
FB
F2
F1
E7
F8
0C
D6
E3
DF
F3
F0
pop
P
% End of image
% Start of gray image
p
.8869 .02381 translate
.02977 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FD
FB
FC
F5
FA
EB
F8
D3
E1
3E
C8
8B
CA
CE
pop
P
% End of image
% Start of gray image
p
.91667 .02381 translate
.02976 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FD
FE
F9
FF
F6
FA
F1
F4
E7
F7
11
ED
CE
pop
P
% End of image
% Start of gray image
p
.94643 .02381 translate
.01488 .95238 scale
1 string
1 16 8 [1 0 0 16 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
F9
F7
E5
B4
39
pop
P
% End of image
% Start of gray image
p
.96131 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FE
FE
F2
D4
pop
P
% End of image
% Start of gray image
p
.96875 .02381 translate
.00744 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD
F6
F2
F2
FA
FE
F9
F1
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S1.7.5"]
}, Open  ]],

Cell[TextData[{
  "The inverse transform is given by ",
  StyleBox["InverseCosPacketTransform", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S1.7.5", "5.16"}],

Cell[CellGroupData[{

Cell["Union[Chop[data-InverseCosPacketTransform[cosdata]]]", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S1.7.5"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[33]= ",
  CellTags->"S1.7.5"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 239}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 87, 1, 86, "Section",
      CellTags->"Contents"],
    Cell[1799, 52, 724, 22, 99, "Contents",
      CellTags->"Contents"]},
  "S1.7.0"->{
    Cell[2526, 76, 94, 1, 86, "Section",
      CellTags->{"S1.7.0", "0.1"}]},
  "0.1"->{
    Cell[2526, 76, 94, 1, 86, "Section",
      CellTags->{"S1.7.0", "0.1"}]},
  "S1.7.1"->{
    Cell[2623, 79, 86, 1, 41, "Subsection",
      CellTags->{"S1.7.1", "1.1"}],
    Cell[2712, 82, 1846, 41, 227, "Text",
      CellTags->{"S1.7.1", "1.2"}],
    Cell[4561, 125, 333, 8, 38, "DisplayFormula",
      CellTags->{"S1.7.1", "1.3"}],
    Cell[4897, 135, 1211, 31, 115, "Text",
      CellTags->{"S1.7.1", "1.4"}],
    Cell[6111, 168, 567, 17, 70, "DisplayFormula",
      CellTags->{"S1.7.1", "1.5"}],
    Cell[6681, 187, 859, 15, 70, "Text",
      CellTags->{"S1.7.1", "1.6"}]},
  "1.1"->{
    Cell[2623, 79, 86, 1, 41, "Subsection",
      CellTags->{"S1.7.1", "1.1"}]},
  "1.2"->{
    Cell[2712, 82, 1846, 41, 227, "Text",
      CellTags->{"S1.7.1", "1.2"}]},
  "1.3"->{
    Cell[4561, 125, 333, 8, 38, "DisplayFormula",
      CellTags->{"S1.7.1", "1.3"}]},
  "1.4"->{
    Cell[4897, 135, 1211, 31, 115, "Text",
      CellTags->{"S1.7.1", "1.4"}]},
  "1.5"->{
    Cell[6111, 168, 567, 17, 70, "DisplayFormula",
      CellTags->{"S1.7.1", "1.5"}]},
  "1.6"->{
    Cell[6681, 187, 859, 15, 70, "Text",
      CellTags->{"S1.7.1", "1.6"}]},
  "S1.7.2"->{
    Cell[7543, 204, 94, 1, 70, "Subsection",
      CellTags->{"S1.7.2", "2.1"}],
    Cell[7640, 207, 676, 15, 70, "Text",
      CellTags->{"S1.7.2", "2.2"}],
    Cell[8319, 224, 214, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.3"}],
    Cell[8536, 230, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.4"}],
    Cell[8586, 233, 233, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.5"}],
    Cell[8822, 240, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.6"}],
    Cell[8872, 243, 228, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.7"}],
    Cell[9103, 250, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.8"}],
    Cell[9153, 253, 228, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.9"}],
    Cell[9384, 260, 1066, 34, 70, "Text",
      CellTags->{"S1.7.2", "2.10"}],
    Cell[10453, 296, 467, 10, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.11"}],
    Cell[10923, 308, 582, 16, 70, "Text",
      CellTags->{"S1.7.2", "2.12"}],
    Cell[11508, 326, 414, 9, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.13"}],
    Cell[11925, 337, 221, 7, 70, "Text",
      CellTags->{"S1.7.2", "2.14"}],
    Cell[12149, 346, 312, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.15"}],
    Cell[12464, 355, 567, 15, 70, "Text",
      CellTags->{"S1.7.2", "2.16"}],
    Cell[13034, 372, 560, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.17"}],
    Cell[13597, 385, 48, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.18"}],
    Cell[13648, 388, 563, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.19"}],
    Cell[14214, 401, 48, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.20"}],
    Cell[14265, 404, 603, 12, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.21"}],
    Cell[14871, 418, 500, 19, 70, "Text",
      CellTags->{"S1.7.2", "2.22"}],
    Cell[15374, 439, 110, 1, 70, "Subsubsection",
      CellTags->{"S1.7.2", "2.23"}],
    Cell[15487, 442, 388, 9, 70, "Text",
      CellTags->{"S1.7.2", "2.24"}],
    Cell[15878, 453, 540, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.25"}],
    Cell[16421, 466, 65, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.26"}],
    Cell[16489, 469, 304, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.27"}],
    Cell[16796, 478, 952, 28, 70, "Text",
      CellTags->{"S1.7.2", "2.28"}],
    Cell[17751, 508, 480, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.29"}],
    Cell[18234, 521, 878, 28, 70, "Text",
      CellTags->{"S1.7.2", "2.30"}],
    Cell[19115, 551, 377, 17, 70, "Text",
      CellTags->{"S1.7.2", "2.31"}],
    Cell[19495, 570, 545, 16, 70, "Text",
      CellTags->{"S1.7.2", "2.32"}],
    Cell[20043, 588, 290, 11, 70, "Text",
      CellTags->{"S1.7.2", "2.33"}],
    Cell[20336, 601, 1672, 44, 70, "Text",
      CellTags->{"S1.7.2", "2.34"}],
    Cell[22011, 647, 429, 22, 70, "Text",
      CellTags->{"S1.7.2", "2.35"}],
    Cell[22443, 671, 78, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.36"}],
    Cell[22524, 674, 93, 2, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[22620, 678, 95, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.37"}],
    Cell[22718, 681, 122, 5, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[22843, 688, 282, 9, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.38"}],
    Cell[23150, 701, 101, 2, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[23254, 705, 528, 10, 70, "Output",
      CellTags->"S1.7.2"],
    Cell[23797, 718, 87, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.39"}],
    Cell[23909, 723, 102, 2, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[24014, 727, 454, 8, 70, "Output",
      CellTags->"S1.7.2"],
    Cell[24483, 738, 98, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.40"}],
    Cell[24606, 743, 76, 2, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[24685, 747, 126, 3, 70, "Output",
      CellTags->"S1.7.2"],
    Cell[24826, 753, 241, 7, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.41"}],
    Cell[25092, 764, 118, 2, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[25213, 768, 506, 9, 70, "Output",
      CellTags->"S1.7.2"],
    Cell[25734, 780, 115, 2, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.42"}],
    Cell[25874, 786, 140, 5, 70, "Input",
      CellTags->"S1.7.2"],
    Cell[26017, 793, 126, 3, 70, "Output",
      CellTags->"S1.7.2"]},
  "2.1"->{
    Cell[7543, 204, 94, 1, 70, "Subsection",
      CellTags->{"S1.7.2", "2.1"}]},
  "2.2"->{
    Cell[7640, 207, 676, 15, 70, "Text",
      CellTags->{"S1.7.2", "2.2"}]},
  "2.3"->{
    Cell[8319, 224, 214, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.3"}]},
  "2.4"->{
    Cell[8536, 230, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.4"}]},
  "2.5"->{
    Cell[8586, 233, 233, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.5"}]},
  "2.6"->{
    Cell[8822, 240, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.6"}]},
  "2.7"->{
    Cell[8872, 243, 228, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.7"}]},
  "2.8"->{
    Cell[9103, 250, 47, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.8"}]},
  "2.9"->{
    Cell[9153, 253, 228, 5, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.9"}]},
  "2.10"->{
    Cell[9384, 260, 1066, 34, 70, "Text",
      CellTags->{"S1.7.2", "2.10"}]},
  "2.11"->{
    Cell[10453, 296, 467, 10, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.11"}]},
  "2.12"->{
    Cell[10923, 308, 582, 16, 70, "Text",
      CellTags->{"S1.7.2", "2.12"}]},
  "2.13"->{
    Cell[11508, 326, 414, 9, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.13"}]},
  "2.14"->{
    Cell[11925, 337, 221, 7, 70, "Text",
      CellTags->{"S1.7.2", "2.14"}]},
  "2.15"->{
    Cell[12149, 346, 312, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.15"}]},
  "2.16"->{
    Cell[12464, 355, 567, 15, 70, "Text",
      CellTags->{"S1.7.2", "2.16"}]},
  "2.17"->{
    Cell[13034, 372, 560, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.17"}]},
  "2.18"->{
    Cell[13597, 385, 48, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.18"}]},
  "2.19"->{
    Cell[13648, 388, 563, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.19"}]},
  "2.20"->{
    Cell[14214, 401, 48, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.20"}]},
  "2.21"->{
    Cell[14265, 404, 603, 12, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.21"}]},
  "2.22"->{
    Cell[14871, 418, 500, 19, 70, "Text",
      CellTags->{"S1.7.2", "2.22"}]},
  "2.23"->{
    Cell[15374, 439, 110, 1, 70, "Subsubsection",
      CellTags->{"S1.7.2", "2.23"}]},
  "2.24"->{
    Cell[15487, 442, 388, 9, 70, "Text",
      CellTags->{"S1.7.2", "2.24"}]},
  "2.25"->{
    Cell[15878, 453, 540, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.25"}]},
  "2.26"->{
    Cell[16421, 466, 65, 1, 70, "Text",
      CellTags->{"S1.7.2", "2.26"}]},
  "2.27"->{
    Cell[16489, 469, 304, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.27"}]},
  "2.28"->{
    Cell[16796, 478, 952, 28, 70, "Text",
      CellTags->{"S1.7.2", "2.28"}]},
  "2.29"->{
    Cell[17751, 508, 480, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.2", "2.29"}]},
  "2.30"->{
    Cell[18234, 521, 878, 28, 70, "Text",
      CellTags->{"S1.7.2", "2.30"}]},
  "2.31"->{
    Cell[19115, 551, 377, 17, 70, "Text",
      CellTags->{"S1.7.2", "2.31"}]},
  "2.32"->{
    Cell[19495, 570, 545, 16, 70, "Text",
      CellTags->{"S1.7.2", "2.32"}]},
  "2.33"->{
    Cell[20043, 588, 290, 11, 70, "Text",
      CellTags->{"S1.7.2", "2.33"}]},
  "2.34"->{
    Cell[20336, 601, 1672, 44, 70, "Text",
      CellTags->{"S1.7.2", "2.34"}]},
  "2.35"->{
    Cell[22011, 647, 429, 22, 70, "Text",
      CellTags->{"S1.7.2", "2.35"}]},
  "2.36"->{
    Cell[22443, 671, 78, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.36"}]},
  "2.37"->{
    Cell[22620, 678, 95, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.37"}]},
  "2.38"->{
    Cell[22843, 688, 282, 9, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.38"}]},
  "2.39"->{
    Cell[23797, 718, 87, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.39"}]},
  "2.40"->{
    Cell[24483, 738, 98, 1, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.40"}]},
  "2.41"->{
    Cell[24826, 753, 241, 7, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.41"}]},
  "2.42"->{
    Cell[25734, 780, 115, 2, 70, "MathCaption",
      CellTags->{"S1.7.2", "2.42"}]},
  "S1.7.3"->{
    Cell[26158, 799, 107, 1, 70, "Subsection",
      CellTags->{"S1.7.3", "3.1"}],
    Cell[26268, 802, 3590, 95, 70, "Text",
      CellTags->{"S1.7.3", "3.2"}],
    Cell[29861, 899, 312, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.3"}],
    Cell[30176, 907, 487, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.4"}],
    Cell[30666, 922, 1342, 34, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.5"}],
    Cell[32011, 958, 1028, 31, 70, "Text",
      CellTags->{"S1.7.3", "3.6"}],
    Cell[33042, 991, 1240, 32, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.7"}],
    Cell[34285, 1025, 199, 7, 70, "Text",
      CellTags->{"S1.7.3", "3.8"}],
    Cell[34487, 1034, 351, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.9"}],
    Cell[34841, 1043, 1067, 28, 70, "Text",
      CellTags->{"S1.7.3", "3.10"}],
    Cell[35911, 1073, 372, 9, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.11"}],
    Cell[36286, 1084, 376, 9, 70, "Text",
      CellTags->{"S1.7.3", "3.12"}],
    Cell[36665, 1095, 1929, 49, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.13"}],
    Cell[38597, 1146, 345, 10, 70, "Text",
      CellTags->{"S1.7.3", "3.14"}],
    Cell[38945, 1158, 356, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.15"}],
    Cell[39304, 1167, 440, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.16"}],
    Cell[39747, 1182, 306, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.17"}],
    Cell[40056, 1190, 2958, 81, 70, "Text",
      CellTags->{"S1.7.3", "3.18"}],
    Cell[43017, 1273, 313, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.19"}],
    Cell[43333, 1281, 346, 11, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.20"}],
    Cell[43704, 1296, 146, 5, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[43853, 1303, 4259, 290, 70, 4186, 287, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[48127, 1596, 81, 1, 70, "Subsubsection",
      CellTags->{"S1.7.3", "3.21"}],
    Cell[48211, 1599, 2077, 51, 70, "Text",
      CellTags->{"S1.7.3", "3.22"}],
    Cell[50291, 1652, 138, 3, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.23"}],
    Cell[50432, 1657, 1921, 46, 70, "Text",
      CellTags->{"S1.7.3", "3.24"}],
    Cell[52356, 1705, 319, 9, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.25"}],
    Cell[52700, 1718, 169, 6, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[52872, 1726, 6723, 450, 70, 6650, 447, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[59610, 2179, 1317, 35, 70, "Text",
      CellTags->{"S1.7.3", "3.26"}],
    Cell[60930, 2216, 226, 10, 70, "Text",
      CellTags->{"S1.7.3", "3.27"}],
    Cell[61159, 2228, 616, 20, 70, "Text",
      CellTags->{"S1.7.3", "3.28"}],
    Cell[61778, 2250, 568, 20, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.29"}],
    Cell[62371, 2274, 88, 2, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[62462, 2278, 124, 3, 70, "Output",
      CellTags->"S1.7.3"],
    Cell[62601, 2284, 2350, 83, 70, "Text",
      CellTags->{"S1.7.3", "3.30"}],
    Cell[64954, 2369, 146, 4, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.31"}],
    Cell[65125, 2377, 387, 11, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[65515, 2390, 9333, 614, 70, 9260, 611, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[74863, 3007, 434, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.32"}],
    Cell[75300, 3022, 471, 23, 70, "Text",
      CellTags->{"S1.7.3", "3.33"}],
    Cell[75774, 3047, 482, 15, 70, "Text",
      CellTags->{"S1.7.3", "3.34"}],
    Cell[76259, 3064, 365, 11, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.35"}],
    Cell[76649, 3079, 209, 6, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[76861, 3087, 9788, 654, 70, 9715, 651, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[86664, 3744, 95, 1, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.36"}],
    Cell[86784, 3749, 298, 9, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[87085, 3760, 13371, 883, 70, 13298, 880, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[100471, 4646, 527, 13, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.37"}],
    Cell[101023, 4663, 309, 9, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[101335, 4674, 19133, 1250, 70, 19060, 1247, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"],
    Cell[120483, 5927, 665, 25, 70, "Text",
      CellTags->{"S1.7.3", "3.38"}],
    Cell[121151, 5954, 234, 7, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.39"}],
    Cell[121410, 5965, 199, 6, 70, "Input",
      CellTags->"S1.7.3"],
    Cell[121612, 5973, 7066, 471, 70, 6993, 468, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.3"]},
  "3.1"->{
    Cell[26158, 799, 107, 1, 70, "Subsection",
      CellTags->{"S1.7.3", "3.1"}]},
  "3.2"->{
    Cell[26268, 802, 3590, 95, 70, "Text",
      CellTags->{"S1.7.3", "3.2"}]},
  "3.3"->{
    Cell[29861, 899, 312, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.3"}]},
  "3.4"->{
    Cell[30176, 907, 487, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.4"}]},
  "3.5"->{
    Cell[30666, 922, 1342, 34, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.5"}]},
  "3.6"->{
    Cell[32011, 958, 1028, 31, 70, "Text",
      CellTags->{"S1.7.3", "3.6"}]},
  "3.7"->{
    Cell[33042, 991, 1240, 32, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.7"}]},
  "3.8"->{
    Cell[34285, 1025, 199, 7, 70, "Text",
      CellTags->{"S1.7.3", "3.8"}]},
  "3.9"->{
    Cell[34487, 1034, 351, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.9"}]},
  "3.10"->{
    Cell[34841, 1043, 1067, 28, 70, "Text",
      CellTags->{"S1.7.3", "3.10"}]},
  "3.11"->{
    Cell[35911, 1073, 372, 9, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.11"}]},
  "3.12"->{
    Cell[36286, 1084, 376, 9, 70, "Text",
      CellTags->{"S1.7.3", "3.12"}]},
  "3.13"->{
    Cell[36665, 1095, 1929, 49, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.13"}]},
  "3.14"->{
    Cell[38597, 1146, 345, 10, 70, "Text",
      CellTags->{"S1.7.3", "3.14"}]},
  "3.15"->{
    Cell[38945, 1158, 356, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.15"}]},
  "3.16"->{
    Cell[39304, 1167, 440, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.16"}]},
  "3.17"->{
    Cell[39747, 1182, 306, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.17"}]},
  "3.18"->{
    Cell[40056, 1190, 2958, 81, 70, "Text",
      CellTags->{"S1.7.3", "3.18"}]},
  "3.19"->{
    Cell[43017, 1273, 313, 6, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.19"}]},
  "3.20"->{
    Cell[43333, 1281, 346, 11, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.20"}]},
  "3.21"->{
    Cell[48127, 1596, 81, 1, 70, "Subsubsection",
      CellTags->{"S1.7.3", "3.21"}]},
  "3.22"->{
    Cell[48211, 1599, 2077, 51, 70, "Text",
      CellTags->{"S1.7.3", "3.22"}]},
  "3.23"->{
    Cell[50291, 1652, 138, 3, 70, "DisplayFormula",
      CellTags->{"S1.7.3", "3.23"}]},
  "3.24"->{
    Cell[50432, 1657, 1921, 46, 70, "Text",
      CellTags->{"S1.7.3", "3.24"}]},
  "3.25"->{
    Cell[52356, 1705, 319, 9, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.25"}]},
  "3.26"->{
    Cell[59610, 2179, 1317, 35, 70, "Text",
      CellTags->{"S1.7.3", "3.26"}]},
  "3.27"->{
    Cell[60930, 2216, 226, 10, 70, "Text",
      CellTags->{"S1.7.3", "3.27"}]},
  "3.28"->{
    Cell[61159, 2228, 616, 20, 70, "Text",
      CellTags->{"S1.7.3", "3.28"}]},
  "3.29"->{
    Cell[61778, 2250, 568, 20, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.29"}]},
  "3.30"->{
    Cell[62601, 2284, 2350, 83, 70, "Text",
      CellTags->{"S1.7.3", "3.30"}]},
  "3.31"->{
    Cell[64954, 2369, 146, 4, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.31"}]},
  "3.32"->{
    Cell[74863, 3007, 434, 13, 70, "Text",
      CellTags->{"S1.7.3", "3.32"}]},
  "3.33"->{
    Cell[75300, 3022, 471, 23, 70, "Text",
      CellTags->{"S1.7.3", "3.33"}]},
  "3.34"->{
    Cell[75774, 3047, 482, 15, 70, "Text",
      CellTags->{"S1.7.3", "3.34"}]},
  "3.35"->{
    Cell[76259, 3064, 365, 11, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.35"}]},
  "3.36"->{
    Cell[86664, 3744, 95, 1, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.36"}]},
  "3.37"->{
    Cell[100471, 4646, 527, 13, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.37"}]},
  "3.38"->{
    Cell[120483, 5927, 665, 25, 70, "Text",
      CellTags->{"S1.7.3", "3.38"}]},
  "3.39"->{
    Cell[121151, 5954, 234, 7, 70, "MathCaption",
      CellTags->{"S1.7.3", "3.39"}]},
  "S1.7.4"->{
    Cell[128693, 6447, 89, 1, 70, "Subsection",
      CellTags->{"S1.7.4", "4.1"}],
    Cell[128785, 6450, 1542, 34, 70, "Text",
      CellTags->{"S1.7.4", "4.2"}],
    Cell[130330, 6486, 304, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.3"}],
    Cell[130637, 6495, 929, 28, 70, "Text",
      CellTags->{"S1.7.4", "4.4"}],
    Cell[131569, 6525, 522, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.5"}],
    Cell[132094, 6538, 97, 1, 70, "Text",
      CellTags->{"S1.7.4", "4.6"}],
    Cell[132194, 6541, 554, 12, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.7"}],
    Cell[132751, 6555, 86, 1, 70, "Text",
      CellTags->{"S1.7.4", "4.8"}],
    Cell[132840, 6558, 1266, 35, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.9"}],
    Cell[134109, 6595, 2264, 57, 70, "Text",
      CellTags->{"S1.7.4", "4.10"}],
    Cell[136376, 6654, 1266, 35, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.11"}],
    Cell[137645, 6691, 2806, 76, 70, "Text",
      CellTags->{"S1.7.4", "4.12"}],
    Cell[140454, 6769, 206, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.13"}],
    Cell[140663, 6775, 196, 7, 70, "Text",
      CellTags->{"S1.7.4", "4.14"}],
    Cell[140862, 6784, 201, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.15"}],
    Cell[141066, 6790, 172, 4, 70, "Text",
      CellTags->{"S1.7.4", "4.16"}],
    Cell[141241, 6796, 230, 10, 70, "Text",
      CellTags->{"S1.7.4", "4.17"}],
    Cell[141474, 6808, 501, 15, 70, "Text",
      CellTags->{"S1.7.4", "4.18"}],
    Cell[141978, 6825, 256, 7, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.19"}],
    Cell[142237, 6834, 136, 5, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[142376, 6841, 353, 11, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.20"}],
    Cell[142732, 6854, 98, 2, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[142833, 6858, 131, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.21"}],
    Cell[142989, 6866, 84, 2, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[143076, 6870, 90, 3, 70, "Output",
      CellTags->"S1.7.4"],
    Cell[143181, 6876, 1151, 28, 70, "Text",
      CellTags->{"S1.7.4", "4.22"}],
    Cell[144335, 6906, 352, 7, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.23"}],
    Cell[144712, 6917, 155, 5, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[144870, 6924, 12179, 1061, 70, 12106, 1058, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.4"],
    Cell[157064, 7988, 143, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.24"}],
    Cell[157232, 7996, 161, 5, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[157396, 8003, 16524, 1451, 70, 16451, 1448, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.4"],
    Cell[173935, 9457, 133, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.25"}],
    Cell[174093, 9465, 156, 5, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[174252, 9472, 16466, 1451, 70, 16393, 1448, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.4"],
    Cell[190733, 10926, 746, 15, 70, "Text",
      CellTags->{"S1.7.4", "4.26"}],
    Cell[191482, 10943, 317, 9, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.27"}],
    Cell[191824, 10956, 236, 7, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[192063, 10965, 11214, 1641, 70, 11141, 1638, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.4"],
    Cell[203292, 12609, 199, 5, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.28"}],
    Cell[203516, 12618, 205, 6, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[203724, 12626, 3511, 241, 70, 3438, 238, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.4"],
    Cell[207250, 12870, 166, 5, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.29"}],
    Cell[207441, 12879, 108, 2, 70, "Input",
      CellTags->"S1.7.4"],
    Cell[207552, 12883, 107, 3, 70, "Output",
      CellTags->"S1.7.4"]},
  "4.1"->{
    Cell[128693, 6447, 89, 1, 70, "Subsection",
      CellTags->{"S1.7.4", "4.1"}]},
  "4.2"->{
    Cell[128785, 6450, 1542, 34, 70, "Text",
      CellTags->{"S1.7.4", "4.2"}]},
  "4.3"->{
    Cell[130330, 6486, 304, 7, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.3"}]},
  "4.4"->{
    Cell[130637, 6495, 929, 28, 70, "Text",
      CellTags->{"S1.7.4", "4.4"}]},
  "4.5"->{
    Cell[131569, 6525, 522, 11, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.5"}]},
  "4.6"->{
    Cell[132094, 6538, 97, 1, 70, "Text",
      CellTags->{"S1.7.4", "4.6"}]},
  "4.7"->{
    Cell[132194, 6541, 554, 12, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.7"}]},
  "4.8"->{
    Cell[132751, 6555, 86, 1, 70, "Text",
      CellTags->{"S1.7.4", "4.8"}]},
  "4.9"->{
    Cell[132840, 6558, 1266, 35, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.9"}]},
  "4.10"->{
    Cell[134109, 6595, 2264, 57, 70, "Text",
      CellTags->{"S1.7.4", "4.10"}]},
  "4.11"->{
    Cell[136376, 6654, 1266, 35, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.11"}]},
  "4.12"->{
    Cell[137645, 6691, 2806, 76, 70, "Text",
      CellTags->{"S1.7.4", "4.12"}]},
  "4.13"->{
    Cell[140454, 6769, 206, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.13"}]},
  "4.14"->{
    Cell[140663, 6775, 196, 7, 70, "Text",
      CellTags->{"S1.7.4", "4.14"}]},
  "4.15"->{
    Cell[140862, 6784, 201, 4, 70, "DisplayFormula",
      CellTags->{"S1.7.4", "4.15"}]},
  "4.16"->{
    Cell[141066, 6790, 172, 4, 70, "Text",
      CellTags->{"S1.7.4", "4.16"}]},
  "4.17"->{
    Cell[141241, 6796, 230, 10, 70, "Text",
      CellTags->{"S1.7.4", "4.17"}]},
  "4.18"->{
    Cell[141474, 6808, 501, 15, 70, "Text",
      CellTags->{"S1.7.4", "4.18"}]},
  "4.19"->{
    Cell[141978, 6825, 256, 7, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.19"}]},
  "4.20"->{
    Cell[142376, 6841, 353, 11, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.20"}]},
  "4.21"->{
    Cell[142833, 6858, 131, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.21"}]},
  "4.22"->{
    Cell[143181, 6876, 1151, 28, 70, "Text",
      CellTags->{"S1.7.4", "4.22"}]},
  "4.23"->{
    Cell[144335, 6906, 352, 7, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.23"}]},
  "4.24"->{
    Cell[157064, 7988, 143, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.24"}]},
  "4.25"->{
    Cell[173935, 9457, 133, 4, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.25"}]},
  "4.26"->{
    Cell[190733, 10926, 746, 15, 70, "Text",
      CellTags->{"S1.7.4", "4.26"}]},
  "4.27"->{
    Cell[191482, 10943, 317, 9, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.27"}]},
  "4.28"->{
    Cell[203292, 12609, 199, 5, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.28"}]},
  "4.29"->{
    Cell[207250, 12870, 166, 5, 70, "MathCaption",
      CellTags->{"S1.7.4", "4.29"}]},
  "S1.7.5"->{
    Cell[207674, 12889, 98, 1, 70, "Subsection",
      CellTags->{"S1.7.5", "5.1"}],
    Cell[207775, 12892, 1840, 50, 70, "Text",
      CellTags->{"S1.7.5", "5.2"}],
    Cell[209618, 12944, 393, 17, 70, "Text",
      CellTags->{"S1.7.5", "5.3"}],
    Cell[210014, 12963, 1534, 46, 70, "Text",
      CellTags->{"S1.7.5", "5.4"}],
    Cell[211551, 13011, 116, 2, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.5"}],
    Cell[211670, 13015, 95, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[211768, 13019, 520, 16, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.6"}],
    Cell[212291, 13037, 108, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[212402, 13041, 211, 7, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.7"}],
    Cell[212638, 13052, 86, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[212727, 13056, 108, 3, 70, "Output",
      CellTags->"S1.7.5"],
    Cell[212850, 13062, 159, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.8"}],
    Cell[213034, 13070, 104, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[213141, 13074, 86, 3, 70, "Output",
      CellTags->"S1.7.5"],
    Cell[213242, 13080, 285, 6, 70, "Text",
      CellTags->{"S1.7.5", "5.9"}],
    Cell[213530, 13088, 388, 17, 70, "Text",
      CellTags->{"S1.7.5", "5.10"}],
    Cell[213921, 13107, 156, 4, 70, "Text",
      CellTags->{"S1.7.5", "5.11"}],
    Cell[214080, 13113, 131, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.12"}],
    Cell[214214, 13119, 105, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[214322, 13123, 154, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.13"}],
    Cell[214501, 13131, 89, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[214593, 13135, 221, 6, 70, "Output",
      CellTags->"S1.7.5"],
    Cell[214829, 13144, 156, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.14"}],
    Cell[215010, 13152, 139, 5, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[215152, 13159, 11117, 938, 70, 11044, 935, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.5"],
    Cell[226284, 14100, 369, 7, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.15"}],
    Cell[226678, 14111, 212, 6, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[226893, 14119, 9652, 1534, 70, 9579, 1531, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S1.7.5"],
    Cell[236560, 15656, 159, 5, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.16"}],
    Cell[236744, 15665, 117, 2, 70, "Input",
      CellTags->"S1.7.5"],
    Cell[236864, 15669, 85, 3, 70, "Output",
      CellTags->"S1.7.5"]},
  "5.1"->{
    Cell[207674, 12889, 98, 1, 70, "Subsection",
      CellTags->{"S1.7.5", "5.1"}]},
  "5.2"->{
    Cell[207775, 12892, 1840, 50, 70, "Text",
      CellTags->{"S1.7.5", "5.2"}]},
  "5.3"->{
    Cell[209618, 12944, 393, 17, 70, "Text",
      CellTags->{"S1.7.5", "5.3"}]},
  "5.4"->{
    Cell[210014, 12963, 1534, 46, 70, "Text",
      CellTags->{"S1.7.5", "5.4"}]},
  "5.5"->{
    Cell[211551, 13011, 116, 2, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.5"}]},
  "5.6"->{
    Cell[211768, 13019, 520, 16, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.6"}]},
  "5.7"->{
    Cell[212402, 13041, 211, 7, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.7"}]},
  "5.8"->{
    Cell[212850, 13062, 159, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.8"}]},
  "5.9"->{
    Cell[213242, 13080, 285, 6, 70, "Text",
      CellTags->{"S1.7.5", "5.9"}]},
  "5.10"->{
    Cell[213530, 13088, 388, 17, 70, "Text",
      CellTags->{"S1.7.5", "5.10"}]},
  "5.11"->{
    Cell[213921, 13107, 156, 4, 70, "Text",
      CellTags->{"S1.7.5", "5.11"}]},
  "5.12"->{
    Cell[214080, 13113, 131, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.12"}]},
  "5.13"->{
    Cell[214322, 13123, 154, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.13"}]},
  "5.14"->{
    Cell[214829, 13144, 156, 4, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.14"}]},
  "5.15"->{
    Cell[226284, 14100, 369, 7, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.15"}]},
  "5.16"->{
    Cell[236560, 15656, 159, 5, 70, "MathCaption",
      CellTags->{"S1.7.5", "5.16"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 237603, 15693},
  {"S1.7.0", 237761, 15698},
  {"0.1", 237850, 15701},
  {"S1.7.1", 237942, 15704},
  {"1.1", 238441, 15717},
  {"1.2", 238533, 15720},
  {"1.3", 238623, 15723},
  {"1.4", 238721, 15726},
  {"1.5", 238812, 15729},
  {"1.6", 238911, 15732},
  {"S1.7.2", 239003, 15735},
  {"2.1", 243307, 15844},
  {"2.2", 243400, 15847},
  {"2.3", 243489, 15850},
  {"2.4", 243587, 15853},
  {"2.5", 243674, 15856},
  {"2.6", 243772, 15859},
  {"2.7", 243859, 15862},
  {"2.8", 243957, 15865},
  {"2.9", 244044, 15868},
  {"2.10", 244143, 15871},
  {"2.11", 244235, 15874},
  {"2.12", 244337, 15877},
  {"2.13", 244429, 15880},
  {"2.14", 244530, 15883},
  {"2.15", 244621, 15886},
  {"2.16", 244722, 15889},
  {"2.17", 244814, 15892},
  {"2.18", 244916, 15895},
  {"2.19", 245006, 15898},
  {"2.20", 245108, 15901},
  {"2.21", 245198, 15904},
  {"2.22", 245300, 15907},
  {"2.23", 245392, 15910},
  {"2.24", 245492, 15913},
  {"2.25", 245583, 15916},
  {"2.26", 245685, 15919},
  {"2.27", 245775, 15922},
  {"2.28", 245876, 15925},
  {"2.29", 245968, 15928},
  {"2.30", 246070, 15931},
  {"2.31", 246162, 15934},
  {"2.32", 246254, 15937},
  {"2.33", 246346, 15940},
  {"2.34", 246438, 15943},
  {"2.35", 246531, 15946},
  {"2.36", 246623, 15949},
  {"2.37", 246720, 15952},
  {"2.38", 246817, 15955},
  {"2.39", 246915, 15958},
  {"2.40", 247012, 15961},
  {"2.41", 247109, 15964},
  {"2.42", 247207, 15967},
  {"S1.7.3", 247307, 15970},
  {"3.1", 252296, 16095},
  {"3.2", 252391, 16098},
  {"3.3", 252482, 16101},
  {"3.4", 252581, 16104},
  {"3.5", 252671, 16107},
  {"3.6", 252772, 16110},
  {"3.7", 252863, 16113},
  {"3.8", 252964, 16116},
  {"3.9", 253054, 16119},
  {"3.10", 253155, 16122},
  {"3.11", 253249, 16125},
  {"3.12", 253351, 16128},
  {"3.13", 253443, 16131},
  {"3.14", 253547, 16134},
  {"3.15", 253640, 16137},
  {"3.16", 253742, 16140},
  {"3.17", 253835, 16143},
  {"3.18", 253937, 16146},
  {"3.19", 254031, 16149},
  {"3.20", 254133, 16152},
  {"3.21", 254233, 16155},
  {"3.22", 254333, 16158},
  {"3.23", 254427, 16161},
  {"3.24", 254529, 16164},
  {"3.25", 254623, 16167},
  {"3.26", 254722, 16170},
  {"3.27", 254816, 16173},
  {"3.28", 254909, 16176},
  {"3.29", 255002, 16179},
  {"3.30", 255102, 16182},
  {"3.31", 255196, 16185},
  {"3.32", 255295, 16188},
  {"3.33", 255388, 16191},
  {"3.34", 255481, 16194},
  {"3.35", 255574, 16197},
  {"3.36", 255674, 16200},
  {"3.37", 255772, 16203},
  {"3.38", 255873, 16206},
  {"3.39", 255967, 16209},
  {"S1.7.4", 256069, 16212},
  {"4.1", 260118, 16313},
  {"4.2", 260214, 16316},
  {"4.3", 260307, 16319},
  {"4.4", 260408, 16322},
  {"4.5", 260500, 16325},
  {"4.6", 260602, 16328},
  {"4.7", 260692, 16331},
  {"4.8", 260794, 16334},
  {"4.9", 260884, 16337},
  {"4.10", 260988, 16340},
  {"4.11", 261083, 16343},
  {"4.12", 261188, 16346},
  {"4.13", 261283, 16349},
  {"4.14", 261386, 16352},
  {"4.15", 261479, 16355},
  {"4.16", 261582, 16358},
  {"4.17", 261675, 16361},
  {"4.18", 261769, 16364},
  {"4.19", 261863, 16367},
  {"4.20", 261963, 16370},
  {"4.21", 262064, 16373},
  {"4.22", 262164, 16376},
  {"4.23", 262259, 16379},
  {"4.24", 262359, 16382},
  {"4.25", 262459, 16385},
  {"4.26", 262559, 16388},
  {"4.27", 262654, 16391},
  {"4.28", 262755, 16394},
  {"4.29", 262856, 16397},
  {"S1.7.5", 262959, 16400},
  {"5.1", 265580, 16467},
  {"5.2", 265677, 16470},
  {"5.3", 265771, 16473},
  {"5.4", 265864, 16476},
  {"5.5", 265958, 16479},
  {"5.6", 266057, 16482},
  {"5.7", 266157, 16485},
  {"5.8", 266256, 16488},
  {"5.9", 266355, 16491},
  {"5.10", 266448, 16494},
  {"5.11", 266543, 16497},
  {"5.12", 266637, 16500},
  {"5.13", 266738, 16503},
  {"5.14", 266839, 16506},
  {"5.15", 266940, 16509},
  {"5.16", 267041, 16512}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 87, 1, 86, "Section",
  CellTags->"Contents"],
Cell[1799, 52, 724, 22, 99, "Contents",
  CellTags->"Contents"],
Cell[2526, 76, 94, 1, 86, "Section",
  CellTags->{"S1.7.0", "0.1"}],
Cell[2623, 79, 86, 1, 41, "Subsection",
  CellTags->{"S1.7.1", "1.1"}],
Cell[2712, 82, 1846, 41, 227, "Text",
  CellTags->{"S1.7.1", "1.2"}],
Cell[4561, 125, 333, 8, 38, "DisplayFormula",
  CellTags->{"S1.7.1", "1.3"}],
Cell[4897, 135, 1211, 31, 115, "Text",
  CellTags->{"S1.7.1", "1.4"}],
Cell[6111, 168, 567, 17, 70, "DisplayFormula",
  CellTags->{"S1.7.1", "1.5"}],
Cell[6681, 187, 859, 15, 70, "Text",
  CellTags->{"S1.7.1", "1.6"}],
Cell[7543, 204, 94, 1, 70, "Subsection",
  CellTags->{"S1.7.2", "2.1"}],
Cell[7640, 207, 676, 15, 70, "Text",
  CellTags->{"S1.7.2", "2.2"}],
Cell[8319, 224, 214, 4, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.3"}],
Cell[8536, 230, 47, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.4"}],
Cell[8586, 233, 233, 5, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.5"}],
Cell[8822, 240, 47, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.6"}],
Cell[8872, 243, 228, 5, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.7"}],
Cell[9103, 250, 47, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.8"}],
Cell[9153, 253, 228, 5, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.9"}],
Cell[9384, 260, 1066, 34, 70, "Text",
  CellTags->{"S1.7.2", "2.10"}],
Cell[10453, 296, 467, 10, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.11"}],
Cell[10923, 308, 582, 16, 70, "Text",
  CellTags->{"S1.7.2", "2.12"}],
Cell[11508, 326, 414, 9, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.13"}],
Cell[11925, 337, 221, 7, 70, "Text",
  CellTags->{"S1.7.2", "2.14"}],
Cell[12149, 346, 312, 7, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.15"}],
Cell[12464, 355, 567, 15, 70, "Text",
  CellTags->{"S1.7.2", "2.16"}],
Cell[13034, 372, 560, 11, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.17"}],
Cell[13597, 385, 48, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.18"}],
Cell[13648, 388, 563, 11, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.19"}],
Cell[14214, 401, 48, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.20"}],
Cell[14265, 404, 603, 12, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.21"}],
Cell[14871, 418, 500, 19, 70, "Text",
  CellTags->{"S1.7.2", "2.22"}],
Cell[15374, 439, 110, 1, 70, "Subsubsection",
  CellTags->{"S1.7.2", "2.23"}],
Cell[15487, 442, 388, 9, 70, "Text",
  CellTags->{"S1.7.2", "2.24"}],
Cell[15878, 453, 540, 11, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.25"}],
Cell[16421, 466, 65, 1, 70, "Text",
  CellTags->{"S1.7.2", "2.26"}],
Cell[16489, 469, 304, 7, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.27"}],
Cell[16796, 478, 952, 28, 70, "Text",
  CellTags->{"S1.7.2", "2.28"}],
Cell[17751, 508, 480, 11, 70, "DisplayFormula",
  CellTags->{"S1.7.2", "2.29"}],
Cell[18234, 521, 878, 28, 70, "Text",
  CellTags->{"S1.7.2", "2.30"}],
Cell[19115, 551, 377, 17, 70, "Text",
  CellTags->{"S1.7.2", "2.31"}],
Cell[19495, 570, 545, 16, 70, "Text",
  CellTags->{"S1.7.2", "2.32"}],
Cell[20043, 588, 290, 11, 70, "Text",
  CellTags->{"S1.7.2", "2.33"}],
Cell[20336, 601, 1672, 44, 70, "Text",
  CellTags->{"S1.7.2", "2.34"}],
Cell[22011, 647, 429, 22, 70, "Text",
  CellTags->{"S1.7.2", "2.35"}],
Cell[22443, 671, 78, 1, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.36"}],
Cell[22524, 674, 93, 2, 70, "Input",
  CellTags->"S1.7.2"],
Cell[22620, 678, 95, 1, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.37"}],
Cell[22718, 681, 122, 5, 70, "Input",
  CellTags->"S1.7.2"],
Cell[22843, 688, 282, 9, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.38"}],

Cell[CellGroupData[{
Cell[23150, 701, 101, 2, 70, "Input",
  CellTags->"S1.7.2"],
Cell[23254, 705, 528, 10, 70, "Output",
  CellTags->"S1.7.2"]
}, Open  ]],
Cell[23797, 718, 87, 1, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.39"}],

Cell[CellGroupData[{
Cell[23909, 723, 102, 2, 70, "Input",
  CellTags->"S1.7.2"],
Cell[24014, 727, 454, 8, 70, "Output",
  CellTags->"S1.7.2"]
}, Open  ]],
Cell[24483, 738, 98, 1, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.40"}],

Cell[CellGroupData[{
Cell[24606, 743, 76, 2, 70, "Input",
  CellTags->"S1.7.2"],
Cell[24685, 747, 126, 3, 70, "Output",
  CellTags->"S1.7.2"]
}, Open  ]],
Cell[24826, 753, 241, 7, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.41"}],

Cell[CellGroupData[{
Cell[25092, 764, 118, 2, 70, "Input",
  CellTags->"S1.7.2"],
Cell[25213, 768, 506, 9, 70, "Output",
  CellTags->"S1.7.2"]
}, Open  ]],
Cell[25734, 780, 115, 2, 70, "MathCaption",
  CellTags->{"S1.7.2", "2.42"}],

Cell[CellGroupData[{
Cell[25874, 786, 140, 5, 70, "Input",
  CellTags->"S1.7.2"],
Cell[26017, 793, 126, 3, 70, "Output",
  CellTags->"S1.7.2"]
}, Open  ]],
Cell[26158, 799, 107, 1, 70, "Subsection",
  CellTags->{"S1.7.3", "3.1"}],
Cell[26268, 802, 3590, 95, 70, "Text",
  CellTags->{"S1.7.3", "3.2"}],
Cell[29861, 899, 312, 6, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.3"}],
Cell[30176, 907, 487, 13, 70, "Text",
  CellTags->{"S1.7.3", "3.4"}],
Cell[30666, 922, 1342, 34, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.5"}],
Cell[32011, 958, 1028, 31, 70, "Text",
  CellTags->{"S1.7.3", "3.6"}],
Cell[33042, 991, 1240, 32, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.7"}],
Cell[34285, 1025, 199, 7, 70, "Text",
  CellTags->{"S1.7.3", "3.8"}],
Cell[34487, 1034, 351, 7, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.9"}],
Cell[34841, 1043, 1067, 28, 70, "Text",
  CellTags->{"S1.7.3", "3.10"}],
Cell[35911, 1073, 372, 9, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.11"}],
Cell[36286, 1084, 376, 9, 70, "Text",
  CellTags->{"S1.7.3", "3.12"}],
Cell[36665, 1095, 1929, 49, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.13"}],
Cell[38597, 1146, 345, 10, 70, "Text",
  CellTags->{"S1.7.3", "3.14"}],
Cell[38945, 1158, 356, 7, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.15"}],
Cell[39304, 1167, 440, 13, 70, "Text",
  CellTags->{"S1.7.3", "3.16"}],
Cell[39747, 1182, 306, 6, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.17"}],
Cell[40056, 1190, 2958, 81, 70, "Text",
  CellTags->{"S1.7.3", "3.18"}],
Cell[43017, 1273, 313, 6, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.19"}],
Cell[43333, 1281, 346, 11, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.20"}],

Cell[CellGroupData[{
Cell[43704, 1296, 146, 5, 70, "Input",
  CellTags->"S1.7.3"],
Cell[43853, 1303, 4259, 290, 70, 4186, 287, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[48127, 1596, 81, 1, 70, "Subsubsection",
  CellTags->{"S1.7.3", "3.21"}],
Cell[48211, 1599, 2077, 51, 70, "Text",
  CellTags->{"S1.7.3", "3.22"}],
Cell[50291, 1652, 138, 3, 70, "DisplayFormula",
  CellTags->{"S1.7.3", "3.23"}],
Cell[50432, 1657, 1921, 46, 70, "Text",
  CellTags->{"S1.7.3", "3.24"}],
Cell[52356, 1705, 319, 9, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.25"}],

Cell[CellGroupData[{
Cell[52700, 1718, 169, 6, 70, "Input",
  CellTags->"S1.7.3"],
Cell[52872, 1726, 6723, 450, 70, 6650, 447, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[59610, 2179, 1317, 35, 70, "Text",
  CellTags->{"S1.7.3", "3.26"}],
Cell[60930, 2216, 226, 10, 70, "Text",
  CellTags->{"S1.7.3", "3.27"}],
Cell[61159, 2228, 616, 20, 70, "Text",
  CellTags->{"S1.7.3", "3.28"}],
Cell[61778, 2250, 568, 20, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.29"}],

Cell[CellGroupData[{
Cell[62371, 2274, 88, 2, 70, "Input",
  CellTags->"S1.7.3"],
Cell[62462, 2278, 124, 3, 70, "Output",
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[62601, 2284, 2350, 83, 70, "Text",
  CellTags->{"S1.7.3", "3.30"}],
Cell[64954, 2369, 146, 4, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.31"}],

Cell[CellGroupData[{
Cell[65125, 2377, 387, 11, 70, "Input",
  CellTags->"S1.7.3"],
Cell[65515, 2390, 9333, 614, 70, 9260, 611, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[74863, 3007, 434, 13, 70, "Text",
  CellTags->{"S1.7.3", "3.32"}],
Cell[75300, 3022, 471, 23, 70, "Text",
  CellTags->{"S1.7.3", "3.33"}],
Cell[75774, 3047, 482, 15, 70, "Text",
  CellTags->{"S1.7.3", "3.34"}],
Cell[76259, 3064, 365, 11, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.35"}],

Cell[CellGroupData[{
Cell[76649, 3079, 209, 6, 70, "Input",
  CellTags->"S1.7.3"],
Cell[76861, 3087, 9788, 654, 70, 9715, 651, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[86664, 3744, 95, 1, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.36"}],

Cell[CellGroupData[{
Cell[86784, 3749, 298, 9, 70, "Input",
  CellTags->"S1.7.3"],
Cell[87085, 3760, 13371, 883, 70, 13298, 880, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[100471, 4646, 527, 13, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.37"}],

Cell[CellGroupData[{
Cell[101023, 4663, 309, 9, 70, "Input",
  CellTags->"S1.7.3"],
Cell[101335, 4674, 19133, 1250, 70, 19060, 1247, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[120483, 5927, 665, 25, 70, "Text",
  CellTags->{"S1.7.3", "3.38"}],
Cell[121151, 5954, 234, 7, 70, "MathCaption",
  CellTags->{"S1.7.3", "3.39"}],

Cell[CellGroupData[{
Cell[121410, 5965, 199, 6, 70, "Input",
  CellTags->"S1.7.3"],
Cell[121612, 5973, 7066, 471, 70, 6993, 468, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.3"]
}, Open  ]],
Cell[128693, 6447, 89, 1, 70, "Subsection",
  CellTags->{"S1.7.4", "4.1"}],
Cell[128785, 6450, 1542, 34, 70, "Text",
  CellTags->{"S1.7.4", "4.2"}],
Cell[130330, 6486, 304, 7, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.3"}],
Cell[130637, 6495, 929, 28, 70, "Text",
  CellTags->{"S1.7.4", "4.4"}],
Cell[131569, 6525, 522, 11, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.5"}],
Cell[132094, 6538, 97, 1, 70, "Text",
  CellTags->{"S1.7.4", "4.6"}],
Cell[132194, 6541, 554, 12, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.7"}],
Cell[132751, 6555, 86, 1, 70, "Text",
  CellTags->{"S1.7.4", "4.8"}],
Cell[132840, 6558, 1266, 35, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.9"}],
Cell[134109, 6595, 2264, 57, 70, "Text",
  CellTags->{"S1.7.4", "4.10"}],
Cell[136376, 6654, 1266, 35, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.11"}],
Cell[137645, 6691, 2806, 76, 70, "Text",
  CellTags->{"S1.7.4", "4.12"}],
Cell[140454, 6769, 206, 4, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.13"}],
Cell[140663, 6775, 196, 7, 70, "Text",
  CellTags->{"S1.7.4", "4.14"}],
Cell[140862, 6784, 201, 4, 70, "DisplayFormula",
  CellTags->{"S1.7.4", "4.15"}],
Cell[141066, 6790, 172, 4, 70, "Text",
  CellTags->{"S1.7.4", "4.16"}],
Cell[141241, 6796, 230, 10, 70, "Text",
  CellTags->{"S1.7.4", "4.17"}],
Cell[141474, 6808, 501, 15, 70, "Text",
  CellTags->{"S1.7.4", "4.18"}],
Cell[141978, 6825, 256, 7, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.19"}],
Cell[142237, 6834, 136, 5, 70, "Input",
  CellTags->"S1.7.4"],
Cell[142376, 6841, 353, 11, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.20"}],
Cell[142732, 6854, 98, 2, 70, "Input",
  CellTags->"S1.7.4"],
Cell[142833, 6858, 131, 4, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.21"}],

Cell[CellGroupData[{
Cell[142989, 6866, 84, 2, 70, "Input",
  CellTags->"S1.7.4"],
Cell[143076, 6870, 90, 3, 70, "Output",
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[143181, 6876, 1151, 28, 70, "Text",
  CellTags->{"S1.7.4", "4.22"}],
Cell[144335, 6906, 352, 7, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.23"}],

Cell[CellGroupData[{
Cell[144712, 6917, 155, 5, 70, "Input",
  CellTags->"S1.7.4"],
Cell[144870, 6924, 12179, 1061, 70, 12106, 1058, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[157064, 7988, 143, 4, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.24"}],

Cell[CellGroupData[{
Cell[157232, 7996, 161, 5, 70, "Input",
  CellTags->"S1.7.4"],
Cell[157396, 8003, 16524, 1451, 70, 16451, 1448, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[173935, 9457, 133, 4, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.25"}],

Cell[CellGroupData[{
Cell[174093, 9465, 156, 5, 70, "Input",
  CellTags->"S1.7.4"],
Cell[174252, 9472, 16466, 1451, 70, 16393, 1448, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[190733, 10926, 746, 15, 70, "Text",
  CellTags->{"S1.7.4", "4.26"}],
Cell[191482, 10943, 317, 9, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.27"}],

Cell[CellGroupData[{
Cell[191824, 10956, 236, 7, 70, "Input",
  CellTags->"S1.7.4"],
Cell[192063, 10965, 11214, 1641, 70, 11141, 1638, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[203292, 12609, 199, 5, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.28"}],

Cell[CellGroupData[{
Cell[203516, 12618, 205, 6, 70, "Input",
  CellTags->"S1.7.4"],
Cell[203724, 12626, 3511, 241, 70, 3438, 238, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[207250, 12870, 166, 5, 70, "MathCaption",
  CellTags->{"S1.7.4", "4.29"}],

Cell[CellGroupData[{
Cell[207441, 12879, 108, 2, 70, "Input",
  CellTags->"S1.7.4"],
Cell[207552, 12883, 107, 3, 70, "Output",
  CellTags->"S1.7.4"]
}, Open  ]],
Cell[207674, 12889, 98, 1, 70, "Subsection",
  CellTags->{"S1.7.5", "5.1"}],
Cell[207775, 12892, 1840, 50, 70, "Text",
  CellTags->{"S1.7.5", "5.2"}],
Cell[209618, 12944, 393, 17, 70, "Text",
  CellTags->{"S1.7.5", "5.3"}],
Cell[210014, 12963, 1534, 46, 70, "Text",
  CellTags->{"S1.7.5", "5.4"}],
Cell[211551, 13011, 116, 2, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.5"}],
Cell[211670, 13015, 95, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[211768, 13019, 520, 16, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.6"}],
Cell[212291, 13037, 108, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[212402, 13041, 211, 7, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.7"}],

Cell[CellGroupData[{
Cell[212638, 13052, 86, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[212727, 13056, 108, 3, 70, "Output",
  CellTags->"S1.7.5"]
}, Open  ]],
Cell[212850, 13062, 159, 4, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.8"}],

Cell[CellGroupData[{
Cell[213034, 13070, 104, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[213141, 13074, 86, 3, 70, "Output",
  CellTags->"S1.7.5"]
}, Open  ]],
Cell[213242, 13080, 285, 6, 70, "Text",
  CellTags->{"S1.7.5", "5.9"}],
Cell[213530, 13088, 388, 17, 70, "Text",
  CellTags->{"S1.7.5", "5.10"}],
Cell[213921, 13107, 156, 4, 70, "Text",
  CellTags->{"S1.7.5", "5.11"}],
Cell[214080, 13113, 131, 4, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.12"}],
Cell[214214, 13119, 105, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[214322, 13123, 154, 4, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.13"}],

Cell[CellGroupData[{
Cell[214501, 13131, 89, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[214593, 13135, 221, 6, 70, "Output",
  CellTags->"S1.7.5"]
}, Open  ]],
Cell[214829, 13144, 156, 4, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.14"}],

Cell[CellGroupData[{
Cell[215010, 13152, 139, 5, 70, "Input",
  CellTags->"S1.7.5"],
Cell[215152, 13159, 11117, 938, 70, 11044, 935, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.5"]
}, Open  ]],
Cell[226284, 14100, 369, 7, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.15"}],

Cell[CellGroupData[{
Cell[226678, 14111, 212, 6, 70, "Input",
  CellTags->"S1.7.5"],
Cell[226893, 14119, 9652, 1534, 70, 9579, 1531, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S1.7.5"]
}, Open  ]],
Cell[236560, 15656, 159, 5, 70, "MathCaption",
  CellTags->{"S1.7.5", "5.16"}],

Cell[CellGroupData[{
Cell[236744, 15665, 117, 2, 70, "Input",
  CellTags->"S1.7.5"],
Cell[236864, 15669, 85, 3, 70, "Output",
  CellTags->"S1.7.5"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

