(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1763632,     116017]*)
(*NotebookOutlinePosition[   1819470,     117566]*)
(*  CellTagsIndexPosition[   1814372,     117386]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["2.1 Analysis of One\[Hyphen]Dimensional Signals", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["2.1.1 Shock Solution of Burgers Equation",
    ButtonData:>{"Wavelets 2.1.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["2.1.2 Denoising",
    ButtonData:>{"Wavelets 2.1.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["2.1.3 Wavelet Packet Analysis of a Speech Signal",
    ButtonData:>{"Wavelets 2.1.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["2.1.4 Local Cosine Packet Analysis of a Sound Signal",
    ButtonData:>{"Wavelets 2.1.4"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["2.1 Analysis of One\[Hyphen]Dimensional Signals", "Section",
  CellTags->{"S2.1.0", "0.1"}],

Cell["2.1.1 Shock Solution of Burgers Equation", "Subsection",
  CellTags->{"S2.1.1", "1.1"}],

Cell["\<\
The Burgers equation is a one\[Hyphen]dimensional, nonlinear \
partial differential equation that occurs in a wide variety of physical \
contexts and has been investigated extensively. It is given by \
\>", "Text",
  CellTags->{"S2.1.1", "1.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(u\_t\) \((x, t)\) + u \((x, t)\) \(u\_x\) \((x, t)\) = \[Nu] 
      \( u\_\(x  x\)\) \((x, t)\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S2.1.1", "1.3"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u \((x, t)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is a one\[Hyphen]dimensional scalar field representing, for example, the \
velocity as a function of the position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the viscosity. It has been used as a one\[Hyphen]dimensional model of \
turbulence, to describe the formation and decay of shocks in a compressible \
fluid and also as the simplest nonlinear diffusion equation.The \
Cole\[Hyphen]Hopf transformation ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Theta] = \(-2\) \[Nu] \[PartialD]log  u\/\[PartialD]x\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  " linearizes Burgers equation and leads to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_t = \[Nu]\[Theta]\_\(x  x\)\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  ". This, in fact, allows us to obtain an explicit solution to the initial \
value problem. In the limit of zero viscosity, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] \[Rule] 0\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", it is easy to see that regions with larger values of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " catch up with slower regions and cause a shock to develop. The effect of \
the viscosity is to smooth the discontinuity and this leads to a finite shock \
width. The existence of well\[Hyphen]localized shocks makes this an excellent \
testing ground for analysis in terms of different basis functions and, in \
particular, wavelets (see Schult and Wyld (1992)). We will illustrate the \
decomposition of the solution to the Burgers equation obtained for different \
initial conditions into wavelets and Fourier series and then compare them. \
The data employed were obtained using a viscosity of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] = 1.5\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " in a system of length ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1024\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " with periodic boundary conditions. "
}], "Text",
  CellTags->{"S2.1.1", "1.4"}],

Cell["Single Shock", "Subsubsection",
  CellTags->{"S2.1.1", "1.5"}],

Cell[TextData[{
  "The data contained in the file ",
  StyleBox["shocksin.dat", "MR"],
  " are the velocity profile ",
  Cell[BoxData[
      \(TraditionalForm\`u \((x, 400)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, 1, \[Ellipsis], 1023\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " evolved from the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`u \((x, 0)\) = sin \((\(\(2  \[Pi]\)\/1024\) x)\)\)],
     "InlineFormula",
    CellTags->"S2.1.1"],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 400\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ". We first read in the data and plot it. "
}], "Text",
  CellTags->{"S2.1.1", "1.6"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.1", "1.7"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.1"],

Cell[TextData[{
  "This reads in the file ",
  StyleBox["shocksin.dat", "MR"],
  " in the subdirectory ",
  StyleBox["Data", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.8"}],

Cell["\<\
data = Get[ToFileName[{\"Wavelets\", \"Data\"}, \"shocksin.dat\"]];\
\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.1"],

Cell[TextData[{
  "We plot the velocity profile at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 400\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " (darker line) along with the initial profile of the velocity (lighter \
line). Note that a shock or \"discontinuity\" has developed."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.9"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[data, AxesLabel -> {\"x\", \"\"},
PlotLabel -> \"u(x,t) at t=0 and t=400\"],
Plot[Sin[2Pi/1024 x], {x, 0, 1024},
PlotStyle -> GrayLevel[0.3]]}]]\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.309016 0.294303 [
[.20982 .29652 -9 -9 ]
[.20982 .29652 9 0 ]
[.39583 .29652 -9 -9 ]
[.39583 .29652 9 0 ]
[.58185 .29652 -9 -9 ]
[.58185 .29652 9 0 ]
[.76786 .29652 -9 -9 ]
[.76786 .29652 9 0 ]
[.95387 .29652 -12 -9 ]
[.95387 .29652 12 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -69 0 ]
[.5 .63053 69 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .30902 m
.20982 .31527 L
s
[(200)] .20982 .29652 0 1 Mshowa
.39583 .30902 m
.39583 .31527 L
s
[(400)] .39583 .29652 0 1 Mshowa
.58185 .30902 m
.58185 .31527 L
s
[(600)] .58185 .29652 0 1 Mshowa
.76786 .30902 m
.76786 .31527 L
s
[(800)] .76786 .29652 0 1 Mshowa
.95387 .30902 m
.95387 .31527 L
s
[(1000)] .95387 .29652 0 1 Mshowa
.125 Mabswid
.07031 .30902 m
.07031 .31277 L
s
.11682 .30902 m
.11682 .31277 L
s
.16332 .30902 m
.16332 .31277 L
s
.25632 .30902 m
.25632 .31277 L
s
.30283 .30902 m
.30283 .31277 L
s
.34933 .30902 m
.34933 .31277 L
s
.44234 .30902 m
.44234 .31277 L
s
.48884 .30902 m
.48884 .31277 L
s
.53534 .30902 m
.53534 .31277 L
s
.62835 .30902 m
.62835 .31277 L
s
.67485 .30902 m
.67485 .31277 L
s
.72135 .30902 m
.72135 .31277 L
s
.81436 .30902 m
.81436 .31277 L
s
.86086 .30902 m
.86086 .31277 L
s
.90737 .30902 m
.90737 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(x)] 1.025 .30902 -1 0 Mshowa
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x,t\\) at t=0 and t=400)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02474 .30902 Mdot
.02567 .30954 Mdot
.0266 .31006 Mdot
.02753 .31058 Mdot
.02846 .3111 Mdot
.02939 .31163 Mdot
.03032 .31215 Mdot
.03125 .31267 Mdot
.03218 .31319 Mdot
.03311 .31371 Mdot
.03404 .31424 Mdot
.03497 .31476 Mdot
.0359 .31528 Mdot
.03683 .3158 Mdot
.03776 .31632 Mdot
.03869 .31685 Mdot
.03962 .31737 Mdot
.04055 .31789 Mdot
.04148 .31841 Mdot
.04241 .31893 Mdot
.04334 .31946 Mdot
.04427 .31998 Mdot
.0452 .3205 Mdot
.04613 .32102 Mdot
.04706 .32154 Mdot
.04799 .32207 Mdot
.04892 .32259 Mdot
.04985 .32311 Mdot
.05078 .32363 Mdot
.05171 .32415 Mdot
.05264 .32467 Mdot
.05357 .3252 Mdot
.0545 .32572 Mdot
.05543 .32624 Mdot
.05636 .32676 Mdot
.05729 .32728 Mdot
.05822 .3278 Mdot
.05915 .32833 Mdot
.06008 .32885 Mdot
.06101 .32937 Mdot
.06194 .32989 Mdot
.06287 .33041 Mdot
.0638 .33093 Mdot
.06473 .33146 Mdot
.06566 .33198 Mdot
.06659 .3325 Mdot
.06752 .33302 Mdot
.06845 .33354 Mdot
.06938 .33406 Mdot
.07031 .33458 Mdot
.07124 .33511 Mdot
.07217 .33563 Mdot
.0731 .33615 Mdot
.07403 .33667 Mdot
.07496 .33719 Mdot
.07589 .33771 Mdot
.07682 .33823 Mdot
.07775 .33876 Mdot
.07868 .33928 Mdot
.07961 .3398 Mdot
.08054 .34032 Mdot
.08147 .34084 Mdot
.0824 .34136 Mdot
.08333 .34188 Mdot
.08426 .3424 Mdot
.08519 .34292 Mdot
.08612 .34344 Mdot
.08705 .34397 Mdot
.08798 .34449 Mdot
.08891 .34501 Mdot
.08984 .34553 Mdot
.09077 .34605 Mdot
.0917 .34657 Mdot
.09263 .34709 Mdot
.09356 .34761 Mdot
.09449 .34813 Mdot
.09542 .34865 Mdot
.09635 .34917 Mdot
.09728 .34969 Mdot
.09821 .35021 Mdot
.09914 .35073 Mdot
.10007 .35125 Mdot
.101 .35178 Mdot
.10193 .3523 Mdot
.10286 .35282 Mdot
.10379 .35334 Mdot
.10472 .35386 Mdot
.10565 .35438 Mdot
.10658 .3549 Mdot
.10751 .35542 Mdot
.10844 .35594 Mdot
.10938 .35646 Mdot
.11031 .35698 Mdot
.11124 .3575 Mdot
.11217 .35802 Mdot
.1131 .35854 Mdot
.11403 .35906 Mdot
.11496 .35958 Mdot
.11589 .36009 Mdot
.11682 .36061 Mdot
.11775 .36113 Mdot
.11868 .36165 Mdot
.11961 .36217 Mdot
.12054 .36269 Mdot
.12147 .36321 Mdot
.1224 .36373 Mdot
.12333 .36425 Mdot
.12426 .36477 Mdot
.12519 .36529 Mdot
.12612 .36581 Mdot
.12705 .36633 Mdot
.12798 .36685 Mdot
.12891 .36736 Mdot
.12984 .36788 Mdot
.13077 .3684 Mdot
.1317 .36892 Mdot
.13263 .36944 Mdot
.13356 .36996 Mdot
.13449 .37048 Mdot
.13542 .37099 Mdot
.13635 .37151 Mdot
.13728 .37203 Mdot
.13821 .37255 Mdot
.13914 .37307 Mdot
.14007 .37359 Mdot
.141 .3741 Mdot
.14193 .37462 Mdot
.14286 .37514 Mdot
.14379 .37566 Mdot
.14472 .37618 Mdot
.14565 .37669 Mdot
.14658 .37721 Mdot
.14751 .37773 Mdot
.14844 .37825 Mdot
.14937 .37876 Mdot
.1503 .37928 Mdot
.15123 .3798 Mdot
.15216 .38032 Mdot
.15309 .38083 Mdot
.15402 .38135 Mdot
.15495 .38187 Mdot
.15588 .38238 Mdot
.15681 .3829 Mdot
.15774 .38342 Mdot
.15867 .38394 Mdot
.1596 .38445 Mdot
.16053 .38497 Mdot
.16146 .38549 Mdot
.16239 .386 Mdot
.16332 .38652 Mdot
.16425 .38703 Mdot
.16518 .38755 Mdot
.16611 .38807 Mdot
.16704 .38858 Mdot
.16797 .3891 Mdot
.1689 .38961 Mdot
.16983 .39013 Mdot
.17076 .39065 Mdot
.17169 .39116 Mdot
.17262 .39168 Mdot
.17355 .39219 Mdot
.17448 .39271 Mdot
.17541 .39322 Mdot
.17634 .39374 Mdot
.17727 .39425 Mdot
.1782 .39477 Mdot
.17913 .39528 Mdot
.18006 .3958 Mdot
.18099 .39631 Mdot
.18192 .39683 Mdot
.18285 .39734 Mdot
.18378 .39786 Mdot
.18471 .39837 Mdot
.18564 .39889 Mdot
.18657 .3994 Mdot
.1875 .39991 Mdot
.18843 .40043 Mdot
.18936 .40094 Mdot
.19029 .40146 Mdot
.19122 .40197 Mdot
.19215 .40248 Mdot
.19308 .403 Mdot
.19401 .40351 Mdot
.19494 .40402 Mdot
.19587 .40454 Mdot
.1968 .40505 Mdot
.19773 .40556 Mdot
.19866 .40608 Mdot
.19959 .40659 Mdot
.20052 .4071 Mdot
.20145 .40761 Mdot
.20238 .40813 Mdot
.20331 .40864 Mdot
.20424 .40915 Mdot
.20517 .40966 Mdot
.2061 .41018 Mdot
.20703 .41069 Mdot
.20796 .4112 Mdot
.20889 .41171 Mdot
.20982 .41222 Mdot
.21075 .41273 Mdot
.21168 .41325 Mdot
.21261 .41376 Mdot
.21354 .41427 Mdot
.21447 .41478 Mdot
.2154 .41529 Mdot
.21633 .4158 Mdot
.21726 .41631 Mdot
.21819 .41682 Mdot
.21912 .41733 Mdot
.22005 .41784 Mdot
.22098 .41835 Mdot
.22191 .41886 Mdot
.22284 .41937 Mdot
.22377 .41988 Mdot
.2247 .42039 Mdot
.22563 .4209 Mdot
.22656 .42141 Mdot
.22749 .42192 Mdot
.22842 .42243 Mdot
.22935 .42294 Mdot
.23028 .42345 Mdot
.23121 .42396 Mdot
.23214 .42447 Mdot
.23307 .42498 Mdot
.234 .42548 Mdot
.23493 .42599 Mdot
.23586 .4265 Mdot
.23679 .42701 Mdot
.23772 .42752 Mdot
.23865 .42803 Mdot
.23958 .42853 Mdot
.24051 .42904 Mdot
.24144 .42955 Mdot
.24237 .43005 Mdot
.2433 .43056 Mdot
.24423 .43107 Mdot
.24516 .43158 Mdot
.24609 .43208 Mdot
.24702 .43259 Mdot
.24795 .4331 Mdot
.24888 .4336 Mdot
.24981 .43411 Mdot
.25074 .43461 Mdot
.25167 .43512 Mdot
.2526 .43563 Mdot
.25353 .43613 Mdot
.25446 .43664 Mdot
.25539 .43714 Mdot
.25632 .43765 Mdot
.25725 .43815 Mdot
.25818 .43866 Mdot
.25911 .43916 Mdot
.26004 .43967 Mdot
.26097 .44017 Mdot
.2619 .44067 Mdot
.26283 .44118 Mdot
.26376 .44168 Mdot
.26469 .44219 Mdot
.26563 .44269 Mdot
.26656 .44319 Mdot
.26749 .4437 Mdot
.26842 .4442 Mdot
.26935 .4447 Mdot
.27028 .4452 Mdot
.27121 .44571 Mdot
.27214 .44621 Mdot
.27307 .44671 Mdot
.274 .44721 Mdot
.27493 .44772 Mdot
.27586 .44822 Mdot
.27679 .44872 Mdot
.27772 .44922 Mdot
.27865 .44972 Mdot
.27958 .45022 Mdot
.28051 .45072 Mdot
.28144 .45122 Mdot
.28237 .45172 Mdot
.2833 .45222 Mdot
.28423 .45272 Mdot
.28516 .45322 Mdot
.28609 .45372 Mdot
.28702 .45422 Mdot
.28795 .45472 Mdot
.28888 .45522 Mdot
.28981 .45572 Mdot
.29074 .45622 Mdot
.29167 .45672 Mdot
.2926 .45722 Mdot
.29353 .45772 Mdot
.29446 .45821 Mdot
.29539 .45871 Mdot
.29632 .45921 Mdot
.29725 .45971 Mdot
.29818 .4602 Mdot
.29911 .4607 Mdot
.30004 .4612 Mdot
.30097 .46169 Mdot
.3019 .46219 Mdot
.30283 .46269 Mdot
.30376 .46318 Mdot
.30469 .46368 Mdot
.30562 .46417 Mdot
.30655 .46467 Mdot
.30748 .46516 Mdot
.30841 .46566 Mdot
.30934 .46615 Mdot
.31027 .46665 Mdot
.3112 .46714 Mdot
.31213 .46764 Mdot
.31306 .46813 Mdot
.31399 .46863 Mdot
.31492 .46912 Mdot
.31585 .46961 Mdot
.31678 .47011 Mdot
.31771 .4706 Mdot
.31864 .47109 Mdot
.31957 .47158 Mdot
.3205 .47208 Mdot
.32143 .47257 Mdot
.32236 .47306 Mdot
.32329 .47355 Mdot
.32422 .47404 Mdot
.32515 .47453 Mdot
.32608 .47502 Mdot
.32701 .47551 Mdot
.32794 .476 Mdot
.32887 .47649 Mdot
.3298 .47698 Mdot
.33073 .47747 Mdot
.33166 .47796 Mdot
.33259 .47845 Mdot
.33352 .47894 Mdot
.33445 .47943 Mdot
.33538 .47992 Mdot
.33631 .48041 Mdot
.33724 .48089 Mdot
.33817 .48138 Mdot
.3391 .48187 Mdot
.34003 .48236 Mdot
.34096 .48284 Mdot
.34189 .48333 Mdot
.34282 .48382 Mdot
.34375 .4843 Mdot
.34468 .48479 Mdot
.34561 .48527 Mdot
.34654 .48576 Mdot
.34747 .48624 Mdot
.3484 .48673 Mdot
.34933 .48721 Mdot
.35026 .4877 Mdot
.35119 .48818 Mdot
.35212 .48866 Mdot
.35305 .48915 Mdot
.35398 .48963 Mdot
.35491 .49011 Mdot
.35584 .4906 Mdot
.35677 .49108 Mdot
.3577 .49156 Mdot
.35863 .49204 Mdot
.35956 .49252 Mdot
.36049 .493 Mdot
.36142 .49348 Mdot
.36235 .49396 Mdot
.36328 .49444 Mdot
.36421 .49492 Mdot
.36514 .4954 Mdot
.36607 .49588 Mdot
.367 .49636 Mdot
.36793 .49684 Mdot
.36886 .49732 Mdot
.36979 .4978 Mdot
.37072 .49827 Mdot
.37165 .49875 Mdot
.37258 .49923 Mdot
.37351 .49971 Mdot
.37444 .50018 Mdot
.37537 .50066 Mdot
.3763 .50113 Mdot
.37723 .50161 Mdot
.37816 .50208 Mdot
.37909 .50256 Mdot
.38002 .50303 Mdot
.38095 .50351 Mdot
.38188 .50398 Mdot
.38281 .50446 Mdot
.38374 .50493 Mdot
.38467 .5054 Mdot
.3856 .50587 Mdot
.38653 .50635 Mdot
.38746 .50682 Mdot
.38839 .50729 Mdot
.38932 .50776 Mdot
.39025 .50823 Mdot
.39118 .5087 Mdot
.39211 .50917 Mdot
.39304 .50964 Mdot
.39397 .51011 Mdot
.3949 .51058 Mdot
.39583 .51105 Mdot
.39676 .51151 Mdot
.39769 .51198 Mdot
.39862 .51245 Mdot
.39955 .51292 Mdot
.40048 .51338 Mdot
.40141 .51385 Mdot
.40234 .51431 Mdot
.40327 .51478 Mdot
.4042 .51524 Mdot
.40513 .51571 Mdot
.40606 .51617 Mdot
.40699 .51664 Mdot
.40792 .5171 Mdot
.40885 .51756 Mdot
.40978 .51803 Mdot
.41071 .51849 Mdot
.41164 .51895 Mdot
.41257 .51941 Mdot
.4135 .51987 Mdot
.41443 .52033 Mdot
.41536 .52079 Mdot
.41629 .52125 Mdot
.41722 .52171 Mdot
.41815 .52217 Mdot
.41908 .52263 Mdot
.42001 .52309 Mdot
.42094 .52354 Mdot
.42188 .524 Mdot
.42281 .52446 Mdot
.42374 .52491 Mdot
.42467 .52537 Mdot
.4256 .52582 Mdot
.42653 .52628 Mdot
.42746 .52673 Mdot
.42839 .52718 Mdot
.42932 .52764 Mdot
.43025 .52809 Mdot
.43118 .52854 Mdot
.43211 .52899 Mdot
.43304 .52945 Mdot
.43397 .5299 Mdot
.4349 .53035 Mdot
.43583 .5308 Mdot
.43676 .53125 Mdot
.43769 .53169 Mdot
.43862 .53214 Mdot
.43955 .53259 Mdot
.44048 .53304 Mdot
.44141 .53348 Mdot
.44234 .53393 Mdot
.44327 .53438 Mdot
.4442 .53482 Mdot
.44513 .53526 Mdot
.44606 .53571 Mdot
.44699 .53615 Mdot
.44792 .53659 Mdot
.44885 .53704 Mdot
.44978 .53748 Mdot
.45071 .53792 Mdot
.45164 .53836 Mdot
.45257 .5388 Mdot
.4535 .53924 Mdot
.45443 .53968 Mdot
.45536 .54012 Mdot
.45629 .54055 Mdot
.45722 .54099 Mdot
.45815 .54143 Mdot
.45908 .54186 Mdot
.46001 .5423 Mdot
.46094 .54273 Mdot
.46187 .54317 Mdot
.4628 .5436 Mdot
.46373 .54403 Mdot
.46466 .54447 Mdot
.46559 .5449 Mdot
.46652 .54533 Mdot
.46745 .54576 Mdot
.46838 .54619 Mdot
.46931 .54662 Mdot
.47024 .54704 Mdot
.47117 .54747 Mdot
.4721 .5479 Mdot
.47303 .54832 Mdot
.47396 .54875 Mdot
.47489 .54917 Mdot
.47582 .5496 Mdot
.47675 .55002 Mdot
.47768 .55044 Mdot
.47861 .55086 Mdot
.47954 .55129 Mdot
.48047 .5517 Mdot
.4814 .55212 Mdot
.48233 .55254 Mdot
.48326 .55295 Mdot
.48419 .55336 Mdot
.48512 .55377 Mdot
.48605 .55416 Mdot
.48698 .55453 Mdot
.48791 .55487 Mdot
.48884 .55515 Mdot
.48977 .55533 Mdot
.4907 .55533 Mdot
.49163 .55501 Mdot
.49256 .55414 Mdot
.49349 .5523 Mdot
.49442 .54879 Mdot
.49535 .5424 Mdot
.49628 .53123 Mdot
.49721 .51246 Mdot
.49814 .48247 Mdot
.49907 .43799 Mdot
.5 .3785 Mdot
.50093 .30902 Mdot
.50186 .23953 Mdot
.50279 .18004 Mdot
.50372 .13556 Mdot
.50465 .10557 Mdot
.50558 .0868 Mdot
.50651 .07563 Mdot
.50744 .06925 Mdot
.50837 .06573 Mdot
.5093 .06389 Mdot
.51023 .06302 Mdot
.51116 .0627 Mdot
.51209 .0627 Mdot
.51302 .06288 Mdot
.51395 .06316 Mdot
.51488 .0635 Mdot
.51581 .06388 Mdot
.51674 .06427 Mdot
.51767 .06467 Mdot
.5186 .06508 Mdot
.51953 .06549 Mdot
.52046 .06591 Mdot
.52139 .06633 Mdot
.52232 .06675 Mdot
.52325 .06717 Mdot
.52418 .06759 Mdot
.52511 .06801 Mdot
.52604 .06843 Mdot
.52697 .06886 Mdot
.5279 .06928 Mdot
.52883 .06971 Mdot
.52976 .07013 Mdot
.53069 .07056 Mdot
.53162 .07099 Mdot
.53255 .07142 Mdot
.53348 .07185 Mdot
.53441 .07227 Mdot
.53534 .07271 Mdot
.53627 .07314 Mdot
.5372 .07357 Mdot
.53813 .074 Mdot
.53906 .07443 Mdot
.53999 .07487 Mdot
.54092 .0753 Mdot
.54185 .07573 Mdot
.54278 .07617 Mdot
.54371 .0766 Mdot
.54464 .07704 Mdot
.54557 .07748 Mdot
.5465 .07792 Mdot
.54743 .07835 Mdot
.54836 .07879 Mdot
.54929 .07923 Mdot
.55022 .07967 Mdot
.55115 .08011 Mdot
.55208 .08055 Mdot
.55301 .081 Mdot
.55394 .08144 Mdot
.55487 .08188 Mdot
.5558 .08232 Mdot
.55673 .08277 Mdot
.55766 .08321 Mdot
.55859 .08366 Mdot
.55952 .0841 Mdot
.56045 .08455 Mdot
.56138 .085 Mdot
.56231 .08544 Mdot
.56324 .08589 Mdot
.56417 .08634 Mdot
.5651 .08679 Mdot
.56603 .08724 Mdot
.56696 .08769 Mdot
.56789 .08814 Mdot
.56882 .08859 Mdot
.56975 .08904 Mdot
.57068 .08949 Mdot
.57161 .08994 Mdot
.57254 .09039 Mdot
.57347 .09085 Mdot
.5744 .0913 Mdot
.57533 .09176 Mdot
.57626 .09221 Mdot
.57719 .09267 Mdot
.57813 .09312 Mdot
.57906 .09358 Mdot
.57999 .09403 Mdot
.58092 .09449 Mdot
.58185 .09495 Mdot
.58278 .09541 Mdot
.58371 .09586 Mdot
.58464 .09632 Mdot
.58557 .09678 Mdot
.5865 .09724 Mdot
.58743 .0977 Mdot
.58836 .09816 Mdot
.58929 .09862 Mdot
.59022 .09908 Mdot
.59115 .09954 Mdot
.59208 .10001 Mdot
.59301 .10047 Mdot
.59394 .10093 Mdot
.59487 .1014 Mdot
.5958 .10186 Mdot
.59673 .10232 Mdot
.59766 .10279 Mdot
.59859 .10325 Mdot
.59952 .10372 Mdot
.60045 .10418 Mdot
.60138 .10465 Mdot
.60231 .10512 Mdot
.60324 .10558 Mdot
.60417 .10605 Mdot
.6051 .10652 Mdot
.60603 .10699 Mdot
.60696 .10746 Mdot
.60789 .10792 Mdot
.60882 .10839 Mdot
.60975 .10886 Mdot
.61068 .10933 Mdot
.61161 .1098 Mdot
.61254 .11027 Mdot
.61347 .11074 Mdot
.6144 .11122 Mdot
.61533 .11169 Mdot
.61626 .11216 Mdot
.61719 .11263 Mdot
.61812 .1131 Mdot
.61905 .11358 Mdot
.61998 .11405 Mdot
.62091 .11452 Mdot
.62184 .115 Mdot
.62277 .11547 Mdot
.6237 .11595 Mdot
.62463 .11642 Mdot
.62556 .1169 Mdot
.62649 .11737 Mdot
.62742 .11785 Mdot
.62835 .11833 Mdot
.62928 .1188 Mdot
.63021 .11928 Mdot
.63114 .11976 Mdot
.63207 .12024 Mdot
.633 .12071 Mdot
.63393 .12119 Mdot
.63486 .12167 Mdot
.63579 .12215 Mdot
.63672 .12263 Mdot
.63765 .12311 Mdot
.63858 .12359 Mdot
.63951 .12407 Mdot
.64044 .12455 Mdot
.64137 .12503 Mdot
.6423 .12551 Mdot
.64323 .12599 Mdot
.64416 .12647 Mdot
.64509 .12696 Mdot
.64602 .12744 Mdot
.64695 .12792 Mdot
.64788 .1284 Mdot
.64881 .12889 Mdot
.64974 .12937 Mdot
.65067 .12985 Mdot
.6516 .13034 Mdot
.65253 .13082 Mdot
.65346 .1313 Mdot
.65439 .13179 Mdot
.65532 .13227 Mdot
.65625 .13276 Mdot
.65718 .13325 Mdot
.65811 .13373 Mdot
.65904 .13422 Mdot
.65997 .1347 Mdot
.6609 .13519 Mdot
.66183 .13568 Mdot
.66276 .13616 Mdot
.66369 .13665 Mdot
.66462 .13714 Mdot
.66555 .13763 Mdot
.66648 .13811 Mdot
.66741 .1386 Mdot
.66834 .13909 Mdot
.66927 .13958 Mdot
.6702 .14007 Mdot
.67113 .14056 Mdot
.67206 .14105 Mdot
.67299 .14154 Mdot
.67392 .14203 Mdot
.67485 .14252 Mdot
.67578 .14301 Mdot
.67671 .1435 Mdot
.67764 .14399 Mdot
.67857 .14448 Mdot
.6795 .14497 Mdot
.68043 .14547 Mdot
.68136 .14596 Mdot
.68229 .14645 Mdot
.68322 .14694 Mdot
.68415 .14743 Mdot
.68508 .14793 Mdot
.68601 .14842 Mdot
.68694 .14891 Mdot
.68787 .14941 Mdot
.6888 .1499 Mdot
.68973 .15039 Mdot
.69066 .15089 Mdot
.69159 .15138 Mdot
.69252 .15188 Mdot
.69345 .15237 Mdot
.69438 .15287 Mdot
.69531 .15336 Mdot
.69624 .15386 Mdot
.69717 .15435 Mdot
.6981 .15485 Mdot
.69903 .15535 Mdot
.69996 .15584 Mdot
.70089 .15634 Mdot
.70182 .15684 Mdot
.70275 .15733 Mdot
.70368 .15783 Mdot
.70461 .15833 Mdot
.70554 .15882 Mdot
.70647 .15932 Mdot
.7074 .15982 Mdot
.70833 .16032 Mdot
.70926 .16082 Mdot
.71019 .16131 Mdot
.71112 .16181 Mdot
.71205 .16231 Mdot
.71298 .16281 Mdot
.71391 .16331 Mdot
.71484 .16381 Mdot
.71577 .16431 Mdot
.7167 .16481 Mdot
.71763 .16531 Mdot
.71856 .16581 Mdot
.71949 .16631 Mdot
.72042 .16681 Mdot
.72135 .16731 Mdot
.72228 .16781 Mdot
.72321 .16831 Mdot
.72414 .16881 Mdot
.72507 .16931 Mdot
.726 .16982 Mdot
.72693 .17032 Mdot
.72786 .17082 Mdot
.72879 .17132 Mdot
.72972 .17182 Mdot
.73065 .17233 Mdot
.73158 .17283 Mdot
.73251 .17333 Mdot
.73344 .17383 Mdot
.73438 .17434 Mdot
.73531 .17484 Mdot
.73624 .17534 Mdot
.73717 .17585 Mdot
.7381 .17635 Mdot
.73903 .17685 Mdot
.73996 .17736 Mdot
.74089 .17786 Mdot
.74182 .17837 Mdot
.74275 .17887 Mdot
.74368 .17938 Mdot
.74461 .17988 Mdot
.74554 .18039 Mdot
.74647 .18089 Mdot
.7474 .1814 Mdot
.74833 .1819 Mdot
.74926 .18241 Mdot
.75019 .18291 Mdot
.75112 .18342 Mdot
.75205 .18392 Mdot
.75298 .18443 Mdot
.75391 .18494 Mdot
.75484 .18544 Mdot
.75577 .18595 Mdot
.7567 .18646 Mdot
.75763 .18696 Mdot
.75856 .18747 Mdot
.75949 .18798 Mdot
.76042 .18849 Mdot
.76135 .18899 Mdot
.76228 .1895 Mdot
.76321 .19001 Mdot
.76414 .19052 Mdot
.76507 .19102 Mdot
.766 .19153 Mdot
.76693 .19204 Mdot
.76786 .19255 Mdot
.76879 .19306 Mdot
.76972 .19357 Mdot
.77065 .19407 Mdot
.77158 .19458 Mdot
.77251 .19509 Mdot
.77344 .1956 Mdot
.77437 .19611 Mdot
.7753 .19662 Mdot
.77623 .19713 Mdot
.77716 .19764 Mdot
.77809 .19815 Mdot
.77902 .19866 Mdot
.77995 .19917 Mdot
.78088 .19968 Mdot
.78181 .20019 Mdot
.78274 .2007 Mdot
.78367 .20121 Mdot
.7846 .20172 Mdot
.78553 .20223 Mdot
.78646 .20274 Mdot
.78739 .20325 Mdot
.78832 .20376 Mdot
.78925 .20428 Mdot
.79018 .20479 Mdot
.79111 .2053 Mdot
.79204 .20581 Mdot
.79297 .20632 Mdot
.7939 .20683 Mdot
.79483 .20734 Mdot
.79576 .20786 Mdot
.79669 .20837 Mdot
.79762 .20888 Mdot
.79855 .20939 Mdot
.79948 .20991 Mdot
.80041 .21042 Mdot
.80134 .21093 Mdot
.80227 .21144 Mdot
.8032 .21196 Mdot
.80413 .21247 Mdot
.80506 .21298 Mdot
.80599 .2135 Mdot
.80692 .21401 Mdot
.80785 .21452 Mdot
.80878 .21504 Mdot
.80971 .21555 Mdot
.81064 .21606 Mdot
.81157 .21658 Mdot
.8125 .21709 Mdot
.81343 .2176 Mdot
.81436 .21812 Mdot
.81529 .21863 Mdot
.81622 .21915 Mdot
.81715 .21966 Mdot
.81808 .22018 Mdot
.81901 .22069 Mdot
.81994 .2212 Mdot
.82087 .22172 Mdot
.8218 .22223 Mdot
.82273 .22275 Mdot
.82366 .22326 Mdot
.82459 .22378 Mdot
.82552 .22429 Mdot
.82645 .22481 Mdot
.82738 .22532 Mdot
.82831 .22584 Mdot
.82924 .22636 Mdot
.83017 .22687 Mdot
.8311 .22739 Mdot
.83203 .2279 Mdot
.83296 .22842 Mdot
.83389 .22893 Mdot
.83482 .22945 Mdot
.83575 .22997 Mdot
.83668 .23048 Mdot
.83761 .231 Mdot
.83854 .23151 Mdot
.83947 .23203 Mdot
.8404 .23255 Mdot
.84133 .23306 Mdot
.84226 .23358 Mdot
.84319 .2341 Mdot
.84412 .23461 Mdot
.84505 .23513 Mdot
.84598 .23565 Mdot
.84691 .23616 Mdot
.84784 .23668 Mdot
.84877 .2372 Mdot
.8497 .23772 Mdot
.85063 .23823 Mdot
.85156 .23875 Mdot
.85249 .23927 Mdot
.85342 .23979 Mdot
.85435 .2403 Mdot
.85528 .24082 Mdot
.85621 .24134 Mdot
.85714 .24186 Mdot
.85807 .24237 Mdot
.859 .24289 Mdot
.85993 .24341 Mdot
.86086 .24393 Mdot
.86179 .24445 Mdot
.86272 .24496 Mdot
.86365 .24548 Mdot
.86458 .246 Mdot
.86551 .24652 Mdot
.86644 .24704 Mdot
.86737 .24756 Mdot
.8683 .24807 Mdot
.86923 .24859 Mdot
.87016 .24911 Mdot
.87109 .24963 Mdot
.87202 .25015 Mdot
.87295 .25067 Mdot
.87388 .25119 Mdot
.87481 .25171 Mdot
.87574 .25223 Mdot
.87667 .25274 Mdot
.8776 .25326 Mdot
.87853 .25378 Mdot
.87946 .2543 Mdot
.88039 .25482 Mdot
.88132 .25534 Mdot
.88225 .25586 Mdot
.88318 .25638 Mdot
.88411 .2569 Mdot
.88504 .25742 Mdot
.88597 .25794 Mdot
.8869 .25846 Mdot
.88783 .25898 Mdot
.88876 .2595 Mdot
.88969 .26002 Mdot
.89063 .26054 Mdot
.89156 .26106 Mdot
.89249 .26158 Mdot
.89342 .2621 Mdot
.89435 .26262 Mdot
.89528 .26314 Mdot
.89621 .26366 Mdot
.89714 .26418 Mdot
.89807 .2647 Mdot
.899 .26522 Mdot
.89993 .26574 Mdot
.90086 .26626 Mdot
.90179 .26678 Mdot
.90272 .2673 Mdot
.90365 .26782 Mdot
.90458 .26834 Mdot
.90551 .26886 Mdot
.90644 .26938 Mdot
.90737 .2699 Mdot
.9083 .27042 Mdot
.90923 .27094 Mdot
.91016 .27146 Mdot
.91109 .27198 Mdot
.91202 .2725 Mdot
.91295 .27303 Mdot
.91388 .27355 Mdot
.91481 .27407 Mdot
.91574 .27459 Mdot
.91667 .27511 Mdot
.9176 .27563 Mdot
.91853 .27615 Mdot
.91946 .27667 Mdot
.92039 .27719 Mdot
.92132 .27771 Mdot
.92225 .27823 Mdot
.92318 .27876 Mdot
.92411 .27928 Mdot
.92504 .2798 Mdot
.92597 .28032 Mdot
.9269 .28084 Mdot
.92783 .28136 Mdot
.92876 .28188 Mdot
.92969 .28241 Mdot
.93062 .28293 Mdot
.93155 .28345 Mdot
.93248 .28397 Mdot
.93341 .28449 Mdot
.93434 .28501 Mdot
.93527 .28553 Mdot
.9362 .28606 Mdot
.93713 .28658 Mdot
.93806 .2871 Mdot
.93899 .28762 Mdot
.93992 .28814 Mdot
.94085 .28866 Mdot
.94178 .28918 Mdot
.94271 .28971 Mdot
.94364 .29023 Mdot
.94457 .29075 Mdot
.9455 .29127 Mdot
.94643 .29179 Mdot
.94736 .29231 Mdot
.94829 .29284 Mdot
.94922 .29336 Mdot
.95015 .29388 Mdot
.95108 .2944 Mdot
.95201 .29492 Mdot
.95294 .29545 Mdot
.95387 .29597 Mdot
.9548 .29649 Mdot
.95573 .29701 Mdot
.95666 .29753 Mdot
.95759 .29806 Mdot
.95852 .29858 Mdot
.95945 .2991 Mdot
.96038 .29962 Mdot
.96131 .30014 Mdot
.96224 .30066 Mdot
.96317 .30119 Mdot
.9641 .30171 Mdot
.96503 .30223 Mdot
.96596 .30275 Mdot
.96689 .30327 Mdot
.96782 .3038 Mdot
.96875 .30432 Mdot
.96968 .30484 Mdot
.97061 .30536 Mdot
.97154 .30588 Mdot
.97247 .30641 Mdot
.9734 .30693 Mdot
.97433 .30745 Mdot
.97526 .30797 Mdot
.97619 .30849 Mdot
.3 g
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45911 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00Oogoo;Goo003oOol]
Ool001]oo`03001oogoo0?moo`moo`006goo00<007ooOol0ogoo3goo000COol30005Ool00`00Oomo
o`3oOol?Ool001Aoo`03001oogoo00Aoo`03001oogoo0?moo`moo`003Goo1@000Woo00<007ooOol0
17oo0P00]goo2BDYCgoo000DOol00`00Oomoo`04Ool00`00Oomoo`2bOol49BT9Ool59BU:Ool001Ao
o`03001oogoo00Aoo`03001oogoo0;5oo`039BUoogoo011oo`039BUoogoo04Moo`004goo0P001Woo
00<007ooOol0[goo0RDY57oo0bDYAWoo000KOol00`00Oomoo`2]Ool29BTIOol00bDYOomoo`13Ool0
01]oo`03001oogoo0:aoo`039BUoogoo01Yoo`039BUoogoo049oo`006goo00<007ooOol0ZWoo0RDY
7Woo0RDY@Woo000KOol00`00Oomoo`2YOol00bDYOomoo`0POol00bDYOomoo`0oOol001]oo`800:Qo
o`8U:BAoo`039BUoogoo03ioo`006goo00<007ooOol0YWoo00<U:GooOol09Goo00<U:GooOol0?Goo
000KOol00`00Oomoo`2UOol00bDYOomoo`0WOol00bDYOomoo`0lOol001]oo`03001oogoo0:Eoo`03
9BUoogoo02Moo`039BUoogoo03aoo`006goo00<007ooOol0OGoo10008goo00<U:GooOol0:Goo00<U
:GooOol0>goo000KOol00`00Oomoo`1mOol6000POol00bDYOomoo`0[Ool00bDYOomoo`0jOol001]o
o`03001oogoo07eoo`P001eoo`039BUoogoo02eoo`039BUoogoo03Uoo`006goo00<007ooOol0OGoo
0P000Woo1P006goo00<U:GooOol0;Woo00<U:GooOol0>7oo000KOol2001mOol20005Ool6000HOol0
0bDYOomoo`0`Ool00bDYOomoo`0gOol001]oo`03001oogoo07aoo`8000Moo`H001Eoo`039BUoogoo
035oo`039BUoogoo03Moo`006goo00<007ooOol0R7oo1@004goo00<U:GooOol0<Woo00<U:GooOol0
=Woo000KOol00`00Oomoo`1lOol2000<Ool5000@Ool00bDYOomoo`0dOol00bDYOomoo`0eOol001]o
o`03001oogoo07aoo`8000ioo`H000aoo`039BUoogoo03Ioo`039BUoogoo03Aoo`006goo00<007oo
Ool0SWoo1P002Goo00<U:GooOol0>7oo00<U:GooOol0<goo000KOol00`00Oomoo`2@Ool60006Ool0
0bDYOomoo`0jOol00bDYOomoo`0bOol001]oo`8009=oo`H000=oo`039BUoogoo03]oo`039BUoogoo
039oo`006goo00<007ooOol0O7oo0P005Woo1P0000=oobDYOol0?Goo00<U:GooOol0<Goo000KOol0
0`00Oomoo`1lOol2000HOol400000bDY001oo`0nOol00bDYOomoo`0`Ool001]oo`03001oogoo09Qo
o`03000U:@0000<003eoo`039BUoogoo031oo`006goo00<007ooOol0VGoo00<U:@0000000`00?Goo
00<U:GooOol0;goo000KOol00`00Oomoo`2HOol012DYOomoogoo1@00?7oo00<U:GooOol0;Woo000K
Ool00`00Oomoo`2GOol00bDYOomoo`04Ool5000jOol00bDYOomoo`0^Ool001]oo`03001oogoo09Mo
o`039BUoogoo00Ioo`D003Uoo`039BUoogoo02eoo`006goo0P00Ugoo00<U:GooOol02Goo1@00>7oo
00<U:GooOol0;7oo000KOol00`00Oomoo`1lOol2000GOol00bDYOomoo`0<Ool5000fOol00bDYOomo
o`0/Ool001]oo`03001oogoo07aoo`8001Ioo`039BUoogoo00ioo`H003Eoo`039BUoogoo02]oo`00
6goo00<007ooOol0U7oo00<U:GooOol047oo1P00<goo00<U:GooOol0:goo000KOol00`00Oomoo`2C
Ool00bDYOomoo`0COol6000bOol00bDYOomoo`0ZOol001]oo`03001oogoo099oo`039BUoogoo01Io
o`H0035oo`039BUoogoo02Uoo`0027oo0P0017oo0P000goo0`001Goo00<007ooOol0TWoo00<U:Goo
Ool067oo1@00<7oo00<U:GooOol0:Goo0007Ool01000Oomoo`000goo0P001Woo00<007ooOol00Woo
00<007ooOol0TGoo00<U:GooOol06goo1@00;goo00<U:GooOol0:7oo00000goo0000000300001Goo
001oogoo00002goo00<007ooOol00Woo0P00TGoo00<U:GooOol07Woo1@00;Woo00<U:GooOol09goo
0007Ool01000Oomoo`0027oo0`001Goo00<007ooOol0T7oo00<U:GooOol087oo1@00;7oo00<U:Goo
Ool09goo0007Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0Sgoo00<U:GooOol08Woo
1P00:goo00<U:GooOol09Woo0008Ool20009Ool40004Ool00`00Oomoo`2?Ool00bDYOomoo`0TOol6
000YOol00bDYOomoo`0VOol001]oo`03001oogoo07]oo`80015oo`039BUoogoo02Moo`H002Qoo`03
9BUoogoo02Eoo`006goo00<007ooOol0Ngoo0P004Goo00<U:GooOol0:Goo1P009goo00<U:GooOol0
97oo000KOol00`00Oomoo`2=Ool00bDYOomoo`0/Ool5000VOol00bDYOomoo`0TOol001]oo`03001o
ogoo08eoo`039BUoogoo02ioo`D002Eoo`039BUoogoo02=oo`006goo0P00SGoo00<U:GooOol0<Goo
1@008goo00<U:GooOol08goo000KOol00`00Oomoo`2<Ool00bDYOomoo`0cOol5000ROol00bDYOomo
o`0ROol001]oo`03001oogoo08]oo`039BUoogoo03Eoo`H0025oo`039BUoogoo025oo`006goo00<0
07ooOol0RWoo00<U:GooOol0>7oo1@0087oo00<U:GooOol08Goo000KOol00`00Oomoo`2:Ool00bDY
Oomoo`0jOol5000OOol00bDYOomoo`0POol001]oo`03001oogoo08Uoo`039BUoogoo03eoo`D001eo
o`039BUoogoo021oo`006goo00<007ooOol0RGoo00<U:GooOol0?goo1@0077oo00<U:GooOol07goo
000KOol00`00Oomoo`28Ool00bDYOomoo`11Ool6000JOol00bDYOomoo`0OOol001]oo`8008Uoo`03
9BUoogoo04=oo`H001Uoo`039BUoogoo01ioo`006goo00<007ooOol0Qgoo00<U:GooOol0AWoo1@00
6Goo00<U:GooOol07Goo000KOol00`00Oomoo`27Ool00bDYOomoo`18Ool5000GOol00bDYOomoo`0M
Ool001]oo`03001oogoo08Ioo`039BUoogoo04]oo`D001Ioo`039BUoogoo01aoo`006goo00<007oo
Ool0Ngoo0P002Goo00<U:GooOol0CGoo1@0057oo00<U:GooOol077oo000KOol00`00Oomoo`1kOol2
0008Ool00bDYOomoo`1?Ool5000DOol00bDYOomoo`0KOol001]oo`03001oogoo08Eoo`039BUoogoo
055oo`D0019oo`039BUoogoo01]oo`006goo00<007ooOol0Q7oo00<U:GooOol0E7oo1@004Goo00<U
:GooOol06Woo000KOol20025Ool00bDYOomoo`1FOol5000?Ool00bDYOomoo`0JOol001]oo`03001o
ogoo08=oo`039BUoogoo05Qoo`H000ioo`039BUoogoo01Uoo`006goo00<007ooOol0Pgoo00<U:Goo
Ool0FWoo1P0037oo00<U:GooOol06Goo000KOol00`00Oomoo`22Ool00bDYOomoo`1MOol5000<Ool0
0bDYOomoo`0HOol001]oo`03001oogoo089oo`039BUoogoo05moo`D000Yoo`039BUoogoo01Qoo`00
6goo00<007ooOol09Woo10000goo0P0017oo0P0097oo0`000goo0P0017oo0P006Woo00<U:GooOol0
1Woo0P0017oo0P0017oo0P008goo0P0017oo0P0017oo0P007Goo1P0017oo0P000Woo00@U:Goo0000
00Aoo`80011oo`006goo00<007ooOol09goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
000TOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo01Ioo`039BUoogoo00Ioo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0025oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol001eoo`H0009oo`04001oogoo0002Ool012DYOomoo`000Woo00@007ooOol000mo
o`006goo0P00:Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0POol40002Ool0
1000Oomoo`000Woo00@007ooOol001Qoo`039BUoogoo00Ioo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol0025oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol001moo`D00005
Ool007ooOol00002Ool012DYOomoo`000Woo00@007ooOol000moo`006goo00<007ooOol0:Goo00@0
07ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0POol00`00Ool00003Ool01000Oomoo`000Woo
00@007ooOol001Moo`039BUoogoo00Moo`<000=oo`04001oogoo0002Ool01000Oomoo`008Woo0P00
0goo00@007ooOol0009oo`04001oogoo000POol60002Ool01`00Oomoo`009BUoo`00009oo`04001o
ogoo000?Ool001]oo`03001oogoo02Ioo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
029oo`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`005goo00<U:GooOol01goo00<007oo
Ool00goo00@007ooOol0009oo`04001oogoo000QOol01000Oomoo`000Woo00@007ooOol0009oo`04
001oogoo000POol00`00Oomoo`060002Ool010009BUoo`000Woo00@007ooOol000moo`006goo00<0
07ooOol09goo0P0017oo0P0017oo0P0097oo0P0017oo0P0017oo0P005goo00<U:GooOol02Goo0`00
0goo0P0017oo0P008goo0P0017oo0P0017oo0P0087oo0P000goo1P000Woo00<002DYOol00goo0P00
47oo000KOol00`00Oomoo`1nOol00bDYOomoo`1_Ool600000goo9BUoo`0EOol001]oo`03001oogoo
07eoo`039BUoogoo079oo`D00003OolU:Goo01Aoo`006goo00<007ooOol0OGoo00<U:GooOol0M7oo
100000<U:GooOol037oo0P0000=oo`0000000Woo000KOol00`00Oomoo`1lOol00bDYOomoo`1gOol3
00000bDY001oo`0<Ool00`00Ool00003Ool001Eoo`H000039BT0000007`000039BT0000007/00003
9BT0000000@000Qoo`03001oogoo009oo`006goo00<U:@0000000P001goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00D007ooOolU:@0000Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo015oo`03001oo`0000=o
o`006goo00<002DY00001000:Woo00<007ooOol0;goo00<007ooOol067oo00<U:GooOol04goo00<0
07ooOol0;Woo00<007ooOol0;goo00<007ooOol047oo0P0000=oo`0000000Woo000KOol00`009BUo
o`05001eOol00bDYOomoo`2AOol001]oo`03001oobDY009oo`D007=oo`039BUoogoo095oo`006goo
00<007oo9BT00goo1P00L7oo00<U:GooOol0TWoo000KOol01000OomoobDY17oo1P00KWoo00<U:Goo
Ool0TWoo000KOol01000OomoobDY1Woo1@00K7oo00<U:GooOol0Tgoo000KOol20002Ool00bDYOomo
o`05Ool5001YOol00bDYOomoo`2DOol001]oo`05001oogooOolU:@09Ool5001WOol00bDYOomoo`2D
Ool001]oo`03001oogoo009oo`039BUoogoo00Qoo`D006Aoo`039BUoogoo09Eoo`006goo00<007oo
Ool00Woo00<U:GooOol02Goo1P00HWoo00<U:GooOol0UGoo000KOol00`00Oomoo`03Ool00bDYOomo
o`0:Ool5001POol00bDYOomoo`2FOol001]oo`03001oogoo00=oo`039BUoogoo00aoo`D005ioo`03
9BUoogoo09Ioo`006goo00<007ooOol017oo00<U:GooOol03Goo1@00Fgoo00<U:GooOol0Ugoo000K
Ool00`00Oomoo`04Ool00bDYOomoo`0>Ool6001IOol00bDYOomoo`2GOol001]oo`8000Ioo`039BUo
ogoo00moo`H005Ioo`039BUoogoo09Qoo`006goo00<007ooOol01Goo00<U:GooOol04Goo1@00E7oo
00<U:GooOol0VGoo000KOol00`00Oomoo`06Ool00bDYOomoo`0BOol5001BOol00bDYOomoo`06Ool2
002AOol001]oo`03001oogoo00Ioo`039BUoogoo01Aoo`D004moo`039BUoogoo00Moo`80095oo`00
6goo00<007ooOol01goo00<U:GooOol057oo1P00CGoo00<U:GooOol0VWoo000KOol00`00Oomoo`07
Ool00bDYOomoo`0FOol6001:Ool00bDYOomoo`2KOol001]oo`03001oogoo00Qoo`039BUoogoo01Mo
o`D004Uoo`039BUoogoo09]oo`006goo00<007ooOol027oo00<U:GooOol06Goo1@00AWoo00<U:Goo
Ool0W7oo000KOol2000:Ool00bDYOomoo`0JOol50014Ool00bDYOomoo`2LOol001]oo`03001oogoo
00Uoo`039BUoogoo01aoo`D0045oo`039BUoogoo09eoo`006goo00<007ooOol02Woo00<U:GooOol0
77oo1P00?goo00<U:GooOol0WGoo000KOol00`00Oomoo`0;Ool00bDYOomoo`0MOol5000mOol00bDY
Oomoo`2NOol001]oo`03001oogoo00]oo`039BUoogoo01moo`D003]oo`039BUoogoo09ioo`006goo
00<007ooOol037oo00<U:GooOol087oo1@00>7oo00<U:GooOol0Wgoo000KOol00`00Oomoo`0<Ool0
0bDYOomoo`0QOol6000fOol00bDYOomoo`2OOol001]oo`8000ioo`039BUoogoo029oo`H003=oo`03
9BUoogoo0:1oo`006goo00<007ooOol03Goo00<U:GooOol097oo1P00<7oo00<U:GooOol0XGoo000K
Ool00`00Oomoo`0>Ool00bDYOomoo`0UOol5000_Ool00bDYOomoo`2QOol001]oo`03001oogoo00io
o`039BUoogoo02Moo`D002aoo`039BUoogoo00ioo`80099oo`006goo00<007ooOol03goo00<U:Goo
Ool0:7oo1@00:Woo00<U:GooOol03Woo0P00TWoo000KOol00`00Oomoo`0@Ool00bDYOomoo`0YOol5
000WOol00bDYOomoo`2SOol000Qoo`8000Aoo`8000=oo`<000Eoo`03001oogoo011oo`039BUoogoo
02Yoo`H002Eoo`039BUoogoo0:=oo`001goo00@007ooOol000=oo`8000Ioo`03001oogoo009oo`03
001oogoo015oo`039BUoogoo02]oo`H0029oo`039BUoogoo0:Aoo`001goo00@007ooOol000]oo`03
001oogoo009oo`80019oo`039BUoogoo02eoo`H0021oo`039BUoogoo0:Aoo`001goo00@007ooOol0
00Qoo`<000Eoo`03001oogoo019oo`039BUoogoo02ioo`D001ioo`039BUoogoo0:Eoo`001goo00@0
07ooOol000Qoo`03001oogoo00Eoo`03001oogoo019oo`039BUoogoo031oo`D001aoo`039BUoogoo
0:Eoo`0027oo0P002Goo100017oo00<007ooOol04goo00<U:GooOol0<Goo1@006Goo00<U:GooOol0
YWoo000KOol00`00Oomoo`0DOol00bDYOomoo`0bOol5000FOol00bDYOomoo`2WOol001]oo`03001o
ogoo01Aoo`039BUoogoo03=oo`H001Aoo`039BUoogoo0:Moo`006goo00<007ooOol05Goo00<U:Goo
Ool0=7oo1P004Goo00<U:GooOol0Z7oo000KOol00`00Oomoo`0FOol00bDYOomoo`0eOol6000>Ool0
0bDYOomoo`0EOol2002BOol001]oo`8001Moo`039BUoogoo03Moo`H000aoo`039BUoogoo01Eoo`80
099oo`006goo00<007ooOol05goo00<U:GooOol0>7oo1P002Goo00<U:GooOol0ZWoo000KOol00`00
Oomoo`0HOol00bDYOomoo`0iOol60006Ool00bDYOomoo`2[Ool001]oo`03001oogoo01Uoo`039BUo
ogoo03Yoo`H000=oo`039BUoogoo0:aoo`006goo00<007ooOol06Goo00<U:GooOol0?7oo1@000Woo
00<U:GooOol0[7oo000KOol00`00Oomoo`0JOol00bDYOomoo`0mOol400000bDYOomoo`2]Ool001]o
o`03001oogoo01]oo`039BUoogoo03ioo`03000U:@0000<00:aoo`006goo00<007ooOol06goo00<U
:GooOol0?goo00<U:@00000010005Woo0P00TWoo000KOol2000MOol00bDYOomoo`0mOol012DYOomo
ogoo1@005Goo0P00TWoo000KOol00`00Oomoo`0MOol00bDYOomoo`0kOol00bDYOomoo`04Ool5002W
Ool001]oo`03001oogoo01eoo`039BUoogoo03]oo`039BUoogoo00Ioo`D00:Eoo`006goo00<007oo
Ool07Woo00<U:GooOol0>Goo00<U:GooOol02Goo1P00XWoo000KOol00`00Oomoo`0OOol00bDYOomo
o`0gOol00bDYOomoo`0<Ool6000<Ool2002BOol001]oo`03001oogoo021oo`039BUoogoo03Eoo`03
9BUoogoo00moo`H000Yoo`80099oo`006goo00<007ooOol08Goo00<U:GooOol0<goo00<U:GooOol0
4Woo1P00W7oo000KOol00`00Oomoo`0ROol00bDYOomoo`0aOol00bDYOomoo`0EOol60005Ool2002C
Ool001]oo`8002=oo`039BUoogoo035oo`039BUoogoo01Moo`H000=oo`8009=oo`006goo00<007oo
Ool08goo00<U:GooOol0;goo00<U:GooOol06Woo1P0000=oo`000000Tgoo000KOol00`00Oomoo`0T
Ool00bDYOomoo`0]Ool00bDYOomoo`0NOol6002COol001]oo`03001oogoo02Eoo`039BUoogoo02]o
o`039BUoogoo025oo`@009=oo`006goo00<007ooOol09Woo00<U:GooOol0:Goo00<U:GooOol0^Goo
000KOol00`00Oomoo`0WOol29BTWOol29BVlOol001]oo`03001oogoo02Uoo`039BUoogoo02=oo`03
9BUoogoo0;aoo`006goo0P00:goo00<U:GooOol08Goo00<U:GooOol0_Goo000KOol00`00Oomoo`0[
Ool00bDYOomoo`0OOol00bDYOomoo`2nOol001]oo`03001oogoo02aoo`8U:Aeoo`8U:L5oo`006goo
00<007ooOol0;Woo00<U:GooOol067oo0RDY`goo000KOol00`00Oomoo`0_Ool29BTGOol00bDYOomo
o`33Ool001]oo`03001oogoo035oo`039BUoogoo019oo`8U:LIoo`004goo0`001Goo00<007ooOol0
<Woo0RDY4Goo00<U:GooOol0aWoo000DOol00`00Oomoo`04Ool00`00Oomoo`0dOol39BT:Ool49BW9
Ool001Aoo`03001oogoo00Aoo`8003Qoo`XU:Leoo`0057oo00<007ooOol017oo00<007ooOol0ogoo
3goo000DOol00`00Oomoo`04Ool00`00Oomoo`3oOol?Ool001=oo`8000Ioo`03001oogoo0?moo`mo
o`006goo00<007ooOol0ogoo3goo003oOol]Ool00?moobeoo`00ogoo;Goo001MOol00`00Oomoo`0D
Ool00`00Oomoo`2eOol005aoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo0;Aoo`00EGoo
1@000Woo00@007ooOomoo`800003Ool0000000=oo`03001oogoo00=oo`<000Aoo`03001oogoo00Mo
o`D0009oo`<000Uoo`<000Uoo`8000Uoo`D00004Ool00000Ool20002Ool50007Ool30009Ool30003
Ool20004Ool2001@Ool005Eoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00
Oomoo`02Ool01000Oomoo`000goo00<007ooOol01goo00@007ooOol000=oo`04001oogoo0008Ool0
1000Oomoo`001goo00@007ooOol000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00D007ooOomo
o`0000Qoo`04001oogoo0009Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo04eo
o`00EGoo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo00Aoo`03001o
ogoo00Moo`@000=oo`03001oogoo00Uoo`03001oogoo009oo`D00005Ool007ooOol00008Ool40002
Ool01000Oomoo`000Woo00D007ooOomoo`0000Qoo`03001oogoo009oo`D00003Ool000000080009o
o`04001oogoo0002Ool01000Oomoo`00Cgoo001EOol01000Oomoo`000goo00<007ooOol00Woo00<0
07oo00002Woo00<007ooOol017oo00<007ooOol02Woo00D007ooOomoo`0000]oo`03001oogoo00Qo
o`04001oogoo000;Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00Ioo`03001oogoo
00Qoo`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`00Cgoo001DOol200000goo00000003
Ool01000Oomoogoo0P0000=oo`00000027oo100017oo00<007ooOol027oo0`000Woo100027oo1000
0Woo1@0000Eoo`00Oomoo`0000Uoo`<00003Ool0000000<000=oo`@000Moo`@0009oo`D00004Ool0
07oo0003Ool01000Oomoo`000Woo00@007ooOol004moo`00GGoo00<007ooOol03Woo00<007ooOol0
0goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol02Goo0P006Goo00<007ooOol01Woo00<0
07ooOol02Goo0P0017oo0P0017oo0P00D7oo001^Ool00`00Oomoo`0EOol00`00Oomoo`09Ool00`00
Oomoo`0SOol20008Ool00`00Oomoo`1WOol00?moobeoo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-110.688, -1.07097, 4.05178, 
  0.0128045}},
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
Now we will analyze this signal using wavelets. First, we choose a \
wavelet basis and then decompose the data in the chosen basis. In this \
example, we use Daubechies wavelet of order 2. \
\>", "Text",
  CellTags->{"S2.1.1", "1.10"}],

Cell["This generates the second\[Hyphen]order Daubechies filter.", 
  "MathCaption",
  CellTags->{"S2.1.1", "1.11"}],

Cell["filter = DaubechiesFilter[2];", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
We transform the data into a set of coefficients in the wavelet \
basis. Note that the default periodic boundary condition is used.\
\>", 
  "MathCaption",
  CellTags->{"S2.1.1", "1.12"}],

Cell["wtdata = WaveletTransform[data, filter];", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.1"],

Cell[TextData[{
  "There are 10 sublists, each labeled by the index ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " containing the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(j  k\)}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_\(\(j\_0\) k\)}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.13"}],

Cell[CellGroupData[{

Cell["Length /@ wtdata", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \({2, 2, 4, 8, 16, 32, 64, 128, 256, 512}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "There are different ways of displaying the relative magnitudes of the \
wavelet coefficients. For example, the function ",
  StyleBox["PlotCoefficients", "MR"],
  " allows us to plot the wavelet coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(j  k\)}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_\(\(j\_0\) k\)}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " against ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " for fixed ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and to stack the plots together with the finest details (",
  StyleBox["i.e.", "TI"],
  ", largest ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ") at the top. Since the sublists have different lengths, the coefficients \
in a sublist of length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " are plotted against ",
  Cell[BoxData[
      \(TraditionalForm\`N  k/n\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the length of the longest sublist."
}], "Text",
  CellTags->{"S2.1.1", "1.14"}],

Cell["\<\
The 10 sublists are plotted and stacked together. The lowest plot \
is the residual trend; the topmost, the finest details. They are all plotted \
with the same vertical scale.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.15"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[wtdata, Frame -> True,
PlotRange -> All,
PlotLabel -> \"wavelet coefficients\"];\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 -0.0248983 0.00344778 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20982 -0.0125 -9 -9 ]
[.20982 -0.0125 9 0 ]
[.39583 -0.0125 -9 -9 ]
[.39583 -0.0125 9 0 ]
[.58185 -0.0125 -9 -9 ]
[.58185 -0.0125 9 0 ]
[.76786 -0.0125 -9 -9 ]
[.76786 -0.0125 9 0 ]
[.95387 -0.0125 -9 -9 ]
[.95387 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20982 0 m
.20982 .00625 L
s
[(100)] .20982 -0.0125 0 1 Mshowa
.39583 0 m
.39583 .00625 L
s
[(200)] .39583 -0.0125 0 1 Mshowa
.58185 0 m
.58185 .00625 L
s
[(300)] .58185 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(400)] .76786 -0.0125 0 1 Mshowa
.95387 0 m
.95387 .00625 L
s
[(500)] .95387 -0.0125 0 1 Mshowa
.125 Mabswid
.06101 0 m
.06101 .00375 L
s
.09821 0 m
.09821 .00375 L
s
.13542 0 m
.13542 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.24702 0 m
.24702 .00375 L
s
.28423 0 m
.28423 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35863 0 m
.35863 .00375 L
s
.43304 0 m
.43304 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.50744 0 m
.50744 .00375 L
s
.54464 0 m
.54464 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.69345 0 m
.69345 .00375 L
s
.73065 0 m
.73065 .00375 L
s
.80506 0 m
.80506 .00375 L
s
.84226 0 m
.84226 .00375 L
s
.87946 0 m
.87946 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.99107 0 m
.99107 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.20982 .61178 m
.20982 .61803 L
s
.39583 .61178 m
.39583 .61803 L
s
.58185 .61178 m
.58185 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.95387 .61178 m
.95387 .61803 L
s
.125 Mabswid
.06101 .61428 m
.06101 .61803 L
s
.09821 .61428 m
.09821 .61803 L
s
.13542 .61428 m
.13542 .61803 L
s
.17262 .61428 m
.17262 .61803 L
s
.24702 .61428 m
.24702 .61803 L
s
.28423 .61428 m
.28423 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.35863 .61428 m
.35863 .61803 L
s
.43304 .61428 m
.43304 .61803 L
s
.47024 .61428 m
.47024 .61803 L
s
.50744 .61428 m
.50744 .61803 L
s
.54464 .61428 m
.54464 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.65625 .61428 m
.65625 .61803 L
s
.69345 .61428 m
.69345 .61803 L
s
.73065 .61428 m
.73065 .61803 L
s
.80506 .61428 m
.80506 .61803 L
s
.84226 .61428 m
.84226 .61803 L
s
.87946 .61428 m
.87946 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.99107 .61428 m
.99107 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet coefficients)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .03791 m
.02381 .06111 L
s
.5 .03791 m
.5 .01472 L
s
.02381 .10072 m
.02381 .1094 L
s
.5 .10072 m
.5 .06932 L
s
.02381 .16353 m
.02381 .16357 L
s
.2619 .16353 m
.2619 .16949 L
s
.5 .16353 m
.5 .14177 L
s
.7381 .16353 m
.7381 .16335 L
s
.02381 .22635 m
.02381 .22635 L
s
.14286 .22635 m
.14286 .22637 L
s
.2619 .22635 m
.2619 .22639 L
s
.38095 .22635 m
.38095 .23038 L
s
.5 .22635 m
.5 .2112 L
s
.61905 .22635 m
.61905 .22625 L
s
.7381 .22635 m
.7381 .22631 L
s
.85714 .22635 m
.85714 .22633 L
s
.02381 .28916 m
.02381 .28916 L
s
.08333 .28916 m
.08333 .28916 L
s
.14286 .28916 m
.14286 .28916 L
s
.20238 .28916 m
.20238 .28916 L
s
.2619 .28916 m
.2619 .28916 L
s
.32143 .28916 m
.32143 .28917 L
s
.38095 .28916 m
.38095 .28917 L
s
.44048 .28916 m
.44048 .29199 L
s
.5 .28916 m
.5 .27872 L
s
.55952 .28916 m
.55952 .28908 L
s
.61905 .28916 m
.61905 .28914 L
s
.67857 .28916 m
.67857 .28915 L
s
.7381 .28916 m
.7381 .28915 L
s
.79762 .28916 m
.79762 .28915 L
s
.85714 .28916 m
.85714 .28915 L
s
.91667 .28916 m
.91667 .28916 L
s
.02381 .35197 m
.02381 .35197 L
s
.05357 .35197 m
.05357 .35197 L
s
.08333 .35197 m
.08333 .35197 L
s
.1131 .35197 m
.1131 .35197 L
s
.14286 .35197 m
.14286 .35197 L
s
.17262 .35197 m
.17262 .35197 L
s
.20238 .35197 m
.20238 .35197 L
s
.23214 .35197 m
.23214 .35197 L
s
.2619 .35197 m
.2619 .35197 L
s
.29167 .35197 m
.29167 .35197 L
s
.32143 .35197 m
.32143 .35197 L
s
.35119 .35197 m
.35119 .35197 L
s
.38095 .35197 m
.38095 .35197 L
s
.41071 .35197 m
.41071 .35197 L
s
.44048 .35197 m
.44048 .35197 L
s
.47024 .35197 m
.47024 .35411 L
s
.5 .35197 m
.5 .34513 L
s
.52976 .35197 m
.52976 .35185 L
s
.55952 .35197 m
.55952 .35196 L
s
.58929 .35197 m
.58929 .35196 L
s
.61905 .35197 m
.61905 .35197 L
s
.64881 .35197 m
.64881 .35197 L
s
.67857 .35197 m
.67857 .35197 L
s
.70833 .35197 m
.70833 .35197 L
s
.7381 .35197 m
.7381 .35197 L
s
.76786 .35197 m
.76786 .35197 L
s
.79762 .35197 m
.79762 .35197 L
s
.82738 .35197 m
.82738 .35197 L
s
.85714 .35197 m
.85714 .35197 L
s
.8869 .35197 m
.8869 .35197 L
s
.91667 .35197 m
.91667 .35197 L
s
.94643 .35197 m
.94643 .35197 L
s
.02381 .41478 m
.02381 .41478 L
s
.03869 .41478 m
.03869 .41478 L
s
.05357 .41478 m
.05357 .41478 L
s
.06845 .41478 m
.06845 .41478 L
s
.08333 .41478 m
.08333 .41478 L
s
.09821 .41478 m
.09821 .41478 L
s
.1131 .41478 m
.1131 .41478 L
s
.12798 .41478 m
.12798 .41478 L
s
.14286 .41478 m
.14286 .41478 L
s
.15774 .41478 m
.15774 .41478 L
s
.17262 .41478 m
.17262 .41478 L
s
.1875 .41478 m
.1875 .41478 L
s
.20238 .41478 m
.20238 .41478 L
s
.21726 .41478 m
.21726 .41478 L
s
.23214 .41478 m
.23214 .41478 L
s
.24702 .41478 m
.24702 .41478 L
s
.2619 .41478 m
.2619 .41478 L
s
.27679 .41478 m
.27679 .41478 L
s
.29167 .41478 m
.29167 .41478 L
s
.30655 .41478 m
.30655 .41478 L
s
.32143 .41478 m
.32143 .41478 L
s
.33631 .41478 m
.33631 .41478 L
s
.35119 .41478 m
.35119 .41478 L
s
.36607 .41478 m
.36607 .41478 L
s
.38095 .41478 m
.38095 .41478 L
s
.39583 .41478 m
.39583 .41478 L
s
.41071 .41478 m
.41071 .41478 L
s
.4256 .41478 m
.4256 .41478 L
s
.44048 .41478 m
.44048 .41478 L
s
.45536 .41478 m
.45536 .41478 L
s
.47024 .41478 m
.47024 .41478 L
s
.48512 .41478 m
.48512 .41653 L
s
.5 .41478 m
.5 .41106 L
s
.51488 .41478 m
.51488 .41453 L
s
.52976 .41478 m
.52976 .41478 L
s
.54464 .41478 m
.54464 .41478 L
s
.55952 .41478 m
.55952 .41478 L
s
.5744 .41478 m
.5744 .41478 L
s
.58929 .41478 m
.58929 .41478 L
s
.60417 .41478 m
.60417 .41478 L
s
.61905 .41478 m
.61905 .41478 L
s
.63393 .41478 m
.63393 .41478 L
s
.64881 .41478 m
.64881 .41478 L
s
.66369 .41478 m
.66369 .41478 L
s
.67857 .41478 m
.67857 .41478 L
s
.69345 .41478 m
.69345 .41478 L
s
.70833 .41478 m
.70833 .41478 L
s
.72321 .41478 m
.72321 .41478 L
s
.7381 .41478 m
.7381 .41478 L
s
.75298 .41478 m
.75298 .41478 L
s
.76786 .41478 m
.76786 .41478 L
s
.78274 .41478 m
.78274 .41478 L
s
.79762 .41478 m
.79762 .41478 L
s
.8125 .41478 m
.8125 .41478 L
s
.82738 .41478 m
.82738 .41478 L
s
.84226 .41478 m
.84226 .41478 L
s
.85714 .41478 m
.85714 .41478 L
s
.87202 .41478 m
.87202 .41478 L
s
.8869 .41478 m
.8869 .41478 L
s
.90179 .41478 m
.90179 .41478 L
s
.91667 .41478 m
.91667 .41478 L
s
.93155 .41478 m
.93155 .41478 L
s
.94643 .41478 m
.94643 .41478 L
s
.96131 .41478 m
.96131 .41478 L
s
.02381 .47759 m
.02381 .47759 L
s
.03125 .47759 m
.03125 .47759 L
s
.03869 .47759 m
.03869 .47759 L
s
.04613 .47759 m
.04613 .47759 L
s
.05357 .47759 m
.05357 .47759 L
s
.06101 .47759 m
.06101 .47759 L
s
.06845 .47759 m
.06845 .47759 L
s
.07589 .47759 m
.07589 .47759 L
s
.08333 .47759 m
.08333 .47759 L
s
.09077 .47759 m
.09077 .47759 L
s
.09821 .47759 m
.09821 .47759 L
s
.10565 .47759 m
.10565 .47759 L
s
.1131 .47759 m
.1131 .47759 L
s
.12054 .47759 m
.12054 .47759 L
s
.12798 .47759 m
.12798 .47759 L
s
.13542 .47759 m
.13542 .47759 L
s
.14286 .47759 m
.14286 .47759 L
s
.1503 .47759 m
.1503 .47759 L
s
.15774 .47759 m
.15774 .47759 L
s
.16518 .47759 m
.16518 .47759 L
s
.17262 .47759 m
.17262 .47759 L
s
.18006 .47759 m
.18006 .47759 L
s
.1875 .47759 m
.1875 .47759 L
s
.19494 .47759 m
.19494 .47759 L
s
.20238 .47759 m
.20238 .47759 L
s
.20982 .47759 m
.20982 .47759 L
s
.21726 .47759 m
.21726 .47759 L
s
.2247 .47759 m
.2247 .47759 L
s
.23214 .47759 m
.23214 .47759 L
s
.23958 .47759 m
.23958 .47759 L
s
.24702 .47759 m
.24702 .47759 L
s
.25446 .47759 m
.25446 .47759 L
s
.2619 .47759 m
.2619 .47759 L
s
.26935 .47759 m
.26935 .47759 L
s
.27679 .47759 m
.27679 .47759 L
s
.28423 .47759 m
.28423 .47759 L
s
.29167 .47759 m
.29167 .47759 L
s
.29911 .47759 m
.29911 .47759 L
s
.30655 .47759 m
.30655 .47759 L
s
.31399 .47759 m
.31399 .47759 L
s
.32143 .47759 m
.32143 .47759 L
s
.32887 .47759 m
.32887 .47759 L
s
.33631 .47759 m
.33631 .47759 L
s
.34375 .47759 m
.34375 .47759 L
s
.35119 .47759 m
.35119 .47759 L
s
.35863 .47759 m
.35863 .47759 L
s
.36607 .47759 m
.36607 .47759 L
s
.37351 .47759 m
.37351 .47759 L
s
.38095 .47759 m
.38095 .47759 L
s
.38839 .47759 m
.38839 .47759 L
s
.39583 .47759 m
.39583 .47759 L
s
.40327 .47759 m
.40327 .47759 L
s
.41071 .47759 m
.41071 .47759 L
s
.41815 .47759 m
.41815 .47759 L
s
.4256 .47759 m
.4256 .47759 L
s
.43304 .47759 m
.43304 .47759 L
s
.44048 .47759 m
.44048 .47759 L
s
.44792 .47759 m
.44792 .47759 L
s
.45536 .47759 m
.45536 .47759 L
s
.4628 .47759 m
.4628 .47759 L
s
.47024 .47759 m
.47024 .47759 L
s
.47768 .47759 m
.47768 .47759 L
s
.48512 .47759 m
.48512 .4776 L
s
.49256 .47759 m
.49256 .4788 L
s
.5 .47759 m
.5 .47643 L
s
.50744 .47759 m
.50744 .47714 L
s
.51488 .47759 m
.51488 .47758 L
s
.52232 .47759 m
.52232 .47759 L
s
.52976 .47759 m
.52976 .47759 L
s
.5372 .47759 m
.5372 .47759 L
s
.54464 .47759 m
.54464 .47759 L
s
.55208 .47759 m
.55208 .47759 L
s
.55952 .47759 m
.55952 .47759 L
s
.56696 .47759 m
.56696 .47759 L
s
.5744 .47759 m
.5744 .47759 L
s
.58185 .47759 m
.58185 .47759 L
s
.58929 .47759 m
.58929 .47759 L
s
.59673 .47759 m
.59673 .47759 L
s
.60417 .47759 m
.60417 .47759 L
s
.61161 .47759 m
.61161 .47759 L
s
.61905 .47759 m
.61905 .47759 L
s
.62649 .47759 m
.62649 .47759 L
s
.63393 .47759 m
.63393 .47759 L
s
.64137 .47759 m
.64137 .47759 L
s
.64881 .47759 m
.64881 .47759 L
s
.65625 .47759 m
.65625 .47759 L
s
.66369 .47759 m
.66369 .47759 L
s
.67113 .47759 m
.67113 .47759 L
s
.67857 .47759 m
.67857 .47759 L
s
.68601 .47759 m
.68601 .47759 L
s
.69345 .47759 m
.69345 .47759 L
s
.70089 .47759 m
.70089 .47759 L
s
.70833 .47759 m
.70833 .47759 L
s
.71577 .47759 m
.71577 .47759 L
s
.72321 .47759 m
.72321 .47759 L
s
.73065 .47759 m
.73065 .47759 L
s
.7381 .47759 m
.7381 .47759 L
s
.74554 .47759 m
.74554 .47759 L
s
.75298 .47759 m
.75298 .47759 L
s
.76042 .47759 m
.76042 .47759 L
s
.76786 .47759 m
.76786 .47759 L
s
.7753 .47759 m
.7753 .47759 L
s
.78274 .47759 m
.78274 .47759 L
s
.79018 .47759 m
.79018 .47759 L
s
.79762 .47759 m
.79762 .47759 L
s
.80506 .47759 m
.80506 .47759 L
s
.8125 .47759 m
.8125 .47759 L
s
.81994 .47759 m
.81994 .47759 L
s
.82738 .47759 m
.82738 .47759 L
s
.83482 .47759 m
.83482 .47759 L
s
.84226 .47759 m
.84226 .47759 L
s
.8497 .47759 m
.8497 .47759 L
s
.85714 .47759 m
.85714 .47759 L
s
.86458 .47759 m
.86458 .47759 L
s
.87202 .47759 m
.87202 .47759 L
s
.87946 .47759 m
.87946 .47759 L
s
.8869 .47759 m
.8869 .47759 L
s
.89435 .47759 m
.89435 .47759 L
s
.90179 .47759 m
.90179 .47759 L
s
.90923 .47759 m
.90923 .47759 L
s
.91667 .47759 m
.91667 .47759 L
s
.92411 .47759 m
.92411 .47759 L
s
.93155 .47759 m
.93155 .47759 L
s
.93899 .47759 m
.93899 .47759 L
s
.94643 .47759 m
.94643 .47759 L
s
.95387 .47759 m
.95387 .47759 L
s
.96131 .47759 m
.96131 .47759 L
s
.96875 .47759 m
.96875 .47759 L
s
.02381 .5404 m
.02381 .5404 L
s
.02753 .5404 m
.02753 .5404 L
s
.03125 .5404 m
.03125 .5404 L
s
.03497 .5404 m
.03497 .5404 L
s
.03869 .5404 m
.03869 .5404 L
s
.04241 .5404 m
.04241 .5404 L
s
.04613 .5404 m
.04613 .5404 L
s
.04985 .5404 m
.04985 .5404 L
s
.05357 .5404 m
.05357 .5404 L
s
.05729 .5404 m
.05729 .5404 L
s
.06101 .5404 m
.06101 .5404 L
s
.06473 .5404 m
.06473 .5404 L
s
.06845 .5404 m
.06845 .5404 L
s
.07217 .5404 m
.07217 .5404 L
s
.07589 .5404 m
.07589 .5404 L
s
.07961 .5404 m
.07961 .5404 L
s
.08333 .5404 m
.08333 .5404 L
s
.08705 .5404 m
.08705 .5404 L
s
.09077 .5404 m
.09077 .5404 L
s
.09449 .5404 m
.09449 .5404 L
s
.09821 .5404 m
.09821 .5404 L
s
.10193 .5404 m
.10193 .5404 L
s
.10565 .5404 m
.10565 .5404 L
s
.10938 .5404 m
.10938 .5404 L
s
.1131 .5404 m
.1131 .5404 L
s
.11682 .5404 m
.11682 .5404 L
s
.12054 .5404 m
.12054 .5404 L
s
.12426 .5404 m
.12426 .5404 L
s
.12798 .5404 m
.12798 .5404 L
s
.1317 .5404 m
.1317 .5404 L
s
.13542 .5404 m
.13542 .5404 L
s
.13914 .5404 m
.13914 .5404 L
s
.14286 .5404 m
.14286 .5404 L
s
.14658 .5404 m
.14658 .5404 L
s
.1503 .5404 m
.1503 .5404 L
s
.15402 .5404 m
.15402 .5404 L
s
.15774 .5404 m
.15774 .5404 L
s
.16146 .5404 m
.16146 .5404 L
s
.16518 .5404 m
.16518 .5404 L
s
.1689 .5404 m
.1689 .5404 L
s
.17262 .5404 m
.17262 .5404 L
s
.17634 .5404 m
.17634 .5404 L
s
.18006 .5404 m
.18006 .5404 L
s
.18378 .5404 m
.18378 .5404 L
s
.1875 .5404 m
.1875 .5404 L
s
.19122 .5404 m
.19122 .5404 L
s
.19494 .5404 m
.19494 .5404 L
s
.19866 .5404 m
.19866 .5404 L
s
.20238 .5404 m
.20238 .5404 L
s
.2061 .5404 m
.2061 .5404 L
s
.20982 .5404 m
.20982 .5404 L
s
.21354 .5404 m
.21354 .5404 L
s
.21726 .5404 m
.21726 .5404 L
s
.22098 .5404 m
.22098 .5404 L
s
.2247 .5404 m
.2247 .5404 L
s
.22842 .5404 m
.22842 .5404 L
s
.23214 .5404 m
.23214 .5404 L
s
.23586 .5404 m
.23586 .5404 L
s
.23958 .5404 m
.23958 .5404 L
s
.2433 .5404 m
.2433 .5404 L
s
.24702 .5404 m
.24702 .5404 L
s
.25074 .5404 m
.25074 .5404 L
s
.25446 .5404 m
.25446 .5404 L
s
.25818 .5404 m
.25818 .5404 L
s
.2619 .5404 m
.2619 .5404 L
s
.26563 .5404 m
.26563 .5404 L
s
.26935 .5404 m
.26935 .5404 L
s
.27307 .5404 m
.27307 .5404 L
s
.27679 .5404 m
.27679 .5404 L
s
.28051 .5404 m
.28051 .5404 L
s
.28423 .5404 m
.28423 .5404 L
s
.28795 .5404 m
.28795 .5404 L
s
.29167 .5404 m
.29167 .5404 L
s
.29539 .5404 m
.29539 .5404 L
s
.29911 .5404 m
.29911 .5404 L
s
.30283 .5404 m
.30283 .5404 L
s
.30655 .5404 m
.30655 .5404 L
s
.31027 .5404 m
.31027 .5404 L
s
.31399 .5404 m
.31399 .5404 L
s
.31771 .5404 m
.31771 .5404 L
s
.32143 .5404 m
.32143 .5404 L
s
.32515 .5404 m
.32515 .5404 L
s
.32887 .5404 m
.32887 .5404 L
s
.33259 .5404 m
.33259 .5404 L
s
.33631 .5404 m
.33631 .5404 L
s
.34003 .5404 m
.34003 .5404 L
s
.34375 .5404 m
.34375 .5404 L
s
.34747 .5404 m
.34747 .5404 L
s
.35119 .5404 m
.35119 .5404 L
s
.35491 .5404 m
.35491 .5404 L
s
.35863 .5404 m
.35863 .5404 L
s
.36235 .5404 m
.36235 .5404 L
s
.36607 .5404 m
.36607 .5404 L
s
.36979 .5404 m
.36979 .5404 L
s
.37351 .5404 m
.37351 .5404 L
s
.37723 .5404 m
.37723 .5404 L
s
.38095 .5404 m
.38095 .5404 L
s
.38467 .5404 m
.38467 .5404 L
s
.38839 .5404 m
.38839 .5404 L
s
.39211 .5404 m
.39211 .5404 L
s
.39583 .5404 m
.39583 .5404 L
s
.39955 .5404 m
.39955 .5404 L
s
.40327 .5404 m
.40327 .5404 L
s
.40699 .5404 m
.40699 .5404 L
s
.41071 .5404 m
.41071 .5404 L
s
.41443 .5404 m
.41443 .5404 L
s
.41815 .5404 m
.41815 .5404 L
s
.42188 .5404 m
.42188 .5404 L
s
.4256 .5404 m
.4256 .5404 L
s
.42932 .5404 m
.42932 .5404 L
s
.43304 .5404 m
.43304 .5404 L
s
.43676 .5404 m
.43676 .5404 L
s
.44048 .5404 m
.44048 .5404 L
s
.4442 .5404 m
.4442 .5404 L
s
.44792 .5404 m
.44792 .5404 L
s
.45164 .5404 m
.45164 .5404 L
s
.45536 .5404 m
.45536 .5404 L
s
.45908 .5404 m
.45908 .5404 L
s
.4628 .5404 m
.4628 .5404 L
s
.46652 .5404 m
.46652 .5404 L
s
.47024 .5404 m
.47024 .5404 L
s
.47396 .5404 m
.47396 .5404 L
s
.47768 .5404 m
.47768 .5404 L
s
.4814 .5404 m
.4814 .5404 L
s
.48512 .5404 m
.48512 .5404 L
s
.48884 .5404 m
.48884 .54041 L
s
.49256 .5404 m
.49256 .54049 L
s
.49628 .5404 m
.49628 .54089 L
s
.5 .5404 m
.5 .5403 L
s
.50372 .5404 m
.50372 .54 L
s
.50744 .5404 m
.50744 .54033 L
s
.51116 .5404 m
.51116 .54039 L
s
.51488 .5404 m
.51488 .5404 L
s
.5186 .5404 m
.5186 .5404 L
s
.52232 .5404 m
.52232 .5404 L
s
.52604 .5404 m
.52604 .5404 L
s
.52976 .5404 m
.52976 .5404 L
s
.53348 .5404 m
.53348 .5404 L
s
.5372 .5404 m
.5372 .5404 L
s
.54092 .5404 m
.54092 .5404 L
s
.54464 .5404 m
.54464 .5404 L
s
.54836 .5404 m
.54836 .5404 L
s
.55208 .5404 m
.55208 .5404 L
s
.5558 .5404 m
.5558 .5404 L
s
.55952 .5404 m
.55952 .5404 L
s
.56324 .5404 m
.56324 .5404 L
s
.56696 .5404 m
.56696 .5404 L
s
.57068 .5404 m
.57068 .5404 L
s
.5744 .5404 m
.5744 .5404 L
s
.57813 .5404 m
.57813 .5404 L
s
.58185 .5404 m
.58185 .5404 L
s
.58557 .5404 m
.58557 .5404 L
s
.58929 .5404 m
.58929 .5404 L
s
.59301 .5404 m
.59301 .5404 L
s
.59673 .5404 m
.59673 .5404 L
s
.60045 .5404 m
.60045 .5404 L
s
.60417 .5404 m
.60417 .5404 L
s
.60789 .5404 m
.60789 .5404 L
s
.61161 .5404 m
.61161 .5404 L
s
.61533 .5404 m
.61533 .5404 L
s
.61905 .5404 m
.61905 .5404 L
s
.62277 .5404 m
.62277 .5404 L
s
.62649 .5404 m
.62649 .5404 L
s
.63021 .5404 m
.63021 .5404 L
s
.63393 .5404 m
.63393 .5404 L
s
.63765 .5404 m
.63765 .5404 L
s
.64137 .5404 m
.64137 .5404 L
s
.64509 .5404 m
.64509 .5404 L
s
.64881 .5404 m
.64881 .5404 L
s
.65253 .5404 m
.65253 .5404 L
s
.65625 .5404 m
.65625 .5404 L
s
.65997 .5404 m
.65997 .5404 L
s
.66369 .5404 m
.66369 .5404 L
s
.66741 .5404 m
.66741 .5404 L
s
.67113 .5404 m
.67113 .5404 L
s
.67485 .5404 m
.67485 .5404 L
s
.67857 .5404 m
.67857 .5404 L
s
.68229 .5404 m
.68229 .5404 L
s
.68601 .5404 m
.68601 .5404 L
s
.68973 .5404 m
.68973 .5404 L
s
.69345 .5404 m
.69345 .5404 L
s
.69717 .5404 m
.69717 .5404 L
s
.70089 .5404 m
.70089 .5404 L
s
.70461 .5404 m
.70461 .5404 L
s
.70833 .5404 m
.70833 .5404 L
s
.71205 .5404 m
.71205 .5404 L
s
.71577 .5404 m
.71577 .5404 L
s
.71949 .5404 m
.71949 .5404 L
s
.72321 .5404 m
.72321 .5404 L
s
.72693 .5404 m
.72693 .5404 L
s
.73065 .5404 m
.73065 .5404 L
s
.73438 .5404 m
.73438 .5404 L
s
.7381 .5404 m
.7381 .5404 L
s
.74182 .5404 m
.74182 .5404 L
s
.74554 .5404 m
.74554 .5404 L
s
.74926 .5404 m
.74926 .5404 L
s
.75298 .5404 m
.75298 .5404 L
s
.7567 .5404 m
.7567 .5404 L
s
.76042 .5404 m
.76042 .5404 L
s
.76414 .5404 m
.76414 .5404 L
s
.76786 .5404 m
.76786 .5404 L
s
.77158 .5404 m
.77158 .5404 L
s
.7753 .5404 m
.7753 .5404 L
s
.77902 .5404 m
.77902 .5404 L
s
.78274 .5404 m
.78274 .5404 L
s
.78646 .5404 m
.78646 .5404 L
s
.79018 .5404 m
.79018 .5404 L
s
.7939 .5404 m
.7939 .5404 L
s
.79762 .5404 m
.79762 .5404 L
s
.80134 .5404 m
.80134 .5404 L
s
.80506 .5404 m
.80506 .5404 L
s
.80878 .5404 m
.80878 .5404 L
s
.8125 .5404 m
.8125 .5404 L
s
.81622 .5404 m
.81622 .5404 L
s
.81994 .5404 m
.81994 .5404 L
s
.82366 .5404 m
.82366 .5404 L
s
.82738 .5404 m
.82738 .5404 L
s
.8311 .5404 m
.8311 .5404 L
s
.83482 .5404 m
.83482 .5404 L
s
.83854 .5404 m
.83854 .5404 L
s
.84226 .5404 m
.84226 .5404 L
s
.84598 .5404 m
.84598 .5404 L
s
.8497 .5404 m
.8497 .5404 L
s
.85342 .5404 m
.85342 .5404 L
s
.85714 .5404 m
.85714 .5404 L
s
.86086 .5404 m
.86086 .5404 L
s
.86458 .5404 m
.86458 .5404 L
s
.8683 .5404 m
.8683 .5404 L
s
.87202 .5404 m
.87202 .5404 L
s
.87574 .5404 m
.87574 .5404 L
s
.87946 .5404 m
.87946 .5404 L
s
.88318 .5404 m
.88318 .5404 L
s
.8869 .5404 m
.8869 .5404 L
s
.89063 .5404 m
.89063 .5404 L
s
.89435 .5404 m
.89435 .5404 L
s
.89807 .5404 m
.89807 .5404 L
s
.90179 .5404 m
.90179 .5404 L
s
.90551 .5404 m
.90551 .5404 L
s
.90923 .5404 m
.90923 .5404 L
s
.91295 .5404 m
.91295 .5404 L
s
.91667 .5404 m
.91667 .5404 L
s
.92039 .5404 m
.92039 .5404 L
s
.92411 .5404 m
.92411 .5404 L
s
.92783 .5404 m
.92783 .5404 L
s
.93155 .5404 m
.93155 .5404 L
s
.93527 .5404 m
.93527 .5404 L
s
.93899 .5404 m
.93899 .5404 L
s
.94271 .5404 m
.94271 .5404 L
s
.94643 .5404 m
.94643 .5404 L
s
.95015 .5404 m
.95015 .5404 L
s
.95387 .5404 m
.95387 .5404 L
s
.95759 .5404 m
.95759 .5404 L
s
.96131 .5404 m
.96131 .5404 L
s
.96503 .5404 m
.96503 .5404 L
s
.96875 .5404 m
.96875 .5404 L
s
.97247 .5404 m
.97247 .5404 L
s
.02381 .60321 m
.02381 .60321 L
s
.02567 .60321 m
.02567 .60321 L
s
.02753 .60321 m
.02753 .60321 L
s
.02939 .60321 m
.02939 .60321 L
s
.03125 .60321 m
.03125 .60321 L
s
.03311 .60321 m
.03311 .60321 L
s
.03497 .60321 m
.03497 .60321 L
s
.03683 .60321 m
.03683 .60321 L
s
.03869 .60321 m
.03869 .60321 L
s
.04055 .60321 m
.04055 .60321 L
s
.04241 .60321 m
.04241 .60321 L
s
.04427 .60321 m
.04427 .60321 L
s
.04613 .60321 m
.04613 .60321 L
s
.04799 .60321 m
.04799 .60321 L
s
.04985 .60321 m
.04985 .60321 L
s
.05171 .60321 m
.05171 .60321 L
s
.05357 .60321 m
.05357 .60321 L
s
.05543 .60321 m
.05543 .60321 L
s
.05729 .60321 m
.05729 .60321 L
s
.05915 .60321 m
.05915 .60321 L
s
.06101 .60321 m
.06101 .60321 L
s
.06287 .60321 m
.06287 .60321 L
s
.06473 .60321 m
.06473 .60321 L
s
.06659 .60321 m
.06659 .60321 L
s
.06845 .60321 m
.06845 .60321 L
s
.07031 .60321 m
.07031 .60321 L
s
.07217 .60321 m
.07217 .60321 L
s
.07403 .60321 m
.07403 .60321 L
s
.07589 .60321 m
.07589 .60321 L
s
.07775 .60321 m
.07775 .60321 L
s
.07961 .60321 m
.07961 .60321 L
s
.08147 .60321 m
.08147 .60321 L
s
.08333 .60321 m
.08333 .60321 L
s
.08519 .60321 m
.08519 .60321 L
s
.08705 .60321 m
.08705 .60321 L
s
.08891 .60321 m
.08891 .60321 L
s
.09077 .60321 m
.09077 .60321 L
s
.09263 .60321 m
.09263 .60321 L
s
.09449 .60321 m
.09449 .60321 L
s
.09635 .60321 m
.09635 .60321 L
s
.09821 .60321 m
.09821 .60321 L
s
.10007 .60321 m
.10007 .60321 L
s
.10193 .60321 m
.10193 .60321 L
s
.10379 .60321 m
.10379 .60321 L
s
.10565 .60321 m
.10565 .60321 L
s
.10751 .60321 m
.10751 .60321 L
s
.10938 .60321 m
.10938 .60321 L
s
.11124 .60321 m
.11124 .60321 L
s
.1131 .60321 m
.1131 .60321 L
s
.11496 .60321 m
.11496 .60321 L
s
.11682 .60321 m
.11682 .60321 L
s
.11868 .60321 m
.11868 .60321 L
s
.12054 .60321 m
.12054 .60321 L
s
.1224 .60321 m
.1224 .60321 L
s
.12426 .60321 m
.12426 .60321 L
s
.12612 .60321 m
.12612 .60321 L
s
.12798 .60321 m
.12798 .60321 L
s
.12984 .60321 m
.12984 .60321 L
s
.1317 .60321 m
.1317 .60321 L
s
.13356 .60321 m
.13356 .60321 L
s
.13542 .60321 m
.13542 .60321 L
s
.13728 .60321 m
.13728 .60321 L
s
.13914 .60321 m
.13914 .60321 L
s
.141 .60321 m
.141 .60321 L
s
.14286 .60321 m
.14286 .60321 L
s
.14472 .60321 m
.14472 .60321 L
s
.14658 .60321 m
.14658 .60321 L
s
.14844 .60321 m
.14844 .60321 L
s
.1503 .60321 m
.1503 .60321 L
s
.15216 .60321 m
.15216 .60321 L
s
.15402 .60321 m
.15402 .60321 L
s
.15588 .60321 m
.15588 .60321 L
s
.15774 .60321 m
.15774 .60321 L
s
.1596 .60321 m
.1596 .60321 L
s
.16146 .60321 m
.16146 .60321 L
s
.16332 .60321 m
.16332 .60321 L
s
.16518 .60321 m
.16518 .60321 L
s
.16704 .60321 m
.16704 .60321 L
s
.1689 .60321 m
.1689 .60321 L
s
.17076 .60321 m
.17076 .60321 L
s
.17262 .60321 m
.17262 .60321 L
s
.17448 .60321 m
.17448 .60321 L
s
.17634 .60321 m
.17634 .60321 L
s
.1782 .60321 m
.1782 .60321 L
s
.18006 .60321 m
.18006 .60321 L
s
.18192 .60321 m
.18192 .60321 L
s
.18378 .60321 m
.18378 .60321 L
s
.18564 .60321 m
.18564 .60321 L
s
.1875 .60321 m
.1875 .60321 L
s
.18936 .60321 m
.18936 .60321 L
s
.19122 .60321 m
.19122 .60321 L
s
.19308 .60321 m
.19308 .60321 L
s
.19494 .60321 m
.19494 .60321 L
s
.1968 .60321 m
.1968 .60321 L
s
.19866 .60321 m
.19866 .60321 L
s
.20052 .60321 m
.20052 .60321 L
s
.20238 .60321 m
.20238 .60321 L
s
.20424 .60321 m
.20424 .60321 L
s
.2061 .60321 m
.2061 .60321 L
s
.20796 .60321 m
.20796 .60321 L
s
.20982 .60321 m
.20982 .60321 L
s
.21168 .60321 m
.21168 .60321 L
s
.21354 .60321 m
.21354 .60321 L
s
.2154 .60321 m
.2154 .60321 L
s
.21726 .60321 m
.21726 .60321 L
s
.21912 .60321 m
.21912 .60321 L
s
.22098 .60321 m
.22098 .60321 L
s
.22284 .60321 m
.22284 .60321 L
s
.2247 .60321 m
.2247 .60321 L
s
.22656 .60321 m
.22656 .60321 L
s
.22842 .60321 m
.22842 .60321 L
s
.23028 .60321 m
.23028 .60321 L
s
.23214 .60321 m
.23214 .60321 L
s
.234 .60321 m
.234 .60321 L
s
.23586 .60321 m
.23586 .60321 L
s
.23772 .60321 m
.23772 .60321 L
s
.23958 .60321 m
.23958 .60321 L
s
.24144 .60321 m
.24144 .60321 L
s
.2433 .60321 m
.2433 .60321 L
s
.24516 .60321 m
.24516 .60321 L
s
.24702 .60321 m
.24702 .60321 L
s
.24888 .60321 m
.24888 .60321 L
s
.25074 .60321 m
.25074 .60321 L
s
.2526 .60321 m
.2526 .60321 L
s
.25446 .60321 m
.25446 .60321 L
s
.25632 .60321 m
.25632 .60321 L
s
.25818 .60321 m
.25818 .60321 L
s
.26004 .60321 m
.26004 .60321 L
s
.2619 .60321 m
.2619 .60321 L
s
.26376 .60321 m
.26376 .60321 L
s
.26563 .60321 m
.26563 .60321 L
s
.26749 .60321 m
.26749 .60321 L
s
.26935 .60321 m
.26935 .60321 L
s
.27121 .60321 m
.27121 .60321 L
s
.27307 .60321 m
.27307 .60321 L
s
.27493 .60321 m
.27493 .60321 L
s
.27679 .60321 m
.27679 .60321 L
s
.27865 .60321 m
.27865 .60321 L
s
.28051 .60321 m
.28051 .60321 L
s
.28237 .60321 m
.28237 .60321 L
s
.28423 .60321 m
.28423 .60321 L
s
.28609 .60321 m
.28609 .60321 L
s
.28795 .60321 m
.28795 .60321 L
s
.28981 .60321 m
.28981 .60321 L
s
.29167 .60321 m
.29167 .60321 L
s
.29353 .60321 m
.29353 .60321 L
s
.29539 .60321 m
.29539 .60321 L
s
.29725 .60321 m
.29725 .60321 L
s
.29911 .60321 m
.29911 .60321 L
s
.30097 .60321 m
.30097 .60321 L
s
.30283 .60321 m
.30283 .60321 L
s
.30469 .60321 m
.30469 .60321 L
s
.30655 .60321 m
.30655 .60321 L
s
.30841 .60321 m
.30841 .60321 L
s
.31027 .60321 m
.31027 .60321 L
s
.31213 .60321 m
.31213 .60321 L
s
.31399 .60321 m
.31399 .60321 L
s
.31585 .60321 m
.31585 .60321 L
s
.31771 .60321 m
.31771 .60321 L
s
.31957 .60321 m
.31957 .60321 L
s
.32143 .60321 m
.32143 .60321 L
s
.32329 .60321 m
.32329 .60321 L
s
.32515 .60321 m
.32515 .60321 L
s
.32701 .60321 m
.32701 .60321 L
s
.32887 .60321 m
.32887 .60321 L
s
.33073 .60321 m
.33073 .60321 L
s
.33259 .60321 m
.33259 .60321 L
s
.33445 .60321 m
.33445 .60321 L
s
.33631 .60321 m
.33631 .60321 L
s
.33817 .60321 m
.33817 .60321 L
s
.34003 .60321 m
.34003 .60321 L
s
.34189 .60321 m
.34189 .60321 L
s
.34375 .60321 m
.34375 .60321 L
s
.34561 .60321 m
.34561 .60321 L
s
.34747 .60321 m
.34747 .60321 L
s
.34933 .60321 m
.34933 .60321 L
s
.35119 .60321 m
.35119 .60321 L
s
.35305 .60321 m
.35305 .60321 L
s
.35491 .60321 m
.35491 .60321 L
s
.35677 .60321 m
.35677 .60321 L
s
.35863 .60321 m
.35863 .60321 L
s
.36049 .60321 m
.36049 .60321 L
s
.36235 .60321 m
.36235 .60321 L
s
.36421 .60321 m
.36421 .60321 L
s
.36607 .60321 m
.36607 .60321 L
s
.36793 .60321 m
.36793 .60321 L
s
.36979 .60321 m
.36979 .60321 L
s
.37165 .60321 m
.37165 .60321 L
s
.37351 .60321 m
.37351 .60321 L
s
.37537 .60321 m
.37537 .60321 L
s
.37723 .60321 m
.37723 .60321 L
s
.37909 .60321 m
.37909 .60321 L
s
.38095 .60321 m
.38095 .60321 L
s
.38281 .60321 m
.38281 .60321 L
s
.38467 .60321 m
.38467 .60321 L
s
.38653 .60321 m
.38653 .60321 L
s
.38839 .60321 m
.38839 .60321 L
s
.39025 .60321 m
.39025 .60321 L
s
.39211 .60321 m
.39211 .60321 L
s
.39397 .60321 m
.39397 .60321 L
s
.39583 .60321 m
.39583 .60321 L
s
.39769 .60321 m
.39769 .60321 L
s
.39955 .60321 m
.39955 .60321 L
s
.40141 .60321 m
.40141 .60321 L
s
.40327 .60321 m
.40327 .60321 L
s
.40513 .60321 m
.40513 .60321 L
s
.40699 .60321 m
.40699 .60321 L
s
.40885 .60321 m
.40885 .60321 L
s
.41071 .60321 m
.41071 .60321 L
s
.41257 .60321 m
.41257 .60321 L
s
.41443 .60321 m
.41443 .60321 L
s
.41629 .60321 m
.41629 .60321 L
s
.41815 .60321 m
.41815 .60321 L
s
.42001 .60321 m
.42001 .60321 L
s
.42188 .60321 m
.42188 .60321 L
s
.42374 .60321 m
.42374 .60321 L
s
.4256 .60321 m
.4256 .60321 L
s
.42746 .60321 m
.42746 .60321 L
s
.42932 .60321 m
.42932 .60321 L
s
.43118 .60321 m
.43118 .60321 L
s
.43304 .60321 m
.43304 .60321 L
s
.4349 .60321 m
.4349 .60321 L
s
.43676 .60321 m
.43676 .60321 L
s
.43862 .60321 m
.43862 .60321 L
s
.44048 .60321 m
.44048 .60321 L
s
.44234 .60321 m
.44234 .60321 L
s
.4442 .60321 m
.4442 .60321 L
s
.44606 .60321 m
.44606 .60321 L
s
.44792 .60321 m
.44792 .60321 L
s
.44978 .60321 m
.44978 .60321 L
s
.45164 .60321 m
.45164 .60321 L
s
.4535 .60321 m
.4535 .60321 L
s
.45536 .60321 m
.45536 .60321 L
s
.45722 .60321 m
.45722 .60321 L
s
.45908 .60321 m
.45908 .60321 L
s
.46094 .60321 m
.46094 .60321 L
s
.4628 .60321 m
.4628 .60321 L
s
.46466 .60321 m
.46466 .60321 L
s
.46652 .60321 m
.46652 .60321 L
s
.46838 .60321 m
.46838 .60321 L
s
.47024 .60321 m
.47024 .60321 L
s
.4721 .60321 m
.4721 .60321 L
s
.47396 .60321 m
.47396 .60321 L
s
.47582 .60321 m
.47582 .60321 L
s
.47768 .60321 m
.47768 .60321 L
s
.47954 .60321 m
.47954 .60321 L
s
.4814 .60321 m
.4814 .60321 L
s
.48326 .60321 m
.48326 .60321 L
s
.48512 .60321 m
.48512 .60321 L
s
.48698 .60321 m
.48698 .60321 L
s
.48884 .60321 m
.48884 .60321 L
s
.4907 .60321 m
.4907 .60322 L
s
.49256 .60321 m
.49256 .60322 L
s
.49442 .60321 m
.49442 .60324 L
s
.49628 .60321 m
.49628 .60329 L
s
.49814 .60321 m
.49814 .60332 L
s
.5 .60321 m
.5 .60323 L
s
.50186 .60321 m
.50186 .60311 L
s
.50372 .60321 m
.50372 .60313 L
s
.50558 .60321 m
.50558 .60317 L
s
.50744 .60321 m
.50744 .6032 L
s
.5093 .60321 m
.5093 .60321 L
s
.51116 .60321 m
.51116 .60321 L
s
.51302 .60321 m
.51302 .60321 L
s
.51488 .60321 m
.51488 .60321 L
s
.51674 .60321 m
.51674 .60321 L
s
.5186 .60321 m
.5186 .60321 L
s
.52046 .60321 m
.52046 .60321 L
s
.52232 .60321 m
.52232 .60321 L
s
.52418 .60321 m
.52418 .60321 L
s
.52604 .60321 m
.52604 .60321 L
s
.5279 .60321 m
.5279 .60321 L
s
.52976 .60321 m
.52976 .60321 L
s
.53162 .60321 m
.53162 .60321 L
s
.53348 .60321 m
.53348 .60321 L
s
.53534 .60321 m
.53534 .60321 L
s
.5372 .60321 m
.5372 .60321 L
s
.53906 .60321 m
.53906 .60321 L
s
.54092 .60321 m
.54092 .60321 L
s
.54278 .60321 m
.54278 .60321 L
s
.54464 .60321 m
.54464 .60321 L
s
.5465 .60321 m
.5465 .60321 L
s
.54836 .60321 m
.54836 .60321 L
s
.55022 .60321 m
.55022 .60321 L
s
.55208 .60321 m
.55208 .60321 L
s
.55394 .60321 m
.55394 .60321 L
s
.5558 .60321 m
.5558 .60321 L
s
.55766 .60321 m
.55766 .60321 L
s
.55952 .60321 m
.55952 .60321 L
s
.56138 .60321 m
.56138 .60321 L
s
.56324 .60321 m
.56324 .60321 L
s
.5651 .60321 m
.5651 .60321 L
s
.56696 .60321 m
.56696 .60321 L
s
.56882 .60321 m
.56882 .60321 L
s
.57068 .60321 m
.57068 .60321 L
s
.57254 .60321 m
.57254 .60321 L
s
.5744 .60321 m
.5744 .60321 L
s
.57626 .60321 m
.57626 .60321 L
s
.57813 .60321 m
.57813 .60321 L
s
.57999 .60321 m
.57999 .60321 L
s
.58185 .60321 m
.58185 .60321 L
s
.58371 .60321 m
.58371 .60321 L
s
.58557 .60321 m
.58557 .60321 L
s
.58743 .60321 m
.58743 .60321 L
s
.58929 .60321 m
.58929 .60321 L
s
.59115 .60321 m
.59115 .60321 L
s
.59301 .60321 m
.59301 .60321 L
s
.59487 .60321 m
.59487 .60321 L
s
.59673 .60321 m
.59673 .60321 L
s
.59859 .60321 m
.59859 .60321 L
s
.60045 .60321 m
.60045 .60321 L
s
.60231 .60321 m
.60231 .60321 L
s
.60417 .60321 m
.60417 .60321 L
s
.60603 .60321 m
.60603 .60321 L
s
.60789 .60321 m
.60789 .60321 L
s
.60975 .60321 m
.60975 .60321 L
s
.61161 .60321 m
.61161 .60321 L
s
.61347 .60321 m
.61347 .60321 L
s
.61533 .60321 m
.61533 .60321 L
s
.61719 .60321 m
.61719 .60321 L
s
.61905 .60321 m
.61905 .60321 L
s
.62091 .60321 m
.62091 .60321 L
s
.62277 .60321 m
.62277 .60321 L
s
.62463 .60321 m
.62463 .60321 L
s
.62649 .60321 m
.62649 .60321 L
s
.62835 .60321 m
.62835 .60321 L
s
.63021 .60321 m
.63021 .60321 L
s
.63207 .60321 m
.63207 .60321 L
s
.63393 .60321 m
.63393 .60321 L
s
.63579 .60321 m
.63579 .60321 L
s
.63765 .60321 m
.63765 .60321 L
s
.63951 .60321 m
.63951 .60321 L
s
.64137 .60321 m
.64137 .60321 L
s
.64323 .60321 m
.64323 .60321 L
s
.64509 .60321 m
.64509 .60321 L
s
.64695 .60321 m
.64695 .60321 L
s
.64881 .60321 m
.64881 .60321 L
s
.65067 .60321 m
.65067 .60321 L
s
.65253 .60321 m
.65253 .60321 L
s
.65439 .60321 m
.65439 .60321 L
s
.65625 .60321 m
.65625 .60321 L
s
.65811 .60321 m
.65811 .60321 L
s
.65997 .60321 m
.65997 .60321 L
s
.66183 .60321 m
.66183 .60321 L
s
.66369 .60321 m
.66369 .60321 L
s
.66555 .60321 m
.66555 .60321 L
s
.66741 .60321 m
.66741 .60321 L
s
.66927 .60321 m
.66927 .60321 L
s
.67113 .60321 m
.67113 .60321 L
s
.67299 .60321 m
.67299 .60321 L
s
.67485 .60321 m
.67485 .60321 L
s
.67671 .60321 m
.67671 .60321 L
s
.67857 .60321 m
.67857 .60321 L
s
.68043 .60321 m
.68043 .60321 L
s
.68229 .60321 m
.68229 .60321 L
s
.68415 .60321 m
.68415 .60321 L
s
.68601 .60321 m
.68601 .60321 L
s
.68787 .60321 m
.68787 .60321 L
s
.68973 .60321 m
.68973 .60321 L
s
.69159 .60321 m
.69159 .60321 L
s
.69345 .60321 m
.69345 .60321 L
s
.69531 .60321 m
.69531 .60321 L
s
.69717 .60321 m
.69717 .60321 L
s
.69903 .60321 m
.69903 .60321 L
s
.70089 .60321 m
.70089 .60321 L
s
.70275 .60321 m
.70275 .60321 L
s
.70461 .60321 m
.70461 .60321 L
s
.70647 .60321 m
.70647 .60321 L
s
.70833 .60321 m
.70833 .60321 L
s
.71019 .60321 m
.71019 .60321 L
s
.71205 .60321 m
.71205 .60321 L
s
.71391 .60321 m
.71391 .60321 L
s
.71577 .60321 m
.71577 .60321 L
s
.71763 .60321 m
.71763 .60321 L
s
.71949 .60321 m
.71949 .60321 L
s
.72135 .60321 m
.72135 .60321 L
s
.72321 .60321 m
.72321 .60321 L
s
.72507 .60321 m
.72507 .60321 L
s
.72693 .60321 m
.72693 .60321 L
s
.72879 .60321 m
.72879 .60321 L
s
.73065 .60321 m
.73065 .60321 L
s
.73251 .60321 m
.73251 .60321 L
s
.73438 .60321 m
.73438 .60321 L
s
.73624 .60321 m
.73624 .60321 L
s
.7381 .60321 m
.7381 .60321 L
s
.73996 .60321 m
.73996 .60321 L
s
.74182 .60321 m
.74182 .60321 L
s
.74368 .60321 m
.74368 .60321 L
s
.74554 .60321 m
.74554 .60321 L
s
.7474 .60321 m
.7474 .60321 L
s
.74926 .60321 m
.74926 .60321 L
s
.75112 .60321 m
.75112 .60321 L
s
.75298 .60321 m
.75298 .60321 L
s
.75484 .60321 m
.75484 .60321 L
s
.7567 .60321 m
.7567 .60321 L
s
.75856 .60321 m
.75856 .60321 L
s
.76042 .60321 m
.76042 .60321 L
s
.76228 .60321 m
.76228 .60321 L
s
.76414 .60321 m
.76414 .60321 L
s
.766 .60321 m
.766 .60321 L
s
.76786 .60321 m
.76786 .60321 L
s
.76972 .60321 m
.76972 .60321 L
s
.77158 .60321 m
.77158 .60321 L
s
.77344 .60321 m
.77344 .60321 L
s
.7753 .60321 m
.7753 .60321 L
s
.77716 .60321 m
.77716 .60321 L
s
.77902 .60321 m
.77902 .60321 L
s
.78088 .60321 m
.78088 .60321 L
s
.78274 .60321 m
.78274 .60321 L
s
.7846 .60321 m
.7846 .60321 L
s
.78646 .60321 m
.78646 .60321 L
s
.78832 .60321 m
.78832 .60321 L
s
.79018 .60321 m
.79018 .60321 L
s
.79204 .60321 m
.79204 .60321 L
s
.7939 .60321 m
.7939 .60321 L
s
.79576 .60321 m
.79576 .60321 L
s
.79762 .60321 m
.79762 .60321 L
s
.79948 .60321 m
.79948 .60321 L
s
.80134 .60321 m
.80134 .60321 L
s
.8032 .60321 m
.8032 .60321 L
s
.80506 .60321 m
.80506 .60321 L
s
.80692 .60321 m
.80692 .60321 L
s
.80878 .60321 m
.80878 .60321 L
s
.81064 .60321 m
.81064 .60321 L
s
.8125 .60321 m
.8125 .60321 L
s
.81436 .60321 m
.81436 .60321 L
s
.81622 .60321 m
.81622 .60321 L
s
.81808 .60321 m
.81808 .60321 L
s
.81994 .60321 m
.81994 .60321 L
s
.8218 .60321 m
.8218 .60321 L
s
.82366 .60321 m
.82366 .60321 L
s
.82552 .60321 m
.82552 .60321 L
s
.82738 .60321 m
.82738 .60321 L
s
.82924 .60321 m
.82924 .60321 L
s
.8311 .60321 m
.8311 .60321 L
s
.83296 .60321 m
.83296 .60321 L
s
.83482 .60321 m
.83482 .60321 L
s
.83668 .60321 m
.83668 .60321 L
s
.83854 .60321 m
.83854 .60321 L
s
.8404 .60321 m
.8404 .60321 L
s
.84226 .60321 m
.84226 .60321 L
s
.84412 .60321 m
.84412 .60321 L
s
.84598 .60321 m
.84598 .60321 L
s
.84784 .60321 m
.84784 .60321 L
s
.8497 .60321 m
.8497 .60321 L
s
.85156 .60321 m
.85156 .60321 L
s
.85342 .60321 m
.85342 .60321 L
s
.85528 .60321 m
.85528 .60321 L
s
.85714 .60321 m
.85714 .60321 L
s
.859 .60321 m
.859 .60321 L
s
.86086 .60321 m
.86086 .60321 L
s
.86272 .60321 m
.86272 .60321 L
s
.86458 .60321 m
.86458 .60321 L
s
.86644 .60321 m
.86644 .60321 L
s
.8683 .60321 m
.8683 .60321 L
s
.87016 .60321 m
.87016 .60321 L
s
.87202 .60321 m
.87202 .60321 L
s
.87388 .60321 m
.87388 .60321 L
s
.87574 .60321 m
.87574 .60321 L
s
.8776 .60321 m
.8776 .60321 L
s
.87946 .60321 m
.87946 .60321 L
s
.88132 .60321 m
.88132 .60321 L
s
.88318 .60321 m
.88318 .60321 L
s
.88504 .60321 m
.88504 .60321 L
s
.8869 .60321 m
.8869 .60321 L
s
.88876 .60321 m
.88876 .60321 L
s
.89063 .60321 m
.89063 .60321 L
s
.89249 .60321 m
.89249 .60321 L
s
.89435 .60321 m
.89435 .60321 L
s
.89621 .60321 m
.89621 .60321 L
s
.89807 .60321 m
.89807 .60321 L
s
.89993 .60321 m
.89993 .60321 L
s
.90179 .60321 m
.90179 .60321 L
s
.90365 .60321 m
.90365 .60321 L
s
.90551 .60321 m
.90551 .60321 L
s
.90737 .60321 m
.90737 .60321 L
s
.90923 .60321 m
.90923 .60321 L
s
.91109 .60321 m
.91109 .60321 L
s
.91295 .60321 m
.91295 .60321 L
s
.91481 .60321 m
.91481 .60321 L
s
.91667 .60321 m
.91667 .60321 L
s
.91853 .60321 m
.91853 .60321 L
s
.92039 .60321 m
.92039 .60321 L
s
.92225 .60321 m
.92225 .60321 L
s
.92411 .60321 m
.92411 .60321 L
s
.92597 .60321 m
.92597 .60321 L
s
.92783 .60321 m
.92783 .60321 L
s
.92969 .60321 m
.92969 .60321 L
s
.93155 .60321 m
.93155 .60321 L
s
.93341 .60321 m
.93341 .60321 L
s
.93527 .60321 m
.93527 .60321 L
s
.93713 .60321 m
.93713 .60321 L
s
.93899 .60321 m
.93899 .60321 L
s
.94085 .60321 m
.94085 .60321 L
s
.94271 .60321 m
.94271 .60321 L
s
.94457 .60321 m
.94457 .60321 L
s
.94643 .60321 m
.94643 .60321 L
s
.94829 .60321 m
.94829 .60321 L
s
.95015 .60321 m
.95015 .60321 L
s
.95201 .60321 m
.95201 .60321 L
s
.95387 .60321 m
.95387 .60321 L
s
.95573 .60321 m
.95573 .60321 L
s
.95759 .60321 m
.95759 .60321 L
s
.95945 .60321 m
.95945 .60321 L
s
.96131 .60321 m
.96131 .60321 L
s
.96317 .60321 m
.96317 .60321 L
s
.96503 .60321 m
.96503 .60321 L
s
.96689 .60321 m
.96689 .60321 L
s
.96875 .60321 m
.96875 .60321 L
s
.97061 .60321 m
.97061 .60321 L
s
.97247 .60321 m
.97247 .60321 L
s
.97433 .60321 m
.97433 .60321 L
s
0 1 1 r
.02381 .03791 m
.97619 .03791 L
s
.02381 .10072 m
.97619 .10072 L
s
.02381 .16353 m
.97619 .16353 L
s
.02381 .22635 m
.97619 .22635 L
s
.02381 .28916 m
.97619 .28916 L
s
.02381 .35197 m
.97619 .35197 L
s
.02381 .41478 m
.97619 .41478 L
s
.02381 .47759 m
.97619 .47759 L
s
.02381 .5404 m
.97619 .5404 L
s
.02381 .60321 m
.97619 .60321 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["We can also select a few sublists and display them.", "MathCaption",
  CellTags->{"S2.1.1", "1.16"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[Take[wtdata, {3, 6}],
Axes -> {True, False}, PlotRange -> All,
PlotLabel -> \"wavelet coefficients\"];\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 -0.0290588 0.0176787 [
[.02381 .04683 -3 -9 ]
[.02381 .04683 3 0 ]
[.17262 .04683 -3 -9 ]
[.17262 .04683 3 0 ]
[.32143 .04683 -6 -9 ]
[.32143 .04683 6 0 ]
[.47024 .04683 -6 -9 ]
[.47024 .04683 6 0 ]
[.61905 .04683 -6 -9 ]
[.61905 .04683 6 0 ]
[.76786 .04683 -6 -9 ]
[.76786 .04683 6 0 ]
[.91667 .04683 -6 -9 ]
[.91667 .04683 6 0 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .05933 m
.02381 .06558 L
s
[(0)] .02381 .04683 0 1 Mshowa
.17262 .05933 m
.17262 .06558 L
s
[(5)] .17262 .04683 0 1 Mshowa
.32143 .05933 m
.32143 .06558 L
s
[(10)] .32143 .04683 0 1 Mshowa
.47024 .05933 m
.47024 .06558 L
s
[(15)] .47024 .04683 0 1 Mshowa
.61905 .05933 m
.61905 .06558 L
s
[(20)] .61905 .04683 0 1 Mshowa
.76786 .05933 m
.76786 .06558 L
s
[(25)] .76786 .04683 0 1 Mshowa
.91667 .05933 m
.91667 .06558 L
s
[(30)] .91667 .04683 0 1 Mshowa
.125 Mabswid
.05357 .05933 m
.05357 .06308 L
s
.08333 .05933 m
.08333 .06308 L
s
.1131 .05933 m
.1131 .06308 L
s
.14286 .05933 m
.14286 .06308 L
s
.20238 .05933 m
.20238 .06308 L
s
.23214 .05933 m
.23214 .06308 L
s
.2619 .05933 m
.2619 .06308 L
s
.29167 .05933 m
.29167 .06308 L
s
.35119 .05933 m
.35119 .06308 L
s
.38095 .05933 m
.38095 .06308 L
s
.41071 .05933 m
.41071 .06308 L
s
.44048 .05933 m
.44048 .06308 L
s
.5 .05933 m
.5 .06308 L
s
.52976 .05933 m
.52976 .06308 L
s
.55952 .05933 m
.55952 .06308 L
s
.58929 .05933 m
.58929 .06308 L
s
.64881 .05933 m
.64881 .06308 L
s
.67857 .05933 m
.67857 .06308 L
s
.70833 .05933 m
.70833 .06308 L
s
.7381 .05933 m
.7381 .06308 L
s
.79762 .05933 m
.79762 .06308 L
s
.82738 .05933 m
.82738 .06308 L
s
.85714 .05933 m
.85714 .06308 L
s
.8869 .05933 m
.8869 .06308 L
s
.94643 .05933 m
.94643 .06308 L
s
.97619 .05933 m
.97619 .06308 L
s
.25 Mabswid
0 .05933 m
1 .05933 L
s
[(wavelet coefficients)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .12629 m
.02381 .12648 L
s
.2619 .12629 m
.2619 .15683 L
s
.5 .12629 m
.5 .01472 L
s
.7381 .12629 m
.7381 .12536 L
s
.02381 .28164 m
.02381 .28166 L
s
.14286 .28164 m
.14286 .28174 L
s
.2619 .28164 m
.2619 .28187 L
s
.38095 .28164 m
.38095 .30231 L
s
.5 .28164 m
.5 .20397 L
s
.61905 .28164 m
.61905 .28114 L
s
.7381 .28164 m
.7381 .28147 L
s
.85714 .28164 m
.85714 .28158 L
s
.02381 .43699 m
.02381 .43699 L
s
.08333 .43699 m
.08333 .437 L
s
.14286 .43699 m
.14286 .43701 L
s
.20238 .43699 m
.20238 .43701 L
s
.2619 .43699 m
.2619 .43703 L
s
.32143 .43699 m
.32143 .43704 L
s
.38095 .43699 m
.38095 .43707 L
s
.44048 .43699 m
.44048 .45152 L
s
.5 .43699 m
.5 .38347 L
s
.55952 .43699 m
.55952 .43659 L
s
.61905 .43699 m
.61905 .43692 L
s
.67857 .43699 m
.67857 .43694 L
s
.7381 .43699 m
.7381 .43696 L
s
.79762 .43699 m
.79762 .43697 L
s
.85714 .43699 m
.85714 .43698 L
s
.91667 .43699 m
.91667 .43698 L
s
.02381 .59234 m
.02381 .59234 L
s
.05357 .59234 m
.05357 .59234 L
s
.08333 .59234 m
.08333 .59234 L
s
.1131 .59234 m
.1131 .59234 L
s
.14286 .59234 m
.14286 .59234 L
s
.17262 .59234 m
.17262 .59234 L
s
.20238 .59234 m
.20238 .59234 L
s
.23214 .59234 m
.23214 .59234 L
s
.2619 .59234 m
.2619 .59235 L
s
.29167 .59234 m
.29167 .59235 L
s
.32143 .59234 m
.32143 .59235 L
s
.35119 .59234 m
.35119 .59235 L
s
.38095 .59234 m
.38095 .59235 L
s
.41071 .59234 m
.41071 .59236 L
s
.44048 .59234 m
.44048 .59236 L
s
.47024 .59234 m
.47024 .60332 L
s
.5 .59234 m
.5 .55729 L
s
.52976 .59234 m
.52976 .59171 L
s
.55952 .59234 m
.55952 .59232 L
s
.58929 .59234 m
.58929 .59232 L
s
.61905 .59234 m
.61905 .59233 L
s
.64881 .59234 m
.64881 .59233 L
s
.67857 .59234 m
.67857 .59233 L
s
.70833 .59234 m
.70833 .59233 L
s
.7381 .59234 m
.7381 .59233 L
s
.76786 .59234 m
.76786 .59233 L
s
.79762 .59234 m
.79762 .59234 L
s
.82738 .59234 m
.82738 .59234 L
s
.85714 .59234 m
.85714 .59234 L
s
.8869 .59234 m
.8869 .59234 L
s
.91667 .59234 m
.91667 .59234 L
s
.94643 .59234 m
.94643 .59234 L
s
0 1 1 r
.02381 .12629 m
.97619 .12629 L
s
.02381 .28164 m
.97619 .28164 L
s
.02381 .43699 m
.97619 .43699 L
s
.02381 .59234 m
.97619 .59234 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "We see that the significant contributions to the signal are from the \
coefficients close to the center of the shock. We can also see this using the \
phase space plot or time\[Hyphen]frequency plot of these coefficients. A \
phase space plot of a one\[Hyphen]dimensional wavelet coefficients is \
produced as follows. Each basis function has a mean location ",
  Cell[BoxData[
      \(TraditionalForm\`{\(t\^*\), \(\[Omega]\^*\)}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and extent ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]  t\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " in phase space. We associate with each wavelet basis function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(j  k\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " a constant rectangular area ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\_\(k, j\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " in phase space (or time\[Hyphen]frequency space). The width of the \
rectangle is proportional to the spread of the wavelet in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]  t\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and the height to that in frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ". For example, the rectangle associated with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((\(2\^j\) t)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is twice as wide and half as tall as that associated with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((\(2\^\(j + 1\)\) t)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ". This is simply because the latter is more localized in time and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]  t  \[CapitalDelta]\[Omega]\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  " is a constant. With each rectangle arranged in phase space according to ",
  
  Cell[BoxData[
      \(TraditionalForm\`\((k, j)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", we shade the area according to the absolute value of the corresponding \
coefficient: the bigger the absolute value of the coefficient, the darker the \
area. The function ",
  StyleBox["PhaseSpacePlot[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox["]", "MR"],
  " gives the representation of the wavelet coefficients ",
  StyleBox["coefs", "TI"],
  " in phase space."
}], "Text",
  CellTags->{"S2.1.1", "1.17"}],

Cell[TextData[{
  "This gives the phase space plot of the coefficients. With increasing ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", the heights of the rectangular cells increase rapidly."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.18"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[wtdata,
Frame -> True, FrameTicks -> None,
PlotLabel -> \"wavelet coefficients in phase space\"]\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0147151 0.475339 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105 0 ]
[.5 .63053 105 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet coefficients in phase space)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01472 translate
.95238 .00185 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4242
pop
P
% End of image
% Start of gray image
p
.02381 .01657 translate
.95238 .00186 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B900
pop
P
% End of image
% Start of gray image
p
.02381 .01843 translate
.95238 .00371 scale
4 string
4 1 8 [4 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFCF4EFE
pop
P
% End of image
% Start of gray image
p
.02381 .02214 translate
.95238 .00743 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFDF84FFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .02957 translate
.95238 .01485 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFE8AAFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .04442 translate
.95238 .02971 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEC8FEFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .07413 translate
.95238 .05942 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF1E1FEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .13355 translate
.95238 .11883 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6FCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .25238 translate
.95238 .23767 scale
256 string
256 1 8 [256 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .49005 translate
.95238 .47534 scale
512 string
512 1 8 [512 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "The first 6 entries are selected from ",
  StyleBox["wtdata", "MR"],
  " and plotted."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.19"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[Take[wtdata, 6],
Frame -> True, FrameTicks -> None,
PlotLabel -> \"wavelet coefficients in phase space\"]\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0147151 0.294302 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105 0 ]
[.5 .63053 105 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet coefficients in phase space)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01472 translate
.95238 .01839 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4242
pop
P
% End of image
% Start of gray image
p
.02381 .03311 translate
.95238 .01839 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B900
pop
P
% End of image
% Start of gray image
p
.02381 .0515 translate
.95238 .03679 scale
4 string
4 1 8 [4 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFCF4EFE
pop
P
% End of image
% Start of gray image
p
.02381 .08829 translate
.95238 .07358 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFDF84FFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .16187 translate
.95238 .14715 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFE8AAFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .2943 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEC8FEFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "We can use the option ",
  StyleBox["LogarithmicScale", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  " to draw all the rectangles with the same height. However, use this option \
only for convenience of viewing and for plotting wavelet coefficients."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.20"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[wtdata, PlotRange -> All,
Frame->True, FrameTicks -> None,
LogarithmicScale -> True,
PlotLabel -> \"wavelet coefficients in phase space\"]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0147151 0.0588604 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105 0 ]
[.5 .63053 105 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet coefficients in phase space)] .5 .63053 0 -1 Mshowa
% Start of gray image
p
.02381 .01472 translate
.95238 .05886 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
4242
pop
P
% End of image
% Start of gray image
p
.02381 .07358 translate
.95238 .05886 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B900
pop
P
% End of image
% Start of gray image
p
.02381 .13244 translate
.95238 .05886 scale
4 string
4 1 8 [4 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFCF4EFE
pop
P
% End of image
% Start of gray image
p
.02381 .1913 translate
.95238 .05886 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFDF84FFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .25016 translate
.95238 .05886 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFE8AAFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .05886 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEC8FEFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .36788 translate
.95238 .05886 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF1E1FEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .42674 translate
.95238 .05886 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6FCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .4856 translate
.95238 .05886 scale
256 string
256 1 8 [256 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .54446 translate
.95238 .05886 scale
512 string
512 1 8 [512 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
We observe that there are only about a dozen or so coefficients \
that are substantially different from zero and that they are concentrated \
around the shock center. We now sort the coefficients according to decreasing \
magnitude and see how they decay. \
\>", "Text",
  CellTags->{"S2.1.1", "1.21"}],

Cell[TextData[{
  "We flatten ",
  StyleBox["wtdata", "MR"],
  " first, and then sort it according to the absolute value."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.22"}],

Cell["Reverse[Sort[Abs[Flatten[wtdata]]]];", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.1"],

Cell["The first 50 largest coefficients are plotted.", "MathCaption",
  CellTags->{"S2.1.1", "1.23"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Take[%, 50],
PlotLabel -> \"decay of wavelet coefficients\"]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 0.136455 [
[.21429 .00222 -6 -9 ]
[.21429 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.59524 .00222 -6 -9 ]
[.59524 .00222 6 0 ]
[.78571 .00222 -6 -9 ]
[.78571 .00222 6 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .15117 -6 -4.5 ]
[.01131 .15117 0 4.5 ]
[.01131 .28763 -6 -4.5 ]
[.01131 .28763 0 4.5 ]
[.01131 .42408 -6 -4.5 ]
[.01131 .42408 0 4.5 ]
[.01131 .56054 -6 -4.5 ]
[.01131 .56054 0 4.5 ]
[.5 .63053 -87 0 ]
[.5 .63053 87 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(10)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(20)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(30)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(40)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(50)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .15117 m
.03006 .15117 L
s
[(1)] .01131 .15117 1 0 Mshowa
.02381 .28763 m
.03006 .28763 L
s
[(2)] .01131 .28763 1 0 Mshowa
.02381 .42408 m
.03006 .42408 L
s
[(3)] .01131 .42408 1 0 Mshowa
.02381 .56054 m
.03006 .56054 L
s
[(4)] .01131 .56054 1 0 Mshowa
.125 Mabswid
.02381 .04201 m
.02756 .04201 L
s
.02381 .0693 m
.02756 .0693 L
s
.02381 .09659 m
.02756 .09659 L
s
.02381 .12388 m
.02756 .12388 L
s
.02381 .17846 m
.02756 .17846 L
s
.02381 .20575 m
.02756 .20575 L
s
.02381 .23304 m
.02756 .23304 L
s
.02381 .26033 m
.02756 .26033 L
s
.02381 .31492 m
.02756 .31492 L
s
.02381 .34221 m
.02756 .34221 L
s
.02381 .3695 m
.02756 .3695 L
s
.02381 .39679 m
.02756 .39679 L
s
.02381 .45137 m
.02756 .45137 L
s
.02381 .47866 m
.02756 .47866 L
s
.02381 .50595 m
.02756 .50595 L
s
.02381 .53325 m
.02756 .53325 L
s
.02381 .58783 m
.02756 .58783 L
s
.02381 .61512 m
.02756 .61512 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(decay of wavelet coefficients)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.11905 .61426 Mdot
.1381 .42781 Mdot
.15714 .35806 Mdot
.17619 .28522 Mdot
.19524 .25045 Mdot
.21429 .17423 Mdot
.23333 .16197 Mdot
.25238 .12685 Mdot
.27143 .09946 Mdot
.29048 .08401 Mdot
.30952 .0627 Mdot
.32857 .06055 Mdot
.34762 .03391 Mdot
.36667 .03265 Mdot
.38571 .03073 Mdot
.40476 .0244 Mdot
.42381 .02187 Mdot
.44286 .01957 Mdot
.4619 .01894 Mdot
.48095 .0188 Mdot
.5 .01867 Mdot
.51905 .01859 Mdot
.5381 .01816 Mdot
.55714 .0181 Mdot
.57619 .01777 Mdot
.59524 .01768 Mdot
.61429 .01761 Mdot
.63333 .01647 Mdot
.65238 .01624 Mdot
.67143 .01614 Mdot
.69048 .01601 Mdot
.70952 .01596 Mdot
.72857 .01549 Mdot
.74762 .01533 Mdot
.76667 .01532 Mdot
.78571 .01526 Mdot
.80476 .01524 Mdot
.82381 .0152 Mdot
.84286 .01515 Mdot
.8619 .01513 Mdot
.88095 .01508 Mdot
.9 .01507 Mdot
.91905 .01504 Mdot
.9381 .015 Mdot
.95714 .015 Mdot
.97619 .01499 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "This extracts the absolute value of the ",
  Cell[BoxData[
      \(TraditionalForm\`50\^th\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " largest coefficient."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.24"}],

Cell[CellGroupData[{

Cell["%%[[50]]", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(0.0020296388635389162`\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "Alternatively, we can look at how the energy of the system is distributed. \
The energy associated with a mode or a basis function is defined to be the \
squared modulus of the corresponding coefficient. In the case of Burgers \
equation, the square of the velocity is proportional to the kinetic energy. \
So instead of sorting the coefficients, we can sort the square of the \
coefficients. We define a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"E", \((n)\), "=", 
          UnderoverscriptBox["\[Sum]", \(i = 1\), "n",
            LimitsPositioning->True], "\[VerticalSeparator]", \(c\_i\), 
          \( \[VerticalSeparator] \^2\)}], TraditionalForm]], "InlineFormula",
    
    CellTags->"S2.1.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c\_i \[VerticalSeparator]  \[GreaterEqual]  
        \[VerticalSeparator] c\_\(i + 1\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  ", which we call \"cumulative energy\", that gives the energy in the modes \
with the first ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " largest coefficients. ",
  StyleBox["CumulativeEnergy[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox["]", "MR"],
  " gives the list ",
  Cell[BoxData[
      \(TraditionalForm\`{E \((1)\), E \((2)\), \[Ellipsis], E \((N)\)}\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the length of ",
  StyleBox["coefs", "TI"],
  " and ",
  StyleBox["CumulativeEnergy[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " gives ",
  Cell[BoxData[
      \(TraditionalForm\`{E \((1)\), E \((2)\), \[Ellipsis], E \((n)\)}\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  "."
}], "Text",
  CellTags->{"S2.1.1", "1.25"}],

Cell[TextData[{
  "We compute the cumulative energy of ",
  StyleBox["wtdata", "MR"],
  " normalized to 1."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.26"}],

Cell["\<\
e = CumulativeEnergy[wtdata]/
(Flatten[wtdata].Flatten[wtdata]);\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
We see that the energy of the system is highly concentrated in \
roughly the first dozen \"modes\".\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.27"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Take[e, 40], PlotRange -> All,
PlotJoined -> True, PlotLabel -> \"cumulative energy\"]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000610501 0.02442 -0.262394 0.865713 [
[.24359 .59082 -6 -9 ]
[.24359 .59082 6 0 ]
[.48779 .59082 -6 -9 ]
[.48779 .59082 6 0 ]
[.73199 .59082 -6 -9 ]
[.73199 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[-0.01311 .08389 -18 -4.5 ]
[-0.01311 .08389 0 4.5 ]
[-0.01311 .17046 -18 -4.5 ]
[-0.01311 .17046 0 4.5 ]
[-0.01311 .25703 -18 -4.5 ]
[-0.01311 .25703 0 4.5 ]
[-0.01311 .34361 -18 -4.5 ]
[-0.01311 .34361 0 4.5 ]
[-0.01311 .43018 -18 -4.5 ]
[-0.01311 .43018 0 4.5 ]
[-0.01311 .51675 -18 -4.5 ]
[-0.01311 .51675 0 4.5 ]
[.5 .63053 -51 0 ]
[.5 .63053 51 9 ]
[ -0.00061 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24359 .60332 m
.24359 .60957 L
s
[(10)] .24359 .59082 0 1 Mshowa
.48779 .60332 m
.48779 .60957 L
s
[(20)] .48779 .59082 0 1 Mshowa
.73199 .60332 m
.73199 .60957 L
s
[(30)] .73199 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(40)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.04823 .60332 m
.04823 .60707 L
s
.09707 .60332 m
.09707 .60707 L
s
.14591 .60332 m
.14591 .60707 L
s
.19475 .60332 m
.19475 .60707 L
s
.29243 .60332 m
.29243 .60707 L
s
.34127 .60332 m
.34127 .60707 L
s
.39011 .60332 m
.39011 .60707 L
s
.43895 .60332 m
.43895 .60707 L
s
.53663 .60332 m
.53663 .60707 L
s
.58547 .60332 m
.58547 .60707 L
s
.63431 .60332 m
.63431 .60707 L
s
.68315 .60332 m
.68315 .60707 L
s
.78083 .60332 m
.78083 .60707 L
s
.82967 .60332 m
.82967 .60707 L
s
.87851 .60332 m
.87851 .60707 L
s
.92735 .60332 m
.92735 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
-0.00061 .08389 m
.00564 .08389 L
s
[(0.4)] -0.01311 .08389 1 0 Mshowa
-0.00061 .17046 m
.00564 .17046 L
s
[(0.5)] -0.01311 .17046 1 0 Mshowa
-0.00061 .25703 m
.00564 .25703 L
s
[(0.6)] -0.01311 .25703 1 0 Mshowa
-0.00061 .34361 m
.00564 .34361 L
s
[(0.7)] -0.01311 .34361 1 0 Mshowa
-0.00061 .43018 m
.00564 .43018 L
s
[(0.8)] -0.01311 .43018 1 0 Mshowa
-0.00061 .51675 m
.00564 .51675 L
s
[(0.9)] -0.01311 .51675 1 0 Mshowa
.125 Mabswid
-0.00061 .01463 m
.00314 .01463 L
s
-0.00061 .03195 m
.00314 .03195 L
s
-0.00061 .04926 m
.00314 .04926 L
s
-0.00061 .06658 m
.00314 .06658 L
s
-0.00061 .10121 m
.00314 .10121 L
s
-0.00061 .11852 m
.00314 .11852 L
s
-0.00061 .13583 m
.00314 .13583 L
s
-0.00061 .15315 m
.00314 .15315 L
s
-0.00061 .18778 m
.00314 .18778 L
s
-0.00061 .20509 m
.00314 .20509 L
s
-0.00061 .22241 m
.00314 .22241 L
s
-0.00061 .23972 m
.00314 .23972 L
s
-0.00061 .27435 m
.00314 .27435 L
s
-0.00061 .29166 m
.00314 .29166 L
s
-0.00061 .30898 m
.00314 .30898 L
s
-0.00061 .32629 m
.00314 .32629 L
s
-0.00061 .36092 m
.00314 .36092 L
s
-0.00061 .37823 m
.00314 .37823 L
s
-0.00061 .39555 m
.00314 .39555 L
s
-0.00061 .41286 m
.00314 .41286 L
s
-0.00061 .44749 m
.00314 .44749 L
s
-0.00061 .46481 m
.00314 .46481 L
s
-0.00061 .48212 m
.00314 .48212 L
s
-0.00061 .49943 m
.00314 .49943 L
s
-0.00061 .53406 m
.00314 .53406 L
s
-0.00061 .55138 m
.00314 .55138 L
s
-0.00061 .56869 m
.00314 .56869 L
s
-0.00061 .586 m
.00314 .586 L
s
.25 Mabswid
-0.00061 0 m
-0.00061 .61803 L
s
[(cumulative energy)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.04823 .16591 L
.07265 .3171 L
.09707 .45013 L
.12149 .5146 L
.14591 .54521 L
.17033 .56636 L
.19475 .57948 L
.21917 .58945 L
.24359 .59401 L
.26801 .5979 L
.29243 .60016 L
.31685 .60144 L
.34127 .60231 L
.36569 .60272 L
.39011 .6031 L
.41453 .60316 L
.43895 .60322 L
.46337 .60327 L
.48779 .60328 L
.51221 .60329 L
.53663 .6033 L
.56105 .6033 L
.58547 .6033 L
.60989 .60331 L
.63431 .60331 L
.65873 .60331 L
.68315 .60331 L
.70757 .60331 L
.73199 .60332 L
.75641 .60332 L
.78083 .60332 L
.80525 .60332 L
.82967 .60332 L
.85409 .60332 L
.87851 .60332 L
.90293 .60332 L
.92735 .60332 L
.95177 .60332 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
In fact, 99.9% of the total energy is concentrated in the first 14 \
coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.28"}],

Cell[CellGroupData[{

Cell["Length[Select[Take[e, 20], # <= 0.999&]]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(14\)], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["This is the energy contained in the first 15 coefficients.", 
  "MathCaption",
  CellTags->{"S2.1.1", "1.29"}],

Cell[CellGroupData[{

Cell["e[[15]]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(0.999306764743201192`\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "Now we can choose to compress the signal by setting the coefficients of \
modes with insignificant energy to zero. There are usually two ways to \
specify how much we want to compress. One way is to specify the number of \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " to retain, that is, fix the compression ratio ",
  Cell[BoxData[
      \(TraditionalForm\`N/M\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the total number of coefficients before compression. Alternatively, we \
can also fix the threshold ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", so that any coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`c\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is set to zero if ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c \[VerticalSeparator]  < \[Tau]\)\)], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  ". The function ",
  StyleBox["Compress[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["M", "TI"],
  StyleBox["]", "MR"],
  " compresses ",
  StyleBox["data", "TI"],
  " with a compression ratio ",
  Cell[BoxData[
      \(TraditionalForm\`N/M\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " and ",
  StyleBox["Compress[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["tau", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["Threshold", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True]", "MR"],
  " compresses ",
  StyleBox["data", "TI"],
  " using the threshold ",
  StyleBox["tau", "TI"],
  ". "
}], "Text",
  CellTags->{"S2.1.1", "1.30"}],

Cell["\<\
We compress the wavelet coefficients by keeping only the first 20 \
largest ones.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.31"}],

Cell["Compress[wtdata, 20];", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S2.1.1"],

Cell["The compressed data are then transformed back.", "MathCaption",
  CellTags->{"S2.1.1", "1.32"}],

Cell["newdata = InverseWaveletTransform[%, filter];", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
We see that it reproduces the shock structure rather \
faithfully.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.33"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[newdata, AxesLabel -> {\"x\", \"\"},
PlotLabel -> \"reconstruction
of u(x) from 20 coefficients\"]\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.310841 0.347895 [
[.20982 .29834 -9 -9 ]
[.20982 .29834 9 0 ]
[.39583 .29834 -9 -9 ]
[.39583 .29834 9 0 ]
[.58185 .29834 -9 -9 ]
[.58185 .29834 9 0 ]
[.76786 .29834 -9 -9 ]
[.76786 .29834 9 0 ]
[.95387 .29834 -12 -9 ]
[.95387 .29834 12 0 ]
[1.025 .31084 0 -4.5 ]
[1.025 .31084 6 4.5 ]
[.01131 .04992 -30 -4.5 ]
[.01131 .04992 0 4.5 ]
[.01131 .13689 -24 -4.5 ]
[.01131 .13689 0 4.5 ]
[.01131 .22387 -30 -4.5 ]
[.01131 .22387 0 4.5 ]
[.01131 .39781 -24 -4.5 ]
[.01131 .39781 0 4.5 ]
[.01131 .48479 -18 -4.5 ]
[.01131 .48479 0 4.5 ]
[.01131 .57176 -24 -4.5 ]
[.01131 .57176 0 4.5 ]
[.5 .63053 -129 0 ]
[.5 .63053 129 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .31084 m
.20982 .31709 L
s
[(200)] .20982 .29834 0 1 Mshowa
.39583 .31084 m
.39583 .31709 L
s
[(400)] .39583 .29834 0 1 Mshowa
.58185 .31084 m
.58185 .31709 L
s
[(600)] .58185 .29834 0 1 Mshowa
.76786 .31084 m
.76786 .31709 L
s
[(800)] .76786 .29834 0 1 Mshowa
.95387 .31084 m
.95387 .31709 L
s
[(1000)] .95387 .29834 0 1 Mshowa
.125 Mabswid
.07031 .31084 m
.07031 .31459 L
s
.11682 .31084 m
.11682 .31459 L
s
.16332 .31084 m
.16332 .31459 L
s
.25632 .31084 m
.25632 .31459 L
s
.30283 .31084 m
.30283 .31459 L
s
.34933 .31084 m
.34933 .31459 L
s
.44234 .31084 m
.44234 .31459 L
s
.48884 .31084 m
.48884 .31459 L
s
.53534 .31084 m
.53534 .31459 L
s
.62835 .31084 m
.62835 .31459 L
s
.67485 .31084 m
.67485 .31459 L
s
.72135 .31084 m
.72135 .31459 L
s
.81436 .31084 m
.81436 .31459 L
s
.86086 .31084 m
.86086 .31459 L
s
.90737 .31084 m
.90737 .31459 L
s
.25 Mabswid
0 .31084 m
1 .31084 L
s
[(x)] 1.025 .31084 -1 0 Mshowa
.02381 .04992 m
.03006 .04992 L
s
[(-0.75)] .01131 .04992 1 0 Mshowa
.02381 .13689 m
.03006 .13689 L
s
[(-0.5)] .01131 .13689 1 0 Mshowa
.02381 .22387 m
.03006 .22387 L
s
[(-0.25)] .01131 .22387 1 0 Mshowa
.02381 .39781 m
.03006 .39781 L
s
[(0.25)] .01131 .39781 1 0 Mshowa
.02381 .48479 m
.03006 .48479 L
s
[(0.5)] .01131 .48479 1 0 Mshowa
.02381 .57176 m
.03006 .57176 L
s
[(0.75)] .01131 .57176 1 0 Mshowa
.125 Mabswid
.02381 .06731 m
.02756 .06731 L
s
.02381 .08471 m
.02756 .08471 L
s
.02381 .1021 m
.02756 .1021 L
s
.02381 .1195 m
.02756 .1195 L
s
.02381 .15429 m
.02756 .15429 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .18908 m
.02756 .18908 L
s
.02381 .20647 m
.02756 .20647 L
s
.02381 .24126 m
.02756 .24126 L
s
.02381 .25866 m
.02756 .25866 L
s
.02381 .27605 m
.02756 .27605 L
s
.02381 .29345 m
.02756 .29345 L
s
.02381 .32824 m
.02756 .32824 L
s
.02381 .34563 m
.02756 .34563 L
s
.02381 .36303 m
.02756 .36303 L
s
.02381 .38042 m
.02756 .38042 L
s
.02381 .41521 m
.02756 .41521 L
s
.02381 .4326 m
.02756 .4326 L
s
.02381 .45 m
.02756 .45 L
s
.02381 .46739 m
.02756 .46739 L
s
.02381 .50218 m
.02756 .50218 L
s
.02381 .51958 m
.02756 .51958 L
s
.02381 .53697 m
.02756 .53697 L
s
.02381 .55437 m
.02756 .55437 L
s
.02381 .03253 m
.02756 .03253 L
s
.02381 .01513 m
.02756 .01513 L
s
.02381 .58916 m
.02756 .58916 L
s
.02381 .60655 m
.02756 .60655 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(reconstruction of u\\(x\\) from 20 coefficients)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02474 .3094 Mdot
.02567 .31015 Mdot
.0266 .31085 Mdot
.02753 .31155 Mdot
.02846 .31221 Mdot
.02939 .31287 Mdot
.03032 .31356 Mdot
.03125 .31423 Mdot
.03218 .31486 Mdot
.03311 .31549 Mdot
.03404 .31615 Mdot
.03497 .3168 Mdot
.0359 .31746 Mdot
.03683 .31812 Mdot
.03776 .31877 Mdot
.03869 .31943 Mdot
.03962 .32003 Mdot
.04055 .32065 Mdot
.04148 .32128 Mdot
.04241 .3219 Mdot
.04334 .32255 Mdot
.04427 .32318 Mdot
.0452 .32382 Mdot
.04613 .32445 Mdot
.04706 .3251 Mdot
.04799 .32575 Mdot
.04892 .32639 Mdot
.04985 .32703 Mdot
.05078 .32767 Mdot
.05171 .32831 Mdot
.05264 .32895 Mdot
.05357 .32959 Mdot
.0545 .33017 Mdot
.05543 .33077 Mdot
.05636 .33139 Mdot
.05729 .332 Mdot
.05822 .33262 Mdot
.05915 .33324 Mdot
.06008 .33386 Mdot
.06101 .33448 Mdot
.06194 .33511 Mdot
.06287 .33574 Mdot
.0638 .33637 Mdot
.06473 .337 Mdot
.06566 .33762 Mdot
.06659 .33824 Mdot
.06752 .33887 Mdot
.06845 .33949 Mdot
.06938 .34013 Mdot
.07031 .34077 Mdot
.07124 .3414 Mdot
.07217 .34203 Mdot
.0731 .34266 Mdot
.07403 .34329 Mdot
.07496 .34392 Mdot
.07589 .34455 Mdot
.07682 .34517 Mdot
.07775 .3458 Mdot
.07868 .34643 Mdot
.07961 .34706 Mdot
.08054 .34769 Mdot
.08147 .34832 Mdot
.0824 .34894 Mdot
.08333 .34957 Mdot
.08426 .35015 Mdot
.08519 .35073 Mdot
.08612 .35134 Mdot
.08705 .35193 Mdot
.08798 .35255 Mdot
.08891 .35316 Mdot
.08984 .35376 Mdot
.09077 .35437 Mdot
.0917 .35499 Mdot
.09263 .35561 Mdot
.09356 .35622 Mdot
.09449 .35684 Mdot
.09542 .35745 Mdot
.09635 .35806 Mdot
.09728 .35867 Mdot
.09821 .35929 Mdot
.09914 .35991 Mdot
.10007 .36054 Mdot
.101 .36116 Mdot
.10193 .36178 Mdot
.10286 .36239 Mdot
.10379 .36301 Mdot
.10472 .36363 Mdot
.10565 .36425 Mdot
.10658 .36486 Mdot
.10751 .36548 Mdot
.10844 .36609 Mdot
.10938 .36671 Mdot
.11031 .36733 Mdot
.11124 .36795 Mdot
.11217 .36856 Mdot
.1131 .36918 Mdot
.11403 .36981 Mdot
.11496 .37044 Mdot
.11589 .37106 Mdot
.11682 .37169 Mdot
.11775 .37231 Mdot
.11868 .37293 Mdot
.11961 .37355 Mdot
.12054 .37418 Mdot
.12147 .3748 Mdot
.1224 .37542 Mdot
.12333 .37604 Mdot
.12426 .37666 Mdot
.12519 .37728 Mdot
.12612 .3779 Mdot
.12705 .37852 Mdot
.12798 .37914 Mdot
.12891 .37976 Mdot
.12984 .38038 Mdot
.13077 .381 Mdot
.1317 .38162 Mdot
.13263 .38224 Mdot
.13356 .38286 Mdot
.13449 .38348 Mdot
.13542 .38409 Mdot
.13635 .38472 Mdot
.13728 .38534 Mdot
.13821 .38596 Mdot
.13914 .38658 Mdot
.14007 .3872 Mdot
.141 .38782 Mdot
.14193 .38844 Mdot
.14286 .38906 Mdot
.14379 .38962 Mdot
.14472 .3902 Mdot
.14565 .39079 Mdot
.14658 .39138 Mdot
.14751 .39199 Mdot
.14844 .39259 Mdot
.14937 .39319 Mdot
.1503 .39378 Mdot
.15123 .3944 Mdot
.15216 .39501 Mdot
.15309 .39561 Mdot
.15402 .39622 Mdot
.15495 .39682 Mdot
.15588 .39742 Mdot
.15681 .39803 Mdot
.15774 .39863 Mdot
.15867 .39925 Mdot
.1596 .39987 Mdot
.16053 .40048 Mdot
.16146 .40109 Mdot
.16239 .4017 Mdot
.16332 .40231 Mdot
.16425 .40292 Mdot
.16518 .40353 Mdot
.16611 .40413 Mdot
.16704 .40474 Mdot
.16797 .40535 Mdot
.1689 .40595 Mdot
.16983 .40656 Mdot
.17076 .40717 Mdot
.17169 .40778 Mdot
.17262 .40839 Mdot
.17355 .40901 Mdot
.17448 .40963 Mdot
.17541 .41025 Mdot
.17634 .41086 Mdot
.17727 .41147 Mdot
.1782 .41209 Mdot
.17913 .4127 Mdot
.18006 .41332 Mdot
.18099 .41393 Mdot
.18192 .41454 Mdot
.18285 .41515 Mdot
.18378 .41576 Mdot
.18471 .41637 Mdot
.18564 .41699 Mdot
.18657 .4176 Mdot
.1875 .41821 Mdot
.18843 .41882 Mdot
.18936 .41943 Mdot
.19029 .42004 Mdot
.19122 .42065 Mdot
.19215 .42126 Mdot
.19308 .42187 Mdot
.19401 .42249 Mdot
.19494 .4231 Mdot
.19587 .42371 Mdot
.1968 .42432 Mdot
.19773 .42493 Mdot
.19866 .42554 Mdot
.19959 .42615 Mdot
.20052 .42677 Mdot
.20145 .42738 Mdot
.20238 .42799 Mdot
.20331 .42862 Mdot
.20424 .42924 Mdot
.20517 .42986 Mdot
.2061 .43048 Mdot
.20703 .43109 Mdot
.20796 .43171 Mdot
.20889 .43233 Mdot
.20982 .43294 Mdot
.21075 .43356 Mdot
.21168 .43417 Mdot
.21261 .43479 Mdot
.21354 .4354 Mdot
.21447 .43602 Mdot
.2154 .43663 Mdot
.21633 .43725 Mdot
.21726 .43786 Mdot
.21819 .43848 Mdot
.21912 .43909 Mdot
.22005 .4397 Mdot
.22098 .44032 Mdot
.22191 .44093 Mdot
.22284 .44155 Mdot
.22377 .44216 Mdot
.2247 .44277 Mdot
.22563 .44339 Mdot
.22656 .444 Mdot
.22749 .44462 Mdot
.22842 .44523 Mdot
.22935 .44585 Mdot
.23028 .44646 Mdot
.23121 .44708 Mdot
.23214 .44769 Mdot
.23307 .4483 Mdot
.234 .44891 Mdot
.23493 .44953 Mdot
.23586 .45014 Mdot
.23679 .45075 Mdot
.23772 .45137 Mdot
.23865 .45198 Mdot
.23958 .45259 Mdot
.24051 .45321 Mdot
.24144 .45382 Mdot
.24237 .45443 Mdot
.2433 .45505 Mdot
.24423 .45566 Mdot
.24516 .45627 Mdot
.24609 .45689 Mdot
.24702 .4575 Mdot
.24795 .45811 Mdot
.24888 .45873 Mdot
.24981 .45934 Mdot
.25074 .45996 Mdot
.25167 .46057 Mdot
.2526 .46118 Mdot
.25353 .4618 Mdot
.25446 .46241 Mdot
.25539 .46302 Mdot
.25632 .46364 Mdot
.25725 .46425 Mdot
.25818 .46487 Mdot
.25911 .46548 Mdot
.26004 .46609 Mdot
.26097 .46671 Mdot
.2619 .46732 Mdot
.26283 .46772 Mdot
.26376 .46817 Mdot
.26469 .46868 Mdot
.26563 .46918 Mdot
.26656 .46973 Mdot
.26749 .47027 Mdot
.26842 .47079 Mdot
.26935 .47132 Mdot
.27028 .47191 Mdot
.27121 .47248 Mdot
.27214 .47303 Mdot
.27307 .47359 Mdot
.274 .47414 Mdot
.27493 .47468 Mdot
.27586 .47524 Mdot
.27679 .47579 Mdot
.27772 .4764 Mdot
.27865 .47699 Mdot
.27958 .47757 Mdot
.28051 .47815 Mdot
.28144 .47872 Mdot
.28237 .47929 Mdot
.2833 .47986 Mdot
.28423 .48044 Mdot
.28516 .48099 Mdot
.28609 .48156 Mdot
.28702 .48212 Mdot
.28795 .48269 Mdot
.28888 .48326 Mdot
.28981 .48383 Mdot
.29074 .48439 Mdot
.29167 .48496 Mdot
.2926 .48559 Mdot
.29353 .4862 Mdot
.29446 .48679 Mdot
.29539 .48739 Mdot
.29632 .48798 Mdot
.29725 .48856 Mdot
.29818 .48916 Mdot
.29911 .48975 Mdot
.30004 .49032 Mdot
.30097 .4909 Mdot
.3019 .49148 Mdot
.30283 .49207 Mdot
.30376 .49265 Mdot
.30469 .49324 Mdot
.30562 .49382 Mdot
.30655 .49441 Mdot
.30748 .49498 Mdot
.30841 .49555 Mdot
.30934 .49613 Mdot
.31027 .4967 Mdot
.3112 .49728 Mdot
.31213 .49786 Mdot
.31306 .49844 Mdot
.31399 .49902 Mdot
.31492 .4996 Mdot
.31585 .50018 Mdot
.31678 .50076 Mdot
.31771 .50134 Mdot
.31864 .50192 Mdot
.31957 .5025 Mdot
.3205 .50308 Mdot
.32143 .50366 Mdot
.32236 .5043 Mdot
.32329 .50492 Mdot
.32422 .50553 Mdot
.32515 .50614 Mdot
.32608 .50674 Mdot
.32701 .50734 Mdot
.32794 .50794 Mdot
.32887 .50855 Mdot
.3298 .50913 Mdot
.33073 .50972 Mdot
.33166 .51032 Mdot
.33259 .51091 Mdot
.33352 .51151 Mdot
.33445 .51211 Mdot
.33538 .51271 Mdot
.33631 .5133 Mdot
.33724 .51389 Mdot
.33817 .51447 Mdot
.3391 .51506 Mdot
.34003 .51565 Mdot
.34096 .51624 Mdot
.34189 .51683 Mdot
.34282 .51742 Mdot
.34375 .51801 Mdot
.34468 .51861 Mdot
.34561 .5192 Mdot
.34654 .5198 Mdot
.34747 .52039 Mdot
.3484 .52098 Mdot
.34933 .52157 Mdot
.35026 .52216 Mdot
.35119 .52276 Mdot
.35212 .52333 Mdot
.35305 .52391 Mdot
.35398 .5245 Mdot
.35491 .52508 Mdot
.35584 .52567 Mdot
.35677 .52626 Mdot
.3577 .52684 Mdot
.35863 .52743 Mdot
.35956 .52802 Mdot
.36049 .52861 Mdot
.36142 .5292 Mdot
.36235 .52979 Mdot
.36328 .53037 Mdot
.36421 .53096 Mdot
.36514 .53155 Mdot
.36607 .53214 Mdot
.367 .53273 Mdot
.36793 .53332 Mdot
.36886 .53391 Mdot
.36979 .5345 Mdot
.37072 .53509 Mdot
.37165 .53568 Mdot
.37258 .53627 Mdot
.37351 .53686 Mdot
.37444 .53745 Mdot
.37537 .53803 Mdot
.3763 .53862 Mdot
.37723 .53921 Mdot
.37816 .5398 Mdot
.37909 .54039 Mdot
.38002 .54098 Mdot
.38095 .54157 Mdot
.38188 .54191 Mdot
.38281 .54232 Mdot
.38374 .54279 Mdot
.38467 .54325 Mdot
.3856 .54378 Mdot
.38653 .54428 Mdot
.38746 .54477 Mdot
.38839 .54526 Mdot
.38932 .54582 Mdot
.39025 .54636 Mdot
.39118 .54688 Mdot
.39211 .54741 Mdot
.39304 .54792 Mdot
.39397 .54844 Mdot
.3949 .54896 Mdot
.39583 .54947 Mdot
.39676 .55006 Mdot
.39769 .55063 Mdot
.39862 .55117 Mdot
.39955 .55173 Mdot
.40048 .55226 Mdot
.40141 .5528 Mdot
.40234 .55335 Mdot
.40327 .55389 Mdot
.4042 .55442 Mdot
.40513 .55495 Mdot
.40606 .55549 Mdot
.40699 .55602 Mdot
.40792 .55656 Mdot
.40885 .5571 Mdot
.40978 .55764 Mdot
.41071 .55817 Mdot
.41164 .55878 Mdot
.41257 .55936 Mdot
.4135 .55993 Mdot
.41443 .5605 Mdot
.41536 .56106 Mdot
.41629 .56162 Mdot
.41722 .56218 Mdot
.41815 .56275 Mdot
.41908 .56329 Mdot
.42001 .56384 Mdot
.42094 .5644 Mdot
.42188 .56495 Mdot
.42281 .56551 Mdot
.42374 .56607 Mdot
.42467 .56662 Mdot
.4256 .56718 Mdot
.42653 .56772 Mdot
.42746 .56826 Mdot
.42839 .56881 Mdot
.42932 .56936 Mdot
.43025 .56991 Mdot
.43118 .57046 Mdot
.43211 .57101 Mdot
.43304 .57156 Mdot
.43397 .57211 Mdot
.4349 .57266 Mdot
.43583 .57321 Mdot
.43676 .57377 Mdot
.43769 .57432 Mdot
.43862 .57487 Mdot
.43955 .57542 Mdot
.44048 .57597 Mdot
.44141 .57638 Mdot
.44234 .57683 Mdot
.44327 .57731 Mdot
.4442 .57779 Mdot
.44513 .5783 Mdot
.44606 .5788 Mdot
.44699 .5793 Mdot
.44792 .57979 Mdot
.44885 .58033 Mdot
.44978 .58085 Mdot
.45071 .58136 Mdot
.45164 .58188 Mdot
.45257 .58238 Mdot
.4535 .58289 Mdot
.45443 .5834 Mdot
.45536 .58392 Mdot
.45629 .58446 Mdot
.45722 .585 Mdot
.45815 .58553 Mdot
.45908 .58606 Mdot
.46001 .58658 Mdot
.46094 .5871 Mdot
.46187 .58763 Mdot
.4628 .58816 Mdot
.46373 .58867 Mdot
.46466 .58919 Mdot
.46559 .58971 Mdot
.46652 .59023 Mdot
.46745 .59075 Mdot
.46838 .59128 Mdot
.46931 .5918 Mdot
.47024 .59232 Mdot
.47117 .59278 Mdot
.4721 .59325 Mdot
.47303 .59375 Mdot
.47396 .59423 Mdot
.47489 .59474 Mdot
.47582 .59524 Mdot
.47675 .59574 Mdot
.47768 .59623 Mdot
.47861 .59675 Mdot
.47954 .59726 Mdot
.48047 .59776 Mdot
.4814 .59827 Mdot
.48233 .59877 Mdot
.48326 .59927 Mdot
.48419 .59978 Mdot
.48512 .60028 Mdot
.48605 .60054 Mdot
.48698 .60087 Mdot
.48791 .60127 Mdot
.48884 .60164 Mdot
.48977 .60208 Mdot
.4907 .6025 Mdot
.49163 .60291 Mdot
.49256 .60332 Mdot
.49349 .59503 Mdot
.49442 .58907 Mdot
.49535 .58545 Mdot
.49628 .5812 Mdot
.49721 .54669 Mdot
.49814 .52029 Mdot
.49907 .45305 Mdot
.5 .39675 Mdot
.50093 .31179 Mdot
.50186 .23452 Mdot
.50279 .16492 Mdot
.50372 .09326 Mdot
.50465 .07504 Mdot
.50558 .0425 Mdot
.50651 .03648 Mdot
.50744 .02336 Mdot
.50837 .02628 Mdot
.5093 .02491 Mdot
.51023 .01924 Mdot
.51116 .01472 Mdot
.51209 .01845 Mdot
.51302 .01997 Mdot
.51395 .01928 Mdot
.51488 .01918 Mdot
.51581 .02021 Mdot
.51674 .02094 Mdot
.51767 .02137 Mdot
.5186 .02188 Mdot
.51953 .02208 Mdot
.52046 .02237 Mdot
.52139 .02273 Mdot
.52232 .02308 Mdot
.52325 .02373 Mdot
.52418 .0243 Mdot
.52511 .02479 Mdot
.52604 .0253 Mdot
.52697 .02573 Mdot
.5279 .02618 Mdot
.52883 .02665 Mdot
.52976 .02712 Mdot
.53069 .02841 Mdot
.53162 .02948 Mdot
.53255 .03033 Mdot
.53348 .03123 Mdot
.53441 .03192 Mdot
.53534 .03267 Mdot
.53627 .03347 Mdot
.5372 .03426 Mdot
.53813 .03483 Mdot
.53906 .03546 Mdot
.53999 .03614 Mdot
.54092 .03681 Mdot
.54185 .03754 Mdot
.54278 .03826 Mdot
.54371 .03896 Mdot
.54464 .03966 Mdot
.54557 .0388 Mdot
.5465 .03835 Mdot
.54743 .03833 Mdot
.54836 .03819 Mdot
.54929 .03848 Mdot
.55022 .03865 Mdot
.55115 .03871 Mdot
.55208 .0388 Mdot
.55301 .0393 Mdot
.55394 .0397 Mdot
.55487 .03998 Mdot
.5558 .0403 Mdot
.55673 .0405 Mdot
.55766 .04073 Mdot
.55859 .04099 Mdot
.55952 .04124 Mdot
.56045 .04301 Mdot
.56138 .04437 Mdot
.56231 .04533 Mdot
.56324 .04639 Mdot
.56417 .04705 Mdot
.5651 .04782 Mdot
.56603 .04869 Mdot
.56696 .04954 Mdot
.56789 .04998 Mdot
.56882 .05053 Mdot
.56975 .05119 Mdot
.57068 .05182 Mdot
.57161 .05256 Mdot
.57254 .05327 Mdot
.57347 .05395 Mdot
.5744 .05463 Mdot
.57533 .05492 Mdot
.57626 .05531 Mdot
.57719 .05581 Mdot
.57813 .05628 Mdot
.57906 .05686 Mdot
.57999 .05741 Mdot
.58092 .05793 Mdot
.58185 .05846 Mdot
.58278 .05909 Mdot
.58371 .0597 Mdot
.58464 .06028 Mdot
.58557 .06087 Mdot
.5865 .06143 Mdot
.58743 .06199 Mdot
.58836 .06257 Mdot
.58929 .06314 Mdot
.59022 .0633 Mdot
.59115 .06358 Mdot
.59208 .06396 Mdot
.59301 .06432 Mdot
.59394 .06478 Mdot
.59487 .06521 Mdot
.5958 .06562 Mdot
.59673 .06603 Mdot
.59766 .06655 Mdot
.59859 .06704 Mdot
.59952 .0675 Mdot
.60045 .06798 Mdot
.60138 .06842 Mdot
.60231 .06887 Mdot
.60324 .06932 Mdot
.60417 .06978 Mdot
.6051 .07034 Mdot
.60603 .07088 Mdot
.60696 .07138 Mdot
.60789 .07189 Mdot
.60882 .07238 Mdot
.60975 .07287 Mdot
.61068 .07337 Mdot
.61161 .07387 Mdot
.61254 .07434 Mdot
.61347 .07481 Mdot
.6144 .0753 Mdot
.61533 .07578 Mdot
.61626 .07627 Mdot
.61719 .07676 Mdot
.61812 .07724 Mdot
.61905 .07773 Mdot
.61998 .07883 Mdot
.62091 .07977 Mdot
.62184 .08054 Mdot
.62277 .08136 Mdot
.6237 .08201 Mdot
.62463 .0827 Mdot
.62556 .08344 Mdot
.62649 .08417 Mdot
.62742 .08473 Mdot
.62835 .08534 Mdot
.62928 .08599 Mdot
.63021 .08663 Mdot
.63114 .08732 Mdot
.63207 .08799 Mdot
.633 .08865 Mdot
.63393 .08931 Mdot
.63486 .08981 Mdot
.63579 .09035 Mdot
.63672 .09094 Mdot
.63765 .09151 Mdot
.63858 .09213 Mdot
.63951 .09274 Mdot
.64044 .09333 Mdot
.64137 .09393 Mdot
.6423 .09458 Mdot
.64323 .09521 Mdot
.64416 .09583 Mdot
.64509 .09645 Mdot
.64602 .09706 Mdot
.64695 .09767 Mdot
.64788 .09829 Mdot
.64881 .0989 Mdot
.64974 .09935 Mdot
.65067 .09985 Mdot
.6516 .10039 Mdot
.65253 .10092 Mdot
.65346 .10149 Mdot
.65439 .10205 Mdot
.65532 .1026 Mdot
.65625 .10315 Mdot
.65718 .10374 Mdot
.65811 .10432 Mdot
.65904 .1049 Mdot
.65997 .10547 Mdot
.6609 .10603 Mdot
.66183 .1066 Mdot
.66276 .10717 Mdot
.66369 .10774 Mdot
.66462 .10835 Mdot
.66555 .10895 Mdot
.66648 .10954 Mdot
.66741 .11013 Mdot
.66834 .11071 Mdot
.66927 .1113 Mdot
.6702 .11188 Mdot
.67113 .11247 Mdot
.67206 .11304 Mdot
.67299 .11362 Mdot
.67392 .1142 Mdot
.67485 .11478 Mdot
.67578 .11536 Mdot
.67671 .11594 Mdot
.67764 .11652 Mdot
.67857 .1171 Mdot
.6795 .11752 Mdot
.68043 .11798 Mdot
.68136 .11848 Mdot
.68229 .11898 Mdot
.68322 .11951 Mdot
.68415 .12004 Mdot
.68508 .12055 Mdot
.68601 .12107 Mdot
.68694 .12163 Mdot
.68787 .12218 Mdot
.6888 .12271 Mdot
.68973 .12325 Mdot
.69066 .12378 Mdot
.69159 .12431 Mdot
.69252 .12485 Mdot
.69345 .12538 Mdot
.69438 .12596 Mdot
.69531 .12653 Mdot
.69624 .12708 Mdot
.69717 .12764 Mdot
.6981 .12818 Mdot
.69903 .12873 Mdot
.69996 .12928 Mdot
.70089 .12983 Mdot
.70182 .13037 Mdot
.70275 .13091 Mdot
.70368 .13146 Mdot
.70461 .13201 Mdot
.70554 .13255 Mdot
.70647 .1331 Mdot
.7074 .13365 Mdot
.70833 .13419 Mdot
.70926 .13478 Mdot
.71019 .13536 Mdot
.71112 .13593 Mdot
.71205 .1365 Mdot
.71298 .13706 Mdot
.71391 .13762 Mdot
.71484 .13818 Mdot
.71577 .13875 Mdot
.7167 .1393 Mdot
.71763 .13985 Mdot
.71856 .14041 Mdot
.71949 .14097 Mdot
.72042 .14153 Mdot
.72135 .14209 Mdot
.72228 .14265 Mdot
.72321 .14321 Mdot
.72414 .14375 Mdot
.72507 .1443 Mdot
.726 .14486 Mdot
.72693 .14541 Mdot
.72786 .14597 Mdot
.72879 .14652 Mdot
.72972 .14708 Mdot
.73065 .14763 Mdot
.73158 .14819 Mdot
.73251 .14874 Mdot
.73344 .1493 Mdot
.73438 .14986 Mdot
.73531 .15041 Mdot
.73624 .15097 Mdot
.73717 .15152 Mdot
.7381 .15208 Mdot
.73903 .15313 Mdot
.73996 .15405 Mdot
.74089 .15483 Mdot
.74182 .15565 Mdot
.74275 .15634 Mdot
.74368 .15707 Mdot
.74461 .15783 Mdot
.74554 .15858 Mdot
.74647 .15919 Mdot
.7474 .15985 Mdot
.74833 .16053 Mdot
.74926 .16121 Mdot
.75019 .16193 Mdot
.75112 .16263 Mdot
.75205 .16333 Mdot
.75298 .16403 Mdot
.75391 .16459 Mdot
.75484 .16519 Mdot
.75577 .16583 Mdot
.7567 .16646 Mdot
.75763 .16712 Mdot
.75856 .16777 Mdot
.75949 .16841 Mdot
.76042 .16906 Mdot
.76135 .16974 Mdot
.76228 .17041 Mdot
.76321 .17108 Mdot
.76414 .17174 Mdot
.76507 .1724 Mdot
.766 .17305 Mdot
.76693 .17371 Mdot
.76786 .17437 Mdot
.76879 .1749 Mdot
.76972 .17546 Mdot
.77065 .17606 Mdot
.77158 .17665 Mdot
.77251 .17727 Mdot
.77344 .17789 Mdot
.77437 .17849 Mdot
.7753 .1791 Mdot
.77623 .17975 Mdot
.77716 .18038 Mdot
.77809 .181 Mdot
.77902 .18163 Mdot
.77995 .18225 Mdot
.78088 .18287 Mdot
.78181 .18349 Mdot
.78274 .18411 Mdot
.78367 .18477 Mdot
.7846 .18542 Mdot
.78553 .18605 Mdot
.78646 .1867 Mdot
.78739 .18733 Mdot
.78832 .18796 Mdot
.78925 .1886 Mdot
.79018 .18923 Mdot
.79111 .18986 Mdot
.79204 .19049 Mdot
.79297 .19112 Mdot
.7939 .19175 Mdot
.79483 .19238 Mdot
.79576 .19301 Mdot
.79669 .19365 Mdot
.79762 .19428 Mdot
.79855 .19478 Mdot
.79948 .19531 Mdot
.80041 .19588 Mdot
.80134 .19644 Mdot
.80227 .19704 Mdot
.8032 .19763 Mdot
.80413 .1982 Mdot
.80506 .19878 Mdot
.80599 .1994 Mdot
.80692 .2 Mdot
.80785 .2006 Mdot
.80878 .2012 Mdot
.80971 .20179 Mdot
.81064 .20238 Mdot
.81157 .20298 Mdot
.8125 .20357 Mdot
.81343 .2042 Mdot
.81436 .20482 Mdot
.81529 .20543 Mdot
.81622 .20604 Mdot
.81715 .20664 Mdot
.81808 .20725 Mdot
.81901 .20786 Mdot
.81994 .20847 Mdot
.82087 .20906 Mdot
.8218 .20967 Mdot
.82273 .21027 Mdot
.82366 .21087 Mdot
.82459 .21148 Mdot
.82552 .21208 Mdot
.82645 .21268 Mdot
.82738 .21329 Mdot
.82831 .21393 Mdot
.82924 .21456 Mdot
.83017 .21518 Mdot
.8311 .2158 Mdot
.83203 .21642 Mdot
.83296 .21703 Mdot
.83389 .21765 Mdot
.83482 .21827 Mdot
.83575 .21888 Mdot
.83668 .21949 Mdot
.83761 .2201 Mdot
.83854 .22071 Mdot
.83947 .22133 Mdot
.8404 .22194 Mdot
.84133 .22256 Mdot
.84226 .22317 Mdot
.84319 .22378 Mdot
.84412 .22438 Mdot
.84505 .22499 Mdot
.84598 .2256 Mdot
.84691 .22621 Mdot
.84784 .22683 Mdot
.84877 .22744 Mdot
.8497 .22805 Mdot
.85063 .22866 Mdot
.85156 .22927 Mdot
.85249 .22988 Mdot
.85342 .23049 Mdot
.85435 .23111 Mdot
.85528 .23172 Mdot
.85621 .23233 Mdot
.85714 .23294 Mdot
.85807 .23342 Mdot
.859 .23393 Mdot
.85993 .23448 Mdot
.86086 .23502 Mdot
.86179 .2356 Mdot
.86272 .23617 Mdot
.86365 .23672 Mdot
.86458 .23728 Mdot
.86551 .23788 Mdot
.86644 .23846 Mdot
.86737 .23904 Mdot
.8683 .23962 Mdot
.86923 .24019 Mdot
.87016 .24076 Mdot
.87109 .24133 Mdot
.87202 .2419 Mdot
.87295 .24251 Mdot
.87388 .24311 Mdot
.87481 .2437 Mdot
.87574 .24429 Mdot
.87667 .24488 Mdot
.8776 .24546 Mdot
.87853 .24605 Mdot
.87946 .24664 Mdot
.88039 .24722 Mdot
.88132 .2478 Mdot
.88225 .24838 Mdot
.88318 .24896 Mdot
.88411 .24955 Mdot
.88504 .25013 Mdot
.88597 .25071 Mdot
.8869 .2513 Mdot
.88783 .25192 Mdot
.88876 .25253 Mdot
.88969 .25313 Mdot
.89063 .25373 Mdot
.89156 .25432 Mdot
.89249 .25492 Mdot
.89342 .25552 Mdot
.89435 .25611 Mdot
.89528 .2567 Mdot
.89621 .25729 Mdot
.89714 .25788 Mdot
.89807 .25848 Mdot
.899 .25907 Mdot
.89993 .25967 Mdot
.90086 .26026 Mdot
.90179 .26085 Mdot
.90272 .26144 Mdot
.90365 .26202 Mdot
.90458 .26261 Mdot
.90551 .2632 Mdot
.90644 .26379 Mdot
.90737 .26438 Mdot
.9083 .26497 Mdot
.90923 .26556 Mdot
.91016 .26616 Mdot
.91109 .26675 Mdot
.91202 .26734 Mdot
.91295 .26793 Mdot
.91388 .26852 Mdot
.91481 .26911 Mdot
.91574 .2697 Mdot
.91667 .27029 Mdot
.9176 .27092 Mdot
.91853 .27154 Mdot
.91946 .27215 Mdot
.92039 .27276 Mdot
.92132 .27336 Mdot
.92225 .27396 Mdot
.92318 .27457 Mdot
.92411 .27517 Mdot
.92504 .27577 Mdot
.92597 .27636 Mdot
.9269 .27696 Mdot
.92783 .27756 Mdot
.92876 .27817 Mdot
.92969 .27877 Mdot
.93062 .27937 Mdot
.93155 .27997 Mdot
.93248 .28056 Mdot
.93341 .28116 Mdot
.93434 .28175 Mdot
.93527 .28235 Mdot
.9362 .28295 Mdot
.93713 .28355 Mdot
.93806 .28414 Mdot
.93899 .28474 Mdot
.93992 .28534 Mdot
.94085 .28594 Mdot
.94178 .28654 Mdot
.94271 .28714 Mdot
.94364 .28774 Mdot
.94457 .28833 Mdot
.9455 .28893 Mdot
.94643 .28953 Mdot
.94736 .29012 Mdot
.94829 .29071 Mdot
.94922 .29131 Mdot
.95015 .2919 Mdot
.95108 .2925 Mdot
.95201 .29309 Mdot
.95294 .29369 Mdot
.95387 .29428 Mdot
.9548 .29488 Mdot
.95573 .29547 Mdot
.95666 .29607 Mdot
.95759 .29667 Mdot
.95852 .29726 Mdot
.95945 .29786 Mdot
.96038 .29845 Mdot
.96131 .29905 Mdot
.96224 .29965 Mdot
.96317 .30025 Mdot
.9641 .30084 Mdot
.96503 .30144 Mdot
.96596 .30204 Mdot
.96689 .30263 Mdot
.96782 .30323 Mdot
.96875 .30383 Mdot
.96968 .30442 Mdot
.97061 .30502 Mdot
.97154 .30561 Mdot
.97247 .30621 Mdot
.9734 .30681 Mdot
.97433 .3074 Mdot
.97526 .308 Mdot
.97619 .3086 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
The error can be estimated using various definitions of \
\"distance\". This gives the maximum absolute value of the difference between \
the compressed signal and the original signal.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.34"}],

Cell[CellGroupData[{

Cell["Max[Abs[data - newdata]]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(0.0360326837081292872`\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
This gives the relative root mean square error due to \
compression.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.35"}],

Cell[CellGroupData[{

Cell["Sqrt[(data-newdata).(data-newdata)]/Sqrt[data.data]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(0.00650219333561439061`\)], "Output",
  CellLabel->"Out[23]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
For comparison, we also apply the Fourier transform to the original \
data. \
\>", "Text",
  CellTags->{"S2.1.1", "1.36"}],

Cell["\<\
We calculate the normalized cumulative energy in the Fourier \
representation.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.37"}],

Cell["\<\
(fdata = Fourier[data];
 ef = CumulativeEnergy[fdata]/(data.data);)\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
Here the cumulative energy obtained from the Fourier coefficients \
(dotted line) and that obtained from the wavelet coefficients (solid line) \
are plotted together for comparison.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.38"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[Take[e, 50], PlotJoined -> True,
 PlotLabel -> \"cumulative energy\"],
 ListPlot[Take[ef, 50]]}]]\
\>", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 -2.90442 3.50774 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .07716 -24 -4.5 ]
[.01131 .07716 0 4.5 ]
[.01131 .16485 -30 -4.5 ]
[.01131 .16485 0 4.5 ]
[.01131 .25255 -18 -4.5 ]
[.01131 .25255 0 4.5 ]
[.01131 .34024 -30 -4.5 ]
[.01131 .34024 0 4.5 ]
[.01131 .42793 -24 -4.5 ]
[.01131 .42793 0 4.5 ]
[.01131 .51563 -30 -4.5 ]
[.01131 .51563 0 4.5 ]
[.5 .63053 -51 0 ]
[.5 .63053 51 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(10)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(20)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(30)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(40)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(50)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.0619 .60332 m
.0619 .60707 L
s
.1 .60332 m
.1 .60707 L
s
.1381 .60332 m
.1381 .60707 L
s
.17619 .60332 m
.17619 .60707 L
s
.25238 .60332 m
.25238 .60707 L
s
.29048 .60332 m
.29048 .60707 L
s
.32857 .60332 m
.32857 .60707 L
s
.36667 .60332 m
.36667 .60707 L
s
.44286 .60332 m
.44286 .60707 L
s
.48095 .60332 m
.48095 .60707 L
s
.51905 .60332 m
.51905 .60707 L
s
.55714 .60332 m
.55714 .60707 L
s
.63333 .60332 m
.63333 .60707 L
s
.67143 .60332 m
.67143 .60707 L
s
.70952 .60332 m
.70952 .60707 L
s
.74762 .60332 m
.74762 .60707 L
s
.82381 .60332 m
.82381 .60707 L
s
.8619 .60332 m
.8619 .60707 L
s
.9 .60332 m
.9 .60707 L
s
.9381 .60332 m
.9381 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .07716 m
.03006 .07716 L
s
[(0.85)] .01131 .07716 1 0 Mshowa
.02381 .16485 m
.03006 .16485 L
s
[(0.875)] .01131 .16485 1 0 Mshowa
.02381 .25255 m
.03006 .25255 L
s
[(0.9)] .01131 .25255 1 0 Mshowa
.02381 .34024 m
.03006 .34024 L
s
[(0.925)] .01131 .34024 1 0 Mshowa
.02381 .42793 m
.03006 .42793 L
s
[(0.95)] .01131 .42793 1 0 Mshowa
.02381 .51563 m
.03006 .51563 L
s
[(0.975)] .01131 .51563 1 0 Mshowa
.125 Mabswid
.02381 .0947 m
.02756 .0947 L
s
.02381 .11224 m
.02756 .11224 L
s
.02381 .12977 m
.02756 .12977 L
s
.02381 .14731 m
.02756 .14731 L
s
.02381 .18239 m
.02756 .18239 L
s
.02381 .19993 m
.02756 .19993 L
s
.02381 .21747 m
.02756 .21747 L
s
.02381 .23501 m
.02756 .23501 L
s
.02381 .27008 m
.02756 .27008 L
s
.02381 .28762 m
.02756 .28762 L
s
.02381 .30516 m
.02756 .30516 L
s
.02381 .3227 m
.02756 .3227 L
s
.02381 .35778 m
.02756 .35778 L
s
.02381 .37532 m
.02756 .37532 L
s
.02381 .39285 m
.02756 .39285 L
s
.02381 .41039 m
.02756 .41039 L
s
.02381 .44547 m
.02756 .44547 L
s
.02381 .46301 m
.02756 .46301 L
s
.02381 .48055 m
.02756 .48055 L
s
.02381 .49809 m
.02756 .49809 L
s
.02381 .53316 m
.02756 .53316 L
s
.02381 .5507 m
.02756 .5507 L
s
.02381 .56824 m
.02756 .56824 L
s
.02381 .58578 m
.02756 .58578 L
s
.02381 .05962 m
.02756 .05962 L
s
.02381 .04208 m
.02756 .04208 L
s
.02381 .02454 m
.02756 .02454 L
s
.02381 .007 m
.02756 .007 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(cumulative energy)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.10127 0 m
.11905 .24386 L
.1381 .36787 L
.15714 .45355 L
.17619 .50673 L
.19524 .54711 L
.21429 .56561 L
.23333 .58137 L
.25238 .5905 L
.27143 .59572 L
.29048 .59921 L
.30952 .60089 L
.32857 .60241 L
.34762 .60268 L
.36667 .60292 L
.38571 .6031 L
.40476 .60317 L
.42381 .60321 L
.44286 .60323 L
.4619 .60324 L
.48095 .60325 L
.5 .60326 L
.51905 .60327 L
.5381 .60328 L
.55714 .60329 L
.57619 .6033 L
.59524 .6033 L
.61429 .60331 L
.63333 .60331 L
.65238 .60331 L
.67143 .60331 L
.69048 .60332 L
.70952 .60332 L
.72857 .60332 L
.74762 .60332 L
.76667 .60332 L
.78571 .60332 L
.80476 .60332 L
.82381 .60332 L
.84286 .60332 L
.8619 .60332 L
.88095 .60332 L
.9 .60332 L
.91905 .60332 L
.9381 .60332 L
.95714 .60332 L
.97619 .60332 L
s
.008 w
.1381 .08432 Mdot
.15714 .14879 Mdot
.17619 .21326 Mdot
.19524 .25424 Mdot
.21429 .29523 Mdot
.23333 .32351 Mdot
.25238 .3518 Mdot
.27143 .37245 Mdot
.29048 .39311 Mdot
.30952 .40882 Mdot
.32857 .42453 Mdot
.34762 .43686 Mdot
.36667 .44918 Mdot
.38571 .45909 Mdot
.40476 .469 Mdot
.42381 .47712 Mdot
.44286 .48524 Mdot
.4619 .49201 Mdot
.48095 .49877 Mdot
.5 .50448 Mdot
.51905 .51019 Mdot
.5381 .51506 Mdot
.55714 .51993 Mdot
.57619 .52413 Mdot
.59524 .52832 Mdot
.61429 .53197 Mdot
.63333 .53562 Mdot
.65238 .53881 Mdot
.67143 .542 Mdot
.69048 .5448 Mdot
.70952 .54761 Mdot
.72857 .5501 Mdot
.74762 .55258 Mdot
.76667 .5548 Mdot
.78571 .55701 Mdot
.80476 .55898 Mdot
.82381 .56096 Mdot
.84286 .56273 Mdot
.8619 .5645 Mdot
.88095 .5661 Mdot
.9 .56769 Mdot
.91905 .56913 Mdot
.9381 .57057 Mdot
.95714 .57187 Mdot
.97619 .57317 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
We see that the cumulative energy of the Fourier coefficients \
(dotted line) is well below that of the wavelet coefficients (solid line). \
This means that in this example the wavelet transform is able to concentrate \
more energy in fewer modes than the Fourier transform, thus requiring fewer \
coefficients to reproduce the signal. \
\>", "Text",
  CellTags->{"S2.1.1", "1.39"}],

Cell["\<\
We compress the Fourier data with the same compression ratio as \
earlier.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.40"}],

Cell["newdata = Chop[InverseFourier[Compress[fdata, 20]]];", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S2.1.1"],

Cell[TextData[{
  "This is the reconstruction of ",
  Cell[BoxData[
      \(TraditionalForm\`u \((x)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " from the 20 largest Fourier coefficients. We see that in this example, \
the wavelet representation of the signal is superior to the Fourier \
representation."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.41"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[newdata, AxesLabel -> {\"x\", \"\"},
PlotLabel -> \"reconstruction of u(x)\"]\
\>", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.309017 0.314086 [
[.20982 .29652 -9 -9 ]
[.20982 .29652 9 0 ]
[.39583 .29652 -9 -9 ]
[.39583 .29652 9 0 ]
[.58185 .29652 -9 -9 ]
[.58185 .29652 9 0 ]
[.76786 .29652 -9 -9 ]
[.76786 .29652 9 0 ]
[.95387 .29652 -12 -9 ]
[.95387 .29652 12 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.01131 .07345 -30 -4.5 ]
[.01131 .07345 0 4.5 ]
[.01131 .15197 -24 -4.5 ]
[.01131 .15197 0 4.5 ]
[.01131 .2305 -30 -4.5 ]
[.01131 .2305 0 4.5 ]
[.01131 .38754 -24 -4.5 ]
[.01131 .38754 0 4.5 ]
[.01131 .46606 -18 -4.5 ]
[.01131 .46606 0 4.5 ]
[.01131 .54458 -24 -4.5 ]
[.01131 .54458 0 4.5 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .30902 m
.20982 .31527 L
s
[(200)] .20982 .29652 0 1 Mshowa
.39583 .30902 m
.39583 .31527 L
s
[(400)] .39583 .29652 0 1 Mshowa
.58185 .30902 m
.58185 .31527 L
s
[(600)] .58185 .29652 0 1 Mshowa
.76786 .30902 m
.76786 .31527 L
s
[(800)] .76786 .29652 0 1 Mshowa
.95387 .30902 m
.95387 .31527 L
s
[(1000)] .95387 .29652 0 1 Mshowa
.125 Mabswid
.07031 .30902 m
.07031 .31277 L
s
.11682 .30902 m
.11682 .31277 L
s
.16332 .30902 m
.16332 .31277 L
s
.25632 .30902 m
.25632 .31277 L
s
.30283 .30902 m
.30283 .31277 L
s
.34933 .30902 m
.34933 .31277 L
s
.44234 .30902 m
.44234 .31277 L
s
.48884 .30902 m
.48884 .31277 L
s
.53534 .30902 m
.53534 .31277 L
s
.62835 .30902 m
.62835 .31277 L
s
.67485 .30902 m
.67485 .31277 L
s
.72135 .30902 m
.72135 .31277 L
s
.81436 .30902 m
.81436 .31277 L
s
.86086 .30902 m
.86086 .31277 L
s
.90737 .30902 m
.90737 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(x)] 1.025 .30902 -1 0 Mshowa
.02381 .07345 m
.03006 .07345 L
s
[(-0.75)] .01131 .07345 1 0 Mshowa
.02381 .15197 m
.03006 .15197 L
s
[(-0.5)] .01131 .15197 1 0 Mshowa
.02381 .2305 m
.03006 .2305 L
s
[(-0.25)] .01131 .2305 1 0 Mshowa
.02381 .38754 m
.03006 .38754 L
s
[(0.25)] .01131 .38754 1 0 Mshowa
.02381 .46606 m
.03006 .46606 L
s
[(0.5)] .01131 .46606 1 0 Mshowa
.02381 .54458 m
.03006 .54458 L
s
[(0.75)] .01131 .54458 1 0 Mshowa
.125 Mabswid
.02381 .08916 m
.02756 .08916 L
s
.02381 .10486 m
.02756 .10486 L
s
.02381 .12057 m
.02756 .12057 L
s
.02381 .13627 m
.02756 .13627 L
s
.02381 .16768 m
.02756 .16768 L
s
.02381 .18338 m
.02756 .18338 L
s
.02381 .19909 m
.02756 .19909 L
s
.02381 .21479 m
.02756 .21479 L
s
.02381 .2462 m
.02756 .2462 L
s
.02381 .2619 m
.02756 .2619 L
s
.02381 .27761 m
.02756 .27761 L
s
.02381 .29331 m
.02756 .29331 L
s
.02381 .32472 m
.02756 .32472 L
s
.02381 .34043 m
.02756 .34043 L
s
.02381 .35613 m
.02756 .35613 L
s
.02381 .37183 m
.02756 .37183 L
s
.02381 .40324 m
.02756 .40324 L
s
.02381 .41895 m
.02756 .41895 L
s
.02381 .43465 m
.02756 .43465 L
s
.02381 .45036 m
.02756 .45036 L
s
.02381 .48176 m
.02756 .48176 L
s
.02381 .49747 m
.02756 .49747 L
s
.02381 .51317 m
.02756 .51317 L
s
.02381 .52888 m
.02756 .52888 L
s
.02381 .05775 m
.02756 .05775 L
s
.02381 .04204 m
.02756 .04204 L
s
.02381 .02634 m
.02756 .02634 L
s
.02381 .01063 m
.02756 .01063 L
s
.02381 .56029 m
.02756 .56029 L
s
.02381 .57599 m
.02756 .57599 L
s
.02381 .59169 m
.02756 .59169 L
s
.02381 .6074 m
.02756 .6074 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(reconstruction of u\\(x\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02474 .30902 Mdot
.02567 .30906 Mdot
.0266 .30911 Mdot
.02753 .30915 Mdot
.02846 .30921 Mdot
.02939 .30927 Mdot
.03032 .30935 Mdot
.03125 .30944 Mdot
.03218 .30954 Mdot
.03311 .30966 Mdot
.03404 .30979 Mdot
.03497 .30995 Mdot
.0359 .31013 Mdot
.03683 .31033 Mdot
.03776 .31055 Mdot
.03869 .3108 Mdot
.03962 .31108 Mdot
.04055 .31139 Mdot
.04148 .31172 Mdot
.04241 .31209 Mdot
.04334 .31249 Mdot
.04427 .31292 Mdot
.0452 .31338 Mdot
.04613 .31387 Mdot
.04706 .3144 Mdot
.04799 .31496 Mdot
.04892 .31556 Mdot
.04985 .31618 Mdot
.05078 .31684 Mdot
.05171 .31754 Mdot
.05264 .31826 Mdot
.05357 .31902 Mdot
.0545 .3198 Mdot
.05543 .32062 Mdot
.05636 .32146 Mdot
.05729 .32233 Mdot
.05822 .32323 Mdot
.05915 .32415 Mdot
.06008 .32509 Mdot
.06101 .32606 Mdot
.06194 .32704 Mdot
.06287 .32805 Mdot
.0638 .32907 Mdot
.06473 .3301 Mdot
.06566 .33115 Mdot
.06659 .3322 Mdot
.06752 .33327 Mdot
.06845 .33434 Mdot
.06938 .33541 Mdot
.07031 .33649 Mdot
.07124 .33756 Mdot
.07217 .33864 Mdot
.0731 .33971 Mdot
.07403 .34077 Mdot
.07496 .34182 Mdot
.07589 .34286 Mdot
.07682 .34389 Mdot
.07775 .34491 Mdot
.07868 .34591 Mdot
.07961 .34689 Mdot
.08054 .34784 Mdot
.08147 .34878 Mdot
.0824 .34969 Mdot
.08333 .35058 Mdot
.08426 .35144 Mdot
.08519 .35228 Mdot
.08612 .35308 Mdot
.08705 .35385 Mdot
.08798 .3546 Mdot
.08891 .35531 Mdot
.08984 .35598 Mdot
.09077 .35663 Mdot
.0917 .35724 Mdot
.09263 .35782 Mdot
.09356 .35836 Mdot
.09449 .35887 Mdot
.09542 .35935 Mdot
.09635 .35979 Mdot
.09728 .3602 Mdot
.09821 .36057 Mdot
.09914 .36092 Mdot
.10007 .36123 Mdot
.101 .36151 Mdot
.10193 .36177 Mdot
.10286 .36199 Mdot
.10379 .36219 Mdot
.10472 .36237 Mdot
.10565 .36252 Mdot
.10658 .36265 Mdot
.10751 .36275 Mdot
.10844 .36285 Mdot
.10938 .36292 Mdot
.11031 .36298 Mdot
.11124 .36303 Mdot
.11217 .36306 Mdot
.1131 .36309 Mdot
.11403 .36311 Mdot
.11496 .36313 Mdot
.11589 .36315 Mdot
.11682 .36316 Mdot
.11775 .36318 Mdot
.11868 .36321 Mdot
.11961 .36324 Mdot
.12054 .36328 Mdot
.12147 .36333 Mdot
.1224 .3634 Mdot
.12333 .36348 Mdot
.12426 .36358 Mdot
.12519 .3637 Mdot
.12612 .36384 Mdot
.12705 .364 Mdot
.12798 .36419 Mdot
.12891 .36441 Mdot
.12984 .36465 Mdot
.13077 .36492 Mdot
.1317 .36523 Mdot
.13263 .36556 Mdot
.13356 .36593 Mdot
.13449 .36633 Mdot
.13542 .36676 Mdot
.13635 .36723 Mdot
.13728 .36773 Mdot
.13821 .36827 Mdot
.13914 .36885 Mdot
.14007 .36946 Mdot
.141 .3701 Mdot
.14193 .37078 Mdot
.14286 .3715 Mdot
.14379 .37225 Mdot
.14472 .37303 Mdot
.14565 .37385 Mdot
.14658 .37469 Mdot
.14751 .37557 Mdot
.14844 .37647 Mdot
.14937 .37741 Mdot
.1503 .37837 Mdot
.15123 .37935 Mdot
.15216 .38036 Mdot
.15309 .38139 Mdot
.15402 .38243 Mdot
.15495 .3835 Mdot
.15588 .38458 Mdot
.15681 .38567 Mdot
.15774 .38677 Mdot
.15867 .38788 Mdot
.1596 .389 Mdot
.16053 .39012 Mdot
.16146 .39124 Mdot
.16239 .39236 Mdot
.16332 .39348 Mdot
.16425 .39459 Mdot
.16518 .3957 Mdot
.16611 .39679 Mdot
.16704 .39787 Mdot
.16797 .39894 Mdot
.1689 .39999 Mdot
.16983 .40102 Mdot
.17076 .40203 Mdot
.17169 .40301 Mdot
.17262 .40397 Mdot
.17355 .40491 Mdot
.17448 .40581 Mdot
.17541 .40669 Mdot
.17634 .40753 Mdot
.17727 .40834 Mdot
.1782 .40912 Mdot
.17913 .40986 Mdot
.18006 .41056 Mdot
.18099 .41123 Mdot
.18192 .41186 Mdot
.18285 .41246 Mdot
.18378 .41301 Mdot
.18471 .41353 Mdot
.18564 .414 Mdot
.18657 .41444 Mdot
.1875 .41485 Mdot
.18843 .41521 Mdot
.18936 .41554 Mdot
.19029 .41583 Mdot
.19122 .41609 Mdot
.19215 .41631 Mdot
.19308 .4165 Mdot
.19401 .41666 Mdot
.19494 .41678 Mdot
.19587 .41688 Mdot
.1968 .41696 Mdot
.19773 .41701 Mdot
.19866 .41703 Mdot
.19959 .41704 Mdot
.20052 .41702 Mdot
.20145 .41699 Mdot
.20238 .41695 Mdot
.20331 .41689 Mdot
.20424 .41683 Mdot
.20517 .41676 Mdot
.2061 .41668 Mdot
.20703 .41661 Mdot
.20796 .41653 Mdot
.20889 .41646 Mdot
.20982 .4164 Mdot
.21075 .41634 Mdot
.21168 .41629 Mdot
.21261 .41626 Mdot
.21354 .41625 Mdot
.21447 .41625 Mdot
.2154 .41628 Mdot
.21633 .41633 Mdot
.21726 .4164 Mdot
.21819 .4165 Mdot
.21912 .41663 Mdot
.22005 .41679 Mdot
.22098 .41699 Mdot
.22191 .41722 Mdot
.22284 .41748 Mdot
.22377 .41779 Mdot
.2247 .41813 Mdot
.22563 .41851 Mdot
.22656 .41893 Mdot
.22749 .4194 Mdot
.22842 .4199 Mdot
.22935 .42045 Mdot
.23028 .42104 Mdot
.23121 .42167 Mdot
.23214 .42235 Mdot
.23307 .42306 Mdot
.234 .42382 Mdot
.23493 .42462 Mdot
.23586 .42546 Mdot
.23679 .42633 Mdot
.23772 .42725 Mdot
.23865 .4282 Mdot
.23958 .42918 Mdot
.24051 .4302 Mdot
.24144 .43125 Mdot
.24237 .43233 Mdot
.2433 .43344 Mdot
.24423 .43457 Mdot
.24516 .43572 Mdot
.24609 .4369 Mdot
.24702 .43809 Mdot
.24795 .4393 Mdot
.24888 .44052 Mdot
.24981 .44175 Mdot
.25074 .44298 Mdot
.25167 .44422 Mdot
.2526 .44546 Mdot
.25353 .4467 Mdot
.25446 .44794 Mdot
.25539 .44917 Mdot
.25632 .45039 Mdot
.25725 .45159 Mdot
.25818 .45278 Mdot
.25911 .45395 Mdot
.26004 .45509 Mdot
.26097 .45622 Mdot
.2619 .45731 Mdot
.26283 .45838 Mdot
.26376 .45941 Mdot
.26469 .46042 Mdot
.26563 .46138 Mdot
.26656 .46231 Mdot
.26749 .46319 Mdot
.26842 .46404 Mdot
.26935 .46484 Mdot
.27028 .46559 Mdot
.27121 .46631 Mdot
.27214 .46697 Mdot
.27307 .46759 Mdot
.274 .46815 Mdot
.27493 .46867 Mdot
.27586 .46914 Mdot
.27679 .46956 Mdot
.27772 .46993 Mdot
.27865 .47026 Mdot
.27958 .47053 Mdot
.28051 .47076 Mdot
.28144 .47094 Mdot
.28237 .47108 Mdot
.2833 .47117 Mdot
.28423 .47122 Mdot
.28516 .47123 Mdot
.28609 .4712 Mdot
.28702 .47113 Mdot
.28795 .47103 Mdot
.28888 .47089 Mdot
.28981 .47073 Mdot
.29074 .47054 Mdot
.29167 .47033 Mdot
.2926 .47009 Mdot
.29353 .46984 Mdot
.29446 .46957 Mdot
.29539 .46929 Mdot
.29632 .469 Mdot
.29725 .46871 Mdot
.29818 .46841 Mdot
.29911 .46812 Mdot
.30004 .46783 Mdot
.30097 .46755 Mdot
.3019 .46728 Mdot
.30283 .46703 Mdot
.30376 .46679 Mdot
.30469 .46658 Mdot
.30562 .4664 Mdot
.30655 .46624 Mdot
.30748 .46611 Mdot
.30841 .46602 Mdot
.30934 .46596 Mdot
.31027 .46595 Mdot
.3112 .46598 Mdot
.31213 .46605 Mdot
.31306 .46617 Mdot
.31399 .46634 Mdot
.31492 .46657 Mdot
.31585 .46684 Mdot
.31678 .46717 Mdot
.31771 .46756 Mdot
.31864 .468 Mdot
.31957 .4685 Mdot
.3205 .46907 Mdot
.32143 .46968 Mdot
.32236 .47036 Mdot
.32329 .4711 Mdot
.32422 .4719 Mdot
.32515 .47275 Mdot
.32608 .47366 Mdot
.32701 .47463 Mdot
.32794 .47565 Mdot
.32887 .47673 Mdot
.3298 .47786 Mdot
.33073 .47904 Mdot
.33166 .48026 Mdot
.33259 .48153 Mdot
.33352 .48284 Mdot
.33445 .48419 Mdot
.33538 .48558 Mdot
.33631 .487 Mdot
.33724 .48845 Mdot
.33817 .48993 Mdot
.3391 .49143 Mdot
.34003 .49294 Mdot
.34096 .49448 Mdot
.34189 .49602 Mdot
.34282 .49757 Mdot
.34375 .49912 Mdot
.34468 .50067 Mdot
.34561 .50221 Mdot
.34654 .50374 Mdot
.34747 .50525 Mdot
.3484 .50675 Mdot
.34933 .50822 Mdot
.35026 .50967 Mdot
.35119 .51108 Mdot
.35212 .51246 Mdot
.35305 .51379 Mdot
.35398 .51509 Mdot
.35491 .51633 Mdot
.35584 .51752 Mdot
.35677 .51866 Mdot
.3577 .51974 Mdot
.35863 .52076 Mdot
.35956 .52171 Mdot
.36049 .5226 Mdot
.36142 .52342 Mdot
.36235 .52416 Mdot
.36328 .52484 Mdot
.36421 .52544 Mdot
.36514 .52596 Mdot
.36607 .52641 Mdot
.367 .52677 Mdot
.36793 .52706 Mdot
.36886 .52728 Mdot
.36979 .52741 Mdot
.37072 .52747 Mdot
.37165 .52745 Mdot
.37258 .52735 Mdot
.37351 .52718 Mdot
.37444 .52694 Mdot
.37537 .52662 Mdot
.3763 .52625 Mdot
.37723 .5258 Mdot
.37816 .52529 Mdot
.37909 .52473 Mdot
.38002 .52411 Mdot
.38095 .52344 Mdot
.38188 .52272 Mdot
.38281 .52196 Mdot
.38374 .52116 Mdot
.38467 .52033 Mdot
.3856 .51948 Mdot
.38653 .51859 Mdot
.38746 .5177 Mdot
.38839 .51679 Mdot
.38932 .51587 Mdot
.39025 .51496 Mdot
.39118 .51405 Mdot
.39211 .51315 Mdot
.39304 .51227 Mdot
.39397 .51142 Mdot
.3949 .5106 Mdot
.39583 .50981 Mdot
.39676 .50906 Mdot
.39769 .50836 Mdot
.39862 .50772 Mdot
.39955 .50714 Mdot
.40048 .50662 Mdot
.40141 .50617 Mdot
.40234 .5058 Mdot
.40327 .50551 Mdot
.4042 .50531 Mdot
.40513 .50519 Mdot
.40606 .50517 Mdot
.40699 .50525 Mdot
.40792 .50544 Mdot
.40885 .50572 Mdot
.40978 .50612 Mdot
.41071 .50663 Mdot
.41164 .50725 Mdot
.41257 .50799 Mdot
.4135 .50884 Mdot
.41443 .50981 Mdot
.41536 .5109 Mdot
.41629 .5121 Mdot
.41722 .51343 Mdot
.41815 .51486 Mdot
.41908 .51642 Mdot
.42001 .51809 Mdot
.42094 .51987 Mdot
.42188 .52175 Mdot
.42281 .52375 Mdot
.42374 .52584 Mdot
.42467 .52803 Mdot
.4256 .53031 Mdot
.42653 .53268 Mdot
.42746 .53512 Mdot
.42839 .53765 Mdot
.42932 .54024 Mdot
.43025 .54289 Mdot
.43118 .54559 Mdot
.43211 .54834 Mdot
.43304 .55112 Mdot
.43397 .55393 Mdot
.4349 .55677 Mdot
.43583 .55961 Mdot
.43676 .56245 Mdot
.43769 .56528 Mdot
.43862 .56809 Mdot
.43955 .57087 Mdot
.44048 .57361 Mdot
.44141 .5763 Mdot
.44234 .57893 Mdot
.44327 .58148 Mdot
.4442 .58394 Mdot
.44513 .58631 Mdot
.44606 .58857 Mdot
.44699 .59071 Mdot
.44792 .59273 Mdot
.44885 .5946 Mdot
.44978 .59631 Mdot
.45071 .59787 Mdot
.45164 .59925 Mdot
.45257 .60045 Mdot
.4535 .60145 Mdot
.45443 .60225 Mdot
.45536 .60283 Mdot
.45629 .60319 Mdot
.45722 .60332 Mdot
.45815 .60321 Mdot
.45908 .60284 Mdot
.46001 .60222 Mdot
.46094 .60134 Mdot
.46187 .60018 Mdot
.4628 .59875 Mdot
.46373 .59703 Mdot
.46466 .59503 Mdot
.46559 .59273 Mdot
.46652 .59014 Mdot
.46745 .58725 Mdot
.46838 .58405 Mdot
.46931 .58055 Mdot
.47024 .57674 Mdot
.47117 .57263 Mdot
.4721 .56821 Mdot
.47303 .56348 Mdot
.47396 .55845 Mdot
.47489 .55311 Mdot
.47582 .54748 Mdot
.47675 .54155 Mdot
.47768 .53532 Mdot
.47861 .52881 Mdot
.47954 .52202 Mdot
.48047 .51494 Mdot
.4814 .5076 Mdot
.48233 .5 Mdot
.48326 .49214 Mdot
.48419 .48404 Mdot
.48512 .4757 Mdot
.48605 .46713 Mdot
.48698 .45835 Mdot
.48791 .44936 Mdot
.48884 .44018 Mdot
.48977 .43081 Mdot
.4907 .42128 Mdot
.49163 .41158 Mdot
.49256 .40175 Mdot
.49349 .39178 Mdot
.49442 .38169 Mdot
.49535 .3715 Mdot
.49628 .36123 Mdot
.49721 .35088 Mdot
.49814 .34046 Mdot
.49907 .33001 Mdot
.5 .31952 Mdot
.50093 .30902 Mdot
.50186 .29851 Mdot
.50279 .28803 Mdot
.50372 .27757 Mdot
.50465 .26716 Mdot
.50558 .25681 Mdot
.50651 .24653 Mdot
.50744 .23634 Mdot
.50837 .22625 Mdot
.5093 .21629 Mdot
.51023 .20645 Mdot
.51116 .19676 Mdot
.51209 .18722 Mdot
.51302 .17786 Mdot
.51395 .16867 Mdot
.51488 .15968 Mdot
.51581 .1509 Mdot
.51674 .14234 Mdot
.51767 .134 Mdot
.5186 .12589 Mdot
.51953 .11803 Mdot
.52046 .11043 Mdot
.52139 .10309 Mdot
.52232 .09602 Mdot
.52325 .08922 Mdot
.52418 .08271 Mdot
.52511 .07649 Mdot
.52604 .07055 Mdot
.52697 .06492 Mdot
.5279 .05958 Mdot
.52883 .05455 Mdot
.52976 .04983 Mdot
.53069 .0454 Mdot
.53162 .04129 Mdot
.53255 .03748 Mdot
.53348 .03398 Mdot
.53441 .03079 Mdot
.53534 .02789 Mdot
.53627 .0253 Mdot
.5372 .023 Mdot
.53813 .021 Mdot
.53906 .01928 Mdot
.53999 .01785 Mdot
.54092 .0167 Mdot
.54185 .01581 Mdot
.54278 .01519 Mdot
.54371 .01483 Mdot
.54464 .01472 Mdot
.54557 .01484 Mdot
.5465 .0152 Mdot
.54743 .01579 Mdot
.54836 .01658 Mdot
.54929 .01759 Mdot
.55022 .01878 Mdot
.55115 .02017 Mdot
.55208 .02172 Mdot
.55301 .02344 Mdot
.55394 .02531 Mdot
.55487 .02732 Mdot
.5558 .02946 Mdot
.55673 .03172 Mdot
.55766 .03409 Mdot
.55859 .03656 Mdot
.55952 .03911 Mdot
.56045 .04173 Mdot
.56138 .04442 Mdot
.56231 .04716 Mdot
.56324 .04994 Mdot
.56417 .05275 Mdot
.5651 .05558 Mdot
.56603 .05843 Mdot
.56696 .06127 Mdot
.56789 .0641 Mdot
.56882 .06691 Mdot
.56975 .0697 Mdot
.57068 .07245 Mdot
.57161 .07515 Mdot
.57254 .0778 Mdot
.57347 .08039 Mdot
.5744 .08291 Mdot
.57533 .08536 Mdot
.57626 .08772 Mdot
.57719 .09001 Mdot
.57813 .09219 Mdot
.57906 .09429 Mdot
.57999 .09628 Mdot
.58092 .09817 Mdot
.58185 .09995 Mdot
.58278 .10161 Mdot
.58371 .10317 Mdot
.58464 .10461 Mdot
.58557 .10593 Mdot
.5865 .10714 Mdot
.58743 .10823 Mdot
.58836 .1092 Mdot
.58929 .11005 Mdot
.59022 .11078 Mdot
.59115 .11141 Mdot
.59208 .11191 Mdot
.59301 .11231 Mdot
.59394 .1126 Mdot
.59487 .11278 Mdot
.5958 .11286 Mdot
.59673 .11284 Mdot
.59766 .11273 Mdot
.59859 .11252 Mdot
.59952 .11223 Mdot
.60045 .11186 Mdot
.60138 .11141 Mdot
.60231 .1109 Mdot
.60324 .11031 Mdot
.60417 .10967 Mdot
.6051 .10897 Mdot
.60603 .10823 Mdot
.60696 .10744 Mdot
.60789 .10661 Mdot
.60882 .10576 Mdot
.60975 .10488 Mdot
.61068 .10398 Mdot
.61161 .10308 Mdot
.61254 .10216 Mdot
.61347 .10125 Mdot
.6144 .10034 Mdot
.61533 .09944 Mdot
.61626 .09856 Mdot
.61719 .0977 Mdot
.61812 .09687 Mdot
.61905 .09607 Mdot
.61998 .09531 Mdot
.62091 .0946 Mdot
.62184 .09392 Mdot
.62277 .09331 Mdot
.6237 .09274 Mdot
.62463 .09223 Mdot
.62556 .09179 Mdot
.62649 .09141 Mdot
.62742 .0911 Mdot
.62835 .09085 Mdot
.62928 .09068 Mdot
.63021 .09059 Mdot
.63114 .09057 Mdot
.63207 .09062 Mdot
.633 .09076 Mdot
.63393 .09097 Mdot
.63486 .09126 Mdot
.63579 .09163 Mdot
.63672 .09207 Mdot
.63765 .0926 Mdot
.63858 .0932 Mdot
.63951 .09387 Mdot
.64044 .09462 Mdot
.64137 .09544 Mdot
.6423 .09632 Mdot
.64323 .09728 Mdot
.64416 .09829 Mdot
.64509 .09937 Mdot
.64602 .10051 Mdot
.64695 .1017 Mdot
.64788 .10295 Mdot
.64881 .10424 Mdot
.64974 .10558 Mdot
.65067 .10695 Mdot
.6516 .10836 Mdot
.65253 .10981 Mdot
.65346 .11128 Mdot
.65439 .11278 Mdot
.65532 .1143 Mdot
.65625 .11583 Mdot
.65718 .11737 Mdot
.65811 .11892 Mdot
.65904 .12047 Mdot
.65997 .12202 Mdot
.6609 .12356 Mdot
.66183 .12509 Mdot
.66276 .12661 Mdot
.66369 .12811 Mdot
.66462 .12958 Mdot
.66555 .13103 Mdot
.66648 .13245 Mdot
.66741 .13384 Mdot
.66834 .13519 Mdot
.66927 .1365 Mdot
.6702 .13777 Mdot
.67113 .139 Mdot
.67206 .14018 Mdot
.67299 .1413 Mdot
.67392 .14238 Mdot
.67485 .1434 Mdot
.67578 .14437 Mdot
.67671 .14528 Mdot
.67764 .14614 Mdot
.67857 .14693 Mdot
.6795 .14767 Mdot
.68043 .14835 Mdot
.68136 .14897 Mdot
.68229 .14953 Mdot
.68322 .15003 Mdot
.68415 .15047 Mdot
.68508 .15086 Mdot
.68601 .15119 Mdot
.68694 .15147 Mdot
.68787 .15169 Mdot
.6888 .15186 Mdot
.68973 .15198 Mdot
.69066 .15206 Mdot
.69159 .15208 Mdot
.69252 .15207 Mdot
.69345 .15202 Mdot
.69438 .15192 Mdot
.69531 .1518 Mdot
.69624 .15164 Mdot
.69717 .15145 Mdot
.6981 .15124 Mdot
.69903 .15101 Mdot
.69996 .15075 Mdot
.70089 .15048 Mdot
.70182 .1502 Mdot
.70275 .14991 Mdot
.70368 .14962 Mdot
.70461 .14933 Mdot
.70554 .14903 Mdot
.70647 .14874 Mdot
.7074 .14846 Mdot
.70833 .14819 Mdot
.70926 .14794 Mdot
.71019 .14771 Mdot
.71112 .14749 Mdot
.71205 .1473 Mdot
.71298 .14714 Mdot
.71391 .14701 Mdot
.71484 .14691 Mdot
.71577 .14684 Mdot
.7167 .14681 Mdot
.71763 .14682 Mdot
.71856 .14687 Mdot
.71949 .14696 Mdot
.72042 .14709 Mdot
.72135 .14728 Mdot
.72228 .1475 Mdot
.72321 .14778 Mdot
.72414 .1481 Mdot
.72507 .14847 Mdot
.726 .14889 Mdot
.72693 .14936 Mdot
.72786 .14988 Mdot
.72879 .15045 Mdot
.72972 .15106 Mdot
.73065 .15173 Mdot
.73158 .15244 Mdot
.73251 .1532 Mdot
.73344 .154 Mdot
.73438 .15484 Mdot
.73531 .15573 Mdot
.73624 .15665 Mdot
.73717 .15762 Mdot
.7381 .15862 Mdot
.73903 .15965 Mdot
.73996 .16072 Mdot
.74089 .16182 Mdot
.74182 .16294 Mdot
.74275 .16409 Mdot
.74368 .16526 Mdot
.74461 .16644 Mdot
.74554 .16765 Mdot
.74647 .16887 Mdot
.7474 .17009 Mdot
.74833 .17133 Mdot
.74926 .17257 Mdot
.75019 .17381 Mdot
.75112 .17505 Mdot
.75205 .17629 Mdot
.75298 .17752 Mdot
.75391 .17874 Mdot
.75484 .17995 Mdot
.75577 .18114 Mdot
.7567 .18231 Mdot
.75763 .18347 Mdot
.75856 .1846 Mdot
.75949 .1857 Mdot
.76042 .18678 Mdot
.76135 .18783 Mdot
.76228 .18885 Mdot
.76321 .18984 Mdot
.76414 .19079 Mdot
.76507 .1917 Mdot
.766 .19258 Mdot
.76693 .19342 Mdot
.76786 .19421 Mdot
.76879 .19497 Mdot
.76972 .19569 Mdot
.77065 .19636 Mdot
.77158 .19699 Mdot
.77251 .19758 Mdot
.77344 .19813 Mdot
.77437 .19864 Mdot
.7753 .1991 Mdot
.77623 .19952 Mdot
.77716 .19991 Mdot
.77809 .20025 Mdot
.77902 .20055 Mdot
.77995 .20082 Mdot
.78088 .20105 Mdot
.78181 .20124 Mdot
.78274 .2014 Mdot
.78367 .20153 Mdot
.7846 .20164 Mdot
.78553 .20171 Mdot
.78646 .20176 Mdot
.78739 .20178 Mdot
.78832 .20179 Mdot
.78925 .20177 Mdot
.79018 .20174 Mdot
.79111 .20169 Mdot
.79204 .20164 Mdot
.79297 .20157 Mdot
.7939 .2015 Mdot
.79483 .20143 Mdot
.79576 .20135 Mdot
.79669 .20127 Mdot
.79762 .2012 Mdot
.79855 .20114 Mdot
.79948 .20108 Mdot
.80041 .20104 Mdot
.80134 .20101 Mdot
.80227 .201 Mdot
.8032 .201 Mdot
.80413 .20103 Mdot
.80506 .20108 Mdot
.80599 .20115 Mdot
.80692 .20125 Mdot
.80785 .20138 Mdot
.80878 .20154 Mdot
.80971 .20173 Mdot
.81064 .20195 Mdot
.81157 .2022 Mdot
.8125 .2025 Mdot
.81343 .20282 Mdot
.81436 .20319 Mdot
.81529 .20359 Mdot
.81622 .20403 Mdot
.81715 .20451 Mdot
.81808 .20502 Mdot
.81901 .20558 Mdot
.81994 .20617 Mdot
.82087 .2068 Mdot
.8218 .20747 Mdot
.82273 .20818 Mdot
.82366 .20892 Mdot
.82459 .20969 Mdot
.82552 .2105 Mdot
.82645 .21135 Mdot
.82738 .21222 Mdot
.82831 .21313 Mdot
.82924 .21406 Mdot
.83017 .21502 Mdot
.8311 .21601 Mdot
.83203 .21702 Mdot
.83296 .21805 Mdot
.83389 .21909 Mdot
.83482 .22016 Mdot
.83575 .22124 Mdot
.83668 .22234 Mdot
.83761 .22344 Mdot
.83854 .22455 Mdot
.83947 .22567 Mdot
.8404 .22679 Mdot
.84133 .22791 Mdot
.84226 .22903 Mdot
.84319 .23015 Mdot
.84412 .23126 Mdot
.84505 .23236 Mdot
.84598 .23346 Mdot
.84691 .23454 Mdot
.84784 .2356 Mdot
.84877 .23665 Mdot
.8497 .23767 Mdot
.85063 .23868 Mdot
.85156 .23967 Mdot
.85249 .24063 Mdot
.85342 .24156 Mdot
.85435 .24246 Mdot
.85528 .24334 Mdot
.85621 .24419 Mdot
.85714 .245 Mdot
.85807 .24579 Mdot
.859 .24654 Mdot
.85993 .24725 Mdot
.86086 .24793 Mdot
.86179 .24858 Mdot
.86272 .24919 Mdot
.86365 .24976 Mdot
.86458 .2503 Mdot
.86551 .25081 Mdot
.86644 .25127 Mdot
.86737 .25171 Mdot
.8683 .25211 Mdot
.86923 .25247 Mdot
.87016 .25281 Mdot
.87109 .25311 Mdot
.87202 .25338 Mdot
.87295 .25363 Mdot
.87388 .25384 Mdot
.87481 .25403 Mdot
.87574 .25419 Mdot
.87667 .25433 Mdot
.8776 .25445 Mdot
.87853 .25455 Mdot
.87946 .25463 Mdot
.88039 .2547 Mdot
.88132 .25475 Mdot
.88225 .25479 Mdot
.88318 .25483 Mdot
.88411 .25485 Mdot
.88504 .25487 Mdot
.88597 .25489 Mdot
.8869 .2549 Mdot
.88783 .25492 Mdot
.88876 .25494 Mdot
.88969 .25497 Mdot
.89063 .25501 Mdot
.89156 .25506 Mdot
.89249 .25512 Mdot
.89342 .25519 Mdot
.89435 .25528 Mdot
.89528 .25539 Mdot
.89621 .25552 Mdot
.89714 .25567 Mdot
.89807 .25584 Mdot
.899 .25604 Mdot
.89993 .25627 Mdot
.90086 .25652 Mdot
.90179 .2568 Mdot
.90272 .25712 Mdot
.90365 .25746 Mdot
.90458 .25784 Mdot
.90551 .25825 Mdot
.90644 .25869 Mdot
.90737 .25916 Mdot
.9083 .25967 Mdot
.90923 .26022 Mdot
.91016 .26079 Mdot
.91109 .2614 Mdot
.91202 .26205 Mdot
.91295 .26273 Mdot
.91388 .26344 Mdot
.91481 .26418 Mdot
.91574 .26495 Mdot
.91667 .26576 Mdot
.9176 .26659 Mdot
.91853 .26745 Mdot
.91946 .26834 Mdot
.92039 .26925 Mdot
.92132 .27019 Mdot
.92225 .27115 Mdot
.92318 .27213 Mdot
.92411 .27312 Mdot
.92504 .27414 Mdot
.92597 .27517 Mdot
.9269 .27621 Mdot
.92783 .27727 Mdot
.92876 .27833 Mdot
.92969 .2794 Mdot
.93062 .28047 Mdot
.93155 .28155 Mdot
.93248 .28262 Mdot
.93341 .2837 Mdot
.93434 .28477 Mdot
.93527 .28583 Mdot
.9362 .28689 Mdot
.93713 .28793 Mdot
.93806 .28897 Mdot
.93899 .28999 Mdot
.93992 .29099 Mdot
.94085 .29198 Mdot
.94178 .29294 Mdot
.94271 .29389 Mdot
.94364 .29481 Mdot
.94457 .2957 Mdot
.9455 .29657 Mdot
.94643 .29742 Mdot
.94736 .29823 Mdot
.94829 .29902 Mdot
.94922 .29977 Mdot
.95015 .3005 Mdot
.95108 .30119 Mdot
.95201 .30185 Mdot
.95294 .30248 Mdot
.95387 .30307 Mdot
.9548 .30363 Mdot
.95573 .30416 Mdot
.95666 .30465 Mdot
.95759 .30512 Mdot
.95852 .30555 Mdot
.95945 .30594 Mdot
.96038 .30631 Mdot
.96131 .30665 Mdot
.96224 .30695 Mdot
.96317 .30723 Mdot
.9641 .30748 Mdot
.96503 .30771 Mdot
.96596 .30791 Mdot
.96689 .30809 Mdot
.96782 .30824 Mdot
.96875 .30838 Mdot
.96968 .3085 Mdot
.97061 .3086 Mdot
.97154 .30868 Mdot
.97247 .30876 Mdot
.9734 .30882 Mdot
.97433 .30888 Mdot
.97526 .30893 Mdot
.97619 .30897 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00Oogoo;Goo003oOol]
Ool00?moobeoo`00ogoo;Goo000QOol00`00Oomoo`3oOol9Ool0025oo`03001oogoo0?moo`Uoo`00
8Goo0P00ogoo2Woo000QOol00`00Oomoo`23Ool30022Ool0025oo`03001oogoo089oo`D0085oo`00
8Goo00<007ooOol0PGoo1`00P7oo000QOol00`00Oomoo`21Ool3000017oo00000000P7oo000QOol2
0022Ool20003Ool3001oOol0025oo`03001oogoo081oo`<000=oo`<007moo`008Goo00<007ooOol0
P7oo0P001Goo0P00Ogoo000QOol00`00Oomoo`20Ool20005Ool2001oOol0025oo`80085oo`8000Eo
o`<007ioo`008Goo00<007ooOol0P7oo0P001Woo0P00OWoo000QOol00`00Oomoo`1oOol30006Ool2
001nOol0025oo`03001oogoo07moo`8000Moo`<007eoo`008Goo0P00P7oo0P0027oo0P00OGoo000Q
Ool00`00Oomoo`1oOol20008Ool2001mOol000Qoo`8000Aoo`8000Aoo`03001oogoo009oo`<000Eo
o`03001oogoo07moo`8000Qoo`<007aoo`001goo00@007ooOol000=oo`8000Aoo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo07moo`8000Uoo`8007aoo`0000=oo`0000000`0000Eoo`00Oomo
o`0000Yoo`03001oogoo00Aoo`03001oogoo009oo`8007moo`<000Uoo`<007]oo`001goo00@007oo
Ool000Yoo`04001oogooOol30005Ool00`00Oomoo`1nOol2000:Ool3001kOol000Moo`04001oogoo
000;Ool01000Oomoo`001goo00<007ooOol0OWoo0P002goo0P00Ngoo0008Ool20009Ool40002Ool4
0004Ool00`00Oomoo`1nOol2000;Ool3001jOol0025oo`8007moo`8000aoo`8000Yoo`H006Yoo`00
8Goo00<007ooOol0OWoo0P0037oo0`001goo2@00JGoo000QOol00`00Oomoo`1nOol2000<Ool30006
Ool40003Ool4001XOol0025oo`03001oogoo07eoo`8000ioo`<000Aoo`@000Eoo`<006Qoo`008Goo
0P00OWoo0P003Woo0`000goo10001goo0`00Igoo000QOol00`00Oomoo`1mOol2000?Ool80009Ool3
001VOol0025oo`03001oogoo07eoo`80011oo`H000Yoo`<006Ioo`008Goo00<007ooOol0OGoo0P00
8Goo0`00IGoo000QOol2001nOol2000ROol3001TOol0025oo`03001oogoo07eoo`80029oo`<006Ao
o`008Goo00<007ooOol0OGoo0P008goo0`00Hgoo000QOol00`00Oomoo`1lOol2000UOol2001SOol0
025oo`8007eoo`8002Eoo`<0069oo`008Goo00<007ooOol0O7oo0P009Woo0`00HGoo000>Ool20004
Ool20003Ool30005Ool00`00Oomoo`1lOol2000VOol40007Ool4001EOol000eoo`04001oogoo0003
Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`1lOol2000WOol500000goo00000008001COol000Mo
o`D00005Ool007ooOol0000;Ool00`00Oomoo`02Ool2001mOol2000XOol:0002Ool5001AOol000eo
o`04001oogoo0008Ool30005Ool00`00Oomoo`2XOol50007Ool4001@Ool000eoo`04001oogoo0008
Ool00`00Oomoo`05Ool00`00Oomoo`1lOol2000gOol4001?Ool000ioo`8000Uoo`@000Aoo`03001o
ogoo07aoo`8003Qoo`<004moo`008Goo0P00O7oo0P00>Woo0`00CWoo000QOol00`00Oomoo`1kOol2
000jOol4001=Ool0025oo`03001oogoo07]oo`8003]oo`<004eoo`008Goo00<007ooOol0Ngoo0P00
?7oo0`00C7oo000QOol2002kOol3001;Ool0025oo`03001oogoo07]oo`8003eoo`@004Yoo`008Goo
00<007ooOol0Ngoo0P00?Woo1000BGoo000QOol00`00Oomoo`1kOol2000oOol40018Ool0025oo`80
07aoo`80041oo`H00003Ool0000000@003ioo`008Goo00<007ooOol0_goo3@00?7oo000QOol00`00
Oomoo`1jOol20016Ool40002Ool6000jOol0025oo`03001oogoo07Yoo`8004moo`@003Uoo`008Goo
0P00Ngoo0P00D7oo1000>7oo000QOol00`00Oomoo`1jOol2001AOol4000gOol0025oo`03001oogoo
0<ioo`@003Ioo`0027oo0P0017oo0P000goo10000Woo0`001Goo00<007ooOol0NWoo0P00Dgoo0`00
=Woo0007Ool01000Oomoo`000goo0P0017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
NWoo0P00E7oo0`00=Goo00000goo0000000300001Goo001oogoo00002Woo00<007ooOol017oo00<0
07ooOol00Woo0P00dWoo0`00=7oo0007Ool01000Oomoo`002goo00<007ooOol00`001Goo00<007oo
Ool0NWoo0P00EWoo0`00<goo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo07Yoo`8005Ioo`@0039oo`0027oo0P002Woo0P000goo100017oo00<007ooOol0NGoo
0P00F7oo1000<Goo000QOol2001jOol2001IOol5000_Ool0025oo`03001oogoo0=Eoo``002Moo`00
8Goo00<007ooOol0NGoo0P00G7oo30009Goo000QOol00`00Oomoo`1iOol2001TOol6000SOol0025o
o`800>=oo`@0029oo`008Goo00<007ooOol0NGoo0P00J7oo10008Goo000QOol00`00Oomoo`0UOol4
0003Ool20004Ool2000ROol30003Ool20004Ool2000EOol2000<Ool20004Ool20004Ool2000ROol2
0004Ool20004Ool2000NOol50002Ool20004Ool20004Ool2000@Ool0025oo`03001oogoo02Ioo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`008Woo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`0BOol2000;Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000P
Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000NOol60002Ool01000Oomoo`000Woo
00@007ooOol0009oo`03001oogoo00eoo`008Goo0P00:7oo00D007ooOomoo`00009oo`04001oogoo
0002Ool00`00Oomoo`0NOol40002Ool01000Oomoo`000Woo00@007ooOol001Aoo`8000]oo`04001o
ogoo0002Ool01000Oomoo`000Woo00@007ooOol0021oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol001ioo`03001oo`0000<0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo
Ool03Goo000QOol00`00Oomoo`0XOol01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo01io
o`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`008Goo0`000goo00@007ooOol0009oo`04
001oogoo000QOol20003Ool01000Oomoo`000Woo00@007ooOol001ioo`03001oogoo00@00005Ool0
07ooOol00002Ool01000Oomoo`000Woo00<007ooOol03Goo000QOol00`00Oomoo`0UOol01000Oomo
o`000Woo00@007ooOol0009oo`04001oogoo000POol00`00Ool00003Ool01000Oomoo`000Woo00@0
07ooOol001Aoo`8000]oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`0087oo00@007oo
Ool0009oo`04001oogoo0002Ool01000Oomoo`007Woo00@007ooOomoo`D0009oo`04001oogoo0002
Ool01000Oomoo`003goo000QOol00`00Oomoo`0VOol20004Ool20004Ool2000ROol20004Ool20004
Ool2000EOol2000<Ool30003Ool20004Ool2000ROol20004Ool20004Ool2000NOol20004Ool40003
Ool20004Ool2000@Ool0025oo`800>]oo`@001Yoo`008Goo00<007ooOol0N7oo0P00LGoo10006Goo
000QOol00`00Oomoo`1hOol2001bOol5000@Ool200000goo00000002Ool0021oo`@007Qoo`8007=o
o`P000eoo`03001oo`0000=oo`006gooo`001@0027oo00<007ooOol00Woo000QOol80004Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00
Ool00003Ool0025oo`03001oogoo009oo`@0079oo`8008Moo`800003Ool00000009oo`008Goo00<0
07ooOol00goo1000LGoo0P00SWoo000QOol20006Ool3003oOol1Ool0025oo`03001oogoo00Ioo`<0
06moo`8008ioo`008Goo00<007ooOol01goo0`00KWoo0P00SWoo000QOol00`00Oomoo`08Ool3003m
Ool0025oo`8000Uoo`@006]oo`8008moo`008Goo00<007ooOol02Goo1000JWoo0P00Sgoo000QOol0
0`00Oomoo`0:Ool4001YOol2002?Ool0025oo`03001oogoo00]oo`@006Qoo`8008moo`008Goo0P00
3Goo1@00mgoo000QOol00`00Oomoo`0=Ool;001OOol2002?Ool0025oo`03001oogoo00moo``005ao
o`8008moo`008Goo00<007ooOol05Woo1`00jgoo000QOol2000KOol4001IOol2002?Ool0025oo`03
001oogoo01]oo`@005Qoo`8008moo`0027oo0P0017oo0P000goo10000Woo0`001Goo00<007ooOol0
77oo1000EWoo0P00T7oo0007Ool01000Oomoo`000goo0P0017oo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol07Goo1000EGoo0P00T7oo0007Ool01000Oomoo`002Woo00<007ooOol017oo00<0
07ooOol00Woo0P007goo1000iWoo0007Ool01000Oomoo`002goo00<007ooOol00`001Goo00<007oo
Ool07goo0`00E7oo0P00T7oo0007Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo00Eo
o`03001oogoo021oo`<005=oo`80091oo`0027oo0P002Woo0P000goo100017oo00<007ooOol08Goo
0`00DWoo0P00T7oo000QOol2000SOol3001AOol2002@Ool0025oo`03001oogoo029oo`@00>9oo`00
8Goo00<007ooOol097oo1000CWoo0P00T7oo000QOol00`00Oomoo`0UOol=0014Ool2002@Ool0025o
o`8002Moo`h00=Aoo`008Goo00<007ooOol0<7oo1@00@7oo0P00TGoo000QOol00`00Oomoo`0bOol4
000oOol2002AOol0025oo`03001oogoo03=oo`@003ioo`80095oo`008Goo0P00=Goo1000?Goo0P00
TGoo000QOol00`00Oomoo`0eOol4000lOol2002AOol0025oo`03001oogoo03Ioo`<003aoo`80095o
o`008Goo00<007ooOol0=goo0`00cWoo000QOol00`00Oomoo`0hOol3000jOol2002AOol0025oo`80
03Uoo`@003Uoo`80095oo`008Goo00<007ooOol0>Goo1000=goo0P00TWoo000>Ool20004Ool20003
Ool30005Ool00`00Oomoo`0jOol3000gOol2002BOol000eoo`04001oogoo0003Ool20006Ool00`00
Oomoo`02Ool00`00Oomoo`0kOol40005Ool6000ZOol2002BOol000eoo`04001oogoo000;Ool00`00
Oomoo`02Ool2000mOol@000XOol2002BOol000eoo`04001oogoo0008Ool30005Ool00`00Oomoo`0m
Ool90002Ool5002kOol000eoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`1:Ool4000V
Ool2002BOol000ioo`8000Uoo`@000Aoo`03001oogoo04]oo`@002Eoo`80099oo`008Goo0P00CGoo
0`009Goo0P00TWoo000QOol00`00Oomoo`1=Ool3000TOol2002BOol0025oo`03001oogoo04eoo`@0
029oo`8009=oo`008Goo00<007ooOol0CWoo0`008Woo0P00Tgoo000QOol2001@Ool2000ROol2002C
Ool0025oo`03001oogoo04moo`<000aoo`@0015oo`8009=oo`008Goo00<007ooOol0D7oo0`002Woo
1`003goo0P00Tgoo000QOol00`00Oomoo`1@Ool30009Ool8000?Ool2002COol0025oo`80059oo`<0
00Moo`@000=oo`<000ioo`8009=oo`008Goo00<007ooOol0DWoo0`001Goo10001Goo0P003Woo0P00
Tgoo000QOol00`00Oomoo`1COol30002Ool50006Ool3000<Ool2002DOol0025oo`03001oogoo05=o
o`P000Uoo`8000aoo`8009Aoo`008Goo0P00EWoo1@002Woo0`002goo0P00U7oo000QOol00`00Oomo
o`1TOol3000;Ool2002DOol000Qoo`8000Aoo`8000Aoo`03001oogoo009oo`<000Eoo`03001oogoo
06Eoo`8000]oo`8009Aoo`001goo00@007ooOol000=oo`8000Aoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo06Eoo`<000Yoo`8009Aoo`001goo00@007ooOol000Yoo`03001oogoo00Aoo`03
001oogoo009oo`8006Moo`8000Yoo`8009Aoo`001goo00@007ooOol000Yoo`04001oogooOol30005
Ool00`00Oomoo`1VOol2000:Ool2002DOol000Moo`04001oogoo000;Ool01000Oomoo`001goo00<0
07ooOol0IWoo0`0027oo0P00UGoo0008Ool20009Ool40002Ool40004Ool00`00Oomoo`1WOol20008
Ool2002EOol0025oo`8006Qoo`8000Qoo`8009Eoo`008Goo00<007ooOol0Igoo0`001goo0P00UGoo
000QOol00`00Oomoo`1XOol20007Ool2002EOol0025oo`03001oogoo06Qoo`8000Ioo`<009Eoo`00
8Goo0P00JGoo0`001Goo0P00UWoo000QOol00`00Oomoo`1YOol20005Ool2002FOol0025oo`03001o
ogoo06Uoo`<000Aoo`8009Ioo`008Goo00<007ooOol0JGoo0`000goo0`00UWoo000QOol2001[Ool3
0002Ool2002GOol0025oo`03001oogoo06Yoo`<00004Ool00000002GOol0025oo`03001oogoo06]o
o`H009Moo`008Goo00<007ooOol0Jgoo1@00V7oo000QOol2001]Ool3002IOol0025oo`03001oogoo
0?moo`Uoo`008Goo00<007ooOol0ogoo2Goo000QOol00`00Oomoo`3oOol9Ool00?moobeoo`00ogoo
;Goo003oOol]Ool00<moo`03001oogoo00Qoo`03001oogoo04moo`00cWoo00<007ooOol02Woo00<0
07ooOol0CWoo001KOol40003Ool40002Ool30003Ool30002Ool2000017oo000007oo10000goo0`00
0Woo10000Woo1@000Woo0`000goo0`000Woo1@000Woo0`000Woo0P0000=oo`00000027oo0`000Woo
100027oo1@000Woo00@007ooOomoo`800003Ool0000000Aoo`03001oogoo04ioo`00G7oo00<007oo
Ool00Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`03
Ool01@00Oomoogoo00000Woo00@007ooOol000Aoo`04001oogoo0002Ool01@00Oomoogoo00000Woo
00@007ooOol000=oo`05001oogooOol00003Ool00`00Ool00002Ool00`00Oomoo`06Ool01@00Oomo
ogoo00000Woo00<007ooOol027oo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Eoo`03
001oogoo04ioo`00G7oo00<007ooOol00Woo1@0000=oo`00Ool017oo00L007ooOomoo`00Ool00002
Ool00`00Oomoo`040003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
Ool017oo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oo`00009oo`03001oogoo00Ioo`05
001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000goo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol0CWoo001LOol20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03
001oo`00009oo`04001oogoo0006Ool00`00Oomoo`03Ool20003Ool01000Oomoo`000Woo00D007oo
Oomoo`00009oo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Ool00002Ool00`00Oomoo`06
Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007ooOol000=oo`03001oogoo009oo`03001o
o`0000Eoo`03001oogoo04ioo`00Fgoo0P0000=oo`0000000Woo0`000goo10000Woo0`0000=oo`00
00000`000Woo10000Woo10000Woo0P0000=oo`0000000P0000=oo`0000000goo100000=oo`000000
0P000goo0P0017oo0`0000=oo`0000000`002Goo0`000Woo10001goo0P0000=oo`0000000goo00@0
07ooOomoo`800003Ool0000000Aoo`03001oogoo04ioo`00P7oo00<007ooOol05Goo00<007ooOol0
8Goo00<007ooOol047oo00<007ooOol027oo00<007ooOol0Cgoo0020Ool00`00Oomoo`0EOol00`00
Oomoo`04Ool00`00Oomoo`0JOol3001]Ool00?moobeoo`00ogoo;Goo003oOol]Ool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-137.771, -1.0232, 4.14422, 
  0.0122717}},
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["As expected, the errors are also larger.", "MathCaption",
  CellTags->{"S2.1.1", "1.42"}],

Cell[CellGroupData[{

Cell["\<\
{Max[Abs[data-newdata]],
Sqrt[(data-newdata).(data-newdata)/(data.data)]}\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \({0.594046340032806785`, 0.195684678119535035`}\)], "Output",
  CellLabel->"Out[28]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["Random Shocks", "Subsubsection",
  CellTags->{"S2.1.1", "1.43"}],

Cell[TextData[{
  "In this example, we look at another solution to the Burgers equation. This \
time the solution evolves from an initial condition that is a superposition \
of sine waves of different frequencies with random amplitudes. The velocity \
profile as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 200\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is in the file ",
  StyleBox["shockran.dat", "MR"],
  ". For variety, we will analyze these data with a different wavelet basis, \
the spline wavelet of order 3. "
}], "Text",
  CellTags->{"S2.1.1", "1.44"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.1", "1.45"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.1"],

Cell["This reads in the content of the file.", "MathCaption",
  CellTags->{"S2.1.1", "1.46"}],

Cell["\<\
data = Get[ToFileName[{\"Wavelets\", \"Data\"}, \"shockran.dat\"]];\
\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.1"],

Cell[TextData[{
  "This shows the velocity profile at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 200\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ". In this case, more than one shock is present in the system."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.47"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[data, AxesLabel -> {\"x\", \"\"},
PlotLabel -> \"velocity profile u(x) at t=200\"]\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.346518 0.558838 [
[.20982 .33402 -9 -9 ]
[.20982 .33402 9 0 ]
[.39583 .33402 -9 -9 ]
[.39583 .33402 9 0 ]
[.58185 .33402 -9 -9 ]
[.58185 .33402 9 0 ]
[.76786 .33402 -9 -9 ]
[.76786 .33402 9 0 ]
[.95387 .33402 -12 -9 ]
[.95387 .33402 12 0 ]
[1.025 .34652 0 -4.5 ]
[1.025 .34652 6 4.5 ]
[.01131 .01122 -24 -4.5 ]
[.01131 .01122 0 4.5 ]
[.01131 .12298 -24 -4.5 ]
[.01131 .12298 0 4.5 ]
[.01131 .23475 -24 -4.5 ]
[.01131 .23475 0 4.5 ]
[.01131 .45829 -18 -4.5 ]
[.01131 .45829 0 4.5 ]
[.01131 .57005 -18 -4.5 ]
[.01131 .57005 0 4.5 ]
[.5 .63053 -90 0 ]
[.5 .63053 90 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .34652 m
.20982 .35277 L
s
[(200)] .20982 .33402 0 1 Mshowa
.39583 .34652 m
.39583 .35277 L
s
[(400)] .39583 .33402 0 1 Mshowa
.58185 .34652 m
.58185 .35277 L
s
[(600)] .58185 .33402 0 1 Mshowa
.76786 .34652 m
.76786 .35277 L
s
[(800)] .76786 .33402 0 1 Mshowa
.95387 .34652 m
.95387 .35277 L
s
[(1000)] .95387 .33402 0 1 Mshowa
.125 Mabswid
.07031 .34652 m
.07031 .35027 L
s
.11682 .34652 m
.11682 .35027 L
s
.16332 .34652 m
.16332 .35027 L
s
.25632 .34652 m
.25632 .35027 L
s
.30283 .34652 m
.30283 .35027 L
s
.34933 .34652 m
.34933 .35027 L
s
.44234 .34652 m
.44234 .35027 L
s
.48884 .34652 m
.48884 .35027 L
s
.53534 .34652 m
.53534 .35027 L
s
.62835 .34652 m
.62835 .35027 L
s
.67485 .34652 m
.67485 .35027 L
s
.72135 .34652 m
.72135 .35027 L
s
.81436 .34652 m
.81436 .35027 L
s
.86086 .34652 m
.86086 .35027 L
s
.90737 .34652 m
.90737 .35027 L
s
.25 Mabswid
0 .34652 m
1 .34652 L
s
[(x)] 1.025 .34652 -1 0 Mshowa
.02381 .01122 m
.03006 .01122 L
s
[(-0.6)] .01131 .01122 1 0 Mshowa
.02381 .12298 m
.03006 .12298 L
s
[(-0.4)] .01131 .12298 1 0 Mshowa
.02381 .23475 m
.03006 .23475 L
s
[(-0.2)] .01131 .23475 1 0 Mshowa
.02381 .45829 m
.03006 .45829 L
s
[(0.2)] .01131 .45829 1 0 Mshowa
.02381 .57005 m
.03006 .57005 L
s
[(0.4)] .01131 .57005 1 0 Mshowa
.125 Mabswid
.02381 .03916 m
.02756 .03916 L
s
.02381 .0671 m
.02756 .0671 L
s
.02381 .09504 m
.02756 .09504 L
s
.02381 .15093 m
.02756 .15093 L
s
.02381 .17887 m
.02756 .17887 L
s
.02381 .20681 m
.02756 .20681 L
s
.02381 .26269 m
.02756 .26269 L
s
.02381 .29063 m
.02756 .29063 L
s
.02381 .31858 m
.02756 .31858 L
s
.02381 .37446 m
.02756 .37446 L
s
.02381 .4024 m
.02756 .4024 L
s
.02381 .43034 m
.02756 .43034 L
s
.02381 .48623 m
.02756 .48623 L
s
.02381 .51417 m
.02756 .51417 L
s
.02381 .54211 m
.02756 .54211 L
s
.02381 .598 m
.02756 .598 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(velocity profile u\\(x\\) at t=200)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02474 .28812 Mdot
.02567 .28875 Mdot
.0266 .28928 Mdot
.02753 .28971 Mdot
.02846 .29004 Mdot
.02939 .29027 Mdot
.03032 .29041 Mdot
.03125 .29044 Mdot
.03218 .29039 Mdot
.03311 .29024 Mdot
.03404 .29001 Mdot
.03497 .2897 Mdot
.0359 .28932 Mdot
.03683 .28888 Mdot
.03776 .28837 Mdot
.03869 .28782 Mdot
.03962 .28723 Mdot
.04055 .2866 Mdot
.04148 .28595 Mdot
.04241 .28527 Mdot
.04334 .28458 Mdot
.04427 .28387 Mdot
.0452 .28315 Mdot
.04613 .28241 Mdot
.04706 .28166 Mdot
.04799 .28086 Mdot
.04892 .28003 Mdot
.04985 .27913 Mdot
.05078 .27813 Mdot
.05171 .27702 Mdot
.05264 .27573 Mdot
.05357 .27423 Mdot
.0545 .27246 Mdot
.05543 .27033 Mdot
.05636 .26778 Mdot
.05729 .26471 Mdot
.05822 .26102 Mdot
.05915 .25659 Mdot
.06008 .25131 Mdot
.06101 .24507 Mdot
.06194 .23777 Mdot
.06287 .22932 Mdot
.0638 .21967 Mdot
.06473 .2088 Mdot
.06566 .19676 Mdot
.06659 .18367 Mdot
.06752 .1697 Mdot
.06845 .1551 Mdot
.06938 .14014 Mdot
.07031 .12517 Mdot
.07124 .1105 Mdot
.07217 .09645 Mdot
.0731 .08327 Mdot
.07403 .07119 Mdot
.07496 .06033 Mdot
.07589 .05078 Mdot
.07682 .04254 Mdot
.07775 .03558 Mdot
.07868 .02983 Mdot
.07961 .0252 Mdot
.08054 .02158 Mdot
.08147 .01884 Mdot
.0824 .01689 Mdot
.08333 .01562 Mdot
.08426 .01492 Mdot
.08519 .01472 Mdot
.08612 .01493 Mdot
.08705 .01549 Mdot
.08798 .01634 Mdot
.08891 .01743 Mdot
.08984 .01873 Mdot
.09077 .02019 Mdot
.0917 .0218 Mdot
.09263 .02351 Mdot
.09356 .02532 Mdot
.09449 .02721 Mdot
.09542 .02916 Mdot
.09635 .03116 Mdot
.09728 .03321 Mdot
.09821 .03529 Mdot
.09914 .0374 Mdot
.10007 .03953 Mdot
.101 .04168 Mdot
.10193 .04384 Mdot
.10286 .04602 Mdot
.10379 .04821 Mdot
.10472 .05041 Mdot
.10565 .05261 Mdot
.10658 .05482 Mdot
.10751 .05703 Mdot
.10844 .05924 Mdot
.10938 .06146 Mdot
.11031 .06368 Mdot
.11124 .0659 Mdot
.11217 .06812 Mdot
.1131 .07034 Mdot
.11403 .07257 Mdot
.11496 .07479 Mdot
.11589 .07702 Mdot
.11682 .07924 Mdot
.11775 .08146 Mdot
.11868 .08369 Mdot
.11961 .08591 Mdot
.12054 .08814 Mdot
.12147 .09036 Mdot
.1224 .09259 Mdot
.12333 .09481 Mdot
.12426 .09704 Mdot
.12519 .09927 Mdot
.12612 .10149 Mdot
.12705 .10372 Mdot
.12798 .10595 Mdot
.12891 .10818 Mdot
.12984 .11041 Mdot
.13077 .11264 Mdot
.1317 .11488 Mdot
.13263 .11711 Mdot
.13356 .11935 Mdot
.13449 .12159 Mdot
.13542 .12383 Mdot
.13635 .12607 Mdot
.13728 .12832 Mdot
.13821 .13057 Mdot
.13914 .13282 Mdot
.14007 .13507 Mdot
.141 .13732 Mdot
.14193 .13958 Mdot
.14286 .14184 Mdot
.14379 .14411 Mdot
.14472 .14637 Mdot
.14565 .14864 Mdot
.14658 .15092 Mdot
.14751 .1532 Mdot
.14844 .15548 Mdot
.14937 .15776 Mdot
.1503 .16005 Mdot
.15123 .16234 Mdot
.15216 .16464 Mdot
.15309 .16694 Mdot
.15402 .16925 Mdot
.15495 .17155 Mdot
.15588 .17387 Mdot
.15681 .17619 Mdot
.15774 .17851 Mdot
.15867 .18084 Mdot
.1596 .18317 Mdot
.16053 .1855 Mdot
.16146 .18785 Mdot
.16239 .19019 Mdot
.16332 .19254 Mdot
.16425 .1949 Mdot
.16518 .19726 Mdot
.16611 .19962 Mdot
.16704 .20199 Mdot
.16797 .20437 Mdot
.1689 .20674 Mdot
.16983 .20913 Mdot
.17076 .21152 Mdot
.17169 .21391 Mdot
.17262 .21631 Mdot
.17355 .21872 Mdot
.17448 .22112 Mdot
.17541 .22354 Mdot
.17634 .22596 Mdot
.17727 .22838 Mdot
.1782 .23081 Mdot
.17913 .23324 Mdot
.18006 .23568 Mdot
.18099 .23812 Mdot
.18192 .24057 Mdot
.18285 .24302 Mdot
.18378 .24547 Mdot
.18471 .24793 Mdot
.18564 .2504 Mdot
.18657 .25287 Mdot
.1875 .25534 Mdot
.18843 .25782 Mdot
.18936 .2603 Mdot
.19029 .26279 Mdot
.19122 .26528 Mdot
.19215 .26778 Mdot
.19308 .27028 Mdot
.19401 .27278 Mdot
.19494 .27529 Mdot
.19587 .2778 Mdot
.1968 .28031 Mdot
.19773 .28283 Mdot
.19866 .28536 Mdot
.19959 .28788 Mdot
.20052 .29041 Mdot
.20145 .29295 Mdot
.20238 .29548 Mdot
.20331 .29803 Mdot
.20424 .30057 Mdot
.20517 .30312 Mdot
.2061 .30567 Mdot
.20703 .30822 Mdot
.20796 .31078 Mdot
.20889 .31334 Mdot
.20982 .3159 Mdot
.21075 .31847 Mdot
.21168 .32104 Mdot
.21261 .32361 Mdot
.21354 .32619 Mdot
.21447 .32877 Mdot
.2154 .33135 Mdot
.21633 .33393 Mdot
.21726 .33651 Mdot
.21819 .3391 Mdot
.21912 .34169 Mdot
.22005 .34429 Mdot
.22098 .34688 Mdot
.22191 .34948 Mdot
.22284 .35208 Mdot
.22377 .35468 Mdot
.2247 .35728 Mdot
.22563 .35989 Mdot
.22656 .36249 Mdot
.22749 .3651 Mdot
.22842 .36771 Mdot
.22935 .37033 Mdot
.23028 .37294 Mdot
.23121 .37555 Mdot
.23214 .37817 Mdot
.23307 .38079 Mdot
.234 .3834 Mdot
.23493 .38602 Mdot
.23586 .38864 Mdot
.23679 .39126 Mdot
.23772 .39387 Mdot
.23865 .39649 Mdot
.23958 .39911 Mdot
.24051 .40172 Mdot
.24144 .40434 Mdot
.24237 .40695 Mdot
.2433 .40955 Mdot
.24423 .41216 Mdot
.24516 .41476 Mdot
.24609 .41735 Mdot
.24702 .41994 Mdot
.24795 .42252 Mdot
.24888 .42508 Mdot
.24981 .42764 Mdot
.25074 .43018 Mdot
.25167 .43271 Mdot
.2526 .43521 Mdot
.25353 .4377 Mdot
.25446 .44015 Mdot
.25539 .44258 Mdot
.25632 .44496 Mdot
.25725 .44731 Mdot
.25818 .4496 Mdot
.25911 .45183 Mdot
.26004 .45399 Mdot
.26097 .45607 Mdot
.2619 .45805 Mdot
.26283 .45992 Mdot
.26376 .46166 Mdot
.26469 .46326 Mdot
.26563 .46467 Mdot
.26656 .46589 Mdot
.26749 .46688 Mdot
.26842 .4676 Mdot
.26935 .46803 Mdot
.27028 .46811 Mdot
.27121 .4678 Mdot
.27214 .46707 Mdot
.27307 .46585 Mdot
.274 .46411 Mdot
.27493 .46179 Mdot
.27586 .45886 Mdot
.27679 .45527 Mdot
.27772 .45101 Mdot
.27865 .44606 Mdot
.27958 .44043 Mdot
.28051 .43414 Mdot
.28144 .42724 Mdot
.28237 .41982 Mdot
.2833 .41195 Mdot
.28423 .40376 Mdot
.28516 .39539 Mdot
.28609 .38696 Mdot
.28702 .37864 Mdot
.28795 .37055 Mdot
.28888 .36282 Mdot
.28981 .35557 Mdot
.29074 .34888 Mdot
.29167 .34282 Mdot
.2926 .33742 Mdot
.29353 .33271 Mdot
.29446 .32868 Mdot
.29539 .32532 Mdot
.29632 .3226 Mdot
.29725 .32048 Mdot
.29818 .31892 Mdot
.29911 .31787 Mdot
.30004 .31728 Mdot
.30097 .3171 Mdot
.3019 .31729 Mdot
.30283 .31781 Mdot
.30376 .31861 Mdot
.30469 .31967 Mdot
.30562 .32094 Mdot
.30655 .32241 Mdot
.30748 .32404 Mdot
.30841 .32581 Mdot
.30934 .3277 Mdot
.31027 .3297 Mdot
.3112 .33179 Mdot
.31213 .33396 Mdot
.31306 .33619 Mdot
.31399 .33848 Mdot
.31492 .34082 Mdot
.31585 .34319 Mdot
.31678 .34561 Mdot
.31771 .34805 Mdot
.31864 .35052 Mdot
.31957 .35301 Mdot
.3205 .35551 Mdot
.32143 .35803 Mdot
.32236 .36056 Mdot
.32329 .3631 Mdot
.32422 .36565 Mdot
.32515 .3682 Mdot
.32608 .37075 Mdot
.32701 .37331 Mdot
.32794 .37587 Mdot
.32887 .37843 Mdot
.3298 .38098 Mdot
.33073 .38353 Mdot
.33166 .38608 Mdot
.33259 .38861 Mdot
.33352 .39115 Mdot
.33445 .39367 Mdot
.33538 .39618 Mdot
.33631 .39868 Mdot
.33724 .40116 Mdot
.33817 .40363 Mdot
.3391 .40608 Mdot
.34003 .40851 Mdot
.34096 .41092 Mdot
.34189 .4133 Mdot
.34282 .41566 Mdot
.34375 .41798 Mdot
.34468 .42027 Mdot
.34561 .42252 Mdot
.34654 .42472 Mdot
.34747 .42688 Mdot
.3484 .42898 Mdot
.34933 .43102 Mdot
.35026 .433 Mdot
.35119 .4349 Mdot
.35212 .43672 Mdot
.35305 .43845 Mdot
.35398 .44008 Mdot
.35491 .4416 Mdot
.35584 .44299 Mdot
.35677 .44424 Mdot
.3577 .44534 Mdot
.35863 .44626 Mdot
.35956 .447 Mdot
.36049 .44752 Mdot
.36142 .4478 Mdot
.36235 .44782 Mdot
.36328 .44753 Mdot
.36421 .44692 Mdot
.36514 .44594 Mdot
.36607 .44454 Mdot
.367 .44268 Mdot
.36793 .44031 Mdot
.36886 .43737 Mdot
.36979 .4338 Mdot
.37072 .42955 Mdot
.37165 .42454 Mdot
.37258 .41873 Mdot
.37351 .41206 Mdot
.37444 .4045 Mdot
.37537 .39601 Mdot
.3763 .38659 Mdot
.37723 .37627 Mdot
.37816 .36511 Mdot
.37909 .35321 Mdot
.38002 .34069 Mdot
.38095 .32771 Mdot
.38188 .31448 Mdot
.38281 .30118 Mdot
.38374 .28805 Mdot
.38467 .27529 Mdot
.3856 .26308 Mdot
.38653 .25158 Mdot
.38746 .24093 Mdot
.38839 .2312 Mdot
.38932 .22245 Mdot
.39025 .2147 Mdot
.39118 .20793 Mdot
.39211 .2021 Mdot
.39304 .19717 Mdot
.39397 .19308 Mdot
.3949 .18974 Mdot
.39583 .1871 Mdot
.39676 .18508 Mdot
.39769 .18361 Mdot
.39862 .18263 Mdot
.39955 .18207 Mdot
.40048 .1819 Mdot
.40141 .18205 Mdot
.40234 .18249 Mdot
.40327 .18317 Mdot
.4042 .18407 Mdot
.40513 .18516 Mdot
.40606 .1864 Mdot
.40699 .18779 Mdot
.40792 .18929 Mdot
.40885 .19089 Mdot
.40978 .19258 Mdot
.41071 .19435 Mdot
.41164 .19618 Mdot
.41257 .19807 Mdot
.4135 .2 Mdot
.41443 .20198 Mdot
.41536 .20398 Mdot
.41629 .20602 Mdot
.41722 .20809 Mdot
.41815 .21017 Mdot
.41908 .21227 Mdot
.42001 .21439 Mdot
.42094 .21651 Mdot
.42188 .21865 Mdot
.42281 .2208 Mdot
.42374 .22295 Mdot
.42467 .22511 Mdot
.4256 .22727 Mdot
.42653 .22943 Mdot
.42746 .23159 Mdot
.42839 .23375 Mdot
.42932 .23591 Mdot
.43025 .23807 Mdot
.43118 .24023 Mdot
.43211 .24239 Mdot
.43304 .24454 Mdot
.43397 .24668 Mdot
.4349 .24882 Mdot
.43583 .25095 Mdot
.43676 .25308 Mdot
.43769 .2552 Mdot
.43862 .25731 Mdot
.43955 .25942 Mdot
.44048 .26151 Mdot
.44141 .2636 Mdot
.44234 .26567 Mdot
.44327 .26773 Mdot
.4442 .26978 Mdot
.44513 .27182 Mdot
.44606 .27384 Mdot
.44699 .27585 Mdot
.44792 .27784 Mdot
.44885 .27982 Mdot
.44978 .28178 Mdot
.45071 .28372 Mdot
.45164 .28564 Mdot
.45257 .28755 Mdot
.4535 .28943 Mdot
.45443 .29129 Mdot
.45536 .29312 Mdot
.45629 .29494 Mdot
.45722 .29672 Mdot
.45815 .29849 Mdot
.45908 .30022 Mdot
.46001 .30193 Mdot
.46094 .3036 Mdot
.46187 .30525 Mdot
.4628 .30687 Mdot
.46373 .30845 Mdot
.46466 .31 Mdot
.46559 .31152 Mdot
.46652 .313 Mdot
.46745 .31445 Mdot
.46838 .31586 Mdot
.46931 .31724 Mdot
.47024 .31858 Mdot
.47117 .31988 Mdot
.4721 .32115 Mdot
.47303 .32238 Mdot
.47396 .32357 Mdot
.47489 .32473 Mdot
.47582 .32585 Mdot
.47675 .32693 Mdot
.47768 .32798 Mdot
.47861 .329 Mdot
.47954 .32999 Mdot
.48047 .33094 Mdot
.4814 .33187 Mdot
.48233 .33276 Mdot
.48326 .33364 Mdot
.48419 .33449 Mdot
.48512 .33532 Mdot
.48605 .33613 Mdot
.48698 .33693 Mdot
.48791 .33771 Mdot
.48884 .33848 Mdot
.48977 .33925 Mdot
.4907 .34001 Mdot
.49163 .34078 Mdot
.49256 .34154 Mdot
.49349 .34231 Mdot
.49442 .34309 Mdot
.49535 .34388 Mdot
.49628 .34469 Mdot
.49721 .34551 Mdot
.49814 .34635 Mdot
.49907 .34722 Mdot
.5 .34811 Mdot
.50093 .34902 Mdot
.50186 .34997 Mdot
.50279 .35094 Mdot
.50372 .35195 Mdot
.50465 .353 Mdot
.50558 .35408 Mdot
.50651 .35519 Mdot
.50744 .35635 Mdot
.50837 .35754 Mdot
.5093 .35877 Mdot
.51023 .36004 Mdot
.51116 .36134 Mdot
.51209 .36269 Mdot
.51302 .36407 Mdot
.51395 .3655 Mdot
.51488 .36696 Mdot
.51581 .36846 Mdot
.51674 .36999 Mdot
.51767 .37156 Mdot
.5186 .37316 Mdot
.51953 .3748 Mdot
.52046 .37647 Mdot
.52139 .37816 Mdot
.52232 .37989 Mdot
.52325 .38165 Mdot
.52418 .38343 Mdot
.52511 .38524 Mdot
.52604 .38707 Mdot
.52697 .38892 Mdot
.5279 .39079 Mdot
.52883 .39268 Mdot
.52976 .39458 Mdot
.53069 .3965 Mdot
.53162 .39843 Mdot
.53255 .40037 Mdot
.53348 .40231 Mdot
.53441 .40427 Mdot
.53534 .40622 Mdot
.53627 .40818 Mdot
.5372 .41014 Mdot
.53813 .4121 Mdot
.53906 .41404 Mdot
.53999 .41598 Mdot
.54092 .41791 Mdot
.54185 .41983 Mdot
.54278 .42173 Mdot
.54371 .42361 Mdot
.54464 .42547 Mdot
.54557 .4273 Mdot
.5465 .4291 Mdot
.54743 .43088 Mdot
.54836 .43261 Mdot
.54929 .43431 Mdot
.55022 .43597 Mdot
.55115 .43758 Mdot
.55208 .43914 Mdot
.55301 .44065 Mdot
.55394 .4421 Mdot
.55487 .44349 Mdot
.5558 .44482 Mdot
.55673 .44608 Mdot
.55766 .44726 Mdot
.55859 .44838 Mdot
.55952 .44942 Mdot
.56045 .45038 Mdot
.56138 .45125 Mdot
.56231 .45204 Mdot
.56324 .45275 Mdot
.56417 .45337 Mdot
.5651 .4539 Mdot
.56603 .45435 Mdot
.56696 .4547 Mdot
.56789 .45498 Mdot
.56882 .45517 Mdot
.56975 .45528 Mdot
.57068 .45532 Mdot
.57161 .45529 Mdot
.57254 .45519 Mdot
.57347 .45503 Mdot
.5744 .45482 Mdot
.57533 .45457 Mdot
.57626 .45429 Mdot
.57719 .45397 Mdot
.57813 .45365 Mdot
.57906 .45331 Mdot
.57999 .45298 Mdot
.58092 .45265 Mdot
.58185 .45236 Mdot
.58278 .45209 Mdot
.58371 .45186 Mdot
.58464 .45168 Mdot
.58557 .45155 Mdot
.5865 .45149 Mdot
.58743 .4515 Mdot
.58836 .45158 Mdot
.58929 .45174 Mdot
.59022 .45199 Mdot
.59115 .45232 Mdot
.59208 .45275 Mdot
.59301 .45326 Mdot
.59394 .45387 Mdot
.59487 .45456 Mdot
.5958 .45535 Mdot
.59673 .45623 Mdot
.59766 .4572 Mdot
.59859 .45826 Mdot
.59952 .4594 Mdot
.60045 .46063 Mdot
.60138 .46193 Mdot
.60231 .46332 Mdot
.60324 .46477 Mdot
.60417 .4663 Mdot
.6051 .4679 Mdot
.60603 .46956 Mdot
.60696 .47128 Mdot
.60789 .47306 Mdot
.60882 .47489 Mdot
.60975 .47678 Mdot
.61068 .47872 Mdot
.61161 .4807 Mdot
.61254 .48272 Mdot
.61347 .48479 Mdot
.6144 .48689 Mdot
.61533 .48903 Mdot
.61626 .4912 Mdot
.61719 .4934 Mdot
.61812 .49563 Mdot
.61905 .49788 Mdot
.61998 .50017 Mdot
.62091 .50247 Mdot
.62184 .5048 Mdot
.62277 .50714 Mdot
.6237 .50951 Mdot
.62463 .51189 Mdot
.62556 .51428 Mdot
.62649 .51669 Mdot
.62742 .51911 Mdot
.62835 .52155 Mdot
.62928 .52399 Mdot
.63021 .52644 Mdot
.63114 .52891 Mdot
.63207 .53137 Mdot
.633 .53385 Mdot
.63393 .53633 Mdot
.63486 .53881 Mdot
.63579 .5413 Mdot
.63672 .54378 Mdot
.63765 .54627 Mdot
.63858 .54875 Mdot
.63951 .55123 Mdot
.64044 .5537 Mdot
.64137 .55616 Mdot
.6423 .55861 Mdot
.64323 .56103 Mdot
.64416 .56344 Mdot
.64509 .56582 Mdot
.64602 .56815 Mdot
.64695 .57044 Mdot
.64788 .57266 Mdot
.64881 .5748 Mdot
.64974 .57684 Mdot
.65067 .57874 Mdot
.6516 .58048 Mdot
.65253 .58199 Mdot
.65346 .58323 Mdot
.65439 .58412 Mdot
.65532 .58456 Mdot
.65625 .58443 Mdot
.65718 .58359 Mdot
.65811 .58185 Mdot
.65904 .57899 Mdot
.65997 .57477 Mdot
.6609 .56889 Mdot
.66183 .56104 Mdot
.66276 .5509 Mdot
.66369 .5382 Mdot
.66462 .52273 Mdot
.66555 .50442 Mdot
.66648 .48341 Mdot
.66741 .46005 Mdot
.66834 .43495 Mdot
.66927 .40895 Mdot
.6702 .38296 Mdot
.67113 .35792 Mdot
.67206 .33464 Mdot
.67299 .31373 Mdot
.67392 .29553 Mdot
.67485 .28017 Mdot
.67578 .26757 Mdot
.67671 .25752 Mdot
.67764 .24974 Mdot
.67857 .24392 Mdot
.6795 .23974 Mdot
.68043 .23691 Mdot
.68136 .23518 Mdot
.68229 .23434 Mdot
.68322 .2342 Mdot
.68415 .23462 Mdot
.68508 .23548 Mdot
.68601 .23667 Mdot
.68694 .23814 Mdot
.68787 .23981 Mdot
.6888 .24163 Mdot
.68973 .24358 Mdot
.69066 .24562 Mdot
.69159 .24772 Mdot
.69252 .24988 Mdot
.69345 .25206 Mdot
.69438 .25426 Mdot
.69531 .25648 Mdot
.69624 .25869 Mdot
.69717 .26089 Mdot
.6981 .26307 Mdot
.69903 .26523 Mdot
.69996 .26736 Mdot
.70089 .26945 Mdot
.70182 .2715 Mdot
.70275 .2735 Mdot
.70368 .27544 Mdot
.70461 .27732 Mdot
.70554 .27912 Mdot
.70647 .28084 Mdot
.7074 .28248 Mdot
.70833 .28401 Mdot
.70926 .28544 Mdot
.71019 .28675 Mdot
.71112 .28793 Mdot
.71205 .28898 Mdot
.71298 .28987 Mdot
.71391 .29061 Mdot
.71484 .29117 Mdot
.71577 .29156 Mdot
.7167 .29175 Mdot
.71763 .29174 Mdot
.71856 .29153 Mdot
.71949 .2911 Mdot
.72042 .29045 Mdot
.72135 .28959 Mdot
.72228 .2885 Mdot
.72321 .28719 Mdot
.72414 .28568 Mdot
.72507 .28396 Mdot
.726 .28206 Mdot
.72693 .27999 Mdot
.72786 .27776 Mdot
.72879 .27542 Mdot
.72972 .27297 Mdot
.73065 .27046 Mdot
.73158 .26791 Mdot
.73251 .26535 Mdot
.73344 .26282 Mdot
.73438 .26035 Mdot
.73531 .25796 Mdot
.73624 .25569 Mdot
.73717 .25356 Mdot
.7381 .2516 Mdot
.73903 .24981 Mdot
.73996 .24823 Mdot
.74089 .24685 Mdot
.74182 .24569 Mdot
.74275 .24475 Mdot
.74368 .24404 Mdot
.74461 .24354 Mdot
.74554 .24327 Mdot
.74647 .24321 Mdot
.7474 .24336 Mdot
.74833 .2437 Mdot
.74926 .24423 Mdot
.75019 .24495 Mdot
.75112 .24582 Mdot
.75205 .24686 Mdot
.75298 .24804 Mdot
.75391 .24936 Mdot
.75484 .25081 Mdot
.75577 .25237 Mdot
.7567 .25404 Mdot
.75763 .25581 Mdot
.75856 .25766 Mdot
.75949 .2596 Mdot
.76042 .26161 Mdot
.76135 .2637 Mdot
.76228 .26584 Mdot
.76321 .26804 Mdot
.76414 .27029 Mdot
.76507 .27258 Mdot
.766 .27492 Mdot
.76693 .2773 Mdot
.76786 .27971 Mdot
.76879 .28215 Mdot
.76972 .28462 Mdot
.77065 .28711 Mdot
.77158 .28963 Mdot
.77251 .29217 Mdot
.77344 .29472 Mdot
.77437 .29729 Mdot
.7753 .29988 Mdot
.77623 .30248 Mdot
.77716 .30509 Mdot
.77809 .30772 Mdot
.77902 .31035 Mdot
.77995 .31299 Mdot
.78088 .31565 Mdot
.78181 .3183 Mdot
.78274 .32097 Mdot
.78367 .32364 Mdot
.7846 .32631 Mdot
.78553 .32899 Mdot
.78646 .33168 Mdot
.78739 .33437 Mdot
.78832 .33706 Mdot
.78925 .33975 Mdot
.79018 .34245 Mdot
.79111 .34515 Mdot
.79204 .34785 Mdot
.79297 .35055 Mdot
.7939 .35326 Mdot
.79483 .35596 Mdot
.79576 .35867 Mdot
.79669 .36138 Mdot
.79762 .36408 Mdot
.79855 .36679 Mdot
.79948 .3695 Mdot
.80041 .37221 Mdot
.80134 .37492 Mdot
.80227 .37763 Mdot
.8032 .38034 Mdot
.80413 .38305 Mdot
.80506 .38576 Mdot
.80599 .38847 Mdot
.80692 .39118 Mdot
.80785 .39389 Mdot
.80878 .3966 Mdot
.80971 .39931 Mdot
.81064 .40202 Mdot
.81157 .40472 Mdot
.8125 .40743 Mdot
.81343 .41013 Mdot
.81436 .41284 Mdot
.81529 .41554 Mdot
.81622 .41824 Mdot
.81715 .42094 Mdot
.81808 .42364 Mdot
.81901 .42634 Mdot
.81994 .42903 Mdot
.82087 .43173 Mdot
.8218 .43442 Mdot
.82273 .43712 Mdot
.82366 .43981 Mdot
.82459 .4425 Mdot
.82552 .44518 Mdot
.82645 .44787 Mdot
.82738 .45055 Mdot
.82831 .45324 Mdot
.82924 .45592 Mdot
.83017 .4586 Mdot
.8311 .46127 Mdot
.83203 .46395 Mdot
.83296 .46662 Mdot
.83389 .46929 Mdot
.83482 .47196 Mdot
.83575 .47462 Mdot
.83668 .47729 Mdot
.83761 .47995 Mdot
.83854 .48261 Mdot
.83947 .48526 Mdot
.8404 .48792 Mdot
.84133 .49057 Mdot
.84226 .49322 Mdot
.84319 .49586 Mdot
.84412 .49851 Mdot
.84505 .50115 Mdot
.84598 .50378 Mdot
.84691 .50642 Mdot
.84784 .50905 Mdot
.84877 .51168 Mdot
.8497 .5143 Mdot
.85063 .51693 Mdot
.85156 .51954 Mdot
.85249 .52216 Mdot
.85342 .52477 Mdot
.85435 .52738 Mdot
.85528 .52999 Mdot
.85621 .53259 Mdot
.85714 .53519 Mdot
.85807 .53778 Mdot
.859 .54037 Mdot
.85993 .54295 Mdot
.86086 .54554 Mdot
.86179 .54811 Mdot
.86272 .55068 Mdot
.86365 .55325 Mdot
.86458 .55581 Mdot
.86551 .55837 Mdot
.86644 .56091 Mdot
.86737 .56345 Mdot
.8683 .56598 Mdot
.86923 .56851 Mdot
.87016 .57102 Mdot
.87109 .57351 Mdot
.87202 .57599 Mdot
.87295 .57845 Mdot
.87388 .58089 Mdot
.87481 .58329 Mdot
.87574 .58566 Mdot
.87667 .58798 Mdot
.8776 .59025 Mdot
.87853 .59243 Mdot
.87946 .59453 Mdot
.88039 .59651 Mdot
.88132 .59833 Mdot
.88225 .59997 Mdot
.88318 .60136 Mdot
.88411 .60244 Mdot
.88504 .60313 Mdot
.88597 .60332 Mdot
.8869 .60289 Mdot
.88783 .60167 Mdot
.88876 .59947 Mdot
.88969 .59606 Mdot
.89063 .59118 Mdot
.89156 .58453 Mdot
.89249 .57579 Mdot
.89342 .56466 Mdot
.89435 .55087 Mdot
.89528 .53424 Mdot
.89621 .51477 Mdot
.89714 .49262 Mdot
.89807 .46822 Mdot
.899 .44223 Mdot
.89993 .41547 Mdot
.90086 .38887 Mdot
.90179 .36332 Mdot
.90272 .33955 Mdot
.90365 .31808 Mdot
.90458 .29922 Mdot
.90551 .28302 Mdot
.90644 .26937 Mdot
.90737 .25806 Mdot
.9083 .24881 Mdot
.90923 .24129 Mdot
.91016 .23524 Mdot
.91109 .23037 Mdot
.91202 .22645 Mdot
.91295 .22331 Mdot
.91388 .22077 Mdot
.91481 .21871 Mdot
.91574 .21703 Mdot
.91667 .21566 Mdot
.9176 .21454 Mdot
.91853 .21362 Mdot
.91946 .21287 Mdot
.92039 .21228 Mdot
.92132 .21181 Mdot
.92225 .21147 Mdot
.92318 .21125 Mdot
.92411 .21113 Mdot
.92504 .21112 Mdot
.92597 .21121 Mdot
.9269 .2114 Mdot
.92783 .2117 Mdot
.92876 .21209 Mdot
.92969 .21258 Mdot
.93062 .21317 Mdot
.93155 .21386 Mdot
.93248 .21464 Mdot
.93341 .2155 Mdot
.93434 .21646 Mdot
.93527 .2175 Mdot
.9362 .21862 Mdot
.93713 .21982 Mdot
.93806 .2211 Mdot
.93899 .22244 Mdot
.93992 .22385 Mdot
.94085 .22532 Mdot
.94178 .22685 Mdot
.94271 .22844 Mdot
.94364 .23007 Mdot
.94457 .23175 Mdot
.9455 .23347 Mdot
.94643 .23523 Mdot
.94736 .23702 Mdot
.94829 .23884 Mdot
.94922 .24069 Mdot
.95015 .24256 Mdot
.95108 .24444 Mdot
.95201 .24634 Mdot
.95294 .24825 Mdot
.95387 .25017 Mdot
.9548 .25208 Mdot
.95573 .254 Mdot
.95666 .25591 Mdot
.95759 .25781 Mdot
.95852 .2597 Mdot
.95945 .26157 Mdot
.96038 .26342 Mdot
.96131 .26524 Mdot
.96224 .26703 Mdot
.96317 .26879 Mdot
.9641 .27051 Mdot
.96503 .27219 Mdot
.96596 .27382 Mdot
.96689 .2754 Mdot
.96782 .27693 Mdot
.96875 .27839 Mdot
.96968 .27979 Mdot
.97061 .28112 Mdot
.97154 .28237 Mdot
.97247 .28355 Mdot
.9734 .28464 Mdot
.97433 .28565 Mdot
.97526 .28656 Mdot
.97619 .28739 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "This time we try a different wavelet basis to analyze this signal. Here we \
will illustrate the analysis using the spline wavelet of order 3 truncated at \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "10"}], TraditionalForm]], "InlineFormula",
    CellTags->"S2.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.48"}],

Cell["\<\
(filter = SplineFilter[3, 10];
 wtdata = WaveletTransform[data, filter];)\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
This shows that the coefficients are concentrated at lower \
resolution levels and around the shocks.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.49"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[wtdata, PlotRange -> All,
Axes -> {True, False}]\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0377509 0.0261653 [
[.02381 .02525 -3 -9 ]
[.02381 .02525 3 0 ]
[.20982 .02525 -9 -9 ]
[.20982 .02525 9 0 ]
[.39583 .02525 -9 -9 ]
[.39583 .02525 9 0 ]
[.58185 .02525 -9 -9 ]
[.58185 .02525 9 0 ]
[.76786 .02525 -9 -9 ]
[.76786 .02525 9 0 ]
[.95387 .02525 -9 -9 ]
[.95387 .02525 9 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .03775 m
.02381 .044 L
s
[(0)] .02381 .02525 0 1 Mshowa
.20982 .03775 m
.20982 .044 L
s
[(100)] .20982 .02525 0 1 Mshowa
.39583 .03775 m
.39583 .044 L
s
[(200)] .39583 .02525 0 1 Mshowa
.58185 .03775 m
.58185 .044 L
s
[(300)] .58185 .02525 0 1 Mshowa
.76786 .03775 m
.76786 .044 L
s
[(400)] .76786 .02525 0 1 Mshowa
.95387 .03775 m
.95387 .044 L
s
[(500)] .95387 .02525 0 1 Mshowa
.125 Mabswid
.06101 .03775 m
.06101 .0415 L
s
.09821 .03775 m
.09821 .0415 L
s
.13542 .03775 m
.13542 .0415 L
s
.17262 .03775 m
.17262 .0415 L
s
.24702 .03775 m
.24702 .0415 L
s
.28423 .03775 m
.28423 .0415 L
s
.32143 .03775 m
.32143 .0415 L
s
.35863 .03775 m
.35863 .0415 L
s
.43304 .03775 m
.43304 .0415 L
s
.47024 .03775 m
.47024 .0415 L
s
.50744 .03775 m
.50744 .0415 L
s
.54464 .03775 m
.54464 .0415 L
s
.61905 .03775 m
.61905 .0415 L
s
.65625 .03775 m
.65625 .0415 L
s
.69345 .03775 m
.69345 .0415 L
s
.73065 .03775 m
.73065 .0415 L
s
.80506 .03775 m
.80506 .0415 L
s
.84226 .03775 m
.84226 .0415 L
s
.87946 .03775 m
.87946 .0415 L
s
.91667 .03775 m
.91667 .0415 L
s
.99107 .03775 m
.99107 .0415 L
s
.25 Mabswid
0 .03775 m
1 .03775 L
s
.5 Mabswid
.02381 .11081 m
.02381 .08352 L
s
.08333 .11081 m
.08333 .01472 L
s
.14286 .11081 m
.14286 .02813 L
s
.20238 .11081 m
.20238 .09772 L
s
.2619 .11081 m
.2619 .13578 L
s
.32143 .11081 m
.32143 .12596 L
s
.38095 .11081 m
.38095 .10066 L
s
.44048 .11081 m
.44048 .06824 L
s
.5 .11081 m
.5 .12054 L
s
.55952 .11081 m
.55952 .13871 L
s
.61905 .11081 m
.61905 .18012 L
s
.67857 .11081 m
.67857 .11722 L
s
.7381 .11081 m
.7381 .07419 L
s
.79762 .11081 m
.79762 .11278 L
s
.85714 .11081 m
.85714 .19229 L
s
.91667 .11081 m
.91667 .09101 L
s
.02381 .23795 m
.02381 .21829 L
s
.08333 .23795 m
.08333 .2346 L
s
.14286 .23795 m
.14286 .23887 L
s
.20238 .23795 m
.20238 .24132 L
s
.2619 .23795 m
.2619 .25229 L
s
.32143 .23795 m
.32143 .20921 L
s
.38095 .23795 m
.38095 .26012 L
s
.44048 .23795 m
.44048 .23241 L
s
.5 .23795 m
.5 .23856 L
s
.55952 .23795 m
.55952 .24714 L
s
.61905 .23795 m
.61905 .20143 L
s
.67857 .23795 m
.67857 .23665 L
s
.7381 .23795 m
.7381 .23578 L
s
.79762 .23795 m
.79762 .25176 L
s
.85714 .23795 m
.85714 .20145 L
s
.91667 .23795 m
.91667 .24255 L
s
.02381 .31101 m
.02381 .31449 L
s
.05357 .31101 m
.05357 .31116 L
s
.08333 .31101 m
.08333 .30685 L
s
.1131 .31101 m
.1131 .31207 L
s
.14286 .31101 m
.14286 .31023 L
s
.17262 .31101 m
.17262 .31173 L
s
.20238 .31101 m
.20238 .30982 L
s
.23214 .31101 m
.23214 .31341 L
s
.2619 .31101 m
.2619 .30498 L
s
.29167 .31101 m
.29167 .31121 L
s
.32143 .31101 m
.32143 .31296 L
s
.35119 .31101 m
.35119 .30318 L
s
.38095 .31101 m
.38095 .31937 L
s
.41071 .31101 m
.41071 .30878 L
s
.44048 .31101 m
.44048 .31229 L
s
.47024 .31101 m
.47024 .31058 L
s
.5 .31101 m
.5 .31152 L
s
.52976 .31101 m
.52976 .31052 L
s
.55952 .31101 m
.55952 .31162 L
s
.58929 .31101 m
.58929 .30855 L
s
.61905 .31101 m
.61905 .31879 L
s
.64881 .31101 m
.64881 .29833 L
s
.67857 .31101 m
.67857 .30865 L
s
.70833 .31101 m
.70833 .30989 L
s
.7381 .31101 m
.7381 .31178 L
s
.76786 .31101 m
.76786 .31055 L
s
.79762 .31101 m
.79762 .31185 L
s
.82738 .31101 m
.82738 .30954 L
s
.85714 .31101 m
.85714 .31681 L
s
.8869 .31101 m
.8869 .31784 L
s
.91667 .31101 m
.91667 .30433 L
s
.94643 .31101 m
.94643 .31178 L
s
.02381 .38406 m
.02381 .38341 L
s
.03869 .38406 m
.03869 .38486 L
s
.05357 .38406 m
.05357 .38163 L
s
.06845 .38406 m
.06845 .38622 L
s
.08333 .38406 m
.08333 .38294 L
s
.09821 .38406 m
.09821 .3844 L
s
.1131 .38406 m
.1131 .38382 L
s
.12798 .38406 m
.12798 .3841 L
s
.14286 .38406 m
.14286 .38392 L
s
.15774 .38406 m
.15774 .38392 L
s
.17262 .38406 m
.17262 .38396 L
s
.1875 .38406 m
.1875 .38399 L
s
.20238 .38406 m
.20238 .38393 L
s
.21726 .38406 m
.21726 .38394 L
s
.23214 .38406 m
.23214 .38399 L
s
.24702 .38406 m
.24702 .384 L
s
.2619 .38406 m
.2619 .3842 L
s
.27679 .38406 m
.27679 .38402 L
s
.29167 .38406 m
.29167 .38404 L
s
.30655 .38406 m
.30655 .38393 L
s
.32143 .38406 m
.32143 .38415 L
s
.33631 .38406 m
.33631 .3838 L
s
.35119 .38406 m
.35119 .38473 L
s
.36607 .38406 m
.36607 .38255 L
s
.38095 .38406 m
.38095 .3856 L
s
.39583 .38406 m
.39583 .38333 L
s
.41071 .38406 m
.41071 .38439 L
s
.4256 .38406 m
.4256 .384 L
s
.44048 .38406 m
.44048 .3842 L
s
.45536 .38406 m
.45536 .38405 L
s
.47024 .38406 m
.47024 .38402 L
s
.48512 .38406 m
.48512 .38405 L
s
.5 .38406 m
.5 .38406 L
s
.51488 .38406 m
.51488 .38408 L
s
.52976 .38406 m
.52976 .38411 L
s
.54464 .38406 m
.54464 .38416 L
s
.55952 .38406 m
.55952 .38415 L
s
.5744 .38406 m
.5744 .38422 L
s
.58929 .38406 m
.58929 .38398 L
s
.60417 .38406 m
.60417 .3841 L
s
.61905 .38406 m
.61905 .38393 L
s
.63393 .38406 m
.63393 .38432 L
s
.64881 .38406 m
.64881 .38342 L
s
.66369 .38406 m
.66369 .38792 L
s
.67857 .38406 m
.67857 .38152 L
s
.69345 .38406 m
.69345 .38506 L
s
.70833 .38406 m
.70833 .38375 L
s
.72321 .38406 m
.72321 .38439 L
s
.7381 .38406 m
.7381 .38418 L
s
.75298 .38406 m
.75298 .38404 L
s
.76786 .38406 m
.76786 .38413 L
s
.78274 .38406 m
.78274 .38415 L
s
.79762 .38406 m
.79762 .38417 L
s
.8125 .38406 m
.8125 .38409 L
s
.82738 .38406 m
.82738 .38375 L
s
.84226 .38406 m
.84226 .38437 L
s
.85714 .38406 m
.85714 .38304 L
s
.87202 .38406 m
.87202 .38653 L
s
.8869 .38406 m
.8869 .37905 L
s
.90179 .38406 m
.90179 .38631 L
s
.91667 .38406 m
.91667 .38343 L
s
.93155 .38406 m
.93155 .38446 L
s
.94643 .38406 m
.94643 .38376 L
s
.96131 .38406 m
.96131 .3843 L
s
.02381 .45712 m
.02381 .457 L
s
.03125 .45712 m
.03125 .45696 L
s
.03869 .45712 m
.03869 .45697 L
s
.04613 .45712 m
.04613 .45695 L
s
.05357 .45712 m
.05357 .45704 L
s
.06101 .45712 m
.06101 .45683 L
s
.06845 .45712 m
.06845 .45715 L
s
.07589 .45712 m
.07589 .45693 L
s
.08333 .45712 m
.08333 .45702 L
s
.09077 .45712 m
.09077 .45699 L
s
.09821 .45712 m
.09821 .457 L
s
.10565 .45712 m
.10565 .45696 L
s
.1131 .45712 m
.1131 .45693 L
s
.12054 .45712 m
.12054 .45693 L
s
.12798 .45712 m
.12798 .45694 L
s
.13542 .45712 m
.13542 .45696 L
s
.14286 .45712 m
.14286 .45697 L
s
.1503 .45712 m
.1503 .45699 L
s
.15774 .45712 m
.15774 .457 L
s
.16518 .45712 m
.16518 .45702 L
s
.17262 .45712 m
.17262 .45703 L
s
.18006 .45712 m
.18006 .45705 L
s
.1875 .45712 m
.1875 .45706 L
s
.19494 .45712 m
.19494 .45708 L
s
.20238 .45712 m
.20238 .45709 L
s
.20982 .45712 m
.20982 .45711 L
s
.21726 .45712 m
.21726 .45712 L
s
.2247 .45712 m
.2247 .45713 L
s
.23214 .45712 m
.23214 .45714 L
s
.23958 .45712 m
.23958 .45712 L
s
.24702 .45712 m
.24702 .45711 L
s
.25446 .45712 m
.25446 .45711 L
s
.2619 .45712 m
.2619 .45711 L
s
.26935 .45712 m
.26935 .45714 L
s
.27679 .45712 m
.27679 .4571 L
s
.28423 .45712 m
.28423 .4572 L
s
.29167 .45712 m
.29167 .45717 L
s
.29911 .45712 m
.29911 .45719 L
s
.30655 .45712 m
.30655 .4572 L
s
.31399 .45712 m
.31399 .4572 L
s
.32143 .45712 m
.32143 .45717 L
s
.32887 .45712 m
.32887 .45714 L
s
.33631 .45712 m
.33631 .4571 L
s
.34375 .45712 m
.34375 .45706 L
s
.35119 .45712 m
.35119 .45706 L
s
.35863 .45712 m
.35863 .45706 L
s
.36607 .45712 m
.36607 .4571 L
s
.37351 .45712 m
.37351 .45701 L
s
.38095 .45712 m
.38095 .45718 L
s
.38839 .45712 m
.38839 .45709 L
s
.39583 .45712 m
.39583 .45713 L
s
.40327 .45712 m
.40327 .45712 L
s
.41071 .45712 m
.41071 .45712 L
s
.41815 .45712 m
.41815 .45708 L
s
.4256 .45712 m
.4256 .45705 L
s
.43304 .45712 m
.43304 .45705 L
s
.44048 .45712 m
.44048 .45705 L
s
.44792 .45712 m
.44792 .45706 L
s
.45536 .45712 m
.45536 .45707 L
s
.4628 .45712 m
.4628 .45708 L
s
.47024 .45712 m
.47024 .45709 L
s
.47768 .45712 m
.47768 .4571 L
s
.48512 .45712 m
.48512 .45711 L
s
.49256 .45712 m
.49256 .45712 L
s
.5 .45712 m
.5 .45713 L
s
.50744 .45712 m
.50744 .45714 L
s
.51488 .45712 m
.51488 .45715 L
s
.52232 .45712 m
.52232 .45716 L
s
.52976 .45712 m
.52976 .45716 L
s
.5372 .45712 m
.5372 .45716 L
s
.54464 .45712 m
.54464 .45716 L
s
.55208 .45712 m
.55208 .45717 L
s
.55952 .45712 m
.55952 .45718 L
s
.56696 .45712 m
.56696 .45719 L
s
.5744 .45712 m
.5744 .4572 L
s
.58185 .45712 m
.58185 .45722 L
s
.58929 .45712 m
.58929 .45723 L
s
.59673 .45712 m
.59673 .45724 L
s
.60417 .45712 m
.60417 .45725 L
s
.61161 .45712 m
.61161 .45725 L
s
.61905 .45712 m
.61905 .45724 L
s
.62649 .45712 m
.62649 .45716 L
s
.63393 .45712 m
.63393 .45711 L
s
.64137 .45712 m
.64137 .45713 L
s
.64881 .45712 m
.64881 .45712 L
s
.65625 .45712 m
.65625 .45725 L
s
.66369 .45712 m
.66369 .45692 L
s
.67113 .45712 m
.67113 .45739 L
s
.67857 .45712 m
.67857 .45705 L
s
.68601 .45712 m
.68601 .45723 L
s
.69345 .45712 m
.69345 .45715 L
s
.70089 .45712 m
.70089 .45715 L
s
.70833 .45712 m
.70833 .45706 L
s
.71577 .45712 m
.71577 .45704 L
s
.72321 .45712 m
.72321 .45705 L
s
.73065 .45712 m
.73065 .45707 L
s
.7381 .45712 m
.7381 .45708 L
s
.74554 .45712 m
.74554 .45709 L
s
.75298 .45712 m
.75298 .4571 L
s
.76042 .45712 m
.76042 .45711 L
s
.76786 .45712 m
.76786 .45711 L
s
.7753 .45712 m
.7753 .45711 L
s
.78274 .45712 m
.78274 .45712 L
s
.79018 .45712 m
.79018 .45713 L
s
.79762 .45712 m
.79762 .45714 L
s
.80506 .45712 m
.80506 .45716 L
s
.8125 .45712 m
.8125 .45717 L
s
.81994 .45712 m
.81994 .45719 L
s
.82738 .45712 m
.82738 .45721 L
s
.83482 .45712 m
.83482 .45722 L
s
.84226 .45712 m
.84226 .45723 L
s
.8497 .45712 m
.8497 .45723 L
s
.85714 .45712 m
.85714 .45716 L
s
.86458 .45712 m
.86458 .45712 L
s
.87202 .45712 m
.87202 .45712 L
s
.87946 .45712 m
.87946 .45713 L
s
.8869 .45712 m
.8869 .4572 L
s
.89435 .45712 m
.89435 .45698 L
s
.90179 .45712 m
.90179 .45733 L
s
.90923 .45712 m
.90923 .45707 L
s
.91667 .45712 m
.91667 .45722 L
s
.92411 .45712 m
.92411 .45717 L
s
.93155 .45712 m
.93155 .45717 L
s
.93899 .45712 m
.93899 .45708 L
s
.94643 .45712 m
.94643 .45705 L
s
.95387 .45712 m
.95387 .45704 L
s
.96131 .45712 m
.96131 .45704 L
s
.96875 .45712 m
.96875 .45703 L
s
.02381 .53017 m
.02381 .53013 L
s
.02753 .53017 m
.02753 .53013 L
s
.03125 .53017 m
.03125 .53013 L
s
.03497 .53017 m
.03497 .53013 L
s
.03869 .53017 m
.03869 .53013 L
s
.04241 .53017 m
.04241 .53012 L
s
.04613 .53017 m
.04613 .5301 L
s
.04985 .53017 m
.04985 .53009 L
s
.05357 .53017 m
.05357 .53008 L
s
.05729 .53017 m
.05729 .53007 L
s
.06101 .53017 m
.06101 .53007 L
s
.06473 .53017 m
.06473 .53006 L
s
.06845 .53017 m
.06845 .53007 L
s
.07217 .53017 m
.07217 .53007 L
s
.07589 .53017 m
.07589 .53007 L
s
.07961 .53017 m
.07961 .53006 L
s
.08333 .53017 m
.08333 .53005 L
s
.08705 .53017 m
.08705 .53004 L
s
.09077 .53017 m
.09077 .53003 L
s
.09449 .53017 m
.09449 .53002 L
s
.09821 .53017 m
.09821 .53002 L
s
.10193 .53017 m
.10193 .53002 L
s
.10565 .53017 m
.10565 .53002 L
s
.10938 .53017 m
.10938 .53002 L
s
.1131 .53017 m
.1131 .53003 L
s
.11682 .53017 m
.11682 .53003 L
s
.12054 .53017 m
.12054 .53004 L
s
.12426 .53017 m
.12426 .53004 L
s
.12798 .53017 m
.12798 .53005 L
s
.1317 .53017 m
.1317 .53005 L
s
.13542 .53017 m
.13542 .53006 L
s
.13914 .53017 m
.13914 .53006 L
s
.14286 .53017 m
.14286 .53007 L
s
.14658 .53017 m
.14658 .53007 L
s
.1503 .53017 m
.1503 .53008 L
s
.15402 .53017 m
.15402 .53008 L
s
.15774 .53017 m
.15774 .53009 L
s
.16146 .53017 m
.16146 .53009 L
s
.16518 .53017 m
.16518 .5301 L
s
.1689 .53017 m
.1689 .5301 L
s
.17262 .53017 m
.17262 .53011 L
s
.17634 .53017 m
.17634 .53011 L
s
.18006 .53017 m
.18006 .53012 L
s
.18378 .53017 m
.18378 .53012 L
s
.1875 .53017 m
.1875 .53013 L
s
.19122 .53017 m
.19122 .53013 L
s
.19494 .53017 m
.19494 .53014 L
s
.19866 .53017 m
.19866 .53014 L
s
.20238 .53017 m
.20238 .53015 L
s
.2061 .53017 m
.2061 .53016 L
s
.20982 .53017 m
.20982 .53016 L
s
.21354 .53017 m
.21354 .53017 L
s
.21726 .53017 m
.21726 .53017 L
s
.22098 .53017 m
.22098 .53018 L
s
.2247 .53017 m
.2247 .53018 L
s
.22842 .53017 m
.22842 .53019 L
s
.23214 .53017 m
.23214 .53019 L
s
.23586 .53017 m
.23586 .5302 L
s
.23958 .53017 m
.23958 .5302 L
s
.2433 .53017 m
.2433 .53021 L
s
.24702 .53017 m
.24702 .53021 L
s
.25074 .53017 m
.25074 .53022 L
s
.25446 .53017 m
.25446 .53022 L
s
.25818 .53017 m
.25818 .53021 L
s
.2619 .53017 m
.2619 .53021 L
s
.26563 .53017 m
.26563 .5302 L
s
.26935 .53017 m
.26935 .5302 L
s
.27307 .53017 m
.27307 .53019 L
s
.27679 .53017 m
.27679 .53019 L
s
.28051 .53017 m
.28051 .5302 L
s
.28423 .53017 m
.28423 .5302 L
s
.28795 .53017 m
.28795 .5302 L
s
.29167 .53017 m
.29167 .5302 L
s
.29539 .53017 m
.29539 .5302 L
s
.29911 .53017 m
.29911 .5302 L
s
.30283 .53017 m
.30283 .53019 L
s
.30655 .53017 m
.30655 .53019 L
s
.31027 .53017 m
.31027 .53018 L
s
.31399 .53017 m
.31399 .53018 L
s
.31771 .53017 m
.31771 .53018 L
s
.32143 .53017 m
.32143 .53019 L
s
.32515 .53017 m
.32515 .53019 L
s
.32887 .53017 m
.32887 .53019 L
s
.33259 .53017 m
.33259 .5302 L
s
.33631 .53017 m
.33631 .5302 L
s
.34003 .53017 m
.34003 .5302 L
s
.34375 .53017 m
.34375 .53021 L
s
.34747 .53017 m
.34747 .53021 L
s
.35119 .53017 m
.35119 .5302 L
s
.35491 .53017 m
.35491 .5302 L
s
.35863 .53017 m
.35863 .53018 L
s
.36235 .53017 m
.36235 .53017 L
s
.36607 .53017 m
.36607 .53016 L
s
.36979 .53017 m
.36979 .53016 L
s
.37351 .53017 m
.37351 .53016 L
s
.37723 .53017 m
.37723 .53015 L
s
.38095 .53017 m
.38095 .53016 L
s
.38467 .53017 m
.38467 .53016 L
s
.38839 .53017 m
.38839 .53015 L
s
.39211 .53017 m
.39211 .53015 L
s
.39583 .53017 m
.39583 .53014 L
s
.39955 .53017 m
.39955 .53013 L
s
.40327 .53017 m
.40327 .53012 L
s
.40699 .53017 m
.40699 .53011 L
s
.41071 .53017 m
.41071 .5301 L
s
.41443 .53017 m
.41443 .5301 L
s
.41815 .53017 m
.41815 .53011 L
s
.42188 .53017 m
.42188 .53011 L
s
.4256 .53017 m
.4256 .53011 L
s
.42932 .53017 m
.42932 .53012 L
s
.43304 .53017 m
.43304 .53012 L
s
.43676 .53017 m
.43676 .53013 L
s
.44048 .53017 m
.44048 .53013 L
s
.4442 .53017 m
.4442 .53013 L
s
.44792 .53017 m
.44792 .53014 L
s
.45164 .53017 m
.45164 .53014 L
s
.45536 .53017 m
.45536 .53014 L
s
.45908 .53017 m
.45908 .53015 L
s
.4628 .53017 m
.4628 .53015 L
s
.46652 .53017 m
.46652 .53015 L
s
.47024 .53017 m
.47024 .53016 L
s
.47396 .53017 m
.47396 .53016 L
s
.47768 .53017 m
.47768 .53016 L
s
.4814 .53017 m
.4814 .53016 L
s
.48512 .53017 m
.48512 .53017 L
s
.48884 .53017 m
.48884 .53017 L
s
.49256 .53017 m
.49256 .53017 L
s
.49628 .53017 m
.49628 .53018 L
s
.5 .53017 m
.5 .53018 L
s
.50372 .53017 m
.50372 .53018 L
s
.50744 .53017 m
.50744 .53018 L
s
.51116 .53017 m
.51116 .53019 L
s
.51488 .53017 m
.51488 .53019 L
s
.5186 .53017 m
.5186 .53019 L
s
.52232 .53017 m
.52232 .5302 L
s
.52604 .53017 m
.52604 .5302 L
s
.52976 .53017 m
.52976 .5302 L
s
.53348 .53017 m
.53348 .53021 L
s
.5372 .53017 m
.5372 .53021 L
s
.54092 .53017 m
.54092 .53021 L
s
.54464 .53017 m
.54464 .53021 L
s
.54836 .53017 m
.54836 .53022 L
s
.55208 .53017 m
.55208 .53022 L
s
.5558 .53017 m
.5558 .53022 L
s
.55952 .53017 m
.55952 .53022 L
s
.56324 .53017 m
.56324 .53022 L
s
.56696 .53017 m
.56696 .53023 L
s
.57068 .53017 m
.57068 .53023 L
s
.5744 .53017 m
.5744 .53023 L
s
.57813 .53017 m
.57813 .53023 L
s
.58185 .53017 m
.58185 .53023 L
s
.58557 .53017 m
.58557 .53024 L
s
.58929 .53017 m
.58929 .53024 L
s
.59301 .53017 m
.59301 .53024 L
s
.59673 .53017 m
.59673 .53024 L
s
.60045 .53017 m
.60045 .53025 L
s
.60417 .53017 m
.60417 .53025 L
s
.60789 .53017 m
.60789 .53025 L
s
.61161 .53017 m
.61161 .53025 L
s
.61533 .53017 m
.61533 .53026 L
s
.61905 .53017 m
.61905 .53026 L
s
.62277 .53017 m
.62277 .53027 L
s
.62649 .53017 m
.62649 .53027 L
s
.63021 .53017 m
.63021 .53027 L
s
.63393 .53017 m
.63393 .53028 L
s
.63765 .53017 m
.63765 .53028 L
s
.64137 .53017 m
.64137 .53027 L
s
.64509 .53017 m
.64509 .53025 L
s
.64881 .53017 m
.64881 .53022 L
s
.65253 .53017 m
.65253 .53021 L
s
.65625 .53017 m
.65625 .5302 L
s
.65997 .53017 m
.65997 .5302 L
s
.66369 .53017 m
.66369 .53019 L
s
.66741 .53017 m
.66741 .53022 L
s
.67113 .53017 m
.67113 .53022 L
s
.67485 .53017 m
.67485 .53021 L
s
.67857 .53017 m
.67857 .53021 L
s
.68229 .53017 m
.68229 .5302 L
s
.68601 .53017 m
.68601 .53018 L
s
.68973 .53017 m
.68973 .53015 L
s
.69345 .53017 m
.69345 .53013 L
s
.69717 .53017 m
.69717 .53013 L
s
.70089 .53017 m
.70089 .53013 L
s
.70461 .53017 m
.70461 .53013 L
s
.70833 .53017 m
.70833 .53013 L
s
.71205 .53017 m
.71205 .53013 L
s
.71577 .53017 m
.71577 .53013 L
s
.71949 .53017 m
.71949 .53013 L
s
.72321 .53017 m
.72321 .53013 L
s
.72693 .53017 m
.72693 .53013 L
s
.73065 .53017 m
.73065 .53013 L
s
.73438 .53017 m
.73438 .53013 L
s
.7381 .53017 m
.7381 .53014 L
s
.74182 .53017 m
.74182 .53014 L
s
.74554 .53017 m
.74554 .53014 L
s
.74926 .53017 m
.74926 .53014 L
s
.75298 .53017 m
.75298 .53014 L
s
.7567 .53017 m
.7567 .53014 L
s
.76042 .53017 m
.76042 .53014 L
s
.76414 .53017 m
.76414 .53014 L
s
.76786 .53017 m
.76786 .53015 L
s
.77158 .53017 m
.77158 .53015 L
s
.7753 .53017 m
.7753 .53015 L
s
.77902 .53017 m
.77902 .53016 L
s
.78274 .53017 m
.78274 .53016 L
s
.78646 .53017 m
.78646 .53017 L
s
.79018 .53017 m
.79018 .53018 L
s
.7939 .53017 m
.7939 .53018 L
s
.79762 .53017 m
.79762 .53019 L
s
.80134 .53017 m
.80134 .53019 L
s
.80506 .53017 m
.80506 .5302 L
s
.80878 .53017 m
.80878 .5302 L
s
.8125 .53017 m
.8125 .53021 L
s
.81622 .53017 m
.81622 .53022 L
s
.81994 .53017 m
.81994 .53022 L
s
.82366 .53017 m
.82366 .53023 L
s
.82738 .53017 m
.82738 .53023 L
s
.8311 .53017 m
.8311 .53024 L
s
.83482 .53017 m
.83482 .53025 L
s
.83854 .53017 m
.83854 .53025 L
s
.84226 .53017 m
.84226 .53026 L
s
.84598 .53017 m
.84598 .53026 L
s
.8497 .53017 m
.8497 .53027 L
s
.85342 .53017 m
.85342 .53027 L
s
.85714 .53017 m
.85714 .53028 L
s
.86086 .53017 m
.86086 .53028 L
s
.86458 .53017 m
.86458 .53029 L
s
.8683 .53017 m
.8683 .53029 L
s
.87202 .53017 m
.87202 .53028 L
s
.87574 .53017 m
.87574 .53026 L
s
.87946 .53017 m
.87946 .53023 L
s
.88318 .53017 m
.88318 .53021 L
s
.8869 .53017 m
.8869 .53021 L
s
.89063 .53017 m
.89063 .5302 L
s
.89435 .53017 m
.89435 .53019 L
s
.89807 .53017 m
.89807 .53022 L
s
.90179 .53017 m
.90179 .53021 L
s
.90551 .53017 m
.90551 .5302 L
s
.90923 .53017 m
.90923 .5302 L
s
.91295 .53017 m
.91295 .53019 L
s
.91667 .53017 m
.91667 .53016 L
s
.92039 .53017 m
.92039 .53014 L
s
.92411 .53017 m
.92411 .53012 L
s
.92783 .53017 m
.92783 .53011 L
s
.93155 .53017 m
.93155 .53011 L
s
.93527 .53017 m
.93527 .53011 L
s
.93899 .53017 m
.93899 .53012 L
s
.94271 .53017 m
.94271 .53012 L
s
.94643 .53017 m
.94643 .53012 L
s
.95015 .53017 m
.95015 .53012 L
s
.95387 .53017 m
.95387 .53012 L
s
.95759 .53017 m
.95759 .53013 L
s
.96131 .53017 m
.96131 .53013 L
s
.96503 .53017 m
.96503 .53013 L
s
.96875 .53017 m
.96875 .53013 L
s
.97247 .53017 m
.97247 .53013 L
s
.02381 .60323 m
.02381 .6032 L
s
.02567 .60323 m
.02567 .6032 L
s
.02753 .60323 m
.02753 .60321 L
s
.02939 .60323 m
.02939 .60321 L
s
.03125 .60323 m
.03125 .60321 L
s
.03311 .60323 m
.03311 .60321 L
s
.03497 .60323 m
.03497 .60321 L
s
.03683 .60323 m
.03683 .60321 L
s
.03869 .60323 m
.03869 .6032 L
s
.04055 .60323 m
.04055 .6032 L
s
.04241 .60323 m
.04241 .6032 L
s
.04427 .60323 m
.04427 .6032 L
s
.04613 .60323 m
.04613 .6032 L
s
.04799 .60323 m
.04799 .6032 L
s
.04985 .60323 m
.04985 .6032 L
s
.05171 .60323 m
.05171 .60319 L
s
.05357 .60323 m
.05357 .60319 L
s
.05543 .60323 m
.05543 .60318 L
s
.05729 .60323 m
.05729 .60318 L
s
.05915 .60323 m
.05915 .60317 L
s
.06101 .60323 m
.06101 .60317 L
s
.06287 .60323 m
.06287 .60316 L
s
.06473 .60323 m
.06473 .60316 L
s
.06659 .60323 m
.06659 .60315 L
s
.06845 .60323 m
.06845 .60315 L
s
.07031 .60323 m
.07031 .60314 L
s
.07217 .60323 m
.07217 .60314 L
s
.07403 .60323 m
.07403 .60314 L
s
.07589 .60323 m
.07589 .60313 L
s
.07775 .60323 m
.07775 .60313 L
s
.07961 .60323 m
.07961 .60312 L
s
.08147 .60323 m
.08147 .60312 L
s
.08333 .60323 m
.08333 .60311 L
s
.08519 .60323 m
.08519 .60311 L
s
.08705 .60323 m
.08705 .60311 L
s
.08891 .60323 m
.08891 .60311 L
s
.09077 .60323 m
.09077 .60311 L
s
.09263 .60323 m
.09263 .60311 L
s
.09449 .60323 m
.09449 .60311 L
s
.09635 .60323 m
.09635 .60311 L
s
.09821 .60323 m
.09821 .60311 L
s
.10007 .60323 m
.10007 .60311 L
s
.10193 .60323 m
.10193 .60311 L
s
.10379 .60323 m
.10379 .60312 L
s
.10565 .60323 m
.10565 .60312 L
s
.10751 .60323 m
.10751 .60312 L
s
.10938 .60323 m
.10938 .60312 L
s
.11124 .60323 m
.11124 .60312 L
s
.1131 .60323 m
.1131 .60312 L
s
.11496 .60323 m
.11496 .60313 L
s
.11682 .60323 m
.11682 .60313 L
s
.11868 .60323 m
.11868 .60313 L
s
.12054 .60323 m
.12054 .60313 L
s
.1224 .60323 m
.1224 .60313 L
s
.12426 .60323 m
.12426 .60314 L
s
.12612 .60323 m
.12612 .60314 L
s
.12798 .60323 m
.12798 .60314 L
s
.12984 .60323 m
.12984 .60314 L
s
.1317 .60323 m
.1317 .60314 L
s
.13356 .60323 m
.13356 .60314 L
s
.13542 .60323 m
.13542 .60315 L
s
.13728 .60323 m
.13728 .60315 L
s
.13914 .60323 m
.13914 .60315 L
s
.141 .60323 m
.141 .60315 L
s
.14286 .60323 m
.14286 .60315 L
s
.14472 .60323 m
.14472 .60315 L
s
.14658 .60323 m
.14658 .60316 L
s
.14844 .60323 m
.14844 .60316 L
s
.1503 .60323 m
.1503 .60316 L
s
.15216 .60323 m
.15216 .60316 L
s
.15402 .60323 m
.15402 .60316 L
s
.15588 .60323 m
.15588 .60316 L
s
.15774 .60323 m
.15774 .60317 L
s
.1596 .60323 m
.1596 .60317 L
s
.16146 .60323 m
.16146 .60317 L
s
.16332 .60323 m
.16332 .60317 L
s
.16518 .60323 m
.16518 .60317 L
s
.16704 .60323 m
.16704 .60318 L
s
.1689 .60323 m
.1689 .60318 L
s
.17076 .60323 m
.17076 .60318 L
s
.17262 .60323 m
.17262 .60318 L
s
.17448 .60323 m
.17448 .60318 L
s
.17634 .60323 m
.17634 .60318 L
s
.1782 .60323 m
.1782 .60319 L
s
.18006 .60323 m
.18006 .60319 L
s
.18192 .60323 m
.18192 .60319 L
s
.18378 .60323 m
.18378 .60319 L
s
.18564 .60323 m
.18564 .60319 L
s
.1875 .60323 m
.1875 .6032 L
s
.18936 .60323 m
.18936 .6032 L
s
.19122 .60323 m
.19122 .6032 L
s
.19308 .60323 m
.19308 .6032 L
s
.19494 .60323 m
.19494 .6032 L
s
.1968 .60323 m
.1968 .60321 L
s
.19866 .60323 m
.19866 .60321 L
s
.20052 .60323 m
.20052 .60321 L
s
.20238 .60323 m
.20238 .60321 L
s
.20424 .60323 m
.20424 .60321 L
s
.2061 .60323 m
.2061 .60321 L
s
.20796 .60323 m
.20796 .60322 L
s
.20982 .60323 m
.20982 .60322 L
s
.21168 .60323 m
.21168 .60322 L
s
.21354 .60323 m
.21354 .60322 L
s
.2154 .60323 m
.2154 .60322 L
s
.21726 .60323 m
.21726 .60323 L
s
.21912 .60323 m
.21912 .60323 L
s
.22098 .60323 m
.22098 .60323 L
s
.22284 .60323 m
.22284 .60323 L
s
.2247 .60323 m
.2247 .60323 L
s
.22656 .60323 m
.22656 .60324 L
s
.22842 .60323 m
.22842 .60324 L
s
.23028 .60323 m
.23028 .60324 L
s
.23214 .60323 m
.23214 .60324 L
s
.234 .60323 m
.234 .60324 L
s
.23586 .60323 m
.23586 .60325 L
s
.23772 .60323 m
.23772 .60325 L
s
.23958 .60323 m
.23958 .60325 L
s
.24144 .60323 m
.24144 .60325 L
s
.2433 .60323 m
.2433 .60325 L
s
.24516 .60323 m
.24516 .60326 L
s
.24702 .60323 m
.24702 .60326 L
s
.24888 .60323 m
.24888 .60326 L
s
.25074 .60323 m
.25074 .60326 L
s
.2526 .60323 m
.2526 .60326 L
s
.25446 .60323 m
.25446 .60326 L
s
.25632 .60323 m
.25632 .60327 L
s
.25818 .60323 m
.25818 .60327 L
s
.26004 .60323 m
.26004 .60327 L
s
.2619 .60323 m
.2619 .60327 L
s
.26376 .60323 m
.26376 .60327 L
s
.26563 .60323 m
.26563 .60327 L
s
.26749 .60323 m
.26749 .60327 L
s
.26935 .60323 m
.26935 .60327 L
s
.27121 .60323 m
.27121 .60326 L
s
.27307 .60323 m
.27307 .60326 L
s
.27493 .60323 m
.27493 .60326 L
s
.27679 .60323 m
.27679 .60326 L
s
.27865 .60323 m
.27865 .60325 L
s
.28051 .60323 m
.28051 .60325 L
s
.28237 .60323 m
.28237 .60325 L
s
.28423 .60323 m
.28423 .60325 L
s
.28609 .60323 m
.28609 .60324 L
s
.28795 .60323 m
.28795 .60324 L
s
.28981 .60323 m
.28981 .60324 L
s
.29167 .60323 m
.29167 .60324 L
s
.29353 .60323 m
.29353 .60323 L
s
.29539 .60323 m
.29539 .60323 L
s
.29725 .60323 m
.29725 .60323 L
s
.29911 .60323 m
.29911 .60323 L
s
.30097 .60323 m
.30097 .60322 L
s
.30283 .60323 m
.30283 .60322 L
s
.30469 .60323 m
.30469 .60322 L
s
.30655 .60323 m
.30655 .60322 L
s
.30841 .60323 m
.30841 .60322 L
s
.31027 .60323 m
.31027 .60323 L
s
.31213 .60323 m
.31213 .60323 L
s
.31399 .60323 m
.31399 .60323 L
s
.31585 .60323 m
.31585 .60323 L
s
.31771 .60323 m
.31771 .60323 L
s
.31957 .60323 m
.31957 .60323 L
s
.32143 .60323 m
.32143 .60324 L
s
.32329 .60323 m
.32329 .60324 L
s
.32515 .60323 m
.32515 .60324 L
s
.32701 .60323 m
.32701 .60324 L
s
.32887 .60323 m
.32887 .60324 L
s
.33073 .60323 m
.33073 .60324 L
s
.33259 .60323 m
.33259 .60325 L
s
.33445 .60323 m
.33445 .60325 L
s
.33631 .60323 m
.33631 .60325 L
s
.33817 .60323 m
.33817 .60325 L
s
.34003 .60323 m
.34003 .60325 L
s
.34189 .60323 m
.34189 .60325 L
s
.34375 .60323 m
.34375 .60326 L
s
.34561 .60323 m
.34561 .60326 L
s
.34747 .60323 m
.34747 .60326 L
s
.34933 .60323 m
.34933 .60326 L
s
.35119 .60323 m
.35119 .60326 L
s
.35305 .60323 m
.35305 .60326 L
s
.35491 .60323 m
.35491 .60326 L
s
.35677 .60323 m
.35677 .60326 L
s
.35863 .60323 m
.35863 .60326 L
s
.36049 .60323 m
.36049 .60326 L
s
.36235 .60323 m
.36235 .60326 L
s
.36421 .60323 m
.36421 .60326 L
s
.36607 .60323 m
.36607 .60325 L
s
.36793 .60323 m
.36793 .60325 L
s
.36979 .60323 m
.36979 .60324 L
s
.37165 .60323 m
.37165 .60324 L
s
.37351 .60323 m
.37351 .60323 L
s
.37537 .60323 m
.37537 .60323 L
s
.37723 .60323 m
.37723 .60322 L
s
.37909 .60323 m
.37909 .60322 L
s
.38095 .60323 m
.38095 .60321 L
s
.38281 .60323 m
.38281 .60321 L
s
.38467 .60323 m
.38467 .6032 L
s
.38653 .60323 m
.38653 .6032 L
s
.38839 .60323 m
.38839 .6032 L
s
.39025 .60323 m
.39025 .60319 L
s
.39211 .60323 m
.39211 .60319 L
s
.39397 .60323 m
.39397 .60318 L
s
.39583 .60323 m
.39583 .60318 L
s
.39769 .60323 m
.39769 .60317 L
s
.39955 .60323 m
.39955 .60317 L
s
.40141 .60323 m
.40141 .60317 L
s
.40327 .60323 m
.40327 .60317 L
s
.40513 .60323 m
.40513 .60317 L
s
.40699 .60323 m
.40699 .60317 L
s
.40885 .60323 m
.40885 .60317 L
s
.41071 .60323 m
.41071 .60317 L
s
.41257 .60323 m
.41257 .60317 L
s
.41443 .60323 m
.41443 .60318 L
s
.41629 .60323 m
.41629 .60318 L
s
.41815 .60323 m
.41815 .60318 L
s
.42001 .60323 m
.42001 .60318 L
s
.42188 .60323 m
.42188 .60318 L
s
.42374 .60323 m
.42374 .60318 L
s
.4256 .60323 m
.4256 .60318 L
s
.42746 .60323 m
.42746 .60319 L
s
.42932 .60323 m
.42932 .60319 L
s
.43118 .60323 m
.43118 .60319 L
s
.43304 .60323 m
.43304 .60319 L
s
.4349 .60323 m
.4349 .60319 L
s
.43676 .60323 m
.43676 .60319 L
s
.43862 .60323 m
.43862 .6032 L
s
.44048 .60323 m
.44048 .6032 L
s
.44234 .60323 m
.44234 .6032 L
s
.4442 .60323 m
.4442 .6032 L
s
.44606 .60323 m
.44606 .6032 L
s
.44792 .60323 m
.44792 .6032 L
s
.44978 .60323 m
.44978 .6032 L
s
.45164 .60323 m
.45164 .60321 L
s
.4535 .60323 m
.4535 .60321 L
s
.45536 .60323 m
.45536 .60321 L
s
.45722 .60323 m
.45722 .60321 L
s
.45908 .60323 m
.45908 .60321 L
s
.46094 .60323 m
.46094 .60321 L
s
.4628 .60323 m
.4628 .60321 L
s
.46466 .60323 m
.46466 .60321 L
s
.46652 .60323 m
.46652 .60322 L
s
.46838 .60323 m
.46838 .60322 L
s
.47024 .60323 m
.47024 .60322 L
s
.4721 .60323 m
.4721 .60322 L
s
.47396 .60323 m
.47396 .60322 L
s
.47582 .60323 m
.47582 .60322 L
s
.47768 .60323 m
.47768 .60322 L
s
.47954 .60323 m
.47954 .60322 L
s
.4814 .60323 m
.4814 .60322 L
s
.48326 .60323 m
.48326 .60322 L
s
.48512 .60323 m
.48512 .60322 L
s
.48698 .60323 m
.48698 .60323 L
s
.48884 .60323 m
.48884 .60323 L
s
.4907 .60323 m
.4907 .60323 L
s
.49256 .60323 m
.49256 .60323 L
s
.49442 .60323 m
.49442 .60323 L
s
.49628 .60323 m
.49628 .60323 L
s
.49814 .60323 m
.49814 .60323 L
s
.5 .60323 m
.5 .60323 L
s
.50186 .60323 m
.50186 .60323 L
s
.50372 .60323 m
.50372 .60323 L
s
.50558 .60323 m
.50558 .60323 L
s
.50744 .60323 m
.50744 .60323 L
s
.5093 .60323 m
.5093 .60323 L
s
.51116 .60323 m
.51116 .60324 L
s
.51302 .60323 m
.51302 .60324 L
s
.51488 .60323 m
.51488 .60324 L
s
.51674 .60323 m
.51674 .60324 L
s
.5186 .60323 m
.5186 .60324 L
s
.52046 .60323 m
.52046 .60324 L
s
.52232 .60323 m
.52232 .60324 L
s
.52418 .60323 m
.52418 .60324 L
s
.52604 .60323 m
.52604 .60325 L
s
.5279 .60323 m
.5279 .60325 L
s
.52976 .60323 m
.52976 .60325 L
s
.53162 .60323 m
.53162 .60325 L
s
.53348 .60323 m
.53348 .60325 L
s
.53534 .60323 m
.53534 .60325 L
s
.5372 .60323 m
.5372 .60325 L
s
.53906 .60323 m
.53906 .60326 L
s
.54092 .60323 m
.54092 .60326 L
s
.54278 .60323 m
.54278 .60326 L
s
.54464 .60323 m
.54464 .60326 L
s
.5465 .60323 m
.5465 .60326 L
s
.54836 .60323 m
.54836 .60326 L
s
.55022 .60323 m
.55022 .60326 L
s
.55208 .60323 m
.55208 .60326 L
s
.55394 .60323 m
.55394 .60326 L
s
.5558 .60323 m
.5558 .60327 L
s
.55766 .60323 m
.55766 .60327 L
s
.55952 .60323 m
.55952 .60327 L
s
.56138 .60323 m
.56138 .60327 L
s
.56324 .60323 m
.56324 .60327 L
s
.5651 .60323 m
.5651 .60327 L
s
.56696 .60323 m
.56696 .60327 L
s
.56882 .60323 m
.56882 .60327 L
s
.57068 .60323 m
.57068 .60327 L
s
.57254 .60323 m
.57254 .60327 L
s
.5744 .60323 m
.5744 .60327 L
s
.57626 .60323 m
.57626 .60327 L
s
.57813 .60323 m
.57813 .60327 L
s
.57999 .60323 m
.57999 .60327 L
s
.58185 .60323 m
.58185 .60327 L
s
.58371 .60323 m
.58371 .60327 L
s
.58557 .60323 m
.58557 .60327 L
s
.58743 .60323 m
.58743 .60327 L
s
.58929 .60323 m
.58929 .60327 L
s
.59115 .60323 m
.59115 .60327 L
s
.59301 .60323 m
.59301 .60327 L
s
.59487 .60323 m
.59487 .60327 L
s
.59673 .60323 m
.59673 .60327 L
s
.59859 .60323 m
.59859 .60327 L
s
.60045 .60323 m
.60045 .60327 L
s
.60231 .60323 m
.60231 .60328 L
s
.60417 .60323 m
.60417 .60328 L
s
.60603 .60323 m
.60603 .60328 L
s
.60789 .60323 m
.60789 .60328 L
s
.60975 .60323 m
.60975 .60328 L
s
.61161 .60323 m
.61161 .60328 L
s
.61347 .60323 m
.61347 .60328 L
s
.61533 .60323 m
.61533 .60329 L
s
.61719 .60323 m
.61719 .60329 L
s
.61905 .60323 m
.61905 .60329 L
s
.62091 .60323 m
.62091 .60329 L
s
.62277 .60323 m
.62277 .60329 L
s
.62463 .60323 m
.62463 .60329 L
s
.62649 .60323 m
.62649 .6033 L
s
.62835 .60323 m
.62835 .6033 L
s
.63021 .60323 m
.63021 .6033 L
s
.63207 .60323 m
.63207 .6033 L
s
.63393 .60323 m
.63393 .6033 L
s
.63579 .60323 m
.63579 .6033 L
s
.63765 .60323 m
.63765 .60331 L
s
.63951 .60323 m
.63951 .60331 L
s
.64137 .60323 m
.64137 .60331 L
s
.64323 .60323 m
.64323 .60331 L
s
.64509 .60323 m
.64509 .60331 L
s
.64695 .60323 m
.64695 .60331 L
s
.64881 .60323 m
.64881 .60331 L
s
.65067 .60323 m
.65067 .60331 L
s
.65253 .60323 m
.65253 .6033 L
s
.65439 .60323 m
.65439 .6033 L
s
.65625 .60323 m
.65625 .60329 L
s
.65811 .60323 m
.65811 .60328 L
s
.65997 .60323 m
.65997 .60327 L
s
.66183 .60323 m
.66183 .60326 L
s
.66369 .60323 m
.66369 .60326 L
s
.66555 .60323 m
.66555 .60326 L
s
.66741 .60323 m
.66741 .60325 L
s
.66927 .60323 m
.66927 .60325 L
s
.67113 .60323 m
.67113 .60325 L
s
.67299 .60323 m
.67299 .60324 L
s
.67485 .60323 m
.67485 .60323 L
s
.67671 .60323 m
.67671 .60322 L
s
.67857 .60323 m
.67857 .60321 L
s
.68043 .60323 m
.68043 .60321 L
s
.68229 .60323 m
.68229 .6032 L
s
.68415 .60323 m
.68415 .6032 L
s
.68601 .60323 m
.68601 .60319 L
s
.68787 .60323 m
.68787 .60319 L
s
.68973 .60323 m
.68973 .60319 L
s
.69159 .60323 m
.69159 .60319 L
s
.69345 .60323 m
.69345 .60319 L
s
.69531 .60323 m
.69531 .6032 L
s
.69717 .60323 m
.69717 .6032 L
s
.69903 .60323 m
.69903 .6032 L
s
.70089 .60323 m
.70089 .6032 L
s
.70275 .60323 m
.70275 .6032 L
s
.70461 .60323 m
.70461 .6032 L
s
.70647 .60323 m
.70647 .6032 L
s
.70833 .60323 m
.70833 .6032 L
s
.71019 .60323 m
.71019 .6032 L
s
.71205 .60323 m
.71205 .6032 L
s
.71391 .60323 m
.71391 .6032 L
s
.71577 .60323 m
.71577 .6032 L
s
.71763 .60323 m
.71763 .6032 L
s
.71949 .60323 m
.71949 .6032 L
s
.72135 .60323 m
.72135 .6032 L
s
.72321 .60323 m
.72321 .6032 L
s
.72507 .60323 m
.72507 .6032 L
s
.72693 .60323 m
.72693 .6032 L
s
.72879 .60323 m
.72879 .6032 L
s
.73065 .60323 m
.73065 .6032 L
s
.73251 .60323 m
.73251 .6032 L
s
.73438 .60323 m
.73438 .6032 L
s
.73624 .60323 m
.73624 .6032 L
s
.7381 .60323 m
.7381 .60319 L
s
.73996 .60323 m
.73996 .60319 L
s
.74182 .60323 m
.74182 .60319 L
s
.74368 .60323 m
.74368 .60319 L
s
.74554 .60323 m
.74554 .60319 L
s
.7474 .60323 m
.7474 .60319 L
s
.74926 .60323 m
.74926 .60319 L
s
.75112 .60323 m
.75112 .60319 L
s
.75298 .60323 m
.75298 .60319 L
s
.75484 .60323 m
.75484 .6032 L
s
.7567 .60323 m
.7567 .6032 L
s
.75856 .60323 m
.75856 .6032 L
s
.76042 .60323 m
.76042 .6032 L
s
.76228 .60323 m
.76228 .6032 L
s
.76414 .60323 m
.76414 .6032 L
s
.766 .60323 m
.766 .6032 L
s
.76786 .60323 m
.76786 .60321 L
s
.76972 .60323 m
.76972 .60321 L
s
.77158 .60323 m
.77158 .60321 L
s
.77344 .60323 m
.77344 .60321 L
s
.7753 .60323 m
.7753 .60321 L
s
.77716 .60323 m
.77716 .60321 L
s
.77902 .60323 m
.77902 .60322 L
s
.78088 .60323 m
.78088 .60322 L
s
.78274 .60323 m
.78274 .60322 L
s
.7846 .60323 m
.7846 .60322 L
s
.78646 .60323 m
.78646 .60322 L
s
.78832 .60323 m
.78832 .60323 L
s
.79018 .60323 m
.79018 .60323 L
s
.79204 .60323 m
.79204 .60323 L
s
.7939 .60323 m
.7939 .60323 L
s
.79576 .60323 m
.79576 .60324 L
s
.79762 .60323 m
.79762 .60324 L
s
.79948 .60323 m
.79948 .60324 L
s
.80134 .60323 m
.80134 .60324 L
s
.8032 .60323 m
.8032 .60324 L
s
.80506 .60323 m
.80506 .60325 L
s
.80692 .60323 m
.80692 .60325 L
s
.80878 .60323 m
.80878 .60325 L
s
.81064 .60323 m
.81064 .60325 L
s
.8125 .60323 m
.8125 .60325 L
s
.81436 .60323 m
.81436 .60326 L
s
.81622 .60323 m
.81622 .60326 L
s
.81808 .60323 m
.81808 .60326 L
s
.81994 .60323 m
.81994 .60326 L
s
.8218 .60323 m
.8218 .60326 L
s
.82366 .60323 m
.82366 .60327 L
s
.82552 .60323 m
.82552 .60327 L
s
.82738 .60323 m
.82738 .60327 L
s
.82924 .60323 m
.82924 .60327 L
s
.8311 .60323 m
.8311 .60327 L
s
.83296 .60323 m
.83296 .60328 L
s
.83482 .60323 m
.83482 .60328 L
s
.83668 .60323 m
.83668 .60328 L
s
.83854 .60323 m
.83854 .60328 L
s
.8404 .60323 m
.8404 .60328 L
s
.84226 .60323 m
.84226 .60329 L
s
.84412 .60323 m
.84412 .60329 L
s
.84598 .60323 m
.84598 .60329 L
s
.84784 .60323 m
.84784 .60329 L
s
.8497 .60323 m
.8497 .60329 L
s
.85156 .60323 m
.85156 .6033 L
s
.85342 .60323 m
.85342 .6033 L
s
.85528 .60323 m
.85528 .6033 L
s
.85714 .60323 m
.85714 .6033 L
s
.859 .60323 m
.859 .6033 L
s
.86086 .60323 m
.86086 .60331 L
s
.86272 .60323 m
.86272 .60331 L
s
.86458 .60323 m
.86458 .60331 L
s
.86644 .60323 m
.86644 .60331 L
s
.8683 .60323 m
.8683 .60331 L
s
.87016 .60323 m
.87016 .60332 L
s
.87202 .60323 m
.87202 .60332 L
s
.87388 .60323 m
.87388 .60332 L
s
.87574 .60323 m
.87574 .60332 L
s
.8776 .60323 m
.8776 .60332 L
s
.87946 .60323 m
.87946 .60332 L
s
.88132 .60323 m
.88132 .60332 L
s
.88318 .60323 m
.88318 .60331 L
s
.88504 .60323 m
.88504 .6033 L
s
.8869 .60323 m
.8869 .6033 L
s
.88876 .60323 m
.88876 .60329 L
s
.89063 .60323 m
.89063 .60328 L
s
.89249 .60323 m
.89249 .60327 L
s
.89435 .60323 m
.89435 .60326 L
s
.89621 .60323 m
.89621 .60326 L
s
.89807 .60323 m
.89807 .60326 L
s
.89993 .60323 m
.89993 .60325 L
s
.90179 .60323 m
.90179 .60325 L
s
.90365 .60323 m
.90365 .60324 L
s
.90551 .60323 m
.90551 .60323 L
s
.90737 .60323 m
.90737 .60322 L
s
.90923 .60323 m
.90923 .60321 L
s
.91109 .60323 m
.91109 .6032 L
s
.91295 .60323 m
.91295 .60319 L
s
.91481 .60323 m
.91481 .60319 L
s
.91667 .60323 m
.91667 .60318 L
s
.91853 .60323 m
.91853 .60318 L
s
.92039 .60323 m
.92039 .60318 L
s
.92225 .60323 m
.92225 .60318 L
s
.92411 .60323 m
.92411 .60318 L
s
.92597 .60323 m
.92597 .60318 L
s
.92783 .60323 m
.92783 .60318 L
s
.92969 .60323 m
.92969 .60318 L
s
.93155 .60323 m
.93155 .60318 L
s
.93341 .60323 m
.93341 .60318 L
s
.93527 .60323 m
.93527 .60318 L
s
.93713 .60323 m
.93713 .60318 L
s
.93899 .60323 m
.93899 .60318 L
s
.94085 .60323 m
.94085 .60318 L
s
.94271 .60323 m
.94271 .60319 L
s
.94457 .60323 m
.94457 .60319 L
s
.94643 .60323 m
.94643 .60319 L
s
.94829 .60323 m
.94829 .60319 L
s
.95015 .60323 m
.95015 .60319 L
s
.95201 .60323 m
.95201 .60319 L
s
.95387 .60323 m
.95387 .60319 L
s
.95573 .60323 m
.95573 .60319 L
s
.95759 .60323 m
.95759 .6032 L
s
.95945 .60323 m
.95945 .6032 L
s
.96131 .60323 m
.96131 .6032 L
s
.96317 .60323 m
.96317 .6032 L
s
.96503 .60323 m
.96503 .6032 L
s
.96689 .60323 m
.96689 .6032 L
s
.96875 .60323 m
.96875 .6032 L
s
.97061 .60323 m
.97061 .6032 L
s
.97247 .60323 m
.97247 .6032 L
s
.97433 .60323 m
.97433 .6032 L
s
0 1 1 r
.02381 .11081 m
.97619 .11081 L
s
.02381 .23795 m
.97619 .23795 L
s
.02381 .31101 m
.97619 .31101 L
s
.02381 .38406 m
.97619 .38406 L
s
.02381 .45712 m
.97619 .45712 L
s
.02381 .53017 m
.97619 .53017 L
s
.02381 .60323 m
.97619 .60323 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
Here the lowest few levels of coefficients are plotted in phase \
space.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.50"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[Take[wtdata, 4], Frame -> True,
FrameTicks -> None, PlotRange -> All,
PlotLabel -> \"wavelet coefficients in phase space\"]\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0147151 0.294302 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -105 0 ]
[.5 .63053 105 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet coefficients in phase space)] .5 .63053 0 -1 Mshowa
% Start of gray image
p
.02381 .01472 translate
.95238 .07357 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
400000A45095B800BB3C00D300F20075
pop
P
% End of image
% Start of gray image
p
.02381 .08829 translate
.95238 .07358 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
76E8F9E89B3664D9FBBF00F6F09F00DF
pop
P
% End of image
% Start of gray image
p
.02381 .16187 translate
.95238 .14715 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E7FEE2F8FAFAF7EFD5FEF2C9C5F0F7FDFCFCFBEEC9A7EFF8
FAFCFAF5D7D0D1FA
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .2943 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FBFAEEF0F8FDFEFFFEFEFFFFFFFFFFFFFFFFFFFFFFFEFBF5
F5FAFDFFFFFFFFFFFFFFFFFFFFFEFFFFFFFEFBE4EEF8FDFD
FFFFFFFFFFFFFDFDF8EEDCF0FBFDFDFE
pop
P
% End of image
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "The energy distribution is calculated using ",
  StyleBox["CumulativeEnergy", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.51"}],

Cell["\<\
e = CumulativeEnergy[wtdata]/
(Flatten[wtdata].Flatten[wtdata]);\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
Again, the energy is highly concentrated in a small number of \
coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.52"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Take[e, 40], PlotRange -> All,
PlotJoined -> True, PlotLabel -> \"cumulative energy\"]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000610501 0.02442 -0.165693 0.770705 [
[.24359 .59251 -6 -9 ]
[.24359 .59251 6 0 ]
[.48779 .59251 -6 -9 ]
[.48779 .59251 6 0 ]
[.73199 .59251 -6 -9 ]
[.73199 .59251 6 0 ]
[.97619 .59251 -6 -9 ]
[.97619 .59251 6 0 ]
[-0.01311 .14259 -18 -4.5 ]
[-0.01311 .14259 0 4.5 ]
[-0.01311 .29673 -18 -4.5 ]
[-0.01311 .29673 0 4.5 ]
[-0.01311 .45087 -18 -4.5 ]
[-0.01311 .45087 0 4.5 ]
[.5 .63053 -51 0 ]
[.5 .63053 51 9 ]
[ -0.00061 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.24359 .60501 m
.24359 .61126 L
s
[(10)] .24359 .59251 0 1 Mshowa
.48779 .60501 m
.48779 .61126 L
s
[(20)] .48779 .59251 0 1 Mshowa
.73199 .60501 m
.73199 .61126 L
s
[(30)] .73199 .59251 0 1 Mshowa
.97619 .60501 m
.97619 .61126 L
s
[(40)] .97619 .59251 0 1 Mshowa
.125 Mabswid
.04823 .60501 m
.04823 .60876 L
s
.09707 .60501 m
.09707 .60876 L
s
.14591 .60501 m
.14591 .60876 L
s
.19475 .60501 m
.19475 .60876 L
s
.29243 .60501 m
.29243 .60876 L
s
.34127 .60501 m
.34127 .60876 L
s
.39011 .60501 m
.39011 .60876 L
s
.43895 .60501 m
.43895 .60876 L
s
.53663 .60501 m
.53663 .60876 L
s
.58547 .60501 m
.58547 .60876 L
s
.63431 .60501 m
.63431 .60876 L
s
.68315 .60501 m
.68315 .60876 L
s
.78083 .60501 m
.78083 .60876 L
s
.82967 .60501 m
.82967 .60876 L
s
.87851 .60501 m
.87851 .60876 L
s
.92735 .60501 m
.92735 .60876 L
s
.25 Mabswid
0 .60501 m
1 .60501 L
s
-0.00061 .14259 m
.00564 .14259 L
s
[(0.4)] -0.01311 .14259 1 0 Mshowa
-0.00061 .29673 m
.00564 .29673 L
s
[(0.6)] -0.01311 .29673 1 0 Mshowa
-0.00061 .45087 m
.00564 .45087 L
s
[(0.8)] -0.01311 .45087 1 0 Mshowa
.125 Mabswid
-0.00061 .18112 m
.00314 .18112 L
s
-0.00061 .21966 m
.00314 .21966 L
s
-0.00061 .2582 m
.00314 .2582 L
s
-0.00061 .33527 m
.00314 .33527 L
s
-0.00061 .3738 m
.00314 .3738 L
s
-0.00061 .41234 m
.00314 .41234 L
s
-0.00061 .48941 m
.00314 .48941 L
s
-0.00061 .52794 m
.00314 .52794 L
s
-0.00061 .56648 m
.00314 .56648 L
s
-0.00061 .10405 m
.00314 .10405 L
s
-0.00061 .06552 m
.00314 .06552 L
s
-0.00061 .02698 m
.00314 .02698 L
s
.25 Mabswid
-0.00061 0 m
-0.00061 .61803 L
s
[(cumulative energy)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.04823 .14826 L
.07265 .278 L
.09707 .37186 L
.12149 .40726 L
.14591 .43345 L
.17033 .45952 L
.19475 .48556 L
.21917 .5017 L
.24359 .51691 L
.26801 .53146 L
.29243 .54364 L
.31685 .55324 L
.34127 .5609 L
.36569 .56845 L
.39011 .57294 L
.41453 .57696 L
.43895 .58069 L
.46337 .58403 L
.48779 .58717 L
.51221 .58919 L
.53663 .59103 L
.56105 .59268 L
.58547 .59405 L
.60989 .59525 L
.63431 .59643 L
.65873 .59734 L
.68315 .59821 L
.70757 .59901 L
.73199 .59972 L
.75641 .60038 L
.78083 .60098 L
.80525 .60147 L
.82967 .60189 L
.85409 .60222 L
.87851 .60252 L
.90293 .60275 L
.92735 .60297 L
.95177 .60319 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["In fact, 99% of the energy is in the first 27 coefficients.", 
  "MathCaption",
  CellTags->{"S2.1.1", "1.53"}],

Cell[CellGroupData[{

Cell["e[[27]]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.1"],

Cell[BoxData[
    \(0.990045894071452003`\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "By retaining 30 coefficients, we keep about 99% the energy. Then the \
velocity profile is reconstructed from the data compressed with a compression \
ratio ",
  Cell[BoxData[
      \(TraditionalForm\`1024/30 \[TildeTilde] 34\)], "InlineFormula",
    CellTags->"S2.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.1", "1.54"}],

Cell["\<\
newdata = InverseWaveletTransform[Compress[wtdata, 30], \
filter];\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
The reconstructed signal visually resembles the original fairly \
well.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.55"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[newdata, AxesLabel -> {\"x\", \"\"},
PlotLabel -> \"reconstruction of u(x)\"]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.337309 0.531372 [
[.20982 .32481 -9 -9 ]
[.20982 .32481 9 0 ]
[.39583 .32481 -9 -9 ]
[.39583 .32481 9 0 ]
[.58185 .32481 -9 -9 ]
[.58185 .32481 9 0 ]
[.76786 .32481 -9 -9 ]
[.76786 .32481 9 0 ]
[.95387 .32481 -12 -9 ]
[.95387 .32481 12 0 ]
[1.025 .33731 0 -4.5 ]
[1.025 .33731 6 4.5 ]
[.01131 .01849 -24 -4.5 ]
[.01131 .01849 0 4.5 ]
[.01131 .12476 -24 -4.5 ]
[.01131 .12476 0 4.5 ]
[.01131 .23103 -24 -4.5 ]
[.01131 .23103 0 4.5 ]
[.01131 .44358 -18 -4.5 ]
[.01131 .44358 0 4.5 ]
[.01131 .54986 -18 -4.5 ]
[.01131 .54986 0 4.5 ]
[.5 .63053 -66 0 ]
[.5 .63053 66 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .33731 m
.20982 .34356 L
s
[(200)] .20982 .32481 0 1 Mshowa
.39583 .33731 m
.39583 .34356 L
s
[(400)] .39583 .32481 0 1 Mshowa
.58185 .33731 m
.58185 .34356 L
s
[(600)] .58185 .32481 0 1 Mshowa
.76786 .33731 m
.76786 .34356 L
s
[(800)] .76786 .32481 0 1 Mshowa
.95387 .33731 m
.95387 .34356 L
s
[(1000)] .95387 .32481 0 1 Mshowa
.125 Mabswid
.07031 .33731 m
.07031 .34106 L
s
.11682 .33731 m
.11682 .34106 L
s
.16332 .33731 m
.16332 .34106 L
s
.25632 .33731 m
.25632 .34106 L
s
.30283 .33731 m
.30283 .34106 L
s
.34933 .33731 m
.34933 .34106 L
s
.44234 .33731 m
.44234 .34106 L
s
.48884 .33731 m
.48884 .34106 L
s
.53534 .33731 m
.53534 .34106 L
s
.62835 .33731 m
.62835 .34106 L
s
.67485 .33731 m
.67485 .34106 L
s
.72135 .33731 m
.72135 .34106 L
s
.81436 .33731 m
.81436 .34106 L
s
.86086 .33731 m
.86086 .34106 L
s
.90737 .33731 m
.90737 .34106 L
s
.25 Mabswid
0 .33731 m
1 .33731 L
s
[(x)] 1.025 .33731 -1 0 Mshowa
.02381 .01849 m
.03006 .01849 L
s
[(-0.6)] .01131 .01849 1 0 Mshowa
.02381 .12476 m
.03006 .12476 L
s
[(-0.4)] .01131 .12476 1 0 Mshowa
.02381 .23103 m
.03006 .23103 L
s
[(-0.2)] .01131 .23103 1 0 Mshowa
.02381 .44358 m
.03006 .44358 L
s
[(0.2)] .01131 .44358 1 0 Mshowa
.02381 .54986 m
.03006 .54986 L
s
[(0.4)] .01131 .54986 1 0 Mshowa
.125 Mabswid
.02381 .04505 m
.02756 .04505 L
s
.02381 .07162 m
.02756 .07162 L
s
.02381 .09819 m
.02756 .09819 L
s
.02381 .15133 m
.02756 .15133 L
s
.02381 .1779 m
.02756 .1779 L
s
.02381 .20447 m
.02756 .20447 L
s
.02381 .2576 m
.02756 .2576 L
s
.02381 .28417 m
.02756 .28417 L
s
.02381 .31074 m
.02756 .31074 L
s
.02381 .36388 m
.02756 .36388 L
s
.02381 .39045 m
.02756 .39045 L
s
.02381 .41701 m
.02756 .41701 L
s
.02381 .47015 m
.02756 .47015 L
s
.02381 .49672 m
.02756 .49672 L
s
.02381 .52329 m
.02756 .52329 L
s
.02381 .57643 m
.02756 .57643 L
s
.02381 .60299 m
.02756 .60299 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(reconstruction of u\\(x\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02474 .26494 Mdot
.02567 .26339 Mdot
.0266 .26312 Mdot
.02753 .26258 Mdot
.02846 .26414 Mdot
.02939 .26408 Mdot
.03032 .26611 Mdot
.03125 .26793 Mdot
.03218 .27095 Mdot
.03311 .27081 Mdot
.03404 .27193 Mdot
.03497 .27284 Mdot
.0359 .27573 Mdot
.03683 .27662 Mdot
.03776 .27941 Mdot
.03869 .28173 Mdot
.03962 .28461 Mdot
.04055 .28314 Mdot
.04148 .28239 Mdot
.04241 .28133 Mdot
.04334 .28204 Mdot
.04427 .28016 Mdot
.0452 .28033 Mdot
.04613 .28051 Mdot
.04706 .2816 Mdot
.04799 .27798 Mdot
.04892 .27549 Mdot
.04985 .27302 Mdot
.05078 .27263 Mdot
.05171 .2687 Mdot
.05264 .26701 Mdot
.05357 .26492 Mdot
.0545 .26375 Mdot
.05543 .25618 Mdot
.05636 .24988 Mdot
.05729 .243 Mdot
.05822 .23881 Mdot
.05915 .2299 Mdot
.06008 .2242 Mdot
.06101 .21803 Mdot
.06194 .21421 Mdot
.06287 .2034 Mdot
.0638 .19536 Mdot
.06473 .1866 Mdot
.06566 .18185 Mdot
.06659 .1712 Mdot
.06752 .16494 Mdot
.06845 .1574 Mdot
.06938 .15331 Mdot
.07031 .14063 Mdot
.07124 .13181 Mdot
.07217 .12131 Mdot
.0731 .11612 Mdot
.07403 .10377 Mdot
.07496 .09729 Mdot
.07589 .08907 Mdot
.07682 .08609 Mdot
.07775 .07392 Mdot
.07868 .06739 Mdot
.07961 .05889 Mdot
.08054 .05708 Mdot
.08147 .0471 Mdot
.0824 .04414 Mdot
.08333 .03894 Mdot
.08426 .03993 Mdot
.08519 .03057 Mdot
.08612 .02769 Mdot
.08705 .02237 Mdot
.08798 .02449 Mdot
.08891 .01742 Mdot
.08984 .01805 Mdot
.09077 .01624 Mdot
.0917 .02126 Mdot
.09263 .01525 Mdot
.09356 .01623 Mdot
.09449 .01472 Mdot
.09542 .02089 Mdot
.09635 .01709 Mdot
.09728 .02097 Mdot
.09821 .02222 Mdot
.09914 .03001 Mdot
.10007 .02586 Mdot
.101 .02829 Mdot
.10193 .02823 Mdot
.10286 .03562 Mdot
.10379 .03282 Mdot
.10472 .03746 Mdot
.10565 .03984 Mdot
.10658 .04854 Mdot
.10751 .04547 Mdot
.10844 .04864 Mdot
.10938 .04977 Mdot
.11031 .05805 Mdot
.11124 .05649 Mdot
.11217 .06183 Mdot
.1131 .06506 Mdot
.11403 .07387 Mdot
.11496 .07095 Mdot
.11589 .07346 Mdot
.11682 .07402 Mdot
.11775 .08124 Mdot
.11868 .07929 Mdot
.11961 .08382 Mdot
.12054 .0866 Mdot
.12147 .09459 Mdot
.1224 .09171 Mdot
.12333 .09385 Mdot
.12426 .09438 Mdot
.12519 .1012 Mdot
.12612 .09971 Mdot
.12705 .10423 Mdot
.12798 .10714 Mdot
.12891 .11467 Mdot
.12984 .11193 Mdot
.13077 .1136 Mdot
.1317 .1137 Mdot
.13263 .1196 Mdot
.13356 .11798 Mdot
.13449 .12197 Mdot
.13542 .12457 Mdot
.13635 .13154 Mdot
.13728 .12922 Mdot
.13821 .13105 Mdot
.13914 .13148 Mdot
.14007 .13728 Mdot
.141 .13625 Mdot
.14193 .14035 Mdot
.14286 .14306 Mdot
.14379 .14964 Mdot
.14472 .14755 Mdot
.14565 .14911 Mdot
.14658 .1493 Mdot
.14751 .15436 Mdot
.14844 .15324 Mdot
.14937 .15686 Mdot
.1503 .15935 Mdot
.15123 .16553 Mdot
.15216 .16411 Mdot
.15309 .16615 Mdot
.15402 .16705 Mdot
.15495 .17238 Mdot
.15588 .17212 Mdot
.15681 .17607 Mdot
.15774 .17885 Mdot
.15867 .18477 Mdot
.1596 .18361 Mdot
.16053 .18535 Mdot
.16146 .18596 Mdot
.16239 .19047 Mdot
.16332 .19 Mdot
.16425 .19332 Mdot
.16518 .19579 Mdot
.16611 .20124 Mdot
.16704 .20069 Mdot
.16797 .20291 Mdot
.1689 .20426 Mdot
.16983 .2091 Mdot
.17076 .2095 Mdot
.17169 .21314 Mdot
.17262 .21585 Mdot
.17355 .22096 Mdot
.17448 .22049 Mdot
.17541 .22219 Mdot
.17634 .22297 Mdot
.17727 .22669 Mdot
.1782 .22654 Mdot
.17913 .22923 Mdot
.18006 .23129 Mdot
.18099 .23565 Mdot
.18192 .23557 Mdot
.18285 .23756 Mdot
.18378 .23893 Mdot
.18471 .24287 Mdot
.18564 .24356 Mdot
.18657 .24659 Mdot
.1875 .24893 Mdot
.18843 .25305 Mdot
.18936 .25324 Mdot
.19029 .25497 Mdot
.19122 .256 Mdot
.19215 .2591 Mdot
.19308 .25953 Mdot
.19401 .26192 Mdot
.19494 .26386 Mdot
.19587 .26747 Mdot
.1968 .26829 Mdot
.19773 .27053 Mdot
.19866 .27233 Mdot
.19959 .2758 Mdot
.20052 .27725 Mdot
.20145 .28014 Mdot
.20238 .28256 Mdot
.20331 .28611 Mdot
.20424 .28746 Mdot
.20517 .28969 Mdot
.2061 .29148 Mdot
.20703 .29441 Mdot
.20796 .29601 Mdot
.20889 .2986 Mdot
.20982 .301 Mdot
.21075 .30432 Mdot
.21168 .30662 Mdot
.21261 .30958 Mdot
.21354 .31238 Mdot
.21447 .31585 Mdot
.2154 .31873 Mdot
.21633 .32199 Mdot
.21726 .32501 Mdot
.21819 .32824 Mdot
.21912 .33103 Mdot
.22005 .33377 Mdot
.22098 .33633 Mdot
.22191 .33894 Mdot
.22284 .34179 Mdot
.22377 .34451 Mdot
.2247 .34738 Mdot
.22563 .35015 Mdot
.22656 .35375 Mdot
.22749 .35701 Mdot
.22842 .36054 Mdot
.22935 .36358 Mdot
.23028 .36769 Mdot
.23121 .37104 Mdot
.23214 .37471 Mdot
.23307 .37755 Mdot
.234 .38181 Mdot
.23493 .38499 Mdot
.23586 .3886 Mdot
.23679 .39103 Mdot
.23772 .39514 Mdot
.23865 .3979 Mdot
.23958 .40123 Mdot
.24051 .40324 Mdot
.24144 .40737 Mdot
.24237 .40999 Mdot
.2433 .41321 Mdot
.24423 .41481 Mdot
.24516 .41859 Mdot
.24609 .42046 Mdot
.24702 .42274 Mdot
.24795 .42303 Mdot
.24888 .42559 Mdot
.24981 .42601 Mdot
.25074 .4269 Mdot
.25167 .42583 Mdot
.2526 .42761 Mdot
.25353 .42735 Mdot
.25446 .4278 Mdot
.25539 .4262 Mdot
.25632 .42779 Mdot
.25725 .42729 Mdot
.25818 .42778 Mdot
.25911 .42624 Mdot
.26004 .42825 Mdot
.26097 .42829 Mdot
.2619 .42958 Mdot
.26283 .42881 Mdot
.26376 .43155 Mdot
.26469 .43226 Mdot
.26563 .43424 Mdot
.26656 .43399 Mdot
.26749 .43682 Mdot
.26842 .43751 Mdot
.26935 .43928 Mdot
.27028 .43877 Mdot
.27121 .44077 Mdot
.27214 .44058 Mdot
.27307 .44108 Mdot
.274 .43919 Mdot
.27493 .439 Mdot
.27586 .43653 Mdot
.27679 .43437 Mdot
.27772 .43001 Mdot
.27865 .42699 Mdot
.27958 .42192 Mdot
.28051 .41694 Mdot
.28144 .41004 Mdot
.28237 .40424 Mdot
.2833 .39684 Mdot
.28423 .3897 Mdot
.28516 .38155 Mdot
.28609 .37518 Mdot
.28702 .36804 Mdot
.28795 .36122 Mdot
.28888 .35366 Mdot
.28981 .34759 Mdot
.29074 .34111 Mdot
.29167 .33512 Mdot
.2926 .32946 Mdot
.29353 .32612 Mdot
.29446 .32327 Mdot
.29539 .32069 Mdot
.29632 .31821 Mdot
.29725 .31684 Mdot
.29818 .31566 Mdot
.29911 .31431 Mdot
.30004 .3136 Mdot
.30097 .31425 Mdot
.3019 .31559 Mdot
.30283 .31639 Mdot
.30376 .3173 Mdot
.30469 .31821 Mdot
.30562 .31925 Mdot
.30655 .31953 Mdot
.30748 .32028 Mdot
.30841 .32152 Mdot
.30934 .32326 Mdot
.31027 .3243 Mdot
.3112 .32527 Mdot
.31213 .32599 Mdot
.31306 .32668 Mdot
.31399 .32703 Mdot
.31492 .32786 Mdot
.31585 .32966 Mdot
.31678 .33187 Mdot
.31771 .33403 Mdot
.31864 .336 Mdot
.31957 .33831 Mdot
.3205 .34029 Mdot
.32143 .34242 Mdot
.32236 .34465 Mdot
.32329 .34835 Mdot
.32422 .35203 Mdot
.32515 .35604 Mdot
.32608 .35946 Mdot
.32701 .36377 Mdot
.32794 .36724 Mdot
.32887 .37097 Mdot
.3298 .37407 Mdot
.33073 .37869 Mdot
.33166 .38255 Mdot
.33259 .38669 Mdot
.33352 .38974 Mdot
.33445 .39402 Mdot
.33538 .39688 Mdot
.33631 .39979 Mdot
.33724 .40121 Mdot
.33817 .40408 Mdot
.3391 .40534 Mdot
.34003 .40683 Mdot
.34096 .40687 Mdot
.34189 .40899 Mdot
.34282 .4095 Mdot
.34375 .41047 Mdot
.34468 .40968 Mdot
.34561 .41123 Mdot
.34654 .41099 Mdot
.34747 .41166 Mdot
.3484 .41083 Mdot
.34933 .41325 Mdot
.35026 .41413 Mdot
.35119 .41621 Mdot
.35212 .41635 Mdot
.35305 .41929 Mdot
.35398 .42033 Mdot
.35491 .42273 Mdot
.35584 .42342 Mdot
.35677 .4272 Mdot
.3577 .42929 Mdot
.35863 .43253 Mdot
.35956 .43337 Mdot
.36049 .43582 Mdot
.36142 .43599 Mdot
.36235 .43706 Mdot
.36328 .43606 Mdot
.36421 .43656 Mdot
.36514 .4352 Mdot
.36607 .43449 Mdot
.367 .43131 Mdot
.36793 .42805 Mdot
.36886 .42262 Mdot
.36979 .4177 Mdot
.37072 .4111 Mdot
.37165 .40458 Mdot
.37258 .3969 Mdot
.37351 .38981 Mdot
.37444 .38156 Mdot
.37537 .37256 Mdot
.3763 .3628 Mdot
.37723 .35338 Mdot
.37816 .34377 Mdot
.37909 .33336 Mdot
.38002 .32316 Mdot
.38095 .3129 Mdot
.38188 .30312 Mdot
.38281 .29184 Mdot
.38374 .28144 Mdot
.38467 .27048 Mdot
.3856 .26105 Mdot
.38653 .25005 Mdot
.38746 .24102 Mdot
.38839 .23114 Mdot
.38932 .22353 Mdot
.39025 .2139 Mdot
.39118 .20693 Mdot
.39211 .19893 Mdot
.39304 .19389 Mdot
.39397 .18658 Mdot
.3949 .1827 Mdot
.39583 .17784 Mdot
.39676 .17653 Mdot
.39769 .17254 Mdot
.39862 .17238 Mdot
.39955 .1711 Mdot
.40048 .17337 Mdot
.40141 .17204 Mdot
.40234 .17444 Mdot
.40327 .17549 Mdot
.4042 .18007 Mdot
.40513 .18035 Mdot
.40606 .18427 Mdot
.40699 .18664 Mdot
.40792 .19227 Mdot
.40885 .19279 Mdot
.40978 .19656 Mdot
.41071 .1986 Mdot
.41164 .20364 Mdot
.41257 .20319 Mdot
.4135 .20577 Mdot
.41443 .20679 Mdot
.41536 .2108 Mdot
.41629 .20958 Mdot
.41722 .21128 Mdot
.41815 .2117 Mdot
.41908 .21489 Mdot
.42001 .21305 Mdot
.42094 .21394 Mdot
.42188 .21403 Mdot
.42281 .21714 Mdot
.42374 .21623 Mdot
.42467 .21818 Mdot
.4256 .21961 Mdot
.42653 .22364 Mdot
.42746 .22367 Mdot
.42839 .22618 Mdot
.42932 .22831 Mdot
.43025 .23324 Mdot
.43118 .23501 Mdot
.43211 .23929 Mdot
.43304 .24295 Mdot
.43397 .24845 Mdot
.4349 .24992 Mdot
.43583 .25307 Mdot
.43676 .25558 Mdot
.43769 .26026 Mdot
.43862 .26198 Mdot
.43955 .26571 Mdot
.44048 .26888 Mdot
.44141 .27338 Mdot
.44234 .2741 Mdot
.44327 .27601 Mdot
.4442 .27742 Mdot
.44513 .2805 Mdot
.44606 .2809 Mdot
.44699 .28286 Mdot
.44792 .28443 Mdot
.44885 .28704 Mdot
.44978 .28633 Mdot
.45071 .28651 Mdot
.45164 .28633 Mdot
.45257 .28757 Mdot
.4535 .28664 Mdot
.45443 .28706 Mdot
.45536 .28727 Mdot
.45629 .28855 Mdot
.45722 .28734 Mdot
.45815 .28708 Mdot
.45908 .28656 Mdot
.46001 .28743 Mdot
.46094 .28666 Mdot
.46187 .28716 Mdot
.4628 .28736 Mdot
.46373 .2886 Mdot
.46466 .28785 Mdot
.46559 .28802 Mdot
.46652 .2878 Mdot
.46745 .28885 Mdot
.46838 .28863 Mdot
.46931 .28961 Mdot
.47024 .29025 Mdot
.47117 .29189 Mdot
.4721 .29208 Mdot
.47303 .29314 Mdot
.47396 .29387 Mdot
.47489 .29566 Mdot
.47582 .29649 Mdot
.47675 .2983 Mdot
.47768 .29985 Mdot
.47861 .30223 Mdot
.47954 .30359 Mdot
.48047 .30562 Mdot
.4814 .30738 Mdot
.48233 .30986 Mdot
.48326 .3116 Mdot
.48419 .31393 Mdot
.48512 .31603 Mdot
.48605 .31859 Mdot
.48698 .32045 Mdot
.48791 .32263 Mdot
.48884 .32463 Mdot
.48977 .32693 Mdot
.4907 .32881 Mdot
.49163 .33088 Mdot
.49256 .3329 Mdot
.49349 .33508 Mdot
.49442 .33707 Mdot
.49535 .33907 Mdot
.49628 .3411 Mdot
.49721 .34307 Mdot
.49814 .34505 Mdot
.49907 .34683 Mdot
.5 .3487 Mdot
.50093 .35036 Mdot
.50186 .35231 Mdot
.50279 .35391 Mdot
.50372 .35563 Mdot
.50465 .35693 Mdot
.50558 .35868 Mdot
.50651 .3599 Mdot
.50744 .36131 Mdot
.50837 .36227 Mdot
.5093 .36405 Mdot
.51023 .36523 Mdot
.51116 .36663 Mdot
.51209 .36735 Mdot
.51302 .36893 Mdot
.51395 .36972 Mdot
.51488 .37078 Mdot
.51581 .37121 Mdot
.51674 .37298 Mdot
.51767 .37397 Mdot
.5186 .3752 Mdot
.51953 .37551 Mdot
.52046 .37707 Mdot
.52139 .3776 Mdot
.52232 .3784 Mdot
.52325 .37839 Mdot
.52418 .38019 Mdot
.52511 .38106 Mdot
.52604 .3822 Mdot
.52697 .38222 Mdot
.5279 .38391 Mdot
.52883 .38439 Mdot
.52976 .38525 Mdot
.53069 .38522 Mdot
.53162 .38761 Mdot
.53255 .38897 Mdot
.53348 .3907 Mdot
.53441 .39107 Mdot
.53534 .39349 Mdot
.53627 .39442 Mdot
.5372 .39569 Mdot
.53813 .39577 Mdot
.53906 .39858 Mdot
.53999 .40008 Mdot
.54092 .40196 Mdot
.54185 .40219 Mdot
.54278 .40482 Mdot
.54371 .40573 Mdot
.54464 .4072 Mdot
.54557 .40733 Mdot
.5465 .41078 Mdot
.54743 .41277 Mdot
.54836 .41537 Mdot
.54929 .41602 Mdot
.55022 .41935 Mdot
.55115 .4206 Mdot
.55208 .42239 Mdot
.55301 .42239 Mdot
.55394 .4258 Mdot
.55487 .42732 Mdot
.5558 .42942 Mdot
.55673 .42923 Mdot
.55766 .43198 Mdot
.55859 .43239 Mdot
.55952 .43352 Mdot
.56045 .43275 Mdot
.56138 .43588 Mdot
.56231 .437 Mdot
.56324 .43887 Mdot
.56417 .43824 Mdot
.5651 .44079 Mdot
.56603 .44074 Mdot
.56696 .44137 Mdot
.56789 .43982 Mdot
.56882 .44228 Mdot
.56975 .44249 Mdot
.57068 .44341 Mdot
.57161 .44165 Mdot
.57254 .4433 Mdot
.57347 .44233 Mdot
.5744 .44232 Mdot
.57533 .44033 Mdot
.57626 .44296 Mdot
.57719 .44355 Mdot
.57813 .44507 Mdot
.57906 .44386 Mdot
.57999 .4461 Mdot
.58092 .44554 Mdot
.58185 .44573 Mdot
.58278 .44374 Mdot
.58371 .44621 Mdot
.58464 .44642 Mdot
.58557 .4472 Mdot
.5865 .44511 Mdot
.58743 .44637 Mdot
.58836 .44477 Mdot
.58929 .44371 Mdot
.59022 .44062 Mdot
.59115 .44234 Mdot
.59208 .44196 Mdot
.59301 .4421 Mdot
.59394 .43947 Mdot
.59487 .44055 Mdot
.5958 .43883 Mdot
.59673 .43772 Mdot
.59766 .43472 Mdot
.59859 .43717 Mdot
.59952 .43764 Mdot
.60045 .43878 Mdot
.60138 .43714 Mdot
.60231 .4398 Mdot
.60324 .43963 Mdot
.60417 .44034 Mdot
.6051 .43918 Mdot
.60603 .44419 Mdot
.60696 .4472 Mdot
.60789 .45114 Mdot
.60882 .45198 Mdot
.60975 .45739 Mdot
.61068 .45955 Mdot
.61161 .4626 Mdot
.61254 .46325 Mdot
.61347 .4701 Mdot
.6144 .47436 Mdot
.61533 .47943 Mdot
.61626 .48081 Mdot
.61719 .48672 Mdot
.61812 .48869 Mdot
.61905 .49134 Mdot
.61998 .49084 Mdot
.62091 .49653 Mdot
.62184 .49893 Mdot
.62277 .50214 Mdot
.6237 .50126 Mdot
.62463 .50561 Mdot
.62556 .50565 Mdot
.62649 .50665 Mdot
.62742 .50412 Mdot
.62835 .50859 Mdot
.62928 .50945 Mdot
.63021 .51171 Mdot
.63114 .50987 Mdot
.63207 .51471 Mdot
.633 .5152 Mdot
.63393 .51721 Mdot
.63486 .51528 Mdot
.63579 .52111 Mdot
.63672 .52295 Mdot
.63765 .52657 Mdot
.63858 .52586 Mdot
.63951 .53261 Mdot
.64044 .53485 Mdot
.64137 .53881 Mdot
.6423 .53807 Mdot
.64323 .54469 Mdot
.64416 .54668 Mdot
.64509 .5506 Mdot
.64602 .54956 Mdot
.64695 .55543 Mdot
.64788 .55658 Mdot
.64881 .55998 Mdot
.64974 .5583 Mdot
.65067 .56289 Mdot
.6516 .56271 Mdot
.65253 .56486 Mdot
.65346 .56176 Mdot
.65439 .56372 Mdot
.65532 .56084 Mdot
.65625 .56016 Mdot
.65718 .5546 Mdot
.65811 .5531 Mdot
.65904 .54709 Mdot
.65997 .54263 Mdot
.6609 .53351 Mdot
.66183 .52683 Mdot
.66276 .51588 Mdot
.66369 .50558 Mdot
.66462 .49154 Mdot
.66555 .47932 Mdot
.66648 .46387 Mdot
.66741 .44846 Mdot
.66834 .43039 Mdot
.66927 .41372 Mdot
.6702 .39512 Mdot
.67113 .37655 Mdot
.67206 .35727 Mdot
.67299 .34029 Mdot
.67392 .32326 Mdot
.67485 .30632 Mdot
.67578 .28977 Mdot
.67671 .27521 Mdot
.67764 .2618 Mdot
.67857 .24871 Mdot
.6795 .23792 Mdot
.68043 .22995 Mdot
.68136 .22476 Mdot
.68229 .21946 Mdot
.68322 .21639 Mdot
.68415 .21401 Mdot
.68508 .21409 Mdot
.68601 .21317 Mdot
.68694 .21488 Mdot
.68787 .21648 Mdot
.6888 .221 Mdot
.68973 .22394 Mdot
.69066 .22889 Mdot
.69159 .23159 Mdot
.69252 .23652 Mdot
.69345 .23965 Mdot
.69438 .24486 Mdot
.69531 .24743 Mdot
.69624 .25229 Mdot
.69717 .25565 Mdot
.6981 .26054 Mdot
.69903 .26176 Mdot
.69996 .26463 Mdot
.70089 .26646 Mdot
.70182 .26992 Mdot
.70275 .27013 Mdot
.70368 .27209 Mdot
.70461 .2736 Mdot
.70554 .27657 Mdot
.70647 .27625 Mdot
.7074 .2773 Mdot
.70833 .27818 Mdot
.70926 .28047 Mdot
.71019 .27982 Mdot
.71112 .28061 Mdot
.71205 .28143 Mdot
.71298 .28379 Mdot
.71391 .28343 Mdot
.71484 .28438 Mdot
.71577 .28502 Mdot
.7167 .28658 Mdot
.71763 .28477 Mdot
.71856 .28393 Mdot
.71949 .28282 Mdot
.72042 .28326 Mdot
.72135 .28127 Mdot
.72228 .28084 Mdot
.72321 .28013 Mdot
.72414 .28056 Mdot
.72507 .27772 Mdot
.726 .27606 Mdot
.72693 .27402 Mdot
.72786 .27374 Mdot
.72879 .27101 Mdot
.72972 .27005 Mdot
.73065 .26852 Mdot
.73158 .26824 Mdot
.73251 .26449 Mdot
.73344 .26201 Mdot
.73438 .25891 Mdot
.73531 .25776 Mdot
.73624 .25417 Mdot
.73717 .25272 Mdot
.7381 .25088 Mdot
.73903 .25098 Mdot
.73996 .24815 Mdot
.74089 .24726 Mdot
.74182 .24588 Mdot
.74275 .24675 Mdot
.74368 .24502 Mdot
.74461 .24551 Mdot
.74554 .24526 Mdot
.74647 .24689 Mdot
.7474 .24516 Mdot
.74833 .24528 Mdot
.74926 .2445 Mdot
.75019 .24587 Mdot
.75112 .24436 Mdot
.75205 .24507 Mdot
.75298 .24501 Mdot
.75391 .247 Mdot
.75484 .24592 Mdot
.75577 .24685 Mdot
.7567 .24704 Mdot
.75763 .24935 Mdot
.75856 .24885 Mdot
.75949 .2504 Mdot
.76042 .25123 Mdot
.76135 .25394 Mdot
.76228 .25373 Mdot
.76321 .2553 Mdot
.76414 .25616 Mdot
.76507 .2589 Mdot
.766 .25911 Mdot
.76693 .2611 Mdot
.76786 .2625 Mdot
.76879 .26564 Mdot
.76972 .26643 Mdot
.77065 .26879 Mdot
.77158 .27061 Mdot
.77251 .27399 Mdot
.77344 .27531 Mdot
.77437 .278 Mdot
.7753 .28016 Mdot
.77623 .28358 Mdot
.77716 .28514 Mdot
.77809 .28777 Mdot
.77902 .28996 Mdot
.77995 .29325 Mdot
.78088 .29513 Mdot
.78181 .29793 Mdot
.78274 .30047 Mdot
.78367 .30396 Mdot
.7846 .30647 Mdot
.78553 .30967 Mdot
.78646 .31265 Mdot
.78739 .31624 Mdot
.78832 .31911 Mdot
.78925 .3223 Mdot
.79018 .32528 Mdot
.79111 .32853 Mdot
.79204 .33146 Mdot
.79297 .33442 Mdot
.7939 .33725 Mdot
.79483 .34008 Mdot
.79576 .34303 Mdot
.79669 .34579 Mdot
.79762 .3487 Mdot
.79855 .35154 Mdot
.79948 .35523 Mdot
.80041 .35856 Mdot
.80134 .36214 Mdot
.80227 .36514 Mdot
.8032 .3691 Mdot
.80413 .37219 Mdot
.80506 .37551 Mdot
.80599 .37806 Mdot
.80692 .38214 Mdot
.80785 .38517 Mdot
.80878 .38845 Mdot
.80971 .39047 Mdot
.81064 .39412 Mdot
.81157 .39635 Mdot
.8125 .39905 Mdot
.81343 .40058 Mdot
.81436 .40471 Mdot
.81529 .40741 Mdot
.81622 .4107 Mdot
.81715 .41218 Mdot
.81808 .41607 Mdot
.81901 .41796 Mdot
.81994 .42055 Mdot
.82087 .42155 Mdot
.8218 .42603 Mdot
.82273 .42865 Mdot
.82366 .43187 Mdot
.82459 .43274 Mdot
.82552 .43653 Mdot
.82645 .43774 Mdot
.82738 .43957 Mdot
.82831 .43937 Mdot
.82924 .44338 Mdot
.83017 .44513 Mdot
.8311 .4475 Mdot
.83203 .44704 Mdot
.83296 .45024 Mdot
.83389 .45051 Mdot
.83482 .45165 Mdot
.83575 .45072 Mdot
.83668 .45525 Mdot
.83761 .45743 Mdot
.83854 .46049 Mdot
.83947 .46039 Mdot
.8404 .46473 Mdot
.84133 .46566 Mdot
.84226 .4674 Mdot
.84319 .46656 Mdot
.84412 .47189 Mdot
.84505 .47441 Mdot
.84598 .47776 Mdot
.84691 .47753 Mdot
.84784 .48261 Mdot
.84877 .48388 Mdot
.8497 .48613 Mdot
.85063 .48544 Mdot
.85156 .49196 Mdot
.85249 .49533 Mdot
.85342 .49986 Mdot
.85435 .50045 Mdot
.85528 .50741 Mdot
.85621 .51004 Mdot
.85714 .51369 Mdot
.85807 .51347 Mdot
.859 .52087 Mdot
.85993 .52423 Mdot
.86086 .52888 Mdot
.86179 .52901 Mdot
.86272 .53656 Mdot
.86365 .53936 Mdot
.86458 .5437 Mdot
.86551 .54342 Mdot
.86644 .5514 Mdot
.86737 .55471 Mdot
.8683 .56007 Mdot
.86923 .56029 Mdot
.87016 .56854 Mdot
.87109 .57161 Mdot
.87202 .57703 Mdot
.87295 .57696 Mdot
.87388 .58477 Mdot
.87481 .58722 Mdot
.87574 .5923 Mdot
.87667 .59159 Mdot
.8776 .59804 Mdot
.87853 .59887 Mdot
.87946 .60229 Mdot
.88039 .59973 Mdot
.88132 .60332 Mdot
.88225 .60121 Mdot
.88318 .60132 Mdot
.88411 .59552 Mdot
.88504 .59463 Mdot
.88597 .58814 Mdot
.8869 .58327 Mdot
.88783 .57275 Mdot
.88876 .56595 Mdot
.88969 .554 Mdot
.89063 .54326 Mdot
.89156 .52782 Mdot
.89249 .51561 Mdot
.89342 .49949 Mdot
.89435 .48458 Mdot
.89528 .46653 Mdot
.89621 .45172 Mdot
.89714 .43445 Mdot
.89807 .41815 Mdot
.899 .39991 Mdot
.89993 .38425 Mdot
.90086 .36744 Mdot
.90179 .35129 Mdot
.90272 .33503 Mdot
.90365 .3214 Mdot
.90458 .30828 Mdot
.90551 .29511 Mdot
.90644 .28258 Mdot
.90737 .27109 Mdot
.9083 .26082 Mdot
.90923 .24977 Mdot
.91016 .2406 Mdot
.91109 .23209 Mdot
.91202 .22602 Mdot
.91295 .2187 Mdot
.91388 .21347 Mdot
.91481 .20716 Mdot
.91574 .20358 Mdot
.91667 .19873 Mdot
.9176 .19705 Mdot
.91853 .19426 Mdot
.91946 .19508 Mdot
.92039 .19458 Mdot
.92132 .1968 Mdot
.92225 .19589 Mdot
.92318 .19797 Mdot
.92411 .19862 Mdot
.92504 .20242 Mdot
.92597 .20305 Mdot
.9269 .20705 Mdot
.92783 .20961 Mdot
.92876 .21475 Mdot
.92969 .21529 Mdot
.93062 .21839 Mdot
.93155 .21999 Mdot
.93248 .22421 Mdot
.93341 .22403 Mdot
.93434 .22658 Mdot
.93527 .22793 Mdot
.9362 .23173 Mdot
.93713 .23093 Mdot
.93806 .23248 Mdot
.93899 .23303 Mdot
.93992 .23589 Mdot
.94085 .23448 Mdot
.94178 .23542 Mdot
.94271 .23577 Mdot
.94364 .23863 Mdot
.94457 .23785 Mdot
.9455 .23942 Mdot
.94643 .24053 Mdot
.94736 .24373 Mdot
.94829 .2431 Mdot
.94922 .2445 Mdot
.95015 .24562 Mdot
.95108 .24913 Mdot
.95201 .2496 Mdot
.95294 .25229 Mdot
.95387 .25454 Mdot
.9548 .25846 Mdot
.95573 .25851 Mdot
.95666 .26014 Mdot
.95759 .26123 Mdot
.95852 .26439 Mdot
.95945 .26453 Mdot
.96038 .26659 Mdot
.96131 .26791 Mdot
.96224 .27047 Mdot
.96317 .26895 Mdot
.9641 .2686 Mdot
.96503 .26756 Mdot
.96596 .26844 Mdot
.96689 .26665 Mdot
.96782 .26678 Mdot
.96875 .26641 Mdot
.96968 .26744 Mdot
.97061 .26509 Mdot
.97154 .26412 Mdot
.97247 .26278 Mdot
.9734 .26353 Mdot
.97433 .26227 Mdot
.97526 .263 Mdot
.97619 .26334 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
For comparison, we display the original signal (dashed line) and \
the reconstructed signal together. Note that it is difficult to distinguish \
between the two.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.56"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[newdata, PlotJoined -> True,
 AxesLabel -> {\"x\", \"\"},
 PlotLabel -> \"velocity profile\"],
 ListPlot[data, PlotJoined -> True,
 PlotStyle -> Dashing[{0.02}]]}]]\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.337309 0.531372 [
[.20982 .32481 -9 -9 ]
[.20982 .32481 9 0 ]
[.39583 .32481 -9 -9 ]
[.39583 .32481 9 0 ]
[.58185 .32481 -9 -9 ]
[.58185 .32481 9 0 ]
[.76786 .32481 -9 -9 ]
[.76786 .32481 9 0 ]
[.95387 .32481 -12 -9 ]
[.95387 .32481 12 0 ]
[1.025 .33731 0 -4.5 ]
[1.025 .33731 6 4.5 ]
[.01131 .01849 -24 -4.5 ]
[.01131 .01849 0 4.5 ]
[.01131 .12476 -24 -4.5 ]
[.01131 .12476 0 4.5 ]
[.01131 .23103 -24 -4.5 ]
[.01131 .23103 0 4.5 ]
[.01131 .44358 -18 -4.5 ]
[.01131 .44358 0 4.5 ]
[.01131 .54986 -18 -4.5 ]
[.01131 .54986 0 4.5 ]
[.5 .63053 -48 0 ]
[.5 .63053 48 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .33731 m
.20982 .34356 L
s
[(200)] .20982 .32481 0 1 Mshowa
.39583 .33731 m
.39583 .34356 L
s
[(400)] .39583 .32481 0 1 Mshowa
.58185 .33731 m
.58185 .34356 L
s
[(600)] .58185 .32481 0 1 Mshowa
.76786 .33731 m
.76786 .34356 L
s
[(800)] .76786 .32481 0 1 Mshowa
.95387 .33731 m
.95387 .34356 L
s
[(1000)] .95387 .32481 0 1 Mshowa
.125 Mabswid
.07031 .33731 m
.07031 .34106 L
s
.11682 .33731 m
.11682 .34106 L
s
.16332 .33731 m
.16332 .34106 L
s
.25632 .33731 m
.25632 .34106 L
s
.30283 .33731 m
.30283 .34106 L
s
.34933 .33731 m
.34933 .34106 L
s
.44234 .33731 m
.44234 .34106 L
s
.48884 .33731 m
.48884 .34106 L
s
.53534 .33731 m
.53534 .34106 L
s
.62835 .33731 m
.62835 .34106 L
s
.67485 .33731 m
.67485 .34106 L
s
.72135 .33731 m
.72135 .34106 L
s
.81436 .33731 m
.81436 .34106 L
s
.86086 .33731 m
.86086 .34106 L
s
.90737 .33731 m
.90737 .34106 L
s
.25 Mabswid
0 .33731 m
1 .33731 L
s
[(x)] 1.025 .33731 -1 0 Mshowa
.02381 .01849 m
.03006 .01849 L
s
[(-0.6)] .01131 .01849 1 0 Mshowa
.02381 .12476 m
.03006 .12476 L
s
[(-0.4)] .01131 .12476 1 0 Mshowa
.02381 .23103 m
.03006 .23103 L
s
[(-0.2)] .01131 .23103 1 0 Mshowa
.02381 .44358 m
.03006 .44358 L
s
[(0.2)] .01131 .44358 1 0 Mshowa
.02381 .54986 m
.03006 .54986 L
s
[(0.4)] .01131 .54986 1 0 Mshowa
.125 Mabswid
.02381 .04505 m
.02756 .04505 L
s
.02381 .07162 m
.02756 .07162 L
s
.02381 .09819 m
.02756 .09819 L
s
.02381 .15133 m
.02756 .15133 L
s
.02381 .1779 m
.02756 .1779 L
s
.02381 .20447 m
.02756 .20447 L
s
.02381 .2576 m
.02756 .2576 L
s
.02381 .28417 m
.02756 .28417 L
s
.02381 .31074 m
.02756 .31074 L
s
.02381 .36388 m
.02756 .36388 L
s
.02381 .39045 m
.02756 .39045 L
s
.02381 .41701 m
.02756 .41701 L
s
.02381 .47015 m
.02756 .47015 L
s
.02381 .49672 m
.02756 .49672 L
s
.02381 .52329 m
.02756 .52329 L
s
.02381 .57643 m
.02756 .57643 L
s
.02381 .60299 m
.02756 .60299 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(velocity profile)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02474 .26494 m
.02567 .26339 L
.0266 .26312 L
.02753 .26258 L
.02846 .26414 L
.02939 .26408 L
.03032 .26611 L
.03125 .26793 L
.03218 .27095 L
.03311 .27081 L
.03404 .27193 L
.03497 .27284 L
.0359 .27573 L
.03683 .27662 L
.03776 .27941 L
.03869 .28173 L
.03962 .28461 L
.04055 .28314 L
.04148 .28239 L
.04241 .28133 L
.04334 .28204 L
.04427 .28016 L
.0452 .28033 L
.04613 .28051 L
.04706 .2816 L
.04799 .27798 L
.04892 .27549 L
.04985 .27302 L
.05078 .27263 L
.05171 .2687 L
.05264 .26701 L
.05357 .26492 L
.0545 .26375 L
.05543 .25618 L
.05636 .24988 L
.05729 .243 L
.05822 .23881 L
.05915 .2299 L
.06008 .2242 L
.06101 .21803 L
.06194 .21421 L
.06287 .2034 L
.0638 .19536 L
.06473 .1866 L
.06566 .18185 L
.06659 .1712 L
.06752 .16494 L
.06845 .1574 L
.06938 .15331 L
.07031 .14063 L
Mistroke
.07124 .13181 L
.07217 .12131 L
.0731 .11612 L
.07403 .10377 L
.07496 .09729 L
.07589 .08907 L
.07682 .08609 L
.07775 .07392 L
.07868 .06739 L
.07961 .05889 L
.08054 .05708 L
.08147 .0471 L
.0824 .04414 L
.08333 .03894 L
.08426 .03993 L
.08519 .03057 L
.08612 .02769 L
.08705 .02237 L
.08798 .02449 L
.08891 .01742 L
.08984 .01805 L
.09077 .01624 L
.0917 .02126 L
.09263 .01525 L
.09356 .01623 L
.09449 .01472 L
.09542 .02089 L
.09635 .01709 L
.09728 .02097 L
.09821 .02222 L
.09914 .03001 L
.10007 .02586 L
.101 .02829 L
.10193 .02823 L
.10286 .03562 L
.10379 .03282 L
.10472 .03746 L
.10565 .03984 L
.10658 .04854 L
.10751 .04547 L
.10844 .04864 L
.10938 .04977 L
.11031 .05805 L
.11124 .05649 L
.11217 .06183 L
.1131 .06506 L
.11403 .07387 L
.11496 .07095 L
.11589 .07346 L
.11682 .07402 L
Mistroke
.11775 .08124 L
.11868 .07929 L
.11961 .08382 L
.12054 .0866 L
.12147 .09459 L
.1224 .09171 L
.12333 .09385 L
.12426 .09438 L
.12519 .1012 L
.12612 .09971 L
.12705 .10423 L
.12798 .10714 L
.12891 .11467 L
.12984 .11193 L
.13077 .1136 L
.1317 .1137 L
.13263 .1196 L
.13356 .11798 L
.13449 .12197 L
.13542 .12457 L
.13635 .13154 L
.13728 .12922 L
.13821 .13105 L
.13914 .13148 L
.14007 .13728 L
.141 .13625 L
.14193 .14035 L
.14286 .14306 L
.14379 .14964 L
.14472 .14755 L
.14565 .14911 L
.14658 .1493 L
.14751 .15436 L
.14844 .15324 L
.14937 .15686 L
.1503 .15935 L
.15123 .16553 L
.15216 .16411 L
.15309 .16615 L
.15402 .16705 L
.15495 .17238 L
.15588 .17212 L
.15681 .17607 L
.15774 .17885 L
.15867 .18477 L
.1596 .18361 L
.16053 .18535 L
.16146 .18596 L
.16239 .19047 L
.16332 .19 L
Mistroke
.16425 .19332 L
.16518 .19579 L
.16611 .20124 L
.16704 .20069 L
.16797 .20291 L
.1689 .20426 L
.16983 .2091 L
.17076 .2095 L
.17169 .21314 L
.17262 .21585 L
.17355 .22096 L
.17448 .22049 L
.17541 .22219 L
.17634 .22297 L
.17727 .22669 L
.1782 .22654 L
.17913 .22923 L
.18006 .23129 L
.18099 .23565 L
.18192 .23557 L
.18285 .23756 L
.18378 .23893 L
.18471 .24287 L
.18564 .24356 L
.18657 .24659 L
.1875 .24893 L
.18843 .25305 L
.18936 .25324 L
.19029 .25497 L
.19122 .256 L
.19215 .2591 L
.19308 .25953 L
.19401 .26192 L
.19494 .26386 L
.19587 .26747 L
.1968 .26829 L
.19773 .27053 L
.19866 .27233 L
.19959 .2758 L
.20052 .27725 L
.20145 .28014 L
.20238 .28256 L
.20331 .28611 L
.20424 .28746 L
.20517 .28969 L
.2061 .29148 L
.20703 .29441 L
.20796 .29601 L
.20889 .2986 L
.20982 .301 L
Mistroke
.21075 .30432 L
.21168 .30662 L
.21261 .30958 L
.21354 .31238 L
.21447 .31585 L
.2154 .31873 L
.21633 .32199 L
.21726 .32501 L
.21819 .32824 L
.21912 .33103 L
.22005 .33377 L
.22098 .33633 L
.22191 .33894 L
.22284 .34179 L
.22377 .34451 L
.2247 .34738 L
.22563 .35015 L
.22656 .35375 L
.22749 .35701 L
.22842 .36054 L
.22935 .36358 L
.23028 .36769 L
.23121 .37104 L
.23214 .37471 L
.23307 .37755 L
.234 .38181 L
.23493 .38499 L
.23586 .3886 L
.23679 .39103 L
.23772 .39514 L
.23865 .3979 L
.23958 .40123 L
.24051 .40324 L
.24144 .40737 L
.24237 .40999 L
.2433 .41321 L
.24423 .41481 L
.24516 .41859 L
.24609 .42046 L
.24702 .42274 L
.24795 .42303 L
.24888 .42559 L
.24981 .42601 L
.25074 .4269 L
.25167 .42583 L
.2526 .42761 L
.25353 .42735 L
.25446 .4278 L
.25539 .4262 L
.25632 .42779 L
Mistroke
.25725 .42729 L
.25818 .42778 L
.25911 .42624 L
.26004 .42825 L
.26097 .42829 L
.2619 .42958 L
.26283 .42881 L
.26376 .43155 L
.26469 .43226 L
.26563 .43424 L
.26656 .43399 L
.26749 .43682 L
.26842 .43751 L
.26935 .43928 L
.27028 .43877 L
.27121 .44077 L
.27214 .44058 L
.27307 .44108 L
.274 .43919 L
.27493 .439 L
.27586 .43653 L
.27679 .43437 L
.27772 .43001 L
.27865 .42699 L
.27958 .42192 L
.28051 .41694 L
.28144 .41004 L
.28237 .40424 L
.2833 .39684 L
.28423 .3897 L
.28516 .38155 L
.28609 .37518 L
.28702 .36804 L
.28795 .36122 L
.28888 .35366 L
.28981 .34759 L
.29074 .34111 L
.29167 .33512 L
.2926 .32946 L
.29353 .32612 L
.29446 .32327 L
.29539 .32069 L
.29632 .31821 L
.29725 .31684 L
.29818 .31566 L
.29911 .31431 L
.30004 .3136 L
.30097 .31425 L
.3019 .31559 L
.30283 .31639 L
Mistroke
.30376 .3173 L
.30469 .31821 L
.30562 .31925 L
.30655 .31953 L
.30748 .32028 L
.30841 .32152 L
.30934 .32326 L
.31027 .3243 L
.3112 .32527 L
.31213 .32599 L
.31306 .32668 L
.31399 .32703 L
.31492 .32786 L
.31585 .32966 L
.31678 .33187 L
.31771 .33403 L
.31864 .336 L
.31957 .33831 L
.3205 .34029 L
.32143 .34242 L
.32236 .34465 L
.32329 .34835 L
.32422 .35203 L
.32515 .35604 L
.32608 .35946 L
.32701 .36377 L
.32794 .36724 L
.32887 .37097 L
.3298 .37407 L
.33073 .37869 L
.33166 .38255 L
.33259 .38669 L
.33352 .38974 L
.33445 .39402 L
.33538 .39688 L
.33631 .39979 L
.33724 .40121 L
.33817 .40408 L
.3391 .40534 L
.34003 .40683 L
.34096 .40687 L
.34189 .40899 L
.34282 .4095 L
.34375 .41047 L
.34468 .40968 L
.34561 .41123 L
.34654 .41099 L
.34747 .41166 L
.3484 .41083 L
.34933 .41325 L
Mistroke
.35026 .41413 L
.35119 .41621 L
.35212 .41635 L
.35305 .41929 L
.35398 .42033 L
.35491 .42273 L
.35584 .42342 L
.35677 .4272 L
.3577 .42929 L
.35863 .43253 L
.35956 .43337 L
.36049 .43582 L
.36142 .43599 L
.36235 .43706 L
.36328 .43606 L
.36421 .43656 L
.36514 .4352 L
.36607 .43449 L
.367 .43131 L
.36793 .42805 L
.36886 .42262 L
.36979 .4177 L
.37072 .4111 L
.37165 .40458 L
.37258 .3969 L
.37351 .38981 L
.37444 .38156 L
.37537 .37256 L
.3763 .3628 L
.37723 .35338 L
.37816 .34377 L
.37909 .33336 L
.38002 .32316 L
.38095 .3129 L
.38188 .30312 L
.38281 .29184 L
.38374 .28144 L
.38467 .27048 L
.3856 .26105 L
.38653 .25005 L
.38746 .24102 L
.38839 .23114 L
.38932 .22353 L
.39025 .2139 L
.39118 .20693 L
.39211 .19893 L
.39304 .19389 L
.39397 .18658 L
.3949 .1827 L
.39583 .17784 L
Mistroke
.39676 .17653 L
.39769 .17254 L
.39862 .17238 L
.39955 .1711 L
.40048 .17337 L
.40141 .17204 L
.40234 .17444 L
.40327 .17549 L
.4042 .18007 L
.40513 .18035 L
.40606 .18427 L
.40699 .18664 L
.40792 .19227 L
.40885 .19279 L
.40978 .19656 L
.41071 .1986 L
.41164 .20364 L
.41257 .20319 L
.4135 .20577 L
.41443 .20679 L
.41536 .2108 L
.41629 .20958 L
.41722 .21128 L
.41815 .2117 L
.41908 .21489 L
.42001 .21305 L
.42094 .21394 L
.42188 .21403 L
.42281 .21714 L
.42374 .21623 L
.42467 .21818 L
.4256 .21961 L
.42653 .22364 L
.42746 .22367 L
.42839 .22618 L
.42932 .22831 L
.43025 .23324 L
.43118 .23501 L
.43211 .23929 L
.43304 .24295 L
.43397 .24845 L
.4349 .24992 L
.43583 .25307 L
.43676 .25558 L
.43769 .26026 L
.43862 .26198 L
.43955 .26571 L
.44048 .26888 L
.44141 .27338 L
.44234 .2741 L
Mistroke
.44327 .27601 L
.4442 .27742 L
.44513 .2805 L
.44606 .2809 L
.44699 .28286 L
.44792 .28443 L
.44885 .28704 L
.44978 .28633 L
.45071 .28651 L
.45164 .28633 L
.45257 .28757 L
.4535 .28664 L
.45443 .28706 L
.45536 .28727 L
.45629 .28855 L
.45722 .28734 L
.45815 .28708 L
.45908 .28656 L
.46001 .28743 L
.46094 .28666 L
.46187 .28716 L
.4628 .28736 L
.46373 .2886 L
.46466 .28785 L
.46559 .28802 L
.46652 .2878 L
.46745 .28885 L
.46838 .28863 L
.46931 .28961 L
.47024 .29025 L
.47117 .29189 L
.4721 .29208 L
.47303 .29314 L
.47396 .29387 L
.47489 .29566 L
.47582 .29649 L
.47675 .2983 L
.47768 .29985 L
.47861 .30223 L
.47954 .30359 L
.48047 .30562 L
.4814 .30738 L
.48233 .30986 L
.48326 .3116 L
.48419 .31393 L
.48512 .31603 L
.48605 .31859 L
.48698 .32045 L
.48791 .32263 L
.48884 .32463 L
Mistroke
.48977 .32693 L
.4907 .32881 L
.49163 .33088 L
.49256 .3329 L
.49349 .33508 L
.49442 .33707 L
.49535 .33907 L
.49628 .3411 L
.49721 .34307 L
.49814 .34505 L
.49907 .34683 L
.5 .3487 L
.50093 .35036 L
.50186 .35231 L
.50279 .35391 L
.50372 .35563 L
.50465 .35693 L
.50558 .35868 L
.50651 .3599 L
.50744 .36131 L
.50837 .36227 L
.5093 .36405 L
.51023 .36523 L
.51116 .36663 L
.51209 .36735 L
.51302 .36893 L
.51395 .36972 L
.51488 .37078 L
.51581 .37121 L
.51674 .37298 L
.51767 .37397 L
.5186 .3752 L
.51953 .37551 L
.52046 .37707 L
.52139 .3776 L
.52232 .3784 L
.52325 .37839 L
.52418 .38019 L
.52511 .38106 L
.52604 .3822 L
.52697 .38222 L
.5279 .38391 L
.52883 .38439 L
.52976 .38525 L
.53069 .38522 L
.53162 .38761 L
.53255 .38897 L
.53348 .3907 L
.53441 .39107 L
.53534 .39349 L
Mistroke
.53627 .39442 L
.5372 .39569 L
.53813 .39577 L
.53906 .39858 L
.53999 .40008 L
.54092 .40196 L
.54185 .40219 L
.54278 .40482 L
.54371 .40573 L
.54464 .4072 L
.54557 .40733 L
.5465 .41078 L
.54743 .41277 L
.54836 .41537 L
.54929 .41602 L
.55022 .41935 L
.55115 .4206 L
.55208 .42239 L
.55301 .42239 L
.55394 .4258 L
.55487 .42732 L
.5558 .42942 L
.55673 .42923 L
.55766 .43198 L
.55859 .43239 L
.55952 .43352 L
.56045 .43275 L
.56138 .43588 L
.56231 .437 L
.56324 .43887 L
.56417 .43824 L
.5651 .44079 L
.56603 .44074 L
.56696 .44137 L
.56789 .43982 L
.56882 .44228 L
.56975 .44249 L
.57068 .44341 L
.57161 .44165 L
.57254 .4433 L
.57347 .44233 L
.5744 .44232 L
.57533 .44033 L
.57626 .44296 L
.57719 .44355 L
.57813 .44507 L
.57906 .44386 L
.57999 .4461 L
.58092 .44554 L
.58185 .44573 L
Mistroke
.58278 .44374 L
.58371 .44621 L
.58464 .44642 L
.58557 .4472 L
.5865 .44511 L
.58743 .44637 L
.58836 .44477 L
.58929 .44371 L
.59022 .44062 L
.59115 .44234 L
.59208 .44196 L
.59301 .4421 L
.59394 .43947 L
.59487 .44055 L
.5958 .43883 L
.59673 .43772 L
.59766 .43472 L
.59859 .43717 L
.59952 .43764 L
.60045 .43878 L
.60138 .43714 L
.60231 .4398 L
.60324 .43963 L
.60417 .44034 L
.6051 .43918 L
.60603 .44419 L
.60696 .4472 L
.60789 .45114 L
.60882 .45198 L
.60975 .45739 L
.61068 .45955 L
.61161 .4626 L
.61254 .46325 L
.61347 .4701 L
.6144 .47436 L
.61533 .47943 L
.61626 .48081 L
.61719 .48672 L
.61812 .48869 L
.61905 .49134 L
.61998 .49084 L
.62091 .49653 L
.62184 .49893 L
.62277 .50214 L
.6237 .50126 L
.62463 .50561 L
.62556 .50565 L
.62649 .50665 L
.62742 .50412 L
.62835 .50859 L
Mistroke
.62928 .50945 L
.63021 .51171 L
.63114 .50987 L
.63207 .51471 L
.633 .5152 L
.63393 .51721 L
.63486 .51528 L
.63579 .52111 L
.63672 .52295 L
.63765 .52657 L
.63858 .52586 L
.63951 .53261 L
.64044 .53485 L
.64137 .53881 L
.6423 .53807 L
.64323 .54469 L
.64416 .54668 L
.64509 .5506 L
.64602 .54956 L
.64695 .55543 L
.64788 .55658 L
.64881 .55998 L
.64974 .5583 L
.65067 .56289 L
.6516 .56271 L
.65253 .56486 L
.65346 .56176 L
.65439 .56372 L
.65532 .56084 L
.65625 .56016 L
.65718 .5546 L
.65811 .5531 L
.65904 .54709 L
.65997 .54263 L
.6609 .53351 L
.66183 .52683 L
.66276 .51588 L
.66369 .50558 L
.66462 .49154 L
.66555 .47932 L
.66648 .46387 L
.66741 .44846 L
.66834 .43039 L
.66927 .41372 L
.6702 .39512 L
.67113 .37655 L
.67206 .35727 L
.67299 .34029 L
.67392 .32326 L
.67485 .30632 L
Mistroke
.67578 .28977 L
.67671 .27521 L
.67764 .2618 L
.67857 .24871 L
.6795 .23792 L
.68043 .22995 L
.68136 .22476 L
.68229 .21946 L
.68322 .21639 L
.68415 .21401 L
.68508 .21409 L
.68601 .21317 L
.68694 .21488 L
.68787 .21648 L
.6888 .221 L
.68973 .22394 L
.69066 .22889 L
.69159 .23159 L
.69252 .23652 L
.69345 .23965 L
.69438 .24486 L
.69531 .24743 L
.69624 .25229 L
.69717 .25565 L
.6981 .26054 L
.69903 .26176 L
.69996 .26463 L
.70089 .26646 L
.70182 .26992 L
.70275 .27013 L
.70368 .27209 L
.70461 .2736 L
.70554 .27657 L
.70647 .27625 L
.7074 .2773 L
.70833 .27818 L
.70926 .28047 L
.71019 .27982 L
.71112 .28061 L
.71205 .28143 L
.71298 .28379 L
.71391 .28343 L
.71484 .28438 L
.71577 .28502 L
.7167 .28658 L
.71763 .28477 L
.71856 .28393 L
.71949 .28282 L
.72042 .28326 L
.72135 .28127 L
Mistroke
.72228 .28084 L
.72321 .28013 L
.72414 .28056 L
.72507 .27772 L
.726 .27606 L
.72693 .27402 L
.72786 .27374 L
.72879 .27101 L
.72972 .27005 L
.73065 .26852 L
.73158 .26824 L
.73251 .26449 L
.73344 .26201 L
.73438 .25891 L
.73531 .25776 L
.73624 .25417 L
.73717 .25272 L
.7381 .25088 L
.73903 .25098 L
.73996 .24815 L
.74089 .24726 L
.74182 .24588 L
.74275 .24675 L
.74368 .24502 L
.74461 .24551 L
.74554 .24526 L
.74647 .24689 L
.7474 .24516 L
.74833 .24528 L
.74926 .2445 L
.75019 .24587 L
.75112 .24436 L
.75205 .24507 L
.75298 .24501 L
.75391 .247 L
.75484 .24592 L
.75577 .24685 L
.7567 .24704 L
.75763 .24935 L
.75856 .24885 L
.75949 .2504 L
.76042 .25123 L
.76135 .25394 L
.76228 .25373 L
.76321 .2553 L
.76414 .25616 L
.76507 .2589 L
.766 .25911 L
.76693 .2611 L
.76786 .2625 L
Mistroke
.76879 .26564 L
.76972 .26643 L
.77065 .26879 L
.77158 .27061 L
.77251 .27399 L
.77344 .27531 L
.77437 .278 L
.7753 .28016 L
.77623 .28358 L
.77716 .28514 L
.77809 .28777 L
.77902 .28996 L
.77995 .29325 L
.78088 .29513 L
.78181 .29793 L
.78274 .30047 L
.78367 .30396 L
.7846 .30647 L
.78553 .30967 L
.78646 .31265 L
.78739 .31624 L
.78832 .31911 L
.78925 .3223 L
.79018 .32528 L
.79111 .32853 L
.79204 .33146 L
.79297 .33442 L
.7939 .33725 L
.79483 .34008 L
.79576 .34303 L
.79669 .34579 L
.79762 .3487 L
.79855 .35154 L
.79948 .35523 L
.80041 .35856 L
.80134 .36214 L
.80227 .36514 L
.8032 .3691 L
.80413 .37219 L
.80506 .37551 L
.80599 .37806 L
.80692 .38214 L
.80785 .38517 L
.80878 .38845 L
.80971 .39047 L
.81064 .39412 L
.81157 .39635 L
.8125 .39905 L
.81343 .40058 L
.81436 .40471 L
Mistroke
.81529 .40741 L
.81622 .4107 L
.81715 .41218 L
.81808 .41607 L
.81901 .41796 L
.81994 .42055 L
.82087 .42155 L
.8218 .42603 L
.82273 .42865 L
.82366 .43187 L
.82459 .43274 L
.82552 .43653 L
.82645 .43774 L
.82738 .43957 L
.82831 .43937 L
.82924 .44338 L
.83017 .44513 L
.8311 .4475 L
.83203 .44704 L
.83296 .45024 L
.83389 .45051 L
.83482 .45165 L
.83575 .45072 L
.83668 .45525 L
.83761 .45743 L
.83854 .46049 L
.83947 .46039 L
.8404 .46473 L
.84133 .46566 L
.84226 .4674 L
.84319 .46656 L
.84412 .47189 L
.84505 .47441 L
.84598 .47776 L
.84691 .47753 L
.84784 .48261 L
.84877 .48388 L
.8497 .48613 L
.85063 .48544 L
.85156 .49196 L
.85249 .49533 L
.85342 .49986 L
.85435 .50045 L
.85528 .50741 L
.85621 .51004 L
.85714 .51369 L
.85807 .51347 L
.859 .52087 L
.85993 .52423 L
.86086 .52888 L
Mistroke
.86179 .52901 L
.86272 .53656 L
.86365 .53936 L
.86458 .5437 L
.86551 .54342 L
.86644 .5514 L
.86737 .55471 L
.8683 .56007 L
.86923 .56029 L
.87016 .56854 L
.87109 .57161 L
.87202 .57703 L
.87295 .57696 L
.87388 .58477 L
.87481 .58722 L
.87574 .5923 L
.87667 .59159 L
.8776 .59804 L
.87853 .59887 L
.87946 .60229 L
.88039 .59973 L
.88132 .60332 L
.88225 .60121 L
.88318 .60132 L
.88411 .59552 L
.88504 .59463 L
.88597 .58814 L
.8869 .58327 L
.88783 .57275 L
.88876 .56595 L
.88969 .554 L
.89063 .54326 L
.89156 .52782 L
.89249 .51561 L
.89342 .49949 L
.89435 .48458 L
.89528 .46653 L
.89621 .45172 L
.89714 .43445 L
.89807 .41815 L
.899 .39991 L
.89993 .38425 L
.90086 .36744 L
.90179 .35129 L
.90272 .33503 L
.90365 .3214 L
.90458 .30828 L
.90551 .29511 L
.90644 .28258 L
.90737 .27109 L
Mistroke
.9083 .26082 L
.90923 .24977 L
.91016 .2406 L
.91109 .23209 L
.91202 .22602 L
.91295 .2187 L
.91388 .21347 L
.91481 .20716 L
.91574 .20358 L
.91667 .19873 L
.9176 .19705 L
.91853 .19426 L
.91946 .19508 L
.92039 .19458 L
.92132 .1968 L
.92225 .19589 L
.92318 .19797 L
.92411 .19862 L
.92504 .20242 L
.92597 .20305 L
.9269 .20705 L
.92783 .20961 L
.92876 .21475 L
.92969 .21529 L
.93062 .21839 L
.93155 .21999 L
.93248 .22421 L
.93341 .22403 L
.93434 .22658 L
.93527 .22793 L
.9362 .23173 L
.93713 .23093 L
.93806 .23248 L
.93899 .23303 L
.93992 .23589 L
.94085 .23448 L
.94178 .23542 L
.94271 .23577 L
.94364 .23863 L
.94457 .23785 L
.9455 .23942 L
.94643 .24053 L
.94736 .24373 L
.94829 .2431 L
.94922 .2445 L
.95015 .24562 L
.95108 .24913 L
.95201 .2496 L
.95294 .25229 L
.95387 .25454 L
Mistroke
.9548 .25846 L
.95573 .25851 L
.95666 .26014 L
.95759 .26123 L
.95852 .26439 L
.95945 .26453 L
.96038 .26659 L
.96131 .26791 L
.96224 .27047 L
.96317 .26895 L
.9641 .2686 L
.96503 .26756 L
.96596 .26844 L
.96689 .26665 L
.96782 .26678 L
.96875 .26641 L
.96968 .26744 L
.97061 .26509 L
.97154 .26412 L
.97247 .26278 L
.9734 .26353 L
.97433 .26227 L
.97526 .263 L
.97619 .26334 L
Mfstroke
[ .02 ] 0 setdash
.02474 .28178 m
.02567 .28238 L
.0266 .28288 L
.02753 .28329 L
.02846 .28361 L
.02939 .28383 L
.03032 .28395 L
.03125 .28399 L
.03218 .28393 L
.03311 .2838 L
.03404 .28358 L
.03497 .28328 L
.0359 .28292 L
.03683 .2825 L
.03776 .28202 L
.03869 .2815 L
.03962 .28093 L
.04055 .28034 L
.04148 .27972 L
.04241 .27907 L
.04334 .27841 L
.04427 .27774 L
.0452 .27706 L
.04613 .27636 L
.04706 .27563 L
.04799 .27488 L
.04892 .27409 L
.04985 .27323 L
.05078 .27229 L
.05171 .27122 L
.05264 .27 L
.05357 .26858 L
.0545 .26689 L
.05543 .26487 L
.05636 .26244 L
.05729 .25952 L
.05822 .25601 L
.05915 .2518 L
.06008 .24678 L
.06101 .24085 L
.06194 .23391 L
.06287 .22587 L
.0638 .21669 L
.06473 .20636 L
.06566 .19492 L
.06659 .18247 L
.06752 .16918 L
.06845 .1553 L
.06938 .14108 L
.07031 .12684 L
Mistroke
.07124 .11289 L
.07217 .09953 L
.0731 .087 L
.07403 .07551 L
.07496 .06519 L
.07589 .0561 L
.07682 .04827 L
.07775 .04165 L
.07868 .03619 L
.07961 .03178 L
.08054 .02834 L
.08147 .02574 L
.0824 .02388 L
.08333 .02267 L
.08426 .02201 L
.08519 .02181 L
.08612 .02201 L
.08705 .02255 L
.08798 .02336 L
.08891 .0244 L
.08984 .02563 L
.09077 .02702 L
.0917 .02855 L
.09263 .03018 L
.09356 .0319 L
.09449 .03369 L
.09542 .03555 L
.09635 .03745 L
.09728 .0394 L
.09821 .04137 L
.09914 .04338 L
.10007 .04541 L
.101 .04745 L
.10193 .04951 L
.10286 .05158 L
.10379 .05366 L
.10472 .05575 L
.10565 .05784 L
.10658 .05994 L
.10751 .06205 L
.10844 .06415 L
.10938 .06626 L
.11031 .06837 L
.11124 .07048 L
.11217 .0726 L
.1131 .07471 L
.11403 .07682 L
.11496 .07894 L
.11589 .08105 L
.11682 .08317 L
Mistroke
.11775 .08528 L
.11868 .0874 L
.11961 .08951 L
.12054 .09163 L
.12147 .09374 L
.1224 .09586 L
.12333 .09797 L
.12426 .10009 L
.12519 .10221 L
.12612 .10433 L
.12705 .10644 L
.12798 .10856 L
.12891 .11068 L
.12984 .11281 L
.13077 .11493 L
.1317 .11705 L
.13263 .11918 L
.13356 .12131 L
.13449 .12343 L
.13542 .12557 L
.13635 .1277 L
.13728 .12983 L
.13821 .13197 L
.13914 .13411 L
.14007 .13625 L
.141 .13839 L
.14193 .14054 L
.14286 .14269 L
.14379 .14484 L
.14472 .147 L
.14565 .14916 L
.14658 .15132 L
.14751 .15349 L
.14844 .15566 L
.14937 .15783 L
.1503 .16001 L
.15123 .16219 L
.15216 .16437 L
.15309 .16656 L
.15402 .16875 L
.15495 .17094 L
.15588 .17314 L
.15681 .17535 L
.15774 .17756 L
.15867 .17977 L
.1596 .18199 L
.16053 .18421 L
.16146 .18643 L
.16239 .18866 L
.16332 .1909 L
Mistroke
.16425 .19314 L
.16518 .19538 L
.16611 .19763 L
.16704 .19988 L
.16797 .20214 L
.1689 .2044 L
.16983 .20667 L
.17076 .20894 L
.17169 .21122 L
.17262 .2135 L
.17355 .21579 L
.17448 .21808 L
.17541 .22037 L
.17634 .22267 L
.17727 .22498 L
.1782 .22728 L
.17913 .2296 L
.18006 .23192 L
.18099 .23424 L
.18192 .23656 L
.18285 .23889 L
.18378 .24123 L
.18471 .24357 L
.18564 .24591 L
.18657 .24826 L
.1875 .25061 L
.18843 .25297 L
.18936 .25533 L
.19029 .2577 L
.19122 .26006 L
.19215 .26244 L
.19308 .26481 L
.19401 .26719 L
.19494 .26958 L
.19587 .27197 L
.1968 .27436 L
.19773 .27675 L
.19866 .27915 L
.19959 .28156 L
.20052 .28396 L
.20145 .28637 L
.20238 .28878 L
.20331 .2912 L
.20424 .29362 L
.20517 .29604 L
.2061 .29847 L
.20703 .3009 L
.20796 .30333 L
.20889 .30576 L
.20982 .3082 L
Mistroke
.21075 .31064 L
.21168 .31308 L
.21261 .31553 L
.21354 .31798 L
.21447 .32043 L
.2154 .32288 L
.21633 .32534 L
.21726 .3278 L
.21819 .33026 L
.21912 .33272 L
.22005 .33519 L
.22098 .33765 L
.22191 .34012 L
.22284 .34259 L
.22377 .34507 L
.2247 .34754 L
.22563 .35002 L
.22656 .3525 L
.22749 .35498 L
.22842 .35746 L
.22935 .35995 L
.23028 .36243 L
.23121 .36492 L
.23214 .3674 L
.23307 .36989 L
.234 .37238 L
.23493 .37487 L
.23586 .37736 L
.23679 .37985 L
.23772 .38234 L
.23865 .38483 L
.23958 .38731 L
.24051 .3898 L
.24144 .39228 L
.24237 .39477 L
.2433 .39725 L
.24423 .39972 L
.24516 .40219 L
.24609 .40466 L
.24702 .40712 L
.24795 .40957 L
.24888 .41201 L
.24981 .41444 L
.25074 .41686 L
.25167 .41926 L
.2526 .42165 L
.25353 .42401 L
.25446 .42634 L
.25539 .42865 L
.25632 .43092 L
Mistroke
.25725 .43314 L
.25818 .43532 L
.25911 .43744 L
.26004 .4395 L
.26097 .44147 L
.2619 .44336 L
.26283 .44514 L
.26376 .4468 L
.26469 .44831 L
.26563 .44966 L
.26656 .45082 L
.26749 .45176 L
.26842 .45244 L
.26935 .45284 L
.27028 .45292 L
.27121 .45263 L
.27214 .45193 L
.27307 .45078 L
.274 .44912 L
.27493 .44692 L
.27586 .44413 L
.27679 .44072 L
.27772 .43667 L
.27865 .43196 L
.27958 .4266 L
.28051 .42062 L
.28144 .41407 L
.28237 .407 L
.2833 .39952 L
.28423 .39174 L
.28516 .38378 L
.28609 .37577 L
.28702 .36785 L
.28795 .36016 L
.28888 .35281 L
.28981 .34592 L
.29074 .33956 L
.29167 .33379 L
.2926 .32866 L
.29353 .32418 L
.29446 .32035 L
.29539 .31715 L
.29632 .31457 L
.29725 .31255 L
.29818 .31107 L
.29911 .31007 L
.30004 .3095 L
.30097 .30934 L
.3019 .30952 L
.30283 .31001 L
Mistroke
.30376 .31078 L
.30469 .31178 L
.30562 .31299 L
.30655 .31438 L
.30748 .31593 L
.30841 .31762 L
.30934 .31942 L
.31027 .32132 L
.3112 .3233 L
.31213 .32536 L
.31306 .32749 L
.31399 .32966 L
.31492 .33189 L
.31585 .33415 L
.31678 .33644 L
.31771 .33877 L
.31864 .34111 L
.31957 .34348 L
.3205 .34586 L
.32143 .34825 L
.32236 .35066 L
.32329 .35307 L
.32422 .3555 L
.32515 .35792 L
.32608 .36035 L
.32701 .36278 L
.32794 .36522 L
.32887 .36765 L
.3298 .37008 L
.33073 .3725 L
.33166 .37492 L
.33259 .37734 L
.33352 .37974 L
.33445 .38214 L
.33538 .38453 L
.33631 .38691 L
.33724 .38927 L
.33817 .39162 L
.3391 .39395 L
.34003 .39626 L
.34096 .39855 L
.34189 .40081 L
.34282 .40305 L
.34375 .40526 L
.34468 .40743 L
.34561 .40957 L
.34654 .41167 L
.34747 .41372 L
.3484 .41572 L
.34933 .41766 L
Mistroke
.35026 .41954 L
.35119 .42135 L
.35212 .42308 L
.35305 .42472 L
.35398 .42627 L
.35491 .42771 L
.35584 .42904 L
.35677 .43023 L
.3577 .43127 L
.35863 .43215 L
.35956 .43285 L
.36049 .43335 L
.36142 .43361 L
.36235 .43363 L
.36328 .43336 L
.36421 .43278 L
.36514 .43184 L
.36607 .43051 L
.367 .42874 L
.36793 .42649 L
.36886 .42369 L
.36979 .4203 L
.37072 .41626 L
.37165 .4115 L
.37258 .40597 L
.37351 .39963 L
.37444 .39244 L
.37537 .38436 L
.3763 .37541 L
.37723 .3656 L
.37816 .35499 L
.37909 .34367 L
.38002 .33176 L
.38095 .31943 L
.38188 .30684 L
.38281 .2942 L
.38374 .28172 L
.38467 .26958 L
.3856 .25797 L
.38653 .24704 L
.38746 .23691 L
.38839 .22766 L
.38932 .21934 L
.39025 .21197 L
.39118 .20553 L
.39211 .19999 L
.39304 .1953 L
.39397 .19141 L
.3949 .18824 L
.39583 .18573 L
Mistroke
.39676 .1838 L
.39769 .1824 L
.39862 .18147 L
.39955 .18095 L
.40048 .18078 L
.40141 .18092 L
.40234 .18134 L
.40327 .18199 L
.4042 .18285 L
.40513 .18388 L
.40606 .18506 L
.40699 .18638 L
.40792 .1878 L
.40885 .18933 L
.40978 .19094 L
.41071 .19262 L
.41164 .19436 L
.41257 .19615 L
.4135 .19799 L
.41443 .19987 L
.41536 .20178 L
.41629 .20372 L
.41722 .20568 L
.41815 .20766 L
.41908 .20966 L
.42001 .21167 L
.42094 .21369 L
.42188 .21573 L
.42281 .21777 L
.42374 .21981 L
.42467 .22186 L
.4256 .22392 L
.42653 .22597 L
.42746 .22803 L
.42839 .23009 L
.42932 .23214 L
.43025 .23419 L
.43118 .23625 L
.43211 .23829 L
.43304 .24034 L
.43397 .24238 L
.4349 .24441 L
.43583 .24644 L
.43676 .24846 L
.43769 .25048 L
.43862 .25249 L
.43955 .25449 L
.44048 .25648 L
.44141 .25846 L
.44234 .26043 L
Mistroke
.44327 .26239 L
.4442 .26434 L
.44513 .26628 L
.44606 .2682 L
.44699 .27011 L
.44792 .27201 L
.44885 .27389 L
.44978 .27575 L
.45071 .2776 L
.45164 .27942 L
.45257 .28123 L
.4535 .28302 L
.45443 .28479 L
.45536 .28654 L
.45629 .28826 L
.45722 .28996 L
.45815 .29164 L
.45908 .29329 L
.46001 .29491 L
.46094 .2965 L
.46187 .29807 L
.4628 .29961 L
.46373 .30111 L
.46466 .30259 L
.46559 .30403 L
.46652 .30544 L
.46745 .30682 L
.46838 .30816 L
.46931 .30947 L
.47024 .31074 L
.47117 .31198 L
.4721 .31319 L
.47303 .31436 L
.47396 .31549 L
.47489 .31659 L
.47582 .31765 L
.47675 .31869 L
.47768 .31968 L
.47861 .32065 L
.47954 .32159 L
.48047 .3225 L
.4814 .32338 L
.48233 .32423 L
.48326 .32506 L
.48419 .32587 L
.48512 .32666 L
.48605 .32743 L
.48698 .32819 L
.48791 .32893 L
.48884 .32967 L
Mistroke
.48977 .3304 L
.4907 .33112 L
.49163 .33185 L
.49256 .33258 L
.49349 .33331 L
.49442 .33405 L
.49535 .3348 L
.49628 .33557 L
.49721 .33635 L
.49814 .33715 L
.49907 .33797 L
.5 .33882 L
.50093 .33969 L
.50186 .34059 L
.50279 .34152 L
.50372 .34248 L
.50465 .34347 L
.50558 .3445 L
.50651 .34556 L
.50744 .34665 L
.50837 .34779 L
.5093 .34895 L
.51023 .35016 L
.51116 .3514 L
.51209 .35268 L
.51302 .354 L
.51395 .35535 L
.51488 .35674 L
.51581 .35817 L
.51674 .35963 L
.51767 .36112 L
.5186 .36264 L
.51953 .3642 L
.52046 .36578 L
.52139 .3674 L
.52232 .36904 L
.52325 .37071 L
.52418 .37241 L
.52511 .37412 L
.52604 .37586 L
.52697 .37762 L
.5279 .3794 L
.52883 .3812 L
.52976 .38301 L
.53069 .38483 L
.53162 .38667 L
.53255 .38851 L
.53348 .39036 L
.53441 .39222 L
.53534 .39408 L
Mistroke
.53627 .39594 L
.5372 .3978 L
.53813 .39966 L
.53906 .40152 L
.53999 .40336 L
.54092 .4052 L
.54185 .40702 L
.54278 .40882 L
.54371 .41061 L
.54464 .41238 L
.54557 .41412 L
.5465 .41583 L
.54743 .41752 L
.54836 .41917 L
.54929 .42079 L
.55022 .42236 L
.55115 .42389 L
.55208 .42538 L
.55301 .42681 L
.55394 .42819 L
.55487 .42951 L
.5558 .43078 L
.55673 .43197 L
.55766 .4331 L
.55859 .43416 L
.55952 .43515 L
.56045 .43606 L
.56138 .43689 L
.56231 .43765 L
.56324 .43832 L
.56417 .43891 L
.5651 .43941 L
.56603 .43984 L
.56696 .44018 L
.56789 .44044 L
.56882 .44062 L
.56975 .44073 L
.57068 .44076 L
.57161 .44073 L
.57254 .44064 L
.57347 .44049 L
.5744 .44029 L
.57533 .44005 L
.57626 .43978 L
.57719 .43948 L
.57813 .43917 L
.57906 .43885 L
.57999 .43853 L
.58092 .43823 L
.58185 .43794 L
Mistroke
.58278 .43769 L
.58371 .43747 L
.58464 .4373 L
.58557 .43718 L
.5865 .43712 L
.58743 .43713 L
.58836 .43721 L
.58929 .43736 L
.59022 .4376 L
.59115 .43791 L
.59208 .43832 L
.59301 .4388 L
.59394 .43938 L
.59487 .44004 L
.5958 .44079 L
.59673 .44163 L
.59766 .44255 L
.59859 .44356 L
.59952 .44465 L
.60045 .44581 L
.60138 .44705 L
.60231 .44837 L
.60324 .44975 L
.60417 .45121 L
.6051 .45272 L
.60603 .4543 L
.60696 .45594 L
.60789 .45763 L
.60882 .45938 L
.60975 .46117 L
.61068 .46301 L
.61161 .46489 L
.61254 .46682 L
.61347 .46878 L
.6144 .47078 L
.61533 .47281 L
.61626 .47488 L
.61719 .47697 L
.61812 .47909 L
.61905 .48124 L
.61998 .4834 L
.62091 .4856 L
.62184 .48781 L
.62277 .49004 L
.6237 .49228 L
.62463 .49455 L
.62556 .49683 L
.62649 .49912 L
.62742 .50142 L
.62835 .50373 L
Mistroke
.62928 .50606 L
.63021 .50839 L
.63114 .51073 L
.63207 .51308 L
.633 .51543 L
.63393 .51779 L
.63486 .52015 L
.63579 .52251 L
.63672 .52488 L
.63765 .52724 L
.63858 .5296 L
.63951 .53196 L
.64044 .53431 L
.64137 .53664 L
.6423 .53897 L
.64323 .54128 L
.64416 .54357 L
.64509 .54583 L
.64602 .54805 L
.64695 .55022 L
.64788 .55234 L
.64881 .55437 L
.64974 .55631 L
.65067 .55812 L
.6516 .55977 L
.65253 .56121 L
.65346 .56239 L
.65439 .56323 L
.65532 .56365 L
.65625 .56353 L
.65718 .56273 L
.65811 .56107 L
.65904 .55836 L
.65997 .55434 L
.6609 .54875 L
.66183 .54128 L
.66276 .53165 L
.66369 .51957 L
.66462 .50486 L
.66555 .48745 L
.66648 .46747 L
.66741 .44526 L
.66834 .4214 L
.66927 .39667 L
.6702 .37196 L
.67113 .34815 L
.67206 .32602 L
.67299 .30613 L
.67392 .28883 L
.67485 .27422 L
Mistroke
.67578 .26224 L
.67671 .25269 L
.67764 .24529 L
.67857 .23975 L
.6795 .23578 L
.68043 .23309 L
.68136 .23145 L
.68229 .23065 L
.68322 .23051 L
.68415 .23091 L
.68508 .23172 L
.68601 .23286 L
.68694 .23425 L
.68787 .23584 L
.6888 .23758 L
.68973 .23943 L
.69066 .24137 L
.69159 .24337 L
.69252 .24542 L
.69345 .24749 L
.69438 .24959 L
.69531 .25169 L
.69624 .25379 L
.69717 .25589 L
.6981 .25796 L
.69903 .26002 L
.69996 .26204 L
.70089 .26403 L
.70182 .26598 L
.70275 .26788 L
.70368 .26973 L
.70461 .27151 L
.70554 .27322 L
.70647 .27486 L
.7074 .27641 L
.70833 .27787 L
.70926 .27923 L
.71019 .28048 L
.71112 .2816 L
.71205 .28259 L
.71298 .28345 L
.71391 .28415 L
.71484 .28468 L
.71577 .28505 L
.7167 .28523 L
.71763 .28523 L
.71856 .28502 L
.71949 .28461 L
.72042 .284 L
.72135 .28317 L
Mistroke
.72228 .28214 L
.72321 .2809 L
.72414 .27946 L
.72507 .27783 L
.726 .27602 L
.72693 .27405 L
.72786 .27193 L
.72879 .2697 L
.72972 .26738 L
.73065 .26499 L
.73158 .26256 L
.73251 .26013 L
.73344 .25773 L
.73438 .25538 L
.73531 .25311 L
.73624 .25095 L
.73717 .24892 L
.7381 .24705 L
.73903 .24536 L
.73996 .24385 L
.74089 .24254 L
.74182 .24144 L
.74275 .24054 L
.74368 .23986 L
.74461 .23939 L
.74554 .23913 L
.74647 .23908 L
.7474 .23922 L
.74833 .23954 L
.74926 .24005 L
.75019 .24073 L
.75112 .24156 L
.75205 .24255 L
.75298 .24367 L
.75391 .24493 L
.75484 .2463 L
.75577 .24779 L
.7567 .24937 L
.75763 .25105 L
.75856 .25282 L
.75949 .25466 L
.76042 .25658 L
.76135 .25856 L
.76228 .26059 L
.76321 .26268 L
.76414 .26482 L
.76507 .26701 L
.766 .26923 L
.76693 .27149 L
.76786 .27378 L
Mistroke
.76879 .2761 L
.76972 .27845 L
.77065 .28082 L
.77158 .28321 L
.77251 .28563 L
.77344 .28806 L
.77437 .2905 L
.7753 .29296 L
.77623 .29544 L
.77716 .29792 L
.77809 .30042 L
.77902 .30292 L
.77995 .30543 L
.78088 .30795 L
.78181 .31048 L
.78274 .31301 L
.78367 .31555 L
.7846 .3181 L
.78553 .32065 L
.78646 .3232 L
.78739 .32575 L
.78832 .32831 L
.78925 .33087 L
.79018 .33344 L
.79111 .336 L
.79204 .33857 L
.79297 .34114 L
.7939 .34371 L
.79483 .34629 L
.79576 .34886 L
.79669 .35144 L
.79762 .35401 L
.79855 .35659 L
.79948 .35916 L
.80041 .36174 L
.80134 .36432 L
.80227 .36689 L
.8032 .36947 L
.80413 .37205 L
.80506 .37463 L
.80599 .3772 L
.80692 .37978 L
.80785 .38235 L
.80878 .38493 L
.80971 .3875 L
.81064 .39008 L
.81157 .39265 L
.8125 .39522 L
.81343 .3978 L
.81436 .40037 L
Mistroke
.81529 .40294 L
.81622 .40551 L
.81715 .40807 L
.81808 .41064 L
.81901 .4132 L
.81994 .41577 L
.82087 .41833 L
.8218 .42089 L
.82273 .42345 L
.82366 .42601 L
.82459 .42857 L
.82552 .43112 L
.82645 .43368 L
.82738 .43623 L
.82831 .43878 L
.82924 .44133 L
.83017 .44388 L
.8311 .44642 L
.83203 .44897 L
.83296 .45151 L
.83389 .45405 L
.83482 .45658 L
.83575 .45912 L
.83668 .46165 L
.83761 .46418 L
.83854 .46671 L
.83947 .46923 L
.8404 .47176 L
.84133 .47428 L
.84226 .4768 L
.84319 .47931 L
.84412 .48183 L
.84505 .48434 L
.84598 .48684 L
.84691 .48935 L
.84784 .49185 L
.84877 .49435 L
.8497 .49685 L
.85063 .49934 L
.85156 .50183 L
.85249 .50432 L
.85342 .5068 L
.85435 .50928 L
.85528 .51176 L
.85621 .51423 L
.85714 .5167 L
.85807 .51917 L
.859 .52163 L
.85993 .52409 L
.86086 .52654 L
Mistroke
.86179 .52899 L
.86272 .53144 L
.86365 .53388 L
.86458 .53631 L
.86551 .53874 L
.86644 .54117 L
.86737 .54358 L
.8683 .54599 L
.86923 .54839 L
.87016 .55077 L
.87109 .55315 L
.87202 .5555 L
.87295 .55784 L
.87388 .56016 L
.87481 .56245 L
.87574 .5647 L
.87667 .56691 L
.8776 .56906 L
.87853 .57114 L
.87946 .57313 L
.88039 .57501 L
.88132 .57675 L
.88225 .5783 L
.88318 .57962 L
.88411 .58065 L
.88504 .5813 L
.88597 .58149 L
.8869 .58108 L
.88783 .57992 L
.88876 .57783 L
.88969 .57459 L
.89063 .56995 L
.89156 .56362 L
.89249 .55531 L
.89342 .54473 L
.89435 .53161 L
.89528 .51581 L
.89621 .49729 L
.89714 .47623 L
.89807 .45303 L
.899 .42831 L
.89993 .40287 L
.90086 .37758 L
.90179 .35328 L
.90272 .33068 L
.90365 .31027 L
.90458 .29233 L
.90551 .27693 L
.90644 .26396 L
.90737 .2532 L
Mistroke
.9083 .2444 L
.90923 .23726 L
.91016 .2315 L
.91109 .22687 L
.91202 .22315 L
.91295 .22015 L
.91388 .21774 L
.91481 .21578 L
.91574 .21419 L
.91667 .21288 L
.9176 .21182 L
.91853 .21094 L
.91946 .21023 L
.92039 .20967 L
.92132 .20923 L
.92225 .2089 L
.92318 .20869 L
.92411 .20857 L
.92504 .20856 L
.92597 .20865 L
.9269 .20883 L
.92783 .20911 L
.92876 .20949 L
.92969 .20996 L
.93062 .21052 L
.93155 .21117 L
.93248 .21191 L
.93341 .21273 L
.93434 .21364 L
.93527 .21463 L
.9362 .2157 L
.93713 .21684 L
.93806 .21805 L
.93899 .21933 L
.93992 .22067 L
.94085 .22207 L
.94178 .22352 L
.94271 .22503 L
.94364 .22658 L
.94457 .22818 L
.9455 .22982 L
.94643 .23149 L
.94736 .23319 L
.94829 .23492 L
.94922 .23668 L
.95015 .23846 L
.95108 .24025 L
.95201 .24206 L
.95294 .24387 L
.95387 .24569 L
Mistroke
.9548 .24752 L
.95573 .24934 L
.95666 .25115 L
.95759 .25296 L
.95852 .25476 L
.95945 .25653 L
.96038 .25829 L
.96131 .26003 L
.96224 .26173 L
.96317 .2634 L
.9641 .26504 L
.96503 .26664 L
.96596 .26819 L
.96689 .26969 L
.96782 .27114 L
.96875 .27253 L
.96968 .27386 L
.97061 .27512 L
.97154 .27631 L
.97247 .27743 L
.9734 .27847 L
.97433 .27943 L
.97526 .2803 L
.97619 .28109 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["We also transform the data using the Fourier basis.", "MathCaption",
  CellTags->{"S2.1.1", "1.57"}],

Cell["fdata = Fourier[data];", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
The same compression ratio is applied to the Fourier \
coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.58"}],

Cell["Chop[InverseFourier[Compress[fdata, 30]]];", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
For this compression ratio, the Fourier basis also yields good \
reconstruction.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.59"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[%, PlotJoined -> True,
 AxesLabel -> {\"x\", \"\"},
 PlotLabel -> \"velocity profile\"],
 ListPlot[data, PlotJoined -> True,
 PlotStyle -> Dashing[{0.02}]]}]]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.339069 0.542256 [
[.20982 .32657 -9 -9 ]
[.20982 .32657 9 0 ]
[.39583 .32657 -9 -9 ]
[.39583 .32657 9 0 ]
[.58185 .32657 -9 -9 ]
[.58185 .32657 9 0 ]
[.76786 .32657 -9 -9 ]
[.76786 .32657 9 0 ]
[.95387 .32657 -12 -9 ]
[.95387 .32657 12 0 ]
[1.025 .33907 0 -4.5 ]
[1.025 .33907 6 4.5 ]
[.01131 .01372 -24 -4.5 ]
[.01131 .01372 0 4.5 ]
[.01131 .12217 -24 -4.5 ]
[.01131 .12217 0 4.5 ]
[.01131 .23062 -24 -4.5 ]
[.01131 .23062 0 4.5 ]
[.01131 .44752 -18 -4.5 ]
[.01131 .44752 0 4.5 ]
[.01131 .55597 -18 -4.5 ]
[.01131 .55597 0 4.5 ]
[.5 .63053 -48 0 ]
[.5 .63053 48 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .33907 m
.20982 .34532 L
s
[(200)] .20982 .32657 0 1 Mshowa
.39583 .33907 m
.39583 .34532 L
s
[(400)] .39583 .32657 0 1 Mshowa
.58185 .33907 m
.58185 .34532 L
s
[(600)] .58185 .32657 0 1 Mshowa
.76786 .33907 m
.76786 .34532 L
s
[(800)] .76786 .32657 0 1 Mshowa
.95387 .33907 m
.95387 .34532 L
s
[(1000)] .95387 .32657 0 1 Mshowa
.125 Mabswid
.07031 .33907 m
.07031 .34282 L
s
.11682 .33907 m
.11682 .34282 L
s
.16332 .33907 m
.16332 .34282 L
s
.25632 .33907 m
.25632 .34282 L
s
.30283 .33907 m
.30283 .34282 L
s
.34933 .33907 m
.34933 .34282 L
s
.44234 .33907 m
.44234 .34282 L
s
.48884 .33907 m
.48884 .34282 L
s
.53534 .33907 m
.53534 .34282 L
s
.62835 .33907 m
.62835 .34282 L
s
.67485 .33907 m
.67485 .34282 L
s
.72135 .33907 m
.72135 .34282 L
s
.81436 .33907 m
.81436 .34282 L
s
.86086 .33907 m
.86086 .34282 L
s
.90737 .33907 m
.90737 .34282 L
s
.25 Mabswid
0 .33907 m
1 .33907 L
s
[(x)] 1.025 .33907 -1 0 Mshowa
.02381 .01372 m
.03006 .01372 L
s
[(-0.6)] .01131 .01372 1 0 Mshowa
.02381 .12217 m
.03006 .12217 L
s
[(-0.4)] .01131 .12217 1 0 Mshowa
.02381 .23062 m
.03006 .23062 L
s
[(-0.2)] .01131 .23062 1 0 Mshowa
.02381 .44752 m
.03006 .44752 L
s
[(0.2)] .01131 .44752 1 0 Mshowa
.02381 .55597 m
.03006 .55597 L
s
[(0.4)] .01131 .55597 1 0 Mshowa
.125 Mabswid
.02381 .04083 m
.02756 .04083 L
s
.02381 .06794 m
.02756 .06794 L
s
.02381 .09505 m
.02756 .09505 L
s
.02381 .14928 m
.02756 .14928 L
s
.02381 .17639 m
.02756 .17639 L
s
.02381 .20351 m
.02756 .20351 L
s
.02381 .25773 m
.02756 .25773 L
s
.02381 .28484 m
.02756 .28484 L
s
.02381 .31196 m
.02756 .31196 L
s
.02381 .36618 m
.02756 .36618 L
s
.02381 .39329 m
.02756 .39329 L
s
.02381 .42041 m
.02756 .42041 L
s
.02381 .47463 m
.02756 .47463 L
s
.02381 .50175 m
.02756 .50175 L
s
.02381 .52886 m
.02756 .52886 L
s
.02381 .58308 m
.02756 .58308 L
s
.02381 .6102 m
.02756 .6102 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(velocity profile)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02474 .2925 m
.02567 .29471 L
.0266 .29685 L
.02753 .29892 L
.02846 .30087 L
.02939 .30269 L
.03032 .30436 L
.03125 .30584 L
.03218 .30712 L
.03311 .30816 L
.03404 .30895 L
.03497 .30946 L
.0359 .30967 L
.03683 .30955 L
.03776 .3091 L
.03869 .30829 L
.03962 .30711 L
.04055 .30554 L
.04148 .30357 L
.04241 .30119 L
.04334 .29839 L
.04427 .29518 L
.0452 .29155 L
.04613 .2875 L
.04706 .28303 L
.04799 .27815 L
.04892 .27288 L
.04985 .26721 L
.05078 .26117 L
.05171 .25478 L
.05264 .24805 L
.05357 .241 L
.0545 .23365 L
.05543 .22604 L
.05636 .21819 L
.05729 .21013 L
.05822 .20189 L
.05915 .1935 L
.06008 .18499 L
.06101 .17639 L
.06194 .16775 L
.06287 .15909 L
.0638 .15044 L
.06473 .14184 L
.06566 .13333 L
.06659 .12493 L
.06752 .11668 L
.06845 .1086 L
.06938 .10073 L
.07031 .0931 L
Mistroke
.07124 .08572 L
.07217 .07863 L
.0731 .07185 L
.07403 .06539 L
.07496 .05928 L
.07589 .05353 L
.07682 .04815 L
.07775 .04316 L
.07868 .03857 L
.07961 .03438 L
.08054 .0306 L
.08147 .02724 L
.0824 .02428 L
.08333 .02173 L
.08426 .01959 L
.08519 .01785 L
.08612 .0165 L
.08705 .01554 L
.08798 .01495 L
.08891 .01472 L
.08984 .01483 L
.09077 .01528 L
.0917 .01604 L
.09263 .01711 L
.09356 .01846 L
.09449 .02007 L
.09542 .02193 L
.09635 .02402 L
.09728 .02632 L
.09821 .02881 L
.09914 .03147 L
.10007 .03429 L
.101 .03725 L
.10193 .04033 L
.10286 .04351 L
.10379 .04678 L
.10472 .05013 L
.10565 .05353 L
.10658 .05699 L
.10751 .06047 L
.10844 .06397 L
.10938 .06749 L
.11031 .071 L
.11124 .07451 L
.11217 .078 L
.1131 .08147 L
.11403 .0849 L
.11496 .0883 L
.11589 .09165 L
.11682 .09496 L
Mistroke
.11775 .09821 L
.11868 .10141 L
.11961 .10455 L
.12054 .10764 L
.12147 .11065 L
.1224 .11361 L
.12333 .11649 L
.12426 .11931 L
.12519 .12206 L
.12612 .12474 L
.12705 .12734 L
.12798 .12987 L
.12891 .13233 L
.12984 .13471 L
.13077 .13701 L
.1317 .13923 L
.13263 .14137 L
.13356 .14342 L
.13449 .1454 L
.13542 .14729 L
.13635 .14909 L
.13728 .15081 L
.13821 .15243 L
.13914 .15397 L
.14007 .15542 L
.141 .15678 L
.14193 .15804 L
.14286 .15922 L
.14379 .1603 L
.14472 .1613 L
.14565 .16221 L
.14658 .16303 L
.14751 .16377 L
.14844 .16444 L
.14937 .16502 L
.1503 .16554 L
.15123 .166 L
.15216 .16639 L
.15309 .16673 L
.15402 .16703 L
.15495 .16729 L
.15588 .16753 L
.15681 .16775 L
.15774 .16796 L
.15867 .16817 L
.1596 .16839 L
.16053 .16864 L
.16146 .16893 L
.16239 .16927 L
.16332 .16966 L
Mistroke
.16425 .17013 L
.16518 .17069 L
.16611 .17134 L
.16704 .1721 L
.16797 .17298 L
.1689 .174 L
.16983 .17515 L
.17076 .17646 L
.17169 .17793 L
.17262 .17957 L
.17355 .18138 L
.17448 .18338 L
.17541 .18557 L
.17634 .18794 L
.17727 .19052 L
.1782 .19329 L
.17913 .19626 L
.18006 .19943 L
.18099 .20279 L
.18192 .20634 L
.18285 .21008 L
.18378 .214 L
.18471 .21809 L
.18564 .22235 L
.18657 .22676 L
.1875 .23131 L
.18843 .23599 L
.18936 .2408 L
.19029 .2457 L
.19122 .25069 L
.19215 .25576 L
.19308 .26088 L
.19401 .26604 L
.19494 .27122 L
.19587 .27642 L
.1968 .2816 L
.19773 .28675 L
.19866 .29186 L
.19959 .29691 L
.20052 .30188 L
.20145 .30675 L
.20238 .31152 L
.20331 .31617 L
.20424 .32069 L
.20517 .32506 L
.2061 .32927 L
.20703 .33331 L
.20796 .33718 L
.20889 .34087 L
.20982 .34437 L
Mistroke
.21075 .34768 L
.21168 .3508 L
.21261 .35371 L
.21354 .35643 L
.21447 .35896 L
.2154 .36129 L
.21633 .36344 L
.21726 .3654 L
.21819 .36719 L
.21912 .3688 L
.22005 .37026 L
.22098 .37157 L
.22191 .37274 L
.22284 .37378 L
.22377 .3747 L
.2247 .37552 L
.22563 .37624 L
.22656 .37689 L
.22749 .37748 L
.22842 .37801 L
.22935 .37851 L
.23028 .37898 L
.23121 .37943 L
.23214 .37989 L
.23307 .38036 L
.234 .38085 L
.23493 .38138 L
.23586 .38195 L
.23679 .38256 L
.23772 .38324 L
.23865 .38398 L
.23958 .38479 L
.24051 .38567 L
.24144 .38663 L
.24237 .38767 L
.2433 .38879 L
.24423 .38999 L
.24516 .39126 L
.24609 .39261 L
.24702 .39402 L
.24795 .3955 L
.24888 .39704 L
.24981 .39863 L
.25074 .40027 L
.25167 .40193 L
.2526 .40363 L
.25353 .40534 L
.25446 .40705 L
.25539 .40875 L
.25632 .41043 L
Mistroke
.25725 .41209 L
.25818 .4137 L
.25911 .41526 L
.26004 .41675 L
.26097 .41816 L
.2619 .41948 L
.26283 .4207 L
.26376 .4218 L
.26469 .42279 L
.26563 .42364 L
.26656 .42435 L
.26749 .42491 L
.26842 .42531 L
.26935 .42555 L
.27028 .42562 L
.27121 .42551 L
.27214 .42523 L
.27307 .42476 L
.274 .42411 L
.27493 .42327 L
.27586 .42225 L
.27679 .42104 L
.27772 .41965 L
.27865 .41808 L
.27958 .41633 L
.28051 .41441 L
.28144 .41233 L
.28237 .41009 L
.2833 .4077 L
.28423 .40517 L
.28516 .4025 L
.28609 .39971 L
.28702 .3968 L
.28795 .3938 L
.28888 .3907 L
.28981 .38752 L
.29074 .38428 L
.29167 .38098 L
.2926 .37764 L
.29353 .37428 L
.29446 .3709 L
.29539 .36752 L
.29632 .36416 L
.29725 .36082 L
.29818 .35753 L
.29911 .3543 L
.30004 .35114 L
.30097 .34806 L
.3019 .34508 L
.30283 .34221 L
Mistroke
.30376 .33947 L
.30469 .33687 L
.30562 .33442 L
.30655 .33213 L
.30748 .33002 L
.30841 .32809 L
.30934 .32636 L
.31027 .32483 L
.3112 .32352 L
.31213 .32244 L
.31306 .32158 L
.31399 .32097 L
.31492 .3206 L
.31585 .32048 L
.31678 .32062 L
.31771 .32101 L
.31864 .32167 L
.31957 .32258 L
.3205 .32376 L
.32143 .3252 L
.32236 .3269 L
.32329 .32885 L
.32422 .33106 L
.32515 .33351 L
.32608 .33619 L
.32701 .33911 L
.32794 .34224 L
.32887 .34558 L
.3298 .34912 L
.33073 .35284 L
.33166 .35672 L
.33259 .36076 L
.33352 .36492 L
.33445 .3692 L
.33538 .37358 L
.33631 .37802 L
.33724 .38252 L
.33817 .38705 L
.3391 .39158 L
.34003 .3961 L
.34096 .40057 L
.34189 .40497 L
.34282 .40928 L
.34375 .41346 L
.34468 .41751 L
.34561 .42138 L
.34654 .42505 L
.34747 .42851 L
.3484 .43172 L
.34933 .43465 L
Mistroke
.35026 .4373 L
.35119 .43963 L
.35212 .44162 L
.35305 .44326 L
.35398 .44453 L
.35491 .44541 L
.35584 .44588 L
.35677 .44594 L
.3577 .44557 L
.35863 .44476 L
.35956 .44351 L
.36049 .44181 L
.36142 .43966 L
.36235 .43706 L
.36328 .43402 L
.36421 .43053 L
.36514 .42661 L
.36607 .42226 L
.367 .4175 L
.36793 .41235 L
.36886 .40681 L
.36979 .40091 L
.37072 .39467 L
.37165 .38811 L
.37258 .38125 L
.37351 .37414 L
.37444 .36678 L
.37537 .35921 L
.3763 .35147 L
.37723 .34358 L
.37816 .33558 L
.37909 .32749 L
.38002 .31936 L
.38095 .31121 L
.38188 .30309 L
.38281 .29502 L
.38374 .28703 L
.38467 .27916 L
.3856 .27144 L
.38653 .26391 L
.38746 .25657 L
.38839 .24948 L
.38932 .24265 L
.39025 .2361 L
.39118 .22986 L
.39211 .22394 L
.39304 .21837 L
.39397 .21316 L
.3949 .20832 L
.39583 .20386 L
Mistroke
.39676 .1998 L
.39769 .19613 L
.39862 .19286 L
.39955 .18999 L
.40048 .18751 L
.40141 .18543 L
.40234 .18374 L
.40327 .18242 L
.4042 .18147 L
.40513 .18088 L
.40606 .18062 L
.40699 .18069 L
.40792 .18107 L
.40885 .18174 L
.40978 .18267 L
.41071 .18385 L
.41164 .18526 L
.41257 .18687 L
.4135 .18866 L
.41443 .19062 L
.41536 .19271 L
.41629 .19492 L
.41722 .19723 L
.41815 .19961 L
.41908 .20205 L
.42001 .20452 L
.42094 .20702 L
.42188 .20952 L
.42281 .21201 L
.42374 .21448 L
.42467 .21692 L
.4256 .21931 L
.42653 .22165 L
.42746 .22394 L
.42839 .22616 L
.42932 .22832 L
.43025 .23041 L
.43118 .23244 L
.43211 .23441 L
.43304 .23632 L
.43397 .23818 L
.4349 .23998 L
.43583 .24175 L
.43676 .24349 L
.43769 .24521 L
.43862 .24691 L
.43955 .24861 L
.44048 .25032 L
.44141 .25206 L
.44234 .25382 L
Mistroke
.44327 .25562 L
.4442 .25748 L
.44513 .2594 L
.44606 .26139 L
.44699 .26346 L
.44792 .26561 L
.44885 .26786 L
.44978 .2702 L
.45071 .27265 L
.45164 .2752 L
.45257 .27785 L
.4535 .28061 L
.45443 .28346 L
.45536 .28642 L
.45629 .28946 L
.45722 .2926 L
.45815 .2958 L
.45908 .29908 L
.46001 .3024 L
.46094 .30577 L
.46187 .30917 L
.4628 .31259 L
.46373 .316 L
.46466 .3194 L
.46559 .32276 L
.46652 .32607 L
.46745 .32931 L
.46838 .33246 L
.46931 .33551 L
.47024 .33844 L
.47117 .34124 L
.4721 .34388 L
.47303 .34636 L
.47396 .34865 L
.47489 .35075 L
.47582 .35265 L
.47675 .35433 L
.47768 .3558 L
.47861 .35703 L
.47954 .35803 L
.48047 .3588 L
.4814 .35933 L
.48233 .35962 L
.48326 .35969 L
.48419 .35953 L
.48512 .35915 L
.48605 .35856 L
.48698 .35778 L
.48791 .35681 L
.48884 .35567 L
Mistroke
.48977 .35437 L
.4907 .35294 L
.49163 .35139 L
.49256 .34974 L
.49349 .34802 L
.49442 .34624 L
.49535 .34442 L
.49628 .3426 L
.49721 .34078 L
.49814 .339 L
.49907 .33727 L
.5 .33562 L
.50093 .33407 L
.50186 .33263 L
.50279 .33133 L
.50372 .33019 L
.50465 .32922 L
.50558 .32843 L
.50651 .32784 L
.50744 .32746 L
.50837 .3273 L
.5093 .32737 L
.51023 .32766 L
.51116 .3282 L
.51209 .32897 L
.51302 .32997 L
.51395 .3312 L
.51488 .33266 L
.51581 .33435 L
.51674 .33624 L
.51767 .33833 L
.5186 .3406 L
.51953 .34305 L
.52046 .34566 L
.52139 .34841 L
.52232 .35128 L
.52325 .35426 L
.52418 .35732 L
.52511 .36045 L
.52604 .36362 L
.52697 .36682 L
.5279 .37002 L
.52883 .37322 L
.52976 .37637 L
.53069 .37948 L
.53162 .38253 L
.53255 .38548 L
.53348 .38834 L
.53441 .39109 L
.53534 .39372 L
Mistroke
.53627 .39621 L
.5372 .39855 L
.53813 .40075 L
.53906 .40279 L
.53999 .40468 L
.54092 .4064 L
.54185 .40797 L
.54278 .40938 L
.54371 .41064 L
.54464 .41175 L
.54557 .41273 L
.5465 .41357 L
.54743 .4143 L
.54836 .41492 L
.54929 .41544 L
.55022 .41588 L
.55115 .41626 L
.55208 .41658 L
.55301 .41686 L
.55394 .41713 L
.55487 .41738 L
.5558 .41765 L
.55673 .41794 L
.55766 .41827 L
.55859 .41865 L
.55952 .41909 L
.56045 .41961 L
.56138 .42021 L
.56231 .42091 L
.56324 .42171 L
.56417 .42262 L
.5651 .42364 L
.56603 .42477 L
.56696 .42602 L
.56789 .42738 L
.56882 .42886 L
.56975 .43044 L
.57068 .43212 L
.57161 .43389 L
.57254 .43575 L
.57347 .43769 L
.5744 .43968 L
.57533 .44173 L
.57626 .44381 L
.57719 .44591 L
.57813 .44802 L
.57906 .45012 L
.57999 .4522 L
.58092 .45423 L
.58185 .45621 L
Mistroke
.58278 .45812 L
.58371 .45994 L
.58464 .46166 L
.58557 .46327 L
.5865 .46476 L
.58743 .46612 L
.58836 .46733 L
.58929 .46839 L
.59022 .4693 L
.59115 .47006 L
.59208 .47065 L
.59301 .47109 L
.59394 .47137 L
.59487 .4715 L
.5958 .47149 L
.59673 .47134 L
.59766 .47106 L
.59859 .47068 L
.59952 .47019 L
.60045 .46962 L
.60138 .46899 L
.60231 .46831 L
.60324 .46761 L
.60417 .4669 L
.6051 .4662 L
.60603 .46554 L
.60696 .46494 L
.60789 .46441 L
.60882 .46399 L
.60975 .4637 L
.61068 .46354 L
.61161 .46355 L
.61254 .46373 L
.61347 .46411 L
.6144 .4647 L
.61533 .46551 L
.61626 .46656 L
.61719 .46784 L
.61812 .46937 L
.61905 .47114 L
.61998 .47317 L
.62091 .47543 L
.62184 .47793 L
.62277 .48067 L
.6237 .48361 L
.62463 .48676 L
.62556 .49009 L
.62649 .49359 L
.62742 .49722 L
.62835 .50097 L
Mistroke
.62928 .50481 L
.63021 .5087 L
.63114 .51261 L
.63207 .51652 L
.633 .52038 L
.63393 .52416 L
.63486 .52783 L
.63579 .53134 L
.63672 .53466 L
.63765 .53775 L
.63858 .54058 L
.63951 .54311 L
.64044 .54531 L
.64137 .54713 L
.6423 .54856 L
.64323 .54957 L
.64416 .55012 L
.64509 .5502 L
.64602 .54978 L
.64695 .54885 L
.64788 .54739 L
.64881 .54539 L
.64974 .54285 L
.65067 .53977 L
.6516 .53614 L
.65253 .53198 L
.65346 .52728 L
.65439 .52207 L
.65532 .51636 L
.65625 .51017 L
.65718 .50353 L
.65811 .49646 L
.65904 .489 L
.65997 .48118 L
.6609 .47304 L
.66183 .46461 L
.66276 .45594 L
.66369 .44708 L
.66462 .43806 L
.66555 .42893 L
.66648 .41975 L
.66741 .41055 L
.66834 .40138 L
.66927 .3923 L
.6702 .38335 L
.67113 .37456 L
.67206 .36599 L
.67299 .35768 L
.67392 .34967 L
.67485 .34198 L
Mistroke
.67578 .33467 L
.67671 .32775 L
.67764 .32125 L
.67857 .3152 L
.6795 .30962 L
.68043 .30452 L
.68136 .29991 L
.68229 .29581 L
.68322 .29222 L
.68415 .28913 L
.68508 .28654 L
.68601 .28444 L
.68694 .28283 L
.68787 .28167 L
.6888 .28096 L
.68973 .28067 L
.69066 .28078 L
.69159 .28124 L
.69252 .28204 L
.69345 .28313 L
.69438 .28448 L
.69531 .28606 L
.69624 .28782 L
.69717 .28972 L
.6981 .29172 L
.69903 .29378 L
.69996 .29587 L
.70089 .29794 L
.70182 .29994 L
.70275 .30186 L
.70368 .30364 L
.70461 .30526 L
.70554 .30668 L
.70647 .30787 L
.7074 .30882 L
.70833 .30949 L
.70926 .30986 L
.71019 .30993 L
.71112 .30967 L
.71205 .30908 L
.71298 .30816 L
.71391 .30689 L
.71484 .30529 L
.71577 .30335 L
.7167 .30109 L
.71763 .29852 L
.71856 .29566 L
.71949 .29252 L
.72042 .28913 L
.72135 .28551 L
Mistroke
.72228 .28168 L
.72321 .27768 L
.72414 .27353 L
.72507 .26928 L
.726 .26494 L
.72693 .26056 L
.72786 .25617 L
.72879 .2518 L
.72972 .2475 L
.73065 .24329 L
.73158 .2392 L
.73251 .23527 L
.73344 .23154 L
.73438 .22802 L
.73531 .22474 L
.73624 .22174 L
.73717 .21903 L
.7381 .21663 L
.73903 .21456 L
.73996 .21284 L
.74089 .21147 L
.74182 .21046 L
.74275 .20982 L
.74368 .20955 L
.74461 .20964 L
.74554 .2101 L
.74647 .21092 L
.7474 .21208 L
.74833 .21358 L
.74926 .2154 L
.75019 .21751 L
.75112 .21991 L
.75205 .22257 L
.75298 .22546 L
.75391 .22857 L
.75484 .23186 L
.75577 .23532 L
.7567 .2389 L
.75763 .24259 L
.75856 .24636 L
.75949 .25018 L
.76042 .25403 L
.76135 .25787 L
.76228 .26168 L
.76321 .26545 L
.76414 .26914 L
.76507 .27275 L
.766 .27624 L
.76693 .2796 L
.76786 .28283 L
Mistroke
.76879 .2859 L
.76972 .28882 L
.77065 .29156 L
.77158 .29413 L
.77251 .29652 L
.77344 .29874 L
.77437 .30079 L
.7753 .30266 L
.77623 .30438 L
.77716 .30594 L
.77809 .30736 L
.77902 .30865 L
.77995 .30982 L
.78088 .31089 L
.78181 .31188 L
.78274 .31281 L
.78367 .31368 L
.7846 .31452 L
.78553 .31535 L
.78646 .31619 L
.78739 .31706 L
.78832 .31796 L
.78925 .31893 L
.79018 .31998 L
.79111 .32111 L
.79204 .32236 L
.79297 .32372 L
.7939 .32521 L
.79483 .32685 L
.79576 .32863 L
.79669 .33057 L
.79762 .33266 L
.79855 .33491 L
.79948 .33733 L
.80041 .33991 L
.80134 .34264 L
.80227 .34552 L
.8032 .34855 L
.80413 .35171 L
.80506 .355 L
.80599 .35841 L
.80692 .36191 L
.80785 .36551 L
.80878 .36919 L
.80971 .37293 L
.81064 .37671 L
.81157 .38052 L
.8125 .38436 L
.81343 .38819 L
.81436 .39201 L
Mistroke
.81529 .3958 L
.81622 .39956 L
.81715 .40326 L
.81808 .4069 L
.81901 .41047 L
.81994 .41395 L
.82087 .41735 L
.8218 .42066 L
.82273 .42387 L
.82366 .42698 L
.82459 .43 L
.82552 .43292 L
.82645 .43575 L
.82738 .43849 L
.82831 .44116 L
.82924 .44375 L
.83017 .44628 L
.8311 .44877 L
.83203 .45121 L
.83296 .45364 L
.83389 .45605 L
.83482 .45848 L
.83575 .46092 L
.83668 .46341 L
.83761 .46594 L
.83854 .46855 L
.83947 .47123 L
.8404 .47402 L
.84133 .47692 L
.84226 .47994 L
.84319 .48309 L
.84412 .48638 L
.84505 .48982 L
.84598 .49341 L
.84691 .49716 L
.84784 .50107 L
.84877 .50513 L
.8497 .50934 L
.85063 .5137 L
.85156 .51819 L
.85249 .52279 L
.85342 .52751 L
.85435 .53231 L
.85528 .53718 L
.85621 .5421 L
.85714 .54704 L
.85807 .55197 L
.859 .55686 L
.85993 .5617 L
.86086 .56643 L
Mistroke
.86179 .57103 L
.86272 .57547 L
.86365 .57971 L
.86458 .58371 L
.86551 .58743 L
.86644 .59085 L
.86737 .59393 L
.8683 .59663 L
.86923 .59891 L
.87016 .60075 L
.87109 .60212 L
.87202 .60298 L
.87295 .60332 L
.87388 .6031 L
.87481 .60231 L
.87574 .60093 L
.87667 .59894 L
.8776 .59634 L
.87853 .59311 L
.87946 .58926 L
.88039 .58477 L
.88132 .57966 L
.88225 .57393 L
.88318 .5676 L
.88411 .56067 L
.88504 .55318 L
.88597 .54513 L
.8869 .53656 L
.88783 .52749 L
.88876 .51796 L
.88969 .50801 L
.89063 .49766 L
.89156 .48697 L
.89249 .47597 L
.89342 .46471 L
.89435 .45324 L
.89528 .44159 L
.89621 .42983 L
.89714 .418 L
.89807 .40614 L
.899 .39432 L
.89993 .38256 L
.90086 .37093 L
.90179 .35946 L
.90272 .34821 L
.90365 .33721 L
.90458 .3265 L
.90551 .31612 L
.90644 .30612 L
.90737 .29651 L
Mistroke
.9083 .28733 L
.90923 .27861 L
.91016 .27037 L
.91109 .26262 L
.91202 .25539 L
.91295 .24868 L
.91388 .2425 L
.91481 .23686 L
.91574 .23176 L
.91667 .2272 L
.9176 .22317 L
.91853 .21966 L
.91946 .21666 L
.92039 .21416 L
.92132 .21213 L
.92225 .21056 L
.92318 .20942 L
.92411 .2087 L
.92504 .20836 L
.92597 .20837 L
.9269 .20872 L
.92783 .20936 L
.92876 .21028 L
.92969 .21143 L
.93062 .21279 L
.93155 .21433 L
.93248 .21602 L
.93341 .21783 L
.93434 .21974 L
.93527 .22171 L
.9362 .22373 L
.93713 .22577 L
.93806 .22781 L
.93899 .22984 L
.93992 .23182 L
.94085 .23376 L
.94178 .23564 L
.94271 .23745 L
.94364 .23917 L
.94457 .24082 L
.9455 .24237 L
.94643 .24384 L
.94736 .24522 L
.94829 .24652 L
.94922 .24773 L
.95015 .24888 L
.95108 .24996 L
.95201 .25099 L
.95294 .25198 L
.95387 .25293 L
Mistroke
.9548 .25386 L
.95573 .25478 L
.95666 .25571 L
.95759 .25666 L
.95852 .25764 L
.95945 .25866 L
.96038 .25973 L
.96131 .26086 L
.96224 .26207 L
.96317 .26336 L
.9641 .26474 L
.96503 .26621 L
.96596 .26777 L
.96689 .26943 L
.96782 .27119 L
.96875 .27304 L
.96968 .27498 L
.97061 .27701 L
.97154 .2791 L
.97247 .28126 L
.9734 .28347 L
.97433 .28572 L
.97526 .28798 L
.97619 .29025 L
Mfstroke
[ .02 ] 0 setdash
.02474 .2824 m
.02567 .28301 L
.0266 .28353 L
.02753 .28395 L
.02846 .28427 L
.02939 .28449 L
.03032 .28462 L
.03125 .28466 L
.03218 .2846 L
.03311 .28446 L
.03404 .28424 L
.03497 .28394 L
.0359 .28357 L
.03683 .28314 L
.03776 .28265 L
.03869 .28212 L
.03962 .28154 L
.04055 .28093 L
.04148 .2803 L
.04241 .27964 L
.04334 .27897 L
.04427 .27828 L
.0452 .27758 L
.04613 .27687 L
.04706 .27613 L
.04799 .27536 L
.04892 .27455 L
.04985 .27368 L
.05078 .27271 L
.05171 .27163 L
.05264 .27038 L
.05357 .26893 L
.0545 .26721 L
.05543 .26515 L
.05636 .26267 L
.05729 .25969 L
.05822 .2561 L
.05915 .25181 L
.06008 .24669 L
.06101 .24064 L
.06194 .23355 L
.06287 .22535 L
.0638 .21598 L
.06473 .20544 L
.06566 .19376 L
.06659 .18106 L
.06752 .1675 L
.06845 .15333 L
.06938 .13882 L
.07031 .12429 L
Mistroke
.07124 .11005 L
.07217 .09642 L
.0731 .08364 L
.07403 .07191 L
.07496 .06137 L
.07589 .0521 L
.07682 .04411 L
.07775 .03736 L
.07868 .03178 L
.07961 .02729 L
.08054 .02377 L
.08147 .02112 L
.0824 .01922 L
.08333 .01799 L
.08426 .01731 L
.08519 .01711 L
.08612 .01732 L
.08705 .01786 L
.08798 .01869 L
.08891 .01975 L
.08984 .02101 L
.09077 .02243 L
.0917 .02398 L
.09263 .02565 L
.09356 .0274 L
.09449 .02923 L
.09542 .03113 L
.09635 .03307 L
.09728 .03505 L
.09821 .03707 L
.09914 .03912 L
.10007 .04119 L
.101 .04327 L
.10193 .04538 L
.10286 .04749 L
.10379 .04961 L
.10472 .05174 L
.10565 .05388 L
.10658 .05602 L
.10751 .05817 L
.10844 .06032 L
.10938 .06247 L
.11031 .06462 L
.11124 .06678 L
.11217 .06893 L
.1131 .07109 L
.11403 .07325 L
.11496 .0754 L
.11589 .07756 L
.11682 .07972 L
Mistroke
.11775 .08188 L
.11868 .08404 L
.11961 .0862 L
.12054 .08835 L
.12147 .09051 L
.1224 .09267 L
.12333 .09483 L
.12426 .09699 L
.12519 .09915 L
.12612 .10131 L
.12705 .10348 L
.12798 .10564 L
.12891 .1078 L
.12984 .10997 L
.13077 .11213 L
.1317 .1143 L
.13263 .11647 L
.13356 .11864 L
.13449 .12081 L
.13542 .12299 L
.13635 .12516 L
.13728 .12734 L
.13821 .12952 L
.13914 .13171 L
.14007 .13389 L
.141 .13608 L
.14193 .13827 L
.14286 .14047 L
.14379 .14266 L
.14472 .14486 L
.14565 .14707 L
.14658 .14927 L
.14751 .15148 L
.14844 .1537 L
.14937 .15591 L
.1503 .15813 L
.15123 .16036 L
.15216 .16259 L
.15309 .16482 L
.15402 .16706 L
.15495 .1693 L
.15588 .17154 L
.15681 .17379 L
.15774 .17605 L
.15867 .1783 L
.1596 .18057 L
.16053 .18283 L
.16146 .1851 L
.16239 .18738 L
.16332 .18966 L
Mistroke
.16425 .19195 L
.16518 .19424 L
.16611 .19653 L
.16704 .19883 L
.16797 .20113 L
.1689 .20344 L
.16983 .20576 L
.17076 .20807 L
.17169 .2104 L
.17262 .21273 L
.17355 .21506 L
.17448 .2174 L
.17541 .21974 L
.17634 .22208 L
.17727 .22444 L
.1782 .22679 L
.17913 .22915 L
.18006 .23152 L
.18099 .23389 L
.18192 .23626 L
.18285 .23864 L
.18378 .24102 L
.18471 .24341 L
.18564 .2458 L
.18657 .2482 L
.1875 .2506 L
.18843 .253 L
.18936 .25541 L
.19029 .25783 L
.19122 .26024 L
.19215 .26266 L
.19308 .26509 L
.19401 .26752 L
.19494 .26995 L
.19587 .27239 L
.1968 .27483 L
.19773 .27727 L
.19866 .27972 L
.19959 .28217 L
.20052 .28463 L
.20145 .28709 L
.20238 .28955 L
.20331 .29202 L
.20424 .29448 L
.20517 .29696 L
.2061 .29943 L
.20703 .30191 L
.20796 .30439 L
.20889 .30688 L
.20982 .30936 L
Mistroke
.21075 .31185 L
.21168 .31435 L
.21261 .31684 L
.21354 .31934 L
.21447 .32184 L
.2154 .32435 L
.21633 .32685 L
.21726 .32936 L
.21819 .33187 L
.21912 .33439 L
.22005 .3369 L
.22098 .33942 L
.22191 .34194 L
.22284 .34446 L
.22377 .34699 L
.2247 .34951 L
.22563 .35204 L
.22656 .35457 L
.22749 .3571 L
.22842 .35964 L
.22935 .36217 L
.23028 .36471 L
.23121 .36724 L
.23214 .36978 L
.23307 .37232 L
.234 .37486 L
.23493 .3774 L
.23586 .37994 L
.23679 .38248 L
.23772 .38502 L
.23865 .38756 L
.23958 .3901 L
.24051 .39264 L
.24144 .39517 L
.24237 .3977 L
.2433 .40023 L
.24423 .40276 L
.24516 .40528 L
.24609 .4078 L
.24702 .41031 L
.24795 .41281 L
.24888 .4153 L
.24981 .41778 L
.25074 .42025 L
.25167 .4227 L
.2526 .42513 L
.25353 .42754 L
.25446 .42993 L
.25539 .43228 L
.25632 .43459 L
Mistroke
.25725 .43687 L
.25818 .43909 L
.25911 .44125 L
.26004 .44335 L
.26097 .44537 L
.2619 .44729 L
.26283 .44911 L
.26376 .4508 L
.26469 .45234 L
.26563 .45372 L
.26656 .4549 L
.26749 .45586 L
.26842 .45656 L
.26935 .45697 L
.27028 .45705 L
.27121 .45676 L
.27214 .45604 L
.27307 .45486 L
.274 .45317 L
.27493 .45092 L
.27586 .44808 L
.27679 .4446 L
.27772 .44046 L
.27865 .43566 L
.27958 .43019 L
.28051 .42409 L
.28144 .4174 L
.28237 .41019 L
.2833 .40256 L
.28423 .39461 L
.28516 .38649 L
.28609 .37831 L
.28702 .37024 L
.28795 .36239 L
.28888 .35489 L
.28981 .34785 L
.29074 .34136 L
.29167 .33548 L
.2926 .33024 L
.29353 .32567 L
.29446 .32176 L
.29539 .3185 L
.29632 .31586 L
.29725 .3138 L
.29818 .31229 L
.29911 .31127 L
.30004 .31069 L
.30097 .31052 L
.3019 .31071 L
.30283 .31121 L
Mistroke
.30376 .31199 L
.30469 .31302 L
.30562 .31425 L
.30655 .31567 L
.30748 .31726 L
.30841 .31897 L
.30934 .32081 L
.31027 .32275 L
.3112 .32478 L
.31213 .32688 L
.31306 .32905 L
.31399 .33127 L
.31492 .33354 L
.31585 .33584 L
.31678 .33819 L
.31771 .34056 L
.31864 .34295 L
.31957 .34536 L
.3205 .34779 L
.32143 .35024 L
.32236 .35269 L
.32329 .35516 L
.32422 .35763 L
.32515 .36011 L
.32608 .36259 L
.32701 .36507 L
.32794 .36755 L
.32887 .37003 L
.3298 .37251 L
.33073 .37498 L
.33166 .37745 L
.33259 .37992 L
.33352 .38237 L
.33445 .38482 L
.33538 .38726 L
.33631 .38968 L
.33724 .39209 L
.33817 .39449 L
.3391 .39687 L
.34003 .39923 L
.34096 .40156 L
.34189 .40387 L
.34282 .40616 L
.34375 .40841 L
.34468 .41063 L
.34561 .41281 L
.34654 .41495 L
.34747 .41704 L
.3484 .41908 L
.34933 .42107 L
Mistroke
.35026 .42298 L
.35119 .42483 L
.35212 .4266 L
.35305 .42828 L
.35398 .42986 L
.35491 .43133 L
.35584 .43268 L
.35677 .43389 L
.3577 .43496 L
.35863 .43586 L
.35956 .43657 L
.36049 .43707 L
.36142 .43735 L
.36235 .43736 L
.36328 .43709 L
.36421 .43649 L
.36514 .43554 L
.36607 .43418 L
.367 .43238 L
.36793 .43008 L
.36886 .42722 L
.36979 .42376 L
.37072 .41963 L
.37165 .41478 L
.37258 .40914 L
.37351 .40267 L
.37444 .39533 L
.37537 .38709 L
.3763 .37795 L
.37723 .36794 L
.37816 .35711 L
.37909 .34556 L
.38002 .33341 L
.38095 .32082 L
.38188 .30798 L
.38281 .29508 L
.38374 .28234 L
.38467 .26995 L
.3856 .2581 L
.38653 .24695 L
.38746 .23661 L
.38839 .22717 L
.38932 .21869 L
.39025 .21116 L
.39118 .20459 L
.39211 .19894 L
.39304 .19416 L
.39397 .19018 L
.3949 .18695 L
.39583 .18438 L
Mistroke
.39676 .18242 L
.39769 .18099 L
.39862 .18004 L
.39955 .1795 L
.40048 .17933 L
.40141 .17948 L
.40234 .17991 L
.40327 .18057 L
.4042 .18144 L
.40513 .1825 L
.40606 .1837 L
.40699 .18505 L
.40792 .1865 L
.40885 .18806 L
.40978 .1897 L
.41071 .19141 L
.41164 .19319 L
.41257 .19502 L
.4135 .1969 L
.41443 .19881 L
.41536 .20076 L
.41629 .20274 L
.41722 .20474 L
.41815 .20677 L
.41908 .2088 L
.42001 .21086 L
.42094 .21292 L
.42188 .215 L
.42281 .21708 L
.42374 .21917 L
.42467 .22126 L
.4256 .22336 L
.42653 .22545 L
.42746 .22755 L
.42839 .22965 L
.42932 .23175 L
.43025 .23384 L
.43118 .23594 L
.43211 .23803 L
.43304 .24011 L
.43397 .24219 L
.4349 .24427 L
.43583 .24634 L
.43676 .24841 L
.43769 .25046 L
.43862 .25251 L
.43955 .25455 L
.44048 .25658 L
.44141 .25861 L
.44234 .26062 L
Mistroke
.44327 .26262 L
.4442 .26461 L
.44513 .26658 L
.44606 .26855 L
.44699 .2705 L
.44792 .27243 L
.44885 .27435 L
.44978 .27625 L
.45071 .27813 L
.45164 .28 L
.45257 .28185 L
.4535 .28367 L
.45443 .28548 L
.45536 .28726 L
.45629 .28902 L
.45722 .29075 L
.45815 .29246 L
.45908 .29414 L
.46001 .2958 L
.46094 .29743 L
.46187 .29903 L
.4628 .30059 L
.46373 .30213 L
.46466 .30364 L
.46559 .30511 L
.46652 .30655 L
.46745 .30795 L
.46838 .30933 L
.46931 .31066 L
.47024 .31196 L
.47117 .31322 L
.4721 .31445 L
.47303 .31565 L
.47396 .3168 L
.47489 .31792 L
.47582 .31901 L
.47675 .32006 L
.47768 .32108 L
.47861 .32207 L
.47954 .32303 L
.48047 .32395 L
.4814 .32485 L
.48233 .32572 L
.48326 .32657 L
.48419 .32739 L
.48512 .3282 L
.48605 .32899 L
.48698 .32976 L
.48791 .33052 L
.48884 .33127 L
Mistroke
.48977 .33202 L
.4907 .33276 L
.49163 .3335 L
.49256 .33424 L
.49349 .33499 L
.49442 .33574 L
.49535 .33651 L
.49628 .33729 L
.49721 .33809 L
.49814 .33891 L
.49907 .33975 L
.5 .34061 L
.50093 .3415 L
.50186 .34242 L
.50279 .34336 L
.50372 .34434 L
.50465 .34536 L
.50558 .3464 L
.50651 .34749 L
.50744 .3486 L
.50837 .34976 L
.5093 .35095 L
.51023 .35218 L
.51116 .35345 L
.51209 .35476 L
.51302 .3561 L
.51395 .35748 L
.51488 .3589 L
.51581 .36035 L
.51674 .36184 L
.51767 .36337 L
.5186 .36492 L
.51953 .36651 L
.52046 .36813 L
.52139 .36978 L
.52232 .37145 L
.52325 .37316 L
.52418 .37489 L
.52511 .37664 L
.52604 .37841 L
.52697 .38021 L
.5279 .38202 L
.52883 .38386 L
.52976 .3857 L
.53069 .38756 L
.53162 .38944 L
.53255 .39132 L
.53348 .39321 L
.53441 .3951 L
.53534 .397 L
Mistroke
.53627 .3989 L
.5372 .4008 L
.53813 .4027 L
.53906 .40459 L
.53999 .40647 L
.54092 .40835 L
.54185 .41021 L
.54278 .41205 L
.54371 .41387 L
.54464 .41568 L
.54557 .41745 L
.5465 .4192 L
.54743 .42092 L
.54836 .42261 L
.54929 .42426 L
.55022 .42586 L
.55115 .42743 L
.55208 .42894 L
.55301 .4304 L
.55394 .43181 L
.55487 .43316 L
.5558 .43445 L
.55673 .43567 L
.55766 .43683 L
.55859 .43791 L
.55952 .43892 L
.56045 .43985 L
.56138 .4407 L
.56231 .44146 L
.56324 .44215 L
.56417 .44275 L
.5651 .44327 L
.56603 .4437 L
.56696 .44405 L
.56789 .44431 L
.56882 .4445 L
.56975 .44461 L
.57068 .44464 L
.57161 .44461 L
.57254 .44451 L
.57347 .44436 L
.5744 .44416 L
.57533 .44392 L
.57626 .44364 L
.57719 .44334 L
.57813 .44302 L
.57906 .44269 L
.57999 .44237 L
.58092 .44206 L
.58185 .44177 L
Mistroke
.58278 .4415 L
.58371 .44128 L
.58464 .44111 L
.58557 .44099 L
.5865 .44093 L
.58743 .44093 L
.58836 .44101 L
.58929 .44117 L
.59022 .44141 L
.59115 .44173 L
.59208 .44214 L
.59301 .44264 L
.59394 .44323 L
.59487 .44391 L
.5958 .44467 L
.59673 .44553 L
.59766 .44647 L
.59859 .4475 L
.59952 .4486 L
.60045 .44979 L
.60138 .45106 L
.60231 .4524 L
.60324 .45382 L
.60417 .4553 L
.6051 .45685 L
.60603 .45846 L
.60696 .46013 L
.60789 .46186 L
.60882 .46364 L
.60975 .46547 L
.61068 .46734 L
.61161 .46927 L
.61254 .47123 L
.61347 .47323 L
.6144 .47527 L
.61533 .47735 L
.61626 .47945 L
.61719 .48159 L
.61812 .48375 L
.61905 .48594 L
.61998 .48816 L
.62091 .49039 L
.62184 .49265 L
.62277 .49493 L
.6237 .49722 L
.62463 .49953 L
.62556 .50185 L
.62649 .50419 L
.62742 .50654 L
.62835 .5089 L
Mistroke
.62928 .51128 L
.63021 .51366 L
.63114 .51604 L
.63207 .51844 L
.633 .52084 L
.63393 .52325 L
.63486 .52566 L
.63579 .52807 L
.63672 .53048 L
.63765 .53289 L
.63858 .5353 L
.63951 .5377 L
.64044 .5401 L
.64137 .54249 L
.6423 .54486 L
.64323 .54722 L
.64416 .54955 L
.64509 .55186 L
.64602 .55413 L
.64695 .55634 L
.64788 .5585 L
.64881 .56058 L
.64974 .56256 L
.65067 .5644 L
.6516 .56608 L
.65253 .56756 L
.65346 .56876 L
.65439 .56962 L
.65532 .57005 L
.65625 .56992 L
.65718 .5691 L
.65811 .56742 L
.65904 .56465 L
.65997 .56055 L
.6609 .55484 L
.66183 .54722 L
.66276 .53739 L
.66369 .52506 L
.66462 .51005 L
.66555 .49229 L
.66648 .47189 L
.66741 .44923 L
.66834 .42488 L
.66927 .39965 L
.6702 .37443 L
.67113 .35013 L
.67206 .32755 L
.67299 .30725 L
.67392 .28959 L
.67485 .27469 L
Mistroke
.67578 .26246 L
.67671 .25271 L
.67764 .24517 L
.67857 .23952 L
.6795 .23546 L
.68043 .23271 L
.68136 .23104 L
.68229 .23022 L
.68322 .23009 L
.68415 .23049 L
.68508 .23132 L
.68601 .23248 L
.68694 .2339 L
.68787 .23552 L
.6888 .2373 L
.68973 .23919 L
.69066 .24116 L
.69159 .24321 L
.69252 .2453 L
.69345 .24741 L
.69438 .24955 L
.69531 .2517 L
.69624 .25384 L
.69717 .25598 L
.6981 .2581 L
.69903 .26019 L
.69996 .26226 L
.70089 .26429 L
.70182 .26628 L
.70275 .26822 L
.70368 .2701 L
.70461 .27192 L
.70554 .27367 L
.70647 .27534 L
.7074 .27693 L
.70833 .27842 L
.70926 .2798 L
.71019 .28107 L
.71112 .28222 L
.71205 .28323 L
.71298 .2841 L
.71391 .28482 L
.71484 .28537 L
.71577 .28574 L
.7167 .28593 L
.71763 .28592 L
.71856 .28571 L
.71949 .2853 L
.72042 .28467 L
.72135 .28383 L
Mistroke
.72228 .28277 L
.72321 .2815 L
.72414 .28003 L
.72507 .27837 L
.726 .27652 L
.72693 .27451 L
.72786 .27236 L
.72879 .27008 L
.72972 .26771 L
.73065 .26527 L
.73158 .26279 L
.73251 .26031 L
.73344 .25786 L
.73438 .25546 L
.73531 .25314 L
.73624 .25094 L
.73717 .24887 L
.7381 .24697 L
.73903 .24523 L
.73996 .2437 L
.74089 .24236 L
.74182 .24123 L
.74275 .24032 L
.74368 .23963 L
.74461 .23915 L
.74554 .23888 L
.74647 .23883 L
.7474 .23897 L
.74833 .2393 L
.74926 .23982 L
.75019 .24051 L
.75112 .24136 L
.75205 .24237 L
.75298 .24352 L
.75391 .2448 L
.75484 .2462 L
.75577 .24772 L
.7567 .24933 L
.75763 .25105 L
.75856 .25285 L
.75949 .25473 L
.76042 .25668 L
.76135 .2587 L
.76228 .26078 L
.76321 .26292 L
.76414 .2651 L
.76507 .26733 L
.766 .2696 L
.76693 .2719 L
.76786 .27424 L
Mistroke
.76879 .27661 L
.76972 .279 L
.77065 .28142 L
.77158 .28387 L
.77251 .28633 L
.77344 .28881 L
.77437 .2913 L
.7753 .29382 L
.77623 .29634 L
.77716 .29887 L
.77809 .30142 L
.77902 .30398 L
.77995 .30654 L
.78088 .30911 L
.78181 .31169 L
.78274 .31428 L
.78367 .31687 L
.7846 .31946 L
.78553 .32206 L
.78646 .32467 L
.78739 .32728 L
.78832 .32989 L
.78925 .3325 L
.79018 .33512 L
.79111 .33774 L
.79204 .34036 L
.79297 .34298 L
.7939 .34561 L
.79483 .34823 L
.79576 .35086 L
.79669 .35349 L
.79762 .35611 L
.79855 .35874 L
.79948 .36137 L
.80041 .364 L
.80134 .36663 L
.80227 .36926 L
.8032 .37189 L
.80413 .37452 L
.80506 .37715 L
.80599 .37978 L
.80692 .38241 L
.80785 .38504 L
.80878 .38767 L
.80971 .39029 L
.81064 .39292 L
.81157 .39555 L
.8125 .39817 L
.81343 .4008 L
.81436 .40342 L
Mistroke
.81529 .40604 L
.81622 .40866 L
.81715 .41128 L
.81808 .4139 L
.81901 .41652 L
.81994 .41914 L
.82087 .42175 L
.8218 .42437 L
.82273 .42698 L
.82366 .42959 L
.82459 .4322 L
.82552 .43481 L
.82645 .43741 L
.82738 .44002 L
.82831 .44262 L
.82924 .44522 L
.83017 .44782 L
.8311 .45042 L
.83203 .45301 L
.83296 .45561 L
.83389 .4582 L
.83482 .46079 L
.83575 .46337 L
.83668 .46596 L
.83761 .46854 L
.83854 .47112 L
.83947 .4737 L
.8404 .47627 L
.84133 .47885 L
.84226 .48142 L
.84319 .48398 L
.84412 .48655 L
.84505 .48911 L
.84598 .49167 L
.84691 .49422 L
.84784 .49678 L
.84877 .49933 L
.8497 .50188 L
.85063 .50442 L
.85156 .50696 L
.85249 .5095 L
.85342 .51203 L
.85435 .51457 L
.85528 .51709 L
.85621 .51962 L
.85714 .52214 L
.85807 .52465 L
.859 .52717 L
.85993 .52968 L
.86086 .53218 L
Mistroke
.86179 .53468 L
.86272 .53718 L
.86365 .53967 L
.86458 .54215 L
.86551 .54463 L
.86644 .5471 L
.86737 .54957 L
.8683 .55202 L
.86923 .55447 L
.87016 .55691 L
.87109 .55933 L
.87202 .56173 L
.87295 .56412 L
.87388 .56648 L
.87481 .56882 L
.87574 .57112 L
.87667 .57337 L
.8776 .57556 L
.87853 .57769 L
.87946 .57972 L
.88039 .58164 L
.88132 .58341 L
.88225 .585 L
.88318 .58635 L
.88411 .58739 L
.88504 .58806 L
.88597 .58825 L
.8869 .58783 L
.88783 .58665 L
.88876 .58451 L
.88969 .58121 L
.89063 .57647 L
.89156 .57002 L
.89249 .56154 L
.89342 .55074 L
.89435 .53735 L
.89528 .52122 L
.89621 .50233 L
.89714 .48084 L
.89807 .45716 L
.899 .43194 L
.89993 .40598 L
.90086 .38017 L
.90179 .35537 L
.90272 .3323 L
.90365 .31148 L
.90458 .29317 L
.90551 .27745 L
.90644 .26421 L
.90737 .25324 L
Mistroke
.9083 .24426 L
.90923 .23697 L
.91016 .23109 L
.91109 .22636 L
.91202 .22257 L
.91295 .21951 L
.91388 .21705 L
.91481 .21505 L
.91574 .21343 L
.91667 .2121 L
.9176 .21101 L
.91853 .21011 L
.91946 .20939 L
.92039 .20881 L
.92132 .20836 L
.92225 .20803 L
.92318 .20781 L
.92411 .2077 L
.92504 .20769 L
.92597 .20777 L
.9269 .20796 L
.92783 .20825 L
.92876 .20863 L
.92969 .20911 L
.93062 .20968 L
.93155 .21035 L
.93248 .2111 L
.93341 .21194 L
.93434 .21287 L
.93527 .21388 L
.9362 .21497 L
.93713 .21613 L
.93806 .21737 L
.93899 .21867 L
.93992 .22004 L
.94085 .22147 L
.94178 .22295 L
.94271 .22449 L
.94364 .22608 L
.94457 .22771 L
.9455 .22938 L
.94643 .23108 L
.94736 .23282 L
.94829 .23459 L
.94922 .23638 L
.95015 .23819 L
.95108 .24002 L
.95201 .24187 L
.95294 .24372 L
.95387 .24558 L
Mistroke
.9548 .24744 L
.95573 .2493 L
.95666 .25115 L
.95759 .25299 L
.95852 .25483 L
.95945 .25664 L
.96038 .25843 L
.96131 .2602 L
.96224 .26194 L
.96317 .26365 L
.9641 .26532 L
.96503 .26695 L
.96596 .26853 L
.96689 .27006 L
.96782 .27154 L
.96875 .27296 L
.96968 .27432 L
.97061 .27561 L
.97154 .27682 L
.97247 .27797 L
.9734 .27903 L
.97433 .28 L
.97526 .28089 L
.97619 .28169 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "Again, the relative root mean square error can be calculated according to \
",
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            UnderoverscriptBox["\[Sum]", \(k = 1\), "N",
              LimitsPositioning->True], 
            \(\[LeftBracketingBar]\(c\&~\)\_k - c\_k\[RightBracketingBar]\^2
                \), "/", 
            UnderoverscriptBox["\[Sum]", \(k = 1\), "N",
              LimitsPositioning->True], \(c\_k\%2\)}]], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`{c\_k}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the original data and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(c\&~\)\_k}\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the reconstructed one. Since an orthogonal wavelet transform with \
periodic boundary conditions preserves the \"norm of the data\" ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          UnderoverscriptBox["\[Sum]", \(k = 1\), "N",
            LimitsPositioning->True], \(c\_k\%2\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S2.1.1"],
  ", we can also calculate the error before doing inverse transforms. It can \
be easily shown that the relative error due to compression with a ratio ",
  Cell[BoxData[
      \(TraditionalForm\`N/M\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1 - \(E\&~\) \((M)\)\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(E\&~\)\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " is the normalized cumulative energy. Often it is desirable to know how \
the errors change with the compression ratio and we would like to achieve \
maximum compression for a given allowed error."
}], "Text",
  CellTags->{"S2.1.1", "1.60"}],

Cell["\<\
This is the curve showing the relative error as a function of the \
compression ratio in the case of the spline wavelet basis.\
\>", "MathCaption",\

  CellTags->{"S2.1.1", "1.61"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Transpose[{Table[1024/i, {i, 1, 1024}],
Sqrt[Chop[1-e]]}], PlotJoined -> True,
PlotRange -> {{0, 150}, {0, 0.5}},
PlotLabel -> \"relative error vs. compression ratio\"]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.20924e-17 0.00666667 0 1.23607 [
[.13333 -0.0125 -6 -9 ]
[.13333 -0.0125 6 0 ]
[.26667 -0.0125 -6 -9 ]
[.26667 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.53333 -0.0125 -6 -9 ]
[.53333 -0.0125 6 0 ]
[.66667 -0.0125 -9 -9 ]
[.66667 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[.93333 -0.0125 -9 -9 ]
[.93333 -0.0125 9 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -108 0 ]
[.5 .63053 108 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13333 0 m
.13333 .00625 L
s
[(20)] .13333 -0.0125 0 1 Mshowa
.26667 0 m
.26667 .00625 L
s
[(40)] .26667 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.53333 0 m
.53333 .00625 L
s
[(80)] .53333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(100)] .66667 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(120)] .8 -0.0125 0 1 Mshowa
.93333 0 m
.93333 .00625 L
s
[(140)] .93333 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.3 0 m
.3 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.5 0 m
.5 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(relative error vs. compression ratio)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1 .54408 m
.97524 .53705 L
.85333 .48663 L
.75852 .45257 L
.68267 .41791 L
.62061 .38186 L
.56889 .3488 L
.52513 .32037 L
.48762 .29572 L
.45511 .26921 L
.42667 .25214 L
.40157 .23582 L
.37926 .2196 L
.3593 .20394 L
.34133 .18806 L
.32508 .17713 L
.3103 .16646 L
.29681 .15634 L
.28444 .14742 L
.27307 .13914 L
.26256 .13044 L
.25284 .12332 L
.24381 .11611 L
.2354 .10904 L
.22756 .10238 L
.22022 .0958 L
.21333 .08939 L
.20687 .08376 L
.20078 .07871 L
.19505 .07434 L
.18963 .07036 L
.1845 .06694 L
.17965 .06358 L
.17504 .06007 L
.17067 .05794 L
.1665 .05587 L
.16254 .05374 L
.15876 .05156 L
.15515 .04935 L
.1517 .04712 L
.14841 .04499 L
.14525 .0428 L
.14222 .04061 L
.13932 .03833 L
.13653 .0363 L
.13386 .03422 L
.13128 .03286 L
.12881 .03148 L
.12642 .03012 L
.12412 .02901 L
Mistroke
.1219 .02789 L
.11977 .0269 L
.1177 .02597 L
.11571 .02502 L
.11378 .02413 L
.11191 .02328 L
.11011 .02243 L
.10836 .0217 L
.10667 .02105 L
.10503 .02045 L
.10343 .01987 L
.10189 .01928 L
.10039 .01868 L
.09894 .0181 L
.09752 .01753 L
.09615 .01704 L
.09481 .01655 L
.09352 .01606 L
.09225 .01556 L
.09102 .01509 L
.08982 .01461 L
.08866 .01426 L
.08752 .01394 L
.08641 .01364 L
.08533 .01338 L
.08428 .01315 L
.08325 .01299 L
.08225 .01283 L
.08127 .01267 L
.08031 .01252 L
.07938 .01237 L
.07847 .01222 L
.07758 .01207 L
.0767 .01193 L
.07585 .01181 L
.07502 .0117 L
.0742 .01159 L
.07341 .01149 L
.07262 .01139 L
.07186 .01132 L
.07111 .01125 L
.07038 .01118 L
.06966 .01112 L
.06896 .01106 L
.06827 .011 L
.06759 .01095 L
.06693 .01089 L
.06628 .01085 L
.06564 .0108 L
.06502 .01075 L
Mistroke
.0644 .01071 L
.0638 .01066 L
.06321 .01062 L
.06263 .01057 L
.06206 .01053 L
.0615 .01049 L
.06095 .01044 L
.06041 .0104 L
.05988 .01036 L
.05936 .01032 L
.05885 .01028 L
.05835 .01024 L
.05785 .0102 L
.05737 .01017 L
.05689 .01013 L
.05642 .01009 L
.05596 .01006 L
.0555 .01002 L
.05505 .00998 L
.05461 .00995 L
.05418 .00991 L
.05375 .00988 L
.05333 .00984 L
.05292 .00981 L
.05251 .00978 L
.05211 .00974 L
.05172 .00971 L
.05133 .00968 L
.05095 .00965 L
.05057 .00961 L
.0502 .00958 L
.04983 .00955 L
.04947 .00952 L
.04911 .0095 L
.04876 .00947 L
.04842 .00944 L
.04808 .00941 L
.04774 .00938 L
.04741 .00935 L
.04708 .00932 L
.04676 .00929 L
.04644 .00926 L
.04613 .00923 L
.04582 .0092 L
.04551 .00917 L
.04521 .00915 L
.04491 .00912 L
.04462 .00909 L
.04433 .00906 L
.04404 .00903 L
Mistroke
.04376 .009 L
.04348 .00898 L
.04321 .00895 L
.04294 .00892 L
.04267 .00889 L
.0424 .00887 L
.04214 .00884 L
.04188 .00881 L
.04163 .00878 L
.04137 .00876 L
.04112 .00873 L
.04088 .0087 L
.04063 .00868 L
.04039 .00865 L
.04016 .00863 L
.03992 .0086 L
.03969 .00857 L
.03946 .00855 L
.03923 .00852 L
.03901 .00849 L
.03879 .00847 L
.03857 .00844 L
.03835 .00842 L
.03814 .00839 L
.03793 .00837 L
.03772 .00834 L
.03751 .00832 L
.0373 .00829 L
.0371 .00827 L
.0369 .00824 L
.0367 .00821 L
.03651 .00819 L
.03631 .00816 L
.03612 .00814 L
.03593 .00811 L
.03574 .00809 L
.03556 .00806 L
.03537 .00804 L
.03519 .00802 L
.03501 .00799 L
.03483 .00797 L
.03465 .00794 L
.03448 .00792 L
.0343 .00789 L
.03413 .00787 L
.03396 .00785 L
.0338 .00783 L
.03363 .0078 L
.03346 .00778 L
.0333 .00776 L
Mistroke
.03314 .00773 L
.03298 .00771 L
.03282 .00769 L
.03266 .00767 L
.03251 .00765 L
.03235 .00762 L
.0322 .0076 L
.03205 .00758 L
.0319 .00756 L
.03175 .00754 L
.0316 .00752 L
.03146 .0075 L
.03131 .00748 L
.03117 .00746 L
.03103 .00744 L
.03089 .00742 L
.03075 .0074 L
.03061 .00738 L
.03048 .00736 L
.03034 .00734 L
.03021 .00732 L
.03007 .0073 L
.02994 .00728 L
.02981 .00726 L
.02968 .00724 L
.02955 .00722 L
.02943 .0072 L
.0293 .00718 L
.02917 .00716 L
.02905 .00714 L
.02893 .00712 L
.0288 .0071 L
.02868 .00708 L
.02856 .00706 L
.02844 .00704 L
.02833 .00702 L
.02821 .00701 L
.02809 .00699 L
.02798 .00697 L
.02786 .00695 L
.02775 .00693 L
.02764 .00691 L
.02753 .00689 L
.02742 .00687 L
.02731 .00685 L
.0272 .00684 L
.02709 .00682 L
.02698 .0068 L
.02688 .00678 L
.02677 .00676 L
Mistroke
.02667 .00674 L
.02656 .00672 L
.02646 .00671 L
.02636 .00669 L
.02626 .00667 L
.02616 .00665 L
.02606 .00663 L
.02596 .00662 L
.02586 .0066 L
.02576 .00658 L
.02566 .00656 L
.02557 .00654 L
.02547 .00653 L
.02538 .00651 L
.02528 .00649 L
.02519 .00647 L
.0251 .00646 L
.02501 .00644 L
.02491 .00642 L
.02482 .0064 L
.02473 .00639 L
.02465 .00637 L
.02456 .00635 L
.02447 .00633 L
.02438 .00632 L
.02429 .0063 L
.02421 .00628 L
.02412 .00627 L
.02404 .00625 L
.02395 .00623 L
.02387 .00622 L
.02379 .0062 L
.0237 .00618 L
.02362 .00617 L
.02354 .00615 L
.02346 .00613 L
.02338 .00612 L
.0233 .0061 L
.02322 .00608 L
.02314 .00607 L
.02306 .00605 L
.02299 .00604 L
.02291 .00602 L
.02283 .006 L
.02276 .00599 L
.02268 .00597 L
.0226 .00596 L
.02253 .00594 L
.02246 .00592 L
.02238 .00591 L
Mistroke
.02231 .00589 L
.02224 .00588 L
.02216 .00586 L
.02209 .00585 L
.02202 .00583 L
.02195 .00582 L
.02188 .0058 L
.02181 .00579 L
.02174 .00577 L
.02167 .00576 L
.0216 .00574 L
.02154 .00573 L
.02147 .00571 L
.0214 .0057 L
.02133 .00568 L
.02127 .00567 L
.0212 .00565 L
.02114 .00564 L
.02107 .00562 L
.02101 .00561 L
.02094 .00559 L
.02088 .00558 L
.02081 .00556 L
.02075 .00555 L
.02069 .00554 L
.02062 .00552 L
.02056 .00551 L
.0205 .00549 L
.02044 .00548 L
.02038 .00547 L
.02032 .00545 L
.02026 .00544 L
.0202 .00542 L
.02014 .00541 L
.02008 .0054 L
.02002 .00538 L
.01996 .00537 L
.0199 .00536 L
.01984 .00534 L
.01979 .00533 L
.01973 .00532 L
.01967 .0053 L
.01962 .00529 L
.01956 .00528 L
.0195 .00526 L
.01945 .00525 L
.01939 .00524 L
.01934 .00523 L
.01928 .00521 L
.01923 .0052 L
Mistroke
.01918 .00519 L
.01912 .00517 L
.01907 .00516 L
.01902 .00515 L
.01896 .00514 L
.01891 .00512 L
.01886 .00511 L
.01881 .0051 L
.01875 .00509 L
.0187 .00507 L
.01865 .00506 L
.0186 .00505 L
.01855 .00504 L
.0185 .00502 L
.01845 .00501 L
.0184 .005 L
.01835 .00499 L
.0183 .00497 L
.01825 .00496 L
.0182 .00495 L
.01816 .00494 L
.01811 .00493 L
.01806 .00491 L
.01801 .0049 L
.01796 .00489 L
.01792 .00488 L
.01787 .00486 L
.01782 .00485 L
.01778 .00484 L
.01773 .00483 L
.01769 .00482 L
.01764 .0048 L
.01759 .00479 L
.01755 .00478 L
.0175 .00477 L
.01746 .00476 L
.01741 .00475 L
.01737 .00473 L
.01733 .00472 L
.01728 .00471 L
.01724 .0047 L
.0172 .00469 L
.01715 .00468 L
.01711 .00466 L
.01707 .00465 L
.01702 .00464 L
.01698 .00463 L
.01694 .00462 L
.0169 .00461 L
.01686 .0046 L
Mistroke
.01681 .00459 L
.01677 .00457 L
.01673 .00456 L
.01669 .00455 L
.01665 .00454 L
.01661 .00453 L
.01657 .00452 L
.01653 .00451 L
.01649 .0045 L
.01645 .00449 L
.01641 .00448 L
.01637 .00447 L
.01633 .00445 L
.01629 .00444 L
.01625 .00443 L
.01622 .00442 L
.01618 .00441 L
.01614 .0044 L
.0161 .00439 L
.01606 .00438 L
.01603 .00437 L
.01599 .00436 L
.01595 .00435 L
.01591 .00434 L
.01588 .00433 L
.01584 .00432 L
.0158 .00431 L
.01577 .0043 L
.01573 .00429 L
.01569 .00428 L
.01566 .00427 L
.01562 .00425 L
.01559 .00424 L
.01555 .00423 L
.01552 .00422 L
.01548 .00421 L
.01544 .0042 L
.01541 .00419 L
.01538 .00418 L
.01534 .00417 L
.01531 .00416 L
.01527 .00415 L
.01524 .00414 L
.0152 .00413 L
.01517 .00412 L
.01514 .00411 L
.0151 .0041 L
.01507 .00409 L
.01504 .00408 L
.015 .00407 L
Mistroke
.01497 .00406 L
.01494 .00405 L
.01491 .00404 L
.01487 .00403 L
.01484 .00402 L
.01481 .00401 L
.01478 .004 L
.01474 .00399 L
.01471 .00398 L
.01468 .00397 L
.01465 .00396 L
.01462 .00395 L
.01459 .00394 L
.01456 .00393 L
.01452 .00392 L
.01449 .00391 L
.01446 .0039 L
.01443 .00389 L
.0144 .00388 L
.01437 .00387 L
.01434 .00386 L
.01431 .00385 L
.01428 .00384 L
.01425 .00383 L
.01422 .00382 L
.01419 .00382 L
.01416 .00381 L
.01413 .0038 L
.0141 .00379 L
.01408 .00378 L
.01405 .00377 L
.01402 .00376 L
.01399 .00375 L
.01396 .00374 L
.01393 .00373 L
.0139 .00372 L
.01388 .00371 L
.01385 .0037 L
.01382 .00369 L
.01379 .00368 L
.01376 .00367 L
.01374 .00366 L
.01371 .00366 L
.01368 .00365 L
.01365 .00364 L
.01363 .00363 L
.0136 .00362 L
.01357 .00361 L
.01354 .0036 L
.01352 .00359 L
Mistroke
.01349 .00358 L
.01346 .00357 L
.01344 .00356 L
.01341 .00355 L
.01339 .00354 L
.01336 .00354 L
.01333 .00353 L
.01331 .00352 L
.01328 .00351 L
.01326 .0035 L
.01323 .00349 L
.0132 .00348 L
.01318 .00347 L
.01315 .00346 L
.01313 .00345 L
.0131 .00344 L
.01308 .00343 L
.01305 .00343 L
.01303 .00342 L
.013 .00341 L
.01298 .0034 L
.01295 .00339 L
.01293 .00338 L
.0129 .00337 L
.01288 .00336 L
.01286 .00335 L
.01283 .00334 L
.01281 .00333 L
.01278 .00332 L
.01276 .00332 L
.01274 .00331 L
.01271 .0033 L
.01269 .00329 L
.01267 .00328 L
.01264 .00327 L
.01262 .00326 L
.0126 .00325 L
.01257 .00324 L
.01255 .00323 L
.01253 .00322 L
.0125 .00322 L
.01248 .00321 L
.01246 .0032 L
.01243 .00319 L
.01241 .00318 L
.01239 .00317 L
.01237 .00316 L
.01234 .00315 L
.01232 .00314 L
.0123 .00313 L
Mistroke
.01228 .00313 L
.01226 .00312 L
.01223 .00311 L
.01221 .0031 L
.01219 .00309 L
.01217 .00308 L
.01215 .00307 L
.01213 .00306 L
.0121 .00305 L
.01208 .00305 L
.01206 .00304 L
.01204 .00303 L
.01202 .00302 L
.012 .00301 L
.01198 .003 L
.01196 .00299 L
.01193 .00298 L
.01191 .00298 L
.01189 .00297 L
.01187 .00296 L
.01185 .00295 L
.01183 .00294 L
.01181 .00293 L
.01179 .00292 L
.01177 .00292 L
.01175 .00291 L
.01173 .0029 L
.01171 .00289 L
.01169 .00288 L
.01167 .00287 L
.01165 .00286 L
.01163 .00285 L
.01161 .00285 L
.01159 .00284 L
.01157 .00283 L
.01155 .00282 L
.01153 .00281 L
.01151 .0028 L
.01149 .0028 L
.01147 .00279 L
.01145 .00278 L
.01143 .00277 L
.01142 .00276 L
.0114 .00275 L
.01138 .00274 L
.01136 .00274 L
.01134 .00273 L
.01132 .00272 L
.0113 .00271 L
.01128 .0027 L
Mistroke
.01127 .00269 L
.01125 .00268 L
.01123 .00268 L
.01121 .00267 L
.01119 .00266 L
.01117 .00265 L
.01115 .00264 L
.01114 .00263 L
.01112 .00263 L
.0111 .00262 L
.01108 .00261 L
.01106 .0026 L
.01105 .00259 L
.01103 .00258 L
.01101 .00258 L
.01099 .00257 L
.01098 .00256 L
.01096 .00255 L
.01094 .00254 L
.01092 .00253 L
.01091 .00252 L
.01089 .00252 L
.01087 .00251 L
.01085 .0025 L
.01084 .00249 L
.01082 .00248 L
.0108 .00247 L
.01078 .00247 L
.01077 .00246 L
.01075 .00245 L
.01073 .00244 L
.01072 .00243 L
.0107 .00242 L
.01068 .00241 L
.01067 .00241 L
.01065 .0024 L
.01063 .00239 L
.01062 .00238 L
.0106 .00237 L
.01058 .00237 L
.01057 .00236 L
.01055 .00235 L
.01053 .00234 L
.01052 .00233 L
.0105 .00232 L
.01049 .00232 L
.01047 .00231 L
.01045 .0023 L
.01044 .00229 L
.01042 .00228 L
Mistroke
.01041 .00227 L
.01039 .00227 L
.01037 .00226 L
.01036 .00225 L
.01034 .00224 L
.01033 .00223 L
.01031 .00222 L
.0103 .00222 L
.01028 .00221 L
.01027 .0022 L
.01025 .00219 L
.01023 .00218 L
.01022 .00217 L
.0102 .00217 L
.01019 .00216 L
.01017 .00215 L
.01016 .00214 L
.01014 .00213 L
.01013 .00213 L
.01011 .00212 L
.0101 .00211 L
.01008 .0021 L
.01007 .00209 L
.01005 .00209 L
.01004 .00208 L
.01002 .00207 L
.01001 .00206 L
.01 .00205 L
.00998 .00205 L
.00997 .00204 L
.00995 .00203 L
.00994 .00202 L
.00992 .00201 L
.00991 .00201 L
.00989 .002 L
.00988 .00199 L
.00987 .00198 L
.00985 .00197 L
.00984 .00197 L
.00982 .00196 L
.00981 .00195 L
.00979 .00194 L
.00978 .00193 L
.00977 .00193 L
.00975 .00192 L
.00974 .00191 L
.00972 .0019 L
.00971 .00189 L
.0097 .00189 L
.00968 .00188 L
Mistroke
.00967 .00187 L
.00966 .00186 L
.00964 .00185 L
.00963 .00185 L
.00962 .00184 L
.0096 .00183 L
.00959 .00182 L
.00957 .00182 L
.00956 .00181 L
.00955 .0018 L
.00953 .00179 L
.00952 .00178 L
.00951 .00178 L
.00949 .00177 L
.00948 .00176 L
.00947 .00175 L
.00946 .00175 L
.00944 .00174 L
.00943 .00173 L
.00942 .00172 L
.0094 .00171 L
.00939 .00171 L
.00938 .0017 L
.00936 .00169 L
.00935 .00168 L
.00934 .00167 L
.00933 .00167 L
.00931 .00166 L
.0093 .00165 L
.00929 .00164 L
.00928 .00163 L
.00926 .00163 L
.00925 .00162 L
.00924 .00161 L
.00923 .0016 L
.00921 .0016 L
.0092 .00159 L
.00919 .00158 L
.00918 .00157 L
.00916 .00156 L
.00915 .00156 L
.00914 .00155 L
.00913 .00154 L
.00911 .00153 L
.0091 .00152 L
.00909 .00152 L
.00908 .00151 L
.00907 .0015 L
.00905 .00149 L
.00904 .00149 L
Mistroke
.00903 .00148 L
.00902 .00147 L
.00901 .00146 L
.00899 .00145 L
.00898 .00145 L
.00897 .00144 L
.00896 .00143 L
.00895 .00142 L
.00894 .00141 L
.00892 .00141 L
.00891 .0014 L
.0089 .00139 L
.00889 .00138 L
.00888 .00137 L
.00887 .00137 L
.00885 .00136 L
.00884 .00135 L
.00883 .00134 L
.00882 .00134 L
.00881 .00133 L
.0088 .00132 L
.00879 .00131 L
.00877 .0013 L
.00876 .0013 L
.00875 .00129 L
.00874 .00128 L
.00873 .00127 L
.00872 .00126 L
.00871 .00126 L
.0087 .00125 L
.00869 .00124 L
.00867 .00123 L
.00866 .00122 L
.00865 .00121 L
.00864 .00121 L
.00863 .0012 L
.00862 .00119 L
.00861 .00118 L
.0086 .00117 L
.00859 .00117 L
.00858 .00116 L
.00857 .00115 L
.00855 .00114 L
.00854 .00114 L
.00853 .00113 L
.00852 .00112 L
.00851 .00111 L
.0085 .0011 L
.00849 .0011 L
.00848 .00109 L
Mistroke
.00847 .00108 L
.00846 .00107 L
.00845 .00107 L
.00844 .00106 L
.00843 .00105 L
.00842 .00104 L
.00841 .00104 L
.0084 .00103 L
.00839 .00102 L
.00838 .00101 L
.00837 .00101 L
.00836 .001 L
.00835 .00099 L
.00834 .00098 L
.00833 .00098 L
.00832 .00097 L
.0083 .00096 L
.00829 .00095 L
.00828 .00095 L
.00827 .00094 L
.00826 .00093 L
.00825 .00092 L
.00824 .00092 L
.00823 .00091 L
.00822 .0009 L
.00822 .0009 L
.00821 .00089 L
.0082 .00088 L
.00819 .00087 L
.00818 .00087 L
.00817 .00086 L
.00816 .00085 L
.00815 .00085 L
.00814 .00084 L
.00813 .00083 L
.00812 .00082 L
.00811 .00082 L
.0081 .00081 L
.00809 .0008 L
.00808 .0008 L
.00807 .00079 L
.00806 .00078 L
.00805 .00077 L
.00804 .00077 L
.00803 .00076 L
.00802 .00075 L
.00801 .00075 L
.008 .00074 L
.00799 .00073 L
.00798 .00073 L
Mistroke
.00798 .00072 L
.00797 .00071 L
.00796 .00071 L
.00795 .0007 L
.00794 .00069 L
.00793 .00069 L
.00792 .00068 L
.00791 .00067 L
.0079 .00067 L
.00789 .00066 L
.00788 .00065 L
.00787 .00065 L
.00786 .00064 L
.00786 .00064 L
.00785 .00063 L
.00784 .00062 L
.00783 .00062 L
.00782 .00061 L
.00781 .0006 L
.0078 .0006 L
.00779 .00059 L
.00778 .00059 L
.00778 .00058 L
.00777 .00057 L
.00776 .00057 L
.00775 .00056 L
.00774 .00055 L
.00773 .00055 L
.00772 .00054 L
.00771 .00053 L
.00771 .00053 L
.0077 .00052 L
.00769 .00052 L
.00768 .00051 L
.00767 .0005 L
.00766 .0005 L
.00765 .00049 L
.00764 .00049 L
.00764 .00048 L
.00763 .00048 L
.00762 .00047 L
.00761 .00046 L
.0076 .00046 L
.00759 .00045 L
.00759 .00045 L
.00758 .00044 L
.00757 .00044 L
.00756 .00043 L
.00755 .00042 L
.00754 .00042 L
Mistroke
.00753 .00041 L
.00753 .00041 L
.00752 .0004 L
.00751 .00039 L
.0075 .00039 L
.00749 .00038 L
.00749 .00038 L
.00748 .00037 L
.00747 .00037 L
.00746 .00036 L
.00745 .00036 L
.00744 .00035 L
.00744 .00035 L
.00743 .00034 L
.00742 .00034 L
.00741 .00033 L
.0074 .00033 L
.0074 .00032 L
.00739 .00032 L
.00738 .00031 L
.00737 .00031 L
.00736 .0003 L
.00736 .0003 L
.00735 .00029 L
.00734 .00029 L
.00733 .00028 L
.00732 .00028 L
.00732 .00027 L
.00731 .00027 L
.0073 .00026 L
.00729 .00026 L
.00729 .00025 L
.00728 .00025 L
.00727 .00024 L
.00726 .00024 L
.00725 .00023 L
.00725 .00023 L
.00724 .00022 L
.00723 .00022 L
.00722 .00022 L
.00722 .00021 L
.00721 .00021 L
.0072 .0002 L
.00719 .0002 L
.00719 .00019 L
.00718 .00019 L
.00717 .00019 L
.00716 .00018 L
.00716 .00018 L
.00715 .00017 L
Mistroke
.00714 .00017 L
.00713 .00017 L
.00713 .00016 L
.00712 .00016 L
.00711 .00016 L
.0071 .00015 L
.0071 .00015 L
.00709 .00014 L
.00708 .00014 L
.00707 .00014 L
.00707 .00013 L
.00706 .00013 L
.00705 .00013 L
.00705 .00012 L
.00704 .00012 L
.00703 .00012 L
.00702 .00011 L
.00702 .00011 L
.00701 .00011 L
.007 .0001 L
.00699 .0001 L
.00699 .0001 L
.00698 .0001 L
.00697 9e-05 L
.00697 9e-05 L
.00696 9e-05 L
.00695 8e-05 L
.00694 8e-05 L
.00694 8e-05 L
.00693 7e-05 L
.00692 7e-05 L
.00692 7e-05 L
.00691 7e-05 L
.0069 6e-05 L
.0069 6e-05 L
.00689 6e-05 L
.00688 5e-05 L
.00687 5e-05 L
.00687 5e-05 L
.00686 5e-05 L
.00685 4e-05 L
.00685 4e-05 L
.00684 4e-05 L
.00683 4e-05 L
.00683 4e-05 L
.00682 3e-05 L
.00681 3e-05 L
.00681 3e-05 L
.0068 3e-05 L
.00679 3e-05 L
Mistroke
.00679 2e-05 L
.00678 2e-05 L
.00677 2e-05 L
.00677 2e-05 L
.00676 2e-05 L
.00675 2e-05 L
.00675 1e-05 L
.00674 0 L
.00673 0 L
.00673 0 L
.00672 0 L
.00671 0 L
.00671 0 L
.0067 0 L
.00669 0 L
.00669 0 L
.00668 0 L
.00667 0 L
.00667 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
This gives the normalized cumulative energy of the Fourier \
coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.62"}],

Cell["ef = CumulativeEnergy[fdata]/(data.data);", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
We display the error curve for Fourier decomposition (dotted line) \
together with that for wavelet decomposition.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.63"}],

Cell[CellGroupData[{

Cell["\<\
Show[%%, ListPlot[Transpose[{Table[1024/i,{i, 1, 150}],
Sqrt[Chop[1-Take[ef,150]]]}],
PlotRange -> {{0, 150}, {0, 0.5}},
DisplayFunction -> Identity]]\
\>", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.20924e-17 0.00666667 0 1.23607 [
[.13333 -0.0125 -6 -9 ]
[.13333 -0.0125 6 0 ]
[.26667 -0.0125 -6 -9 ]
[.26667 -0.0125 6 0 ]
[.4 -0.0125 -6 -9 ]
[.4 -0.0125 6 0 ]
[.53333 -0.0125 -6 -9 ]
[.53333 -0.0125 6 0 ]
[.66667 -0.0125 -9 -9 ]
[.66667 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[.93333 -0.0125 -9 -9 ]
[.93333 -0.0125 9 0 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -108 0 ]
[.5 .63053 108 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13333 0 m
.13333 .00625 L
s
[(20)] .13333 -0.0125 0 1 Mshowa
.26667 0 m
.26667 .00625 L
s
[(40)] .26667 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(60)] .4 -0.0125 0 1 Mshowa
.53333 0 m
.53333 .00625 L
s
[(80)] .53333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(100)] .66667 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(120)] .8 -0.0125 0 1 Mshowa
.93333 0 m
.93333 .00625 L
s
[(140)] .93333 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.3 0 m
.3 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.5 0 m
.5 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(0.1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0.5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(relative error vs. compression ratio)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
1 .54408 m
.97524 .53705 L
.85333 .48663 L
.75852 .45257 L
.68267 .41791 L
.62061 .38186 L
.56889 .3488 L
.52513 .32037 L
.48762 .29572 L
.45511 .26921 L
.42667 .25214 L
.40157 .23582 L
.37926 .2196 L
.3593 .20394 L
.34133 .18806 L
.32508 .17713 L
.3103 .16646 L
.29681 .15634 L
.28444 .14742 L
.27307 .13914 L
.26256 .13044 L
.25284 .12332 L
.24381 .11611 L
.2354 .10904 L
.22756 .10238 L
.22022 .0958 L
.21333 .08939 L
.20687 .08376 L
.20078 .07871 L
.19505 .07434 L
.18963 .07036 L
.1845 .06694 L
.17965 .06358 L
.17504 .06007 L
.17067 .05794 L
.1665 .05587 L
.16254 .05374 L
.15876 .05156 L
.15515 .04935 L
.1517 .04712 L
.14841 .04499 L
.14525 .0428 L
.14222 .04061 L
.13932 .03833 L
.13653 .0363 L
.13386 .03422 L
.13128 .03286 L
.12881 .03148 L
.12642 .03012 L
.12412 .02901 L
Mistroke
.1219 .02789 L
.11977 .0269 L
.1177 .02597 L
.11571 .02502 L
.11378 .02413 L
.11191 .02328 L
.11011 .02243 L
.10836 .0217 L
.10667 .02105 L
.10503 .02045 L
.10343 .01987 L
.10189 .01928 L
.10039 .01868 L
.09894 .0181 L
.09752 .01753 L
.09615 .01704 L
.09481 .01655 L
.09352 .01606 L
.09225 .01556 L
.09102 .01509 L
.08982 .01461 L
.08866 .01426 L
.08752 .01394 L
.08641 .01364 L
.08533 .01338 L
.08428 .01315 L
.08325 .01299 L
.08225 .01283 L
.08127 .01267 L
.08031 .01252 L
.07938 .01237 L
.07847 .01222 L
.07758 .01207 L
.0767 .01193 L
.07585 .01181 L
.07502 .0117 L
.0742 .01159 L
.07341 .01149 L
.07262 .01139 L
.07186 .01132 L
.07111 .01125 L
.07038 .01118 L
.06966 .01112 L
.06896 .01106 L
.06827 .011 L
.06759 .01095 L
.06693 .01089 L
.06628 .01085 L
.06564 .0108 L
.06502 .01075 L
Mistroke
.0644 .01071 L
.0638 .01066 L
.06321 .01062 L
.06263 .01057 L
.06206 .01053 L
.0615 .01049 L
.06095 .01044 L
.06041 .0104 L
.05988 .01036 L
.05936 .01032 L
.05885 .01028 L
.05835 .01024 L
.05785 .0102 L
.05737 .01017 L
.05689 .01013 L
.05642 .01009 L
.05596 .01006 L
.0555 .01002 L
.05505 .00998 L
.05461 .00995 L
.05418 .00991 L
.05375 .00988 L
.05333 .00984 L
.05292 .00981 L
.05251 .00978 L
.05211 .00974 L
.05172 .00971 L
.05133 .00968 L
.05095 .00965 L
.05057 .00961 L
.0502 .00958 L
.04983 .00955 L
.04947 .00952 L
.04911 .0095 L
.04876 .00947 L
.04842 .00944 L
.04808 .00941 L
.04774 .00938 L
.04741 .00935 L
.04708 .00932 L
.04676 .00929 L
.04644 .00926 L
.04613 .00923 L
.04582 .0092 L
.04551 .00917 L
.04521 .00915 L
.04491 .00912 L
.04462 .00909 L
.04433 .00906 L
.04404 .00903 L
Mistroke
.04376 .009 L
.04348 .00898 L
.04321 .00895 L
.04294 .00892 L
.04267 .00889 L
.0424 .00887 L
.04214 .00884 L
.04188 .00881 L
.04163 .00878 L
.04137 .00876 L
.04112 .00873 L
.04088 .0087 L
.04063 .00868 L
.04039 .00865 L
.04016 .00863 L
.03992 .0086 L
.03969 .00857 L
.03946 .00855 L
.03923 .00852 L
.03901 .00849 L
.03879 .00847 L
.03857 .00844 L
.03835 .00842 L
.03814 .00839 L
.03793 .00837 L
.03772 .00834 L
.03751 .00832 L
.0373 .00829 L
.0371 .00827 L
.0369 .00824 L
.0367 .00821 L
.03651 .00819 L
.03631 .00816 L
.03612 .00814 L
.03593 .00811 L
.03574 .00809 L
.03556 .00806 L
.03537 .00804 L
.03519 .00802 L
.03501 .00799 L
.03483 .00797 L
.03465 .00794 L
.03448 .00792 L
.0343 .00789 L
.03413 .00787 L
.03396 .00785 L
.0338 .00783 L
.03363 .0078 L
.03346 .00778 L
.0333 .00776 L
Mistroke
.03314 .00773 L
.03298 .00771 L
.03282 .00769 L
.03266 .00767 L
.03251 .00765 L
.03235 .00762 L
.0322 .0076 L
.03205 .00758 L
.0319 .00756 L
.03175 .00754 L
.0316 .00752 L
.03146 .0075 L
.03131 .00748 L
.03117 .00746 L
.03103 .00744 L
.03089 .00742 L
.03075 .0074 L
.03061 .00738 L
.03048 .00736 L
.03034 .00734 L
.03021 .00732 L
.03007 .0073 L
.02994 .00728 L
.02981 .00726 L
.02968 .00724 L
.02955 .00722 L
.02943 .0072 L
.0293 .00718 L
.02917 .00716 L
.02905 .00714 L
.02893 .00712 L
.0288 .0071 L
.02868 .00708 L
.02856 .00706 L
.02844 .00704 L
.02833 .00702 L
.02821 .00701 L
.02809 .00699 L
.02798 .00697 L
.02786 .00695 L
.02775 .00693 L
.02764 .00691 L
.02753 .00689 L
.02742 .00687 L
.02731 .00685 L
.0272 .00684 L
.02709 .00682 L
.02698 .0068 L
.02688 .00678 L
.02677 .00676 L
Mistroke
.02667 .00674 L
.02656 .00672 L
.02646 .00671 L
.02636 .00669 L
.02626 .00667 L
.02616 .00665 L
.02606 .00663 L
.02596 .00662 L
.02586 .0066 L
.02576 .00658 L
.02566 .00656 L
.02557 .00654 L
.02547 .00653 L
.02538 .00651 L
.02528 .00649 L
.02519 .00647 L
.0251 .00646 L
.02501 .00644 L
.02491 .00642 L
.02482 .0064 L
.02473 .00639 L
.02465 .00637 L
.02456 .00635 L
.02447 .00633 L
.02438 .00632 L
.02429 .0063 L
.02421 .00628 L
.02412 .00627 L
.02404 .00625 L
.02395 .00623 L
.02387 .00622 L
.02379 .0062 L
.0237 .00618 L
.02362 .00617 L
.02354 .00615 L
.02346 .00613 L
.02338 .00612 L
.0233 .0061 L
.02322 .00608 L
.02314 .00607 L
.02306 .00605 L
.02299 .00604 L
.02291 .00602 L
.02283 .006 L
.02276 .00599 L
.02268 .00597 L
.0226 .00596 L
.02253 .00594 L
.02246 .00592 L
.02238 .00591 L
Mistroke
.02231 .00589 L
.02224 .00588 L
.02216 .00586 L
.02209 .00585 L
.02202 .00583 L
.02195 .00582 L
.02188 .0058 L
.02181 .00579 L
.02174 .00577 L
.02167 .00576 L
.0216 .00574 L
.02154 .00573 L
.02147 .00571 L
.0214 .0057 L
.02133 .00568 L
.02127 .00567 L
.0212 .00565 L
.02114 .00564 L
.02107 .00562 L
.02101 .00561 L
.02094 .00559 L
.02088 .00558 L
.02081 .00556 L
.02075 .00555 L
.02069 .00554 L
.02062 .00552 L
.02056 .00551 L
.0205 .00549 L
.02044 .00548 L
.02038 .00547 L
.02032 .00545 L
.02026 .00544 L
.0202 .00542 L
.02014 .00541 L
.02008 .0054 L
.02002 .00538 L
.01996 .00537 L
.0199 .00536 L
.01984 .00534 L
.01979 .00533 L
.01973 .00532 L
.01967 .0053 L
.01962 .00529 L
.01956 .00528 L
.0195 .00526 L
.01945 .00525 L
.01939 .00524 L
.01934 .00523 L
.01928 .00521 L
.01923 .0052 L
Mistroke
.01918 .00519 L
.01912 .00517 L
.01907 .00516 L
.01902 .00515 L
.01896 .00514 L
.01891 .00512 L
.01886 .00511 L
.01881 .0051 L
.01875 .00509 L
.0187 .00507 L
.01865 .00506 L
.0186 .00505 L
.01855 .00504 L
.0185 .00502 L
.01845 .00501 L
.0184 .005 L
.01835 .00499 L
.0183 .00497 L
.01825 .00496 L
.0182 .00495 L
.01816 .00494 L
.01811 .00493 L
.01806 .00491 L
.01801 .0049 L
.01796 .00489 L
.01792 .00488 L
.01787 .00486 L
.01782 .00485 L
.01778 .00484 L
.01773 .00483 L
.01769 .00482 L
.01764 .0048 L
.01759 .00479 L
.01755 .00478 L
.0175 .00477 L
.01746 .00476 L
.01741 .00475 L
.01737 .00473 L
.01733 .00472 L
.01728 .00471 L
.01724 .0047 L
.0172 .00469 L
.01715 .00468 L
.01711 .00466 L
.01707 .00465 L
.01702 .00464 L
.01698 .00463 L
.01694 .00462 L
.0169 .00461 L
.01686 .0046 L
Mistroke
.01681 .00459 L
.01677 .00457 L
.01673 .00456 L
.01669 .00455 L
.01665 .00454 L
.01661 .00453 L
.01657 .00452 L
.01653 .00451 L
.01649 .0045 L
.01645 .00449 L
.01641 .00448 L
.01637 .00447 L
.01633 .00445 L
.01629 .00444 L
.01625 .00443 L
.01622 .00442 L
.01618 .00441 L
.01614 .0044 L
.0161 .00439 L
.01606 .00438 L
.01603 .00437 L
.01599 .00436 L
.01595 .00435 L
.01591 .00434 L
.01588 .00433 L
.01584 .00432 L
.0158 .00431 L
.01577 .0043 L
.01573 .00429 L
.01569 .00428 L
.01566 .00427 L
.01562 .00425 L
.01559 .00424 L
.01555 .00423 L
.01552 .00422 L
.01548 .00421 L
.01544 .0042 L
.01541 .00419 L
.01538 .00418 L
.01534 .00417 L
.01531 .00416 L
.01527 .00415 L
.01524 .00414 L
.0152 .00413 L
.01517 .00412 L
.01514 .00411 L
.0151 .0041 L
.01507 .00409 L
.01504 .00408 L
.015 .00407 L
Mistroke
.01497 .00406 L
.01494 .00405 L
.01491 .00404 L
.01487 .00403 L
.01484 .00402 L
.01481 .00401 L
.01478 .004 L
.01474 .00399 L
.01471 .00398 L
.01468 .00397 L
.01465 .00396 L
.01462 .00395 L
.01459 .00394 L
.01456 .00393 L
.01452 .00392 L
.01449 .00391 L
.01446 .0039 L
.01443 .00389 L
.0144 .00388 L
.01437 .00387 L
.01434 .00386 L
.01431 .00385 L
.01428 .00384 L
.01425 .00383 L
.01422 .00382 L
.01419 .00382 L
.01416 .00381 L
.01413 .0038 L
.0141 .00379 L
.01408 .00378 L
.01405 .00377 L
.01402 .00376 L
.01399 .00375 L
.01396 .00374 L
.01393 .00373 L
.0139 .00372 L
.01388 .00371 L
.01385 .0037 L
.01382 .00369 L
.01379 .00368 L
.01376 .00367 L
.01374 .00366 L
.01371 .00366 L
.01368 .00365 L
.01365 .00364 L
.01363 .00363 L
.0136 .00362 L
.01357 .00361 L
.01354 .0036 L
.01352 .00359 L
Mistroke
.01349 .00358 L
.01346 .00357 L
.01344 .00356 L
.01341 .00355 L
.01339 .00354 L
.01336 .00354 L
.01333 .00353 L
.01331 .00352 L
.01328 .00351 L
.01326 .0035 L
.01323 .00349 L
.0132 .00348 L
.01318 .00347 L
.01315 .00346 L
.01313 .00345 L
.0131 .00344 L
.01308 .00343 L
.01305 .00343 L
.01303 .00342 L
.013 .00341 L
.01298 .0034 L
.01295 .00339 L
.01293 .00338 L
.0129 .00337 L
.01288 .00336 L
.01286 .00335 L
.01283 .00334 L
.01281 .00333 L
.01278 .00332 L
.01276 .00332 L
.01274 .00331 L
.01271 .0033 L
.01269 .00329 L
.01267 .00328 L
.01264 .00327 L
.01262 .00326 L
.0126 .00325 L
.01257 .00324 L
.01255 .00323 L
.01253 .00322 L
.0125 .00322 L
.01248 .00321 L
.01246 .0032 L
.01243 .00319 L
.01241 .00318 L
.01239 .00317 L
.01237 .00316 L
.01234 .00315 L
.01232 .00314 L
.0123 .00313 L
Mistroke
.01228 .00313 L
.01226 .00312 L
.01223 .00311 L
.01221 .0031 L
.01219 .00309 L
.01217 .00308 L
.01215 .00307 L
.01213 .00306 L
.0121 .00305 L
.01208 .00305 L
.01206 .00304 L
.01204 .00303 L
.01202 .00302 L
.012 .00301 L
.01198 .003 L
.01196 .00299 L
.01193 .00298 L
.01191 .00298 L
.01189 .00297 L
.01187 .00296 L
.01185 .00295 L
.01183 .00294 L
.01181 .00293 L
.01179 .00292 L
.01177 .00292 L
.01175 .00291 L
.01173 .0029 L
.01171 .00289 L
.01169 .00288 L
.01167 .00287 L
.01165 .00286 L
.01163 .00285 L
.01161 .00285 L
.01159 .00284 L
.01157 .00283 L
.01155 .00282 L
.01153 .00281 L
.01151 .0028 L
.01149 .0028 L
.01147 .00279 L
.01145 .00278 L
.01143 .00277 L
.01142 .00276 L
.0114 .00275 L
.01138 .00274 L
.01136 .00274 L
.01134 .00273 L
.01132 .00272 L
.0113 .00271 L
.01128 .0027 L
Mistroke
.01127 .00269 L
.01125 .00268 L
.01123 .00268 L
.01121 .00267 L
.01119 .00266 L
.01117 .00265 L
.01115 .00264 L
.01114 .00263 L
.01112 .00263 L
.0111 .00262 L
.01108 .00261 L
.01106 .0026 L
.01105 .00259 L
.01103 .00258 L
.01101 .00258 L
.01099 .00257 L
.01098 .00256 L
.01096 .00255 L
.01094 .00254 L
.01092 .00253 L
.01091 .00252 L
.01089 .00252 L
.01087 .00251 L
.01085 .0025 L
.01084 .00249 L
.01082 .00248 L
.0108 .00247 L
.01078 .00247 L
.01077 .00246 L
.01075 .00245 L
.01073 .00244 L
.01072 .00243 L
.0107 .00242 L
.01068 .00241 L
.01067 .00241 L
.01065 .0024 L
.01063 .00239 L
.01062 .00238 L
.0106 .00237 L
.01058 .00237 L
.01057 .00236 L
.01055 .00235 L
.01053 .00234 L
.01052 .00233 L
.0105 .00232 L
.01049 .00232 L
.01047 .00231 L
.01045 .0023 L
.01044 .00229 L
.01042 .00228 L
Mistroke
.01041 .00227 L
.01039 .00227 L
.01037 .00226 L
.01036 .00225 L
.01034 .00224 L
.01033 .00223 L
.01031 .00222 L
.0103 .00222 L
.01028 .00221 L
.01027 .0022 L
.01025 .00219 L
.01023 .00218 L
.01022 .00217 L
.0102 .00217 L
.01019 .00216 L
.01017 .00215 L
.01016 .00214 L
.01014 .00213 L
.01013 .00213 L
.01011 .00212 L
.0101 .00211 L
.01008 .0021 L
.01007 .00209 L
.01005 .00209 L
.01004 .00208 L
.01002 .00207 L
.01001 .00206 L
.01 .00205 L
.00998 .00205 L
.00997 .00204 L
.00995 .00203 L
.00994 .00202 L
.00992 .00201 L
.00991 .00201 L
.00989 .002 L
.00988 .00199 L
.00987 .00198 L
.00985 .00197 L
.00984 .00197 L
.00982 .00196 L
.00981 .00195 L
.00979 .00194 L
.00978 .00193 L
.00977 .00193 L
.00975 .00192 L
.00974 .00191 L
.00972 .0019 L
.00971 .00189 L
.0097 .00189 L
.00968 .00188 L
Mistroke
.00967 .00187 L
.00966 .00186 L
.00964 .00185 L
.00963 .00185 L
.00962 .00184 L
.0096 .00183 L
.00959 .00182 L
.00957 .00182 L
.00956 .00181 L
.00955 .0018 L
.00953 .00179 L
.00952 .00178 L
.00951 .00178 L
.00949 .00177 L
.00948 .00176 L
.00947 .00175 L
.00946 .00175 L
.00944 .00174 L
.00943 .00173 L
.00942 .00172 L
.0094 .00171 L
.00939 .00171 L
.00938 .0017 L
.00936 .00169 L
.00935 .00168 L
.00934 .00167 L
.00933 .00167 L
.00931 .00166 L
.0093 .00165 L
.00929 .00164 L
.00928 .00163 L
.00926 .00163 L
.00925 .00162 L
.00924 .00161 L
.00923 .0016 L
.00921 .0016 L
.0092 .00159 L
.00919 .00158 L
.00918 .00157 L
.00916 .00156 L
.00915 .00156 L
.00914 .00155 L
.00913 .00154 L
.00911 .00153 L
.0091 .00152 L
.00909 .00152 L
.00908 .00151 L
.00907 .0015 L
.00905 .00149 L
.00904 .00149 L
Mistroke
.00903 .00148 L
.00902 .00147 L
.00901 .00146 L
.00899 .00145 L
.00898 .00145 L
.00897 .00144 L
.00896 .00143 L
.00895 .00142 L
.00894 .00141 L
.00892 .00141 L
.00891 .0014 L
.0089 .00139 L
.00889 .00138 L
.00888 .00137 L
.00887 .00137 L
.00885 .00136 L
.00884 .00135 L
.00883 .00134 L
.00882 .00134 L
.00881 .00133 L
.0088 .00132 L
.00879 .00131 L
.00877 .0013 L
.00876 .0013 L
.00875 .00129 L
.00874 .00128 L
.00873 .00127 L
.00872 .00126 L
.00871 .00126 L
.0087 .00125 L
.00869 .00124 L
.00867 .00123 L
.00866 .00122 L
.00865 .00121 L
.00864 .00121 L
.00863 .0012 L
.00862 .00119 L
.00861 .00118 L
.0086 .00117 L
.00859 .00117 L
.00858 .00116 L
.00857 .00115 L
.00855 .00114 L
.00854 .00114 L
.00853 .00113 L
.00852 .00112 L
.00851 .00111 L
.0085 .0011 L
.00849 .0011 L
.00848 .00109 L
Mistroke
.00847 .00108 L
.00846 .00107 L
.00845 .00107 L
.00844 .00106 L
.00843 .00105 L
.00842 .00104 L
.00841 .00104 L
.0084 .00103 L
.00839 .00102 L
.00838 .00101 L
.00837 .00101 L
.00836 .001 L
.00835 .00099 L
.00834 .00098 L
.00833 .00098 L
.00832 .00097 L
.0083 .00096 L
.00829 .00095 L
.00828 .00095 L
.00827 .00094 L
.00826 .00093 L
.00825 .00092 L
.00824 .00092 L
.00823 .00091 L
.00822 .0009 L
.00822 .0009 L
.00821 .00089 L
.0082 .00088 L
.00819 .00087 L
.00818 .00087 L
.00817 .00086 L
.00816 .00085 L
.00815 .00085 L
.00814 .00084 L
.00813 .00083 L
.00812 .00082 L
.00811 .00082 L
.0081 .00081 L
.00809 .0008 L
.00808 .0008 L
.00807 .00079 L
.00806 .00078 L
.00805 .00077 L
.00804 .00077 L
.00803 .00076 L
.00802 .00075 L
.00801 .00075 L
.008 .00074 L
.00799 .00073 L
.00798 .00073 L
Mistroke
.00798 .00072 L
.00797 .00071 L
.00796 .00071 L
.00795 .0007 L
.00794 .00069 L
.00793 .00069 L
.00792 .00068 L
.00791 .00067 L
.0079 .00067 L
.00789 .00066 L
.00788 .00065 L
.00787 .00065 L
.00786 .00064 L
.00786 .00064 L
.00785 .00063 L
.00784 .00062 L
.00783 .00062 L
.00782 .00061 L
.00781 .0006 L
.0078 .0006 L
.00779 .00059 L
.00778 .00059 L
.00778 .00058 L
.00777 .00057 L
.00776 .00057 L
.00775 .00056 L
.00774 .00055 L
.00773 .00055 L
.00772 .00054 L
.00771 .00053 L
.00771 .00053 L
.0077 .00052 L
.00769 .00052 L
.00768 .00051 L
.00767 .0005 L
.00766 .0005 L
.00765 .00049 L
.00764 .00049 L
.00764 .00048 L
.00763 .00048 L
.00762 .00047 L
.00761 .00046 L
.0076 .00046 L
.00759 .00045 L
.00759 .00045 L
.00758 .00044 L
.00757 .00044 L
.00756 .00043 L
.00755 .00042 L
.00754 .00042 L
Mistroke
.00753 .00041 L
.00753 .00041 L
.00752 .0004 L
.00751 .00039 L
.0075 .00039 L
.00749 .00038 L
.00749 .00038 L
.00748 .00037 L
.00747 .00037 L
.00746 .00036 L
.00745 .00036 L
.00744 .00035 L
.00744 .00035 L
.00743 .00034 L
.00742 .00034 L
.00741 .00033 L
.0074 .00033 L
.0074 .00032 L
.00739 .00032 L
.00738 .00031 L
.00737 .00031 L
.00736 .0003 L
.00736 .0003 L
.00735 .00029 L
.00734 .00029 L
.00733 .00028 L
.00732 .00028 L
.00732 .00027 L
.00731 .00027 L
.0073 .00026 L
.00729 .00026 L
.00729 .00025 L
.00728 .00025 L
.00727 .00024 L
.00726 .00024 L
.00725 .00023 L
.00725 .00023 L
.00724 .00022 L
.00723 .00022 L
.00722 .00022 L
.00722 .00021 L
.00721 .00021 L
.0072 .0002 L
.00719 .0002 L
.00719 .00019 L
.00718 .00019 L
.00717 .00019 L
.00716 .00018 L
.00716 .00018 L
.00715 .00017 L
Mistroke
.00714 .00017 L
.00713 .00017 L
.00713 .00016 L
.00712 .00016 L
.00711 .00016 L
.0071 .00015 L
.0071 .00015 L
.00709 .00014 L
.00708 .00014 L
.00707 .00014 L
.00707 .00013 L
.00706 .00013 L
.00705 .00013 L
.00705 .00012 L
.00704 .00012 L
.00703 .00012 L
.00702 .00011 L
.00702 .00011 L
.00701 .00011 L
.007 .0001 L
.00699 .0001 L
.00699 .0001 L
.00698 .0001 L
.00697 9e-05 L
.00697 9e-05 L
.00696 9e-05 L
.00695 8e-05 L
.00694 8e-05 L
.00694 8e-05 L
.00693 7e-05 L
.00692 7e-05 L
.00692 7e-05 L
.00691 7e-05 L
.0069 6e-05 L
.0069 6e-05 L
.00689 6e-05 L
.00688 5e-05 L
.00687 5e-05 L
.00687 5e-05 L
.00686 5e-05 L
.00685 4e-05 L
.00685 4e-05 L
.00684 4e-05 L
.00683 4e-05 L
.00683 4e-05 L
.00682 3e-05 L
.00681 3e-05 L
.00681 3e-05 L
.0068 3e-05 L
.00679 3e-05 L
Mistroke
.00679 2e-05 L
.00678 2e-05 L
.00677 2e-05 L
.00677 2e-05 L
.00676 2e-05 L
.00675 2e-05 L
.00675 1e-05 L
.00674 0 L
.00673 0 L
.00673 0 L
.00672 0 L
.00671 0 L
.00671 0 L
.0067 0 L
.00669 0 L
.00669 0 L
.00668 0 L
.00667 0 L
.00667 0 L
Mfstroke
.008 w
.85333 .61509 Mdot
.75852 .58655 Mdot
.68267 .55656 Mdot
.62061 .52868 Mdot
.56889 .49924 Mdot
.52513 .47345 Mdot
.48762 .44617 Mdot
.45511 .423 Mdot
.42667 .39935 Mdot
.40157 .3742 Mdot
.37926 .35621 Mdot
.3593 .33726 Mdot
.34133 .31891 Mdot
.32508 .29944 Mdot
.3103 .2796 Mdot
.29681 .25824 Mdot
.28444 .24629 Mdot
.27307 .23372 Mdot
.26256 .22144 Mdot
.25284 .20844 Mdot
.24381 .19652 Mdot
.2354 .18383 Mdot
.22756 .17222 Mdot
.22022 .15977 Mdot
.21333 .15294 Mdot
.20687 .14579 Mdot
.20078 .13973 Mdot
.19505 .1334 Mdot
.18963 .12835 Mdot
.1845 .1231 Mdot
.17965 .11776 Mdot
.17504 .11217 Mdot
.17067 .10825 Mdot
.1665 .10418 Mdot
.16254 .10017 Mdot
.15876 .09599 Mdot
.15515 .09171 Mdot
.1517 .08722 Mdot
.14841 .08396 Mdot
.14525 .08056 Mdot
.14222 .07767 Mdot
.13932 .07467 Mdot
.13653 .07166 Mdot
.13386 .06851 Mdot
.13128 .06563 Mdot
.12881 .06261 Mdot
.12642 .06077 Mdot
.12412 .05888 Mdot
.1219 .0571 Mdot
.11977 .05526 Mdot
.1177 .05342 Mdot
.11571 .05152 Mdot
.11378 .0497 Mdot
.11191 .04782 Mdot
.11011 .04605 Mdot
.10836 .04421 Mdot
.10667 .04231 Mdot
.10503 .04032 Mdot
.10343 .03866 Mdot
.10189 .03693 Mdot
.10039 .0357 Mdot
.09894 .03443 Mdot
.09752 .03323 Mdot
.09615 .03197 Mdot
.09481 .03075 Mdot
.09352 .02948 Mdot
.09225 .02836 Mdot
.09102 .02719 Mdot
.08982 .02616 Mdot
.08866 .02509 Mdot
.08752 .02402 Mdot
.08641 .02291 Mdot
.08533 .02199 Mdot
.08428 .02103 Mdot
.08325 .02013 Mdot
.08225 .01919 Mdot
.08127 .01839 Mdot
.08031 .01755 Mdot
.07938 .01692 Mdot
.07847 .01626 Mdot
.07758 .01572 Mdot
.0767 .01517 Mdot
.07585 .01466 Mdot
.07502 .01413 Mdot
.0742 .01362 Mdot
.07341 .01309 Mdot
.07262 .01267 Mdot
.07186 .01223 Mdot
.07111 .01184 Mdot
.07038 .01144 Mdot
.06966 .01103 Mdot
.06896 .01061 Mdot
.06827 .01026 Mdot
.06759 .00991 Mdot
.06693 .00957 Mdot
.06628 .00921 Mdot
.06564 .00887 Mdot
.06502 .00851 Mdot
.0644 .00823 Mdot
.0638 .00794 Mdot
.06321 .00765 Mdot
.06263 .00735 Mdot
.06206 .00708 Mdot
.0615 .00679 Mdot
.06095 .00651 Mdot
.06041 .00622 Mdot
.05988 .00598 Mdot
.05936 .00572 Mdot
.05885 .00548 Mdot
.05835 .00523 Mdot
.05785 .00503 Mdot
.05737 .00482 Mdot
.05689 .00462 Mdot
.05642 .0044 Mdot
.05596 .00421 Mdot
.0555 .00401 Mdot
.05505 .00383 Mdot
.05461 .00363 Mdot
.05418 .00347 Mdot
.05375 .00331 Mdot
.05333 .00315 Mdot
.05292 .00298 Mdot
.05251 .00286 Mdot
.05211 .00274 Mdot
.05172 .00265 Mdot
.05133 .00256 Mdot
.05095 .00247 Mdot
.05057 .00237 Mdot
.0502 .00229 Mdot
.04983 .0022 Mdot
.04947 .00213 Mdot
.04911 .00205 Mdot
.04876 .00197 Mdot
.04842 .00188 Mdot
.04808 .0018 Mdot
.04774 .00172 Mdot
.04741 .00165 Mdot
.04708 .00159 Mdot
.04676 .00154 Mdot
.04644 .00149 Mdot
.04613 .00145 Mdot
.04582 .00141 Mdot
.04551 .00137 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell[TextData[{
  "The preceding graph shows that for the same compression ratio, wavelet \
decomposition has less relative error or, for the same error, it can achieve \
a larger compression ratio. We explore this by decreasing ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S2.1.1"],
  " to 20 from 30, that is, increasing the compression ratio to 50 from 34, \
both in the case of the wavelet and Fourier transforms and comparing the \
relative errors. "
}], "Text",
  CellTags->{"S2.1.1", "1.64"}],

Cell["\<\
We increase the compression ratio to about 50 in the wavelet \
representation.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.65"}],

Cell["InverseWaveletTransform[Compress[wtdata, 20], filter];", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
The original data (dashed line) and the reconstructed signal (solid \
line) are shown here. As expected, the error is larger than in the case with \
a compression ratio of 34.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.66"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[%, PlotJoined -> True,
 PlotLabel -> \"u(x), compression ratio 1024/20\"],
 ListPlot[data, PlotJoined -> True,
 PlotStyle->Dashing[{0.02}]]}]]\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.346742 0.545606 [
[.20982 .33424 -9 -9 ]
[.20982 .33424 9 0 ]
[.39583 .33424 -9 -9 ]
[.39583 .33424 9 0 ]
[.58185 .33424 -9 -9 ]
[.58185 .33424 9 0 ]
[.76786 .33424 -9 -9 ]
[.76786 .33424 9 0 ]
[.95387 .33424 -12 -9 ]
[.95387 .33424 12 0 ]
[.01131 .01938 -24 -4.5 ]
[.01131 .01938 0 4.5 ]
[.01131 .1285 -24 -4.5 ]
[.01131 .1285 0 4.5 ]
[.01131 .23762 -24 -4.5 ]
[.01131 .23762 0 4.5 ]
[.01131 .45586 -18 -4.5 ]
[.01131 .45586 0 4.5 ]
[.01131 .56498 -18 -4.5 ]
[.01131 .56498 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .34674 m
.20982 .35299 L
s
[(200)] .20982 .33424 0 1 Mshowa
.39583 .34674 m
.39583 .35299 L
s
[(400)] .39583 .33424 0 1 Mshowa
.58185 .34674 m
.58185 .35299 L
s
[(600)] .58185 .33424 0 1 Mshowa
.76786 .34674 m
.76786 .35299 L
s
[(800)] .76786 .33424 0 1 Mshowa
.95387 .34674 m
.95387 .35299 L
s
[(1000)] .95387 .33424 0 1 Mshowa
.125 Mabswid
.07031 .34674 m
.07031 .35049 L
s
.11682 .34674 m
.11682 .35049 L
s
.16332 .34674 m
.16332 .35049 L
s
.25632 .34674 m
.25632 .35049 L
s
.30283 .34674 m
.30283 .35049 L
s
.34933 .34674 m
.34933 .35049 L
s
.44234 .34674 m
.44234 .35049 L
s
.48884 .34674 m
.48884 .35049 L
s
.53534 .34674 m
.53534 .35049 L
s
.62835 .34674 m
.62835 .35049 L
s
.67485 .34674 m
.67485 .35049 L
s
.72135 .34674 m
.72135 .35049 L
s
.81436 .34674 m
.81436 .35049 L
s
.86086 .34674 m
.86086 .35049 L
s
.90737 .34674 m
.90737 .35049 L
s
.25 Mabswid
0 .34674 m
1 .34674 L
s
.02381 .01938 m
.03006 .01938 L
s
[(-0.6)] .01131 .01938 1 0 Mshowa
.02381 .1285 m
.03006 .1285 L
s
[(-0.4)] .01131 .1285 1 0 Mshowa
.02381 .23762 m
.03006 .23762 L
s
[(-0.2)] .01131 .23762 1 0 Mshowa
.02381 .45586 m
.03006 .45586 L
s
[(0.2)] .01131 .45586 1 0 Mshowa
.02381 .56498 m
.03006 .56498 L
s
[(0.4)] .01131 .56498 1 0 Mshowa
.125 Mabswid
.02381 .04666 m
.02756 .04666 L
s
.02381 .07394 m
.02756 .07394 L
s
.02381 .10122 m
.02756 .10122 L
s
.02381 .15578 m
.02756 .15578 L
s
.02381 .18306 m
.02756 .18306 L
s
.02381 .21034 m
.02756 .21034 L
s
.02381 .2649 m
.02756 .2649 L
s
.02381 .29218 m
.02756 .29218 L
s
.02381 .31946 m
.02756 .31946 L
s
.02381 .37402 m
.02756 .37402 L
s
.02381 .4013 m
.02756 .4013 L
s
.02381 .42858 m
.02756 .42858 L
s
.02381 .48314 m
.02756 .48314 L
s
.02381 .51042 m
.02756 .51042 L
s
.02381 .5377 m
.02756 .5377 L
s
.02381 .59226 m
.02756 .59226 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\), compression ratio 1024/20)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02474 .26818 m
.02567 .26682 L
.0266 .26683 L
.02753 .26637 L
.02846 .26811 L
.02939 .26811 L
.03032 .27036 L
.03125 .27229 L
.03218 .27553 L
.03311 .27548 L
.03404 .27678 L
.03497 .27782 L
.0359 .28091 L
.03683 .28185 L
.03776 .28479 L
.03869 .28726 L
.03962 .29039 L
.04055 .2891 L
.04148 .28862 L
.04241 .28788 L
.04334 .28897 L
.04427 .28736 L
.0452 .28785 L
.04613 .28836 L
.04706 .28982 L
.04799 .28643 L
.04892 .28421 L
.04985 .28201 L
.05078 .28194 L
.05171 .27817 L
.05264 .27667 L
.05357 .27472 L
.0545 .27367 L
.05543 .26595 L
.05636 .25948 L
.05729 .25241 L
.05822 .24804 L
.05915 .23882 L
.06008 .23284 L
.06101 .22641 L
.06194 .22235 L
.06287 .2111 L
.0638 .20265 L
.06473 .1935 L
.06566 .18844 L
.06659 .17736 L
.06752 .17076 L
.06845 .16288 L
.06938 .15853 L
.07031 .14537 L
Mistroke
.07124 .13616 L
.07217 .12523 L
.0731 .11976 L
.07403 .10696 L
.07496 .10018 L
.07589 .09162 L
.07682 .08843 L
.07775 .07582 L
.07868 .06899 L
.07961 .06014 L
.08054 .05816 L
.08147 .04781 L
.0824 .04471 L
.08333 .03929 L
.08426 .04025 L
.08519 .03061 L
.08612 .02765 L
.08705 .02218 L
.08798 .02437 L
.08891 .01712 L
.08984 .01782 L
.09077 .01599 L
.0917 .02121 L
.09263 .0151 L
.09356 .0162 L
.09449 .01472 L
.09542 .02114 L
.09635 .0173 L
.09728 .02137 L
.09821 .02272 L
.09914 .0308 L
.10007 .02662 L
.101 .02919 L
.10193 .0292 L
.10286 .03687 L
.10379 .03406 L
.10472 .03889 L
.10565 .0414 L
.10658 .05039 L
.10751 .04731 L
.10844 .05063 L
.10938 .05186 L
.11031 .06042 L
.11124 .05888 L
.11217 .06441 L
.1131 .06778 L
.11403 .07686 L
.11496 .0739 L
.11589 .07649 L
.11682 .07709 L
Mistroke
.11775 .08452 L
.11868 .08254 L
.11961 .0872 L
.12054 .09006 L
.12147 .09826 L
.1224 .09531 L
.12333 .09749 L
.12426 .09804 L
.12519 .10502 L
.12612 .10351 L
.12705 .10815 L
.12798 .11115 L
.12891 .11888 L
.12984 .11608 L
.13077 .11778 L
.1317 .11789 L
.13263 .12394 L
.13356 .12229 L
.13449 .1264 L
.13542 .12908 L
.13635 .13623 L
.13728 .13385 L
.13821 .13571 L
.13914 .13615 L
.14007 .14208 L
.141 .141 L
.14193 .14519 L
.14286 .14795 L
.14379 .15467 L
.14472 .15249 L
.14565 .15403 L
.14658 .15418 L
.14751 .15932 L
.14844 .15811 L
.14937 .16176 L
.1503 .16425 L
.15123 .17053 L
.15216 .169 L
.15309 .17102 L
.15402 .17187 L
.15495 .17727 L
.15588 .17692 L
.15681 .1809 L
.15774 .18366 L
.15867 .18966 L
.1596 .18838 L
.16053 .19011 L
.16146 .19065 L
.16239 .19522 L
.16332 .19465 L
Mistroke
.16425 .19799 L
.16518 .20044 L
.16611 .20598 L
.16704 .20535 L
.16797 .20758 L
.1689 .20892 L
.16983 .21386 L
.17076 .21423 L
.17169 .21796 L
.17262 .22072 L
.17355 .22597 L
.17448 .2255 L
.17541 .22729 L
.17634 .22812 L
.17727 .232 L
.1782 .23189 L
.17913 .23474 L
.18006 .23691 L
.18099 .24146 L
.18192 .24144 L
.18285 .24356 L
.18378 .24503 L
.18471 .24916 L
.18564 .24993 L
.18657 .25311 L
.1875 .25561 L
.18843 .25992 L
.18936 .2602 L
.19029 .26206 L
.19122 .26322 L
.19215 .26651 L
.19308 .26705 L
.19401 .26961 L
.19494 .27172 L
.19587 .27554 L
.1968 .27647 L
.19773 .27886 L
.19866 .28081 L
.19959 .28446 L
.20052 .28602 L
.20145 .28903 L
.20238 .29155 L
.20331 .2952 L
.20424 .29654 L
.20517 .29875 L
.2061 .30049 L
.20703 .30337 L
.20796 .30486 L
.20889 .30736 L
.20982 .30967 L
Mistroke
.21075 .31292 L
.21168 .31514 L
.21261 .31804 L
.21354 .32078 L
.21447 .3242 L
.2154 .32701 L
.21633 .33021 L
.21726 .3332 L
.21819 .33648 L
.21912 .33936 L
.22005 .34224 L
.22098 .34498 L
.22191 .34777 L
.22284 .35077 L
.22377 .35363 L
.2247 .35661 L
.22563 .35953 L
.22656 .36327 L
.22749 .36667 L
.22842 .3703 L
.22935 .37345 L
.23028 .37766 L
.23121 .38106 L
.23214 .38463 L
.23307 .38731 L
.234 .39137 L
.23493 .3943 L
.23586 .3975 L
.23679 .39956 L
.23772 .40352 L
.23865 .40616 L
.23958 .40933 L
.24051 .41118 L
.24144 .41544 L
.24237 .41818 L
.2433 .42164 L
.24423 .42346 L
.24516 .42796 L
.24609 .4306 L
.24702 .43401 L
.24795 .43541 L
.24888 .43957 L
.24981 .44159 L
.25074 .44447 L
.25167 .44517 L
.2526 .44888 L
.25353 .45032 L
.25446 .45273 L
.25539 .45278 L
.25632 .45582 L
Mistroke
.25725 .45644 L
.25818 .45804 L
.25911 .45719 L
.26004 .45932 L
.26097 .45897 L
.2619 .45952 L
.26283 .4575 L
.26376 .45823 L
.26469 .45642 L
.26563 .45545 L
.26656 .45203 L
.26749 .45137 L
.26842 .44839 L
.26935 .44627 L
.27028 .44194 L
.27121 .4403 L
.27214 .43659 L
.27307 .43366 L
.274 .42873 L
.27493 .42627 L
.27586 .42203 L
.27679 .41856 L
.27772 .41355 L
.27865 .41101 L
.27958 .40711 L
.28051 .40375 L
.28144 .39898 L
.28237 .39603 L
.2833 .39189 L
.28423 .38812 L
.28516 .38351 L
.28609 .38074 L
.28702 .37731 L
.28795 .37399 L
.28888 .3698 L
.28981 .36656 L
.29074 .36273 L
.29167 .35892 L
.2926 .35501 L
.29353 .35244 L
.29446 .34992 L
.29539 .34723 L
.29632 .34421 L
.29725 .34144 L
.29818 .33853 L
.29911 .33539 L
.30004 .33274 L
.30097 .33107 L
.3019 .32999 L
.30283 .32853 L
Mistroke
.30376 .32713 L
.30469 .32558 L
.30562 .32417 L
.30655 .32236 L
.30748 .32136 L
.30841 .32128 L
.30934 .32201 L
.31027 .32234 L
.3112 .32286 L
.31213 .3233 L
.31306 .32389 L
.31399 .32407 L
.31492 .325 L
.31585 .32703 L
.31678 .32974 L
.31771 .33213 L
.31864 .33458 L
.31957 .33738 L
.3205 .34003 L
.32143 .34241 L
.32236 .34505 L
.32329 .34915 L
.32422 .35336 L
.32515 .35751 L
.32608 .36124 L
.32701 .36606 L
.32794 .37018 L
.32887 .37436 L
.3298 .37803 L
.33073 .38366 L
.33166 .38858 L
.33259 .39385 L
.33352 .39801 L
.33445 .40407 L
.33538 .4087 L
.33631 .41382 L
.33724 .41742 L
.33817 .42336 L
.3391 .42763 L
.34003 .43266 L
.34096 .43583 L
.34189 .44156 L
.34282 .44519 L
.34375 .4497 L
.34468 .45184 L
.34561 .45656 L
.34654 .45881 L
.34747 .46213 L
.3484 .46302 L
.34933 .46683 L
Mistroke
.35026 .46806 L
.35119 .47034 L
.35212 .46969 L
.35305 .47147 L
.35398 .47034 L
.35491 .47034 L
.35584 .46776 L
.35677 .46815 L
.3577 .46604 L
.35863 .46507 L
.35956 .46132 L
.36049 .45986 L
.36142 .45578 L
.36235 .4528 L
.36328 .44764 L
.36421 .44514 L
.36514 .44068 L
.36607 .43717 L
.367 .43146 L
.36793 .42744 L
.36886 .42149 L
.36979 .4163 L
.37072 .40966 L
.37165 .40483 L
.37258 .39894 L
.37351 .39366 L
.37444 .38721 L
.37537 .38156 L
.3763 .37509 L
.37723 .36893 L
.37816 .36229 L
.37909 .35613 L
.38002 .34994 L
.38095 .34383 L
.38188 .33765 L
.38281 .33101 L
.38374 .32471 L
.38467 .31818 L
.3856 .3122 L
.38653 .30521 L
.38746 .29927 L
.38839 .29296 L
.38932 .28785 L
.39025 .28113 L
.39118 .27598 L
.39211 .27018 L
.39304 .26597 L
.39397 .25938 L
.3949 .25474 L
.39583 .24919 L
Mistroke
.39676 .2458 L
.39769 .2396 L
.39862 .23587 L
.39955 .23101 L
.40048 .22863 L
.40141 .22287 L
.40234 .21984 L
.40327 .21562 L
.4042 .21432 L
.40513 .20958 L
.40606 .20798 L
.40699 .2052 L
.40792 .20553 L
.40885 .2021 L
.40978 .2019 L
.41071 .20049 L
.41164 .20234 L
.41257 .20037 L
.4135 .20174 L
.41443 .20196 L
.41536 .20546 L
.41629 .20502 L
.41722 .20778 L
.41815 .20931 L
.41908 .21376 L
.42001 .21396 L
.42094 .21707 L
.42188 .21912 L
.42281 .22415 L
.42374 .2253 L
.42467 .22933 L
.4256 .23242 L
.42653 .23795 L
.42746 .23922 L
.42839 .24284 L
.42932 .24574 L
.43025 .25116 L
.43118 .25297 L
.43211 .2571 L
.43304 .26053 L
.43397 .26569 L
.4349 .26657 L
.43583 .26907 L
.43676 .27103 L
.43769 .27502 L
.43862 .27579 L
.43955 .27845 L
.44048 .28073 L
.44141 .28435 L
.44234 .28413 L
Mistroke
.44327 .28516 L
.4442 .28588 L
.44513 .28835 L
.44606 .28804 L
.44699 .28934 L
.44792 .29031 L
.44885 .29236 L
.44978 .29086 L
.45071 .29035 L
.45164 .28947 L
.45257 .29021 L
.4535 .28856 L
.45443 .28848 L
.45536 .28809 L
.45629 .28889 L
.45722 .28671 L
.45815 .28565 L
.45908 .2842 L
.46001 .28442 L
.46094 .28258 L
.46187 .28238 L
.4628 .28174 L
.46373 .28244 L
.46466 .28055 L
.46559 .27991 L
.46652 .27876 L
.46745 .27929 L
.46838 .27801 L
.46931 .27841 L
.47024 .27837 L
.47117 .2798 L
.4721 .27914 L
.47303 .27986 L
.47396 .2801 L
.47489 .28193 L
.47582 .28213 L
.47675 .28387 L
.47768 .28514 L
.47861 .28775 L
.47954 .28853 L
.48047 .29052 L
.4814 .29201 L
.48233 .29479 L
.48326 .29604 L
.48419 .29847 L
.48512 .30045 L
.48605 .30343 L
.48698 .30484 L
.48791 .30712 L
.48884 .309 L
Mistroke
.48977 .31179 L
.4907 .31336 L
.49163 .3157 L
.49256 .31779 L
.49349 .32055 L
.49442 .32223 L
.49535 .32443 L
.49628 .32648 L
.49721 .32906 L
.49814 .33092 L
.49907 .33315 L
.5 .33532 L
.50093 .33776 L
.50186 .33967 L
.50279 .34169 L
.50372 .34369 L
.50465 .34583 L
.50558 .34776 L
.50651 .34967 L
.50744 .3516 L
.50837 .35345 L
.5093 .35526 L
.51023 .35682 L
.51116 .35847 L
.51209 .3599 L
.51302 .3616 L
.51395 .36295 L
.51488 .3645 L
.51581 .36573 L
.51674 .36751 L
.51767 .36881 L
.5186 .37031 L
.51953 .37127 L
.52046 .3729 L
.52139 .37388 L
.52232 .37507 L
.52325 .3757 L
.52418 .37733 L
.52511 .37825 L
.52604 .37936 L
.52697 .37966 L
.5279 .38097 L
.52883 .3814 L
.52976 .38212 L
.53069 .38223 L
.53162 .38395 L
.53255 .38491 L
.53348 .38611 L
.53441 .3863 L
.53534 .38784 L
Mistroke
.53627 .38826 L
.5372 .38893 L
.53813 .38882 L
.53906 .39078 L
.53999 .39181 L
.54092 .39307 L
.54185 .39309 L
.54278 .39487 L
.54371 .39532 L
.54464 .39613 L
.54557 .39609 L
.5465 .39885 L
.54743 .4006 L
.54836 .40268 L
.54929 .40328 L
.55022 .4061 L
.55115 .40726 L
.55208 .40871 L
.55301 .40895 L
.55394 .41239 L
.55487 .41445 L
.5558 .41688 L
.55673 .41748 L
.55766 .42088 L
.55859 .42232 L
.55952 .42432 L
.56045 .42487 L
.56138 .42943 L
.56231 .43235 L
.56324 .43593 L
.56417 .43729 L
.5651 .44201 L
.56603 .44426 L
.56696 .44714 L
.56789 .44789 L
.56882 .45293 L
.56975 .45567 L
.57068 .45917 L
.57161 .45988 L
.57254 .46441 L
.57347 .46605 L
.5744 .46871 L
.57533 .4689 L
.57626 .474 L
.57719 .4765 L
.57813 .48011 L
.57906 .48049 L
.57999 .48495 L
.58092 .48605 L
.58185 .48824 L
Mistroke
.58278 .48748 L
.58371 .4917 L
.58464 .49284 L
.58557 .495 L
.5865 .4935 L
.58743 .49603 L
.58836 .49491 L
.58929 .4949 L
.59022 .49191 L
.59115 .49421 L
.59208 .49349 L
.59301 .49382 L
.59394 .49047 L
.59487 .49127 L
.5958 .4884 L
.59673 .4866 L
.59766 .48209 L
.59859 .48323 L
.59952 .48161 L
.60045 .48086 L
.60138 .4767 L
.60231 .47688 L
.60324 .47359 L
.60417 .47097 L
.6051 .46594 L
.60603 .46696 L
.60696 .46551 L
.60789 .46458 L
.60882 .4605 L
.60975 .46131 L
.61068 .45895 L
.61161 .4572 L
.61254 .45335 L
.61347 .4564 L
.6144 .45728 L
.61533 .45894 L
.61626 .45748 L
.61719 .46164 L
.61812 .46265 L
.61905 .46472 L
.61998 .46454 L
.62091 .47183 L
.62184 .47678 L
.62277 .48296 L
.6237 .48558 L
.62463 .49392 L
.62556 .49846 L
.62649 .50407 L
.62742 .50638 L
.62835 .51549 L
Mistroke
.62928 .52119 L
.63021 .52798 L
.63114 .53045 L
.63207 .53837 L
.633 .54161 L
.63393 .54562 L
.63486 .54511 L
.63579 .55064 L
.63672 .55165 L
.63765 .55373 L
.63858 .55107 L
.63951 .55452 L
.64044 .55318 L
.64137 .55334 L
.6423 .54879 L
.64323 .55101 L
.64416 .54868 L
.64509 .54854 L
.64602 .54378 L
.64695 .54604 L
.64788 .54399 L
.64881 .54474 L
.64974 .54111 L
.65067 .54435 L
.6516 .5435 L
.65253 .54549 L
.65346 .54296 L
.65439 .54595 L
.65532 .5447 L
.65625 .54568 L
.65718 .54218 L
.65811 .54255 L
.65904 .53881 L
.65997 .5363 L
.6609 .5295 L
.66183 .52466 L
.66276 .51589 L
.66369 .50727 L
.66462 .49493 L
.66555 .48336 L
.66648 .4686 L
.66741 .4534 L
.66834 .43563 L
.66927 .41835 L
.6702 .39933 L
.67113 .38013 L
.67206 .36039 L
.67299 .34216 L
.67392 .32404 L
.67485 .306 L
Mistroke
.67578 .28859 L
.67671 .27264 L
.67764 .2581 L
.67857 .24401 L
.6795 .23263 L
.68043 .22376 L
.68136 .21806 L
.68229 .21238 L
.68322 .20936 L
.68415 .20675 L
.68508 .20695 L
.68601 .2061 L
.68694 .20821 L
.68787 .20979 L
.6888 .21459 L
.68973 .21769 L
.69066 .22318 L
.69159 .22603 L
.69252 .23146 L
.69345 .23491 L
.69438 .24067 L
.69531 .24319 L
.69624 .24827 L
.69717 .25163 L
.6981 .25684 L
.69903 .25793 L
.69996 .261 L
.70089 .26293 L
.70182 .26677 L
.70275 .26685 L
.70368 .26895 L
.70461 .27052 L
.70554 .27385 L
.70647 .27349 L
.7074 .2748 L
.70833 .27587 L
.70926 .27864 L
.71019 .27805 L
.71112 .27916 L
.71205 .28024 L
.71298 .28312 L
.71391 .28297 L
.71484 .28435 L
.71577 .28536 L
.7167 .28747 L
.71763 .28586 L
.71856 .28539 L
.71949 .28458 L
.72042 .28553 L
.72135 .28377 L
Mistroke
.72228 .28376 L
.72321 .28339 L
.72414 .28428 L
.72507 .28158 L
.726 .28015 L
.72693 .2783 L
.72786 .27835 L
.72879 .27575 L
.72972 .27506 L
.73065 .27379 L
.73158 .27385 L
.73251 .27021 L
.73344 .26791 L
.73438 .26498 L
.73531 .2641 L
.73624 .26065 L
.73717 .25943 L
.7381 .25782 L
.73903 .25817 L
.73996 .25541 L
.74089 .25462 L
.74182 .25334 L
.74275 .25436 L
.74368 .2527 L
.74461 .25332 L
.74554 .2532 L
.74647 .25498 L
.7474 .25329 L
.74833 .25347 L
.74926 .25274 L
.75019 .25421 L
.75112 .25275 L
.75205 .25354 L
.75298 .25355 L
.75391 .25563 L
.75484 .25453 L
.75577 .25545 L
.7567 .25561 L
.75763 .25792 L
.75856 .25739 L
.75949 .25894 L
.76042 .25977 L
.76135 .2625 L
.76228 .26227 L
.76321 .26382 L
.76414 .26467 L
.76507 .26742 L
.766 .26764 L
.76693 .26967 L
.76786 .2711 L
Mistroke
.76879 .27429 L
.76972 .2751 L
.77065 .2775 L
.77158 .27934 L
.77251 .28276 L
.77344 .28413 L
.77437 .28689 L
.7753 .28911 L
.77623 .29262 L
.77716 .29425 L
.77809 .29697 L
.77902 .29924 L
.77995 .30262 L
.78088 .3046 L
.78181 .30752 L
.78274 .31017 L
.78367 .31375 L
.7846 .31636 L
.78553 .31965 L
.78646 .32273 L
.78739 .32639 L
.78832 .32935 L
.78925 .33263 L
.79018 .3357 L
.79111 .33904 L
.79204 .34205 L
.79297 .34507 L
.7939 .34798 L
.79483 .35086 L
.79576 .35385 L
.79669 .35662 L
.79762 .35956 L
.79855 .36239 L
.79948 .36606 L
.80041 .36936 L
.80134 .37289 L
.80227 .37583 L
.8032 .3797 L
.80413 .38268 L
.80506 .38591 L
.80599 .38836 L
.80692 .39238 L
.80785 .39533 L
.80878 .39854 L
.80971 .40047 L
.81064 .40404 L
.81157 .40616 L
.8125 .40875 L
.81343 .41017 L
.81436 .41424 L
Mistroke
.81529 .41688 L
.81622 .42008 L
.81715 .42146 L
.81808 .42527 L
.81901 .42706 L
.81994 .42952 L
.82087 .43042 L
.8218 .43488 L
.82273 .43749 L
.82366 .44069 L
.82459 .44153 L
.82552 .44536 L
.82645 .44662 L
.82738 .4485 L
.82831 .44839 L
.82924 .45267 L
.83017 .4547 L
.8311 .45738 L
.83203 .45722 L
.83296 .46084 L
.83389 .46149 L
.83482 .46302 L
.83575 .46241 L
.83668 .46742 L
.83761 .47003 L
.83854 .4735 L
.83947 .47376 L
.8404 .4786 L
.84133 .47993 L
.84226 .48204 L
.84319 .48142 L
.84412 .48711 L
.84505 .48981 L
.84598 .49336 L
.84691 .4932 L
.84784 .49857 L
.84877 .50002 L
.8497 .50254 L
.85063 .50195 L
.85156 .50883 L
.85249 .51238 L
.85342 .51723 L
.85435 .51794 L
.85528 .52525 L
.85621 .52808 L
.85714 .53215 L
.85807 .53218 L
.859 .54009 L
.85993 .54379 L
.86086 .54898 L
Mistroke
.86179 .54939 L
.86272 .55722 L
.86365 .56003 L
.86458 .56453 L
.86551 .56421 L
.86644 .57212 L
.86737 .57517 L
.8683 .58024 L
.86923 .57995 L
.87016 .58743 L
.87109 .58945 L
.87202 .59357 L
.87295 .59203 L
.87388 .59818 L
.87481 .5988 L
.87574 .60175 L
.87667 .59892 L
.8776 .60332 L
.87853 .60212 L
.87946 .60327 L
.88039 .59862 L
.88132 .60054 L
.88225 .59696 L
.88318 .59561 L
.88411 .58868 L
.88504 .58751 L
.88597 .58113 L
.8869 .57665 L
.88783 .5669 L
.88876 .56186 L
.88969 .55205 L
.89063 .54381 L
.89156 .53107 L
.89249 .52232 L
.89342 .50977 L
.89435 .49866 L
.89528 .48422 L
.89621 .4732 L
.89714 .45949 L
.89807 .44678 L
.899 .43165 L
.89993 .4188 L
.90086 .40431 L
.90179 .39037 L
.90272 .3756 L
.90365 .36271 L
.90458 .34963 L
.90551 .33643 L
.90644 .32312 L
.90737 .31011 L
Mistroke
.9083 .29771 L
.90923 .28467 L
.91016 .27307 L
.91109 .26168 L
.91202 .25235 L
.91295 .24195 L
.91388 .23343 L
.91481 .22351 L
.91574 .21609 L
.91667 .20745 L
.9176 .20208 L
.91853 .1956 L
.91946 .19284 L
.92039 .18865 L
.92132 .18757 L
.92225 .1836 L
.92318 .183 L
.92411 .1807 L
.92504 .1821 L
.92597 .18071 L
.9269 .18327 L
.92783 .1842 L
.92876 .18842 L
.92969 .18865 L
.93062 .19227 L
.93155 .19438 L
.93248 .19991 L
.93341 .20167 L
.93434 .20696 L
.93527 .21111 L
.9362 .21822 L
.93713 .22095 L
.93806 .22651 L
.93899 .23103 L
.93992 .23809 L
.94085 .24066 L
.94178 .24573 L
.94271 .25003 L
.94364 .25667 L
.94457 .25891 L
.9455 .26324 L
.94643 .26679 L
.94736 .27197 L
.94829 .27236 L
.94922 .27431 L
.95015 .27574 L
.95108 .2791 L
.95201 .27865 L
.95294 .27999 L
.95387 .28093 L
Mistroke
.9548 .28324 L
.95573 .28132 L
.95666 .2807 L
.95759 .27981 L
.95852 .28089 L
.95945 .279 L
.96038 .27891 L
.96131 .27843 L
.96224 .27924 L
.96317 .27625 L
.9641 .27448 L
.96503 .2723 L
.96596 .27223 L
.96689 .26989 L
.96782 .26959 L
.96875 .26887 L
.96968 .26964 L
.97061 .26719 L
.97154 .26621 L
.97247 .26477 L
.9734 .26559 L
.97433 .26454 L
.97526 .26569 L
.97619 .26626 L
Mfstroke
[ .02 ] 0 setdash
.02474 .28972 m
.02567 .29034 L
.0266 .29086 L
.02753 .29128 L
.02846 .2916 L
.02939 .29183 L
.03032 .29196 L
.03125 .29199 L
.03218 .29194 L
.03311 .2918 L
.03404 .29157 L
.03497 .29127 L
.0359 .2909 L
.03683 .29046 L
.03776 .28997 L
.03869 .28944 L
.03962 .28886 L
.04055 .28825 L
.04148 .28761 L
.04241 .28695 L
.04334 .28627 L
.04427 .28558 L
.0452 .28488 L
.04613 .28416 L
.04706 .28341 L
.04799 .28264 L
.04892 .28183 L
.04985 .28095 L
.05078 .27998 L
.05171 .27889 L
.05264 .27763 L
.05357 .27617 L
.0545 .27443 L
.05543 .27236 L
.05636 .26987 L
.05729 .26687 L
.05822 .26327 L
.05915 .25894 L
.06008 .25379 L
.06101 .2477 L
.06194 .24057 L
.06287 .23232 L
.0638 .22289 L
.06473 .21228 L
.06566 .20053 L
.06659 .18775 L
.06752 .17411 L
.06845 .15985 L
.06938 .14525 L
.07031 .13063 L
Mistroke
.07124 .11631 L
.07217 .10259 L
.0731 .08973 L
.07403 .07793 L
.07496 .06733 L
.07589 .058 L
.07682 .04996 L
.07775 .04317 L
.07868 .03756 L
.07961 .03303 L
.08054 .02949 L
.08147 .02683 L
.0824 .02492 L
.08333 .02367 L
.08426 .02299 L
.08519 .02279 L
.08612 .023 L
.08705 .02355 L
.08798 .02438 L
.08891 .02545 L
.08984 .02671 L
.09077 .02814 L
.0917 .02971 L
.09263 .03138 L
.09356 .03315 L
.09449 .03499 L
.09542 .0369 L
.09635 .03885 L
.09728 .04085 L
.09821 .04288 L
.09914 .04494 L
.10007 .04702 L
.101 .04912 L
.10193 .05123 L
.10286 .05336 L
.10379 .0555 L
.10472 .05764 L
.10565 .05979 L
.10658 .06195 L
.10751 .06411 L
.10844 .06627 L
.10938 .06843 L
.11031 .0706 L
.11124 .07277 L
.11217 .07494 L
.1131 .07711 L
.11403 .07928 L
.11496 .08145 L
.11589 .08362 L
.11682 .08579 L
Mistroke
.11775 .08796 L
.11868 .09013 L
.11961 .09231 L
.12054 .09448 L
.12147 .09665 L
.1224 .09882 L
.12333 .101 L
.12426 .10317 L
.12519 .10534 L
.12612 .10752 L
.12705 .10969 L
.12798 .11187 L
.12891 .11405 L
.12984 .11623 L
.13077 .11841 L
.1317 .12059 L
.13263 .12277 L
.13356 .12495 L
.13449 .12714 L
.13542 .12933 L
.13635 .13152 L
.13728 .13371 L
.13821 .1359 L
.13914 .1381 L
.14007 .1403 L
.141 .1425 L
.14193 .1447 L
.14286 .14691 L
.14379 .14912 L
.14472 .15134 L
.14565 .15355 L
.14658 .15577 L
.14751 .158 L
.14844 .16022 L
.14937 .16245 L
.1503 .16469 L
.15123 .16693 L
.15216 .16917 L
.15309 .17142 L
.15402 .17367 L
.15495 .17592 L
.15588 .17818 L
.15681 .18044 L
.15774 .18271 L
.15867 .18498 L
.1596 .18726 L
.16053 .18954 L
.16146 .19183 L
.16239 .19412 L
.16332 .19641 L
Mistroke
.16425 .19871 L
.16518 .20101 L
.16611 .20332 L
.16704 .20564 L
.16797 .20795 L
.1689 .21028 L
.16983 .21261 L
.17076 .21494 L
.17169 .21728 L
.17262 .21962 L
.17355 .22196 L
.17448 .22432 L
.17541 .22667 L
.17634 .22903 L
.17727 .2314 L
.1782 .23377 L
.17913 .23615 L
.18006 .23853 L
.18099 .24091 L
.18192 .2433 L
.18285 .24569 L
.18378 .24809 L
.18471 .25049 L
.18564 .2529 L
.18657 .25531 L
.1875 .25773 L
.18843 .26014 L
.18936 .26257 L
.19029 .265 L
.19122 .26743 L
.19215 .26987 L
.19308 .27231 L
.19401 .27475 L
.19494 .2772 L
.19587 .27965 L
.1968 .28211 L
.19773 .28456 L
.19866 .28703 L
.19959 .28949 L
.20052 .29197 L
.20145 .29444 L
.20238 .29692 L
.20331 .2994 L
.20424 .30188 L
.20517 .30437 L
.2061 .30686 L
.20703 .30935 L
.20796 .31185 L
.20889 .31435 L
.20982 .31685 L
Mistroke
.21075 .31936 L
.21168 .32187 L
.21261 .32438 L
.21354 .32689 L
.21447 .32941 L
.2154 .33193 L
.21633 .33445 L
.21726 .33697 L
.21819 .3395 L
.21912 .34203 L
.22005 .34456 L
.22098 .3471 L
.22191 .34963 L
.22284 .35217 L
.22377 .35471 L
.2247 .35725 L
.22563 .35979 L
.22656 .36234 L
.22749 .36489 L
.22842 .36744 L
.22935 .36999 L
.23028 .37254 L
.23121 .37509 L
.23214 .37764 L
.23307 .3802 L
.234 .38275 L
.23493 .38531 L
.23586 .38786 L
.23679 .39042 L
.23772 .39298 L
.23865 .39553 L
.23958 .39809 L
.24051 .40064 L
.24144 .40319 L
.24237 .40574 L
.2433 .40829 L
.24423 .41083 L
.24516 .41336 L
.24609 .4159 L
.24702 .41842 L
.24795 .42094 L
.24888 .42345 L
.24981 .42594 L
.25074 .42842 L
.25167 .43089 L
.2526 .43334 L
.25353 .43576 L
.25446 .43816 L
.25539 .44053 L
.25632 .44286 L
Mistroke
.25725 .44514 L
.25818 .44738 L
.25911 .44956 L
.26004 .45167 L
.26097 .4537 L
.2619 .45563 L
.26283 .45746 L
.26376 .45916 L
.26469 .46072 L
.26563 .4621 L
.26656 .46329 L
.26749 .46425 L
.26842 .46496 L
.26935 .46537 L
.27028 .46545 L
.27121 .46515 L
.27214 .46444 L
.27307 .46325 L
.274 .46155 L
.27493 .45929 L
.27586 .45642 L
.27679 .45292 L
.27772 .44876 L
.27865 .44393 L
.27958 .43843 L
.28051 .43229 L
.28144 .42556 L
.28237 .4183 L
.2833 .41062 L
.28423 .40263 L
.28516 .39445 L
.28609 .38623 L
.28702 .3781 L
.28795 .3702 L
.28888 .36266 L
.28981 .35558 L
.29074 .34905 L
.29167 .34313 L
.2926 .33786 L
.29353 .33326 L
.29446 .32932 L
.29539 .32605 L
.29632 .32339 L
.29725 .32132 L
.29818 .3198 L
.29911 .31877 L
.30004 .31819 L
.30097 .31802 L
.3019 .31821 L
.30283 .31871 L
Mistroke
.30376 .3195 L
.30469 .32053 L
.30562 .32177 L
.30655 .3232 L
.30748 .32479 L
.30841 .32652 L
.30934 .32837 L
.31027 .33032 L
.3112 .33236 L
.31213 .33448 L
.31306 .33666 L
.31399 .33889 L
.31492 .34118 L
.31585 .3435 L
.31678 .34585 L
.31771 .34824 L
.31864 .35065 L
.31957 .35308 L
.3205 .35552 L
.32143 .35798 L
.32236 .36045 L
.32329 .36293 L
.32422 .36542 L
.32515 .36791 L
.32608 .3704 L
.32701 .3729 L
.32794 .3754 L
.32887 .37789 L
.3298 .38039 L
.33073 .38288 L
.33166 .38536 L
.33259 .38784 L
.33352 .39031 L
.33445 .39278 L
.33538 .39523 L
.33631 .39767 L
.33724 .40009 L
.33817 .4025 L
.3391 .4049 L
.34003 .40727 L
.34096 .40962 L
.34189 .41195 L
.34282 .41425 L
.34375 .41651 L
.34468 .41875 L
.34561 .42094 L
.34654 .42309 L
.34747 .4252 L
.3484 .42725 L
.34933 .42925 L
Mistroke
.35026 .43118 L
.35119 .43303 L
.35212 .43481 L
.35305 .4365 L
.35398 .43809 L
.35491 .43957 L
.35584 .44093 L
.35677 .44215 L
.3577 .44322 L
.35863 .44413 L
.35956 .44484 L
.36049 .44535 L
.36142 .44563 L
.36235 .44564 L
.36328 .44537 L
.36421 .44477 L
.36514 .44381 L
.36607 .44244 L
.367 .44063 L
.36793 .43831 L
.36886 .43544 L
.36979 .43196 L
.37072 .4278 L
.37165 .42292 L
.37258 .41725 L
.37351 .41074 L
.37444 .40335 L
.37537 .39506 L
.3763 .38586 L
.37723 .37579 L
.37816 .3649 L
.37909 .35327 L
.38002 .34105 L
.38095 .32838 L
.38188 .31546 L
.38281 .30248 L
.38374 .28966 L
.38467 .2772 L
.3856 .26528 L
.38653 .25405 L
.38746 .24365 L
.38839 .23416 L
.38932 .22561 L
.39025 .21804 L
.39118 .21143 L
.39211 .20575 L
.39304 .20093 L
.39397 .19693 L
.3949 .19368 L
.39583 .1911 L
Mistroke
.39676 .18912 L
.39769 .18769 L
.39862 .18673 L
.39955 .18619 L
.40048 .18602 L
.40141 .18617 L
.40234 .1866 L
.40327 .18726 L
.4042 .18814 L
.40513 .1892 L
.40606 .19042 L
.40699 .19177 L
.40792 .19323 L
.40885 .1948 L
.40978 .19645 L
.41071 .19818 L
.41164 .19996 L
.41257 .20181 L
.4135 .20369 L
.41443 .20562 L
.41536 .20758 L
.41629 .20957 L
.41722 .21159 L
.41815 .21362 L
.41908 .21567 L
.42001 .21774 L
.42094 .21982 L
.42188 .2219 L
.42281 .224 L
.42374 .2261 L
.42467 .2282 L
.4256 .23031 L
.42653 .23242 L
.42746 .23454 L
.42839 .23665 L
.42932 .23876 L
.43025 .24087 L
.43118 .24297 L
.43211 .24508 L
.43304 .24717 L
.43397 .24927 L
.4349 .25136 L
.43583 .25344 L
.43676 .25552 L
.43769 .25759 L
.43862 .25965 L
.43955 .2617 L
.44048 .26375 L
.44141 .26578 L
.44234 .26781 L
Mistroke
.44327 .26982 L
.4442 .27182 L
.44513 .27381 L
.44606 .27578 L
.44699 .27775 L
.44792 .27969 L
.44885 .28162 L
.44978 .28353 L
.45071 .28543 L
.45164 .28731 L
.45257 .28917 L
.4535 .291 L
.45443 .29282 L
.45536 .29461 L
.45629 .29638 L
.45722 .29813 L
.45815 .29985 L
.45908 .30154 L
.46001 .30321 L
.46094 .30484 L
.46187 .30645 L
.4628 .30803 L
.46373 .30958 L
.46466 .31109 L
.46559 .31257 L
.46652 .31402 L
.46745 .31544 L
.46838 .31681 L
.46931 .31816 L
.47024 .31947 L
.47117 .32074 L
.4721 .32197 L
.47303 .32317 L
.47396 .32434 L
.47489 .32547 L
.47582 .32656 L
.47675 .32762 L
.47768 .32865 L
.47861 .32964 L
.47954 .3306 L
.48047 .33153 L
.4814 .33244 L
.48233 .33331 L
.48326 .33417 L
.48419 .335 L
.48512 .33581 L
.48605 .3366 L
.48698 .33738 L
.48791 .33814 L
.48884 .3389 L
Mistroke
.48977 .33965 L
.4907 .34039 L
.49163 .34114 L
.49256 .34188 L
.49349 .34263 L
.49442 .3434 L
.49535 .34417 L
.49628 .34495 L
.49721 .34576 L
.49814 .34658 L
.49907 .34742 L
.5 .34829 L
.50093 .34919 L
.50186 .35011 L
.50279 .35106 L
.50372 .35205 L
.50465 .35307 L
.50558 .35412 L
.50651 .35521 L
.50744 .35634 L
.50837 .3575 L
.5093 .3587 L
.51023 .35994 L
.51116 .36121 L
.51209 .36253 L
.51302 .36388 L
.51395 .36527 L
.51488 .3667 L
.51581 .36816 L
.51674 .36966 L
.51767 .37119 L
.5186 .37275 L
.51953 .37435 L
.52046 .37598 L
.52139 .37764 L
.52232 .37933 L
.52325 .38104 L
.52418 .38278 L
.52511 .38454 L
.52604 .38633 L
.52697 .38814 L
.5279 .38996 L
.52883 .39181 L
.52976 .39366 L
.53069 .39554 L
.53162 .39742 L
.53255 .39931 L
.53348 .40122 L
.53441 .40312 L
.53534 .40503 L
Mistroke
.53627 .40695 L
.5372 .40886 L
.53813 .41077 L
.53906 .41267 L
.53999 .41456 L
.54092 .41645 L
.54185 .41832 L
.54278 .42017 L
.54371 .42201 L
.54464 .42382 L
.54557 .42561 L
.5465 .42737 L
.54743 .4291 L
.54836 .4308 L
.54929 .43246 L
.55022 .43407 L
.55115 .43564 L
.55208 .43717 L
.55301 .43864 L
.55394 .44006 L
.55487 .44142 L
.5558 .44271 L
.55673 .44394 L
.55766 .4451 L
.55859 .44619 L
.55952 .4472 L
.56045 .44814 L
.56138 .449 L
.56231 .44977 L
.56324 .45046 L
.56417 .45106 L
.5651 .45158 L
.56603 .45202 L
.56696 .45237 L
.56789 .45263 L
.56882 .45282 L
.56975 .45293 L
.57068 .45297 L
.57161 .45293 L
.57254 .45284 L
.57347 .45268 L
.5744 .45248 L
.57533 .45224 L
.57626 .45196 L
.57719 .45165 L
.57813 .45133 L
.57906 .451 L
.57999 .45068 L
.58092 .45037 L
.58185 .45007 L
Mistroke
.58278 .44981 L
.58371 .44959 L
.58464 .44941 L
.58557 .44929 L
.5865 .44923 L
.58743 .44924 L
.58836 .44932 L
.58929 .44948 L
.59022 .44972 L
.59115 .45004 L
.59208 .45045 L
.59301 .45096 L
.59394 .45155 L
.59487 .45223 L
.5958 .453 L
.59673 .45386 L
.59766 .45481 L
.59859 .45584 L
.59952 .45695 L
.60045 .45815 L
.60138 .45942 L
.60231 .46078 L
.60324 .4622 L
.60417 .46369 L
.6051 .46525 L
.60603 .46687 L
.60696 .46855 L
.60789 .47029 L
.60882 .47208 L
.60975 .47392 L
.61068 .47581 L
.61161 .47774 L
.61254 .47972 L
.61347 .48174 L
.6144 .48379 L
.61533 .48587 L
.61626 .48799 L
.61719 .49014 L
.61812 .49232 L
.61905 .49452 L
.61998 .49675 L
.62091 .499 L
.62184 .50127 L
.62277 .50356 L
.6237 .50587 L
.62463 .50819 L
.62556 .51053 L
.62649 .51288 L
.62742 .51525 L
.62835 .51763 L
Mistroke
.62928 .52001 L
.63021 .52241 L
.63114 .52481 L
.63207 .52722 L
.633 .52964 L
.63393 .53206 L
.63486 .53448 L
.63579 .53691 L
.63672 .53933 L
.63765 .54176 L
.63858 .54418 L
.63951 .5466 L
.64044 .54902 L
.64137 .55142 L
.6423 .55381 L
.64323 .55618 L
.64416 .55853 L
.64509 .56085 L
.64602 .56313 L
.64695 .56536 L
.64788 .56753 L
.64881 .56962 L
.64974 .57161 L
.65067 .57347 L
.6516 .57516 L
.65253 .57664 L
.65346 .57785 L
.65439 .57872 L
.65532 .57915 L
.65625 .57902 L
.65718 .5782 L
.65811 .5765 L
.65904 .57371 L
.65997 .56959 L
.6609 .56385 L
.66183 .55618 L
.66276 .54629 L
.66369 .53389 L
.66462 .51878 L
.66555 .50091 L
.66648 .48039 L
.66741 .45758 L
.66834 .43308 L
.66927 .40769 L
.6702 .38232 L
.67113 .35788 L
.67206 .33515 L
.67299 .31473 L
.67392 .29696 L
.67485 .28196 L
Mistroke
.67578 .26966 L
.67671 .25985 L
.67764 .25226 L
.67857 .24657 L
.6795 .24249 L
.68043 .23973 L
.68136 .23804 L
.68229 .23722 L
.68322 .23709 L
.68415 .23749 L
.68508 .23833 L
.68601 .2395 L
.68694 .24093 L
.68787 .24256 L
.6888 .24434 L
.68973 .24624 L
.69066 .24823 L
.69159 .25029 L
.69252 .25239 L
.69345 .25452 L
.69438 .25667 L
.69531 .25883 L
.69624 .26099 L
.69717 .26314 L
.6981 .26527 L
.69903 .26738 L
.69996 .26946 L
.70089 .2715 L
.70182 .2735 L
.70275 .27545 L
.70368 .27735 L
.70461 .27918 L
.70554 .28094 L
.70647 .28262 L
.7074 .28422 L
.70833 .28572 L
.70926 .28711 L
.71019 .28839 L
.71112 .28954 L
.71205 .29056 L
.71298 .29144 L
.71391 .29215 L
.71484 .29271 L
.71577 .29308 L
.7167 .29327 L
.71763 .29326 L
.71856 .29305 L
.71949 .29264 L
.72042 .292 L
.72135 .29116 L
Mistroke
.72228 .2901 L
.72321 .28882 L
.72414 .28734 L
.72507 .28567 L
.726 .28381 L
.72693 .28178 L
.72786 .27962 L
.72879 .27733 L
.72972 .27494 L
.73065 .27249 L
.73158 .27 L
.73251 .2675 L
.73344 .26503 L
.73438 .26261 L
.73531 .26028 L
.73624 .25807 L
.73717 .25599 L
.7381 .25407 L
.73903 .25233 L
.73996 .25078 L
.74089 .24943 L
.74182 .2483 L
.74275 .24738 L
.74368 .24669 L
.74461 .2462 L
.74554 .24594 L
.74647 .24588 L
.7474 .24602 L
.74833 .24636 L
.74926 .24688 L
.75019 .24757 L
.75112 .24843 L
.75205 .24944 L
.75298 .2506 L
.75391 .25189 L
.75484 .2533 L
.75577 .25482 L
.7567 .25645 L
.75763 .25818 L
.75856 .25999 L
.75949 .26188 L
.76042 .26385 L
.76135 .26588 L
.76228 .26797 L
.76321 .27012 L
.76414 .27232 L
.76507 .27456 L
.766 .27684 L
.76693 .27916 L
.76786 .28151 L
Mistroke
.76879 .2839 L
.76972 .28631 L
.77065 .28874 L
.77158 .2912 L
.77251 .29368 L
.77344 .29617 L
.77437 .29868 L
.7753 .30121 L
.77623 .30375 L
.77716 .3063 L
.77809 .30886 L
.77902 .31143 L
.77995 .31401 L
.78088 .3166 L
.78181 .3192 L
.78274 .3218 L
.78367 .3244 L
.7846 .32702 L
.78553 .32963 L
.78646 .33225 L
.78739 .33488 L
.78832 .3375 L
.78925 .34013 L
.79018 .34277 L
.79111 .3454 L
.79204 .34804 L
.79297 .35068 L
.7939 .35332 L
.79483 .35596 L
.79576 .3586 L
.79669 .36125 L
.79762 .36389 L
.79855 .36654 L
.79948 .36918 L
.80041 .37183 L
.80134 .37447 L
.80227 .37712 L
.8032 .37977 L
.80413 .38241 L
.80506 .38506 L
.80599 .3877 L
.80692 .39035 L
.80785 .39299 L
.80878 .39564 L
.80971 .39828 L
.81064 .40093 L
.81157 .40357 L
.8125 .40621 L
.81343 .40885 L
.81436 .41149 L
Mistroke
.81529 .41413 L
.81622 .41677 L
.81715 .4194 L
.81808 .42204 L
.81901 .42467 L
.81994 .4273 L
.82087 .42994 L
.8218 .43257 L
.82273 .43519 L
.82366 .43782 L
.82459 .44045 L
.82552 .44307 L
.82645 .44569 L
.82738 .44831 L
.82831 .45093 L
.82924 .45355 L
.83017 .45616 L
.8311 .45878 L
.83203 .46139 L
.83296 .464 L
.83389 .46661 L
.83482 .46921 L
.83575 .47181 L
.83668 .47441 L
.83761 .47701 L
.83854 .47961 L
.83947 .4822 L
.8404 .48479 L
.84133 .48738 L
.84226 .48997 L
.84319 .49255 L
.84412 .49513 L
.84505 .49771 L
.84598 .50028 L
.84691 .50286 L
.84784 .50543 L
.84877 .50799 L
.8497 .51055 L
.85063 .51311 L
.85156 .51567 L
.85249 .51823 L
.85342 .52078 L
.85435 .52332 L
.85528 .52587 L
.85621 .52841 L
.85714 .53094 L
.85807 .53347 L
.859 .536 L
.85993 .53853 L
.86086 .54105 L
Mistroke
.86179 .54356 L
.86272 .54607 L
.86365 .54858 L
.86458 .55108 L
.86551 .55357 L
.86644 .55606 L
.86737 .55854 L
.8683 .56101 L
.86923 .56347 L
.87016 .56592 L
.87109 .56836 L
.87202 .57078 L
.87295 .57318 L
.87388 .57556 L
.87481 .57791 L
.87574 .58022 L
.87667 .58249 L
.8776 .5847 L
.87853 .58683 L
.87946 .58888 L
.88039 .59081 L
.88132 .59259 L
.88225 .59419 L
.88318 .59555 L
.88411 .5966 L
.88504 .59727 L
.88597 .59746 L
.8869 .59704 L
.88783 .59585 L
.88876 .5937 L
.88969 .59038 L
.89063 .58561 L
.89156 .57912 L
.89249 .57059 L
.89342 .55972 L
.89435 .54625 L
.89528 .53002 L
.89621 .51101 L
.89714 .48938 L
.89807 .46556 L
.899 .44019 L
.89993 .41406 L
.90086 .3881 L
.90179 .36314 L
.90272 .33993 L
.90365 .31898 L
.90458 .30056 L
.90551 .28475 L
.90644 .27142 L
.90737 .26038 L
Mistroke
.9083 .25134 L
.90923 .24401 L
.91016 .23809 L
.91109 .23334 L
.91202 .22952 L
.91295 .22645 L
.91388 .22397 L
.91481 .22196 L
.91574 .22032 L
.91667 .21898 L
.9176 .21789 L
.91853 .21699 L
.91946 .21626 L
.92039 .21568 L
.92132 .21523 L
.92225 .21489 L
.92318 .21467 L
.92411 .21456 L
.92504 .21455 L
.92597 .21464 L
.9269 .21483 L
.92783 .21511 L
.92876 .2155 L
.92969 .21598 L
.93062 .21655 L
.93155 .21722 L
.93248 .21798 L
.93341 .21883 L
.93434 .21976 L
.93527 .22078 L
.9362 .22187 L
.93713 .22305 L
.93806 .22429 L
.93899 .2256 L
.93992 .22698 L
.94085 .22841 L
.94178 .22991 L
.94271 .23146 L
.94364 .23305 L
.94457 .23469 L
.9455 .23637 L
.94643 .23809 L
.94736 .23984 L
.94829 .24161 L
.94922 .24342 L
.95015 .24524 L
.95108 .24708 L
.95201 .24894 L
.95294 .2508 L
.95387 .25267 L
Mistroke
.9548 .25454 L
.95573 .25641 L
.95666 .25828 L
.95759 .26014 L
.95852 .26198 L
.95945 .2638 L
.96038 .26561 L
.96131 .26739 L
.96224 .26914 L
.96317 .27086 L
.9641 .27254 L
.96503 .27418 L
.96596 .27577 L
.96689 .27731 L
.96782 .2788 L
.96875 .28023 L
.96968 .28159 L
.97061 .28289 L
.97154 .28411 L
.97247 .28526 L
.9734 .28633 L
.97433 .28731 L
.97526 .28821 L
.97619 .28901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["\<\
We compress the Fourier coefficients with the same compression \
ratio.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.67"}],

Cell["Chop[InverseFourier[Compress[fdata, 20]]];", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S2.1.1"],

Cell["\<\
The reconstructed (solid line) and original (dashed line) signals \
are plotted. The reconstruction is clearly inferior to that obtained in the \
case of wavelets for the same compression ratio.\
\>", "MathCaption",
  CellTags->{"S2.1.1", "1.68"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[%, PlotJoined -> True,
 PlotLabel -> \"u(x), compression ratio 1024/20\"],
 ListPlot[data, PlotJoined -> True,
 PlotStyle->Dashing[{0.02}]]}]]\
\>", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S2.1.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00093006 0.346518 0.558838 [
[.20982 .33402 -9 -9 ]
[.20982 .33402 9 0 ]
[.39583 .33402 -9 -9 ]
[.39583 .33402 9 0 ]
[.58185 .33402 -9 -9 ]
[.58185 .33402 9 0 ]
[.76786 .33402 -9 -9 ]
[.76786 .33402 9 0 ]
[.95387 .33402 -12 -9 ]
[.95387 .33402 12 0 ]
[.01131 .01122 -24 -4.5 ]
[.01131 .01122 0 4.5 ]
[.01131 .12298 -24 -4.5 ]
[.01131 .12298 0 4.5 ]
[.01131 .23475 -24 -4.5 ]
[.01131 .23475 0 4.5 ]
[.01131 .45829 -18 -4.5 ]
[.01131 .45829 0 4.5 ]
[.01131 .57005 -18 -4.5 ]
[.01131 .57005 0 4.5 ]
[.5 .63053 -93 0 ]
[.5 .63053 93 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .34652 m
.20982 .35277 L
s
[(200)] .20982 .33402 0 1 Mshowa
.39583 .34652 m
.39583 .35277 L
s
[(400)] .39583 .33402 0 1 Mshowa
.58185 .34652 m
.58185 .35277 L
s
[(600)] .58185 .33402 0 1 Mshowa
.76786 .34652 m
.76786 .35277 L
s
[(800)] .76786 .33402 0 1 Mshowa
.95387 .34652 m
.95387 .35277 L
s
[(1000)] .95387 .33402 0 1 Mshowa
.125 Mabswid
.07031 .34652 m
.07031 .35027 L
s
.11682 .34652 m
.11682 .35027 L
s
.16332 .34652 m
.16332 .35027 L
s
.25632 .34652 m
.25632 .35027 L
s
.30283 .34652 m
.30283 .35027 L
s
.34933 .34652 m
.34933 .35027 L
s
.44234 .34652 m
.44234 .35027 L
s
.48884 .34652 m
.48884 .35027 L
s
.53534 .34652 m
.53534 .35027 L
s
.62835 .34652 m
.62835 .35027 L
s
.67485 .34652 m
.67485 .35027 L
s
.72135 .34652 m
.72135 .35027 L
s
.81436 .34652 m
.81436 .35027 L
s
.86086 .34652 m
.86086 .35027 L
s
.90737 .34652 m
.90737 .35027 L
s
.25 Mabswid
0 .34652 m
1 .34652 L
s
.02381 .01122 m
.03006 .01122 L
s
[(-0.6)] .01131 .01122 1 0 Mshowa
.02381 .12298 m
.03006 .12298 L
s
[(-0.4)] .01131 .12298 1 0 Mshowa
.02381 .23475 m
.03006 .23475 L
s
[(-0.2)] .01131 .23475 1 0 Mshowa
.02381 .45829 m
.03006 .45829 L
s
[(0.2)] .01131 .45829 1 0 Mshowa
.02381 .57005 m
.03006 .57005 L
s
[(0.4)] .01131 .57005 1 0 Mshowa
.125 Mabswid
.02381 .03916 m
.02756 .03916 L
s
.02381 .0671 m
.02756 .0671 L
s
.02381 .09504 m
.02756 .09504 L
s
.02381 .15093 m
.02756 .15093 L
s
.02381 .17887 m
.02756 .17887 L
s
.02381 .20681 m
.02756 .20681 L
s
.02381 .26269 m
.02756 .26269 L
s
.02381 .29063 m
.02756 .29063 L
s
.02381 .31858 m
.02756 .31858 L
s
.02381 .37446 m
.02756 .37446 L
s
.02381 .4024 m
.02756 .4024 L
s
.02381 .43034 m
.02756 .43034 L
s
.02381 .48623 m
.02756 .48623 L
s
.02381 .51417 m
.02756 .51417 L
s
.02381 .54211 m
.02756 .54211 L
s
.02381 .598 m
.02756 .598 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\), compression ratio 1024/20)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02474 .31287 m
.02567 .31179 L
.0266 .31049 L
.02753 .30895 L
.02846 .3072 L
.02939 .30521 L
.03032 .303 L
.03125 .30056 L
.03218 .2979 L
.03311 .29502 L
.03404 .29193 L
.03497 .28862 L
.0359 .2851 L
.03683 .28138 L
.03776 .27746 L
.03869 .27335 L
.03962 .26905 L
.04055 .26457 L
.04148 .25992 L
.04241 .25511 L
.04334 .25014 L
.04427 .24503 L
.0452 .23978 L
.04613 .2344 L
.04706 .22891 L
.04799 .2233 L
.04892 .2176 L
.04985 .21182 L
.05078 .20596 L
.05171 .20003 L
.05264 .19405 L
.05357 .18803 L
.0545 .18198 L
.05543 .17592 L
.05636 .16984 L
.05729 .16377 L
.05822 .15772 L
.05915 .1517 L
.06008 .14571 L
.06101 .13978 L
.06194 .1339 L
.06287 .12811 L
.0638 .12239 L
.06473 .11677 L
.06566 .11126 L
.06659 .10586 L
.06752 .10059 L
.06845 .09545 L
.06938 .09045 L
.07031 .08561 L
Mistroke
.07124 .08093 L
.07217 .07642 L
.0731 .07208 L
.07403 .06793 L
.07496 .06396 L
.07589 .0602 L
.07682 .05663 L
.07775 .05328 L
.07868 .05013 L
.07961 .0472 L
.08054 .04449 L
.08147 .042 L
.0824 .03974 L
.08333 .03771 L
.08426 .0359 L
.08519 .03432 L
.08612 .03297 L
.08705 .03185 L
.08798 .03096 L
.08891 .0303 L
.08984 .02987 L
.09077 .02965 L
.0917 .02966 L
.09263 .02989 L
.09356 .03033 L
.09449 .03097 L
.09542 .03183 L
.09635 .03288 L
.09728 .03413 L
.09821 .03557 L
.09914 .03719 L
.10007 .03898 L
.101 .04095 L
.10193 .04307 L
.10286 .04535 L
.10379 .04778 L
.10472 .05035 L
.10565 .05305 L
.10658 .05586 L
.10751 .0588 L
.10844 .06184 L
.10938 .06497 L
.11031 .06819 L
.11124 .07149 L
.11217 .07487 L
.1131 .0783 L
.11403 .08178 L
.11496 .08531 L
.11589 .08887 L
.11682 .09246 L
Mistroke
.11775 .09607 L
.11868 .09968 L
.11961 .1033 L
.12054 .10691 L
.12147 .1105 L
.1224 .11408 L
.12333 .11762 L
.12426 .12112 L
.12519 .12459 L
.12612 .128 L
.12705 .13136 L
.12798 .13466 L
.12891 .13789 L
.12984 .14105 L
.13077 .14413 L
.1317 .14713 L
.13263 .15005 L
.13356 .15288 L
.13449 .15562 L
.13542 .15826 L
.13635 .16081 L
.13728 .16327 L
.13821 .16562 L
.13914 .16788 L
.14007 .17004 L
.141 .17209 L
.14193 .17405 L
.14286 .17591 L
.14379 .17767 L
.14472 .17933 L
.14565 .1809 L
.14658 .18238 L
.14751 .18377 L
.14844 .18508 L
.14937 .1863 L
.1503 .18744 L
.15123 .18851 L
.15216 .18951 L
.15309 .19044 L
.15402 .19131 L
.15495 .19213 L
.15588 .19289 L
.15681 .19361 L
.15774 .19429 L
.15867 .19493 L
.1596 .19555 L
.16053 .19614 L
.16146 .19672 L
.16239 .19729 L
.16332 .19786 L
Mistroke
.16425 .19842 L
.16518 .199 L
.16611 .19959 L
.16704 .2002 L
.16797 .20084 L
.1689 .20152 L
.16983 .20223 L
.17076 .20299 L
.17169 .20379 L
.17262 .20466 L
.17355 .20558 L
.17448 .20657 L
.17541 .20763 L
.17634 .20877 L
.17727 .20999 L
.1782 .21129 L
.17913 .21268 L
.18006 .21416 L
.18099 .21573 L
.18192 .2174 L
.18285 .21917 L
.18378 .22105 L
.18471 .22302 L
.18564 .2251 L
.18657 .22729 L
.1875 .22958 L
.18843 .23198 L
.18936 .23448 L
.19029 .2371 L
.19122 .23981 L
.19215 .24263 L
.19308 .24556 L
.19401 .24858 L
.19494 .2517 L
.19587 .25492 L
.1968 .25824 L
.19773 .26164 L
.19866 .26512 L
.19959 .26869 L
.20052 .27234 L
.20145 .27606 L
.20238 .27985 L
.20331 .2837 L
.20424 .28761 L
.20517 .29157 L
.2061 .29557 L
.20703 .29962 L
.20796 .3037 L
.20889 .30781 L
.20982 .31194 L
Mistroke
.21075 .31609 L
.21168 .32024 L
.21261 .3244 L
.21354 .32855 L
.21447 .33268 L
.2154 .3368 L
.21633 .34089 L
.21726 .34495 L
.21819 .34897 L
.21912 .35294 L
.22005 .35685 L
.22098 .36071 L
.22191 .3645 L
.22284 .36822 L
.22377 .37186 L
.2247 .37541 L
.22563 .37887 L
.22656 .38224 L
.22749 .3855 L
.22842 .38866 L
.22935 .39171 L
.23028 .39464 L
.23121 .39745 L
.23214 .40013 L
.23307 .40269 L
.234 .40512 L
.23493 .40741 L
.23586 .40957 L
.23679 .41158 L
.23772 .41346 L
.23865 .41519 L
.23958 .41678 L
.24051 .41823 L
.24144 .41953 L
.24237 .42069 L
.2433 .4217 L
.24423 .42257 L
.24516 .42329 L
.24609 .42388 L
.24702 .42433 L
.24795 .42463 L
.24888 .42481 L
.24981 .42485 L
.25074 .42477 L
.25167 .42456 L
.2526 .42423 L
.25353 .42379 L
.25446 .42323 L
.25539 .42256 L
.25632 .4218 L
Mistroke
.25725 .42093 L
.25818 .41998 L
.25911 .41893 L
.26004 .41781 L
.26097 .41662 L
.2619 .41535 L
.26283 .41403 L
.26376 .41265 L
.26469 .41122 L
.26563 .40975 L
.26656 .40825 L
.26749 .40671 L
.26842 .40516 L
.26935 .40359 L
.27028 .40201 L
.27121 .40043 L
.27214 .39886 L
.27307 .39729 L
.274 .39575 L
.27493 .39423 L
.27586 .39274 L
.27679 .39128 L
.27772 .38987 L
.27865 .38851 L
.27958 .3872 L
.28051 .38595 L
.28144 .38476 L
.28237 .38364 L
.2833 .38259 L
.28423 .38161 L
.28516 .38072 L
.28609 .37991 L
.28702 .37918 L
.28795 .37855 L
.28888 .378 L
.28981 .37755 L
.29074 .3772 L
.29167 .37694 L
.2926 .37678 L
.29353 .37671 L
.29446 .37675 L
.29539 .37688 L
.29632 .37711 L
.29725 .37744 L
.29818 .37786 L
.29911 .37838 L
.30004 .37898 L
.30097 .37968 L
.3019 .38046 L
.30283 .38133 L
Mistroke
.30376 .38228 L
.30469 .3833 L
.30562 .38439 L
.30655 .38556 L
.30748 .38678 L
.30841 .38807 L
.30934 .38941 L
.31027 .39079 L
.3112 .39222 L
.31213 .39368 L
.31306 .39518 L
.31399 .3967 L
.31492 .39824 L
.31585 .39979 L
.31678 .40134 L
.31771 .40289 L
.31864 .40444 L
.31957 .40596 L
.3205 .40747 L
.32143 .40895 L
.32236 .41039 L
.32329 .41179 L
.32422 .41313 L
.32515 .41443 L
.32608 .41565 L
.32701 .41681 L
.32794 .4179 L
.32887 .4189 L
.3298 .41981 L
.33073 .42063 L
.33166 .42135 L
.33259 .42196 L
.33352 .42246 L
.33445 .42285 L
.33538 .42312 L
.33631 .42326 L
.33724 .42327 L
.33817 .42315 L
.3391 .4229 L
.34003 .4225 L
.34096 .42196 L
.34189 .42128 L
.34282 .42045 L
.34375 .41948 L
.34468 .41835 L
.34561 .41707 L
.34654 .41564 L
.34747 .41406 L
.3484 .41233 L
.34933 .41044 L
Mistroke
.35026 .40841 L
.35119 .40623 L
.35212 .4039 L
.35305 .40142 L
.35398 .39881 L
.35491 .39605 L
.35584 .39316 L
.35677 .39014 L
.3577 .38699 L
.35863 .38371 L
.35956 .38032 L
.36049 .37681 L
.36142 .37319 L
.36235 .36947 L
.36328 .36565 L
.36421 .36174 L
.36514 .35774 L
.36607 .35367 L
.367 .34952 L
.36793 .34531 L
.36886 .34104 L
.36979 .33672 L
.37072 .33236 L
.37165 .32796 L
.37258 .32354 L
.37351 .31909 L
.37444 .31463 L
.37537 .31017 L
.3763 .30572 L
.37723 .30128 L
.37816 .29685 L
.37909 .29246 L
.38002 .2881 L
.38095 .28378 L
.38188 .27952 L
.38281 .27531 L
.38374 .27117 L
.38467 .26711 L
.3856 .26312 L
.38653 .25923 L
.38746 .25543 L
.38839 .25173 L
.38932 .24813 L
.39025 .24466 L
.39118 .2413 L
.39211 .23806 L
.39304 .23496 L
.39397 .23199 L
.3949 .22916 L
.39583 .22648 L
Mistroke
.39676 .22394 L
.39769 .22156 L
.39862 .21933 L
.39955 .21726 L
.40048 .21535 L
.40141 .2136 L
.40234 .21202 L
.40327 .21061 L
.4042 .20936 L
.40513 .20828 L
.40606 .20737 L
.40699 .20663 L
.40792 .20606 L
.40885 .20566 L
.40978 .20542 L
.41071 .20535 L
.41164 .20545 L
.41257 .20571 L
.4135 .20613 L
.41443 .2067 L
.41536 .20743 L
.41629 .20831 L
.41722 .20934 L
.41815 .21051 L
.41908 .21182 L
.42001 .21327 L
.42094 .21485 L
.42188 .21656 L
.42281 .21838 L
.42374 .22033 L
.42467 .22238 L
.4256 .22454 L
.42653 .22679 L
.42746 .22915 L
.42839 .23159 L
.42932 .23411 L
.43025 .2367 L
.43118 .23937 L
.43211 .2421 L
.43304 .24489 L
.43397 .24773 L
.4349 .25061 L
.43583 .25353 L
.43676 .25649 L
.43769 .25947 L
.43862 .26247 L
.43955 .26549 L
.44048 .26851 L
.44141 .27154 L
.44234 .27456 L
Mistroke
.44327 .27758 L
.4442 .28058 L
.44513 .28356 L
.44606 .28652 L
.44699 .28945 L
.44792 .29235 L
.44885 .29521 L
.44978 .29802 L
.45071 .30079 L
.45164 .30351 L
.45257 .30618 L
.4535 .30878 L
.45443 .31133 L
.45536 .31382 L
.45629 .31624 L
.45722 .31859 L
.45815 .32087 L
.45908 .32307 L
.46001 .32521 L
.46094 .32727 L
.46187 .32925 L
.4628 .33115 L
.46373 .33298 L
.46466 .33473 L
.46559 .3364 L
.46652 .33799 L
.46745 .3395 L
.46838 .34094 L
.46931 .3423 L
.47024 .34358 L
.47117 .34479 L
.4721 .34592 L
.47303 .34699 L
.47396 .34798 L
.47489 .3489 L
.47582 .34976 L
.47675 .35055 L
.47768 .35129 L
.47861 .35196 L
.47954 .35257 L
.48047 .35313 L
.4814 .35364 L
.48233 .3541 L
.48326 .35452 L
.48419 .35489 L
.48512 .35522 L
.48605 .35551 L
.48698 .35577 L
.48791 .356 L
.48884 .3562 L
Mistroke
.48977 .35638 L
.4907 .35653 L
.49163 .35666 L
.49256 .35678 L
.49349 .35689 L
.49442 .35699 L
.49535 .35707 L
.49628 .35716 L
.49721 .35724 L
.49814 .35732 L
.49907 .35741 L
.5 .3575 L
.50093 .35761 L
.50186 .35772 L
.50279 .35784 L
.50372 .35798 L
.50465 .35813 L
.50558 .3583 L
.50651 .35849 L
.50744 .35871 L
.50837 .35894 L
.5093 .3592 L
.51023 .35948 L
.51116 .35979 L
.51209 .36013 L
.51302 .36049 L
.51395 .36089 L
.51488 .36131 L
.51581 .36176 L
.51674 .36224 L
.51767 .36274 L
.5186 .36328 L
.51953 .36385 L
.52046 .36445 L
.52139 .36507 L
.52232 .36573 L
.52325 .36641 L
.52418 .36713 L
.52511 .36787 L
.52604 .36863 L
.52697 .36943 L
.5279 .37025 L
.52883 .37109 L
.52976 .37196 L
.53069 .37285 L
.53162 .37377 L
.53255 .37471 L
.53348 .37567 L
.53441 .37665 L
.53534 .37764 L
Mistroke
.53627 .37866 L
.5372 .3797 L
.53813 .38075 L
.53906 .38183 L
.53999 .38291 L
.54092 .38402 L
.54185 .38514 L
.54278 .38627 L
.54371 .38742 L
.54464 .38858 L
.54557 .38975 L
.5465 .39094 L
.54743 .39214 L
.54836 .39335 L
.54929 .39458 L
.55022 .39582 L
.55115 .39707 L
.55208 .39834 L
.55301 .39962 L
.55394 .40091 L
.55487 .40222 L
.5558 .40354 L
.55673 .40488 L
.55766 .40624 L
.55859 .40761 L
.55952 .40899 L
.56045 .4104 L
.56138 .41182 L
.56231 .41327 L
.56324 .41473 L
.56417 .41622 L
.5651 .41773 L
.56603 .41926 L
.56696 .42081 L
.56789 .42239 L
.56882 .424 L
.56975 .42564 L
.57068 .4273 L
.57161 .42899 L
.57254 .43071 L
.57347 .43247 L
.5744 .43425 L
.57533 .43607 L
.57626 .43792 L
.57719 .4398 L
.57813 .44172 L
.57906 .44367 L
.57999 .44566 L
.58092 .44768 L
.58185 .44973 L
Mistroke
.58278 .45183 L
.58371 .45395 L
.58464 .45611 L
.58557 .45831 L
.5865 .46053 L
.58743 .4628 L
.58836 .46509 L
.58929 .46741 L
.59022 .46976 L
.59115 .47214 L
.59208 .47455 L
.59301 .47698 L
.59394 .47943 L
.59487 .4819 L
.5958 .4844 L
.59673 .4869 L
.59766 .48942 L
.59859 .49195 L
.59952 .49449 L
.60045 .49703 L
.60138 .49957 L
.60231 .50211 L
.60324 .50464 L
.60417 .50715 L
.6051 .50966 L
.60603 .51214 L
.60696 .5146 L
.60789 .51704 L
.60882 .51944 L
.60975 .5218 L
.61068 .52412 L
.61161 .52639 L
.61254 .52861 L
.61347 .53078 L
.6144 .53288 L
.61533 .53491 L
.61626 .53688 L
.61719 .53876 L
.61812 .54056 L
.61905 .54227 L
.61998 .54389 L
.62091 .54541 L
.62184 .54682 L
.62277 .54813 L
.6237 .54932 L
.62463 .55039 L
.62556 .55134 L
.62649 .55216 L
.62742 .55285 L
.62835 .5534 L
Mistroke
.62928 .55381 L
.63021 .55407 L
.63114 .55418 L
.63207 .55414 L
.633 .55394 L
.63393 .55359 L
.63486 .55306 L
.63579 .55238 L
.63672 .55152 L
.63765 .5505 L
.63858 .5493 L
.63951 .54792 L
.64044 .54638 L
.64137 .54465 L
.6423 .54275 L
.64323 .54067 L
.64416 .53841 L
.64509 .53598 L
.64602 .53337 L
.64695 .53058 L
.64788 .52763 L
.64881 .52449 L
.64974 .52119 L
.65067 .51772 L
.6516 .51409 L
.65253 .51029 L
.65346 .50634 L
.65439 .50223 L
.65532 .49797 L
.65625 .49357 L
.65718 .48902 L
.65811 .48434 L
.65904 .47953 L
.65997 .4746 L
.6609 .46954 L
.66183 .46438 L
.66276 .4591 L
.66369 .45373 L
.66462 .44827 L
.66555 .44273 L
.66648 .4371 L
.66741 .43141 L
.66834 .42566 L
.66927 .41985 L
.6702 .414 L
.67113 .40811 L
.67206 .4022 L
.67299 .39626 L
.67392 .39032 L
.67485 .38437 L
Mistroke
.67578 .37843 L
.67671 .3725 L
.67764 .3666 L
.67857 .36073 L
.6795 .35489 L
.68043 .34911 L
.68136 .34339 L
.68229 .33773 L
.68322 .33215 L
.68415 .32665 L
.68508 .32124 L
.68601 .31593 L
.68694 .31072 L
.68787 .30563 L
.6888 .30065 L
.68973 .29581 L
.69066 .29109 L
.69159 .28651 L
.69252 .28208 L
.69345 .2778 L
.69438 .27367 L
.69531 .26971 L
.69624 .26591 L
.69717 .26228 L
.6981 .25882 L
.69903 .25553 L
.69996 .25243 L
.70089 .24951 L
.70182 .24677 L
.70275 .24421 L
.70368 .24185 L
.70461 .23967 L
.70554 .23768 L
.70647 .23587 L
.7074 .23426 L
.70833 .23283 L
.70926 .23159 L
.71019 .23053 L
.71112 .22966 L
.71205 .22896 L
.71298 .22845 L
.71391 .2281 L
.71484 .22793 L
.71577 .22792 L
.7167 .22808 L
.71763 .2284 L
.71856 .22887 L
.71949 .22948 L
.72042 .23024 L
.72135 .23114 L
Mistroke
.72228 .23217 L
.72321 .23332 L
.72414 .23459 L
.72507 .23598 L
.726 .23747 L
.72693 .23906 L
.72786 .24074 L
.72879 .2425 L
.72972 .24435 L
.73065 .24626 L
.73158 .24823 L
.73251 .25026 L
.73344 .25234 L
.73438 .25446 L
.73531 .25661 L
.73624 .25879 L
.73717 .26099 L
.7381 .2632 L
.73903 .26541 L
.73996 .26762 L
.74089 .26983 L
.74182 .27202 L
.74275 .27419 L
.74368 .27633 L
.74461 .27845 L
.74554 .28052 L
.74647 .28255 L
.7474 .28453 L
.74833 .28647 L
.74926 .28834 L
.75019 .29016 L
.75112 .29191 L
.75205 .29359 L
.75298 .29521 L
.75391 .29675 L
.75484 .29822 L
.75577 .29962 L
.7567 .30094 L
.75763 .30218 L
.75856 .30334 L
.75949 .30442 L
.76042 .30543 L
.76135 .30636 L
.76228 .30721 L
.76321 .30799 L
.76414 .3087 L
.76507 .30933 L
.766 .3099 L
.76693 .31041 L
.76786 .31086 L
Mistroke
.76879 .31125 L
.76972 .31158 L
.77065 .31187 L
.77158 .31211 L
.77251 .31232 L
.77344 .31249 L
.77437 .31263 L
.7753 .31275 L
.77623 .31286 L
.77716 .31295 L
.77809 .31304 L
.77902 .31314 L
.77995 .31324 L
.78088 .31336 L
.78181 .3135 L
.78274 .31367 L
.78367 .31388 L
.7846 .31413 L
.78553 .31443 L
.78646 .31479 L
.78739 .31521 L
.78832 .3157 L
.78925 .31627 L
.79018 .31692 L
.79111 .31766 L
.79204 .3185 L
.79297 .31944 L
.7939 .32049 L
.79483 .32165 L
.79576 .32292 L
.79669 .32432 L
.79762 .32585 L
.79855 .32751 L
.79948 .3293 L
.80041 .33123 L
.80134 .3333 L
.80227 .33552 L
.8032 .33788 L
.80413 .34039 L
.80506 .34306 L
.80599 .34587 L
.80692 .34883 L
.80785 .35195 L
.80878 .35521 L
.80971 .35863 L
.81064 .36219 L
.81157 .3659 L
.8125 .36975 L
.81343 .37374 L
.81436 .37788 L
Mistroke
.81529 .38214 L
.81622 .38653 L
.81715 .39105 L
.81808 .39569 L
.81901 .40044 L
.81994 .4053 L
.82087 .41026 L
.8218 .41531 L
.82273 .42045 L
.82366 .42567 L
.82459 .43095 L
.82552 .4363 L
.82645 .4417 L
.82738 .44714 L
.82831 .45262 L
.82924 .45812 L
.83017 .46363 L
.8311 .46915 L
.83203 .47466 L
.83296 .48015 L
.83389 .48561 L
.83482 .49104 L
.83575 .49641 L
.83668 .50172 L
.83761 .50695 L
.83854 .51211 L
.83947 .51716 L
.8404 .52211 L
.84133 .52694 L
.84226 .53165 L
.84319 .53621 L
.84412 .54063 L
.84505 .54488 L
.84598 .54897 L
.84691 .55287 L
.84784 .55658 L
.84877 .56009 L
.8497 .5634 L
.85063 .56649 L
.85156 .56935 L
.85249 .57198 L
.85342 .57437 L
.85435 .57651 L
.85528 .5784 L
.85621 .58002 L
.85714 .58138 L
.85807 .58247 L
.859 .58329 L
.85993 .58383 L
.86086 .58408 L
Mistroke
.86179 .58405 L
.86272 .58373 L
.86365 .58313 L
.86458 .58224 L
.86551 .58105 L
.86644 .57958 L
.86737 .57782 L
.8683 .57577 L
.86923 .57344 L
.87016 .57083 L
.87109 .56794 L
.87202 .56477 L
.87295 .56134 L
.87388 .55764 L
.87481 .55369 L
.87574 .54948 L
.87667 .54503 L
.8776 .54035 L
.87853 .53543 L
.87946 .5303 L
.88039 .52495 L
.88132 .51941 L
.88225 .51367 L
.88318 .50775 L
.88411 .50166 L
.88504 .49542 L
.88597 .48902 L
.8869 .48249 L
.88783 .47584 L
.88876 .46908 L
.88969 .46221 L
.89063 .45527 L
.89156 .44825 L
.89249 .44117 L
.89342 .43405 L
.89435 .42689 L
.89528 .41972 L
.89621 .41254 L
.89714 .40537 L
.89807 .39821 L
.899 .3911 L
.89993 .38403 L
.90086 .37702 L
.90179 .37008 L
.90272 .36323 L
.90365 .35647 L
.90458 .34983 L
.90551 .34331 L
.90644 .33691 L
.90737 .33067 L
Mistroke
.9083 .32457 L
.90923 .31864 L
.91016 .31288 L
.91109 .30731 L
.91202 .30193 L
.91295 .29674 L
.91388 .29177 L
.91481 .287 L
.91574 .28246 L
.91667 .27814 L
.9176 .27406 L
.91853 .27021 L
.91946 .2666 L
.92039 .26324 L
.92132 .26012 L
.92225 .25725 L
.92318 .25463 L
.92411 .25226 L
.92504 .25014 L
.92597 .24827 L
.9269 .24665 L
.92783 .24527 L
.92876 .24414 L
.92969 .24325 L
.93062 .2426 L
.93155 .24218 L
.93248 .24199 L
.93341 .24202 L
.93434 .24227 L
.93527 .24273 L
.9362 .24338 L
.93713 .24424 L
.93806 .24528 L
.93899 .24649 L
.93992 .24788 L
.94085 .24942 L
.94178 .25112 L
.94271 .25295 L
.94364 .25491 L
.94457 .25698 L
.9455 .25916 L
.94643 .26143 L
.94736 .26379 L
.94829 .26622 L
.94922 .2687 L
.95015 .27123 L
.95108 .27379 L
.95201 .27637 L
.95294 .27897 L
.95387 .28155 L
Mistroke
.9548 .28413 L
.95573 .28667 L
.95666 .28917 L
.95759 .29163 L
.95852 .29401 L
.95945 .29632 L
.96038 .29855 L
.96131 .30067 L
.96224 .30269 L
.96317 .30459 L
.9641 .30635 L
.96503 .30798 L
.96596 .30946 L
.96689 .31078 L
.96782 .31194 L
.96875 .31292 L
.96968 .31372 L
.97061 .31433 L
.97154 .31475 L
.97247 .31497 L
.9734 .31498 L
.97433 .31478 L
.97526 .31436 L
.97619 .31373 L
Mfstroke
[ .02 ] 0 setdash
.02474 .28812 m
.02567 .28875 L
.0266 .28928 L
.02753 .28971 L
.02846 .29004 L
.02939 .29027 L
.03032 .29041 L
.03125 .29044 L
.03218 .29039 L
.03311 .29024 L
.03404 .29001 L
.03497 .2897 L
.0359 .28932 L
.03683 .28888 L
.03776 .28837 L
.03869 .28782 L
.03962 .28723 L
.04055 .2866 L
.04148 .28595 L
.04241 .28527 L
.04334 .28458 L
.04427 .28387 L
.0452 .28315 L
.04613 .28241 L
.04706 .28166 L
.04799 .28086 L
.04892 .28003 L
.04985 .27913 L
.05078 .27813 L
.05171 .27702 L
.05264 .27573 L
.05357 .27423 L
.0545 .27246 L
.05543 .27033 L
.05636 .26778 L
.05729 .26471 L
.05822 .26102 L
.05915 .25659 L
.06008 .25131 L
.06101 .24507 L
.06194 .23777 L
.06287 .22932 L
.0638 .21967 L
.06473 .2088 L
.06566 .19676 L
.06659 .18367 L
.06752 .1697 L
.06845 .1551 L
.06938 .14014 L
.07031 .12517 L
Mistroke
.07124 .1105 L
.07217 .09645 L
.0731 .08327 L
.07403 .07119 L
.07496 .06033 L
.07589 .05078 L
.07682 .04254 L
.07775 .03558 L
.07868 .02983 L
.07961 .0252 L
.08054 .02158 L
.08147 .01884 L
.0824 .01689 L
.08333 .01562 L
.08426 .01492 L
.08519 .01472 L
.08612 .01493 L
.08705 .01549 L
.08798 .01634 L
.08891 .01743 L
.08984 .01873 L
.09077 .02019 L
.0917 .0218 L
.09263 .02351 L
.09356 .02532 L
.09449 .02721 L
.09542 .02916 L
.09635 .03116 L
.09728 .03321 L
.09821 .03529 L
.09914 .0374 L
.10007 .03953 L
.101 .04168 L
.10193 .04384 L
.10286 .04602 L
.10379 .04821 L
.10472 .05041 L
.10565 .05261 L
.10658 .05482 L
.10751 .05703 L
.10844 .05924 L
.10938 .06146 L
.11031 .06368 L
.11124 .0659 L
.11217 .06812 L
.1131 .07034 L
.11403 .07257 L
.11496 .07479 L
.11589 .07702 L
.11682 .07924 L
Mistroke
.11775 .08146 L
.11868 .08369 L
.11961 .08591 L
.12054 .08814 L
.12147 .09036 L
.1224 .09259 L
.12333 .09481 L
.12426 .09704 L
.12519 .09927 L
.12612 .10149 L
.12705 .10372 L
.12798 .10595 L
.12891 .10818 L
.12984 .11041 L
.13077 .11264 L
.1317 .11488 L
.13263 .11711 L
.13356 .11935 L
.13449 .12159 L
.13542 .12383 L
.13635 .12607 L
.13728 .12832 L
.13821 .13057 L
.13914 .13282 L
.14007 .13507 L
.141 .13732 L
.14193 .13958 L
.14286 .14184 L
.14379 .14411 L
.14472 .14637 L
.14565 .14864 L
.14658 .15092 L
.14751 .1532 L
.14844 .15548 L
.14937 .15776 L
.1503 .16005 L
.15123 .16234 L
.15216 .16464 L
.15309 .16694 L
.15402 .16925 L
.15495 .17155 L
.15588 .17387 L
.15681 .17619 L
.15774 .17851 L
.15867 .18084 L
.1596 .18317 L
.16053 .1855 L
.16146 .18785 L
.16239 .19019 L
.16332 .19254 L
Mistroke
.16425 .1949 L
.16518 .19726 L
.16611 .19962 L
.16704 .20199 L
.16797 .20437 L
.1689 .20674 L
.16983 .20913 L
.17076 .21152 L
.17169 .21391 L
.17262 .21631 L
.17355 .21872 L
.17448 .22112 L
.17541 .22354 L
.17634 .22596 L
.17727 .22838 L
.1782 .23081 L
.17913 .23324 L
.18006 .23568 L
.18099 .23812 L
.18192 .24057 L
.18285 .24302 L
.18378 .24547 L
.18471 .24793 L
.18564 .2504 L
.18657 .25287 L
.1875 .25534 L
.18843 .25782 L
.18936 .2603 L
.19029 .26279 L
.19122 .26528 L
.19215 .26778 L
.19308 .27028 L
.19401 .27278 L
.19494 .27529 L
.19587 .2778 L
.1968 .28031 L
.19773 .28283 L
.19866 .28536 L
.19959 .28788 L
.20052 .29041 L
.20145 .29295 L
.20238 .29548 L
.20331 .29803 L
.20424 .30057 L
.20517 .30312 L
.2061 .30567 L
.20703 .30822 L
.20796 .31078 L
.20889 .31334 L
.20982 .3159 L
Mistroke
.21075 .31847 L
.21168 .32104 L
.21261 .32361 L
.21354 .32619 L
.21447 .32877 L
.2154 .33135 L
.21633 .33393 L
.21726 .33651 L
.21819 .3391 L
.21912 .34169 L
.22005 .34429 L
.22098 .34688 L
.22191 .34948 L
.22284 .35208 L
.22377 .35468 L
.2247 .35728 L
.22563 .35989 L
.22656 .36249 L
.22749 .3651 L
.22842 .36771 L
.22935 .37033 L
.23028 .37294 L
.23121 .37555 L
.23214 .37817 L
.23307 .38079 L
.234 .3834 L
.23493 .38602 L
.23586 .38864 L
.23679 .39126 L
.23772 .39387 L
.23865 .39649 L
.23958 .39911 L
.24051 .40172 L
.24144 .40434 L
.24237 .40695 L
.2433 .40955 L
.24423 .41216 L
.24516 .41476 L
.24609 .41735 L
.24702 .41994 L
.24795 .42252 L
.24888 .42508 L
.24981 .42764 L
.25074 .43018 L
.25167 .43271 L
.2526 .43521 L
.25353 .4377 L
.25446 .44015 L
.25539 .44258 L
.25632 .44496 L
Mistroke
.25725 .44731 L
.25818 .4496 L
.25911 .45183 L
.26004 .45399 L
.26097 .45607 L
.2619 .45805 L
.26283 .45992 L
.26376 .46166 L
.26469 .46326 L
.26563 .46467 L
.26656 .46589 L
.26749 .46688 L
.26842 .4676 L
.26935 .46803 L
.27028 .46811 L
.27121 .4678 L
.27214 .46707 L
.27307 .46585 L
.274 .46411 L
.27493 .46179 L
.27586 .45886 L
.27679 .45527 L
.27772 .45101 L
.27865 .44606 L
.27958 .44043 L
.28051 .43414 L
.28144 .42724 L
.28237 .41982 L
.2833 .41195 L
.28423 .40376 L
.28516 .39539 L
.28609 .38696 L
.28702 .37864 L
.28795 .37055 L
.28888 .36282 L
.28981 .35557 L
.29074 .34888 L
.29167 .34282 L
.2926 .33742 L
.29353 .33271 L
.29446 .32868 L
.29539 .32532 L
.29632 .3226 L
.29725 .32048 L
.29818 .31892 L
.29911 .31787 L
.30004 .31728 L
.30097 .3171 L
.3019 .31729 L
.30283 .31781 L
Mistroke
.30376 .31861 L
.30469 .31967 L
.30562 .32094 L
.30655 .32241 L
.30748 .32404 L
.30841 .32581 L
.30934 .3277 L
.31027 .3297 L
.3112 .33179 L
.31213 .33396 L
.31306 .33619 L
.31399 .33848 L
.31492 .34082 L
.31585 .34319 L
.31678 .34561 L
.31771 .34805 L
.31864 .35052 L
.31957 .35301 L
.3205 .35551 L
.32143 .35803 L
.32236 .36056 L
.32329 .3631 L
.32422 .36565 L
.32515 .3682 L
.32608 .37075 L
.32701 .37331 L
.32794 .37587 L
.32887 .37843 L
.3298 .38098 L
.33073 .38353 L
.33166 .38608 L
.33259 .38861 L
.33352 .39115 L
.33445 .39367 L
.33538 .39618 L
.33631 .39868 L
.33724 .40116 L
.33817 .40363 L
.3391 .40608 L
.34003 .40851 L
.34096 .41092 L
.34189 .4133 L
.34282 .41566 L
.34375 .41798 L
.34468 .42027 L
.34561 .42252 L
.34654 .42472 L
.34747 .42688 L
.3484 .42898 L
.34933 .43102 L
Mistroke
.35026 .433 L
.35119 .4349 L
.35212 .43672 L
.35305 .43845 L
.35398 .44008 L
.35491 .4416 L
.35584 .44299 L
.35677 .44424 L
.3577 .44534 L
.35863 .44626 L
.35956 .447 L
.36049 .44752 L
.36142 .4478 L
.36235 .44782 L
.36328 .44753 L
.36421 .44692 L
.36514 .44594 L
.36607 .44454 L
.367 .44268 L
.36793 .44031 L
.36886 .43737 L
.36979 .4338 L
.37072 .42955 L
.37165 .42454 L
.37258 .41873 L
.37351 .41206 L
.37444 .4045 L
.37537 .39601 L
.3763 .38659 L
.37723 .37627 L
.37816 .36511 L
.37909 .35321 L
.38002 .34069 L
.38095 .32771 L
.38188 .31448 L
.38281 .30118 L
.38374 .28805 L
.38467 .27529 L
.3856 .26308 L
.38653 .25158 L
.38746 .24093 L
.38839 .2312 L
.38932 .22245 L
.39025 .2147 L
.39118 .20793 L
.39211 .2021 L
.39304 .19717 L
.39397 .19308 L
.3949 .18974 L
.39583 .1871 L
Mistroke
.39676 .18508 L
.39769 .18361 L
.39862 .18263 L
.39955 .18207 L
.40048 .1819 L
.40141 .18205 L
.40234 .18249 L
.40327 .18317 L
.4042 .18407 L
.40513 .18516 L
.40606 .1864 L
.40699 .18779 L
.40792 .18929 L
.40885 .19089 L
.40978 .19258 L
.41071 .19435 L
.41164 .19618 L
.41257 .19807 L
.4135 .2 L
.41443 .20198 L
.41536 .20398 L
.41629 .20602 L
.41722 .20809 L
.41815 .21017 L
.41908 .21227 L
.42001 .21439 L
.42094 .21651 L
.42188 .21865 L
.42281 .2208 L
.42374 .22295 L
.42467 .22511 L
.4256 .22727 L
.42653 .22943 L
.42746 .23159 L
.42839 .23375 L
.42932 .23591 L
.43025 .23807 L
.43118 .24023 L
.43211 .24239 L
.43304 .24454 L
.43397 .24668 L
.4349 .24882 L
.43583 .25095 L
.43676 .25308 L
.43769 .2552 L
.43862 .25731 L
.43955 .25942 L
.44048 .26151 L
.44141 .2636 L
.44234 .26567 L
Mistroke
.44327 .26773 L
.4442 .26978 L
.44513 .27182 L
.44606 .27384 L
.44699 .27585 L
.44792 .27784 L
.44885 .27982 L
.44978 .28178 L
.45071 .28372 L
.45164 .28564 L
.45257 .28755 L
.4535 .28943 L
.45443 .29129 L
.45536 .29312 L
.45629 .29494 L
.45722 .29672 L
.45815 .29849 L
.45908 .30022 L
.46001 .30193 L
.46094 .3036 L
.46187 .30525 L
.4628 .30687 L
.46373 .30845 L
.46466 .31 L
.46559 .31152 L
.46652 .313 L
.46745 .31445 L
.46838 .31586 L
.46931 .31724 L
.47024 .31858 L
.47117 .31988 L
.4721 .32115 L
.47303 .32238 L
.47396 .32357 L
.47489 .32473 L
.47582 .32585 L
.47675 .32693 L
.47768 .32798 L
.47861 .329 L
.47954 .32999 L
.48047 .33094 L
.4814 .33187 L
.48233 .33276 L
.48326 .33364 L
.48419 .33449 L
.48512 .33532 L
.48605 .33613 L
.48698 .33693 L
.48791 .33771 L
.48884 .33848 L
Mistroke
.48977 .33925 L
.4907 .34001 L
.49163 .34078 L
.49256 .34154 L
.49349 .34231 L
.49442 .34309 L
.49535 .34388 L
.49628 .34469 L
.49721 .34551 L
.49814 .34635 L
.49907 .34722 L
.5 .34811 L
.50093 .34902 L
.50186 .34997 L
.50279 .35094 L
.50372 .35195 L
.50465 .353 L
.50558 .35408 L
.50651 .35519 L
.50744 .35635 L
.50837 .35754 L
.5093 .35877 L
.51023 .36004 L
.51116 .36134 L
.51209 .36269 L
.51302 .36407 L
.51395 .3655 L
.51488 .36696 L
.51581 .36846 L
.51674 .36999 L
.51767 .37156 L
.5186 .37316 L
.51953 .3748 L
.52046 .37647 L
.52139 .37816 L
.52232 .37989 L
.52325 .38165 L
.52418 .38343 L
.52511 .38524 L
.52604 .38707 L
.52697 .38892 L
.5279 .39079 L
.52883 .39268 L
.52976 .39458 L
.53069 .3965 L
.53162 .39843 L
.53255 .40037 L
.53348 .40231 L
.53441 .40427 L
.53534 .40622 L
Mistroke
.53627 .40818 L
.5372 .41014 L
.53813 .4121 L
.53906 .41404 L
.53999 .41598 L
.54092 .41791 L
.54185 .41983 L
.54278 .42173 L
.54371 .42361 L
.54464 .42547 L
.54557 .4273 L
.5465 .4291 L
.54743 .43088 L
.54836 .43261 L
.54929 .43431 L
.55022 .43597 L
.55115 .43758 L
.55208 .43914 L
.55301 .44065 L
.55394 .4421 L
.55487 .44349 L
.5558 .44482 L
.55673 .44608 L
.55766 .44726 L
.55859 .44838 L
.55952 .44942 L
.56045 .45038 L
.56138 .45125 L
.56231 .45204 L
.56324 .45275 L
.56417 .45337 L
.5651 .4539 L
.56603 .45435 L
.56696 .4547 L
.56789 .45498 L
.56882 .45517 L
.56975 .45528 L
.57068 .45532 L
.57161 .45529 L
.57254 .45519 L
.57347 .45503 L
.5744 .45482 L
.57533 .45457 L
.57626 .45429 L
.57719 .45397 L
.57813 .45365 L
.57906 .45331 L
.57999 .45298 L
.58092 .45265 L
.58185 .45236 L
Mistroke
.58278 .45209 L
.58371 .45186 L
.58464 .45168 L
.58557 .45155 L
.5865 .45149 L
.58743 .4515 L
.58836 .45158 L
.58929 .45174 L
.59022 .45199 L
.59115 .45232 L
.59208 .45275 L
.59301 .45326 L
.59394 .45387 L
.59487 .45456 L
.5958 .45535 L
.59673 .45623 L
.59766 .4572 L
.59859 .45826 L
.59952 .4594 L
.60045 .46063 L
.60138 .46193 L
.60231 .46332 L
.60324 .46477 L
.60417 .4663 L
.6051 .4679 L
.60603 .46956 L
.60696 .47128 L
.60789 .47306 L
.60882 .47489 L
.60975 .47678 L
.61068 .47872 L
.61161 .4807 L
.61254 .48272 L
.61347 .48479 L
.6144 .48689 L
.61533 .48903 L
.61626 .4912 L
.61719 .4934 L
.61812 .49563 L
.61905 .49788 L
.61998 .50017 L
.62091 .50247 L
.62184 .5048 L
.62277 .50714 L
.6237 .50951 L
.62463 .51189 L
.62556 .51428 L
.62649 .51669 L
.62742 .51911 L
.62835 .52155 L
Mistroke
.62928 .52399 L
.63021 .52644 L
.63114 .52891 L
.63207 .53137 L
.633 .53385 L
.63393 .53633 L
.63486 .53881 L
.63579 .5413 L
.63672 .54378 L
.63765 .54627 L
.63858 .54875 L
.63951 .55123 L
.64044 .5537 L
.64137 .55616 L
.6423 .55861 L
.64323 .56103 L
.64416 .56344 L
.64509 .56582 L
.64602 .56815 L
.64695 .57044 L
.64788 .57266 L
.64881 .5748 L
.64974 .57684 L
.65067 .57874 L
.6516 .58048 L
.65253 .58199 L
.65346 .58323 L
.65439 .58412 L
.65532 .58456 L
.65625 .58443 L
.65718 .58359 L
.65811 .58185 L
.65904 .57899 L
.65997 .57477 L
.6609 .56889 L
.66183 .56104 L
.66276 .5509 L
.66369 .5382 L
.66462 .52273 L
.66555 .50442 L
.66648 .48341 L
.66741 .46005 L
.66834 .43495 L
.66927 .40895 L
.6702 .38296 L
.67113 .35792 L
.67206 .33464 L
.67299 .31373 L
.67392 .29553 L
.67485 .28017 L
Mistroke
.67578 .26757 L
.67671 .25752 L
.67764 .24974 L
.67857 .24392 L
.6795 .23974 L
.68043 .23691 L
.68136 .23518 L
.68229 .23434 L
.68322 .2342 L
.68415 .23462 L
.68508 .23548 L
.68601 .23667 L
.68694 .23814 L
.68787 .23981 L
.6888 .24163 L
.68973 .24358 L
.69066 .24562 L
.69159 .24772 L
.69252 .24988 L
.69345 .25206 L
.69438 .25426 L
.69531 .25648 L
.69624 .25869 L
.69717 .26089 L
.6981 .26307 L
.69903 .26523 L
.69996 .26736 L
.70089 .26945 L
.70182 .2715 L
.70275 .2735 L
.70368 .27544 L
.70461 .27732 L
.70554 .27912 L
.70647 .28084 L
.7074 .28248 L
.70833 .28401 L
.70926 .28544 L
.71019 .28675 L
.71112 .28793 L
.71205 .28898 L
.71298 .28987 L
.71391 .29061 L
.71484 .29117 L
.71577 .29156 L
.7167 .29175 L
.71763 .29174 L
.71856 .29153 L
.71949 .2911 L
.72042 .29045 L
.72135 .28959 L
Mistroke
.72228 .2885 L
.72321 .28719 L
.72414 .28568 L
.72507 .28396 L
.726 .28206 L
.72693 .27999 L
.72786 .27776 L
.72879 .27542 L
.72972 .27297 L
.73065 .27046 L
.73158 .26791 L
.73251 .26535 L
.73344 .26282 L
.73438 .26035 L
.73531 .25796 L
.73624 .25569 L
.73717 .25356 L
.7381 .2516 L
.73903 .24981 L
.73996 .24823 L
.74089 .24685 L
.74182 .24569 L
.74275 .24475 L
.74368 .24404 L
.74461 .24354 L
.74554 .24327 L
.74647 .24321 L
.7474 .24336 L
.74833 .2437 L
.74926 .24423 L
.75019 .24495 L
.75112 .24582 L
.75205 .24686 L
.75298 .24804 L
.75391 .24936 L
.75484 .25081 L
.75577 .25237 L
.7567 .25404 L
.75763 .25581 L
.75856 .25766 L
.75949 .2596 L
.76042 .26161 L
.76135 .2637 L
.76228 .26584 L
.76321 .26804 L
.76414 .27029 L
.76507 .27258 L
.766 .27492 L
.76693 .2773 L
.76786 .27971 L
Mistroke
.76879 .28215 L
.76972 .28462 L
.77065 .28711 L
.77158 .28963 L
.77251 .29217 L
.77344 .29472 L
.77437 .29729 L
.7753 .29988 L
.77623 .30248 L
.77716 .30509 L
.77809 .30772 L
.77902 .31035 L
.77995 .31299 L
.78088 .31565 L
.78181 .3183 L
.78274 .32097 L
.78367 .32364 L
.7846 .32631 L
.78553 .32899 L
.78646 .33168 L
.78739 .33437 L
.78832 .33706 L
.78925 .33975 L
.79018 .34245 L
.79111 .34515 L
.79204 .34785 L
.79297 .35055 L
.7939 .35326 L
.79483 .35596 L
.79576 .35867 L
.79669 .36138 L
.79762 .36408 L
.79855 .36679 L
.79948 .3695 L
.80041 .37221 L
.80134 .37492 L
.80227 .37763 L
.8032 .38034 L
.80413 .38305 L
.80506 .38576 L
.80599 .38847 L
.80692 .39118 L
.80785 .39389 L
.80878 .3966 L
.80971 .39931 L
.81064 .40202 L
.81157 .40472 L
.8125 .40743 L
.81343 .41013 L
.81436 .41284 L
Mistroke
.81529 .41554 L
.81622 .41824 L
.81715 .42094 L
.81808 .42364 L
.81901 .42634 L
.81994 .42903 L
.82087 .43173 L
.8218 .43442 L
.82273 .43712 L
.82366 .43981 L
.82459 .4425 L
.82552 .44518 L
.82645 .44787 L
.82738 .45055 L
.82831 .45324 L
.82924 .45592 L
.83017 .4586 L
.8311 .46127 L
.83203 .46395 L
.83296 .46662 L
.83389 .46929 L
.83482 .47196 L
.83575 .47462 L
.83668 .47729 L
.83761 .47995 L
.83854 .48261 L
.83947 .48526 L
.8404 .48792 L
.84133 .49057 L
.84226 .49322 L
.84319 .49586 L
.84412 .49851 L
.84505 .50115 L
.84598 .50378 L
.84691 .50642 L
.84784 .50905 L
.84877 .51168 L
.8497 .5143 L
.85063 .51693 L
.85156 .51954 L
.85249 .52216 L
.85342 .52477 L
.85435 .52738 L
.85528 .52999 L
.85621 .53259 L
.85714 .53519 L
.85807 .53778 L
.859 .54037 L
.85993 .54295 L
.86086 .54554 L
Mistroke
.86179 .54811 L
.86272 .55068 L
.86365 .55325 L
.86458 .55581 L
.86551 .55837 L
.86644 .56091 L
.86737 .56345 L
.8683 .56598 L
.86923 .56851 L
.87016 .57102 L
.87109 .57351 L
.87202 .57599 L
.87295 .57845 L
.87388 .58089 L
.87481 .58329 L
.87574 .58566 L
.87667 .58798 L
.8776 .59025 L
.87853 .59243 L
.87946 .59453 L
.88039 .59651 L
.88132 .59833 L
.88225 .59997 L
.88318 .60136 L
.88411 .60244 L
.88504 .60313 L
.88597 .60332 L
.8869 .60289 L
.88783 .60167 L
.88876 .59947 L
.88969 .59606 L
.89063 .59118 L
.89156 .58453 L
.89249 .57579 L
.89342 .56466 L
.89435 .55087 L
.89528 .53424 L
.89621 .51477 L
.89714 .49262 L
.89807 .46822 L
.899 .44223 L
.89993 .41547 L
.90086 .38887 L
.90179 .36332 L
.90272 .33955 L
.90365 .31808 L
.90458 .29922 L
.90551 .28302 L
.90644 .26937 L
.90737 .25806 L
Mistroke
.9083 .24881 L
.90923 .24129 L
.91016 .23524 L
.91109 .23037 L
.91202 .22645 L
.91295 .22331 L
.91388 .22077 L
.91481 .21871 L
.91574 .21703 L
.91667 .21566 L
.9176 .21454 L
.91853 .21362 L
.91946 .21287 L
.92039 .21228 L
.92132 .21181 L
.92225 .21147 L
.92318 .21125 L
.92411 .21113 L
.92504 .21112 L
.92597 .21121 L
.9269 .2114 L
.92783 .2117 L
.92876 .21209 L
.92969 .21258 L
.93062 .21317 L
.93155 .21386 L
.93248 .21464 L
.93341 .2155 L
.93434 .21646 L
.93527 .2175 L
.9362 .21862 L
.93713 .21982 L
.93806 .2211 L
.93899 .22244 L
.93992 .22385 L
.94085 .22532 L
.94178 .22685 L
.94271 .22844 L
.94364 .23007 L
.94457 .23175 L
.9455 .23347 L
.94643 .23523 L
.94736 .23702 L
.94829 .23884 L
.94922 .24069 L
.95015 .24256 L
.95108 .24444 L
.95201 .24634 L
.95294 .24825 L
.95387 .25017 L
Mistroke
.9548 .25208 L
.95573 .254 L
.95666 .25591 L
.95759 .25781 L
.95852 .2597 L
.95945 .26157 L
.96038 .26342 L
.96131 .26524 L
.96224 .26703 L
.96317 .26879 L
.9641 .27051 L
.96503 .27219 L
.96596 .27382 L
.96689 .2754 L
.96782 .27693 L
.96875 .27839 L
.96968 .27979 L
.97061 .28112 L
.97154 .28237 L
.97247 .28355 L
.9734 .28464 L
.97433 .28565 L
.97526 .28656 L
.97619 .28739 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00Oogoo;Goo003oOol]
Ool0021oo`03001oogoo0?moo`Yoo`003Goo0P0017oo0P0017oo0P001Goo00<007ooOol0ogoo2Woo
000<Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo0?moo`Yoo`001Woo1@00
00Eoo`00Oomoo`0000Qoo`04001oogoo0004Ool3003oOol:Ool000aoo`04001oogoo0008Ool30005
Ool00`00Oomoo`0=Ool2003jOol000aoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`0=
Ool00`00Ool0003iOol000eoo`8000Yoo`<000Aoo`03001oogoo00moo`800?Qoo`0087oo00<007oo
Ool047oo00<007ooOol0mWoo000POol00`00Oomoo`0>Ool3003hOol0021oo`03001oogoo00ioo`04
001oo`00003gOol0021oo`8000eoo`8000=oo`800?Ioo`0087oo00<007ooOol02goo00<007oo0000
17oo00<007ooOol0m7oo000POol00`00Oomoo`0;Ool20005Ool00`00Oomoo`3dOol0021oo`03001o
ogoo00]oo`8000Ioo`03001oogoo0?=oo`0087oo00<007ooOol02goo0P001Woo00<007ooOol0lgoo
000POol00`00Oomoo`0;Ool00`00Oomoo`05Ool2003dOol0021oo`03001oogoo00]oo`03001oogoo
00Ioo`03001oogoo0?9oo`0087oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0lWoo000P
Ool2000<Ool00`00Oomoo`06Ool00`00Oomoo`3bOol0021oo`03001oogoo00Yoo`03001oogoo00Qo
o`03001oogoo0?5oo`0087oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol0lGoo000POol0
0`00Oomoo`0:Ool20009Ool2003bOol0021oo`03001oogoo00Yoo`03001oogoo00Qoo`<00?5oo`00
87oo00<007ooOol02Woo00<007ooOol02Goo0P00lGoo000POol00`00Oomoo`09Ool2000;Ool00`00
Oomoo`3`Ool0021oo`8000Yoo`8000]oo`03001oogoo0?1oo`0087oo00<007ooOol02Goo0P002goo
00<007ooOol0l7oo000POol00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`3_Ool0021oo`03
001oogoo00Uoo`03001oogoo00]oo`03001oo`000>moo`0087oo00<007ooOol02Goo00<007ooOol0
2goo00<007oo0000kgoo000POol00`00Oomoo`08Ool00`00Oomoo`0<Ool200000goo001oo`3]Ool0
00eoo`8000Aoo`8000Aoo`<000Aoo`03001oogoo00Qoo`03001oo`0000eoo`03001oo`000>ioo`00
37oo00@007ooOol000=oo`8000Eoo`03001oogoo00=oo`03001oogoo00Qoo`03001oo`0000eoo`04
001oogoo003]Ool000Ioo`D00005Ool007ooOol00008Ool40004Ool30008Ool00`00Ool0000=Ool0
0`00Oomoo`3^Ool000aoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`08Ool00`00Ool0
000>Ool00`00Oomoo`3]Ool000aoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`08Ool0
0`00Ool0000>Ool00`00Oomoo`3]Ool000eoo`8000Yoo`8000Eoo`03001oogoo00Moo`03001oo`00
00moo`03001oogoo0>eoo`0087oo00<007ooOol01goo00<007oo00003goo00D007ooOomoo`000>]o
o`0087oo00<007ooOol01goo00<007ooOol047oo00@007ooOol00>]oo`0087oo00<007ooOol01goo
00<007ooOol047oo00<007ooOol00P00jWoo000POol20008Ool00`00Oomoo`0@Ool01@00Oomoogoo
0000jWoo000POol00`00Oomoo`07Ool00`00Oomoo`0AOol01000Oomoo`00jWoo000POol00`00Oomo
o`06Ool01000Oomoo`004Goo00D007ooOomoo`000>Uoo`0087oo00<007ooOol01Woo00@007ooOol0
015oo`03001oogoo0>]oo`0087oo00<007ooOol01Woo00@007ooOol0019oo`03001oogoo0>Yoo`00
87oo00<007ooOol01Woo00@007ooOol0019oo`03001oogoo0>Yoo`0087oo00<007ooOol01Woo00@0
07ooOol001=oo`03001oogoo0>Uoo`0087oo00<007ooOol01Woo00@007ooOol001=oo`05001oogoo
Ool0003WOol0021oo`8000Moo`03001oogoo01Eoo`04001oogoo003WOol0021oo`03001oogoo00Eo
o`03001oogoo01Ioo`80009oo`03001oogoo0>Aoo`0087oo00<007ooOol01Goo00<007ooOol05goo
00@007ooOol003ioo`03001oogoo0:Eoo`0087oo00<007ooOol01Goo00<007ooOol067oo00@007oo
000003aoo`05001oogooOol0002TOol0021oo`03001oogoo00Eoo`03001oogoo01Uoo`8003eoo`03
001oogoo009oo`03001oogoo0:5oo`0087oo00<007ooOol01Goo00@007ooOol001Uoo`80045oo`03
001oogoo0:5oo`0087oo00<007ooOol01Goo00@007ooOol001]oo`80041oo`03001oogoo0:1oo`00
87oo0P001Goo00D007ooOomoo`0001]oo`<003aoo`@00:9oo`0087oo00<007ooOol017oo00D007oo
Oomoo`0001]oo`03001oo`0003aoo`03001oogoo008008Ioo`8001Uoo`0087oo00<007ooOol017oo
00D007ooOomoo`0001aoo`03001oo`0003Moo`04001oogoo0004Ool00`00Oomoo`25Ool2000HOol0
021oo`03001oogoo00Aoo`05001oogooOol0000LOol00`00Ool0000gOol01000Oomoo`001Goo00<0
07ooOol0QGoo0P005goo000POol00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Ool0000fOol00`00
Ool00006Ool00`00Oomoo`26Ool2000FOol0021oo`03001oogoo00Aoo`03001oogoo01moo`03001o
o`0003Ioo`03001oo`0000Ioo`80085oo`03001oogoo00Aoo`03001oogoo01Aoo`003Goo0P0017oo
0P000goo100017oo00<007ooOol00goo00<007ooOol08goo00<007ooOol0<goo0`001goo00<007oo
Ool0BGoo0`00<goo00<007ooOol06goo000<Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo
00<007ooOol00goo00<007ooOol08goo00<007ooOol0<goo0P0027oo00<007ooOol0@Goo00<007oo
Ool017oo0P0000=oo`000000<Goo00<007ooOol077oo0006Ool500001Goo001oogoo00002Woo00<0
07ooOol00goo0`000goo00D007ooOomoo`00025oo`8003Eoo`03001oogoo00Moo`03001oogoo041o
o`03001oogoo00Aoo`04001oogooOol2000`Ool00`00Oomoo`0LOol000aoo`04001oogoo000;Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00008Woo00<007ooOol0<Woo0P002Goo00<0
07ooOol0?goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0;Woo00<007ooOol01goo0P00
4goo000<Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00=oo`05001oogooOol0000P
Ool00`00Ool0000dOol00`00Oomoo`08Ool20010Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`03000ZOol00`00Oomoo`02Ool30003Ool00`00Oomoo`0AOol000eoo`8000Yoo`8000Eoo`03
001oogoo00=oo`05001oogooOol0000POol01000Ool00000<goo00<007ooOol02Goo00<007ooOol0
?Woo00<007ooOol00goo00<007ooOol01Goo00@007ooOol0009oo`03001oogoo02Moo`04001oogoo
Ool20002Ool00`00Oomoo`02000BOol0021oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
01ioo`04001oogoo000cOol00`00Oomoo`09Ool00`00Oomoo`0nOol01`00Oomoogoo001oo`0000Qo
o`03001oogoo009oo`8002aoo`04001oogooOol20002Ool00`00Oomoo`0@Ool0021oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo01moo`03001oo`00039oo`03001oogoo00Yoo`03001oogoo
03ioo`07001oogooOol007oo000027oo00<007ooOol00goo00<007ooOol0:Woo00<007ooOol00Woo
00<007ooOol04goo000POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Ool0
000bOol00`00Oomoo`0;Ool00`00Oomoo`12Ool00`00Oomoo`07Ool2000/Ool01@00Oomoogoo0000
1Goo0P0057oo000POol20003Ool00`00Oomoo`0TOol200000goo001oo`0`Ool00`00Oomoo`0;Ool2
0013Ool00`00Oomoo`07Ool2000/Ool01@00Oomoogoo00001Woo00<007ooOol00P0047oo000POol0
0`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0_Ool00`00Oomoo`0;Ool20013Ool20008Ool2
000/Ool01@00Oomoogoo00001Woo00D007ooOomoo`00011oo`0087oo00D007ooOomoo`0002Yoo`03
001oogoo02ioo`8000ioo`03001oogoo045oo`8000Moo`04001oogoo000[Ool01000Oomoo`0027oo
00<007ooOol00P003goo000POol01@00Oomoogoo00000goo00<007ooOol097oo00<007ooOol0;Woo
0P003Woo00<007ooOol0>goo00<007ooOol00Woo00<007ooOol01goo00@007ooOol000Eoo`8002Ao
o`04001oogoo0008Ool01@00Oomoogoo00003goo000POol01@00Oomoogoo00000Woo0P009goo00<0
07ooOol0;Goo00<007ooOol03Goo0`00>goo00<007ooOol00Woo00<007ooOol01Woo0P000goo00<0
07ooOol00goo00<007ooOol09Goo00<007ooOol01Woo00@007ooOomoo`8000ioo`0087oo00H007oo
Oomoo`00Ool2000VOol3000_Ool00`00Oomoo`0>Ool2000kOol00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0UOol00`00Oomoo`07Ool01@00Oomoogoo
00003Woo000POol01@00Oomoo`00Ool00P00:7oo0P00;goo00<007ooOol03Woo0`00?goo00<007oo
Ool02goo0P001Goo00<007ooOol097oo00<007ooOol01goo00<007ooOol047oo000POol00`00Oomo
o`03000YOol2000^Ool00`00Oomoo`0?Ool00`00Ool0000jOol00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol08goo00<007ooOol027oo0P004Goo000P
Ool200000goo001oo`0ZOol3000]Ool2000AOol3000iOol01@00Oomoogoo00001Woo0P001goo0P00
:7oo00<007oo00002goo00<007ooOol03goo000POol01000Oomoo`00;7oo0P00;Goo0P004Goo00<0
07ooOol0>Goo00D007ooOomoo`00011oo`03001oogoo02Ioo`03001oo`0000]oo`03001oogoo00mo
o`0087oo00<007oo0000;Goo0P00;Goo0P004Goo00<007ooOol0>Goo00D007ooOomoo`00015oo`03
001oogoo02Eoo`03001oo`0000aoo`03001oogoo00ioo`0087oo00<007oo0000;Woo00<007ooOol0
:goo0P004Woo00<007ooOol0>7oo00D007ooOomoo`00015oo`8002Ioo`03001oo`0000aoo`03001o
ogoo00ioo`0087oo0`009goo10000goo0P0017oo0P0097oo10000Woo0P0017oo0P0027oo00<007oo
Ool067oo0P0017oo0P0017oo0P004Woo00D007ooOomoo`0000eoo`8000=oo`<0009oo`04001oo`00
000MOol00`00Ool000030004Ool20004Ool20004Ool20009Ool0021oo`8002Uoo`03001oogoo009o
o`04001oo`000002Ool01000Oomoo`0097oo00D007oo001oo`00009oo`04001oogoo0002Ool00`00
Oomoo`05Ool01000Oomoo`005Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0057oo
00<007ooOol02goo00@007ooOol0009oo`@00003Ool00000009oo`03001oogoo01Yoo`05001oo`00
Ool00004Ool01000Oomoo`000Woo00@007oo0000009oo`04001oogoo0008Ool0021oo`03001oogoo
02Uoo`06001oogooOol007oo0P000Woo00@007ooOol0029oo`D00005Ool007ooOol00002Ool01000
Oomoo`0027oo00@007ooOol001Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol001Ao
o`03001oogoo00]oo`04001oogoo0002Ool00`00Oomoo`07000NOol00`00Ool00004Ool01000Oomo
o`000Woo00<007ooOol010000Woo00<007ooOol01Woo000POol2000[Ool01@00Oomoo`00Ool00P00
0Woo00@007ooOol0011oo`80011oo`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`0027oo
00<007ooOol00P0057oo0`000goo00@007ooOol0009oo`04001oogoo000DOol00`00Oomoo`0<Ool2
0003Ool01000Oomoo`000Woo00@007oo000001ioo`03001oo`0000Aoo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol000Qoo`0087oo00<007ooOol09goo00@007ooOol0009oo`04001oo`00
0002Ool01000Oomoo`003goo00@007ooOol000moo`<000=oo`04001oogoo0002Ool01000Oomoo`00
27oo0P000Woo0P004goo00<007ooOol00goo00@007ooOol0009oo`04001oogoo000DOol00`00Oomo
o`0;Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo008001eoo`03001oo`0000Aoo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Qoo`0087oo00<007ooOol0:7oo0P0017oo
0`000goo0P0047oo00@007ooOol0011oo`8000Aoo`8000Aoo`8000Yoo`05001oogooOol0000DOol3
0003Ool20004Ool2000EOol00`00Oomoo`0<Ool20004Ool20003Ool300000goo001oo`0LOol30005
Ool20004Ool20004Ool20009Ool0021oo`03001oogoo031oo`03001oogoo01=oo`05001oogooOol0
000?Ool00`00Oomoo`0EOol2000gOol01000Oomoo`007Goo0P006goo00<007ooOol07Goo000POol0
0`00Oomoo`0`Ool00`00Oomoo`0GOol00`00Oomoo`0=Ool01000Oomoo`005Goo00<007ooOol0=7oo
00@007ooOol001moo`03001oogoo01Qoo`8001moo`0087oo00<007ooOol0<7oo00<007ooOol067oo
00<007ooOol037oo00@007ooOol001Eoo`8003Eoo`04001oogoo000OOol2000IOol2000OOol0021o
o`03001oogoo035oo`03001oogoo01Moo`03001oogoo00]oo`04001oogoo000GOol00`00Oomoo`0c
Ool01000Oomoo`0087oo00<007ooOol05goo0P007goo000POol00`00Oomoo`0aOol00`00Oomoo`0U
Ool01000Oomoo`0067oo00<007ooOol00goo0P00;Goo00@007ooOol001aoo`05001oogooOol0000I
Ool2000OOol001Yoool000d000Ioo`0087oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol02Goo00@007oo000000Qoo`03001oogoo00Moo`04001oogoo000;Ool00`00Oomo
o`02Ool01000Oomoo`0017oo00<007ooOol02Goo00<007ooOol01Woo0P000Woo00<007ooOol00P00
1goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo00002Woo00<007ooOol0
2Goo00<007ooOol017oo00@007ooOomoo`8000aoo`03001oogoo00Qoo`8000aoo`03001oogoo011o
o`0087oo00<007ooOol0<Woo0P0047oo00<007ooOol04Woo00<007ooOol077oo1@0000=oo`00Ool0
;7oo00<007ooOol077oo00D007ooOomoo`0001Qoo`03001oogoo01ioo`0087oo00<007ooOol0<Woo
0P0047oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol08Goo1@00:goo00<007ooOol07Goo
00@007ooOol001Qoo`03001oogoo01ioo`0087oo00<007ooOol0<Woo0P0047oo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol09Goo0`00:Goo00<007ooOol07Goo00D007ooOomoo`0001Moo`03
001oogoo01ioo`0087oo00<007ooOol0<Woo00<007oo00003goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol09goo0P009Woo00<007oo00008goo00<007ooOol05Goo00<007ooOol07Woo000P
Ool00`00Oomoo`0cOol2000?Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0XOol2000U
Ool00`00Ool0000SOol00`00Oomoo`0EOol00`00Oomoo`0NOol0021oo`8003Aoo`03001oogoo01Qo
o`8000Moo`03001oogoo009oo`03001oogoo02=oo`04001oogoo000TOol00`00Ool0000SOol00`00
Oomoo`0EOol00`00Oomoo`0NOol0021oo`03001oogoo03=oo`03001oogoo00ioo`@000Moo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo02=oo`05001oogooOol0000SOol2000TOol00`00Oomo
o`0EOol00`00Oomoo`0NOol0021oo`03001oogoo03=oo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo009oo`03001oogoo02=oo`8000=oo`03001oogoo021oo`80029oo`04
001oogoo000FOol00`00Oomoo`0NOol0021oo`03001oogoo03Aoo`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo00Yoo`8000=oo`03001oogoo02Eoo`04001oogooOol2000QOol2000ROol01000
Oomoo`005Goo0P0087oo000POol00`00Oomoo`0dOol00`00Ool0000:Ool00`00Ool00005Ool2000;
Ool00`00Oomoo`02Ool00`00Oomoo`0VOol01000Oomoogoo0P0087oo0P008Woo00@007ooOol001Eo
o`80021oo`0087oo00<007ooOol0=7oo00<007oo00002Goo0P0000=oo`00Ool01Goo00<007ooOol0
2Goo00<007ooOol00Woo00<007ooOol09Woo00<007ooOol00Woo0P0087oo00<007ooOol08Goo00<0
07oo00005Goo0P0087oo000POol00`00Oomoo`0eOol00`00Ool00008Ool01000Oomoo`001goo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol0<Goo00<007ooOol07Woo00<007ooOol08Goo00<0
07oo00005Goo00<007ooOol07goo000POol00`00Oomoo`0eOol00`00Ool00007Ool20002Ool00`00
Oomoo`05Ool20004Ool01@00Oomoogoo0000=Goo00<007ooOol077oo00<007ooOol08Woo00@007oo
Ool001Aoo`03001oogoo01moo`0087oo0P00=Woo00<007oo00001goo00D007ooOomoo`0000Qoo`03
001oogoo009oo`05001oogooOol0000eOol2000MOol00`00Oomoo`0UOol00`00Oomoo`0BOol00`00
Oomoo`0OOol0021oo`03001oogoo03Ioo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo00Mo
o`04001oogooOol200000goo0000000fOol00`00Oomoo`0KOol00`00Oomoo`0UOol00`00Oomoo`0B
Ool00`00Oomoo`0OOol0021oo`03001oogoo03Ioo`03001oogoo00Aoo`8000ioo`8000=oo`03001o
o`0000Ioo`03001oogoo02moo`03001oogoo01Yoo`03001oogoo02Eoo`03001oogoo015oo`80025o
o`0087oo00<007ooOol0=goo00<007ooOol00goo00<007ooOol03Woo00@007ooOomoo`<000Ioo`03
001oogoo02moo`8001]oo`03001oogoo02Eoo`03001oogoo015oo`80025oo`0087oo00<007ooOol0
=goo0P000goo00<007ooOol047oo00<007ooOol00P001Woo00<007ooOol0:Woo0P001Goo00<007oo
Ool06Goo00<007ooOol097oo00<007oo00004Woo0P008Goo000POol00`00Oomoo`0hOol4000DOol3
0007Ool00`00Oomoo`0[Ool00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`0TOol00`00Ool0
000BOol2000QOol0021oo`03001oogoo03Uoo`8001moo`03001oogoo02]oo`8000Eoo`03001oogoo
01Moo`8002Moo`80019oo`80025oo`0087oo0P00>goo00<007ooOol01Goo00<007ooOol03goo00<0
07ooOol00goo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol05Woo00<007ooOol09Woo0P00
4Woo0P008Goo000POol00`00Oomoo`0jOol00`00Oomoo`05Ool00`00Oomoo`0?Ool20004Ool00`00
Oomoo`0/Ool20005Ool00`00Oomoo`0FOol00`00Oomoo`0VOol2000BOol00`00Oomoo`0POol0021o
o`03001oogoo03]oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo03Uoo`03001oogoo01Eo
o`03001oogoo02Moo`03001oogoo011oo`03001oogoo021oo`0087oo00<007ooOol0>goo00<007oo
Ool017oo00<007ooOol047oo0P00>Woo00<007ooOol05Goo00<007ooOol0:7oo00<007ooOol03Woo
00<007ooOol08Goo000POol00`00Oomoo`0kOol00`00Oomoo`03Ool00`00Oomoo`0BOol2000jOol0
0`00Oomoo`0DOol00`00Oomoo`0XOol00`00Oomoo`0>Ool00`00Oomoo`0QOol000eoo`8000Aoo`80
00=oo`@000Aoo`03001oogoo045oo`03001oogoo01=oo`03001oogoo03Qoo`03001oogoo01=oo`80
02Yoo`03001oogoo00ioo`03001oogoo025oo`0037oo00@007ooOol000=oo`8000Aoo`03001oogoo
00Aoo`03001oogoo03aoo`03001oogoo04ioo`80009oo`H0015oo`8002Yoo`03001oogoo00ioo`03
001oo`00025oo`0037oo00@007ooOol000Yoo`03001oogoo00=oo`<003eoo`03001oogoo04ioo`<0
009oo`03001oogoo0080011oo`8002Yoo`8000moo`03001oo`00025oo`0037oo00@007ooOol000]o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo05Aoo`03001oogoo008000moo`8002Yoo`80
00moo`03001oo`00025oo`0037oo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`0nOol0
0`00Oomoo`1COol00`00Oomoo`0AOol2000[Ool00`00Oomoo`0=Ool00`00Ool0000QOol000eoo`80
00Yoo`8000Eoo`03001oogoo03ioo`<005=oo`03001oogoo011oo`03001oo`0002]oo`8000eoo`04
001oogoo000QOol0021oo`03001oogoo09Eoo`03001oogoo00moo`03001oogoo02]oo`8000eoo`04
001oogoo000QOol0021oo`03001oogoo09Eoo`03001oogoo00moo`03001oogoo02]oo`8000eoo`03
001oogoo029oo`0087oo00<007ooOol0UWoo00D007ooOomoo`0000aoo`03001oogoo02]oo`03001o
ogoo00aoo`03001oogoo029oo`0087oo00<007ooOol0UWoo00<007ooOol00Woo00<007ooOol02Goo
00<007ooOol0:goo00<007ooOol037oo00<007ooOol08Woo000POol2002GOol00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Ool0000/Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol0021oo`03001oogoo
09Moo`04001oogooOol20009Ool01000Oomoo`00;7oo00<007ooOol02goo00@007ooOol0025oo`00
87oo00<007ooOol0Ugoo00<007ooOol00Woo00<007ooOol01goo00@007ooOol002aoo`03001oogoo
00Yoo`05001oogooOol0000QOol0021oo`03001oogoo09Moo`03001oogoo009oo`03001oogoo00Mo
o`04001oogoo000/Ool00`00Ool0000:Ool01@00Oomoogoo00008Goo000POol00`00Oomoo`2HOol0
0`00Oomoo`0;Ool01000Oomoo`00;7oo00@007ooOol000Uoo`05001oogooOol0000QOol0021oo`03
001oogoo09Qoo`03001oogoo00Yoo`05001oogooOol0000]Ool00`00Ool00009Ool01000Oomoo`00
8Woo000POol00`00Oomoo`2HOol2000;Ool01@00Oomoogoo0000;Goo00<007oo00002Goo00@007oo
Ool0029oo`0087oo0P00VWoo00<007ooOol02Goo00<007ooOol0;goo00@007ooOol000Qoo`04001o
ogoo000ROol0021oo`03001oogoo09Uoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo02mo
o`04001oogoo0008Ool00`00Oomoo`0SOol0021oo`03001oogoo09Yoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo02moo`03001oogoo00Qoo`03001oogoo02Aoo`0087oo00<007ooOol0VWoo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0<7oo00<007ooOol027oo00<007ooOol097oo
000POol00`00Oomoo`2JOol20003Ool20003Ool01@00Oomoogoo0000;goo00<007ooOol01goo00<0
07ooOol097oo000POol00`00Oomoo`2KOol00`00Oomoo`06Ool01@00Oomoogoo0000;goo00<007oo
Ool01goo00D007ooOomoo`00029oo`0087oo00<007ooOol0Vgoo0P001Woo0P000goo00<007ooOol0
;Goo00D007ooOomoo`0000Eoo`05001oogooOol0000ROol0021oo`03001oogoo09aoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo02eoo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00
Oomoo`0POol0021oo`8009eoo`8000Eoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`0POol0021oo`03001oogoo09eoo`04001oogooOol20005
Ool00`00Oomoo`0^Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol087oo000POol0
0`00Oomoo`2NOol00`00Oomoo`02000fOol01@00Oomoogoo00000goo00<007ooOol00Woo00<007oo
Ool087oo000POol00`00Oomoo`2NOol5000fOol00`00Oomoo`02Ool01000Oomoo`009goo000POol0
0`00Oomoo`2ROol2000eOol00`00Oomoo`02Ool00`00Ool0000XOol000eoo`8000Aoo`8000Aoo`<0
00Aoo`03001oogoo0:=oo`03001oogoo03Aoo`07001oogooOol007oo0000:7oo000<Ool01000Oomo
o`000goo0P001Goo00<007ooOol00goo00<007ooOol0Xgoo00<007ooOol0=7oo00<007ooOol00goo
00<007ooOol09Woo000<Ool01000Oomoo`0027oo100017oo0`00Ygoo00<007ooOol0<7oo00<007oo
Ool00goo00<007ooOol09Woo000<Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0Ygoo
00<007ooOol0<Goo00D007ooOomoo`0000Eoo`03001oogoo025oo`0037oo00@007ooOol000Qoo`03
001oo`0000Eoo`03001oogoo0:Moo`03001oogoo035oo`05001oogooOol00005Ool00`00Oomoo`0Q
Ool000eoo`8000Yoo`8000Eoo`03001oogoo0:Moo`03001oogoo035oo`800004Ool007oo0004Ool0
0`00Oomoo`0QOol0021oo`03001oogoo0:Ioo`03001oogoo03=oo`<0009oo`05001oogooOol0000S
Ool0021oo`03001oogoo0>5oo`05001oogooOol0000SOol0021oo`03001oogoo0>5oo`80009oo`03
001oogoo025oo`0087oo00<007ooOol0hWoo00<007ooOol097oo000POol2003SOol00`00Oomoo`0T
Ool0021oo`03001oogoo0?moo`Yoo`0087oo00<007ooOol0ogoo2Woo000POol00`00Oomoo`3oOol:
Ool0021oo`03001oogoo0?moo`Yoo`0087oo00<007ooOol0ogoo2Woo003oOol]Ool00?moobeoo`00
ogoo;Goo001;Ool00`00Oomoo`08Ool00`00Oomoo`0OOol4002`Ool004Yoo`03001oogoo00Yoo`03
001oogoo009oo`03001oogoo01Yoo`03001oogoo06moo`03001oogoo03ioo`00@goo1@000Woo00@0
07ooOomoo`800003Ool0000000Aoo`03001oogoo009oo`03001oogoo00Uoo`<000=oo`<0009oo`06
001oo`00Ool007oo10000Woo10000goo100000=oo`0000000P000Woo10000Woo1@000Woo0`000Woo
0P0000=oo`0000001goo10000Woo1@000Woo0`000Woo1@000Woo0`0027oo0`0017oo0P000goo1000
0goo0`000Woo00<007ooOol00goo10000goo0P00<Woo0013Ool01000Oomoo`000goo00<007ooOol0
0Woo00<007oo00001Goo00<007ooOol00goo00<007ooOol01goo00L007ooOomoo`00Ool00003Ool0
2@00Ool007oo001oo`00Ool00003Ool01000Oomoo`0017oo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo
009oo`04001oogoo0003Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`03001oogoo00Ioo`03
001oogoo009oo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool01000Oomoo`00<Goo0013Ool01000Oomoo`000goo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol03Goo00<007ooOol00goo00d007ooOomoo`00Ool007oo001oo`00Ool00003
Ool01000Oomoo`0017oo1@0000=oo`0000000P000Woo100017oo00D007ooOomoo`0000=oo`03001o
o`00009oo`03001oogoo00Moo`03001oogoo009oo`@000=oo`03001oogoo00Aoo`05001oogooOol0
0003Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOomoo`@000=oo`03
001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`0_Ool004=oo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`0000=oo`09001oo`00
Ool007oo001oo`0000=oo`03001oogoo008000=oo`07001oogooOol007oo00001Goo00<007ooOol0
1Goo00D007ooOomoo`0000=oo`03001oo`00009oo`03001oogoo00Moo`8000Ioo`05001oogooOol0
0006Ool01@00Oomoogoo00000goo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol000Eoo`06
001oogoo001oo`001Goo00<007ooOol017oo00@007ooOol0009oo`03001oogoo02moo`00@Woo0P00
00=oo`0000000goo00@007ooOomoo`800003Ool0000000Aoo`03001oogoo00ioo`@0009oo`<00003
Ool0000000T0009oo`800003Ool00000009oo`<0009oo`@0009oo`@000=oo`8000Aoo`<00003Ool0
000000<000Qoo`800003Ool00000009oo`<0009oo`@000=oo`8000Aoo`<000Uoo`03001oogoo009o
o`04001oogoo0002Ool01000Oomoo`000Woo00<007oo00001Goo00D007ooOomoo`00009oo`04001o
ogoo0002Ool00`00Oomoo`0_Ool004]oo`03001oogoo00Qoo`03001oogoo06=oo`03001oogoo01Ao
o`8000Eoo`8000Aoo`8000Aoo`8000Ioo`04001oogooOol20004Ool2000bOol009Uoo`03001oogoo
021oo`03001oogoo00Aoo`03001oogoo02Qoo`03001oogoo03]oo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-131.714, -0.63013, 4.0235, 
  0.0066962}},
  CellTags->"S2.1.1"]
}, Open  ]],

Cell["2.1.2 Denoising", "Subsection",
  CellTags->{"S2.1.2", "2.1"}],

Cell[TextData[{
  "The removal of noise from noisy data to obtain the unknown signal is often \
referred to as denoising. We can use what is called the wavelet shrinkage \
method to accomplish this. The idea is to first represent the data in terms \
of a wavelet basis, then the coefficients that are below a certain threshold \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " are set to zero and those above ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " are \"shrunk by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.2"],
  "\". That is, the new coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_i\)\&~\)\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " after shrinkage is"
}], "Text",
  CellTags->{"S2.1.2", "2.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(c\_i\)\&~\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    
                    StyleBox[
                      \( \[VerticalSeparator] c\_i \[VerticalSeparator]  < 
                        \[Tau]\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox[
                  RowBox[{
                    StyleBox[\("sign"\),
                      "TI"], \((c\_i)\), 
                    \(( \[VerticalSeparator] c\_i \[VerticalSeparator] -
                        \[Tau])\)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{
                    RowBox[{\(" if "\), 
                      
                      StyleBox[
                        \( \[VerticalSeparator] c\_i \[VerticalSeparator]  
                          \[GreaterEqual] \[Tau]\),
                        "DisplayFormula"]}], "."}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S2.1.2", "2.3"}],

Cell[TextData[{
  "The threshold ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " determines how much noise we want to suppress, and the larger the \
variance of the noise, the larger should ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " be. For more details on the shrinkage method, see Donoho (1992) and \
Donoho and Johnstone (1994) and the references therein. Here we give one \
example showing how denoising is done using this package. It should be \
emphasized that to do denoising, one must have some understanding of what \
constitutes the signal and what constitutes noise. \nWe will use the solution \
to a stochastically driven Burgers equation to illustrate the method. We add \
to the equation in (",
  ButtonBox["1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.3"},
    ButtonStyle->"AddOnsLink"],
  ") a noise that has long\[Hyphen]ranged correlations in space, but is \
uncorrelated in time. In contrast to (spatial) white noise which suppresses \
the shocks, the noise used is expected to preserve the shock structure that \
occurs in the deterministic equation; the denoising is performed to focus on \
the larger shocks. Note that the smoothness of the denoised data depends on \
the smoothness of the wavelets used, as well as on the threshold. \nThe file \
",
  StyleBox["shocknoi.dat", "MR"],
  " contains the solution to the noisy Burgers equation obtained using a \
pseudo\[Hyphen]spectral method. "
}], "Text",
  CellTags->{"S2.1.2", "2.4"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.2", "2.5"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.2"],

Cell["This reads in the content of the file.", "MathCaption",
  CellTags->{"S2.1.2", "2.6"}],

Cell["data = Get[ToFileName[{\"Wavelets\", \"Data\"},\"shocknoi.dat\"]];", 
  "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.2"],

Cell["This plots the data.", "MathCaption",
  CellTags->{"S2.1.2", "2.7"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[data, PlotJoined -> True,
AxesLabel -> {\"x\", \"u(x)\"}]\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.372686 0.130319 [
[.25632 .36019 -12 -9 ]
[.25632 .36019 12 0 ]
[.48884 .36019 -12 -9 ]
[.48884 .36019 12 0 ]
[.72135 .36019 -12 -9 ]
[.72135 .36019 12 0 ]
[.95387 .36019 -12 -9 ]
[.95387 .36019 12 0 ]
[1.025 .37269 0 -4.5 ]
[1.025 .37269 6 4.5 ]
[.01131 .11205 -12 -4.5 ]
[.01131 .11205 0 4.5 ]
[.01131 .24237 -12 -4.5 ]
[.01131 .24237 0 4.5 ]
[.01131 .503 -6 -4.5 ]
[.01131 .503 0 4.5 ]
[.02381 .64303 -12 0 ]
[.02381 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 .37269 m
.25632 .37894 L
s
[(1000)] .25632 .36019 0 1 Mshowa
.48884 .37269 m
.48884 .37894 L
s
[(2000)] .48884 .36019 0 1 Mshowa
.72135 .37269 m
.72135 .37894 L
s
[(3000)] .72135 .36019 0 1 Mshowa
.95387 .37269 m
.95387 .37894 L
s
[(4000)] .95387 .36019 0 1 Mshowa
.125 Mabswid
.07031 .37269 m
.07031 .37644 L
s
.11682 .37269 m
.11682 .37644 L
s
.16332 .37269 m
.16332 .37644 L
s
.20982 .37269 m
.20982 .37644 L
s
.30283 .37269 m
.30283 .37644 L
s
.34933 .37269 m
.34933 .37644 L
s
.39583 .37269 m
.39583 .37644 L
s
.44234 .37269 m
.44234 .37644 L
s
.53534 .37269 m
.53534 .37644 L
s
.58185 .37269 m
.58185 .37644 L
s
.62835 .37269 m
.62835 .37644 L
s
.67485 .37269 m
.67485 .37644 L
s
.76786 .37269 m
.76786 .37644 L
s
.81436 .37269 m
.81436 .37644 L
s
.86086 .37269 m
.86086 .37644 L
s
.90737 .37269 m
.90737 .37644 L
s
.25 Mabswid
0 .37269 m
1 .37269 L
s
[(x)] 1.025 .37269 -1 0 Mshowa
.02381 .11205 m
.03006 .11205 L
s
[(-2)] .01131 .11205 1 0 Mshowa
.02381 .24237 m
.03006 .24237 L
s
[(-1)] .01131 .24237 1 0 Mshowa
.02381 .503 m
.03006 .503 L
s
[(1)] .01131 .503 1 0 Mshowa
.125 Mabswid
.02381 .13811 m
.02756 .13811 L
s
.02381 .16418 m
.02756 .16418 L
s
.02381 .19024 m
.02756 .19024 L
s
.02381 .2163 m
.02756 .2163 L
s
.02381 .26843 m
.02756 .26843 L
s
.02381 .29449 m
.02756 .29449 L
s
.02381 .32056 m
.02756 .32056 L
s
.02381 .34662 m
.02756 .34662 L
s
.02381 .39875 m
.02756 .39875 L
s
.02381 .42481 m
.02756 .42481 L
s
.02381 .45088 m
.02756 .45088 L
s
.02381 .47694 m
.02756 .47694 L
s
.02381 .08598 m
.02756 .08598 L
s
.02381 .05992 m
.02756 .05992 L
s
.02381 .03386 m
.02756 .03386 L
s
.02381 .00779 m
.02756 .00779 L
s
.02381 .52907 m
.02756 .52907 L
s
.02381 .55513 m
.02756 .55513 L
s
.02381 .5812 m
.02756 .5812 L
s
.02381 .60726 m
.02756 .60726 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02404 .50335 m
.02427 .50146 L
.02451 .5031 L
.02474 .50532 L
.02497 .50294 L
.0252 .49449 L
.02544 .49788 L
.02567 .49974 L
.0259 .50436 L
.02613 .49961 L
.02637 .49009 L
.0266 .47622 L
.02683 .46559 L
.02706 .4631 L
.0273 .46731 L
.02753 .46838 L
.02776 .46365 L
.02799 .46017 L
.02823 .46464 L
.02846 .46203 L
.02869 .46169 L
.02892 .46593 L
.02916 .47231 L
.02939 .46853 L
.02962 .47382 L
.02985 .47612 L
.03009 .48005 L
.03032 .48487 L
.03055 .48823 L
.03078 .49122 L
.03102 .49682 L
.03125 .49688 L
.03148 .50042 L
.03172 .49922 L
.03195 .50249 L
.03218 .50963 L
.03241 .51651 L
.03265 .52072 L
.03288 .51898 L
.03311 .51406 L
.03334 .51681 L
.03358 .52359 L
.03381 .52337 L
.03404 .51738 L
.03427 .51019 L
.03451 .50669 L
.03474 .50571 L
.03497 .50648 L
.0352 .51029 L
.03544 .51626 L
Mistroke
.03567 .52037 L
.0359 .52245 L
.03613 .52572 L
.03637 .53029 L
.0366 .53165 L
.03683 .53085 L
.03706 .53393 L
.0373 .53661 L
.03753 .53472 L
.03776 .53133 L
.03799 .52897 L
.03823 .52907 L
.03846 .52684 L
.03869 .52798 L
.03892 .52664 L
.03916 .52072 L
.03939 .51975 L
.03962 .51442 L
.03985 .50393 L
.04009 .49059 L
.04032 .48932 L
.04055 .48861 L
.04078 .48528 L
.04102 .48074 L
.04125 .48511 L
.04148 .48993 L
.04171 .49252 L
.04195 .4918 L
.04218 .49393 L
.04241 .4913 L
.04264 .49133 L
.04288 .49539 L
.04311 .50223 L
.04334 .49469 L
.04357 .48956 L
.04381 .48781 L
.04404 .49122 L
.04427 .4961 L
.0445 .49151 L
.04474 .48331 L
.04497 .47623 L
.0452 .4607 L
.04543 .43978 L
.04567 .4158 L
.0459 .39079 L
.04613 .371 L
.04636 .36313 L
.0466 .36044 L
.04683 .35986 L
.04706 .35685 L
Mistroke
.04729 .36124 L
.04753 .3602 L
.04776 .36351 L
.04799 .36751 L
.04822 .37388 L
.04846 .37605 L
.04869 .3757 L
.04892 .37093 L
.04915 .36587 L
.04939 .35633 L
.04962 .34745 L
.04985 .34118 L
.05008 .34264 L
.05032 .34018 L
.05055 .3365 L
.05078 .33184 L
.05101 .33193 L
.05125 .32984 L
.05148 .33487 L
.05171 .34203 L
.05194 .35857 L
.05218 .36599 L
.05241 .37253 L
.05264 .37479 L
.05287 .37477 L
.05311 .37365 L
.05334 .37329 L
.05357 .37908 L
.0538 .38636 L
.05404 .39024 L
.05427 .39781 L
.0545 .39912 L
.05473 .40184 L
.05497 .40164 L
.0552 .41241 L
.05543 .42134 L
.05566 .43307 L
.0559 .44272 L
.05613 .44376 L
.05636 .43986 L
.05659 .43717 L
.05683 .43193 L
.05706 .43411 L
.05729 .43659 L
.05752 .44282 L
.05776 .44598 L
.05799 .44536 L
.05822 .44142 L
.05845 .44312 L
.05869 .44019 L
Mistroke
.05892 .43661 L
.05915 .43259 L
.05938 .42264 L
.05962 .41514 L
.05985 .40891 L
.06008 .40212 L
.06031 .39286 L
.06055 .38759 L
.06078 .38216 L
.06101 .37934 L
.06124 .37439 L
.06148 .37244 L
.06171 .3733 L
.06194 .37167 L
.06217 .37599 L
.06241 .375 L
.06264 .38265 L
.06287 .38336 L
.0631 .38475 L
.06334 .38407 L
.06357 .3916 L
.0638 .38684 L
.06403 .39039 L
.06427 .39181 L
.0645 .39324 L
.06473 .39639 L
.06496 .39776 L
.0652 .39674 L
.06543 .39474 L
.06566 .38893 L
.06589 .38848 L
.06613 .38762 L
.06636 .38168 L
.06659 .37222 L
.06682 .36961 L
.06706 .36891 L
.06729 .3712 L
.06752 .37391 L
.06775 .37744 L
.06799 .38029 L
.06822 .38585 L
.06845 .38069 L
.06868 .37099 L
.06892 .37028 L
.06915 .36906 L
.06938 .36651 L
.06961 .36846 L
.06985 .36418 L
.07008 .36041 L
.07031 .35477 L
Mistroke
.07055 .34989 L
.07078 .34537 L
.07101 .3471 L
.07124 .33708 L
.07148 .33872 L
.07171 .34413 L
.07194 .35094 L
.07217 .35422 L
.07241 .37173 L
.07264 .37847 L
.07287 .38734 L
.0731 .39125 L
.07334 .39717 L
.07357 .39697 L
.0738 .39755 L
.07403 .39216 L
.07427 .38878 L
.0745 .3858 L
.07473 .38518 L
.07496 .38905 L
.0752 .38875 L
.07543 .38737 L
.07566 .38624 L
.07589 .37741 L
.07613 .375 L
.07636 .37376 L
.07659 .36482 L
.07682 .35977 L
.07706 .35437 L
.07729 .35225 L
.07752 .35458 L
.07775 .35056 L
.07799 .35461 L
.07822 .35979 L
.07845 .36752 L
.07868 .36621 L
.07892 .37278 L
.07915 .37365 L
.07938 .37746 L
.07961 .37901 L
.07985 .38308 L
.08008 .3827 L
.08031 .39238 L
.08054 .40179 L
.08078 .40557 L
.08101 .40208 L
.08124 .40078 L
.08147 .40324 L
.08171 .4128 L
.08194 .4139 L
Mistroke
.08217 .41712 L
.0824 .42091 L
.08264 .42592 L
.08287 .42392 L
.0831 .42248 L
.08333 .41266 L
.08357 .40239 L
.0838 .40124 L
.08403 .40292 L
.08426 .40483 L
.0845 .40348 L
.08473 .3991 L
.08496 .39515 L
.08519 .39021 L
.08543 .39025 L
.08566 .38811 L
.08589 .3867 L
.08612 .39041 L
.08636 .39433 L
.08659 .39033 L
.08682 .39436 L
.08705 .39812 L
.08729 .40609 L
.08752 .40839 L
.08775 .41333 L
.08798 .41707 L
.08822 .42121 L
.08845 .42939 L
.08868 .43045 L
.08891 .41897 L
.08915 .39744 L
.08938 .36733 L
.08961 .3506 L
.08984 .33902 L
.09008 .32724 L
.09031 .31379 L
.09054 .31297 L
.09077 .30437 L
.09101 .29028 L
.09124 .27482 L
.09147 .2712 L
.0917 .26718 L
.09194 .26421 L
.09217 .26561 L
.0924 .26772 L
.09263 .26551 L
.09287 .27199 L
.0931 .27206 L
.09333 .27677 L
.09356 .27194 L
Mistroke
.0938 .27481 L
.09403 .27626 L
.09426 .2836 L
.09449 .28566 L
.09473 .29392 L
.09496 .29776 L
.09519 .29678 L
.09542 .30018 L
.09566 .30664 L
.09589 .30499 L
.09612 .30504 L
.09635 .30065 L
.09659 .30916 L
.09682 .30979 L
.09705 .31398 L
.09728 .31253 L
.09752 .31239 L
.09775 .31387 L
.09798 .31392 L
.09821 .3088 L
.09845 .30366 L
.09868 .29524 L
.09891 .29625 L
.09914 .29467 L
.09938 .30075 L
.09961 .3046 L
.09984 .31453 L
.10007 .3156 L
.10031 .31907 L
.10054 .31963 L
.10077 .31348 L
.101 .30983 L
.10124 .31143 L
.10147 .30638 L
.1017 .31075 L
.10193 .30466 L
.10217 .2979 L
.1024 .28174 L
.10263 .28031 L
.10286 .28347 L
.1031 .28267 L
.10333 .2794 L
.10356 .28829 L
.10379 .29449 L
.10403 .31159 L
.10426 .32159 L
.10449 .33411 L
.10472 .33333 L
.10496 .33858 L
.10519 .3392 L
Mistroke
.10542 .33886 L
.10565 .33149 L
.10589 .33321 L
.10612 .32785 L
.10635 .33358 L
.10658 .33593 L
.10682 .33962 L
.10705 .33434 L
.10728 .33201 L
.10751 .32982 L
.10775 .33516 L
.10798 .33737 L
.10821 .34157 L
.10844 .34129 L
.10868 .34844 L
.10891 .35417 L
.10914 .3632 L
.10938 .36137 L
.10961 .36038 L
.10984 .35307 L
.11007 .3552 L
.11031 .35286 L
.11054 .36248 L
.11077 .36037 L
.111 .36642 L
.11124 .36121 L
.11147 .36906 L
.1117 .36268 L
.11193 .35771 L
.11217 .35066 L
.1124 .35526 L
.11263 .35366 L
.11286 .3526 L
.1131 .34639 L
.11333 .35724 L
.11356 .35764 L
.11379 .36676 L
.11403 .37301 L
.11426 .3856 L
.11449 .37636 L
.11472 .37464 L
.11496 .36553 L
.11519 .37138 L
.11542 .36328 L
.11565 .36926 L
.11589 .36513 L
.11612 .3741 L
.11635 .38044 L
.11658 .39068 L
.11682 .38642 L
Mistroke
.11705 .39656 L
.11728 .39968 L
.11751 .40592 L
.11775 .40468 L
.11798 .42001 L
.11821 .42207 L
.11844 .42315 L
.11868 .41594 L
.11891 .41989 L
.11914 .41767 L
.11937 .42329 L
.11961 .41926 L
.11984 .42485 L
.12007 .4246 L
.1203 .43566 L
.12054 .43573 L
.12077 .44274 L
.121 .44186 L
.12123 .44752 L
.12147 .44916 L
.1217 .45745 L
.12193 .46056 L
.12216 .47576 L
.1224 .48174 L
.12263 .47932 L
.12286 .4728 L
.12309 .47792 L
.12333 .47853 L
.12356 .47929 L
.12379 .47219 L
.12402 .47308 L
.12426 .47311 L
.12449 .47605 L
.12472 .46868 L
.12495 .46995 L
.12519 .46622 L
.12542 .46336 L
.12565 .45459 L
.12588 .45657 L
.12612 .44713 L
.12635 .44097 L
.12658 .43784 L
.12681 .44386 L
.12705 .44422 L
.12728 .4462 L
.12751 .44564 L
.12774 .45622 L
.12798 .45909 L
.12821 .46742 L
.12844 .46765 L
Mistroke
.12867 .46786 L
.12891 .46077 L
.12914 .45926 L
.12937 .45196 L
.1296 .45365 L
.12984 .45261 L
.13007 .45669 L
.1303 .45073 L
.13053 .44414 L
.13077 .4341 L
.131 .41914 L
.13123 .403 L
.13146 .39193 L
.1317 .37528 L
.13193 .37026 L
.13216 .36256 L
.13239 .36046 L
.13263 .36122 L
.13286 .36317 L
.13309 .35587 L
.13332 .35868 L
.13356 .35066 L
.13379 .35421 L
.13402 .35578 L
.13425 .35744 L
.13449 .35979 L
.13472 .36694 L
.13495 .36235 L
.13518 .36027 L
.13542 .35399 L
.13565 .35995 L
.13588 .35999 L
.13611 .36117 L
.13635 .35315 L
.13658 .3588 L
.13681 .3557 L
.13704 .35966 L
.13728 .35197 L
.13751 .35399 L
.13774 .34824 L
.13797 .35464 L
.13821 .35651 L
.13844 .36462 L
.13867 .36247 L
.1389 .36837 L
.13914 .36234 L
.13937 .36422 L
.1396 .35531 L
.13983 .36253 L
.14007 .35924 L
Mistroke
.1403 .36166 L
.14053 .361 L
.14076 .36584 L
.141 .36439 L
.14123 .36623 L
.14146 .35552 L
.14169 .36645 L
.14193 .36999 L
.14216 .38065 L
.14239 .38381 L
.14262 .39817 L
.14286 .40453 L
.14309 .41632 L
.14332 .42319 L
.14355 .42761 L
.14379 .42009 L
.14402 .43467 L
.14425 .43391 L
.14448 .4376 L
.14472 .43645 L
.14495 .44441 L
.14518 .43386 L
.14541 .4367 L
.14565 .43826 L
.14588 .44966 L
.14611 .44632 L
.14634 .45131 L
.14658 .45248 L
.14681 .47331 L
.14704 .48358 L
.14727 .49062 L
.14751 .48722 L
.14774 .4875 L
.14797 .47772 L
.1482 .47847 L
.14844 .46792 L
.14867 .457 L
.1489 .44234 L
.14914 .43621 L
.14937 .42094 L
.1496 .41865 L
.14983 .4127 L
.15007 .42174 L
.1503 .42204 L
.15053 .42888 L
.15076 .4242 L
.151 .43253 L
.15123 .43084 L
.15146 .43818 L
.15169 .43232 L
Mistroke
.15193 .43219 L
.15216 .4223 L
.15239 .43014 L
.15262 .42951 L
.15286 .44225 L
.15309 .44381 L
.15332 .45121 L
.15355 .44702 L
.15379 .45159 L
.15402 .44963 L
.15425 .45901 L
.15448 .45693 L
.15472 .46677 L
.15495 .46429 L
.15518 .47124 L
.15541 .46816 L
.15565 .47236 L
.15588 .46822 L
.15611 .475 L
.15634 .47573 L
.15658 .4842 L
.15681 .48315 L
.15704 .4875 L
.15727 .4818 L
.15751 .48405 L
.15774 .47274 L
.15797 .46809 L
.1582 .46533 L
.15844 .46902 L
.15867 .46591 L
.1589 .47449 L
.15913 .47888 L
.15937 .48847 L
.1596 .48716 L
.15983 .49089 L
.16006 .48734 L
.1603 .49388 L
.16053 .49401 L
.16076 .4963 L
.16099 .4884 L
.16123 .48836 L
.16146 .4759 L
.16169 .48233 L
.16192 .48011 L
.16216 .48591 L
.16239 .47997 L
.16262 .47327 L
.16285 .46094 L
.16309 .4556 L
.16332 .45104 L
Mistroke
.16355 .45995 L
.16378 .46419 L
.16402 .4783 L
.16425 .47704 L
.16448 .47898 L
.16471 .47435 L
.16495 .4805 L
.16518 .48002 L
.16541 .48821 L
.16564 .48715 L
.16588 .50045 L
.16611 .49962 L
.16634 .49903 L
.16657 .4958 L
.16681 .49648 L
.16704 .48883 L
.16727 .49084 L
.1675 .4855 L
.16774 .49227 L
.16797 .4904 L
.1682 .4946 L
.16843 .48646 L
.16867 .48798 L
.1689 .48421 L
.16913 .49354 L
.16936 .49914 L
.1696 .50146 L
.16983 .49395 L
.17006 .49864 L
.17029 .49029 L
.17053 .48765 L
.17076 .48215 L
.17099 .48665 L
.17122 .48982 L
.17146 .50154 L
.17169 .49964 L
.17192 .50483 L
.17215 .50348 L
.17239 .50888 L
.17262 .50839 L
.17285 .51315 L
.17308 .51323 L
.17332 .52159 L
.17355 .5245 L
.17378 .53458 L
.17401 .53317 L
.17425 .54093 L
.17448 .53538 L
.17471 .53807 L
.17494 .5344 L
Mistroke
.17518 .53823 L
.17541 .53937 L
.17564 .54421 L
.17587 .53795 L
.17611 .53148 L
.17634 .50202 L
.17657 .44975 L
.1768 .40071 L
.17704 .38712 L
.17727 .38551 L
.1775 .39082 L
.17773 .38974 L
.17797 .40199 L
.1782 .39807 L
.17843 .40584 L
.17866 .40347 L
.1789 .41586 L
.17913 .41246 L
.17936 .43171 L
.17959 .43192 L
.17983 .44094 L
.18006 .43938 L
.18029 .44683 L
.18052 .44303 L
.18076 .45175 L
.18099 .44549 L
.18122 .45062 L
.18145 .4461 L
.18169 .4448 L
.18192 .43083 L
.18215 .43469 L
.18238 .42981 L
.18262 .44125 L
.18285 .43965 L
.18308 .45512 L
.18331 .45875 L
.18355 .47315 L
.18378 .47087 L
.18401 .48016 L
.18424 .47348 L
.18448 .47249 L
.18471 .45911 L
.18494 .46273 L
.18517 .45497 L
.18541 .4594 L
.18564 .45414 L
.18587 .45804 L
.1861 .44881 L
.18634 .44858 L
.18657 .4317 L
Mistroke
.1868 .43462 L
.18703 .42612 L
.18727 .43266 L
.1875 .43289 L
.18773 .44436 L
.18797 .43647 L
.1882 .44584 L
.18843 .43907 L
.18866 .4534 L
.1889 .45336 L
.18913 .45678 L
.18936 .45292 L
.18959 .4722 L
.18983 .46846 L
.19006 .48131 L
.19029 .47191 L
.19052 .4838 L
.19076 .48541 L
.19099 .49903 L
.19122 .49611 L
.19145 .50822 L
.19169 .50652 L
.19192 .51833 L
.19215 .51263 L
.19238 .52259 L
.19262 .51606 L
.19285 .53037 L
.19308 .53241 L
.19331 .54053 L
.19355 .54028 L
.19378 .54908 L
.19401 .54045 L
.19424 .54938 L
.19448 .54208 L
.19471 .55187 L
.19494 .54792 L
.19517 .55453 L
.19541 .54663 L
.19564 .55545 L
.19587 .55142 L
.1961 .55616 L
.19634 .54868 L
.19657 .56473 L
.1968 .56122 L
.19703 .57185 L
.19727 .56708 L
.1975 .57671 L
.19773 .57386 L
.19796 .58401 L
.1982 .56979 L
Mistroke
.19843 .57628 L
.19866 .56634 L
.19889 .57268 L
.19913 .56506 L
.19936 .57371 L
.19959 .5659 L
.19982 .57463 L
.20006 .56194 L
.20029 .57262 L
.20052 .56681 L
.20075 .57219 L
.20099 .55178 L
.20122 .55448 L
.20145 .54103 L
.20168 .55198 L
.20192 .54111 L
.20215 .55018 L
.20238 .5337 L
.20261 .54327 L
.20285 .52558 L
.20308 .5414 L
.20331 .52415 L
.20354 .5495 L
.20378 .53469 L
.20401 .57119 L
.20424 .55489 L
.20447 .5839 L
.20471 .43272 L
.20494 .21029 L
.20517 .21027 L
.2054 .19646 L
.20564 .22486 L
.20587 .21307 L
.2061 .23184 L
.20633 .21629 L
.20657 .23073 L
.2068 .21691 L
.20703 .22742 L
.20726 .20918 L
.2075 .22183 L
.20773 .21118 L
.20796 .22844 L
.20819 .23099 L
.20843 .25445 L
.20866 .25082 L
.20889 .26326 L
.20912 .25186 L
.20936 .26602 L
.20959 .25572 L
.20982 .27667 L
Mistroke
.21005 .26889 L
.21029 .27403 L
.21052 .26543 L
.21075 .27618 L
.21098 .27257 L
.21122 .28364 L
.21145 .27755 L
.21168 .27833 L
.21191 .26954 L
.21215 .27299 L
.21238 .26472 L
.21261 .27058 L
.21284 .26278 L
.21308 .27131 L
.21331 .27046 L
.21354 .28479 L
.21377 .28627 L
.21401 .29657 L
.21424 .29748 L
.21447 .30738 L
.2147 .30987 L
.21494 .32258 L
.21517 .32003 L
.2154 .3166 L
.21563 .3021 L
.21587 .20062 L
.2161 .07076 L
.21633 .0511 L
.21656 .04428 L
.2168 .0476 L
.21703 .0489 L
.21726 .05451 L
.21749 .05249 L
.21773 .06532 L
.21796 .06416 L
.21819 .06673 L
.21842 .07015 L
.21866 .0813 L
.21889 .08101 L
.21912 .09083 L
.21935 .08723 L
.21959 .09283 L
.21982 .08703 L
.22005 .091 L
.22028 .09483 L
.22052 .10563 L
.22075 .10765 L
.22098 .11435 L
.22121 .11281 L
.22145 .11571 L
Mistroke
.22168 .11036 L
.22191 .11537 L
.22214 .11026 L
.22238 .11368 L
.22261 .11268 L
.22284 .11686 L
.22307 .11766 L
.22331 .11888 L
.22354 .11102 L
.22377 .10963 L
.224 .10182 L
.22424 .09656 L
.22447 .09429 L
.2247 .10547 L
.22493 .10924 L
.22517 .1207 L
.2254 .12047 L
.22563 .12541 L
.22586 .12415 L
.2261 .12674 L
.22633 .11945 L
.22656 .11924 L
.2268 .11199 L
.22703 .10711 L
.22726 .09673 L
.22749 .09883 L
.22773 .09565 L
.22796 .10109 L
.22819 .1043 L
.22842 .11437 L
.22866 .11332 L
.22889 .11599 L
.22912 .1137 L
.22935 .11743 L
.22959 .11159 L
.22982 .11381 L
.23005 .11408 L
.23028 .1187 L
.23052 .11586 L
.23075 .11471 L
.23098 .11268 L
.23121 .11133 L
.23145 .10903 L
.23168 .11398 L
.23191 .10898 L
.23214 .11219 L
.23238 .11315 L
.23261 .11446 L
.23284 .11037 L
.23307 .10643 L
Mistroke
.23331 .1052 L
.23354 .10995 L
.23377 .11073 L
.234 .11647 L
.23424 .11621 L
.23447 .12304 L
.2347 .122 L
.23493 .12413 L
.23517 .12512 L
.2354 .13423 L
.23563 .13788 L
.23586 .14317 L
.2361 .14099 L
.23633 .13673 L
.23656 .13199 L
.23679 .13943 L
.23703 .13594 L
.23726 .14264 L
.23749 .15162 L
.23772 .16031 L
.23796 .15067 L
.23819 .15548 L
.23842 .1552 L
.23865 .15906 L
.23889 .16038 L
.23912 .16645 L
.23935 .16119 L
.23958 .16371 L
.23982 .16589 L
.24005 .1688 L
.24028 .16368 L
.24051 .16449 L
.24075 .1593 L
.24098 .15703 L
.24121 .1484 L
.24144 .13531 L
.24168 .11821 L
.24191 .0993 L
.24214 .07185 L
.24237 .05539 L
.24261 .03922 L
.24284 .03265 L
.24307 .02627 L
.2433 .02202 L
.24354 .01971 L
.24377 .02422 L
.244 .0249 L
.24423 .02958 L
.24447 .02681 L
.2447 .02788 L
Mistroke
.24493 .02305 L
.24516 .02219 L
.2454 .0203 L
.24563 .02303 L
.24586 .01891 L
.24609 .01916 L
.24633 .02312 L
.24656 .02901 L
.24679 .02237 L
.24702 .0166 L
.24726 .01491 L
.24749 .01967 L
.24772 .01571 L
.24795 .01906 L
.24819 .01472 L
.24842 .01811 L
.24865 .02409 L
.24888 .03228 L
.24912 .02752 L
.24935 .03565 L
.24958 .04159 L
.24981 .04704 L
.25005 .049 L
.25028 .04764 L
.25051 .0405 L
.25074 .03517 L
.25098 .03014 L
.25121 .02874 L
.25144 .0209 L
.25167 .0256 L
.25191 .02111 L
.25214 .02421 L
.25237 .02232 L
.2526 .02551 L
.25284 .02528 L
.25307 .02659 L
.2533 .03022 L
.25353 .03651 L
.25377 .03047 L
.254 .0249 L
.25423 .02131 L
.25446 .02459 L
.2547 .02391 L
.25493 .02377 L
.25516 .02673 L
.25539 .02505 L
.25563 .02269 L
.25586 .02367 L
.25609 .02659 L
.25632 .03084 L
Mistroke
.25656 .03562 L
.25679 .04589 L
.25702 .05075 L
.25725 .05166 L
.25749 .04608 L
.25772 .04891 L
.25795 .05003 L
.25818 .05017 L
.25842 .04462 L
.25865 .04347 L
.25888 .0383 L
.25911 .03765 L
.25935 .03999 L
.25958 .04695 L
.25981 .04826 L
.26004 .05204 L
.26028 .05178 L
.26051 .05768 L
.26074 .06 L
.26097 .06385 L
.26121 .06745 L
.26144 .0718 L
.26167 .07277 L
.2619 .08056 L
.26214 .08294 L
.26237 .081 L
.2626 .07142 L
.26283 .06884 L
.26307 .06398 L
.2633 .05901 L
.26353 .05696 L
.26376 .05939 L
.264 .06124 L
.26423 .07057 L
.26446 .06878 L
.26469 .07195 L
.26493 .07047 L
.26516 .07097 L
.26539 .0677 L
.26563 .07576 L
.26586 .07579 L
.26609 .07457 L
.26632 .08121 L
.26656 .08545 L
.26679 .08463 L
.26702 .08396 L
.26725 .08199 L
.26749 .08396 L
.26772 .08524 L
.26795 .09075 L
Mistroke
.26818 .09109 L
.26842 .0928 L
.26865 .08985 L
.26888 .09475 L
.26911 .09441 L
.26935 .09107 L
.26958 .08299 L
.26981 .07596 L
.27004 .06295 L
.27028 .05348 L
.27051 .04463 L
.27074 .04391 L
.27097 .04822 L
.27121 .05086 L
.27144 .04492 L
.27167 .05406 L
.2719 .05649 L
.27214 .06404 L
.27237 .07601 L
.2726 .08484 L
.27283 .09064 L
.27307 .09832 L
.2733 .09833 L
.27353 .09819 L
.27376 .08666 L
.274 .07554 L
.27423 .0644 L
.27446 .05826 L
.27469 .06216 L
.27493 .0726 L
.27516 .07196 L
.27539 .07344 L
.27562 .07541 L
.27586 .077 L
.27609 .08085 L
.27632 .08726 L
.27655 .09475 L
.27679 .10175 L
.27702 .10294 L
.27725 .10431 L
.27748 .10292 L
.27772 .10891 L
.27795 .10624 L
.27818 .10615 L
.27841 .09936 L
.27865 .09769 L
.27888 .09825 L
.27911 .0977 L
.27934 .08869 L
.27958 .08672 L
Mistroke
.27981 .08444 L
.28004 .08198 L
.28027 .08118 L
.28051 .08599 L
.28074 .08978 L
.28097 .09586 L
.2812 .09809 L
.28144 .10398 L
.28167 .10914 L
.2819 .11525 L
.28213 .11778 L
.28237 .11931 L
.2826 .1151 L
.28283 .11509 L
.28306 .11038 L
.2833 .1122 L
.28353 .11258 L
.28376 .11127 L
.28399 .10276 L
.28423 .09723 L
.28446 .0922 L
.28469 .08962 L
.28492 .08639 L
.28516 .08984 L
.28539 .09133 L
.28562 .09434 L
.28585 .09625 L
.28609 .09642 L
.28632 .09318 L
.28655 .09613 L
.28678 .09452 L
.28702 .09337 L
.28725 .09274 L
.28748 .09473 L
.28771 .09009 L
.28795 .08826 L
.28818 .08661 L
.28841 .08744 L
.28864 .08172 L
.28888 .08143 L
.28911 .07599 L
.28934 .07767 L
.28957 .07867 L
.28981 .07822 L
.29004 .07619 L
.29027 .0835 L
.2905 .08252 L
.29074 .0878 L
.29097 .08813 L
.2912 .09811 L
Mistroke
.29143 .10009 L
.29167 .10875 L
.2919 .10881 L
.29213 .11625 L
.29236 .11486 L
.2926 .12154 L
.29283 .11301 L
.29306 .11178 L
.29329 .11083 L
.29353 .1125 L
.29376 .11638 L
.29399 .12622 L
.29422 .12916 L
.29446 .13093 L
.29469 .12413 L
.29492 .11768 L
.29515 .11139 L
.29539 .11049 L
.29562 .10896 L
.29585 .11124 L
.29608 .11528 L
.29632 .1222 L
.29655 .12061 L
.29678 .11757 L
.29701 .11599 L
.29725 .11898 L
.29748 .11788 L
.29771 .11727 L
.29794 .11771 L
.29818 .12347 L
.29841 .12118 L
.29864 .12154 L
.29887 .12229 L
.29911 .12851 L
.29934 .12792 L
.29957 .13268 L
.2998 .14148 L
.30004 .15457 L
.30027 .15594 L
.3005 .15507 L
.30073 .14804 L
.30097 .15015 L
.3012 .14943 L
.30143 .15362 L
.30166 .15089 L
.3019 .1494 L
.30213 .14663 L
.30236 .14225 L
.30259 .13761 L
.30283 .13991 L
Mistroke
.30306 .14182 L
.30329 .15202 L
.30352 .1581 L
.30376 .16384 L
.30399 .16561 L
.30422 .16646 L
.30445 .15989 L
.30469 .15524 L
.30492 .15251 L
.30515 .14862 L
.30539 .14009 L
.30562 .13787 L
.30585 .13729 L
.30608 .13634 L
.30632 .13106 L
.30655 .13007 L
.30678 .13092 L
.30701 .13443 L
.30725 .13335 L
.30748 .13826 L
.30771 .14011 L
.30794 .14692 L
.30818 .13889 L
.30841 .13606 L
.30864 .1272 L
.30887 .12971 L
.30911 .13291 L
.30934 .13666 L
.30957 .13562 L
.3098 .12797 L
.31004 .12349 L
.31027 .12816 L
.3105 .13329 L
.31073 .13609 L
.31097 .13516 L
.3112 .13548 L
.31143 .13855 L
.31166 .14878 L
.3119 .14816 L
.31213 .15356 L
.31236 .15526 L
.31259 .153 L
.31283 .15639 L
.31306 .1619 L
.31329 .15921 L
.31352 .1684 L
.31376 .17326 L
.31399 .17418 L
.31422 .16751 L
.31445 .16162 L
Mistroke
.31469 .15045 L
.31492 .1433 L
.31515 .14034 L
.31538 .14501 L
.31562 .1434 L
.31585 .15305 L
.31608 .15541 L
.31631 .15293 L
.31655 .14819 L
.31678 .14741 L
.31701 .14402 L
.31724 .14565 L
.31748 .138 L
.31771 .1254 L
.31794 .11666 L
.31817 .11059 L
.31841 .11048 L
.31864 .11159 L
.31887 .10694 L
.3191 .10682 L
.31934 .10256 L
.31957 .10099 L
.3198 .08896 L
.32003 .08398 L
.32027 .08157 L
.3205 .08424 L
.32073 .08966 L
.32096 .09171 L
.3212 .09545 L
.32143 .10354 L
.32166 .1041 L
.32189 .10065 L
.32213 .10234 L
.32236 .11338 L
.32259 .11925 L
.32282 .12634 L
.32306 .12739 L
.32329 .13204 L
.32352 .13794 L
.32375 .13738 L
.32399 .12972 L
.32422 .12921 L
.32445 .13368 L
.32468 .14148 L
.32492 .15075 L
.32515 .16015 L
.32538 .15965 L
.32561 .16849 L
.32585 .17693 L
.32608 .17947 L
Mistroke
.32631 .17866 L
.32654 .17809 L
.32678 .17492 L
.32701 .17011 L
.32724 .1574 L
.32747 .14842 L
.32771 .13412 L
.32794 .11597 L
.32817 .10721 L
.3284 .10866 L
.32864 .10983 L
.32887 .10567 L
.3291 .09895 L
.32933 .10029 L
.32957 .09785 L
.3298 .09783 L
.33003 .0972 L
.33026 .10085 L
.3305 .10418 L
.33073 .10938 L
.33096 .11244 L
.33119 .11236 L
.33143 .10934 L
.33166 .10755 L
.33189 .10156 L
.33212 .10403 L
.33236 .0998 L
.33259 .09834 L
.33282 .0993 L
.33305 .09976 L
.33329 .10045 L
.33352 .10406 L
.33375 .10469 L
.33398 .1103 L
.33422 .1087 L
.33445 .10883 L
.33468 .11035 L
.33491 .11231 L
.33515 .1099 L
.33538 .11482 L
.33561 .11755 L
.33584 .13019 L
.33608 .12939 L
.33631 .12753 L
.33654 .12559 L
.33677 .12431 L
.33701 .11923 L
.33724 .11934 L
.33747 .11864 L
.3377 .12042 L
Mistroke
.33794 .1214 L
.33817 .12365 L
.3384 .11877 L
.33863 .11636 L
.33887 .11163 L
.3391 .11634 L
.33933 .11513 L
.33956 .11795 L
.3398 .11803 L
.34003 .11798 L
.34026 .11776 L
.34049 .12754 L
.34073 .13137 L
.34096 .13857 L
.34119 .14158 L
.34142 .14728 L
.34166 .14508 L
.34189 .14599 L
.34212 .13742 L
.34235 .1398 L
.34259 .13718 L
.34282 .14169 L
.34305 .14738 L
.34328 .14988 L
.34352 .1462 L
.34375 .1481 L
.34398 .15156 L
.34422 .15791 L
.34445 .16013 L
.34468 .16497 L
.34491 .16722 L
.34515 .17461 L
.34538 .17696 L
.34561 .18567 L
.34584 .18757 L
.34608 .19226 L
.34631 .19272 L
.34654 .19269 L
.34677 .18491 L
.34701 .17856 L
.34724 .16967 L
.34747 .17409 L
.3477 .17164 L
.34794 .17193 L
.34817 .17195 L
.3484 .17265 L
.34863 .16659 L
.34887 .169 L
.3491 .16832 L
.34933 .17477 L
Mistroke
.34956 .17461 L
.3498 .17875 L
.35003 .18306 L
.35026 .18826 L
.35049 .19277 L
.35073 .19956 L
.35096 .19733 L
.35119 .20273 L
.35142 .21346 L
.35166 .22811 L
.35189 .23241 L
.35212 .23831 L
.35235 .23006 L
.35259 .23202 L
.35282 .23169 L
.35305 .2395 L
.35328 .24122 L
.35352 .24761 L
.35375 .25006 L
.35398 .26095 L
.35421 .2627 L
.35445 .2709 L
.35468 .27216 L
.35491 .28047 L
.35514 .27962 L
.35538 .28056 L
.35561 .27778 L
.35584 .28121 L
.35607 .28567 L
.35631 .29998 L
.35654 .30574 L
.35677 .31199 L
.357 .3137 L
.35724 .32067 L
.35747 .31832 L
.3577 .31571 L
.35793 .31018 L
.35817 .30525 L
.3584 .29737 L
.35863 .29167 L
.35886 .288 L
.3591 .28424 L
.35933 .27374 L
.35956 .26926 L
.35979 .26156 L
.36003 .25307 L
.36026 .24613 L
.36049 .25136 L
.36072 .24646 L
.36096 .24366 L
Mistroke
.36119 .24273 L
.36142 .24011 L
.36165 .23522 L
.36189 .23394 L
.36212 .2296 L
.36235 .23063 L
.36258 .23152 L
.36282 .23764 L
.36305 .2386 L
.36328 .24287 L
.36351 .24145 L
.36375 .24964 L
.36398 .25622 L
.36421 .26501 L
.36444 .25957 L
.36468 .26183 L
.36491 .25976 L
.36514 .25968 L
.36537 .25245 L
.36561 .24864 L
.36584 .24823 L
.36607 .25267 L
.3663 .24662 L
.36654 .24399 L
.36677 .24004 L
.367 .24366 L
.36723 .24944 L
.36747 .2532 L
.3677 .24909 L
.36793 .24437 L
.36816 .23207 L
.3684 .23681 L
.36863 .23712 L
.36886 .23367 L
.36909 .23307 L
.36933 .2335 L
.36956 .2314 L
.36979 .22959 L
.37002 .22238 L
.37026 .2164 L
.37049 .19982 L
.37072 .18119 L
.37095 .16535 L
.37119 .15837 L
.37142 .15105 L
.37165 .1508 L
.37188 .14688 L
.37212 .14699 L
.37235 .14782 L
.37258 .14929 L
Mistroke
.37281 .15137 L
.37305 .15586 L
.37328 .15742 L
.37351 .16529 L
.37374 .16085 L
.37398 .16747 L
.37421 .16968 L
.37444 .1713 L
.37467 .17435 L
.37491 .17789 L
.37514 .17759 L
.37537 .18837 L
.3756 .18792 L
.37584 .18642 L
.37607 .17527 L
.3763 .18279 L
.37653 .188 L
.37677 .1967 L
.377 .20066 L
.37723 .20648 L
.37746 .21193 L
.3777 .2193 L
.37793 .21499 L
.37816 .21164 L
.37839 .20883 L
.37863 .20646 L
.37886 .20078 L
.37909 .20152 L
.37932 .19916 L
.37956 .20818 L
.37979 .2086 L
.38002 .21118 L
.38025 .21408 L
.38049 .21184 L
.38072 .20749 L
.38095 .21136 L
.38118 .21218 L
.38142 .21893 L
.38165 .21578 L
.38188 .21685 L
.38211 .21287 L
.38235 .21906 L
.38258 .22129 L
.38281 .229 L
.38305 .23037 L
.38328 .23623 L
.38351 .23617 L
.38374 .23468 L
.38398 .22642 L
.38421 .22331 L
Mistroke
.38444 .21839 L
.38467 .22249 L
.38491 .22588 L
.38514 .23002 L
.38537 .23354 L
.3856 .23564 L
.38584 .2323 L
.38607 .23133 L
.3863 .22699 L
.38653 .23189 L
.38677 .23384 L
.387 .23747 L
.38723 .233 L
.38746 .22483 L
.3877 .22236 L
.38793 .2264 L
.38816 .22753 L
.38839 .23115 L
.38863 .22338 L
.38886 .22278 L
.38909 .22235 L
.38932 .22168 L
.38956 .21834 L
.38979 .2214 L
.39002 .21844 L
.39025 .21889 L
.39049 .21249 L
.39072 .21288 L
.39095 .20822 L
.39118 .20938 L
.39142 .20724 L
.39165 .20298 L
.39188 .19466 L
.39211 .19501 L
.39235 .18903 L
.39258 .18371 L
.39281 .18372 L
.39304 .189 L
.39328 .18638 L
.39351 .18511 L
.39374 .18622 L
.39397 .19217 L
.39421 .19137 L
.39444 .19965 L
.39467 .20455 L
.3949 .21021 L
.39514 .20963 L
.39537 .2083 L
.3956 .20243 L
.39583 .20604 L
Mistroke
.39607 .20869 L
.3963 .22156 L
.39653 .23152 L
.39676 .2398 L
.397 .23977 L
.39723 .24658 L
.39746 .24733 L
.39769 .25742 L
.39793 .25701 L
.39816 .26055 L
.39839 .25988 L
.39862 .26471 L
.39886 .26096 L
.39909 .25652 L
.39932 .24907 L
.39955 .24985 L
.39979 .23998 L
.40002 .24066 L
.40025 .2329 L
.40048 .22899 L
.40072 .22732 L
.40095 .23072 L
.40118 .22978 L
.40141 .23644 L
.40165 .23428 L
.40188 .23237 L
.40211 .2307 L
.40234 .23268 L
.40258 .22605 L
.40281 .22564 L
.40304 .22435 L
.40327 .22834 L
.40351 .22216 L
.40374 .22087 L
.40397 .22609 L
.4042 .22946 L
.40444 .228 L
.40467 .23195 L
.4049 .23353 L
.40513 .23804 L
.40537 .23249 L
.4056 .23234 L
.40583 .23399 L
.40606 .23097 L
.4063 .22735 L
.40653 .23313 L
.40676 .23779 L
.40699 .24389 L
.40723 .2426 L
.40746 .2449 L
Mistroke
.40769 .24364 L
.40792 .24562 L
.40816 .24927 L
.40839 .26046 L
.40862 .25957 L
.40885 .26013 L
.40909 .25518 L
.40932 .26186 L
.40955 .26398 L
.40978 .26297 L
.41002 .25813 L
.41025 .2585 L
.41048 .25343 L
.41071 .25865 L
.41095 .26195 L
.41118 .26205 L
.41141 .25538 L
.41164 .25806 L
.41188 .25192 L
.41211 .24745 L
.41234 .24092 L
.41257 .23552 L
.41281 .23228 L
.41304 .23372 L
.41327 .23076 L
.4135 .23404 L
.41374 .22762 L
.41397 .22671 L
.4142 .23045 L
.41443 .24223 L
.41467 .25257 L
.4149 .26469 L
.41513 .26377 L
.41536 .26676 L
.4156 .26249 L
.41583 .26741 L
.41606 .27064 L
.41629 .27729 L
.41653 .28104 L
.41676 .28477 L
.41699 .27753 L
.41722 .27438 L
.41746 .26618 L
.41769 .25023 L
.41792 .2261 L
.41815 .21072 L
.41839 .20831 L
.41862 .21075 L
.41885 .20836 L
.41908 .21093 L
Mistroke
.41932 .21314 L
.41955 .22615 L
.41978 .23092 L
.42001 .23773 L
.42025 .24086 L
.42048 .2475 L
.42071 .25075 L
.42094 .25966 L
.42118 .25901 L
.42141 .26395 L
.42164 .26561 L
.42188 .26688 L
.42211 .26292 L
.42234 .25878 L
.42257 .26075 L
.42281 .26741 L
.42304 .26685 L
.42327 .27232 L
.4235 .27089 L
.42374 .27411 L
.42397 .27594 L
.4242 .28573 L
.42443 .28563 L
.42467 .29158 L
.4249 .2913 L
.42513 .29537 L
.42536 .29253 L
.4256 .29115 L
.42583 .29278 L
.42606 .30066 L
.42629 .30535 L
.42653 .31558 L
.42676 .30994 L
.42699 .31676 L
.42722 .31938 L
.42746 .32304 L
.42769 .32696 L
.42792 .33043 L
.42815 .33221 L
.42839 .33644 L
.42862 .33427 L
.42885 .33252 L
.42908 .32913 L
.42932 .32973 L
.42955 .32813 L
.42978 .32359 L
.43001 .32729 L
.43025 .34019 L
.43048 .34109 L
.43071 .33733 L
Mistroke
.43094 .33252 L
.43118 .33216 L
.43141 .32404 L
.43164 .3158 L
.43187 .30318 L
.43211 .30044 L
.43234 .29824 L
.43257 .2983 L
.4328 .2984 L
.43304 .30164 L
.43327 .30524 L
.4335 .30906 L
.43373 .30123 L
.43397 .30077 L
.4342 .30409 L
.43443 .30146 L
.43466 .29653 L
.4349 .29408 L
.43513 .29239 L
.43536 .29635 L
.43559 .28988 L
.43583 .28915 L
.43606 .28054 L
.43629 .28114 L
.43652 .28141 L
.43676 .28482 L
.43699 .27898 L
.43722 .2807 L
.43745 .27978 L
.43769 .28949 L
.43792 .28829 L
.43815 .29314 L
.43838 .29876 L
.43862 .30865 L
.43885 .31484 L
.43908 .31847 L
.43931 .31673 L
.43955 .31029 L
.43978 .30541 L
.44001 .30272 L
.44024 .29997 L
.44048 .30097 L
.44071 .29831 L
.44094 .30255 L
.44117 .30008 L
.44141 .30092 L
.44164 .29679 L
.44187 .29703 L
.4421 .29982 L
.44234 .30248 L
Mistroke
.44257 .29789 L
.4428 .30226 L
.44303 .29987 L
.44327 .30061 L
.4435 .29575 L
.44373 .29841 L
.44396 .29705 L
.4442 .29796 L
.44443 .29623 L
.44466 .30655 L
.44489 .30718 L
.44513 .30909 L
.44536 .31277 L
.44559 .31511 L
.44582 .31418 L
.44606 .32425 L
.44629 .32728 L
.44652 .33856 L
.44675 .34423 L
.44699 .35457 L
.44722 .35383 L
.44745 .36077 L
.44768 .35747 L
.44792 .36619 L
.44815 .36406 L
.44838 .35789 L
.44861 .35602 L
.44885 .35486 L
.44908 .34871 L
.44931 .35515 L
.44954 .35385 L
.44978 .35867 L
.45001 .35452 L
.45024 .36083 L
.45047 .36014 L
.45071 .36058 L
.45094 .36168 L
.45117 .37022 L
.4514 .3704 L
.45164 .37472 L
.45187 .3789 L
.4521 .38607 L
.45233 .38851 L
.45257 .38734 L
.4528 .38504 L
.45303 .39225 L
.45326 .38773 L
.4535 .37994 L
.45373 .37225 L
.45396 .36986 L
Mistroke
.45419 .36801 L
.45443 .37261 L
.45466 .36937 L
.45489 .37918 L
.45512 .38527 L
.45536 .39475 L
.45559 .3945 L
.45582 .3995 L
.45605 .39931 L
.45629 .40346 L
.45652 .40001 L
.45675 .40118 L
.45698 .39039 L
.45722 .38899 L
.45745 .38334 L
.45768 .38482 L
.45791 .38575 L
.45815 .39161 L
.45838 .39078 L
.45861 .3989 L
.45884 .39889 L
.45908 .39984 L
.45931 .39572 L
.45954 .40165 L
.45977 .40668 L
.46001 .41235 L
.46024 .40904 L
.46047 .41277 L
.4607 .4114 L
.46094 .41115 L
.46117 .40751 L
.4614 .40733 L
.46164 .39798 L
.46187 .3995 L
.4621 .40008 L
.46233 .40786 L
.46257 .4117 L
.4628 .4132 L
.46303 .40779 L
.46326 .40809 L
.4635 .40845 L
.46373 .41295 L
.46396 .4145 L
.46419 .42301 L
.46443 .42413 L
.46466 .42822 L
.46489 .42354 L
.46512 .42009 L
.46536 .41828 L
.46559 .41993 L
Mistroke
.46582 .41879 L
.46605 .42079 L
.46629 .4204 L
.46652 .4212 L
.46675 .41232 L
.46698 .41142 L
.46722 .40595 L
.46745 .40851 L
.46768 .41053 L
.46791 .41249 L
.46815 .41061 L
.46838 .4143 L
.46861 .41299 L
.46884 .41987 L
.46908 .41798 L
.46931 .41305 L
.46954 .40847 L
.46977 .40903 L
.47001 .40949 L
.47024 .42015 L
.47047 .42839 L
.4707 .43483 L
.47094 .43334 L
.47117 .43906 L
.4714 .43862 L
.47163 .44388 L
.47187 .44945 L
.4721 .45491 L
.47233 .45187 L
.47256 .45018 L
.4728 .45202 L
.47303 .45579 L
.47326 .45226 L
.47349 .44435 L
.47373 .43555 L
.47396 .43094 L
.47419 .42373 L
.47442 .42541 L
.47466 .427 L
.47489 .431 L
.47512 .42959 L
.47535 .43373 L
.47559 .43592 L
.47582 .43851 L
.47605 .43365 L
.47628 .42297 L
.47652 .41233 L
.47675 .40059 L
.47698 .38189 L
.47721 .36742 L
Mistroke
.47745 .36131 L
.47768 .35877 L
.47791 .35591 L
.47814 .35434 L
.47838 .35601 L
.47861 .35922 L
.47884 .35745 L
.47907 .35651 L
.47931 .35327 L
.47954 .36266 L
.47977 .36919 L
.48 .3775 L
.48024 .37848 L
.48047 .37764 L
.4807 .3767 L
.48093 .37981 L
.48117 .38569 L
.4814 .39173 L
.48163 .39991 L
.48186 .40659 L
.4821 .41115 L
.48233 .4169 L
.48256 .42086 L
.48279 .422 L
.48303 .42022 L
.48326 .42373 L
.48349 .42573 L
.48372 .43129 L
.48396 .43618 L
.48419 .43988 L
.48442 .43895 L
.48465 .43817 L
.48489 .43548 L
.48512 .43726 L
.48535 .43535 L
.48558 .43685 L
.48582 .43473 L
.48605 .43703 L
.48628 .43958 L
.48651 .4323 L
.48675 .41468 L
.48698 .40668 L
.48721 .40652 L
.48744 .41049 L
.48768 .40488 L
.48791 .39865 L
.48814 .39347 L
.48837 .3991 L
.48861 .39886 L
.48884 .39219 L
Mistroke
.48907 .37924 L
.4893 .36544 L
.48954 .3558 L
.48977 .35372 L
.49 .34524 L
.49023 .34164 L
.49047 .33821 L
.4907 .33919 L
.49093 .33315 L
.49116 .3313 L
.4914 .32651 L
.49163 .33144 L
.49186 .32971 L
.49209 .33196 L
.49233 .32851 L
.49256 .33255 L
.49279 .32722 L
.49302 .32697 L
.49326 .32153 L
.49349 .31394 L
.49372 .30199 L
.49395 .29323 L
.49419 .29181 L
.49442 .28974 L
.49465 .28953 L
.49488 .29556 L
.49512 .29505 L
.49535 .29272 L
.49558 .29159 L
.49581 .28943 L
.49605 .2881 L
.49628 .29377 L
.49651 .29599 L
.49674 .29919 L
.49698 .30402 L
.49721 .30873 L
.49744 .30697 L
.49767 .31143 L
.49791 .30929 L
.49814 .31427 L
.49837 .31489 L
.4986 .31878 L
.49884 .3184 L
.49907 .32716 L
.4993 .32713 L
.49953 .33055 L
.49977 .33742 L
.5 .34471 L
.50023 .34516 L
.50047 .35035 L
Mistroke
.5007 .34973 L
.50093 .35258 L
.50116 .35214 L
.5014 .36209 L
.50163 .36803 L
.50186 .37357 L
.50209 .37718 L
.50233 .38623 L
.50256 .38923 L
.50279 .39457 L
.50302 .39462 L
.50326 .39589 L
.50349 .39368 L
.50372 .39407 L
.50395 .39562 L
.50419 .3995 L
.50442 .40521 L
.50465 .4178 L
.50488 .41868 L
.50512 .41737 L
.50535 .4165 L
.50558 .41959 L
.50581 .4212 L
.50605 .42096 L
.50628 .42279 L
.50651 .41939 L
.50674 .41594 L
.50698 .41705 L
.50721 .41005 L
.50744 .40704 L
.50767 .40638 L
.50791 .40943 L
.50814 .41477 L
.50837 .41946 L
.5086 .41511 L
.50884 .41675 L
.50907 .41134 L
.5093 .40778 L
.50953 .39651 L
.50977 .38522 L
.51 .3787 L
.51023 .37836 L
.51046 .36576 L
.5107 .36343 L
.51093 .36561 L
.51116 .3586 L
.51139 .34936 L
.51163 .34606 L
.51186 .34303 L
.51209 .3513 L
Mistroke
.51232 .35637 L
.51256 .35859 L
.51279 .3585 L
.51302 .36382 L
.51325 .36735 L
.51349 .37747 L
.51372 .3776 L
.51395 .382 L
.51418 .386 L
.51442 .38653 L
.51465 .38615 L
.51488 .39139 L
.51511 .39861 L
.51535 .40631 L
.51558 .40719 L
.51581 .40729 L
.51604 .41083 L
.51628 .41656 L
.51651 .4173 L
.51674 .42197 L
.51697 .42691 L
.51721 .4323 L
.51744 .43532 L
.51767 .44311 L
.5179 .43891 L
.51814 .44221 L
.51837 .44163 L
.5186 .43697 L
.51883 .43298 L
.51907 .43353 L
.5193 .43256 L
.51953 .43892 L
.51976 .44846 L
.52 .45339 L
.52023 .45794 L
.52046 .46704 L
.52069 .46467 L
.52093 .47042 L
.52116 .46757 L
.52139 .47013 L
.52162 .47586 L
.52186 .47816 L
.52209 .47381 L
.52232 .47472 L
.52255 .47553 L
.52279 .47296 L
.52302 .46963 L
.52325 .46957 L
.52348 .46976 L
.52372 .46605 L
Mistroke
.52395 .45536 L
.52418 .44384 L
.52441 .43725 L
.52465 .43451 L
.52488 .42683 L
.52511 .42579 L
.52534 .42396 L
.52558 .41968 L
.52581 .41521 L
.52604 .41813 L
.52627 .42069 L
.52651 .42205 L
.52674 .42548 L
.52697 .43423 L
.5272 .43862 L
.52744 .44693 L
.52767 .44489 L
.5279 .44533 L
.52813 .44199 L
.52837 .44517 L
.5286 .43938 L
.52883 .43765 L
.52906 .43202 L
.5293 .42805 L
.52953 .42225 L
.52976 .42739 L
.52999 .43047 L
.53023 .42922 L
.53046 .42995 L
.53069 .42948 L
.53092 .42603 L
.53116 .42675 L
.53139 .42743 L
.53162 .43186 L
.53185 .43517 L
.53209 .43935 L
.53232 .44051 L
.53255 .4372 L
.53278 .42599 L
.53302 .41511 L
.53325 .40556 L
.53348 .40401 L
.53371 .40839 L
.53395 .40849 L
.53418 .40759 L
.53441 .40762 L
.53464 .40719 L
.53488 .41173 L
.53511 .41418 L
.53534 .41661 L
Mistroke
.53557 .41686 L
.53581 .41474 L
.53604 .42152 L
.53627 .42576 L
.5365 .42401 L
.53674 .43109 L
.53697 .43476 L
.5372 .43494 L
.53743 .43269 L
.53767 .43347 L
.5379 .42989 L
.53813 .42942 L
.53836 .42352 L
.5386 .42301 L
.53883 .41808 L
.53906 .41965 L
.5393 .41875 L
.53953 .42547 L
.53976 .43444 L
.53999 .44302 L
.54023 .44634 L
.54046 .45513 L
.54069 .46083 L
.54092 .46913 L
.54116 .46703 L
.54139 .46484 L
.54162 .46219 L
.54185 .45897 L
.54209 .46007 L
.54232 .46471 L
.54255 .46332 L
.54278 .46618 L
.54302 .46176 L
.54325 .45775 L
.54348 .44603 L
.54371 .44651 L
.54395 .44771 L
.54418 .4418 L
.54441 .43639 L
.54464 .4376 L
.54488 .44323 L
.54511 .44915 L
.54534 .44673 L
.54557 .4467 L
.54581 .44365 L
.54604 .44021 L
.54627 .43466 L
.5465 .43913 L
.54674 .44328 L
.54697 .44528 L
Mistroke
.5472 .45023 L
.54743 .44953 L
.54767 .44803 L
.5479 .44685 L
.54813 .44604 L
.54836 .44738 L
.5486 .44346 L
.54883 .44649 L
.54906 .43915 L
.54929 .4362 L
.54953 .43527 L
.54976 .43501 L
.54999 .43857 L
.55022 .43992 L
.55046 .43799 L
.55069 .44124 L
.55092 .44495 L
.55115 .4465 L
.55139 .44958 L
.55162 .45298 L
.55185 .45429 L
.55208 .45307 L
.55232 .45621 L
.55255 .45505 L
.55278 .44782 L
.55301 .44069 L
.55325 .43016 L
.55348 .42951 L
.55371 .42398 L
.55394 .41809 L
.55418 .41273 L
.55441 .40739 L
.55464 .39844 L
.55487 .39204 L
.55511 .38412 L
.55534 .37193 L
.55557 .36174 L
.5558 .35706 L
.55604 .35387 L
.55627 .3508 L
.5565 .35485 L
.55673 .35681 L
.55697 .35771 L
.5572 .36286 L
.55743 .36899 L
.55766 .37396 L
.5579 .36941 L
.55813 .37035 L
.55836 .37288 L
.55859 .37238 L
Mistroke
.55883 .36377 L
.55906 .36236 L
.55929 .3659 L
.55952 .3735 L
.55976 .37516 L
.55999 .37112 L
.56022 .36448 L
.56045 .36079 L
.56069 .35632 L
.56092 .35734 L
.56115 .35192 L
.56138 .35641 L
.56162 .35746 L
.56185 .35851 L
.56208 .36315 L
.56231 .36995 L
.56255 .36773 L
.56278 .36465 L
.56301 .36476 L
.56324 .36821 L
.56348 .37949 L
.56371 .38781 L
.56394 .38756 L
.56417 .38913 L
.56441 .39092 L
.56464 .39891 L
.56487 .40245 L
.5651 .41033 L
.56534 .40857 L
.56557 .40914 L
.5658 .40796 L
.56603 .41422 L
.56627 .4158 L
.5665 .42292 L
.56673 .43103 L
.56696 .43119 L
.5672 .43139 L
.56743 .43976 L
.56766 .44672 L
.56789 .45289 L
.56813 .45296 L
.56836 .44712 L
.56859 .4498 L
.56882 .45022 L
.56906 .4442 L
.56929 .43986 L
.56952 .43405 L
.56975 .42478 L
.56999 .41644 L
.57022 .41363 L
Mistroke
.57045 .41503 L
.57068 .41468 L
.57092 .4131 L
.57115 .40463 L
.57138 .40195 L
.57161 .40358 L
.57185 .4036 L
.57208 .41106 L
.57231 .41674 L
.57254 .42669 L
.57278 .42997 L
.57301 .4365 L
.57324 .4363 L
.57347 .44056 L
.57371 .44215 L
.57394 .44087 L
.57417 .44473 L
.5744 .44294 L
.57464 .43656 L
.57487 .43294 L
.5751 .43014 L
.57533 .43323 L
.57557 .43588 L
.5758 .43597 L
.57603 .43844 L
.57626 .44137 L
.5765 .4466 L
.57673 .44787 L
.57696 .44813 L
.57719 .4465 L
.57743 .44219 L
.57766 .43949 L
.57789 .43768 L
.57813 .43549 L
.57836 .42947 L
.57859 .42305 L
.57882 .41405 L
.57906 .41062 L
.57929 .41094 L
.57952 .41683 L
.57975 .42516 L
.57999 .42867 L
.58022 .43246 L
.58045 .42948 L
.58068 .4339 L
.58092 .44413 L
.58115 .44986 L
.58138 .45666 L
.58161 .46065 L
.58185 .46002 L
Mistroke
.58208 .45729 L
.58231 .45076 L
.58254 .44425 L
.58278 .44258 L
.58301 .44834 L
.58324 .44575 L
.58347 .44469 L
.58371 .44247 L
.58394 .442 L
.58417 .44428 L
.5844 .44778 L
.58464 .45293 L
.58487 .45339 L
.5851 .46273 L
.58533 .46536 L
.58557 .46438 L
.5858 .46893 L
.58603 .4806 L
.58626 .48781 L
.5865 .49319 L
.58673 .49747 L
.58696 .50371 L
.58719 .50737 L
.58743 .51142 L
.58766 .51225 L
.58789 .51129 L
.58812 .50976 L
.58836 .51917 L
.58859 .52542 L
.58882 .5298 L
.58905 .52967 L
.58929 .53121 L
.58952 .5383 L
.58975 .54553 L
.58998 .54963 L
.59022 .55609 L
.59045 .55631 L
.59068 .55817 L
.59091 .55323 L
.59115 .54363 L
.59138 .53726 L
.59161 .53887 L
.59184 .54165 L
.59208 .54445 L
.59231 .55647 L
.59254 .56083 L
.59277 .56344 L
.59301 .57075 L
.59324 .57427 L
.59347 .57483 L
Mistroke
.5937 .57531 L
.59394 .58015 L
.59417 .5815 L
.5944 .58009 L
.59463 .58076 L
.59487 .57238 L
.5951 .56413 L
.59533 .55599 L
.59556 .54637 L
.5958 .53453 L
.59603 .5233 L
.59626 .5161 L
.59649 .50989 L
.59673 .50345 L
.59696 .50062 L
.59719 .50547 L
.59742 .50381 L
.59766 .50363 L
.59789 .50849 L
.59812 .51389 L
.59835 .5167 L
.59859 .51295 L
.59882 .51014 L
.59905 .51405 L
.59928 .51538 L
.59952 .51374 L
.59975 .50659 L
.59998 .50775 L
.60021 .51375 L
.60045 .51728 L
.60068 .51675 L
.60091 .51606 L
.60114 .52011 L
.60138 .51886 L
.60161 .52033 L
.60184 .52031 L
.60207 .51376 L
.60231 .50935 L
.60254 .50828 L
.60277 .51329 L
.603 .51515 L
.60324 .51899 L
.60347 .52845 L
.6037 .53266 L
.60393 .53065 L
.60417 .52461 L
.6044 .52389 L
.60463 .52572 L
.60486 .52366 L
.6051 .51954 L
Mistroke
.60533 .52044 L
.60556 .51924 L
.60579 .51555 L
.60603 .51131 L
.60626 .51123 L
.60649 .51535 L
.60672 .50797 L
.60696 .49926 L
.60719 .48432 L
.60742 .46934 L
.60765 .46601 L
.60789 .46996 L
.60812 .47707 L
.60835 .48586 L
.60858 .49024 L
.60882 .49108 L
.60905 .49098 L
.60928 .48923 L
.60951 .49254 L
.60975 .49964 L
.60998 .5007 L
.61021 .5019 L
.61044 .4931 L
.61068 .4741 L
.61091 .45985 L
.61114 .44851 L
.61137 .44396 L
.61161 .44771 L
.61184 .44848 L
.61207 .44913 L
.6123 .45219 L
.61254 .46072 L
.61277 .4717 L
.613 .47827 L
.61323 .47693 L
.61347 .47882 L
.6137 .47911 L
.61393 .48226 L
.61416 .48548 L
.6144 .49388 L
.61463 .50243 L
.61486 .50943 L
.61509 .51762 L
.61533 .52014 L
.61556 .51551 L
.61579 .51005 L
.61602 .50465 L
.61626 .50242 L
.61649 .50513 L
.61672 .5078 L
Mistroke
.61695 .50678 L
.61719 .50614 L
.61742 .50225 L
.61765 .49806 L
.61789 .50274 L
.61812 .50777 L
.61835 .51225 L
.61858 .5124 L
.61882 .51847 L
.61905 .52383 L
.61928 .52874 L
.61951 .53956 L
.61975 .54846 L
.61998 .54574 L
.62021 .5427 L
.62044 .54487 L
.62068 .546 L
.62091 .54929 L
.62114 .5531 L
.62137 .55524 L
.62161 .55674 L
.62184 .55271 L
.62207 .55239 L
.6223 .55599 L
.62254 .55854 L
.62277 .55472 L
.623 .55172 L
.62323 .55091 L
.62347 .55044 L
.6237 .55384 L
.62393 .55655 L
.62416 .56117 L
.6244 .55176 L
.62463 .54321 L
.62486 .53618 L
.62509 .53131 L
.62533 .53038 L
.62556 .53531 L
.62579 .53762 L
.62602 .53578 L
.62626 .52989 L
.62649 .52224 L
.62672 .51686 L
.62695 .50473 L
.62719 .49861 L
.62742 .49417 L
.62765 .49296 L
.62788 .48836 L
.62812 .48331 L
.62835 .48193 L
Mistroke
.62858 .48351 L
.62881 .48401 L
.62905 .48702 L
.62928 .48612 L
.62951 .48804 L
.62974 .49095 L
.62998 .49096 L
.63021 .4922 L
.63044 .49381 L
.63067 .49445 L
.63091 .49801 L
.63114 .50142 L
.63137 .50926 L
.6316 .52114 L
.63184 .51873 L
.63207 .51919 L
.6323 .52007 L
.63253 .5249 L
.63277 .53058 L
.633 .531 L
.63323 .5393 L
.63346 .54719 L
.6337 .54404 L
.63393 .54264 L
.63416 .54292 L
.63439 .55154 L
.63463 .55805 L
.63486 .55235 L
.63509 .54408 L
.63532 .53679 L
.63556 .5325 L
.63579 .52904 L
.63602 .52917 L
.63625 .53177 L
.63649 .52871 L
.63672 .52615 L
.63695 .53136 L
.63718 .52989 L
.63742 .52512 L
.63765 .52769 L
.63788 .5304 L
.63811 .53193 L
.63835 .53962 L
.63858 .54859 L
.63881 .54833 L
.63904 .54453 L
.63928 .53784 L
.63951 .52821 L
.63974 .52337 L
.63997 .526 L
Mistroke
.64021 .52746 L
.64044 .53357 L
.64067 .53584 L
.6409 .53864 L
.64114 .5412 L
.64137 .54747 L
.6416 .54397 L
.64183 .53251 L
.64207 .5143 L
.6423 .49946 L
.64253 .48533 L
.64276 .47853 L
.643 .4709 L
.64323 .46488 L
.64346 .46256 L
.64369 .46552 L
.64393 .46685 L
.64416 .46858 L
.64439 .47404 L
.64462 .47797 L
.64486 .48388 L
.64509 .49228 L
.64532 .49313 L
.64555 .49766 L
.64579 .50289 L
.64602 .50294 L
.64625 .5037 L
.64648 .50245 L
.64672 .50061 L
.64695 .48735 L
.64718 .47505 L
.64741 .47028 L
.64765 .47106 L
.64788 .46768 L
.64811 .45855 L
.64834 .45553 L
.64858 .45236 L
.64881 .45435 L
.64904 .45998 L
.64927 .46022 L
.64951 .45955 L
.64974 .45986 L
.64997 .45909 L
.6502 .45908 L
.65044 .46286 L
.65067 .46005 L
.6509 .45322 L
.65113 .44788 L
.65137 .4512 L
.6516 .45655 L
Mistroke
.65183 .46205 L
.65206 .46319 L
.6523 .46193 L
.65253 .46797 L
.65276 .47499 L
.65299 .47467 L
.65323 .47109 L
.65346 .46947 L
.65369 .4702 L
.65392 .47398 L
.65416 .47827 L
.65439 .48568 L
.65462 .48856 L
.65485 .48974 L
.65509 .49527 L
.65532 .49968 L
.65555 .49614 L
.65578 .49384 L
.65602 .49691 L
.65625 .50142 L
.65648 .49755 L
.65672 .49614 L
.65695 .4953 L
.65718 .49494 L
.65741 .49397 L
.65765 .49553 L
.65788 .49516 L
.65811 .49406 L
.65834 .49978 L
.65858 .49993 L
.65881 .50154 L
.65904 .50318 L
.65927 .50313 L
.65951 .50836 L
.65974 .51449 L
.65997 .51795 L
.6602 .51658 L
.66044 .51792 L
.66067 .51666 L
.6609 .51418 L
.66113 .51305 L
.66137 .51292 L
.6616 .52072 L
.66183 .52002 L
.66206 .51874 L
.6623 .51509 L
.66253 .51239 L
.66276 .5012 L
.66299 .4772 L
.66323 .45418 L
Mistroke
.66346 .43519 L
.66369 .43099 L
.66392 .42544 L
.66416 .42156 L
.66439 .40798 L
.66462 .40376 L
.66485 .40661 L
.66509 .41026 L
.66532 .41599 L
.66555 .41682 L
.66578 .41524 L
.66602 .42084 L
.66625 .42828 L
.66648 .42854 L
.66671 .42674 L
.66695 .43086 L
.66718 .42838 L
.66741 .43002 L
.66764 .43128 L
.66788 .43376 L
.66811 .43549 L
.66834 .4334 L
.66857 .4371 L
.66881 .44015 L
.66904 .44383 L
.66927 .44785 L
.6695 .45221 L
.66974 .45719 L
.66997 .4568 L
.6702 .45067 L
.67043 .44721 L
.67067 .44438 L
.6709 .4521 L
.67113 .4588 L
.67136 .4664 L
.6716 .46327 L
.67183 .46084 L
.67206 .46342 L
.67229 .46813 L
.67253 .47888 L
.67276 .47531 L
.67299 .4804 L
.67322 .48385 L
.67346 .48495 L
.67369 .49132 L
.67392 .49389 L
.67415 .48888 L
.67439 .49377 L
.67462 .48633 L
.67485 .4837 L
Mistroke
.67508 .48393 L
.67532 .48145 L
.67555 .4836 L
.67578 .48081 L
.67601 .48332 L
.67625 .48437 L
.67648 .48726 L
.67671 .49023 L
.67694 .49064 L
.67718 .48987 L
.67741 .48877 L
.67764 .48874 L
.67787 .48737 L
.67811 .48665 L
.67834 .48885 L
.67857 .49019 L
.6788 .49571 L
.67904 .50072 L
.67927 .50471 L
.6795 .50674 L
.67973 .51507 L
.67997 .51998 L
.6802 .5218 L
.68043 .51857 L
.68066 .51024 L
.6809 .5054 L
.68113 .50256 L
.68136 .49645 L
.68159 .49163 L
.68183 .495 L
.68206 .4939 L
.68229 .49025 L
.68252 .48426 L
.68276 .47833 L
.68299 .46992 L
.68322 .4576 L
.68345 .45395 L
.68369 .45188 L
.68392 .44686 L
.68415 .4373 L
.68438 .43536 L
.68462 .44227 L
.68485 .45114 L
.68508 .45298 L
.68531 .45301 L
.68555 .45041 L
.68578 .45211 L
.68601 .45761 L
.68624 .47086 L
.68648 .47345 L
Mistroke
.68671 .46883 L
.68694 .46432 L
.68717 .46102 L
.68741 .46347 L
.68764 .46307 L
.68787 .46496 L
.6881 .46209 L
.68834 .46495 L
.68857 .4692 L
.6888 .46978 L
.68903 .4685 L
.68927 .46825 L
.6895 .47174 L
.68973 .47308 L
.68996 .47858 L
.6902 .4851 L
.69043 .48046 L
.69066 .47995 L
.69089 .47733 L
.69113 .47775 L
.69136 .47553 L
.69159 .47813 L
.69182 .47498 L
.69206 .47719 L
.69229 .48117 L
.69252 .48249 L
.69275 .478 L
.69299 .475 L
.69322 .47619 L
.69345 .47396 L
.69368 .47506 L
.69392 .47861 L
.69415 .4874 L
.69438 .48832 L
.69461 .48889 L
.69485 .48619 L
.69508 .4847 L
.69531 .48252 L
.69555 .48026 L
.69578 .47443 L
.69601 .46383 L
.69624 .45413 L
.69648 .45121 L
.69671 .45355 L
.69694 .45877 L
.69717 .45325 L
.69741 .44575 L
.69764 .4424 L
.69787 .43997 L
.6981 .43384 L
Mistroke
.69834 .42932 L
.69857 .43217 L
.6988 .42914 L
.69903 .42754 L
.69927 .43071 L
.6995 .437 L
.69973 .44164 L
.69996 .4513 L
.7002 .45666 L
.70043 .46211 L
.70066 .46629 L
.70089 .47154 L
.70113 .4805 L
.70136 .48446 L
.70159 .4903 L
.70182 .49675 L
.70206 .49898 L
.70229 .49834 L
.70252 .50037 L
.70275 .50154 L
.70299 .50045 L
.70322 .50625 L
.70345 .50561 L
.70368 .49162 L
.70392 .4865 L
.70415 .48776 L
.70438 .48196 L
.70461 .47733 L
.70485 .47192 L
.70508 .46867 L
.70531 .45147 L
.70554 .42582 L
.70578 .39747 L
.70601 .37752 L
.70624 .36677 L
.70647 .36129 L
.70671 .36661 L
.70694 .36773 L
.70717 .37032 L
.7074 .36749 L
.70764 .37217 L
.70787 .375 L
.7081 .37838 L
.70833 .38071 L
.70857 .38208 L
.7088 .3815 L
.70903 .37793 L
.70926 .38157 L
.7095 .38411 L
.70973 .38377 L
Mistroke
.70996 .38119 L
.71019 .37763 L
.71043 .3802 L
.71066 .38466 L
.71089 .39172 L
.71112 .39561 L
.71136 .39501 L
.71159 .38793 L
.71182 .38315 L
.71205 .38386 L
.71229 .38747 L
.71252 .39128 L
.71275 .40248 L
.71298 .40624 L
.71322 .40925 L
.71345 .41448 L
.71368 .41784 L
.71391 .42272 L
.71415 .42494 L
.71438 .42987 L
.71461 .43199 L
.71484 .43192 L
.71508 .43252 L
.71531 .43629 L
.71554 .44126 L
.71577 .43647 L
.71601 .42664 L
.71624 .42328 L
.71647 .42639 L
.7167 .42718 L
.71694 .43196 L
.71717 .43365 L
.7174 .43466 L
.71763 .43269 L
.71787 .43461 L
.7181 .43412 L
.71833 .43257 L
.71856 .42778 L
.7188 .41462 L
.71903 .4109 L
.71926 .41604 L
.71949 .41167 L
.71973 .40831 L
.71996 .40767 L
.72019 .40793 L
.72042 .40672 L
.72066 .40905 L
.72089 .41317 L
.72112 .41258 L
.72135 .41652 L
Mistroke
.72159 .41932 L
.72182 .4171 L
.72205 .42013 L
.72228 .41921 L
.72252 .41831 L
.72275 .41814 L
.72298 .42382 L
.72321 .43603 L
.72345 .43962 L
.72368 .44196 L
.72391 .44618 L
.72414 .44912 L
.72438 .45083 L
.72461 .45112 L
.72484 .45603 L
.72507 .45588 L
.72531 .45312 L
.72554 .45334 L
.72577 .45732 L
.726 .46558 L
.72624 .47965 L
.72647 .48728 L
.7267 .48565 L
.72693 .48973 L
.72717 .49279 L
.7274 .49131 L
.72763 .4995 L
.72786 .50941 L
.7281 .52075 L
.72833 .52434 L
.72856 .52501 L
.72879 .52045 L
.72903 .5133 L
.72926 .50245 L
.72949 .49194 L
.72972 .48184 L
.72996 .46785 L
.73019 .46016 L
.73042 .46133 L
.73065 .45996 L
.73089 .46582 L
.73112 .47464 L
.73135 .48328 L
.73158 .4916 L
.73182 .49514 L
.73205 .48979 L
.73228 .48793 L
.73251 .48789 L
.73275 .48943 L
.73298 .48758 L
Mistroke
.73321 .48644 L
.73344 .48603 L
.73368 .48471 L
.73391 .47928 L
.73414 .47629 L
.73438 .47871 L
.73461 .47856 L
.73484 .46845 L
.73507 .45902 L
.73531 .45717 L
.73554 .4582 L
.73577 .46206 L
.736 .47079 L
.73624 .47431 L
.73647 .47676 L
.7367 .47534 L
.73693 .47606 L
.73717 .47477 L
.7374 .48042 L
.73763 .48549 L
.73786 .48507 L
.7381 .49142 L
.73833 .49651 L
.73856 .49829 L
.73879 .50376 L
.73903 .50849 L
.73926 .51452 L
.73949 .52296 L
.73972 .53325 L
.73996 .53573 L
.74019 .54033 L
.74042 .54029 L
.74065 .53319 L
.74089 .51856 L
.74112 .496 L
.74135 .46926 L
.74158 .44305 L
.74182 .43543 L
.74205 .43543 L
.74228 .43525 L
.74251 .43263 L
.74275 .43225 L
.74298 .43563 L
.74321 .44084 L
.74344 .44462 L
.74368 .44631 L
.74391 .45019 L
.74414 .45621 L
.74437 .45798 L
.74461 .46194 L
Mistroke
.74484 .46767 L
.74507 .46953 L
.7453 .47405 L
.74554 .47256 L
.74577 .472 L
.746 .47457 L
.74623 .47221 L
.74647 .47463 L
.7467 .47831 L
.74693 .47402 L
.74716 .47325 L
.7474 .46826 L
.74763 .46579 L
.74786 .46682 L
.74809 .46788 L
.74833 .46965 L
.74856 .47403 L
.74879 .47652 L
.74902 .47154 L
.74926 .47029 L
.74949 .47001 L
.74972 .47351 L
.74995 .48014 L
.75019 .48306 L
.75042 .48751 L
.75065 .48709 L
.75088 .48809 L
.75112 .4975 L
.75135 .50581 L
.75158 .50991 L
.75181 .51064 L
.75205 .51284 L
.75228 .51358 L
.75251 .51084 L
.75274 .5134 L
.75298 .5148 L
.75321 .51301 L
.75344 .51792 L
.75367 .5244 L
.75391 .52434 L
.75414 .51625 L
.75437 .51454 L
.7546 .5143 L
.75484 .5153 L
.75507 .52198 L
.7553 .52524 L
.75553 .52689 L
.75577 .53258 L
.756 .53954 L
.75623 .54169 L
Mistroke
.75646 .54958 L
.7567 .55847 L
.75693 .55826 L
.75716 .55332 L
.75739 .55146 L
.75763 .54743 L
.75786 .55048 L
.75809 .55172 L
.75832 .5448 L
.75856 .53464 L
.75879 .52873 L
.75902 .52076 L
.75925 .52188 L
.75949 .52667 L
.75972 .52575 L
.75995 .52797 L
.76018 .53777 L
.76042 .54559 L
.76065 .55005 L
.76088 .553 L
.76111 .56108 L
.76135 .56714 L
.76158 .57328 L
.76181 .57404 L
.76204 .57424 L
.76228 .57275 L
.76251 .57185 L
.76274 .57033 L
.76297 .57861 L
.76321 .58898 L
.76344 .59868 L
.76367 .5998 L
.7639 .60278 L
.76414 .60332 L
.76437 .60008 L
.7646 .59645 L
.76483 .59261 L
.76507 .59003 L
.7653 .58622 L
.76553 .58656 L
.76576 .58856 L
.766 .58716 L
.76623 .58676 L
.76646 .59508 L
.76669 .60189 L
.76693 .6021 L
.76716 .60058 L
.76739 .59281 L
.76762 .58253 L
.76786 .57134 L
Mistroke
.76809 .55467 L
.76832 .5381 L
.76855 .53239 L
.76879 .5275 L
.76902 .51911 L
.76925 .51012 L
.76948 .50096 L
.76972 .49888 L
.76995 .49825 L
.77018 .49833 L
.77041 .50383 L
.77065 .50636 L
.77088 .50567 L
.77111 .51119 L
.77134 .51819 L
.77158 .52999 L
.77181 .5391 L
.77204 .54296 L
.77227 .54652 L
.77251 .55124 L
.77274 .56081 L
.77297 .56526 L
.7732 .57244 L
.77344 .57193 L
.77367 .57084 L
.7739 .56965 L
.77414 .56922 L
.77437 .56774 L
.7746 .56867 L
.77483 .56327 L
.77507 .56039 L
.7753 .56768 L
.77553 .56702 L
.77576 .56417 L
.776 .55828 L
.77623 .5619 L
.77646 .57037 L
.77669 .57341 L
.77693 .57722 L
.77716 .57671 L
.77739 .57776 L
.77762 .57622 L
.77786 .56839 L
.77809 .56394 L
.77832 .56402 L
.77855 .5665 L
.77879 .5724 L
.77902 .57801 L
.77925 .58 L
.77948 .57682 L
Mistroke
.77972 .56936 L
.77995 .55963 L
.78018 .5462 L
.78041 .54199 L
.78065 .54616 L
.78088 .55121 L
.78111 .55616 L
.78134 .55614 L
.78158 .555 L
.78181 .56063 L
.78204 .5651 L
.78227 .56989 L
.78251 .57119 L
.78274 .56524 L
.78297 .55963 L
.7832 .54896 L
.78344 .53817 L
.78367 .52335 L
.7839 .50196 L
.78413 .49314 L
.78437 .48982 L
.7846 .48349 L
.78483 .48512 L
.78506 .48599 L
.7853 .48331 L
.78553 .48449 L
.78576 .48779 L
.78599 .49238 L
.78623 .49662 L
.78646 .49765 L
.78669 .49799 L
.78692 .50083 L
.78716 .50683 L
.78739 .50661 L
.78762 .50475 L
.78785 .49898 L
.78809 .49899 L
.78832 .49951 L
.78855 .50197 L
.78878 .50006 L
.78902 .50071 L
.78925 .50159 L
.78948 .50718 L
.78971 .51303 L
.78995 .51499 L
.79018 .51662 L
.79041 .51738 L
.79064 .51673 L
.79088 .51732 L
.79111 .51871 L
Mistroke
.79134 .52054 L
.79157 .52134 L
.79181 .52068 L
.79204 .52176 L
.79227 .52149 L
.7925 .52474 L
.79274 .53048 L
.79297 .53684 L
.7932 .53682 L
.79343 .53598 L
.79367 .53663 L
.7939 .53514 L
.79413 .53929 L
.79436 .53806 L
.7946 .53567 L
.79483 .5277 L
.79506 .52502 L
.79529 .52159 L
.79553 .52405 L
.79576 .5314 L
.79599 .53367 L
.79622 .53624 L
.79646 .54188 L
.79669 .54099 L
.79692 .53462 L
.79715 .52993 L
.79739 .52638 L
.79762 .52647 L
.79785 .52856 L
.79808 .52341 L
.79832 .52424 L
.79855 .52374 L
.79878 .52294 L
.79901 .52375 L
.79925 .53135 L
.79948 .53911 L
.79971 .54466 L
.79994 .55575 L
.80018 .5627 L
.80041 .56642 L
.80064 .56461 L
.80087 .5592 L
.80111 .5587 L
.80134 .5656 L
.80157 .56914 L
.8018 .5689 L
.80204 .57255 L
.80227 .58168 L
.8025 .58463 L
.80273 .57261 L
Mistroke
.80297 .54342 L
.8032 .49241 L
.80343 .44869 L
.80366 .41967 L
.8039 .41131 L
.80413 .40061 L
.80436 .39871 L
.80459 .40305 L
.80483 .40555 L
.80506 .40774 L
.80529 .41204 L
.80552 .42582 L
.80576 .43042 L
.80599 .42786 L
.80622 .43075 L
.80645 .42857 L
.80669 .43012 L
.80692 .43083 L
.80715 .42805 L
.80738 .42575 L
.80762 .42681 L
.80785 .42492 L
.80808 .42224 L
.80831 .41806 L
.80855 .41265 L
.80878 .41253 L
.80901 .41522 L
.80924 .41161 L
.80948 .41435 L
.80971 .41546 L
.80994 .4138 L
.81017 .41626 L
.81041 .41678 L
.81064 .41885 L
.81087 .41871 L
.8111 .42001 L
.81134 .42434 L
.81157 .42476 L
.8118 .42908 L
.81203 .43042 L
.81227 .42761 L
.8125 .4274 L
.81273 .42436 L
.81297 .42813 L
.8132 .43462 L
.81343 .4368 L
.81366 .4388 L
.8139 .43821 L
.81413 .43324 L
.81436 .4299 L
Mistroke
.81459 .43555 L
.81483 .4406 L
.81506 .44268 L
.81529 .44086 L
.81552 .43963 L
.81576 .44076 L
.81599 .43752 L
.81622 .43332 L
.81645 .43568 L
.81669 .44282 L
.81692 .44285 L
.81715 .43582 L
.81738 .42609 L
.81762 .41724 L
.81785 .41209 L
.81808 .41044 L
.81831 .40573 L
.81855 .40148 L
.81878 .3982 L
.81901 .39729 L
.81924 .39574 L
.81948 .38435 L
.81971 .3803 L
.81994 .37988 L
.82017 .37581 L
.82041 .36886 L
.82064 .36166 L
.82087 .3516 L
.8211 .34756 L
.82134 .33871 L
.82157 .3355 L
.8218 .33221 L
.82203 .32834 L
.82227 .32149 L
.8225 .31799 L
.82273 .31752 L
.82296 .31291 L
.8232 .31506 L
.82343 .32401 L
.82366 .32823 L
.82389 .32967 L
.82413 .33216 L
.82436 .33766 L
.82459 .34108 L
.82482 .34427 L
.82506 .34865 L
.82529 .3583 L
.82552 .36371 L
.82575 .35789 L
.82599 .35551 L
Mistroke
.82622 .36237 L
.82645 .37221 L
.82668 .38345 L
.82692 .38849 L
.82715 .39437 L
.82738 .39392 L
.82761 .39705 L
.82785 .40124 L
.82808 .40894 L
.82831 .40748 L
.82854 .40676 L
.82878 .40425 L
.82901 .40041 L
.82924 .39865 L
.82947 .39152 L
.82971 .39001 L
.82994 .38231 L
.83017 .36907 L
.8304 .37175 L
.83064 .37253 L
.83087 .36872 L
.8311 .36763 L
.83133 .37637 L
.83157 .38619 L
.8318 .39274 L
.83203 .39884 L
.83226 .40439 L
.8325 .41023 L
.83273 .41072 L
.83296 .41225 L
.83319 .41861 L
.83343 .42783 L
.83366 .4307 L
.83389 .4235 L
.83412 .41733 L
.83436 .41287 L
.83459 .40447 L
.83482 .39064 L
.83505 .37804 L
.83529 .37124 L
.83552 .36908 L
.83575 .36238 L
.83598 .35917 L
.83622 .34986 L
.83645 .33928 L
.83668 .342 L
.83691 .34626 L
.83715 .35054 L
.83738 .35384 L
.83761 .35441 L
Mistroke
.83784 .35553 L
.83808 .35413 L
.83831 .34534 L
.83854 .34029 L
.83877 .33376 L
.83901 .33067 L
.83924 .33378 L
.83947 .34096 L
.8397 .34225 L
.83994 .34054 L
.84017 .33594 L
.8404 .32899 L
.84063 .33017 L
.84087 .33072 L
.8411 .33155 L
.84133 .3339 L
.84156 .33779 L
.8418 .33417 L
.84203 .32711 L
.84226 .3244 L
.84249 .33056 L
.84273 .33202 L
.84296 .33062 L
.84319 .33319 L
.84342 .32423 L
.84366 .31376 L
.84389 .30387 L
.84412 .29468 L
.84435 .29189 L
.84459 .29096 L
.84482 .29697 L
.84505 .30066 L
.84528 .29624 L
.84552 .2894 L
.84575 .28618 L
.84598 .28474 L
.84621 .28732 L
.84645 .28923 L
.84668 .2966 L
.84691 .30157 L
.84714 .31203 L
.84738 .32269 L
.84761 .32655 L
.84784 .32203 L
.84807 .32585 L
.84831 .32699 L
.84854 .33037 L
.84877 .33336 L
.849 .34461 L
.84924 .34966 L
Mistroke
.84947 .34965 L
.8497 .34462 L
.84993 .33777 L
.85017 .33549 L
.8504 .3401 L
.85063 .33932 L
.85086 .33279 L
.8511 .32918 L
.85133 .32869 L
.85156 .32484 L
.8518 .33188 L
.85203 .34204 L
.85226 .35081 L
.85249 .35232 L
.85273 .35407 L
.85296 .34935 L
.85319 .348 L
.85342 .34756 L
.85366 .35643 L
.85389 .36453 L
.85412 .37034 L
.85435 .36607 L
.85459 .35964 L
.85482 .34811 L
.85505 .3366 L
.85528 .33149 L
.85552 .32507 L
.85575 .32654 L
.85598 .32604 L
.85621 .33224 L
.85645 .34849 L
.85668 .35559 L
.85691 .35653 L
.85714 .35158 L
.85738 .34999 L
.85761 .35323 L
.85784 .35589 L
.85807 .35411 L
.85831 .35427 L
.85854 .3557 L
.85877 .36328 L
.859 .36877 L
.85924 .37144 L
.85947 .37083 L
.8597 .36639 L
.85993 .35728 L
.86017 .34932 L
.8604 .34162 L
.86063 .34307 L
.86086 .34302 L
Mistroke
.8611 .34657 L
.86133 .34479 L
.86156 .35113 L
.86179 .35566 L
.86203 .35549 L
.86226 .35712 L
.86249 .36004 L
.86272 .36109 L
.86296 .36134 L
.86319 .36669 L
.86342 .37029 L
.86365 .36819 L
.86389 .37322 L
.86412 .37642 L
.86435 .38045 L
.86458 .37863 L
.86482 .37941 L
.86505 .37755 L
.86528 .38095 L
.86551 .38136 L
.86575 .37851 L
.86598 .36845 L
.86621 .35812 L
.86644 .35082 L
.86668 .34689 L
.86691 .34479 L
.86714 .35166 L
.86737 .36554 L
.86761 .37578 L
.86784 .37941 L
.86807 .38154 L
.8683 .37873 L
.86854 .38735 L
.86877 .39447 L
.869 .3999 L
.86923 .40408 L
.86947 .41028 L
.8697 .40632 L
.86993 .39641 L
.87016 .39279 L
.8704 .38698 L
.87063 .37693 L
.87086 .36693 L
.87109 .3524 L
.87133 .35137 L
.87156 .35898 L
.87179 .36554 L
.87202 .37169 L
.87226 .37472 L
.87249 .36798 L
Mistroke
.87272 .36578 L
.87295 .36438 L
.87319 .37094 L
.87342 .37331 L
.87365 .3722 L
.87388 .37381 L
.87412 .37967 L
.87435 .37746 L
.87458 .38197 L
.87481 .38797 L
.87505 .39934 L
.87528 .40701 L
.87551 .4132 L
.87574 .42054 L
.87598 .4241 L
.87621 .42433 L
.87644 .42522 L
.87667 .42541 L
.87691 .42302 L
.87714 .4107 L
.87737 .39682 L
.8776 .38413 L
.87784 .37426 L
.87807 .3696 L
.8783 .37127 L
.87853 .37155 L
.87877 .37523 L
.879 .37246 L
.87923 .36992 L
.87946 .36814 L
.8797 .36648 L
.87993 .36454 L
.88016 .36703 L
.88039 .3687 L
.88063 .36982 L
.88086 .364 L
.88109 .3633 L
.88132 .36997 L
.88156 .37377 L
.88179 .37586 L
.88202 .37906 L
.88225 .38386 L
.88249 .38732 L
.88272 .38151 L
.88295 .38289 L
.88318 .38318 L
.88342 .3845 L
.88365 .38007 L
.88388 .38259 L
.88411 .38612 L
Mistroke
.88435 .39142 L
.88458 .39549 L
.88481 .39888 L
.88504 .39826 L
.88528 .39834 L
.88551 .40035 L
.88574 .40703 L
.88597 .40937 L
.88621 .41855 L
.88644 .42565 L
.88667 .43412 L
.8869 .4413 L
.88714 .44832 L
.88737 .44419 L
.8876 .44515 L
.88783 .44603 L
.88807 .44979 L
.8883 .44964 L
.88853 .44337 L
.88876 .43782 L
.889 .43751 L
.88923 .42903 L
.88946 .41633 L
.88969 .41287 L
.88993 .40902 L
.89016 .40573 L
.89039 .41507 L
.89063 .42037 L
.89086 .43036 L
.89109 .43293 L
.89132 .43066 L
.89156 .4235 L
.89179 .42036 L
.89202 .41921 L
.89225 .42249 L
.89249 .42246 L
.89272 .42513 L
.89295 .41952 L
.89318 .42267 L
.89342 .42234 L
.89365 .43357 L
.89388 .44263 L
.89411 .4446 L
.89435 .43906 L
.89458 .44029 L
.89481 .44242 L
.89504 .44504 L
.89528 .4459 L
.89551 .4457 L
.89574 .44111 L
Mistroke
.89597 .4425 L
.89621 .4468 L
.89644 .4562 L
.89667 .46561 L
.8969 .47713 L
.89714 .48208 L
.89737 .48462 L
.8976 .48665 L
.89783 .48692 L
.89807 .48612 L
.8983 .48505 L
.89853 .48946 L
.89876 .49303 L
.899 .49421 L
.89923 .49155 L
.89946 .49112 L
.89969 .49686 L
.89993 .50157 L
.90016 .50082 L
.90039 .49339 L
.90062 .48238 L
.90086 .47199 L
.90109 .47113 L
.90132 .47048 L
.90155 .4674 L
.90179 .45843 L
.90202 .46031 L
.90225 .46129 L
.90248 .46548 L
.90272 .46909 L
.90295 .46254 L
.90318 .4601 L
.90341 .45933 L
.90365 .45392 L
.90388 .45394 L
.90411 .45376 L
.90434 .45575 L
.90458 .45623 L
.90481 .46427 L
.90504 .47457 L
.90527 .48355 L
.90551 .48477 L
.90574 .48411 L
.90597 .48474 L
.9062 .48791 L
.90644 .4873 L
.90667 .4892 L
.9069 .49093 L
.90713 .48884 L
.90737 .47771 L
Mistroke
.9076 .47497 L
.90783 .46851 L
.90806 .46051 L
.9083 .45104 L
.90853 .44309 L
.90876 .44347 L
.90899 .44652 L
.90923 .4459 L
.90946 .44597 L
.90969 .44509 L
.90992 .44714 L
.91016 .4467 L
.91039 .45312 L
.91062 .45943 L
.91085 .46494 L
.91109 .46546 L
.91132 .46764 L
.91155 .46749 L
.91178 .4615 L
.91202 .45192 L
.91225 .44388 L
.91248 .4328 L
.91271 .42313 L
.91295 .42157 L
.91318 .43246 L
.91341 .43753 L
.91364 .44306 L
.91388 .4387 L
.91411 .43685 L
.91434 .44228 L
.91457 .43933 L
.91481 .42789 L
.91504 .43519 L
.91527 .44117 L
.9155 .44413 L
.91574 .44258 L
.91597 .44146 L
.9162 .44363 L
.91643 .44433 L
.91667 .44011 L
.9169 .43005 L
.91713 .42905 L
.91736 .43364 L
.9176 .43492 L
.91783 .44228 L
.91806 .44178 L
.91829 .43937 L
.91853 .43268 L
.91876 .43464 L
.91899 .43908 L
Mistroke
.91922 .44263 L
.91946 .44715 L
.91969 .44879 L
.91992 .446 L
.92015 .44544 L
.92039 .44061 L
.92062 .43963 L
.92085 .43648 L
.92108 .43711 L
.92132 .43683 L
.92155 .4428 L
.92178 .4495 L
.92201 .45962 L
.92225 .46341 L
.92248 .46404 L
.92271 .45895 L
.92294 .45963 L
.92318 .46305 L
.92341 .46365 L
.92364 .45995 L
.92387 .45309 L
.92411 .45094 L
.92434 .45402 L
.92457 .44637 L
.9248 .43872 L
.92504 .43634 L
.92527 .43655 L
.9255 .43463 L
.92573 .43897 L
.92597 .44207 L
.9262 .44158 L
.92643 .44233 L
.92666 .44316 L
.9269 .43057 L
.92713 .42434 L
.92736 .42432 L
.92759 .42308 L
.92783 .42432 L
.92806 .42759 L
.92829 .42876 L
.92852 .4249 L
.92876 .42717 L
.92899 .42511 L
.92922 .41691 L
.92945 .42087 L
.92969 .41721 L
.92992 .41479 L
.93015 .41658 L
.93039 .42181 L
.93062 .42064 L
Mistroke
.93085 .42834 L
.93108 .4397 L
.93132 .4465 L
.93155 .44948 L
.93178 .45694 L
.93201 .45672 L
.93225 .46135 L
.93248 .46468 L
.93271 .46906 L
.93294 .47446 L
.93318 .48374 L
.93341 .48656 L
.93364 .48642 L
.93387 .48231 L
.93411 .4823 L
.93434 .47716 L
.93457 .46225 L
.9348 .43875 L
.93504 .41453 L
.93527 .39507 L
.9355 .38894 L
.93573 .38755 L
.93597 .3902 L
.9362 .38657 L
.93643 .37976 L
.93666 .37646 L
.9369 .37726 L
.93713 .37437 L
.93736 .37477 L
.93759 .37108 L
.93783 .37334 L
.93806 .3766 L
.93829 .38503 L
.93852 .39221 L
.93876 .39712 L
.93899 .40269 L
.93922 .40204 L
.93945 .39381 L
.93969 .38694 L
.93992 .38563 L
.94015 .38846 L
.94038 .38414 L
.94062 .38357 L
.94085 .38625 L
.94108 .38421 L
.94131 .37432 L
.94155 .36664 L
.94178 .35918 L
.94201 .35819 L
.94224 .35875 L
Mistroke
.94248 .36318 L
.94271 .36379 L
.94294 .36765 L
.94317 .3752 L
.94341 .38279 L
.94364 .3844 L
.94387 .38807 L
.9441 .39132 L
.94434 .39637 L
.94457 .39908 L
.9448 .40771 L
.94503 .40638 L
.94527 .4081 L
.9455 .4124 L
.94573 .4181 L
.94596 .42103 L
.9462 .42917 L
.94643 .43237 L
.94666 .43529 L
.94689 .43804 L
.94713 .44116 L
.94736 .44246 L
.94759 .44711 L
.94782 .44251 L
.94806 .44042 L
.94829 .43693 L
.94852 .43232 L
.94875 .42625 L
.94899 .42134 L
.94922 .41771 L
.94945 .41653 L
.94968 .41423 L
.94992 .42201 L
.95015 .42549 L
.95038 .4256 L
.95061 .42264 L
.95085 .42516 L
.95108 .41793 L
.95131 .42377 L
.95154 .42837 L
.95178 .43129 L
.95201 .42645 L
.95224 .42112 L
.95247 .42196 L
.95271 .42693 L
.95294 .42559 L
.95317 .43122 L
.9534 .42946 L
.95364 .43778 L
.95387 .44133 L
Mistroke
.9541 .43768 L
.95433 .43245 L
.95457 .43221 L
.9548 .43384 L
.95503 .44039 L
.95526 .43821 L
.9555 .43943 L
.95573 .44079 L
.95596 .44135 L
.95619 .44123 L
.95643 .44246 L
.95666 .4395 L
.95689 .43536 L
.95712 .43145 L
.95736 .43168 L
.95759 .43342 L
.95782 .43637 L
.95805 .43702 L
.95829 .443 L
.95852 .44324 L
.95875 .44325 L
.95898 .44153 L
.95922 .4495 L
.95945 .45156 L
.95968 .45166 L
.95991 .45186 L
.96015 .44728 L
.96038 .4499 L
.96061 .45723 L
.96084 .46552 L
.96108 .47049 L
.96131 .47121 L
.96154 .47289 L
.96177 .47256 L
.96201 .46639 L
.96224 .45864 L
.96247 .45277 L
.9627 .45782 L
.96294 .46496 L
.96317 .47232 L
.9634 .48117 L
.96363 .48578 L
.96387 .48754 L
.9641 .48239 L
.96433 .48849 L
.96456 .49042 L
.9648 .49228 L
.96503 .49831 L
.96526 .50279 L
.96549 .50211 L
Mistroke
.96573 .50998 L
.96596 .51247 L
.96619 .51258 L
.96642 .51345 L
.96666 .51867 L
.96689 .52134 L
.96712 .52313 L
.96735 .53105 L
.96759 .53087 L
.96782 .52591 L
.96805 .52172 L
.96828 .52617 L
.96852 .52784 L
.96875 .52087 L
.96898 .52662 L
.96922 .52988 L
.96945 .53895 L
.96968 .55101 L
.96991 .55356 L
.97015 .54547 L
.97038 .53585 L
.97061 .52871 L
.97084 .53308 L
.97108 .53474 L
.97131 .5376 L
.97154 .5429 L
.97177 .54667 L
.97201 .54879 L
.97224 .54843 L
.97247 .54694 L
.9727 .54644 L
.97294 .54255 L
.97317 .54156 L
.9734 .53937 L
.97363 .53492 L
.97387 .53525 L
.9741 .53993 L
.97433 .53685 L
.97456 .5309 L
.9748 .52764 L
.97503 .5247 L
.97526 .51767 L
.97549 .51236 L
.97573 .50694 L
.97596 .50487 L
.97619 .50382 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00O5Goo00<007ooOol0
ogoo5Goo000EOol00`00Oomoo`3oOolEOol001Eoo`03001oogoo0?mooaEoo`005Goo0P00ogoo5Woo
000EOol00`00Oomoo`0hOol2003JOol001Eoo`03001oogoo03Qoo`800=Yoo`005Goo00<007ooOol0
=goo1@00f7oo000EOol00`00Oomoo`0gOol5003HOol001Eoo`03001oogoo03Moo`D00=Qoo`005Goo
0P00>7oo00<007oo00000P00f7oo000EOol00`00Oomoo`0gOol00`00Ool00003003GOol001Eoo`03
001oogoo03Moo`04001oo`00Ool2003GOol001Eoo`03001oogoo031oo`03001oogoo00Aoo`04001o
o`00Ool20002Ool00`00Oomoo`3BOol001Eoo`03001oogoo031oo`03001oogoo00Aoo`04001oo`00
Ool20002Ool00`00Oomoo`3BOol001Eoo`03001oogoo031oo`8000Eoo`04001oogooOol200000goo
0000003DOol001Eoo`03001oogoo031oo`8000Eoo`03001oogoo009oo`04001oo`00003DOol001Eo
o`80035oo`8000Eoo`03001oogoo009oo`D00==oo`005Goo00<007ooOol0<7oo0P001Goo00<007oo
Ool00Woo1@00dgoo000EOol00`00Oomoo`0`Ool20005Ool00`00Oomoo`02Ool5003COol001Eoo`03
001oogoo031oo`8000Eoo`03001oogoo009oo`D00==oo`005Goo00<007ooOol0<7oo0P001Goo00<0
07ooOol00Woo1@00dgoo000EOol00`00Oomoo`0`Ool20005Ool00`00Oomoo`02Ool50002Ool2003?
Ool001Eoo`03001oogoo031oo`8000Eoo`03001oogoo009oo`H00003Ool0000000Moo`03001oogoo
0<Eoo`005Goo0P00<Goo0P001Goo00<007ooOol00goo20001goo00<007ooOol0aGoo000EOol00`00
Oomoo`0`Ool20005Ool00`00Oomoo`04Ool70007Ool00`00Oomoo`35Ool001Eoo`03001oogoo031o
o`<000Aoo`03001oogoo00Aoo`L000Moo`03001oogoo0<Eoo`005Goo00<007ooOol0<7oo10000goo
00<007ooOol017oo1`001goo00@007oo00000<Aoo`005Goo00<007ooOol0<7oo10000goo00<007oo
Ool01Woo0`0000=oo`00Ool01Woo00@007oo00000<Aoo`003Goo100017oo00<007ooOol0<7oo1000
00Aoo`00Ool000Qoo`<00003Ool007oo00Eoo`800003Ool000000<Aoo`003Woo00<007ooOol017oo
00<007ooOol0<7oo1P0000=oo`00Ool01goo0`0000=oo`0000001Goo0P0000=oo`000000a7oo0007
Ool50003Ool00`00Oomoo`03Ool3000`Ool600000goo001oo`08Ool200000goo00000005Ool20000
0goo000000020032Ool0011oo`03001oogoo009oo`03001oogoo031oo`H00003Ool007oo00Uoo`03
001oo`00008000Aoo`800003Ool007oo00800<9oo`003Goo00@007ooOol000Aoo`03001oogoo031o
o`03001oo`0000<00003Ool007oo00Uoo`03001oo`00008000Aoo`800003Ool007oo00800<9oo`00
3Woo0P001Goo00<007ooOol0<7oo00P007ooOol007oo001oo`0037oo0`000Woo00L007oo000007oo
001oo`020032Ool001Eoo`03001oogoo031oo`08001oogoo001oo`00Ool000eoo`80009oo`07001o
o`00001oo`00Ool00P00`Woo000EOol00`00Oomoo`0`Ool00`00Oomoo`02Ool3000=Ool2000017oo
000007oo100000=oo`000000`Woo000EOol00`00Oomoo`0`Ool00`00Oomoo`02Ool3000>Ool01@00
Ool00000Ool010000Woo00<007ooOol0`7oo000EOol2000aOol00`00Oomoo`02Ool3000>Ool40000
0goo001oo`020002Ool20031Ool001Eoo`03001oogoo031oo`03001oogoo009oo`<000ioo`H00003
Ool00000009oo`800<5oo`005Goo00<007ooOol0<7oo00<007ooOol00goo0P003Woo1P0000=oo`00
00000Woo0P001Woo00<007ooOol0^7oo000EOol00`00Oomoo`0`Ool00`00Oomoo`03Ool2000>Ool6
00000goo00000003Ool00`00Oomoo`04Ool2002iOol001Eoo`03001oogoo031oo`03001oogoo00=o
o`8000ioo`<00004Ool00000Ool20003Ool00`00Oomoo`04Ool2002iOol001Eoo`03001oogoo031o
o`03001oogoo00=oo`8000ioo`<00004Ool00000Ool20003Ool00`00Oomoo`04Ool2002iOol001Eo
o`03001oogoo031oo`03001oogoo00=oo`8000moo`800004Ool007ooOol20003Ool00`00Oomoo`04
Ool2002iOol001Eoo`80035oo`03001oogoo00=oo`8000moo`800005Ool007ooOol00004Ool00`00
Oomoo`04Ool2002iOol001Eoo`03001oogoo031oo`03001oogoo00=oo`03001oogoo00ioo`04001o
ogoo0002Ool00`00Oomoo`02Ool20005Ool2002iOol001Eoo`03001oogoo031oo`03001oogoo01Mo
o`04001oogoo0004Ool20005Ool2002iOol001Eoo`03001oogoo031oo`03001oogoo01Moo`04001o
ogoo0004Ool20005Ool2002iOol001Eoo`03001oogoo031oo`03001oogoo01Yoo`03001oogoo009o
o`8000Eoo`800;Uoo`005Goo00<007ooOol0<7oo00<007ooOol07goo0`0017oo0P0017oo00<007oo
Ool0/Woo000EOol00`00Oomoo`0`Ool00`00Oomoo`0OOol30004Ool30003Ool00`00Oomoo`2bOol0
01Eoo`80035oo`03001oogoo021oo`8000Aoo`03001oo`0000=oo`03001oogoo0;9oo`005Goo00<0
07ooOol0;Goo00@007ooOol002=oo`03001oogoo009oo`03001oo`0000=oo`03001oogoo0;9oo`00
5Goo00<007ooOol0;Goo00@007ooOol002=oo`03001oogoo009oo`03001oo`0000=oo`03001oogoo
0;9oo`005Goo00<007ooOol0;Goo00@007ooOol002=oo`03001oogoo009oo`03001oo`0000=oo`80
0;=oo`005Goo00<007ooOol0;Goo00@007ooOol002=oo`03001oogoo009oo`05001oo`00001oo`03
002cOol001Eoo`03001oogoo02eoo`800003Ool007oo029oo`03001oogoo009oo`05001oo`00001o
o`030005Ool00`00Oomoo`2[Ool001Eoo`03001oogoo02eoo`800003Ool007oo029oo`03001oogoo
009oo`08001oo`00001oo`00Ool000Eoo`03001oogoo0:]oo`005Goo0P00;Woo0P0000=oo`00Ool0
8Woo00<007ooOol00Woo00<007oo00000`0000=oo`00Ool017oo00<007ooOol0Zgoo000EOol00`00
Oomoo`0]Ool200000goo001oo`0ROol00`00Oomoo`02Ool00`00Oomoo`03000017oo001oo`000goo
00<007ooOol0Zgoo000EOol00`00Oomoo`0]Ool200000goo001oo`0ROol00`00Oomoo`02Ool00`00
Oomoo`03000027oo00000000Ool007oo002]Ool001Eoo`03001oogoo02eoo`800003Ool007oo029o
o`06001oogoo001oo`000Woo0`0000Eoo`00000007oo00<00:eoo`005Goo00<007ooOol0;Goo0P00
00=oo`00Ool08Woo00<007ooOol00`000Woo0`0000Eoo`00000007oo00<00:eoo`003Goo0`001Goo
00<007ooOol0;Goo0P0000=oo`00Ool08Woo00<007ooOol00P000goo0P000Woo1`00[Goo000>Ool0
0`00Oomoo`04Ool00`00Oomoo`0]Ool200000goo001oo`0ROol00`00Oomoo`020007Ool200000goo
00000002002]Ool000Moo`D0009oo`03001oogoo00Aoo`<002eoo`800003Ool007oo029oo`03001o
o`00008000Moo`800003Ool0000000800:eoo`003Woo00<007ooOol017oo00<007ooOol0;Goo0P00
00=oo`00Ool08Woo00<007oo00000P001goo0P0000=oo`0000000P00[Goo000>Ool00`00Oomoo`04
Ool00`00Oomoo`0]Ool200000goo001oo`0SOol40007Ool200000goo00000002002]Ool000eoo`80
00Ioo`03001oogoo02eoo`800003Ool007oo02=oo`@000Moo`800003Ool0000000800:eoo`005Goo
00<007ooOol0;Goo0P0000=oo`00Ool08goo10001goo00<007ooOol01@00[7oo000EOol00`00Oomo
o`0?Ool00`00Oomoo`0KOol4000TOol30008Ool00`00Oomoo`05002/Ool001Eoo`80011oo`8001ao
o`@002Aoo`<000eoo`<00:aoo`005Goo00<007ooOol03goo0P0077oo100097oo0P003Woo00<007oo
0000[7oo000EOol00`00Oomoo`0?Ool2000LOol4000TOol2000>Ool00`00Ool0002/Ool001Eoo`03
001oogoo00moo`800003Ool007oo01Uoo`@002Aoo`8000ioo`03001oo`0000=oo`03001oogoo0:Io
o`005Goo00<007ooOol03goo0P0000=oo`00Ool06Goo00@007oo000002Aoo`8000ioo`03001oo`00
009oo`800:Qoo`005Goo00<007ooOol03goo0P0000=oo`00Ool06Goo00@007oo000002Aoo`8000io
o`03001oo`00009oo`8006]oo`03001oogoo03Yoo`005Goo00<007ooOol03goo0P0000=oo`00Ool0
6Goo00@007ooOol002Aoo`80011oo`800003Ool0000000ioo`03001oogoo05Uoo`8003aoo`005Goo
0P0047oo10006Woo00@007ooOol002Aoo`80011oo`800003Ool0000000ioo`03001oogoo05Uoo`80
03aoo`005Goo00<007ooOol03goo10006Woo00@007ooOol002Aoo`80011oo`L000aoo`03001oogoo
05Uoo`8003aoo`005Goo00<007ooOol03goo10006Woo00@007ooOol002Aoo`80015oo`H000aoo`03
001oogoo05Uoo`8003aoo`005Goo00<007ooOol03goo1@006Goo00@007ooOol002Aoo`80015oo`@0
0003Ool007oo00]oo`03001oogoo05Uoo`8003aoo`005Goo00<007ooOol03goo1@006Goo00@007oo
Ool002Aoo`80015oo`@00003Ool007oo00Yoo`<005Yoo`8003aoo`005Goo00<007ooOol03goo00<0
07oo00000P006Goo00@007ooOol002Aoo`80015oo`800004Ool007oo000;Ool00`00Ool0001EOol0
0`00Oomoo`02Ool2000lOol001Eoo`03001oogoo00moo`03001oo`00008001Uoo`04001oogoo000T
Ool2000AOol2000017oo001oo`002goo00<007oo0000EGoo00<007ooOol00Woo0P00?7oo000EOol2
000@Ool00`00Oomoo`02000IOol01000Oomoo`0097oo0P004Goo0P0000Aoo`00Ool000]oo`03001o
o`0005Aoo`8000Aoo`8003aoo`005Goo00<007ooOol03goo00D007ooOomoo`0001Uoo`04001oogoo
000gOol20003Ool00`00Oomoo`09Ool00`00Ool0001DOol20004Ool4000jOol001Eoo`03001oogoo
00moo`05001oogooOol0000IOol00`00Oomoo`0hOol20003Ool00`00Oomoo`09Ool00`00Ool0001D
Ool20003Ool5000jOol001Eoo`03001oogoo00Aoo`8000Uoo`05001oogooOol0000IOol00`00Oomo
o`0hOol20003Ool00`00Oomoo`09Ool00`00Ool0001DOol20003Ool5000jOol001Eoo`03001oogoo
00Aoo`8000Uoo`04001oogooOol2000HOol00`00Oomoo`030004Ool20004Ool20004Ool2000SOol2
0003Ool40003Ool20003Ool30004Ool2000YOol30004Ool20004Ool20004Ool2000@Ool20003Ool5
000?Ool30003Ool20004Ool20004Ool2000GOol001Eoo`03001oogoo00Aoo`8000Aoo`03001oogoo
009oo`04001oogooOol2000HOol01@00Oomoogoo000017oo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`008goo00@007ooOomoo`8000Aoo`04001oogoo0002Ool01000Ool000000Woo00@0
07ooOol002]oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00eo
o`80009oo`H0011oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001o
ogoo01Aoo`005Goo00<007ooOol017oo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool05Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol002=o
o`07001oogooOol007oo00000goo00@007ooOol0009oo`05001oo`00001oo`020002Ool00`00Oomo
o`0YOol01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0=Ool20002
Ool200000goo00000003000<Ool40002Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo
000FOol001Eoo`8000Eoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`8001Moo`05001oogoo
Ool00004Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000WOol01000Oomoo`000Woo
00@007ooOol0009oo`05001oo`00001oo`020002Ool00`00Oomoo`0WOol20003Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000?Ool20002Ool200000goo00000004000;Ool00`00Ool0
0003Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol001Eoo`03001oogoo00Ao
o`8000Aoo`03001oo`00009oo`03001oogoo009oo`8000Aoo`80015oo`05001oogooOol00004Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000WOol200001Goo001oogoo00000Woo00D0
07ooOol007oo00800003Ool00000009oo`03001oogoo00Eoo`03001oogoo025oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00eoo`80009oo`80009oo`H000Yoo`03
001oo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol001Ioo`005Goo00<007oo
Ool017oo0P0017oo0`000Woo00<007ooOol00Woo0P0017oo0`0047oo00<007ooOol00P001Goo0P00
17oo0P0017oo0P00:7oo0`0017oo0`0000=oo`00Ool00`0000=oo`00Ool00P0027oo0P007goo0`00
17oo0P0017oo0P0017oo0P0047oo0P000Woo0P000Woo1P002goo0P0017oo0P0017oo0P0017oo0P00
5goo000EOol00`00Oomoo`03Ool30004Ool30002Ool00`00Oomoo`02Ool20004Ool3000@Ool00`00
Oomoo`0mOol20006Ool200000goo001oo`02Ool01000Ool000002Woo0`00@goo0P000Woo00<007oo
Ool00Woo1@004Woo00<007ooOol08Goo000EOol00`00Oomoo`03Ool30004Ool30002Ool00`00Oomo
o`02Ool20004Ool3000@Ool00`00Oomoo`0mOol20006Ool200000goo001oo`02Ool01000Ool00000
2Woo0`009Goo00<007ooOol06goo0P000Woo00<007ooOol00Woo1@004Woo00<007ooOol08Goo000E
Ool00`00Oomoo`03Ool30003Ool40002Ool00`00Oomoo`02Ool30003Ool3000@Ool00`00Oomoo`0m
Ool20006Ool200000goo001oo`02Ool01000Ool000002Woo0`009Goo00<007ooOol06goo0P000Woo
00<007ooOol00Woo1P0000=oo`00Ool03Woo00<007ooOol04goo0P0000=oo`0000002Goo000EOol0
0`00Oomoo`03Ool30003Ool40002Ool00`00Oomoo`02Ool30003Ool4000?Ool00`00Oomoo`0nOol2
0005Ool200000goo001oo`02Ool01000Ool000002Woo0`009Goo00<007ooOol06goo00<007oo0000
0P0017oo20003goo00<007ooOol057oo00<007oo00002Woo000?Oooo000:0008Ool00`00Oomoo`09
Ool001Eoo`03001oogoo00=oo`<00003Ool0000000@0009oo`03001oogoo00=oo`8000=oo`04001o
ogoo0004Ool00`00Oomoo`08Ool2000<Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool01000Ool000001Goo0P0000=oo`00Ool00Woo00@007oo000000Eoo`03001o
ogoo009oo`<000Aoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Ioo`80009oo`03001o
ogoo00Uoo`03001oogoo00Uoo`04001oo`00Ool30006Ool60006Ool00`00Oomoo`05Ool20002Ool0
0`00Oomoo`0AOol00`00Ool0000:Ool001Eoo`03001oogoo00=oo`04001oo`00Ool60002Ool00`00
Oomoo`03Ool20003Ool01000Oomoo`003goo00<007ooOol02goo00<007ooOol0<7oo0P001Goo0P00
00=oo`00Ool00Woo00@007oo000000Yoo`03001oo`0002Eoo`80009oo`03001oogoo01Moo`03001o
o`00008000Moo`H000eoo`80009oo`03001oogoo011oo`800003Ool0000000Uoo`005Goo00<007oo
Ool00goo00@007oo001oo`H0009oo`03001oogoo00=oo`8000=oo`04001oogoo0008Ool00`00Oomo
o`04Ool00`00Oomoo`0nOol30004Ool200000goo001oo`02Ool01000Ool000002Woo00<007oo0000
9Goo0P0077oo00<007oo00000P0027oo1@003Goo0P008goo000EOol00`00Oomoo`03Ool01000Ool0
07oo1P0000=oo`0000001Woo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo03moo`8000Aoo`800003Ool007oo009oo`04001oo`00000:Ool00`00Ool0000UOol2000L
Ool00`00Ool000020008Ool5000<Ool4000ROol001Eoo`03001oogoo00=oo`04001oo`00Ool20000
1Goo00000000Ool00P001Woo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo03moo`8000Aoo`800003Ool007oo009oo`04001oo`00000:Ool00`00Ool0000UOol2000L
Ool00`00Ool000020008Ool300000goo001oo`0;Ool200000goo001oo`0QOol001Eoo`03001oogoo
00=oo`04001oo`00Ool200000goo000000040006Ool01@00Oomoogoo00000Woo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol0?goo0P0017oo0P0000=oo`00Ool00Woo00@007oo000000Yoo`03
001oo`0002Eoo`8001aoo`03001oo`00008000Qoo`<00003Ool007oo00]oo`800003Ool007oo025o
o`005Goo0P0017oo00@007oo001oo`80009oo`D000Ioo`05001oogooOol00002Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`10Ool20003Ool200000goo001oo`02Ool01000Ool000002Woo
00<007oo00009Goo0P0067oo00<007ooOol00P0000Aoo`00000000Qoo`<00003Ool007oo00]oo`80
0003Ool007oo025oo`005Goo00<007ooOol00goo00<007oo00000P0017oo10001Woo00D007ooOomo
o`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo041oo`8000=oo`800003Ool007oo
009oo`04001oo`000004Ool00`00Oomoo`03Ool01@00Ool007oo000067oo00<007ooOol027oo0P00
67oo00@007ooOol0009oo`<000Qoo`<00003Ool007oo00]oo`800003Ool007oo025oo`005Goo00<0
07ooOol00goo00<007ooOol00P0017oo10001Woo00D007ooOomoo`00009oo`03001oogoo00Ioo`03
001oogoo00Aoo`03001oogoo045oo`<00005Ool00000Ool00003Ool40004Ool00`00Oomoo`03Ool0
0`00Ool00002000HOol00`00Oomoo`08Ool01000Ool000005Woo00@007ooOol0009oo`<000Qoo`<0
0003Ool0000000]oo`04001oogoo000ROol001Eoo`03001oogoo00=oo`03001oogoo008000Eoo`<0
00Ioo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`11Ool30000
1Goo000007oo00000goo100017oo00<007ooOol00goo00<007oo00000P0000=oo`00Ool05Goo00<0
07ooOol027oo00<007oo00000P005Goo0P0000Aoo`00Oomoo`<000Qoo`<00003Ool0000000]oo`04
001oogoo000ROol001Eoo`03001oogoo00=oo`03001oogoo008000Eoo`<000Ioo`05001oogooOol0
0002Ool00`00Ool00006Ool00`00Oomoo`04Ool00`00Oomoo`11Ool300001Goo000007oo00000goo
10000Woo00@007oo000000Aoo`03001oogoo00800003Ool007oo01Eoo`03001oogoo00Qoo`03001o
o`00008001Eoo`800003Ool007oo009oo`8000Uoo`800003Ool0000000Yoo`80009oo`80025oo`00
5Goo00<007ooOol00goo00<007ooOol00P001Goo0`001Woo0P000Woo00H007ooOol007oo0006Ool0
0`00Oomoo`04Ool00`00Oomoo`12Ool200000goo001oo`020003Ool300001Goo001oo`00Ool00`00
0Woo00@007ooOomoo`800003Ool007oo01Eoo`03001oogoo00Qoo`03001oo`00008001Aoo`<00003
Ool007oo009oo`8000Uoo`800004Ool000000009Ool20002Ool2000QOol001Eoo`03001oogoo00=o
o`03001oogoo008000Eoo`<000Ioo`80009oo`06001oogoo001oo`001Woo00<007ooOol017oo00<0
07ooOol0@Woo0P0000=oo`00Ool00P0017oo00D007ooOol007oo00D0009oo`04001oogooOol20000
0goo001oo`0EOol00`00Oomoo`08Ool00`00Ool00002000DOol300000goo001oo`02Ool00`00Oomo
o`09Ool00`00Ool000020004Ool01000Oomoogoo0`000Woo0`0087oo000EOol20004Ool00`00Oomo
o`020005Ool20008Ool01000Oomoo`000Woo00<007oo00001Woo00<007oo000017oo00<007ooOol0
@Woo100000=oo`0000001goo00<007oo000010000Woo00@007ooOomoo`800003Ool007oo01Eoo`03
001oogoo00Qoo`03001oo`00008001Aoo`D000=oo`03001oogoo00Uoo`03001oo`00008000Aoo`04
001oogooOol30002Ool3000POol001Eoo`03001oogoo00=oo`03001oogoo008000Ioo`03001oogoo
00Ioo`04001oogoo0002Ool00`00Ool00006Ool30004Ool00`00Oomoo`12Ool400000goo00000007
Ool00`00Ool000040002Ool01000Oomoogoo10005Goo0P0027oo00@007oo001oo`<001Aoo`800003
Ool0000000=oo`03001oogoo00]oo`<000Aoo`80009oo`<0009oo`<0021oo`005Goo00<007ooOol0
0goo00<007ooOol00P003goo00@007ooOol0009oo`<000Ioo`@000=oo`03001oogoo04=oo`<00003
Ool0000000Moo`03001oo`0000D00003Ool007oo009oo`D001Aoo`03001oo`0000Moo`04001oo`00
Ool30004Ool00`00Oomoo`0=Ool00`00Oomoo`02000AOol30004Ool3000017oo000000000Woo1000
7goo000EOol00`00Oomoo`03Ool00`00Oomoo`02000?Ool2000017oo001oogoo0`001Woo10000goo
00<007ooOol0A7oo0P0000=oo`0000001goo00<007oo00000P0000=oo`0000000P000goo1@0057oo
00<007oo00000goo00/007ooOomoo`00Ool007oo001oo`0000Aoo`03001oogoo00eoo`03001oogoo
0080015oo`<000Aoo`L0009oo`@001moo`005Goo00<007ooOol00goo00<007ooOol00P003goo0P00
00Aoo`00Oomoo`<000Ioo`@000=oo`03001oogoo04Aoo`03001oogoo008000Moo`03001oo`000080
0003Ool00000008000=oo`D001Aoo`03001oo`0000=oo`03001oogoo00<0009oo`03001oo`0000Ao
o`03001oogoo00eoo`03001oogoo0080015oo`@000=oo`L0009oo`D001ioo`005Goo00<007ooOol0
0goo00@007ooOol0011oo`@0009oo`<000Ioo`@000=oo`03001oogoo04Aoo`03001oogoo00Uoo`04
001oo`000002Ool40003Ool00`00Ool000020007Ool00`00Oomoo`0:Ool00`00Ool00003Ool00`00
Oomoo`030004Ool00`00Oomoo`02Ool2000>Ool00`00Oomoo`02000AOol40002Ool80002Ool20000
0goo0000000NOol001Eoo`03001oogoo00=oo`03001oogoo015oo`@000=oo`<000Eoo`@000=oo`03
001oogoo04Aoo`03001oogoo00Uoo`03001oo`0000=oo`@000=oo`03001oo`0000<000Ioo`03001o
ogoo00Moo`06001oogoo001oo`000goo00<007ooOol00`0017oo00<007ooOol00Woo0P003Woo00<0
07ooOol057oo00<007oo00000Woo0P0000Aoo`00001oo`8000=oo`04001oogoo000NOol001Eoo`80
00Aoo`03001oogoo015oo`<000Aoo`05001oo`00Ool00003Ool40003Ool00`00Oomoo`14Ool00`00
Oomoo`09Ool00`00Ool00003Ool40003Ool01000Oomoogoo0P001Woo00<007ooOol01Woo0P000Woo
00<007oo00000goo00<007ooOol00`001Goo00@007ooOomoo`8000ioo`03001oogoo01Ioo`03001o
o`000080009oo`04001oo`000006Ool00`00Oomoo`0LOol001Eoo`03001oogoo00=oo`03001oogoo
015oo`<000Aoo`05001oo`00Ool00003Ool40003Ool00`00Oomoo`14Ool00`00Oomoo`09Ool00`00
Ool00003Ool200000goo001oo`06Ool20006Ool00`00Oomoo`06Ool20002Ool00`00Ool00003Ool0
0`00Oomoo`030005Ool01000Ool007oo0P003Woo00<007ooOol05Woo00<007oo00000P000Woo00@0
07oo000000Ioo`03001oogoo01aoo`005Goo0P0017oo00<007ooOol04Goo0`0017oo00D007oo001o
o`0000=oo`@000=oo`03001oogoo055oo`8000=oo`8000Uoo`8000Ioo`03001oogoo00Ioo`80009o
o`04001oo`000002Ool2000017oo000000001Goo0`0000=oo`0000003Woo00<007ooOol05Woo1@00
0Woo00@007oo000000Ioo`8001eoo`005Goo0`000goo00<007ooOol04Goo0`0017oo00D007oo001o
o`0000=oo`@000=oo`03001oogoo055oo`03001oogoo009oo`8000Yoo`03001oogoo00Aoo`03001o
ogoo00Eoo`<0009oo`04001oo`000002Ool2000017oo000000001Goo1P003Woo00<007ooOol05Woo
1@000Woo00@007ooOol000Ioo`8001eoo`005Goo0`000goo00<007ooOol04Goo0`0017oo00<007oo
00000P000goo10000goo00<007ooOol0DGoo00<007ooOol00Woo0P002Woo00<007ooOol00goo0P00
1goo0P0000Aoo`00Ool0009oo`03001oogoo00800004Ool000000005Ool7000=Ool00`00Oomoo`0F
Ool50005Ool00`00Oomoo`04Ool2000MOol001Eoo`<000=oo`03001oogoo015oo`8000Eoo`03001o
o`00008000=oo`04001oo`000003Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`09Ool0
0`00Oomoo`03Ool20007Ool2000017oo001oo`000Woo00<007ooOol00P0000Aoo`00000000Eoo`L0
00eoo`03001oogoo01Ioo`@000Ioo`03001oogoo00Aoo`8001eoo`005Goo0`000goo00<007ooOol0
4Goo0P001Goo00<007oo00000`000Woo00@007oo000000=oo`03001oogoo055oo`03001oogoo00io
o`03001oogoo00=oo`8000Moo`800004Ool007oo0002Ool00`00Oomoo`060005Ool7000=Ool00`00
Oomoo`0FOol40006Ool00`00Oomoo`04Ool2000MOol001Eoo`<000=oo`03001oogoo015oo`8000Eo
o`03001oo`0000<0009oo`04001oo`000003Ool00`00Oomoo`1AOol00`00Oomoo`0>Ool00`00Oomo
o`03Ool20007Ool2000017oo001oo`000Woo00<007ooOol01P001Goo1`003Goo00<007ooOol05Woo
10001Woo00<007ooOol01Goo00<007ooOol06goo000EOol30002Ool2000COol00`00Oomoo`04Ool0
0`00Ool0000400001Goo001oogoo00000goo00<007ooOol0HWoo00<007ooOol00goo0P000goo00@0
07ooOomoo`800004Ool007oo0002Ool200000goo000000040005Ool500000goo001oo`07Ool20003
Ool00`00Oomoo`0FOol40006Ool00`00Oomoo`05Ool00`00Oomoo`0KOol001Eoo`<0009oo`8001Yo
o`03001oo`0000@00005Ool007ooOol00003Ool00`00Oomoo`1ROol00`00Oomoo`03Ool20003Ool0
1000Oomoogoo0P0000Aoo`00Ool0009oo`<00003Ool007oo00<000Eoo`D00003Ool007oo00Moo`80
00=oo`03001oogoo01Ioo`@000Ioo`03001oogoo00Eoo`03001oogoo01]oo`005Goo0`000Woo0P00
6Woo00<007ooOol0100000Eoo`00Oomoo`0000=oo`03001oogoo069oo`03001oogoo00=oo`8000=o
o`80009oo`800004Ool007oo0002Ool30003Ool30005Ool50002Ool00`00Oomoo`05Ool20003Ool0
0`00Oomoo`0GOol00`00Ool0000>Ool00`00Oomoo`0KOol000eoo`<000Eoo`<0009oo`8001eoo`@0
0003Ool007oo009oo`04001oogoo001TOol00`00Oomoo`02Ool30003Ool20002Ool2000017oo0000
00000Woo0`0017oo0P001Goo0P0000=oo`0000000Woo00<007ooOol01Goo0P000goo00<007ooOol0
5goo00<007ooOol03Woo00<007ooOol06goo000>Ool00`00Oomoo`04Ool30002Ool2000NOol30000
0goo001oo`02Ool01000Oomoo`00I7oo00<007ooOol00Woo10000Woo0P000Woo0P0000Aoo`000000
00=oo`8000Eoo`03001oogoo00=oo`800003Ool00000009oo`03001oogoo009oo`03001oogoo0080
00=oo`03001oogoo01Moo`03001oogoo00ioo`03001oogoo01]oo`003Woo00<007ooOol017oo0`00
0Woo00<007ooOol07Woo0P0000=oo`00Ool00Woo00@007ooOol006Aoo`05001oogoo001oo`020000
17oo001oogoo0P000Woo0P0000Aoo`00000000Aoo`03001oogoo00=oo`03001oogoo00=oo`800003
Ool00000009oo`04001oogooOol20002Ool30002Ool00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00
Oomoo`0KOol000ioo`03001oogoo00Aoo`@00003Ool007oo021oo`<000=oo`04001oogoo001TOol0
0`00Oomoo`030002Ool00`00Oomoo`020002Ool20002Ool20004Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool200000goo00000002Ool01000Oomoogoo0P000Woo0`000Woo00<007ooOol0:7oo00@007oo
Ool001Yoo`003Woo00<007ooOol017oo00H007ooOol007oo000ROol20003Ool01000Oomoo`00I7oo
00<007ooOol00`000Woo00<007ooOol00P000Woo00@007ooOomoo`8000Aoo`03001oogoo00Uoo`80
0003Ool00000009oo`04001oogooOol20002Ool00`00Ool00002Ool00`00Oomoo`0XOol01000Oomo
o`006Woo000=Ool20006Ool00`00Oomoo`02000SOol20003Ool01000Oomoo`00I7oo00<007ooOol0
0`000Woo0P0000=oo`0000000Woo00@007ooOomoo`8000Aoo`03001oogoo00Uoo`800003Ool00000
009oo`80009oo`80009oo`03001oo`00009oo`03001oogoo02Qoo`800003Ool007oo01Uoo`005Goo
00<007ooOol00P008goo0P000goo00@007ooOol006Eoo`03001oo`000080009oo`800003Ool00000
009oo`04001oogooOol20004Ool00`00Oomoo`0:Ool01000Ool000000Woo0P000Woo0P000Woo00<0
07oo00000Woo00<007ooOol0:Goo00<007oo00006Woo000EOol00`00Oomoo`02000SOol20003Ool0
1000Oomoo`00IGoo00<007oo00000P000Woo0P0000=oo`0000000Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol02Woo00@007oo0000009oo`<00003Ool00000009oo`06001oo`00001oo`00
:goo00<007oo00006Woo000EOol00`00Oomoo`02000SOol20003Ool01000Oomoo`00IGoo00<007oo
00000P000goo00D007oo000007oo008001Ioo`04001oogoo0002Ool300000goo00000002Ool00`00
Oomoo`03000[Ool00`00Ool0000JOol001Eoo`80009oo`03001oogoo025oo`8000=oo`04001oogoo
001UOol01@00Ool007oo00000goo00<007oo000010006Goo00@007ooOomoo`800003Ool00000009o
o`03001oogoo00<002]oo`<001Yoo`005Goo00D007ooOomoo`0002=oo`8000=oo`04001oogoo001U
Ool01@00Ool007oo00000goo1`006Goo00@007ooOomoo`800003Ool00000009oo`03001oogoo00<0
02]oo`<001Yoo`005Goo00D007ooOomoo`0002=oo`8000=oo`04001oogoo001UOol00`00Ool00005
Ool7000IOol01000Oomoogoo0P0000=oo`0000000Woo00<007ooOol00`00:goo0`006Woo000EOol0
0`00Oomoo`0UOol20003Ool01000Oomoo`00IGoo00<007oo00001Goo0P0000=oo`0000000P006Goo
00@007ooOomoo`800003Ool00000009oo`03001oogoo00<002]oo`<001Yoo`005Goo00<007ooOol0
9Goo00<007ooOol00Woo00@007oo000006Eoo`8000Ioo`800003Ool00000008001eoo`800004Ool0
0000Ool20003Ool2000[Ool2000KOol001Eoo`03001oogoo02Yoo`@006Eoo`8000Ioo`800003Ool0
0000008001eoo`800004Ool00000Ool20003Ool2000[Ool2000KOol001Eoo`03001oogoo02Yoo`@0
06Eoo`8000Ioo`80009oo`8001ioo`800004Ool00000Ool20003Ool2000[Ool2000KOol001Eoo`80
02aoo`<006Eoo`8000Ioo`80009oo`03001oogoo01eoo`800004Ool00000Ool20003Ool2000[Ool0
0`00Oomoo`0JOol001Eoo`03001oogoo02]oo`<006Eoo`8000Ioo`80009oo`03001oogoo01eoo`80
0003Ool0000000<000=oo`8004Qoo`005Goo00<007ooOol0:goo0`00IWoo00<007ooOol01Goo00<0
07ooOol08Goo00<007oo0000100017oo00<007ooOol0AWoo000EOol00`00Oomoo`0[Ool3001VOol0
0`00Oomoo`0YOol00`00Ool000040004Ool00`00Oomoo`16Ool001Eoo`03001oogoo02]oo`<006Io
o`03001oogoo02Uoo`L000Aoo`03001oogoo04Ioo`005Goo00<007ooOol0:goo0`00IWoo00<007oo
Ool0:Goo1`0017oo00<007ooOol0AWoo000EOol00`00Oomoo`0[Ool00`00Ool0001VOol00`00Oomo
o`0ZOol200000goo00000005Ool00`00Oomoo`16Ool001Eoo`8002aoo`03001oo`0006Ioo`03001o
ogoo02Yoo`80009oo`03001oogoo00=oo`03001oogoo04Ioo`005Goo00<007ooOol0:goo00<007oo
0000Tgoo0P0027oo00<007ooOol0AWoo000EOol00`00Oomoo`31Ool2001AOol001Eoo`03001oogoo
0<5oo`80055oo`005Goo00<007ooOol0`Goo0P00DGoo000EOol00`00Oomoo`31Ool2001AOol001Eo
o`03001oogoo0<5oo`80055oo`005Goo0P00ogoo5Woo000EOol00`00Oomoo`3oOolEOol001Eoo`03
001oogoo0?mooaEoo`005Goo00<007ooOol0ogoo5Goo003oOol]Ool00?moobeoo`00ogoo;Goo003o
Ool]Ool00?moobeoo`00ogoo;Goo000BOol00`00Oomoo`08Ool00`00Oomoo`3oOol=Ool0015oo`03
001oogoo00Yoo`03001oogoo0?moo`aoo`002Woo1@000Woo00@007ooOomoo`800003Ool0000000Ao
o`03001oogoo0?moo`aoo`002Woo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Eoo`03
001oogoo0?moo`aoo`002Woo00@007ooOol000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo0?moo`aoo`002Woo00@007ooOol000=oo`03001oogoo009oo`03001oo`0000Eoo`03001oogoo
0?moo`aoo`002Goo0P0000=oo`0000000goo00@007ooOomoo`800003Ool0000000Aoo`03001oogoo
0?moo`aoo`004Woo00<007ooOol027oo00<007ooOol0ogoo3Goo003oOol]Ool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-354.799, -2.85982, 16.2681, 
  0.0290254}},
  CellTags->"S2.1.2"]
}, Open  ]],

Cell["\<\
We first transform the data using the spline wavelet of order \
4.\
\>", "MathCaption",
  CellTags->{"S2.1.2", "2.8"}],

Cell["\<\
(s4 = SplineFilter[4, 8];
 wtdata = WaveletTransform[data, s4];)\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.2"],

Cell["\<\
We set the coefficients below the threshold 1.5 to zero and shrink \
the rest. Note that the residual trend is excluded from shrinking.\
\>", 
  "MathCaption",
  CellTags->{"S2.1.2", "2.9"}],

Cell["Compress[Rest[wtdata], 1.5, Shrinking -> True];", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.2"],

Cell["\<\
Next we do the inverse transform and obtain the \"denoised\" \
data.\
\>", "MathCaption",
  CellTags->{"S2.1.2", "2.10"}],

Cell["\<\
InverseWaveletTransform[
Join[{wtdata[[1]]}, %], s4];\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.2"],

Cell["This shows the data after denoising.", "MathCaption",
  CellTags->{"S2.1.2", "2.11"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotJoined -> True,
AxesLabel -> {\"x\", \"u(x)\"}]\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.392359 0.138884 [
[.25632 .37986 -12 -9 ]
[.25632 .37986 12 0 ]
[.48884 .37986 -12 -9 ]
[.48884 .37986 12 0 ]
[.72135 .37986 -12 -9 ]
[.72135 .37986 12 0 ]
[.95387 .37986 -12 -9 ]
[.95387 .37986 12 0 ]
[1.025 .39236 0 -4.5 ]
[1.025 .39236 6 4.5 ]
[.01131 .11459 -12 -4.5 ]
[.01131 .11459 0 4.5 ]
[.01131 .25347 -12 -4.5 ]
[.01131 .25347 0 4.5 ]
[.01131 .53124 -6 -4.5 ]
[.01131 .53124 0 4.5 ]
[.02381 .64303 -12 0 ]
[.02381 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 .39236 m
.25632 .39861 L
s
[(1000)] .25632 .37986 0 1 Mshowa
.48884 .39236 m
.48884 .39861 L
s
[(2000)] .48884 .37986 0 1 Mshowa
.72135 .39236 m
.72135 .39861 L
s
[(3000)] .72135 .37986 0 1 Mshowa
.95387 .39236 m
.95387 .39861 L
s
[(4000)] .95387 .37986 0 1 Mshowa
.125 Mabswid
.07031 .39236 m
.07031 .39611 L
s
.11682 .39236 m
.11682 .39611 L
s
.16332 .39236 m
.16332 .39611 L
s
.20982 .39236 m
.20982 .39611 L
s
.30283 .39236 m
.30283 .39611 L
s
.34933 .39236 m
.34933 .39611 L
s
.39583 .39236 m
.39583 .39611 L
s
.44234 .39236 m
.44234 .39611 L
s
.53534 .39236 m
.53534 .39611 L
s
.58185 .39236 m
.58185 .39611 L
s
.62835 .39236 m
.62835 .39611 L
s
.67485 .39236 m
.67485 .39611 L
s
.76786 .39236 m
.76786 .39611 L
s
.81436 .39236 m
.81436 .39611 L
s
.86086 .39236 m
.86086 .39611 L
s
.90737 .39236 m
.90737 .39611 L
s
.25 Mabswid
0 .39236 m
1 .39236 L
s
[(x)] 1.025 .39236 -1 0 Mshowa
.02381 .11459 m
.03006 .11459 L
s
[(-2)] .01131 .11459 1 0 Mshowa
.02381 .25347 m
.03006 .25347 L
s
[(-1)] .01131 .25347 1 0 Mshowa
.02381 .53124 m
.03006 .53124 L
s
[(1)] .01131 .53124 1 0 Mshowa
.125 Mabswid
.02381 .14237 m
.02756 .14237 L
s
.02381 .17014 m
.02756 .17014 L
s
.02381 .19792 m
.02756 .19792 L
s
.02381 .2257 m
.02756 .2257 L
s
.02381 .28125 m
.02756 .28125 L
s
.02381 .30903 m
.02756 .30903 L
s
.02381 .3368 m
.02756 .3368 L
s
.02381 .36458 m
.02756 .36458 L
s
.02381 .42014 m
.02756 .42014 L
s
.02381 .44791 m
.02756 .44791 L
s
.02381 .47569 m
.02756 .47569 L
s
.02381 .50347 m
.02756 .50347 L
s
.02381 .08681 m
.02756 .08681 L
s
.02381 .05904 m
.02756 .05904 L
s
.02381 .03126 m
.02756 .03126 L
s
.02381 .00348 m
.02756 .00348 L
s
.02381 .55902 m
.02756 .55902 L
s
.02381 .5868 m
.02756 .5868 L
s
.02381 .61457 m
.02756 .61457 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02404 .5152 m
.02427 .51443 L
.02451 .51362 L
.02474 .51299 L
.02497 .51177 L
.0252 .51116 L
.02544 .51046 L
.02567 .50984 L
.0259 .50864 L
.02613 .50801 L
.02637 .50739 L
.0266 .50691 L
.02683 .50604 L
.02706 .50559 L
.0273 .50516 L
.02753 .5048 L
.02776 .50418 L
.02799 .50386 L
.02823 .50369 L
.02846 .50366 L
.02869 .50358 L
.02892 .50363 L
.02916 .50379 L
.02939 .50403 L
.02962 .50429 L
.02985 .50446 L
.03009 .50466 L
.03032 .50486 L
.03055 .50521 L
.03078 .50528 L
.03102 .50539 L
.03125 .50551 L
.03148 .50599 L
.03172 .50615 L
.03195 .5065 L
.03218 .50694 L
.03241 .50797 L
.03265 .50861 L
.03288 .50943 L
.03311 .51029 L
.03334 .51175 L
.03358 .51265 L
.03381 .51364 L
.03404 .51446 L
.03427 .51581 L
.03451 .51645 L
.03474 .5171 L
.03497 .5175 L
.0352 .51845 L
.03544 .51891 L
Mistroke
.03567 .51961 L
.0359 .52024 L
.03613 .52143 L
.03637 .52217 L
.0366 .5229 L
.03683 .52343 L
.03706 .52422 L
.0373 .5248 L
.03753 .52541 L
.03776 .52586 L
.03799 .52633 L
.03823 .5265 L
.03846 .52632 L
.03869 .52569 L
.03892 .52478 L
.03916 .52422 L
.03939 .52384 L
.03962 .52357 L
.03985 .52301 L
.04009 .52289 L
.04032 .52244 L
.04055 .52167 L
.04078 .52 L
.04102 .51933 L
.04125 .5187 L
.04148 .51812 L
.04171 .51646 L
.04195 .51569 L
.04218 .51435 L
.04241 .51251 L
.04264 .50903 L
.04288 .50718 L
.04311 .5055 L
.04334 .50413 L
.04357 .50124 L
.04381 .49992 L
.04404 .49804 L
.04427 .49596 L
.0445 .4917 L
.04474 .48953 L
.04497 .48729 L
.0452 .4855 L
.04543 .48171 L
.04567 .47966 L
.0459 .4769 L
.04613 .474 L
.04636 .46885 L
.0466 .46597 L
.04683 .46333 L
.04706 .46148 L
Mistroke
.04729 .45805 L
.04753 .45649 L
.04776 .45461 L
.04799 .45282 L
.04822 .44926 L
.04846 .44756 L
.04869 .44617 L
.04892 .44532 L
.04915 .44328 L
.04939 .44236 L
.04962 .44122 L
.04985 .43988 L
.05008 .4374 L
.05032 .43609 L
.05055 .43541 L
.05078 .43525 L
.05101 .43474 L
.05125 .43479 L
.05148 .43487 L
.05171 .43481 L
.05194 .43424 L
.05218 .43409 L
.05241 .43431 L
.05264 .43473 L
.05287 .4351 L
.05311 .43528 L
.05334 .43529 L
.05357 .43493 L
.0538 .43451 L
.05404 .43412 L
.05427 .43425 L
.0545 .43469 L
.05473 .43564 L
.05497 .43643 L
.0552 .43729 L
.05543 .43794 L
.05566 .43875 L
.0559 .43938 L
.05613 .44021 L
.05636 .44093 L
.05659 .44185 L
.05683 .44238 L
.05706 .44275 L
.05729 .44263 L
.05752 .44244 L
.05776 .44224 L
.05799 .44227 L
.05822 .44232 L
.05845 .44241 L
.05869 .44263 L
Mistroke
.05892 .44272 L
.05915 .44267 L
.05938 .44215 L
.05962 .44197 L
.05985 .44156 L
.06008 .44114 L
.06031 .44004 L
.06055 .43925 L
.06078 .43798 L
.06101 .43655 L
.06124 .43432 L
.06148 .43287 L
.06171 .43144 L
.06194 .43037 L
.06217 .42873 L
.06241 .42797 L
.06264 .42705 L
.06287 .42628 L
.0631 .42475 L
.06334 .42415 L
.06357 .4236 L
.0638 .42322 L
.06403 .42212 L
.06427 .42163 L
.0645 .42094 L
.06473 .42004 L
.06496 .41837 L
.0652 .4175 L
.06543 .41693 L
.06566 .41657 L
.06589 .41573 L
.06613 .41545 L
.06636 .41508 L
.06659 .41461 L
.06682 .41344 L
.06706 .41294 L
.06729 .41256 L
.06752 .41235 L
.06775 .41161 L
.06799 .41119 L
.06822 .41048 L
.06845 .40953 L
.06868 .40796 L
.06892 .40702 L
.06915 .40635 L
.06938 .40601 L
.06961 .40542 L
.06985 .40529 L
.07008 .40505 L
.07031 .40471 L
Mistroke
.07055 .40387 L
.07078 .40356 L
.07101 .40341 L
.07124 .40337 L
.07148 .40301 L
.07171 .4029 L
.07194 .40265 L
.07217 .40209 L
.07241 .40104 L
.07264 .40047 L
.07287 .40018 L
.0731 .40004 L
.07334 .39962 L
.07357 .3996 L
.0738 .39949 L
.07403 .39925 L
.07427 .39842 L
.0745 .39805 L
.07473 .39763 L
.07496 .39727 L
.0752 .39636 L
.07543 .39573 L
.07566 .39478 L
.07589 .39371 L
.07613 .39204 L
.07636 .39096 L
.07659 .39002 L
.07682 .38944 L
.07706 .3886 L
.07729 .38829 L
.07752 .38792 L
.07775 .38766 L
.07799 .38699 L
.07822 .38681 L
.07845 .38671 L
.07868 .38672 L
.07892 .38643 L
.07915 .38628 L
.07938 .386 L
.07961 .38549 L
.07985 .38471 L
.08008 .38426 L
.08031 .38414 L
.08054 .38421 L
.08078 .38428 L
.08101 .3845 L
.08124 .38472 L
.08147 .3848 L
.08171 .38466 L
.08194 .38477 L
Mistroke
.08217 .38502 L
.0824 .3853 L
.08264 .38539 L
.08287 .38542 L
.0831 .38518 L
.08333 .38456 L
.08357 .38359 L
.0838 .38297 L
.08403 .38264 L
.08426 .3825 L
.0845 .38223 L
.08473 .38227 L
.08496 .38214 L
.08519 .38177 L
.08543 .38087 L
.08566 .38056 L
.08589 .38036 L
.08612 .38023 L
.08636 .37954 L
.08659 .37928 L
.08682 .37866 L
.08705 .37765 L
.08729 .37572 L
.08752 .37466 L
.08775 .37376 L
.08798 .37305 L
.08822 .37155 L
.08845 .37088 L
.08868 .36988 L
.08891 .36872 L
.08915 .36635 L
.08938 .36514 L
.08961 .36391 L
.08984 .36296 L
.09008 .36091 L
.09031 .35982 L
.09054 .35828 L
.09077 .35662 L
.09101 .35367 L
.09124 .352 L
.09147 .35045 L
.0917 .34934 L
.09194 .34732 L
.09217 .34637 L
.0924 .34521 L
.09263 .34407 L
.09287 .34188 L
.0931 .34083 L
.09333 .34001 L
.09356 .33953 L
Mistroke
.0938 .33836 L
.09403 .33795 L
.09426 .33746 L
.09449 .33684 L
.09473 .33546 L
.09496 .33478 L
.09519 .33435 L
.09542 .33411 L
.09566 .33345 L
.09589 .3332 L
.09612 .33293 L
.09635 .33256 L
.09659 .33173 L
.09682 .33125 L
.09705 .33093 L
.09728 .3308 L
.09752 .33049 L
.09775 .33039 L
.09798 .33027 L
.09821 .3302 L
.09845 .32997 L
.09868 .32977 L
.09891 .32958 L
.09914 .32951 L
.09938 .32951 L
.09961 .32947 L
.09984 .32952 L
.10007 .32967 L
.10031 .33007 L
.10054 .3302 L
.10077 .33039 L
.101 .33064 L
.10124 .33134 L
.10147 .33179 L
.1017 .33252 L
.10193 .33342 L
.10217 .33492 L
.1024 .33574 L
.10263 .33647 L
.10286 .337 L
.1031 .33808 L
.10333 .33854 L
.10356 .33928 L
.10379 .34013 L
.10403 .34183 L
.10426 .34261 L
.10449 .34332 L
.10472 .34385 L
.10496 .34519 L
.10519 .34589 L
Mistroke
.10542 .34696 L
.10565 .34833 L
.10589 .3507 L
.10612 .35196 L
.10635 .3529 L
.10658 .35349 L
.10682 .35478 L
.10705 .35523 L
.10728 .35596 L
.10751 .35692 L
.10775 .35901 L
.10798 .35992 L
.10821 .3606 L
.10844 .36104 L
.10868 .36242 L
.10891 .36307 L
.10914 .36416 L
.10938 .36571 L
.10961 .36852 L
.10984 .37003 L
.11007 .37112 L
.11031 .37177 L
.11054 .37327 L
.11077 .37379 L
.111 .37468 L
.11124 .37587 L
.11147 .37843 L
.1117 .37964 L
.11193 .38061 L
.11217 .38124 L
.1124 .38297 L
.11263 .38382 L
.11286 .38522 L
.1131 .38707 L
.11333 .39039 L
.11356 .39224 L
.11379 .39367 L
.11403 .39457 L
.11426 .39639 L
.11449 .39705 L
.11472 .39804 L
.11496 .39929 L
.11519 .40198 L
.11542 .40321 L
.11565 .40418 L
.11589 .40482 L
.11612 .40657 L
.11635 .40734 L
.11658 .40852 L
.11682 .41012 L
Mistroke
.11705 .41319 L
.11728 .41487 L
.11751 .41618 L
.11775 .41707 L
.11798 .41892 L
.11821 .41966 L
.11844 .42066 L
.11868 .4218 L
.11891 .42432 L
.11914 .4256 L
.11937 .4268 L
.11961 .42764 L
.11984 .42954 L
.12007 .43056 L
.1203 .43196 L
.12054 .43346 L
.12077 .43608 L
.121 .43765 L
.12123 .43899 L
.12147 .43981 L
.1217 .44114 L
.12193 .44166 L
.12216 .44218 L
.1224 .44257 L
.12263 .44351 L
.12286 .44388 L
.12309 .44408 L
.12333 .44409 L
.12356 .4443 L
.12379 .44434 L
.12402 .4443 L
.12426 .44436 L
.12449 .4445 L
.12472 .44462 L
.12495 .44444 L
.12519 .44415 L
.12542 .44356 L
.12565 .44312 L
.12588 .44247 L
.12612 .44177 L
.12635 .44075 L
.12658 .44017 L
.12681 .43959 L
.12705 .43908 L
.12728 .43817 L
.12751 .43784 L
.12774 .43748 L
.12798 .43714 L
.12821 .4362 L
.12844 .43589 L
Mistroke
.12867 .43548 L
.12891 .43503 L
.12914 .43378 L
.12937 .43307 L
.1296 .4321 L
.12984 .43103 L
.13007 .42913 L
.1303 .42799 L
.13053 .42688 L
.13077 .42602 L
.131 .42451 L
.13123 .42374 L
.13146 .42283 L
.1317 .42209 L
.13193 .42063 L
.13216 .41989 L
.13239 .41909 L
.13263 .41851 L
.13286 .41738 L
.13309 .41674 L
.13332 .41602 L
.13356 .41531 L
.13379 .41421 L
.13402 .41357 L
.13425 .41317 L
.13449 .41299 L
.13472 .41277 L
.13495 .41288 L
.13518 .41323 L
.13542 .41366 L
.13565 .41404 L
.13588 .41442 L
.13611 .41483 L
.13635 .41515 L
.13658 .41546 L
.13681 .41558 L
.13704 .41577 L
.13728 .41592 L
.13751 .41623 L
.13774 .41621 L
.13797 .41622 L
.13821 .41627 L
.13844 .41667 L
.13867 .41687 L
.1389 .41726 L
.13914 .41793 L
.13937 .4191 L
.1396 .41968 L
.13983 .42004 L
.14007 .4203 L
Mistroke
.1403 .42102 L
.14053 .42123 L
.14076 .42166 L
.141 .42228 L
.14123 .42374 L
.14146 .42437 L
.14169 .42498 L
.14193 .42547 L
.14216 .42686 L
.14239 .42767 L
.14262 .42899 L
.14286 .43064 L
.14309 .43341 L
.14332 .43499 L
.14355 .4363 L
.14379 .43716 L
.14402 .43879 L
.14425 .43944 L
.14448 .44042 L
.14472 .44157 L
.14495 .44395 L
.14518 .44498 L
.14541 .44579 L
.14565 .44631 L
.14588 .44785 L
.14611 .44854 L
.14634 .44967 L
.14658 .45129 L
.14681 .45427 L
.14704 .45584 L
.14727 .45693 L
.14751 .4576 L
.14774 .4592 L
.14797 .45973 L
.1482 .46064 L
.14844 .46188 L
.14867 .46462 L
.1489 .4659 L
.14914 .46694 L
.14937 .46764 L
.1496 .46955 L
.14983 .47052 L
.15007 .47209 L
.1503 .47414 L
.15053 .47778 L
.15076 .47983 L
.151 .48145 L
.15123 .48248 L
.15146 .48451 L
.15169 .48527 L
Mistroke
.15193 .48641 L
.15216 .48778 L
.15239 .49069 L
.15262 .49204 L
.15286 .49309 L
.15309 .49378 L
.15332 .49561 L
.15355 .49641 L
.15379 .49763 L
.15402 .49929 L
.15425 .50246 L
.15448 .50419 L
.15472 .50549 L
.15495 .50633 L
.15518 .50814 L
.15541 .50882 L
.15565 .50976 L
.15588 .51088 L
.15611 .51339 L
.15634 .51464 L
.15658 .51575 L
.15681 .51651 L
.15704 .51831 L
.15727 .51925 L
.15751 .52059 L
.15774 .52209 L
.15797 .52475 L
.1582 .52636 L
.15844 .52773 L
.15867 .5286 L
.1589 .53001 L
.15913 .53057 L
.15937 .53116 L
.1596 .53166 L
.15983 .53279 L
.16006 .53326 L
.1603 .53355 L
.16053 .53364 L
.16076 .534 L
.16099 .53407 L
.16123 .53407 L
.16146 .53416 L
.16169 .53445 L
.16192 .53462 L
.16216 .53456 L
.16239 .53438 L
.16262 .53409 L
.16285 .53389 L
.16309 .53357 L
.16332 .53317 L
Mistroke
.16355 .53259 L
.16378 .53233 L
.16402 .53208 L
.16425 .53175 L
.16448 .53105 L
.16471 .53086 L
.16495 .53065 L
.16518 .53037 L
.16541 .52946 L
.16564 .52917 L
.16588 .52875 L
.16611 .52826 L
.16634 .52684 L
.16657 .52597 L
.16681 .52469 L
.16704 .52337 L
.16727 .52104 L
.1675 .51957 L
.16774 .51795 L
.16797 .51675 L
.1682 .5147 L
.16843 .51337 L
.16867 .51161 L
.1689 .51009 L
.16913 .50786 L
.16936 .50656 L
.1696 .50543 L
.16983 .50484 L
.17006 .50405 L
.17029 .50383 L
.17053 .50367 L
.17076 .50338 L
.17099 .50294 L
.17122 .50304 L
.17146 .50383 L
.17169 .50461 L
.17192 .50553 L
.17215 .50667 L
.17239 .50817 L
.17262 .50905 L
.17285 .50962 L
.17308 .51032 L
.17332 .51131 L
.17355 .51187 L
.17378 .51187 L
.17401 .51194 L
.17425 .5117 L
.17448 .51105 L
.17471 .50935 L
.17494 .50806 L
Mistroke
.17518 .5063 L
.17541 .50477 L
.17564 .50216 L
.17587 .50023 L
.17611 .49759 L
.17634 .49543 L
.17657 .49229 L
.1768 .49009 L
.17704 .48749 L
.17727 .48571 L
.1775 .48347 L
.17773 .48211 L
.17797 .48068 L
.1782 .47987 L
.17843 .47907 L
.17866 .47883 L
.1789 .47902 L
.17913 .47954 L
.17936 .48061 L
.17959 .48168 L
.17983 .48345 L
.18006 .48507 L
.18029 .48746 L
.18052 .48924 L
.18076 .49168 L
.18099 .49362 L
.18122 .49634 L
.18145 .49812 L
.18169 .50035 L
.18192 .50201 L
.18215 .5043 L
.18238 .50552 L
.18262 .50675 L
.18285 .50745 L
.18308 .50852 L
.18331 .50887 L
.18355 .50913 L
.18378 .50925 L
.18401 .50959 L
.18424 .5094 L
.18448 .50877 L
.18471 .50817 L
.18494 .50757 L
.18517 .50706 L
.18541 .50637 L
.18564 .50622 L
.18587 .50602 L
.1861 .50567 L
.18634 .50455 L
.18657 .5035 L
Mistroke
.1868 .50225 L
.18703 .50111 L
.18727 .50001 L
.1875 .49954 L
.18773 .49956 L
.18797 .49939 L
.1882 .49922 L
.18843 .49928 L
.18866 .50008 L
.1889 .50067 L
.18913 .50192 L
.18936 .50373 L
.18959 .50675 L
.18983 .50879 L
.19006 .51084 L
.19029 .51245 L
.19052 .51503 L
.19076 .51614 L
.19099 .5176 L
.19122 .51877 L
.19145 .52152 L
.19169 .52289 L
.19192 .52486 L
.19215 .52664 L
.19238 .53012 L
.19262 .53226 L
.19285 .53477 L
.19308 .53704 L
.19331 .54066 L
.19355 .54296 L
.19378 .54528 L
.19401 .54703 L
.19424 .54954 L
.19448 .55054 L
.19471 .55103 L
.19494 .55067 L
.19517 .55079 L
.19541 .55074 L
.19564 .55115 L
.19587 .55161 L
.1961 .55235 L
.19634 .55289 L
.19657 .5528 L
.1968 .55191 L
.19703 .55025 L
.19727 .54974 L
.1975 .54969 L
.19773 .55012 L
.19796 .54948 L
.1982 .54939 L
Mistroke
.19843 .54763 L
.19866 .54475 L
.19889 .53926 L
.19913 .53615 L
.19936 .53308 L
.19959 .53022 L
.19982 .5251 L
.20006 .5222 L
.20029 .51827 L
.20052 .51248 L
.20075 .50349 L
.20099 .49968 L
.20122 .49858 L
.20145 .49852 L
.20168 .4956 L
.20192 .49732 L
.20215 .49816 L
.20238 .49737 L
.20261 .48927 L
.20285 .4863 L
.20308 .48162 L
.20331 .47648 L
.20354 .46262 L
.20378 .45255 L
.20401 .43773 L
.20424 .42134 L
.20447 .39623 L
.20471 .37954 L
.20494 .36381 L
.20517 .35266 L
.2054 .33685 L
.20564 .33 L
.20587 .32264 L
.2061 .31724 L
.20633 .30563 L
.20657 .30255 L
.2068 .30062 L
.20703 .30033 L
.20726 .29435 L
.2075 .29231 L
.20773 .2885 L
.20796 .28222 L
.20819 .26984 L
.20843 .26237 L
.20866 .25746 L
.20889 .25459 L
.20912 .24916 L
.20936 .2468 L
.20959 .2439 L
.20982 .24053 L
Mistroke
.21005 .23392 L
.21029 .23098 L
.21052 .22986 L
.21075 .23016 L
.21098 .22943 L
.21122 .23007 L
.21145 .2302 L
.21168 .22796 L
.21191 .22365 L
.21215 .22207 L
.21238 .22355 L
.21261 .2257 L
.21284 .22732 L
.21308 .23056 L
.21331 .23355 L
.21354 .23469 L
.21377 .23196 L
.21401 .23092 L
.21424 .22913 L
.21447 .22707 L
.2147 .22096 L
.21494 .21593 L
.21517 .20797 L
.2154 .1992 L
.21563 .1861 L
.21587 .17668 L
.2161 .16726 L
.21633 .16072 L
.21656 .15238 L
.2168 .14827 L
.21703 .14376 L
.21726 .1409 L
.21749 .13582 L
.21773 .13446 L
.21796 .13369 L
.21819 .13406 L
.21842 .13293 L
.21866 .13325 L
.21889 .13343 L
.21912 .13263 L
.21935 .13039 L
.21959 .12925 L
.21982 .12964 L
.22005 .13012 L
.22028 .13063 L
.22052 .1314 L
.22075 .13287 L
.22098 .13356 L
.22121 .13414 L
.22145 .13508 L
Mistroke
.22168 .13725 L
.22191 .13936 L
.22214 .14167 L
.22238 .14363 L
.22261 .14534 L
.22284 .14599 L
.22307 .14574 L
.22331 .14553 L
.22354 .14514 L
.22377 .14471 L
.224 .14328 L
.22424 .1418 L
.22447 .13909 L
.2247 .13606 L
.22493 .13168 L
.22517 .12828 L
.2254 .12469 L
.22563 .12226 L
.22586 .11945 L
.2261 .118 L
.22633 .11628 L
.22656 .11519 L
.2268 .11351 L
.22703 .11308 L
.22726 .11285 L
.22749 .11294 L
.22773 .11268 L
.22796 .11298 L
.22819 .11348 L
.22842 .11345 L
.22866 .11304 L
.22889 .11319 L
.22912 .11416 L
.22935 .11496 L
.22959 .11561 L
.22982 .11646 L
.23005 .11748 L
.23028 .11803 L
.23052 .11789 L
.23075 .11803 L
.23098 .11808 L
.23121 .11799 L
.23145 .11699 L
.23168 .11599 L
.23191 .11418 L
.23214 .11201 L
.23238 .10885 L
.23261 .10654 L
.23284 .10431 L
.23307 .10284 L
Mistroke
.23331 .10097 L
.23354 .10008 L
.23377 .0989 L
.234 .09795 L
.23424 .09628 L
.23447 .0957 L
.2347 .09533 L
.23493 .09524 L
.23517 .09465 L
.2354 .09463 L
.23563 .0945 L
.23586 .09388 L
.2361 .09254 L
.23633 .09199 L
.23656 .09202 L
.23679 .09213 L
.23703 .09179 L
.23726 .09195 L
.23749 .09201 L
.23772 .09171 L
.23796 .09046 L
.23819 .08996 L
.23842 .08953 L
.23865 .08918 L
.23889 .08791 L
.23912 .08704 L
.23935 .08553 L
.23958 .08363 L
.23982 .0806 L
.24005 .07868 L
.24028 .07705 L
.24051 .07601 L
.24075 .07435 L
.24098 .07369 L
.24121 .07272 L
.24144 .07168 L
.24168 .06956 L
.24191 .06869 L
.24214 .06806 L
.24237 .0677 L
.24261 .0665 L
.24284 .06607 L
.24307 .06531 L
.2433 .06407 L
.24354 .06166 L
.24377 .06041 L
.244 .05962 L
.24423 .05912 L
.24447 .05783 L
.2447 .05744 L
Mistroke
.24493 .05683 L
.24516 .05593 L
.2454 .05375 L
.24563 .05273 L
.24586 .0518 L
.24609 .05112 L
.24633 .04933 L
.24656 .04833 L
.24679 .04679 L
.24702 .04496 L
.24726 .04179 L
.24749 .03989 L
.24772 .03825 L
.24795 .03716 L
.24819 .03528 L
.24842 .03448 L
.24865 .03344 L
.24888 .0324 L
.24912 .03029 L
.24935 .02932 L
.24958 .02855 L
.24981 .02812 L
.25005 .02695 L
.25028 .02647 L
.25051 .02579 L
.25074 .02486 L
.25098 .0231 L
.25121 .02214 L
.25144 .02155 L
.25167 .02125 L
.25191 .02057 L
.25214 .0204 L
.25237 .02021 L
.2526 .01991 L
.25284 .01904 L
.25307 .01868 L
.2533 .01849 L
.25353 .01846 L
.25377 .01811 L
.254 .01796 L
.25423 .01764 L
.25446 .01716 L
.2547 .0163 L
.25493 .01572 L
.25516 .01534 L
.25539 .01518 L
.25563 .01497 L
.25586 .01496 L
.25609 .01495 L
.25632 .01493 L
Mistroke
.25656 .01476 L
.25679 .01472 L
.25702 .01475 L
.25725 .01486 L
.25749 .01497 L
.25772 .01508 L
.25795 .01519 L
.25818 .01524 L
.25842 .01526 L
.25865 .01522 L
.25888 .01523 L
.25911 .01525 L
.25935 .01536 L
.25958 .01544 L
.25981 .0156 L
.26004 .01581 L
.26028 .01611 L
.26051 .01625 L
.26074 .01633 L
.26097 .01639 L
.26121 .01654 L
.26144 .01659 L
.26167 .01669 L
.2619 .0169 L
.26214 .01731 L
.26237 .01745 L
.2626 .01748 L
.26283 .01747 L
.26307 .01766 L
.2633 .01768 L
.26353 .01783 L
.26376 .01816 L
.264 .01888 L
.26423 .01922 L
.26446 .01948 L
.26469 .01971 L
.26493 .0203 L
.26516 .02059 L
.26539 .02109 L
.26563 .02177 L
.26586 .02301 L
.26609 .02367 L
.26632 .02422 L
.26656 .02461 L
.26679 .02547 L
.26702 .02582 L
.26725 .02638 L
.26749 .02705 L
.26772 .02846 L
.26795 .02917 L
Mistroke
.26818 .02986 L
.26842 .0304 L
.26865 .03159 L
.26888 .03223 L
.26911 .03314 L
.26935 .03419 L
.26958 .03601 L
.26981 .03702 L
.27004 .03787 L
.27028 .03843 L
.27051 .0395 L
.27074 .03992 L
.27097 .04047 L
.27121 .04106 L
.27144 .04235 L
.27167 .04293 L
.2719 .0434 L
.27214 .04371 L
.27237 .04457 L
.2726 .045 L
.27283 .04561 L
.27307 .04641 L
.2733 .0478 L
.27353 .04858 L
.27376 .04908 L
.274 .04933 L
.27423 .04985 L
.27446 .04996 L
.27469 .05014 L
.27493 .05038 L
.27516 .05111 L
.27539 .05138 L
.27562 .05156 L
.27586 .05162 L
.27609 .05202 L
.27632 .05227 L
.27655 .05272 L
.27679 .05339 L
.27702 .05445 L
.27725 .05511 L
.27748 .05549 L
.27772 .05563 L
.27795 .05582 L
.27818 .05573 L
.27841 .05569 L
.27865 .05573 L
.27888 .05607 L
.27911 .05609 L
.27934 .05601 L
.27958 .05589 L
Mistroke
.27981 .05601 L
.28004 .05606 L
.28027 .0563 L
.28051 .05685 L
.28074 .05776 L
.28097 .05831 L
.2812 .05861 L
.28144 .05874 L
.28167 .05905 L
.2819 .05904 L
.28213 .05914 L
.28237 .05936 L
.2826 .06007 L
.28283 .06033 L
.28306 .06059 L
.2833 .06079 L
.28353 .06149 L
.28376 .06193 L
.28399 .06273 L
.28423 .06376 L
.28446 .06542 L
.28469 .06644 L
.28492 .06725 L
.28516 .06777 L
.28539 .06863 L
.28562 .06891 L
.28585 .06933 L
.28609 .06982 L
.28632 .07094 L
.28655 .07135 L
.28678 .07165 L
.28702 .07185 L
.28725 .07262 L
.28748 .07297 L
.28771 .07359 L
.28795 .07453 L
.28818 .07622 L
.28841 .07715 L
.28864 .07779 L
.28888 .07821 L
.28911 .07912 L
.28934 .07941 L
.28957 .07988 L
.28981 .08049 L
.29004 .08194 L
.29027 .08259 L
.2905 .08318 L
.29074 .0836 L
.29097 .08476 L
.2912 .08542 L
Mistroke
.29143 .08646 L
.29167 .08774 L
.2919 .0899 L
.29213 .09119 L
.29236 .09222 L
.2926 .09288 L
.29283 .09403 L
.29306 .09446 L
.29329 .09505 L
.29353 .0957 L
.29376 .09713 L
.29399 .09772 L
.29422 .09815 L
.29446 .09839 L
.29469 .09921 L
.29492 .09955 L
.29515 .10012 L
.29539 .10098 L
.29562 .10257 L
.29585 .10344 L
.29608 .10399 L
.29632 .10429 L
.29655 .105 L
.29678 .10518 L
.29701 .10548 L
.29725 .10593 L
.29748 .10708 L
.29771 .10759 L
.29794 .10801 L
.29818 .10827 L
.29841 .10908 L
.29864 .10953 L
.29887 .11029 L
.29911 .11127 L
.29934 .1129 L
.29957 .1139 L
.2998 .11468 L
.30004 .11513 L
.30027 .11588 L
.3005 .11612 L
.30073 .11645 L
.30097 .11683 L
.3012 .11772 L
.30143 .11806 L
.30166 .11827 L
.3019 .11836 L
.30213 .11881 L
.30236 .11898 L
.30259 .11929 L
.30283 .11982 L
Mistroke
.30306 .12084 L
.30329 .12141 L
.30352 .12176 L
.30376 .12195 L
.30399 .12238 L
.30422 .12248 L
.30445 .12264 L
.30469 .12287 L
.30492 .12354 L
.30515 .12384 L
.30539 .12412 L
.30562 .12431 L
.30585 .12486 L
.30608 .12522 L
.30632 .12577 L
.30655 .12643 L
.30678 .12748 L
.30701 .12818 L
.30725 .12875 L
.30748 .1291 L
.30771 .12958 L
.30794 .12974 L
.30818 .12992 L
.30841 .13007 L
.30864 .13041 L
.30887 .1305 L
.30911 .13049 L
.30934 .13042 L
.30957 .13046 L
.3098 .13041 L
.31004 .13037 L
.31027 .13047 L
.3105 .13071 L
.31073 .13084 L
.31097 .13083 L
.3112 .13079 L
.31143 .13078 L
.31166 .13071 L
.3119 .13065 L
.31213 .13063 L
.31236 .13073 L
.31259 .13077 L
.31283 .13081 L
.31306 .13082 L
.31329 .13092 L
.31352 .13103 L
.31376 .13125 L
.31399 .13151 L
.31422 .13187 L
.31445 .13215 L
Mistroke
.31469 .1324 L
.31492 .13253 L
.31515 .13264 L
.31538 .13266 L
.31562 .13268 L
.31585 .13267 L
.31608 .13267 L
.31631 .13261 L
.31655 .13248 L
.31678 .13236 L
.31701 .13221 L
.31724 .13205 L
.31748 .13184 L
.31771 .13172 L
.31794 .13163 L
.31817 .13154 L
.31841 .13142 L
.31864 .13136 L
.31887 .13136 L
.3191 .13135 L
.31934 .13135 L
.31957 .13137 L
.3198 .13152 L
.32003 .13164 L
.32027 .13187 L
.3205 .13209 L
.32073 .13246 L
.32096 .13277 L
.3212 .13316 L
.32143 .13347 L
.32166 .13388 L
.32189 .1342 L
.32213 .13458 L
.32236 .13485 L
.32259 .13514 L
.32282 .13531 L
.32306 .13543 L
.32329 .13542 L
.32352 .13533 L
.32375 .13525 L
.32399 .13514 L
.32422 .13504 L
.32445 .13482 L
.32468 .13466 L
.32492 .13437 L
.32515 .13407 L
.32538 .13357 L
.32561 .13325 L
.32585 .13284 L
.32608 .1325 L
Mistroke
.32631 .13196 L
.32654 .13164 L
.32678 .13121 L
.32701 .13079 L
.32724 .13015 L
.32747 .1298 L
.32771 .12951 L
.32794 .1293 L
.32817 .12894 L
.3284 .12886 L
.32864 .12881 L
.32887 .12878 L
.3291 .12849 L
.32933 .12842 L
.32957 .12834 L
.3298 .12821 L
.33003 .1278 L
.33026 .12755 L
.3305 .12724 L
.33073 .1269 L
.33096 .12631 L
.33119 .12591 L
.33143 .12555 L
.33166 .12529 L
.33189 .1249 L
.33212 .12473 L
.33236 .12456 L
.33259 .12454 L
.33282 .12437 L
.33305 .12429 L
.33329 .12408 L
.33352 .12391 L
.33375 .12362 L
.33398 .12336 L
.33422 .12313 L
.33445 .12296 L
.33468 .12287 L
.33491 .12273 L
.33515 .12268 L
.33538 .1227 L
.33561 .12297 L
.33584 .12326 L
.33608 .12381 L
.33631 .12455 L
.33654 .12559 L
.33677 .12625 L
.33701 .12678 L
.33724 .12711 L
.33747 .12763 L
.3377 .12777 L
Mistroke
.33794 .12805 L
.33817 .12838 L
.3384 .12918 L
.33863 .12941 L
.33887 .12958 L
.3391 .1297 L
.33933 .13034 L
.33956 .13067 L
.3398 .13132 L
.34003 .13233 L
.34026 .13404 L
.34049 .13497 L
.34073 .13558 L
.34096 .13593 L
.34119 .13678 L
.34142 .13701 L
.34166 .1375 L
.34189 .13824 L
.34212 .13992 L
.34235 .14062 L
.34259 .14117 L
.34282 .14154 L
.34305 .14281 L
.34328 .14347 L
.34352 .14467 L
.34375 .14634 L
.34398 .14924 L
.34422 .15086 L
.34445 .1521 L
.34468 .15291 L
.34491 .15456 L
.34515 .15516 L
.34538 .15614 L
.34561 .15743 L
.34584 .16016 L
.34608 .16139 L
.34631 .16236 L
.34654 .16303 L
.34677 .16493 L
.34701 .16578 L
.34724 .16719 L
.34747 .16912 L
.3477 .17275 L
.34794 .17471 L
.34817 .17626 L
.3484 .17733 L
.34863 .17964 L
.34887 .18058 L
.3491 .18197 L
.34933 .18363 L
Mistroke
.34956 .18712 L
.3498 .18885 L
.35003 .1904 L
.35026 .19151 L
.35049 .1941 L
.35073 .1954 L
.35096 .19728 L
.35119 .19948 L
.35142 .20347 L
.35166 .20571 L
.35189 .20762 L
.35212 .20889 L
.35235 .21129 L
.35259 .21232 L
.35282 .21362 L
.35305 .21499 L
.35328 .21781 L
.35352 .21917 L
.35375 .22024 L
.35398 .2209 L
.35421 .2225 L
.35445 .22319 L
.35468 .22408 L
.35491 .2252 L
.35514 .22739 L
.35538 .22859 L
.35561 .2294 L
.35584 .22984 L
.35607 .23076 L
.35631 .23104 L
.35654 .23135 L
.35677 .2317 L
.357 .23266 L
.35724 .23313 L
.35747 .23343 L
.3577 .23352 L
.35793 .23384 L
.35817 .23401 L
.3584 .23422 L
.35863 .2345 L
.35886 .23493 L
.3591 .2353 L
.35933 .23549 L
.35956 .23546 L
.35979 .23518 L
.36003 .23493 L
.36026 .2345 L
.36049 .23396 L
.36072 .2331 L
.36096 .23261 L
Mistroke
.36119 .23207 L
.36142 .23157 L
.36165 .23062 L
.36189 .23011 L
.36212 .22939 L
.36235 .22866 L
.36258 .2273 L
.36282 .22665 L
.36305 .22597 L
.36328 .22542 L
.36351 .22419 L
.36375 .22356 L
.36398 .22264 L
.36421 .22156 L
.36444 .21969 L
.36468 .21872 L
.36491 .21793 L
.36514 .21737 L
.36537 .21617 L
.36561 .21572 L
.36584 .2151 L
.36607 .21433 L
.3663 .21265 L
.36654 .21191 L
.36677 .21131 L
.367 .21087 L
.36723 .20964 L
.36747 .20907 L
.3677 .20823 L
.36793 .20717 L
.36816 .20508 L
.3684 .20393 L
.36863 .20291 L
.36886 .20217 L
.36909 .20068 L
.36933 .19997 L
.36956 .19902 L
.36979 .19803 L
.37002 .19611 L
.37026 .19509 L
.37049 .19415 L
.37072 .19351 L
.37095 .19225 L
.37119 .19167 L
.37142 .19094 L
.37165 .1902 L
.37188 .18877 L
.37212 .18799 L
.37235 .18735 L
.37258 .18694 L
Mistroke
.37281 .18616 L
.37305 .18586 L
.37328 .1856 L
.37351 .18537 L
.37374 .18479 L
.37398 .1845 L
.37421 .18431 L
.37444 .18423 L
.37467 .18403 L
.37491 .18396 L
.37514 .18398 L
.37537 .18407 L
.3756 .18415 L
.37584 .18412 L
.37607 .18412 L
.3763 .18418 L
.37653 .18443 L
.37677 .1845 L
.377 .18471 L
.37723 .18509 L
.37746 .18588 L
.3777 .18621 L
.37793 .18654 L
.37816 .18689 L
.37839 .18781 L
.37863 .18826 L
.37886 .18897 L
.37909 .18986 L
.37932 .19157 L
.37956 .19248 L
.37979 .19343 L
.38002 .19422 L
.38025 .19586 L
.38049 .19674 L
.38072 .19798 L
.38095 .19929 L
.38118 .20163 L
.38142 .2029 L
.38165 .20412 L
.38188 .20503 L
.38211 .20678 L
.38235 .20763 L
.38258 .20874 L
.38281 .20989 L
.38305 .21205 L
.38328 .21313 L
.38351 .21404 L
.38374 .21466 L
.38398 .21603 L
.38421 .21662 L
Mistroke
.38444 .21737 L
.38467 .21824 L
.38491 .21997 L
.38514 .22082 L
.38537 .2214 L
.3856 .22173 L
.38584 .22259 L
.38607 .2229 L
.3863 .22333 L
.38653 .22388 L
.38677 .22512 L
.387 .22575 L
.38723 .22619 L
.38746 .22644 L
.3877 .22708 L
.38793 .22738 L
.38816 .22784 L
.38839 .22844 L
.38863 .22949 L
.38886 .23011 L
.38909 .23051 L
.38932 .23066 L
.38956 .23093 L
.38979 .23094 L
.39002 .23098 L
.39025 .23107 L
.39049 .23141 L
.39072 .23154 L
.39095 .23155 L
.39118 .23149 L
.39142 .23151 L
.39165 .23147 L
.39188 .23146 L
.39211 .23158 L
.39235 .23182 L
.39258 .23199 L
.39281 .232 L
.39304 .23195 L
.39328 .23185 L
.39351 .23171 L
.39374 .23153 L
.39397 .23135 L
.39421 .23123 L
.39444 .23115 L
.39467 .23114 L
.3949 .23114 L
.39514 .2312 L
.39537 .23135 L
.3956 .23158 L
.39583 .23182 L
Mistroke
.39607 .23203 L
.3963 .23228 L
.39653 .23248 L
.39676 .23257 L
.397 .23248 L
.39723 .23238 L
.39746 .23217 L
.39769 .23185 L
.39793 .23133 L
.39816 .23095 L
.39839 .23057 L
.39862 .23027 L
.39886 .22981 L
.39909 .22958 L
.39932 .2293 L
.39955 .22912 L
.39979 .2287 L
.40002 .2285 L
.40025 .22819 L
.40048 .22791 L
.40072 .22739 L
.40095 .22706 L
.40118 .22666 L
.40141 .22629 L
.40165 .22573 L
.40188 .22537 L
.40211 .22506 L
.40234 .22482 L
.40258 .22453 L
.40281 .22448 L
.40304 .22457 L
.40327 .22479 L
.40351 .22495 L
.40374 .22512 L
.40397 .22521 L
.4042 .22521 L
.40444 .22509 L
.40467 .22494 L
.4049 .22482 L
.40513 .22476 L
.40537 .22476 L
.4056 .22462 L
.40583 .22443 L
.40606 .22431 L
.4063 .22435 L
.40653 .22433 L
.40676 .22445 L
.40699 .22485 L
.40723 .2256 L
.40746 .22598 L
Mistroke
.40769 .22621 L
.40792 .22641 L
.40816 .22697 L
.40839 .22714 L
.40862 .22752 L
.40885 .22803 L
.40909 .22925 L
.40932 .22984 L
.40955 .23051 L
.40978 .23109 L
.41002 .23244 L
.41025 .23327 L
.41048 .23453 L
.41071 .23595 L
.41095 .23826 L
.41118 .23963 L
.41141 .24085 L
.41164 .24169 L
.41188 .24315 L
.41211 .24376 L
.41234 .24458 L
.41257 .2454 L
.41281 .24709 L
.41304 .24779 L
.41327 .24833 L
.4135 .24868 L
.41374 .24972 L
.41397 .25017 L
.4142 .25085 L
.41443 .25185 L
.41467 .25369 L
.4149 .25464 L
.41513 .2552 L
.41536 .25549 L
.4156 .25631 L
.41583 .2565 L
.41606 .25688 L
.41629 .25747 L
.41653 .25895 L
.41676 .25961 L
.41699 .26014 L
.41722 .26048 L
.41746 .26154 L
.41769 .26216 L
.41792 .26321 L
.41815 .26458 L
.41839 .26684 L
.41862 .2682 L
.41885 .26921 L
.41908 .26977 L
Mistroke
.41932 .27076 L
.41955 .27103 L
.41978 .27149 L
.42001 .27209 L
.42025 .2735 L
.42048 .27404 L
.42071 .27438 L
.42094 .27455 L
.42118 .27535 L
.42141 .27566 L
.42164 .27627 L
.42188 .2773 L
.42211 .27922 L
.42234 .28026 L
.42257 .28092 L
.42281 .2813 L
.42304 .28223 L
.42327 .28246 L
.4235 .28289 L
.42374 .2835 L
.42397 .28512 L
.4242 .28586 L
.42443 .28659 L
.42467 .28714 L
.4249 .28858 L
.42513 .28947 L
.42536 .29085 L
.4256 .29249 L
.42583 .29514 L
.42606 .29678 L
.42629 .29814 L
.42653 .29899 L
.42676 .30035 L
.42699 .30084 L
.42722 .30147 L
.42746 .30208 L
.42769 .30349 L
.42792 .304 L
.42815 .30433 L
.42839 .30448 L
.42862 .30522 L
.42885 .30553 L
.42908 .30606 L
.42932 .30695 L
.42955 .30856 L
.42978 .30944 L
.43001 .3099 L
.43025 .31008 L
.43048 .31059 L
.43071 .31061 L
Mistroke
.43094 .31072 L
.43118 .31099 L
.43141 .31193 L
.43164 .31229 L
.43187 .31255 L
.43211 .31268 L
.43234 .31338 L
.43257 .31385 L
.4328 .31472 L
.43304 .31592 L
.43327 .3178 L
.4335 .319 L
.43373 .31987 L
.43397 .32034 L
.4342 .32103 L
.43443 .32116 L
.43466 .32141 L
.4349 .32174 L
.43513 .32266 L
.43536 .32291 L
.43559 .32299 L
.43583 .32299 L
.43606 .32346 L
.43629 .32361 L
.43652 .32401 L
.43676 .32485 L
.43699 .32638 L
.43722 .32724 L
.43745 .32774 L
.43769 .32803 L
.43792 .32876 L
.43815 .32891 L
.43838 .32923 L
.43862 .32973 L
.43885 .3311 L
.43908 .33171 L
.43931 .33235 L
.43955 .33286 L
.43978 .33422 L
.44001 .33509 L
.44024 .33644 L
.44048 .33803 L
.44071 .3406 L
.44094 .34219 L
.44117 .34356 L
.44141 .34444 L
.44164 .34585 L
.44187 .34639 L
.4421 .34708 L
.44234 .34775 L
Mistroke
.44257 .34922 L
.4428 .34977 L
.44303 .35016 L
.44327 .35035 L
.4435 .35118 L
.44373 .35153 L
.44396 .3521 L
.4442 .35302 L
.44443 .35469 L
.44466 .35559 L
.44489 .35607 L
.44513 .35629 L
.44536 .35687 L
.44559 .35693 L
.44582 .3571 L
.44606 .35744 L
.44629 .3585 L
.44652 .35891 L
.44675 .35921 L
.44699 .35938 L
.44722 .36015 L
.44745 .36063 L
.44768 .36152 L
.44792 .36274 L
.44815 .3647 L
.44838 .36593 L
.44861 .36683 L
.44885 .36733 L
.44908 .36813 L
.44931 .36833 L
.44954 .36868 L
.44978 .36914 L
.45001 .37026 L
.45024 .37065 L
.45047 .37087 L
.45071 .37096 L
.45094 .37159 L
.45117 .37183 L
.4514 .37235 L
.45164 .37328 L
.45187 .37498 L
.4521 .37592 L
.45233 .37652 L
.45257 .37687 L
.4528 .3777 L
.45303 .3779 L
.45326 .37828 L
.4535 .37883 L
.45373 .38028 L
.45396 .38092 L
Mistroke
.45419 .38154 L
.45443 .38201 L
.45466 .3833 L
.45489 .38407 L
.45512 .38529 L
.45536 .38676 L
.45559 .38921 L
.45582 .39071 L
.45605 .39198 L
.45629 .39282 L
.45652 .39422 L
.45675 .39478 L
.45698 .39552 L
.45722 .39626 L
.45745 .39781 L
.45768 .39845 L
.45791 .39893 L
.45815 .39919 L
.45838 .40007 L
.45861 .40043 L
.45884 .40102 L
.45908 .4019 L
.45931 .40352 L
.45954 .4044 L
.45977 .40493 L
.46001 .40521 L
.46024 .40586 L
.46047 .40602 L
.4607 .40629 L
.46094 .40671 L
.46117 .40777 L
.4614 .40822 L
.46164 .40851 L
.46187 .40863 L
.4621 .40922 L
.46233 .40952 L
.46257 .41009 L
.4628 .41093 L
.46303 .41239 L
.46326 .41326 L
.4635 .41389 L
.46373 .41424 L
.46396 .41486 L
.46419 .41502 L
.46443 .4153 L
.46466 .41568 L
.46489 .41661 L
.46512 .417 L
.46536 .41726 L
.46559 .41742 L
Mistroke
.46582 .41797 L
.46605 .41817 L
.46629 .41851 L
.46652 .41908 L
.46675 .42022 L
.46698 .42086 L
.46722 .42137 L
.46745 .42174 L
.46768 .42251 L
.46791 .42281 L
.46815 .42319 L
.46838 .42359 L
.46861 .42456 L
.46884 .42508 L
.46908 .42568 L
.46931 .42615 L
.46954 .42712 L
.46977 .42772 L
.47001 .4285 L
.47024 .4292 L
.47047 .43033 L
.4707 .43109 L
.47094 .43185 L
.47117 .43236 L
.4714 .43302 L
.47163 .43337 L
.47187 .43365 L
.4721 .43372 L
.47233 .4338 L
.47256 .43377 L
.4728 .43364 L
.47303 .43341 L
.47326 .433 L
.47349 .43272 L
.47373 .43228 L
.47396 .43182 L
.47419 .43103 L
.47442 .43057 L
.47466 .42996 L
.47489 .42939 L
.47512 .42838 L
.47535 .42784 L
.47559 .42713 L
.47582 .42648 L
.47605 .42528 L
.47628 .42462 L
.47652 .42384 L
.47675 .42314 L
.47698 .42187 L
.47721 .42116 L
Mistroke
.47745 .42035 L
.47768 .41966 L
.47791 .41843 L
.47814 .41777 L
.47838 .41711 L
.47861 .41661 L
.47884 .41568 L
.47907 .4152 L
.47931 .41469 L
.47954 .41432 L
.47977 .41362 L
.48 .4133 L
.48024 .41305 L
.48047 .41298 L
.4807 .41276 L
.48093 .41261 L
.48117 .41243 L
.4814 .41227 L
.48163 .41211 L
.48186 .41202 L
.4821 .41218 L
.48233 .41249 L
.48256 .41308 L
.48279 .41344 L
.48303 .41387 L
.48326 .41414 L
.48349 .41472 L
.48372 .41515 L
.48396 .41596 L
.48419 .41677 L
.48442 .41804 L
.48465 .41892 L
.48489 .41982 L
.48512 .42031 L
.48535 .42099 L
.48558 .42149 L
.48582 .42224 L
.48605 .42285 L
.48628 .42359 L
.48651 .42411 L
.48675 .42444 L
.48698 .42431 L
.48721 .42386 L
.48744 .4236 L
.48768 .42337 L
.48791 .42309 L
.48814 .42238 L
.48837 .42206 L
.48861 .42141 L
.48884 .42052 L
Mistroke
.48907 .4187 L
.4893 .41768 L
.48954 .41646 L
.48977 .41533 L
.49 .41318 L
.49023 .41204 L
.49047 .41053 L
.4907 .40906 L
.49093 .40626 L
.49116 .40467 L
.4914 .4028 L
.49163 .4012 L
.49186 .39834 L
.49209 .3968 L
.49233 .39504 L
.49256 .39361 L
.49279 .39097 L
.49302 .38949 L
.49326 .38782 L
.49349 .3865 L
.49372 .38421 L
.49395 .38294 L
.49419 .38171 L
.49442 .38093 L
.49465 .3796 L
.49488 .37885 L
.49512 .37813 L
.49535 .37774 L
.49558 .37721 L
.49581 .37692 L
.49605 .37695 L
.49628 .37737 L
.49651 .37824 L
.49674 .37872 L
.49698 .3794 L
.49721 .38017 L
.49744 .38179 L
.49767 .38263 L
.49791 .38397 L
.49814 .38547 L
.49837 .38837 L
.4986 .38995 L
.49884 .39189 L
.49907 .39364 L
.4993 .39705 L
.49953 .39894 L
.49977 .40142 L
.5 .40381 L
.50023 .4081 L
.50047 .41047 L
Mistroke
.5007 .413 L
.50093 .41502 L
.50116 .41876 L
.5014 .4207 L
.50163 .42299 L
.50186 .42503 L
.50209 .42878 L
.50233 .43069 L
.50256 .4325 L
.50279 .43378 L
.50302 .43636 L
.50326 .43763 L
.50349 .43905 L
.50372 .44036 L
.50395 .44278 L
.50419 .444 L
.50442 .44481 L
.50465 .44515 L
.50488 .44596 L
.50512 .44621 L
.50535 .44638 L
.50558 .4466 L
.50581 .44715 L
.50605 .44733 L
.50628 .447 L
.50651 .44644 L
.50674 .44567 L
.50698 .4451 L
.50721 .44442 L
.50744 .44403 L
.50767 .44342 L
.50791 .44306 L
.50814 .44221 L
.50837 .4413 L
.5086 .43979 L
.50884 .4388 L
.50907 .43773 L
.5093 .43697 L
.50953 .43586 L
.50977 .43524 L
.51 .43446 L
.51023 .43379 L
.51046 .43269 L
.5107 .43209 L
.51093 .43157 L
.51116 .43134 L
.51139 .43092 L
.51163 .43079 L
.51186 .43064 L
.51209 .43055 L
Mistroke
.51232 .43029 L
.51256 .43009 L
.51279 .42999 L
.51302 .42994 L
.51325 .43003 L
.51349 .43009 L
.51372 .4304 L
.51395 .43077 L
.51418 .43148 L
.51442 .43198 L
.51465 .4327 L
.51488 .43336 L
.51511 .43441 L
.51535 .4351 L
.51558 .43595 L
.51581 .43667 L
.51604 .43775 L
.51628 .43833 L
.51651 .43895 L
.51674 .43933 L
.51697 .44003 L
.51721 .44032 L
.51744 .4407 L
.51767 .441 L
.5179 .44163 L
.51814 .44198 L
.51837 .44233 L
.5186 .44261 L
.51883 .44305 L
.51907 .44329 L
.5193 .44346 L
.51953 .44354 L
.51976 .44365 L
.52 .4437 L
.52023 .44364 L
.52046 .44353 L
.52069 .4433 L
.52093 .44312 L
.52116 .44281 L
.52139 .44248 L
.52162 .44194 L
.52186 .44162 L
.52209 .44121 L
.52232 .44088 L
.52255 .44031 L
.52279 .43999 L
.52302 .43954 L
.52325 .43913 L
.52348 .43842 L
.52372 .43801 L
Mistroke
.52395 .43754 L
.52418 .43719 L
.52441 .43659 L
.52465 .43626 L
.52488 .43588 L
.52511 .43559 L
.52534 .43506 L
.52558 .43476 L
.52581 .43445 L
.52604 .43425 L
.52627 .43393 L
.52651 .43376 L
.52674 .43362 L
.52697 .43355 L
.5272 .43347 L
.52744 .43342 L
.52767 .43344 L
.5279 .4335 L
.52813 .43365 L
.52837 .43376 L
.5286 .434 L
.52883 .43426 L
.52906 .43471 L
.5293 .43501 L
.52953 .43543 L
.52976 .43579 L
.52999 .43634 L
.53023 .43669 L
.53046 .43712 L
.53069 .43748 L
.53092 .43803 L
.53116 .43834 L
.53139 .43868 L
.53162 .43892 L
.53185 .43933 L
.53209 .43951 L
.53232 .43968 L
.53255 .43979 L
.53278 .44005 L
.53302 .44016 L
.53325 .44025 L
.53348 .44033 L
.53371 .4405 L
.53395 .44056 L
.53418 .44055 L
.53441 .44052 L
.53464 .44053 L
.53488 .44052 L
.53511 .4405 L
.53534 .44051 L
Mistroke
.53557 .44054 L
.53581 .44053 L
.53604 .44046 L
.53627 .44035 L
.5365 .44022 L
.53674 .44012 L
.53697 .44004 L
.5372 .44002 L
.53743 .43999 L
.53767 .43997 L
.5379 .4399 L
.53813 .43982 L
.53836 .4397 L
.5386 .43962 L
.53883 .43956 L
.53906 .43956 L
.5393 .43959 L
.53953 .4396 L
.53976 .43958 L
.53999 .43957 L
.54023 .43956 L
.54046 .43952 L
.54069 .43949 L
.54092 .4395 L
.54116 .4396 L
.54139 .43964 L
.54162 .43969 L
.54185 .43976 L
.54209 .43995 L
.54232 .44004 L
.54255 .44018 L
.54278 .44032 L
.54302 .44063 L
.54325 .44084 L
.54348 .44112 L
.54371 .44138 L
.54395 .44181 L
.54418 .4421 L
.54441 .44244 L
.54464 .44271 L
.54488 .44311 L
.54511 .44337 L
.54534 .44367 L
.54557 .44389 L
.54581 .44418 L
.54604 .44434 L
.54627 .44446 L
.5465 .44447 L
.54674 .44448 L
.54697 .44446 L
Mistroke
.5472 .44442 L
.54743 .44437 L
.54767 .44426 L
.5479 .44419 L
.54813 .44403 L
.54836 .44385 L
.5486 .44353 L
.54883 .44334 L
.54906 .44308 L
.54929 .44285 L
.54953 .44245 L
.54976 .44223 L
.54999 .44193 L
.55022 .44163 L
.55046 .4411 L
.55069 .44082 L
.55092 .44052 L
.55115 .44027 L
.55139 .43981 L
.55162 .43962 L
.55185 .43941 L
.55208 .43924 L
.55232 .4388 L
.55255 .43861 L
.55278 .43837 L
.55301 .43815 L
.55325 .43765 L
.55348 .43736 L
.55371 .43703 L
.55394 .43674 L
.55418 .43621 L
.55441 .43588 L
.55464 .43553 L
.55487 .43528 L
.55511 .43488 L
.55534 .43464 L
.55557 .4344 L
.5558 .43429 L
.55604 .43411 L
.55627 .43399 L
.5565 .43386 L
.55673 .43379 L
.55697 .43377 L
.5572 .43373 L
.55743 .43376 L
.55766 .43385 L
.5579 .43413 L
.55813 .43428 L
.55836 .43455 L
.55859 .43482 L
Mistroke
.55883 .4354 L
.55906 .43581 L
.55929 .43641 L
.55952 .43703 L
.55976 .43798 L
.55999 .43857 L
.56022 .43916 L
.56045 .43959 L
.56069 .44028 L
.56092 .4406 L
.56115 .44099 L
.56138 .44134 L
.56162 .44201 L
.56185 .44227 L
.56208 .4425 L
.56231 .44266 L
.56255 .44313 L
.56278 .44334 L
.56301 .44361 L
.56324 .44402 L
.56348 .44475 L
.56371 .4451 L
.56394 .44527 L
.56417 .44535 L
.56441 .44564 L
.56464 .44567 L
.56487 .44577 L
.5651 .44594 L
.56534 .44649 L
.56557 .44671 L
.5658 .4469 L
.56603 .44704 L
.56627 .4475 L
.5665 .44783 L
.56673 .44836 L
.56696 .44906 L
.5672 .45012 L
.56743 .45077 L
.56766 .45124 L
.56789 .45147 L
.56813 .45183 L
.56836 .45187 L
.56859 .45199 L
.56882 .45216 L
.56906 .45268 L
.56929 .45281 L
.56952 .45285 L
.56975 .45284 L
.56999 .45312 L
.57022 .45325 L
Mistroke
.57045 .45355 L
.57068 .45414 L
.57092 .45513 L
.57115 .45568 L
.57138 .45595 L
.57161 .45606 L
.57185 .45638 L
.57208 .45636 L
.57231 .45646 L
.57254 .45671 L
.57278 .45751 L
.57301 .4578 L
.57324 .45809 L
.57347 .45831 L
.57371 .4591 L
.57394 .45962 L
.57417 .46053 L
.5744 .46171 L
.57464 .46359 L
.57487 .46474 L
.5751 .46563 L
.57533 .46616 L
.57557 .46707 L
.5758 .46734 L
.57603 .46778 L
.57626 .46832 L
.5765 .46958 L
.57673 .47002 L
.57696 .47034 L
.57719 .47053 L
.57743 .47139 L
.57766 .47179 L
.57789 .47254 L
.57813 .4737 L
.57836 .47574 L
.57859 .47687 L
.57882 .47761 L
.57906 .47806 L
.57929 .47906 L
.57952 .47934 L
.57975 .47986 L
.57999 .48059 L
.58022 .48235 L
.58045 .4831 L
.58068 .48374 L
.58092 .48418 L
.58115 .48553 L
.58138 .48627 L
.58161 .48754 L
.58185 .48921 L
Mistroke
.58208 .49205 L
.58231 .4937 L
.58254 .49499 L
.58278 .4958 L
.58301 .49731 L
.58324 .49784 L
.58347 .49866 L
.58371 .49965 L
.58394 .50181 L
.58417 .50273 L
.5844 .50341 L
.58464 .50385 L
.58487 .50523 L
.5851 .50582 L
.58533 .50683 L
.58557 .5083 L
.5858 .51104 L
.58603 .51253 L
.58626 .51362 L
.5865 .51432 L
.58673 .51587 L
.58696 .51642 L
.58719 .51727 L
.58743 .51833 L
.58766 .52071 L
.58789 .52186 L
.58812 .52287 L
.58836 .52358 L
.58859 .52537 L
.58882 .52632 L
.58905 .52775 L
.58929 .52947 L
.58952 .53247 L
.58975 .53423 L
.58998 .53568 L
.59022 .53661 L
.59045 .53826 L
.59068 .53892 L
.59091 .53975 L
.59115 .54063 L
.59138 .54252 L
.59161 .54335 L
.59184 .54397 L
.59208 .5443 L
.59231 .54531 L
.59254 .54571 L
.59277 .54629 L
.59301 .54714 L
.59324 .54877 L
.59347 .54967 L
Mistroke
.5937 .55022 L
.59394 .5505 L
.59417 .55115 L
.5944 .55129 L
.59463 .55148 L
.59487 .55174 L
.5951 .55256 L
.59533 .55294 L
.59556 .55323 L
.5958 .55338 L
.59603 .55387 L
.59626 .55418 L
.59649 .55466 L
.59673 .55524 L
.59696 .55615 L
.59719 .5568 L
.59742 .55728 L
.59766 .5575 L
.59789 .55768 L
.59812 .55766 L
.59835 .55758 L
.59859 .5574 L
.59882 .55724 L
.59905 .55706 L
.59928 .55681 L
.59952 .55656 L
.59975 .55619 L
.59998 .55598 L
.60021 .5557 L
.60045 .55551 L
.60068 .55514 L
.60091 .555 L
.60114 .55471 L
.60138 .55445 L
.60161 .55387 L
.60184 .5535 L
.60207 .55298 L
.60231 .55242 L
.60254 .55159 L
.60277 .55111 L
.603 .55072 L
.60324 .55044 L
.60347 .54997 L
.6037 .54986 L
.60393 .54978 L
.60417 .54969 L
.6044 .5493 L
.60463 .54923 L
.60486 .54917 L
.6051 .54908 L
Mistroke
.60533 .54863 L
.60556 .54838 L
.60579 .54802 L
.60603 .54755 L
.60626 .54667 L
.60649 .54611 L
.60672 .54559 L
.60696 .54518 L
.60719 .54449 L
.60742 .54414 L
.60765 .54376 L
.60789 .54346 L
.60812 .54284 L
.60835 .54251 L
.60858 .54212 L
.60882 .54183 L
.60905 .54128 L
.60928 .54097 L
.60951 .54062 L
.60975 .54034 L
.60998 .5399 L
.61021 .5396 L
.61044 .53933 L
.61068 .53915 L
.61091 .53896 L
.61114 .53891 L
.61137 .53902 L
.61161 .53927 L
.61184 .53963 L
.61207 .53986 L
.6123 .54006 L
.61254 .54023 L
.61277 .54055 L
.613 .54068 L
.61323 .54097 L
.61347 .54135 L
.6137 .54208 L
.61393 .5424 L
.61416 .5427 L
.6144 .54295 L
.61463 .54361 L
.61486 .54389 L
.61509 .54439 L
.61533 .54506 L
.61556 .54637 L
.61579 .54704 L
.61602 .54763 L
.61626 .54812 L
.61649 .54922 L
.61672 .54972 L
Mistroke
.61695 .55044 L
.61719 .55129 L
.61742 .55297 L
.61765 .55384 L
.61789 .55468 L
.61812 .55534 L
.61835 .55676 L
.61858 .55748 L
.61882 .55846 L
.61905 .55952 L
.61928 .5615 L
.61951 .56257 L
.61975 .56356 L
.61998 .56429 L
.62021 .56571 L
.62044 .5664 L
.62068 .56726 L
.62091 .56813 L
.62114 .56979 L
.62137 .57065 L
.62161 .57139 L
.62184 .57187 L
.62207 .57287 L
.6223 .57333 L
.62254 .57389 L
.62277 .57448 L
.623 .57561 L
.62323 .57621 L
.62347 .57661 L
.6237 .57681 L
.62393 .57725 L
.62416 .57739 L
.6244 .57753 L
.62463 .57772 L
.62486 .57814 L
.62509 .57834 L
.62533 .57835 L
.62556 .57825 L
.62579 .57816 L
.62602 .57803 L
.62626 .57786 L
.62649 .57777 L
.62672 .57769 L
.62695 .57766 L
.62719 .5775 L
.62742 .57731 L
.62765 .57699 L
.62788 .57678 L
.62812 .57654 L
.62835 .57633 L
Mistroke
.62858 .57601 L
.62881 .57587 L
.62905 .57571 L
.62928 .57555 L
.62951 .57519 L
.62974 .57501 L
.62998 .57479 L
.63021 .57453 L
.63044 .57407 L
.63067 .57387 L
.63091 .57373 L
.63114 .57364 L
.63137 .57333 L
.6316 .5732 L
.63184 .57299 L
.63207 .5727 L
.6323 .57212 L
.63253 .57185 L
.63277 .57162 L
.633 .57147 L
.63323 .57104 L
.63346 .57082 L
.6337 .57044 L
.63393 .56995 L
.63416 .56911 L
.63439 .56866 L
.63463 .56834 L
.63486 .56817 L
.63509 .56778 L
.63532 .56767 L
.63556 .56743 L
.63579 .56707 L
.63602 .56632 L
.63625 .56599 L
.63649 .56576 L
.63672 .56562 L
.63695 .56515 L
.63718 .56494 L
.63742 .56457 L
.63765 .56399 L
.63788 .56291 L
.63811 .56235 L
.63835 .56198 L
.63858 .56175 L
.63881 .56118 L
.63904 .56101 L
.63928 .56068 L
.63951 .5602 L
.63974 .55911 L
.63997 .5586 L
Mistroke
.64021 .55813 L
.64044 .55777 L
.64067 .55688 L
.6409 .55638 L
.64114 .55561 L
.64137 .55466 L
.6416 .55304 L
.64183 .5521 L
.64207 .55134 L
.6423 .55085 L
.64253 .54994 L
.64276 .5496 L
.643 .54913 L
.64323 .54859 L
.64346 .5474 L
.64369 .54688 L
.64393 .54644 L
.64416 .54614 L
.64439 .54531 L
.64462 .5449 L
.64486 .54429 L
.64509 .54348 L
.64532 .54204 L
.64555 .54123 L
.64579 .54066 L
.64602 .54032 L
.64625 .53961 L
.64648 .5394 L
.64672 .5391 L
.64695 .53873 L
.64718 .53779 L
.64741 .53738 L
.64765 .53703 L
.64788 .53681 L
.64811 .53612 L
.64834 .53571 L
.64858 .53508 L
.64881 .53428 L
.64904 .53298 L
.64927 .53218 L
.64951 .5316 L
.64974 .53129 L
.64997 .53081 L
.6502 .5307 L
.65044 .53055 L
.65067 .53038 L
.6509 .52987 L
.65113 .52974 L
.65137 .52973 L
.6516 .5298 L
Mistroke
.65183 .52966 L
.65206 .52961 L
.6523 .52943 L
.65253 .52902 L
.65276 .52831 L
.65299 .52789 L
.65323 .52773 L
.65346 .52771 L
.65369 .52763 L
.65392 .52772 L
.65416 .52774 L
.65439 .52765 L
.65462 .52726 L
.65485 .52715 L
.65509 .52712 L
.65532 .52715 L
.65555 .52691 L
.65578 .52677 L
.65602 .52639 L
.65625 .52576 L
.65648 .52474 L
.65672 .52411 L
.65695 .52366 L
.65718 .5234 L
.65741 .52294 L
.65765 .52283 L
.65788 .5226 L
.65811 .52226 L
.65834 .52144 L
.65858 .52113 L
.65881 .52089 L
.65904 .52071 L
.65927 .52008 L
.65951 .51981 L
.65974 .51934 L
.65997 .51862 L
.6602 .51724 L
.66044 .51648 L
.66067 .51586 L
.6609 .51539 L
.66113 .51439 L
.66137 .51399 L
.6616 .51341 L
.66183 .51278 L
.66206 .51137 L
.6623 .51066 L
.66253 .50989 L
.66276 .50928 L
.66299 .50796 L
.66323 .50719 L
Mistroke
.66346 .50615 L
.66369 .50508 L
.66392 .50327 L
.66416 .50219 L
.66439 .50119 L
.66462 .50051 L
.66485 .49941 L
.66509 .49892 L
.66532 .49838 L
.66555 .49796 L
.66578 .49709 L
.66602 .49673 L
.66625 .49648 L
.66648 .49638 L
.66671 .49604 L
.66695 .49591 L
.66718 .49578 L
.66741 .49556 L
.66764 .49518 L
.66788 .49497 L
.66811 .49502 L
.66834 .49519 L
.66857 .49544 L
.66881 .49569 L
.66904 .49601 L
.66927 .49627 L
.6695 .49658 L
.66974 .49682 L
.66997 .49718 L
.6702 .49754 L
.67043 .49806 L
.67067 .49831 L
.6709 .4985 L
.67113 .49852 L
.67136 .49868 L
.6716 .49869 L
.67183 .49887 L
.67206 .49911 L
.67229 .49965 L
.67253 .50001 L
.67276 .5004 L
.67299 .50067 L
.67322 .50107 L
.67346 .50137 L
.67369 .50174 L
.67392 .50202 L
.67415 .50239 L
.67439 .50263 L
.67462 .5028 L
.67485 .50275 L
Mistroke
.67508 .50259 L
.67532 .5025 L
.67555 .50245 L
.67578 .50237 L
.67601 .50214 L
.67625 .50207 L
.67648 .50188 L
.67671 .50162 L
.67694 .50096 L
.67718 .50062 L
.67741 .50014 L
.67764 .49969 L
.67787 .49875 L
.67811 .49817 L
.67834 .49734 L
.67857 .49651 L
.6788 .49511 L
.67904 .49427 L
.67927 .49337 L
.6795 .49268 L
.67973 .49153 L
.67997 .49094 L
.6802 .49025 L
.68043 .48969 L
.68066 .48864 L
.6809 .48816 L
.68113 .48769 L
.68136 .48737 L
.68159 .48667 L
.68183 .48634 L
.68206 .48599 L
.68229 .48562 L
.68252 .48491 L
.68276 .48457 L
.68299 .48436 L
.68322 .48428 L
.68345 .48403 L
.68369 .48398 L
.68392 .48396 L
.68415 .48392 L
.68438 .48374 L
.68462 .48368 L
.68485 .48373 L
.68508 .48382 L
.68531 .48389 L
.68555 .48392 L
.68578 .48394 L
.68601 .48388 L
.68624 .48381 L
.68648 .48375 L
Mistroke
.68671 .48384 L
.68694 .484 L
.68717 .48431 L
.68741 .48454 L
.68764 .48477 L
.68787 .48497 L
.6881 .48523 L
.68834 .48539 L
.68857 .48558 L
.6888 .48578 L
.68903 .48607 L
.68927 .48619 L
.6895 .48625 L
.68973 .48621 L
.68996 .48625 L
.6902 .48622 L
.69043 .48628 L
.69066 .48637 L
.69089 .48663 L
.69113 .48687 L
.69136 .48717 L
.69159 .48741 L
.69182 .48767 L
.69206 .48791 L
.69229 .48814 L
.69252 .48824 L
.69275 .48825 L
.69299 .48826 L
.69322 .48821 L
.69345 .48802 L
.69368 .48766 L
.69392 .48743 L
.69415 .48719 L
.69438 .48697 L
.69461 .48651 L
.69485 .48624 L
.69508 .48581 L
.69531 .48545 L
.69555 .48476 L
.69578 .48435 L
.69601 .48381 L
.69624 .48343 L
.69648 .48272 L
.69671 .48215 L
.69694 .48131 L
.69717 .4805 L
.69741 .47948 L
.69764 .47881 L
.69787 .47832 L
.6981 .47812 L
Mistroke
.69834 .47803 L
.69857 .47813 L
.6988 .47832 L
.69903 .4784 L
.69927 .47852 L
.6995 .47888 L
.69973 .47964 L
.69996 .48031 L
.7002 .48105 L
.70043 .48182 L
.70066 .48269 L
.70089 .48303 L
.70113 .48308 L
.70136 .48332 L
.70159 .48377 L
.70182 .48399 L
.70206 .48372 L
.70229 .48367 L
.70252 .4833 L
.70275 .4826 L
.70299 .48094 L
.70322 .47988 L
.70345 .47851 L
.70368 .47732 L
.70392 .4751 L
.70415 .4736 L
.70438 .47144 L
.70461 .46945 L
.70485 .46633 L
.70508 .46432 L
.70531 .46211 L
.70554 .46053 L
.70578 .45821 L
.70601 .45694 L
.70624 .4555 L
.70647 .45436 L
.70671 .45261 L
.70694 .45186 L
.70717 .45144 L
.7074 .45134 L
.70764 .45102 L
.70787 .45125 L
.7081 .45176 L
.70833 .4521 L
.70857 .45218 L
.7088 .45257 L
.70903 .45339 L
.70926 .45405 L
.7095 .45457 L
.70973 .45503 L
Mistroke
.70996 .45557 L
.71019 .45575 L
.71043 .45567 L
.71066 .45556 L
.71089 .45555 L
.71112 .45554 L
.71136 .45536 L
.71159 .45517 L
.71182 .45477 L
.71205 .45436 L
.71229 .45369 L
.71252 .4531 L
.71275 .45234 L
.71298 .45179 L
.71322 .45115 L
.71345 .4507 L
.71368 .45016 L
.71391 .44982 L
.71415 .44946 L
.71438 .44919 L
.71461 .4489 L
.71484 .44876 L
.71508 .44878 L
.71531 .44894 L
.71554 .44935 L
.71577 .44997 L
.71601 .45084 L
.71624 .45143 L
.71647 .45195 L
.7167 .45229 L
.71694 .45283 L
.71717 .45305 L
.7174 .45351 L
.71763 .45406 L
.71787 .4551 L
.7181 .45554 L
.71833 .4559 L
.71856 .45617 L
.7188 .45692 L
.71903 .45723 L
.71926 .45778 L
.71949 .45864 L
.71973 .46026 L
.71996 .46107 L
.72019 .46164 L
.72042 .46206 L
.72066 .46312 L
.72089 .46352 L
.72112 .46418 L
.72135 .46507 L
Mistroke
.72159 .46701 L
.72182 .46795 L
.72205 .46884 L
.72228 .46953 L
.72252 .47121 L
.72275 .47214 L
.72298 .47355 L
.72321 .47522 L
.72345 .47808 L
.72368 .4797 L
.72391 .48105 L
.72414 .48195 L
.72438 .48365 L
.72461 .48432 L
.72484 .48528 L
.72507 .48635 L
.72531 .48861 L
.72554 .48962 L
.72577 .49042 L
.726 .49096 L
.72624 .49241 L
.72647 .49307 L
.7267 .49406 L
.72693 .4954 L
.72717 .49789 L
.7274 .49923 L
.72763 .50015 L
.72786 .5007 L
.7281 .50196 L
.72833 .50237 L
.72856 .50298 L
.72879 .50377 L
.72903 .50566 L
.72926 .50654 L
.72949 .50728 L
.72972 .50776 L
.72996 .50908 L
.73019 .50982 L
.73042 .51095 L
.73065 .51237 L
.73089 .51476 L
.73112 .51619 L
.73135 .51726 L
.73158 .51786 L
.73182 .5189 L
.73205 .51919 L
.73228 .51961 L
.73251 .52009 L
.73275 .5213 L
.73298 .52176 L
Mistroke
.73321 .52203 L
.73344 .52213 L
.73368 .52273 L
.73391 .52299 L
.73414 .52346 L
.73438 .52426 L
.73461 .52568 L
.73484 .5265 L
.73507 .52694 L
.73531 .52712 L
.73554 .52751 L
.73577 .52749 L
.736 .52752 L
.73624 .52767 L
.73647 .52835 L
.7367 .52858 L
.73693 .52876 L
.73717 .52884 L
.7374 .52937 L
.73763 .52975 L
.73786 .53046 L
.7381 .53142 L
.73833 .53288 L
.73856 .53386 L
.73879 .53456 L
.73903 .53493 L
.73926 .53541 L
.73949 .53546 L
.73972 .53557 L
.73996 .53569 L
.74019 .5362 L
.74042 .53626 L
.74065 .53622 L
.74089 .53613 L
.74112 .53636 L
.74135 .53645 L
.74158 .53673 L
.74182 .53736 L
.74205 .53843 L
.74228 .53907 L
.74251 .5394 L
.74275 .53957 L
.74298 .53995 L
.74321 .53996 L
.74344 .54007 L
.74368 .54029 L
.74391 .54106 L
.74414 .54133 L
.74437 .54161 L
.74461 .54181 L
Mistroke
.74484 .54257 L
.74507 .54307 L
.7453 .54394 L
.74554 .54506 L
.74577 .54686 L
.746 .54798 L
.74623 .5489 L
.74647 .54948 L
.7467 .55041 L
.74693 .55074 L
.74716 .55121 L
.7474 .55172 L
.74763 .55287 L
.74786 .55328 L
.74809 .55358 L
.74833 .55375 L
.74856 .55446 L
.74879 .55476 L
.74902 .55532 L
.74926 .55621 L
.74949 .55781 L
.74972 .55869 L
.74995 .55925 L
.75019 .5596 L
.75042 .56039 L
.75065 .56061 L
.75088 .56099 L
.75112 .56154 L
.75135 .56288 L
.75158 .56346 L
.75181 .56396 L
.75205 .56431 L
.75228 .56534 L
.75251 .56591 L
.75274 .56685 L
.75298 .56806 L
.75321 .57013 L
.75344 .57136 L
.75367 .57235 L
.75391 .57298 L
.75414 .57413 L
.75437 .57457 L
.7546 .57519 L
.75484 .5759 L
.75507 .5774 L
.7553 .57807 L
.75553 .57858 L
.75577 .57889 L
.756 .57981 L
.75623 .58021 L
Mistroke
.75646 .58085 L
.7567 .58175 L
.75693 .58343 L
.75716 .58435 L
.75739 .58499 L
.75763 .58539 L
.75786 .58624 L
.75809 .58652 L
.75832 .58691 L
.75856 .58743 L
.75879 .58866 L
.75902 .58923 L
.75925 .58969 L
.75949 .59 L
.75972 .59085 L
.75995 .59128 L
.76018 .59196 L
.76042 .5928 L
.76065 .5943 L
.76088 .5952 L
.76111 .59593 L
.76135 .59638 L
.76158 .59719 L
.76181 .59751 L
.76204 .59792 L
.76228 .59833 L
.76251 .59922 L
.76274 .59964 L
.76297 .59996 L
.76321 .60012 L
.76344 .60057 L
.76367 .60077 L
.7639 .60107 L
.76414 .60145 L
.76437 .60216 L
.7646 .60258 L
.76483 .60285 L
.76507 .60297 L
.7653 .60317 L
.76553 .60319 L
.76576 .60318 L
.766 .60318 L
.76623 .6033 L
.76646 .60332 L
.76669 .60324 L
.76693 .60312 L
.76716 .603 L
.76739 .6029 L
.76762 .60278 L
.76786 .60273 L
Mistroke
.76809 .6027 L
.76832 .60272 L
.76855 .60269 L
.76879 .60265 L
.76902 .60254 L
.76925 .60248 L
.76948 .60239 L
.76972 .60228 L
.76995 .6021 L
.77018 .60203 L
.77041 .60196 L
.77065 .60189 L
.77088 .6017 L
.77111 .6016 L
.77134 .60147 L
.77158 .60127 L
.77181 .60093 L
.77204 .60078 L
.77227 .60071 L
.77251 .60068 L
.77274 .60049 L
.77297 .60044 L
.7732 .60031 L
.77344 .60011 L
.77367 .59963 L
.7739 .5994 L
.77414 .59917 L
.77437 .59899 L
.7746 .59852 L
.77483 .59822 L
.77507 .59774 L
.7753 .59715 L
.77553 .59624 L
.77576 .59571 L
.776 .59532 L
.77623 .59511 L
.77646 .59472 L
.77669 .59464 L
.77693 .59446 L
.77716 .59422 L
.77739 .59363 L
.77762 .59343 L
.77786 .59333 L
.77809 .59327 L
.77832 .59289 L
.77855 .59272 L
.77879 .59238 L
.77902 .59179 L
.77925 .59076 L
.77948 .59022 L
Mistroke
.77972 .58991 L
.77995 .58975 L
.78018 .58931 L
.78041 .58923 L
.78065 .589 L
.78088 .58863 L
.78111 .58766 L
.78134 .58724 L
.78158 .58684 L
.78181 .58653 L
.78204 .58565 L
.78227 .5851 L
.78251 .58418 L
.78274 .58301 L
.78297 .58114 L
.7832 .58002 L
.78344 .57916 L
.78367 .57865 L
.7839 .57776 L
.78413 .57751 L
.78437 .57709 L
.7846 .57658 L
.78483 .57536 L
.78506 .57492 L
.7853 .57461 L
.78553 .57441 L
.78576 .57357 L
.78599 .57319 L
.78623 .57252 L
.78646 .57145 L
.78669 .56954 L
.78692 .5685 L
.78716 .56783 L
.78739 .56744 L
.78762 .56649 L
.78785 .56625 L
.78809 .5658 L
.78832 .56518 L
.78855 .56356 L
.78878 .56285 L
.78902 .56216 L
.78925 .56164 L
.78948 .56021 L
.78971 .55933 L
.78995 .55791 L
.79018 .55619 L
.79041 .55342 L
.79064 .55173 L
.79088 .5504 L
.79111 .5496 L
Mistroke
.79134 .54829 L
.79157 .54787 L
.79181 .54727 L
.79204 .5466 L
.79227 .54503 L
.7925 .54448 L
.79274 .54417 L
.79297 .54405 L
.7932 .54321 L
.79343 .54288 L
.79367 .54223 L
.7939 .54108 L
.79413 .53898 L
.79436 .53786 L
.7946 .53726 L
.79483 .53696 L
.79506 .53613 L
.79529 .53598 L
.79553 .53561 L
.79576 .53493 L
.79599 .53317 L
.79622 .5324 L
.79646 .5318 L
.79669 .53146 L
.79692 .53018 L
.79715 .52945 L
.79739 .52807 L
.79762 .52628 L
.79785 .52324 L
.79808 .52138 L
.79832 .51981 L
.79855 .51876 L
.79878 .51703 L
.79901 .5163 L
.79925 .51529 L
.79948 .51406 L
.79971 .51176 L
.79994 .51084 L
.80018 .51045 L
.80041 .51037 L
.80064 .5095 L
.80087 .50954 L
.80111 .50931 L
.80134 .50854 L
.80157 .50632 L
.8018 .50529 L
.80204 .50445 L
.80227 .50376 L
.8025 .5018 L
.80273 .50068 L
Mistroke
.80297 .49893 L
.8032 .49683 L
.80343 .49311 L
.80366 .49086 L
.8039 .48877 L
.80413 .48728 L
.80436 .48473 L
.80459 .48347 L
.80483 .4818 L
.80506 .48012 L
.80529 .47709 L
.80552 .47564 L
.80576 .47452 L
.80599 .47393 L
.80622 .47244 L
.80645 .47197 L
.80669 .47122 L
.80692 .47023 L
.80715 .46801 L
.80738 .46691 L
.80762 .46612 L
.80785 .46562 L
.80808 .46437 L
.80831 .46375 L
.80855 .46292 L
.80878 .46179 L
.80901 .45983 L
.80924 .4588 L
.80948 .45831 L
.80971 .45822 L
.80994 .45783 L
.81017 .45796 L
.81041 .45797 L
.81064 .45773 L
.81087 .45678 L
.8111 .45647 L
.81134 .45638 L
.81157 .45644 L
.8118 .45601 L
.81203 .45573 L
.81227 .45504 L
.8125 .4539 L
.81273 .45208 L
.81297 .45091 L
.8132 .45016 L
.81343 .44983 L
.81366 .44936 L
.8139 .44939 L
.81413 .44928 L
.81436 .44898 L
Mistroke
.81459 .44808 L
.81483 .44785 L
.81506 .44783 L
.81529 .44789 L
.81552 .44742 L
.81576 .44729 L
.81599 .44681 L
.81622 .44581 L
.81645 .44395 L
.81669 .44289 L
.81692 .44218 L
.81715 .44169 L
.81738 .44059 L
.81762 .44027 L
.81785 .43968 L
.81808 .43891 L
.81831 .43699 L
.81855 .43609 L
.81878 .43511 L
.81901 .43432 L
.81924 .43242 L
.81948 .43128 L
.81971 .42958 L
.81994 .42767 L
.82017 .42448 L
.82041 .42254 L
.82064 .42077 L
.82087 .41955 L
.8211 .41753 L
.82134 .41664 L
.82157 .41557 L
.8218 .4146 L
.82203 .4126 L
.82227 .41175 L
.8225 .41106 L
.82273 .41065 L
.82296 .40948 L
.8232 .40898 L
.82343 .40831 L
.82366 .40738 L
.82389 .40567 L
.82413 .40475 L
.82436 .40425 L
.82459 .40403 L
.82482 .40346 L
.82506 .40339 L
.82529 .4033 L
.82552 .4031 L
.82575 .40234 L
.82599 .40206 L
Mistroke
.82622 .40194 L
.82645 .40196 L
.82668 .40162 L
.82692 .4014 L
.82715 .40093 L
.82738 .40023 L
.82761 .39915 L
.82785 .39841 L
.82808 .39796 L
.82831 .39781 L
.82854 .3977 L
.82878 .39781 L
.82901 .3979 L
.82924 .39793 L
.82947 .39779 L
.82971 .39786 L
.82994 .39808 L
.83017 .39835 L
.8304 .39856 L
.83064 .39874 L
.83087 .39882 L
.8311 .3986 L
.83133 .39819 L
.83157 .39794 L
.8318 .39792 L
.83203 .39796 L
.83226 .39796 L
.8325 .3981 L
.83273 .39818 L
.83296 .39814 L
.83319 .39778 L
.83343 .39766 L
.83366 .39749 L
.83389 .39733 L
.83412 .39681 L
.83436 .39645 L
.83459 .3958 L
.83482 .395 L
.83505 .39374 L
.83529 .39292 L
.83552 .39216 L
.83575 .39162 L
.83598 .39079 L
.83622 .39043 L
.83645 .38997 L
.83668 .38955 L
.83691 .38869 L
.83715 .38835 L
.83738 .38805 L
.83761 .38786 L
Mistroke
.83784 .38728 L
.83808 .38703 L
.83831 .38667 L
.83854 .38617 L
.83877 .38521 L
.83901 .3847 L
.83924 .38435 L
.83947 .38411 L
.8397 .38357 L
.83994 .38339 L
.84017 .38315 L
.8404 .38285 L
.84063 .38214 L
.84087 .38182 L
.8411 .38156 L
.84133 .38138 L
.84156 .38087 L
.8418 .38059 L
.84203 .38017 L
.84226 .37967 L
.84249 .37878 L
.84273 .37824 L
.84296 .37779 L
.84319 .37751 L
.84342 .37703 L
.84366 .37683 L
.84389 .37658 L
.84412 .37633 L
.84435 .37583 L
.84459 .37559 L
.84482 .37544 L
.84505 .37538 L
.84528 .37519 L
.84552 .37514 L
.84575 .37506 L
.84598 .37492 L
.84621 .37464 L
.84645 .37448 L
.84668 .37442 L
.84691 .37442 L
.84714 .37439 L
.84738 .37442 L
.84761 .37448 L
.84784 .3745 L
.84807 .37445 L
.84831 .37445 L
.84854 .37448 L
.84877 .37453 L
.849 .37458 L
.84924 .37461 L
Mistroke
.84947 .37463 L
.8497 .37463 L
.84993 .37462 L
.85017 .37458 L
.8504 .37456 L
.85063 .37455 L
.85086 .37459 L
.8511 .3746 L
.85133 .37464 L
.85156 .37469 L
.8518 .37479 L
.85203 .37483 L
.85226 .37487 L
.85249 .37492 L
.85273 .37503 L
.85296 .3751 L
.85319 .3752 L
.85342 .37533 L
.85366 .37555 L
.85389 .37566 L
.85412 .37573 L
.85435 .37578 L
.85459 .37592 L
.85482 .37598 L
.85505 .37609 L
.85528 .37623 L
.85552 .37653 L
.85575 .37668 L
.85598 .37683 L
.85621 .37693 L
.85645 .37719 L
.85668 .37734 L
.85691 .37759 L
.85714 .37789 L
.85738 .37837 L
.85761 .37864 L
.85784 .37882 L
.85807 .37892 L
.85831 .37911 L
.85854 .37915 L
.85877 .37923 L
.859 .37936 L
.85924 .37968 L
.85947 .37979 L
.8597 .37985 L
.85993 .37988 L
.86017 .38009 L
.8604 .38018 L
.86063 .38036 L
.86086 .38067 L
Mistroke
.8611 .38123 L
.86133 .38153 L
.86156 .38171 L
.86179 .38182 L
.86203 .3821 L
.86226 .38216 L
.86249 .38231 L
.86272 .38253 L
.86296 .3831 L
.86319 .38335 L
.86342 .38362 L
.86365 .38383 L
.86389 .38436 L
.86412 .3847 L
.86435 .38523 L
.86458 .38586 L
.86482 .38687 L
.86505 .38748 L
.86528 .38797 L
.86551 .38827 L
.86575 .38877 L
.86598 .38893 L
.86621 .38916 L
.86644 .38941 L
.86668 .39001 L
.86691 .39022 L
.86714 .39036 L
.86737 .39045 L
.86761 .39083 L
.86784 .39101 L
.86807 .39131 L
.8683 .3918 L
.86854 .39265 L
.86877 .39312 L
.869 .39338 L
.86923 .39351 L
.86947 .39385 L
.8697 .39389 L
.86993 .39401 L
.87016 .39422 L
.8704 .39484 L
.87063 .39508 L
.87086 .39531 L
.87109 .39546 L
.87133 .396 L
.87156 .39634 L
.87179 .39693 L
.87202 .3977 L
.87226 .39891 L
.87249 .39966 L
Mistroke
.87272 .40022 L
.87295 .40053 L
.87319 .40104 L
.87342 .40116 L
.87365 .40137 L
.87388 .40164 L
.87412 .40232 L
.87435 .40253 L
.87458 .40265 L
.87481 .4027 L
.87505 .4031 L
.87528 .40328 L
.87551 .40366 L
.87574 .4043 L
.87598 .40543 L
.87621 .40605 L
.87644 .40642 L
.87667 .40662 L
.87691 .40709 L
.87714 .40717 L
.87737 .40737 L
.8776 .40771 L
.87784 .40863 L
.87807 .409 L
.8783 .40934 L
.87853 .40958 L
.87877 .41036 L
.879 .41083 L
.87923 .41164 L
.87946 .41269 L
.8797 .41443 L
.87993 .41547 L
.88016 .41628 L
.88039 .41678 L
.88063 .41767 L
.88086 .41795 L
.88109 .4184 L
.88132 .41893 L
.88156 .42013 L
.88179 .4206 L
.88202 .42095 L
.88225 .42117 L
.88249 .42197 L
.88272 .42233 L
.88295 .42296 L
.88318 .42391 L
.88342 .42561 L
.88365 .42655 L
.88388 .42719 L
.88411 .42758 L
Mistroke
.88435 .42845 L
.88458 .42872 L
.88481 .42915 L
.88504 .42972 L
.88528 .43111 L
.88551 .43173 L
.88574 .43227 L
.88597 .43266 L
.88621 .43374 L
.88644 .43435 L
.88667 .43532 L
.8869 .43654 L
.88714 .43862 L
.88737 .43985 L
.8876 .44082 L
.88783 .44143 L
.88807 .44251 L
.8883 .4429 L
.88853 .44345 L
.88876 .44406 L
.889 .44541 L
.88923 .44597 L
.88946 .44638 L
.88969 .4466 L
.88993 .4474 L
.89016 .44774 L
.89039 .44832 L
.89063 .44918 L
.89086 .45075 L
.89109 .45162 L
.89132 .45219 L
.89156 .45251 L
.89179 .45321 L
.89202 .4534 L
.89225 .4537 L
.89249 .45414 L
.89272 .45524 L
.89295 .45572 L
.89318 .45609 L
.89342 .45631 L
.89365 .45705 L
.89388 .45745 L
.89411 .45813 L
.89435 .45902 L
.89458 .46055 L
.89481 .46148 L
.89504 .46219 L
.89528 .46261 L
.89551 .46333 L
.89574 .46356 L
Mistroke
.89597 .46389 L
.89621 .46428 L
.89644 .46518 L
.89667 .46554 L
.8969 .46578 L
.89714 .46589 L
.89737 .46637 L
.8976 .46655 L
.89783 .46687 L
.89807 .4674 L
.8983 .46842 L
.89853 .46899 L
.89876 .46938 L
.899 .46961 L
.89923 .47011 L
.89946 .47026 L
.89969 .47047 L
.89993 .47075 L
.90016 .47146 L
.90039 .47179 L
.90062 .4721 L
.90086 .47231 L
.90109 .47286 L
.90132 .47318 L
.90155 .47366 L
.90179 .47421 L
.90202 .47514 L
.90225 .47574 L
.90248 .47625 L
.90272 .47658 L
.90295 .47705 L
.90318 .47725 L
.90341 .47745 L
.90365 .47761 L
.90388 .47794 L
.90411 .47806 L
.90434 .47812 L
.90458 .4781 L
.90481 .47817 L
.90504 .47815 L
.90527 .47811 L
.90551 .47812 L
.90574 .47819 L
.90597 .47824 L
.9062 .47819 L
.90644 .47813 L
.90667 .47802 L
.9069 .47793 L
.90713 .47778 L
.90737 .47764 L
Mistroke
.9076 .47744 L
.90783 .47733 L
.90806 .47723 L
.9083 .47712 L
.90853 .47693 L
.90876 .47686 L
.90899 .47679 L
.90923 .4767 L
.90946 .47648 L
.90969 .47642 L
.90992 .47637 L
.91016 .47631 L
.91039 .47607 L
.91062 .47596 L
.91085 .47577 L
.91109 .47553 L
.91132 .47506 L
.91155 .4748 L
.91178 .47454 L
.91202 .47433 L
.91225 .47391 L
.91248 .47366 L
.91271 .47331 L
.91295 .47294 L
.91318 .47231 L
.91341 .47197 L
.91364 .47166 L
.91388 .47146 L
.91411 .47108 L
.91434 .47092 L
.91457 .47068 L
.91481 .47041 L
.91504 .46992 L
.91527 .46969 L
.9155 .46956 L
.91574 .46949 L
.91597 .46928 L
.9162 .46923 L
.91643 .46915 L
.91667 .46897 L
.9169 .46857 L
.91713 .46839 L
.91736 .46832 L
.9176 .46829 L
.91783 .4681 L
.91806 .46805 L
.91829 .46794 L
.91853 .46774 L
.91876 .46727 L
.91899 .46702 L
Mistroke
.91922 .4668 L
.91946 .46665 L
.91969 .46628 L
.91992 .46608 L
.92015 .46576 L
.92039 .4654 L
.92062 .46476 L
.92085 .46438 L
.92108 .46403 L
.92132 .4638 L
.92155 .4634 L
.92178 .46322 L
.92201 .46299 L
.92225 .46275 L
.92248 .46228 L
.92271 .46205 L
.92294 .46186 L
.92318 .46174 L
.92341 .46147 L
.92364 .46137 L
.92387 .46125 L
.92411 .4611 L
.92434 .46076 L
.92457 .46059 L
.9248 .46046 L
.92504 .46038 L
.92527 .46018 L
.9255 .4601 L
.92573 .46002 L
.92597 .45993 L
.9262 .45971 L
.92643 .45958 L
.92666 .45946 L
.9269 .45938 L
.92713 .45923 L
.92736 .45913 L
.92759 .459 L
.92783 .45891 L
.92806 .45878 L
.92829 .45867 L
.92852 .45857 L
.92876 .45852 L
.92899 .45853 L
.92922 .45853 L
.92945 .45858 L
.92969 .45866 L
.92992 .45886 L
.93015 .45897 L
.93039 .45913 L
.93062 .45928 L
Mistroke
.93085 .45959 L
.93108 .45979 L
.93132 .46008 L
.93155 .46037 L
.93178 .46084 L
.93201 .46111 L
.93225 .46139 L
.93248 .46159 L
.93271 .46195 L
.93294 .46212 L
.93318 .46235 L
.93341 .46258 L
.93364 .46299 L
.93387 .46318 L
.93411 .46334 L
.93434 .46346 L
.93457 .46374 L
.9348 .46387 L
.93504 .46403 L
.93527 .46424 L
.9355 .46464 L
.93573 .46483 L
.93597 .46493 L
.9362 .46498 L
.93643 .46517 L
.93666 .46521 L
.9369 .46528 L
.93713 .4654 L
.93736 .46573 L
.93759 .46588 L
.93783 .46602 L
.93806 .46612 L
.93829 .46639 L
.93852 .46657 L
.93876 .46684 L
.93899 .46718 L
.93922 .46772 L
.93945 .46804 L
.93969 .46828 L
.93992 .46841 L
.94015 .46861 L
.94038 .46866 L
.94062 .46873 L
.94085 .46883 L
.94108 .46908 L
.94131 .46916 L
.94155 .4692 L
.94178 .46921 L
.94201 .46935 L
.94224 .46942 L
Mistroke
.94248 .46957 L
.94271 .46983 L
.94294 .47025 L
.94317 .47049 L
.94341 .4706 L
.94364 .47062 L
.94387 .47071 L
.9441 .47066 L
.94434 .47065 L
.94457 .4707 L
.9448 .47095 L
.94503 .47102 L
.94527 .47107 L
.9455 .4711 L
.94573 .47133 L
.94596 .47149 L
.9462 .47181 L
.94643 .47227 L
.94666 .47298 L
.94689 .47341 L
.94713 .47371 L
.94736 .47387 L
.94759 .47414 L
.94782 .47417 L
.94806 .47426 L
.94829 .47441 L
.94852 .47485 L
.94875 .47497 L
.94899 .47506 L
.94922 .47511 L
.94945 .47546 L
.94968 .47563 L
.94992 .47598 L
.95015 .47653 L
.95038 .47746 L
.95061 .47799 L
.95085 .47836 L
.95108 .47859 L
.95131 .47907 L
.95154 .4792 L
.95178 .47944 L
.95201 .47977 L
.95224 .48057 L
.95247 .4809 L
.95271 .48121 L
.95294 .48144 L
.95317 .48213 L
.9534 .48253 L
.95364 .48318 L
.95387 .48402 L
Mistroke
.9541 .48541 L
.95433 .48623 L
.95457 .48689 L
.9548 .48731 L
.95503 .48806 L
.95526 .48834 L
.9555 .48876 L
.95573 .48924 L
.95596 .49027 L
.95619 .49069 L
.95643 .49099 L
.95666 .49116 L
.95689 .49177 L
.95712 .49204 L
.95736 .49253 L
.95759 .49325 L
.95782 .49457 L
.95805 .49528 L
.95829 .49576 L
.95852 .49603 L
.95875 .49666 L
.95898 .49685 L
.95922 .49719 L
.95945 .49769 L
.95968 .4988 L
.95991 .4993 L
.96015 .49965 L
.96038 .49987 L
.96061 .50058 L
.96084 .50089 L
.96108 .50146 L
.96131 .50227 L
.96154 .50379 L
.96177 .50463 L
.96201 .50529 L
.96224 .50573 L
.96247 .50663 L
.9627 .50699 L
.96294 .50752 L
.96317 .50818 L
.9634 .50957 L
.96363 .51026 L
.96387 .51086 L
.9641 .51129 L
.96433 .51231 L
.96456 .51279 L
.9648 .51348 L
.96503 .51431 L
.96526 .51587 L
.96549 .51674 L
Mistroke
.96573 .51749 L
.96596 .51802 L
.96619 .51903 L
.96642 .51946 L
.96666 .51998 L
.96689 .52049 L
.96712 .52162 L
.96735 .5222 L
.96759 .52275 L
.96782 .52315 L
.96805 .524 L
.96828 .52445 L
.96852 .52498 L
.96875 .52549 L
.96898 .52642 L
.96922 .52698 L
.96945 .52745 L
.96968 .52773 L
.96991 .52817 L
.97015 .52834 L
.97038 .52845 L
.97061 .52842 L
.97084 .52848 L
.97108 .52849 L
.97131 .52848 L
.97154 .5284 L
.97177 .52824 L
.97201 .5282 L
.97224 .52808 L
.97247 .52791 L
.9727 .52746 L
.97294 .52729 L
.97317 .52701 L
.9734 .52668 L
.97363 .5259 L
.97387 .52545 L
.9741 .52479 L
.97433 .52407 L
.97456 .52275 L
.9748 .52198 L
.97503 .52113 L
.97526 .52039 L
.97549 .51905 L
.97573 .51833 L
.97596 .51746 L
.97619 .51666 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],

Cell[TextData[{
  "Depending on the problem, one may prefer to do denoising without \
shrinking. That is, the new coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_i\)\&~\)\)], "InlineFormula",
    CellTags->"S2.1.2"],
  " is given by"
}], "Text",
  CellTags->{"S2.1.2", "2.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(c\_i\)\&~\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    
                    StyleBox[
                      \( \[VerticalSeparator] c\_i \[VerticalSeparator]  < 
                        \[Tau]\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox[\(c\_i\),
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{
                    RowBox[{\(" if "\), 
                      
                      StyleBox[
                        \( \[VerticalSeparator] c\_i \[VerticalSeparator]  
                          \[GreaterEqual] \[Tau]\),
                        "DisplayFormula"]}], "."}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S2.1.2", "2.13"}],

Cell["Note that this does denoising without shrinking.", "MathCaption",
  CellTags->{"S2.1.2", "2.14"}],

Cell["Compress[Rest[wtdata], 1.5, Threshold -> True];", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.2"],

Cell["\<\
Note the extra structure as compared to the previous graph. Whether \
this is noise or part of the signal depends on the details of the \
problem.\
\>", "MathCaption",
  CellTags->{"S2.1.2", "2.15"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[InverseWaveletTransform[
Join[{wtdata[[1]]}, %], s4],
PlotJoined -> True, AxesLabel -> {\"x\", \"u(x)\"}]\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.388192 0.131897 [
[.25632 .37569 -12 -9 ]
[.25632 .37569 12 0 ]
[.48884 .37569 -12 -9 ]
[.48884 .37569 12 0 ]
[.72135 .37569 -12 -9 ]
[.72135 .37569 12 0 ]
[.95387 .37569 -12 -9 ]
[.95387 .37569 12 0 ]
[1.025 .38819 0 -4.5 ]
[1.025 .38819 6 4.5 ]
[.01131 .1244 -12 -4.5 ]
[.01131 .1244 0 4.5 ]
[.01131 .25629 -12 -4.5 ]
[.01131 .25629 0 4.5 ]
[.01131 .52009 -6 -4.5 ]
[.01131 .52009 0 4.5 ]
[.02381 .64303 -12 0 ]
[.02381 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 .38819 m
.25632 .39444 L
s
[(1000)] .25632 .37569 0 1 Mshowa
.48884 .38819 m
.48884 .39444 L
s
[(2000)] .48884 .37569 0 1 Mshowa
.72135 .38819 m
.72135 .39444 L
s
[(3000)] .72135 .37569 0 1 Mshowa
.95387 .38819 m
.95387 .39444 L
s
[(4000)] .95387 .37569 0 1 Mshowa
.125 Mabswid
.07031 .38819 m
.07031 .39194 L
s
.11682 .38819 m
.11682 .39194 L
s
.16332 .38819 m
.16332 .39194 L
s
.20982 .38819 m
.20982 .39194 L
s
.30283 .38819 m
.30283 .39194 L
s
.34933 .38819 m
.34933 .39194 L
s
.39583 .38819 m
.39583 .39194 L
s
.44234 .38819 m
.44234 .39194 L
s
.53534 .38819 m
.53534 .39194 L
s
.58185 .38819 m
.58185 .39194 L
s
.62835 .38819 m
.62835 .39194 L
s
.67485 .38819 m
.67485 .39194 L
s
.76786 .38819 m
.76786 .39194 L
s
.81436 .38819 m
.81436 .39194 L
s
.86086 .38819 m
.86086 .39194 L
s
.90737 .38819 m
.90737 .39194 L
s
.25 Mabswid
0 .38819 m
1 .38819 L
s
[(x)] 1.025 .38819 -1 0 Mshowa
.02381 .1244 m
.03006 .1244 L
s
[(-2)] .01131 .1244 1 0 Mshowa
.02381 .25629 m
.03006 .25629 L
s
[(-1)] .01131 .25629 1 0 Mshowa
.02381 .52009 m
.03006 .52009 L
s
[(1)] .01131 .52009 1 0 Mshowa
.125 Mabswid
.02381 .15078 m
.02756 .15078 L
s
.02381 .17716 m
.02756 .17716 L
s
.02381 .20354 m
.02756 .20354 L
s
.02381 .22992 m
.02756 .22992 L
s
.02381 .28267 m
.02756 .28267 L
s
.02381 .30905 m
.02756 .30905 L
s
.02381 .33543 m
.02756 .33543 L
s
.02381 .36181 m
.02756 .36181 L
s
.02381 .41457 m
.02756 .41457 L
s
.02381 .44095 m
.02756 .44095 L
s
.02381 .46733 m
.02756 .46733 L
s
.02381 .49371 m
.02756 .49371 L
s
.02381 .09802 m
.02756 .09802 L
s
.02381 .07164 m
.02756 .07164 L
s
.02381 .04526 m
.02756 .04526 L
s
.02381 .01888 m
.02756 .01888 L
s
.02381 .54647 m
.02756 .54647 L
s
.02381 .57285 m
.02756 .57285 L
s
.02381 .59923 m
.02756 .59923 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02404 .52725 m
.02427 .52535 L
.02451 .52327 L
.02474 .52163 L
.02497 .51848 L
.0252 .51684 L
.02544 .51499 L
.02567 .51345 L
.0259 .51057 L
.02613 .509 L
.02637 .50746 L
.0266 .50633 L
.02683 .50434 L
.02706 .50327 L
.0273 .50231 L
.02753 .50165 L
.02776 .50059 L
.02799 .50006 L
.02823 .49991 L
.02846 .50011 L
.02869 .50049 L
.02892 .5009 L
.02916 .50166 L
.02939 .5026 L
.02962 .50402 L
.02985 .50489 L
.03009 .506 L
.03032 .50706 L
.03055 .50894 L
.03078 .5098 L
.03102 .51091 L
.03125 .5119 L
.03148 .51413 L
.03172 .5152 L
.03195 .51676 L
.03218 .51833 L
.03241 .5215 L
.03265 .52338 L
.03288 .52566 L
.03311 .5278 L
.03334 .53145 L
.03358 .53362 L
.03381 .53592 L
.03404 .53779 L
.03427 .54089 L
.03451 .54236 L
.03474 .54374 L
.03497 .54452 L
.0352 .54641 L
.03544 .54728 L
Mistroke
.03567 .54847 L
.0359 .54952 L
.03613 .55155 L
.03637 .5528 L
.0366 .55389 L
.03683 .55455 L
.03706 .55548 L
.0373 .55629 L
.03753 .55707 L
.03776 .55758 L
.03799 .55779 L
.03823 .55783 L
.03846 .55709 L
.03869 .55549 L
.03892 .55284 L
.03916 .55135 L
.03939 .5501 L
.03962 .54906 L
.03985 .54685 L
.04009 .54598 L
.04032 .54434 L
.04055 .54209 L
.04078 .53752 L
.04102 .53543 L
.04125 .5334 L
.04148 .53163 L
.04171 .52728 L
.04195 .52519 L
.04218 .52194 L
.04241 .51787 L
.04264 .5102 L
.04288 .50611 L
.04311 .50228 L
.04334 .49921 L
.04357 .49287 L
.04381 .48989 L
.04404 .48584 L
.04427 .48148 L
.0445 .47282 L
.04474 .46835 L
.04497 .46391 L
.0452 .46045 L
.04543 .45325 L
.04567 .44952 L
.0459 .44468 L
.04613 .43966 L
.04636 .43052 L
.0466 .42548 L
.04683 .42092 L
.04706 .41775 L
Mistroke
.04729 .41175 L
.04753 .40898 L
.04776 .40573 L
.04799 .4027 L
.04822 .39666 L
.04846 .39366 L
.04869 .39125 L
.04892 .38984 L
.04915 .38667 L
.04939 .38523 L
.04962 .38362 L
.04985 .38186 L
.05008 .37861 L
.05032 .37686 L
.05055 .37615 L
.05078 .37626 L
.05101 .37632 L
.05125 .37681 L
.05148 .37759 L
.05171 .37826 L
.05194 .3789 L
.05218 .37944 L
.05241 .38065 L
.05264 .38209 L
.05287 .38433 L
.05311 .38554 L
.05334 .38686 L
.05357 .38768 L
.0538 .38946 L
.05404 .39019 L
.05427 .39171 L
.0545 .39337 L
.05473 .39674 L
.05497 .39888 L
.0552 .4014 L
.05543 .40359 L
.05566 .40708 L
.0559 .40916 L
.05613 .41142 L
.05636 .41321 L
.05659 .41615 L
.05683 .41768 L
.05706 .4192 L
.05729 .42008 L
.05752 .42178 L
.05776 .42248 L
.05799 .42321 L
.05822 .42365 L
.05845 .42468 L
.05869 .42531 L
Mistroke
.05892 .42587 L
.05915 .42637 L
.05938 .42688 L
.05962 .42719 L
.05985 .42692 L
.06008 .42639 L
.06031 .42527 L
.06055 .42431 L
.06078 .42281 L
.06101 .42136 L
.06124 .41921 L
.06148 .4177 L
.06171 .41583 L
.06194 .41423 L
.06217 .41192 L
.06241 .4106 L
.06264 .40916 L
.06287 .40814 L
.0631 .40643 L
.06334 .40575 L
.06357 .405 L
.0638 .40444 L
.06403 .40313 L
.06427 .40256 L
.0645 .40193 L
.06473 .4013 L
.06496 .40003 L
.0652 .39946 L
.06543 .39912 L
.06566 .39889 L
.06589 .39818 L
.06613 .39786 L
.06636 .39751 L
.06659 .39705 L
.06682 .39618 L
.06706 .3958 L
.06729 .39572 L
.06752 .39582 L
.06775 .39575 L
.06799 .39582 L
.06822 .3958 L
.06845 .39555 L
.06868 .39499 L
.06892 .39473 L
.06915 .39474 L
.06938 .39489 L
.06961 .39495 L
.06985 .39512 L
.07008 .39516 L
.07031 .39492 L
Mistroke
.07055 .39433 L
.07078 .39401 L
.07101 .39382 L
.07124 .39366 L
.07148 .3933 L
.07171 .39325 L
.07194 .39315 L
.07217 .39284 L
.07241 .39207 L
.07264 .39171 L
.07287 .39139 L
.0731 .39109 L
.07334 .39031 L
.07357 .39004 L
.0738 .38966 L
.07403 .38932 L
.07427 .38823 L
.0745 .38755 L
.07473 .38645 L
.07496 .38542 L
.0752 .38359 L
.07543 .38226 L
.07566 .38067 L
.07589 .37944 L
.07613 .37773 L
.07636 .37646 L
.07659 .37502 L
.07682 .37403 L
.07706 .37297 L
.07729 .37241 L
.07752 .37213 L
.07775 .37246 L
.07799 .37314 L
.07822 .37372 L
.07845 .37436 L
.07868 .375 L
.07892 .37612 L
.07915 .37669 L
.07938 .37764 L
.07961 .37865 L
.07985 .38069 L
.08008 .38187 L
.08031 .38352 L
.08054 .38511 L
.08078 .38788 L
.08101 .38934 L
.08124 .39105 L
.08147 .39263 L
.08171 .39558 L
.08194 .39724 L
Mistroke
.08217 .3992 L
.0824 .4011 L
.08264 .40436 L
.08287 .40584 L
.0831 .40708 L
.08333 .40768 L
.08357 .40962 L
.0838 .4105 L
.08403 .41205 L
.08426 .41355 L
.0845 .41661 L
.08473 .41879 L
.08496 .42112 L
.08519 .42245 L
.08543 .42434 L
.08566 .42603 L
.08589 .4283 L
.08612 .42969 L
.08636 .43092 L
.08659 .43242 L
.08682 .43371 L
.08705 .43354 L
.08729 .43147 L
.08752 .43072 L
.08775 .42953 L
.08798 .4277 L
.08822 .42272 L
.08845 .41981 L
.08868 .41528 L
.08891 .41056 L
.08915 .40136 L
.08938 .39559 L
.08961 .38815 L
.08984 .38195 L
.09008 .37111 L
.09031 .36398 L
.09054 .35464 L
.09077 .34673 L
.09101 .33467 L
.09124 .32723 L
.09147 .3194 L
.0917 .31408 L
.09194 .30646 L
.09217 .30259 L
.0924 .29875 L
.09263 .29598 L
.09287 .29196 L
.0931 .29095 L
.09333 .29196 L
.09356 .29371 L
Mistroke
.0938 .29577 L
.09403 .29885 L
.09426 .30359 L
.09449 .30702 L
.09473 .31053 L
.09496 .31393 L
.09519 .31923 L
.09542 .32329 L
.09566 .32745 L
.09589 .33037 L
.09612 .33346 L
.09635 .33482 L
.09659 .33529 L
.09682 .33491 L
.09705 .33418 L
.09728 .33328 L
.09752 .33149 L
.09775 .32941 L
.09798 .3259 L
.09821 .32277 L
.09845 .31846 L
.09868 .31471 L
.09891 .30984 L
.09914 .3064 L
.09938 .30264 L
.09961 .30007 L
.09984 .29712 L
.10007 .29554 L
.10031 .29423 L
.10054 .29354 L
.10077 .29301 L
.101 .29316 L
.10124 .29435 L
.10147 .29572 L
.1017 .29836 L
.10193 .30136 L
.10217 .30599 L
.1024 .30933 L
.10263 .31333 L
.10286 .31639 L
.1031 .32093 L
.10333 .32359 L
.10356 .32728 L
.10379 .33045 L
.10403 .33555 L
.10426 .33826 L
.10449 .34115 L
.10472 .3432 L
.10496 .34682 L
.10519 .34842 L
Mistroke
.10542 .35024 L
.10565 .35204 L
.10589 .35547 L
.10612 .35689 L
.10635 .35767 L
.10658 .35808 L
.10682 .35965 L
.10705 .36002 L
.10728 .36038 L
.10751 .36108 L
.10775 .36311 L
.10798 .36386 L
.10821 .3641 L
.10844 .36413 L
.10868 .36515 L
.10891 .36575 L
.10914 .36688 L
.10938 .36862 L
.10961 .37144 L
.10984 .37309 L
.11007 .37399 L
.11031 .37422 L
.11054 .37477 L
.11077 .3747 L
.111 .37504 L
.11124 .37587 L
.11147 .37772 L
.1117 .37841 L
.11193 .3785 L
.11217 .37823 L
.1124 .37857 L
.11263 .37845 L
.11286 .37895 L
.1131 .38039 L
.11333 .38321 L
.11356 .38471 L
.11379 .38556 L
.11403 .38602 L
.11426 .38736 L
.11449 .38767 L
.11472 .38855 L
.11496 .39015 L
.11519 .39364 L
.11542 .39531 L
.11565 .39668 L
.11589 .39774 L
.11612 .40051 L
.11635 .40174 L
.11658 .4038 L
.11682 .40655 L
Mistroke
.11705 .4119 L
.11728 .41482 L
.11751 .41755 L
.11775 .4197 L
.11798 .42405 L
.11821 .42607 L
.11844 .42881 L
.11868 .43172 L
.11891 .43759 L
.11914 .44073 L
.11937 .44397 L
.11961 .44654 L
.11984 .45161 L
.12007 .45427 L
.1203 .45758 L
.12054 .46074 L
.12077 .46653 L
.121 .46984 L
.12123 .47306 L
.12147 .47538 L
.1217 .47944 L
.12193 .48142 L
.12216 .48345 L
.1224 .48496 L
.12263 .48794 L
.12286 .48947 L
.12309 .49081 L
.12333 .49158 L
.12356 .49298 L
.12379 .49364 L
.12402 .49394 L
.12426 .49389 L
.12449 .4938 L
.12472 .4938 L
.12495 .49336 L
.12519 .49264 L
.12542 .49105 L
.12565 .49008 L
.12588 .48836 L
.12612 .48628 L
.12635 .48268 L
.12658 .48075 L
.12681 .47861 L
.12705 .47666 L
.12728 .47281 L
.12751 .47095 L
.12774 .46838 L
.12798 .46567 L
.12821 .46032 L
.12844 .45768 L
Mistroke
.12867 .45481 L
.12891 .45232 L
.12914 .44704 L
.12937 .44428 L
.1296 .44067 L
.12984 .43692 L
.13007 .43 L
.1303 .42624 L
.13053 .42258 L
.13077 .41975 L
.131 .41427 L
.13123 .41158 L
.13146 .40833 L
.1317 .40527 L
.13193 .39936 L
.13216 .39631 L
.13239 .39348 L
.13263 .39147 L
.13286 .38738 L
.13309 .38539 L
.13332 .38313 L
.13356 .38094 L
.13379 .37682 L
.13402 .37459 L
.13425 .37289 L
.13449 .3719 L
.13472 .37002 L
.13495 .36935 L
.13518 .3689 L
.13542 .36861 L
.13565 .36762 L
.13588 .36721 L
.13611 .36722 L
.13635 .36754 L
.13658 .36792 L
.13681 .36822 L
.13704 .36882 L
.13728 .3695 L
.13751 .37062 L
.13774 .37104 L
.13797 .37174 L
.13821 .3726 L
.13844 .37454 L
.13867 .37551 L
.1389 .37695 L
.13914 .37865 L
.13937 .38191 L
.1396 .38351 L
.13983 .38521 L
.14007 .3868 L
Mistroke
.1403 .39025 L
.14053 .39197 L
.14076 .39431 L
.141 .39678 L
.14123 .40162 L
.14146 .40413 L
.14169 .4068 L
.14193 .40901 L
.14216 .41352 L
.14239 .41596 L
.14262 .41912 L
.14286 .42228 L
.14309 .42794 L
.14332 .43102 L
.14355 .43393 L
.14379 .436 L
.14402 .43995 L
.14425 .44187 L
.14448 .44421 L
.14472 .44644 L
.14495 .45066 L
.14518 .45274 L
.14541 .45439 L
.14565 .45534 L
.14588 .45752 L
.14611 .45849 L
.14634 .45969 L
.14658 .46111 L
.14681 .46371 L
.14704 .46499 L
.14727 .46544 L
.14751 .46529 L
.14774 .46543 L
.14797 .46513 L
.1482 .46488 L
.14844 .46504 L
.14867 .46572 L
.1489 .46586 L
.14914 .4653 L
.14937 .46448 L
.1496 .46359 L
.14983 .46295 L
.15007 .46255 L
.1503 .46292 L
.15053 .46358 L
.15076 .46395 L
.151 .46359 L
.15123 .46296 L
.15146 .4621 L
.15169 .46123 L
Mistroke
.15193 .46059 L
.15216 .46061 L
.15239 .46124 L
.15262 .4614 L
.15286 .46133 L
.15309 .4613 L
.15332 .46183 L
.15355 .462 L
.15379 .46269 L
.15402 .46408 L
.15425 .46675 L
.15448 .4683 L
.15472 .46971 L
.15495 .47088 L
.15518 .47321 L
.15541 .4742 L
.15565 .47568 L
.15588 .47727 L
.15611 .48082 L
.15634 .48268 L
.15658 .48495 L
.15681 .48689 L
.15704 .49081 L
.15727 .49311 L
.15751 .49614 L
.15774 .49904 L
.15797 .50398 L
.1582 .50702 L
.15844 .5102 L
.15867 .51262 L
.1589 .51642 L
.15913 .51835 L
.15937 .52029 L
.1596 .52166 L
.15983 .52417 L
.16006 .52526 L
.1603 .52615 L
.16053 .52666 L
.16076 .52784 L
.16099 .52824 L
.16123 .52836 L
.16146 .52834 L
.16169 .52858 L
.16192 .52855 L
.16216 .52806 L
.16239 .52738 L
.16262 .52652 L
.16285 .52614 L
.16309 .52563 L
.16332 .52503 L
Mistroke
.16355 .5238 L
.16378 .52331 L
.16402 .52248 L
.16425 .52128 L
.16448 .51886 L
.16471 .51786 L
.16495 .51688 L
.16518 .51603 L
.16541 .51355 L
.16564 .51245 L
.16588 .51065 L
.16611 .50875 L
.16634 .50453 L
.16657 .5017 L
.16681 .49811 L
.16704 .49525 L
.16727 .49043 L
.1675 .48717 L
.16774 .48312 L
.16797 .48028 L
.1682 .476 L
.16843 .47268 L
.16867 .46857 L
.1689 .46571 L
.16913 .46277 L
.16936 .46072 L
.1696 .4593 L
.16983 .45928 L
.17006 .46089 L
.17029 .46229 L
.17053 .46477 L
.17076 .46709 L
.17099 .47187 L
.17122 .47574 L
.17146 .48204 L
.17169 .48753 L
.17192 .49606 L
.17215 .50275 L
.17239 .51132 L
.17262 .51758 L
.17285 .52543 L
.17308 .53106 L
.17332 .5376 L
.17355 .54178 L
.17378 .5459 L
.17401 .54818 L
.17425 .54958 L
.17448 .54926 L
.17471 .54697 L
.17494 .54435 L
Mistroke
.17518 .53969 L
.17541 .53514 L
.17564 .52766 L
.17587 .52157 L
.17611 .5128 L
.17634 .50557 L
.17657 .49531 L
.1768 .48796 L
.17704 .47864 L
.17727 .47181 L
.1775 .46296 L
.17773 .45756 L
.17797 .4516 L
.1782 .44776 L
.17843 .4432 L
.17866 .44142 L
.1789 .44067 L
.17913 .44097 L
.17936 .44177 L
.17959 .44396 L
.17983 .44814 L
.18006 .452 L
.18029 .45685 L
.18052 .46126 L
.18076 .46742 L
.18099 .47205 L
.18122 .47741 L
.18145 .48113 L
.18169 .48587 L
.18192 .48895 L
.18215 .49247 L
.18238 .49422 L
.18262 .49605 L
.18285 .49686 L
.18308 .49763 L
.18331 .49734 L
.18355 .4964 L
.18378 .49539 L
.18401 .49397 L
.18424 .49212 L
.18448 .48901 L
.18471 .48653 L
.18494 .48358 L
.18517 .48124 L
.18541 .47814 L
.18564 .47648 L
.18587 .47462 L
.1861 .47292 L
.18634 .47011 L
.18657 .46808 L
Mistroke
.1868 .46629 L
.18703 .46489 L
.18727 .46406 L
.1875 .4646 L
.18773 .46681 L
.18797 .46813 L
.1882 .46984 L
.18843 .47159 L
.18866 .47551 L
.1889 .47814 L
.18913 .48251 L
.18936 .48732 L
.18959 .49533 L
.18983 .50043 L
.19006 .50601 L
.19029 .51026 L
.19052 .51713 L
.19076 .52066 L
.19099 .52523 L
.19122 .52913 L
.19145 .53633 L
.19169 .54003 L
.19192 .54406 L
.19215 .54712 L
.19238 .55292 L
.19262 .55595 L
.19285 .55934 L
.19308 .56256 L
.19331 .56806 L
.19355 .57086 L
.19378 .5729 L
.19401 .57424 L
.19424 .57685 L
.19448 .57727 L
.19471 .5769 L
.19494 .57651 L
.19517 .57744 L
.19541 .57776 L
.19564 .57787 L
.19587 .57805 L
.1961 .5789 L
.19634 .5788 L
.19657 .57801 L
.1968 .57642 L
.19703 .57529 L
.19727 .57502 L
.1975 .57648 L
.19773 .57937 L
.19796 .58293 L
.1982 .58634 L
Mistroke
.19843 .58807 L
.19866 .58877 L
.19889 .58743 L
.19913 .58701 L
.19936 .58546 L
.19959 .58222 L
.19982 .57676 L
.20006 .57213 L
.20029 .56682 L
.20052 .55703 L
.20075 .5454 L
.20099 .54065 L
.20122 .54308 L
.20145 .54703 L
.20168 .54972 L
.20192 .56034 L
.20215 .57178 L
.20238 .58148 L
.20261 .57907 L
.20285 .58177 L
.20308 .57645 L
.20331 .56696 L
.20354 .5386 L
.20378 .51316 L
.20401 .47602 L
.20424 .43648 L
.20447 .38206 L
.20471 .34158 L
.20494 .30246 L
.20517 .27506 L
.2054 .24358 L
.20564 .23072 L
.20587 .22033 L
.2061 .21913 L
.20633 .21213 L
.20657 .21827 L
.2068 .22522 L
.20703 .23303 L
.20726 .233 L
.2075 .23451 L
.20773 .23395 L
.20796 .22679 L
.20819 .21409 L
.20843 .20399 L
.20866 .20092 L
.20889 .20052 L
.20912 .2023 L
.20936 .2053 L
.20959 .2105 L
.20982 .21614 L
Mistroke
.21005 .22223 L
.21029 .22825 L
.21052 .23533 L
.21075 .24127 L
.21098 .2484 L
.21122 .25183 L
.21145 .25444 L
.21168 .25042 L
.21191 .24739 L
.21215 .24571 L
.21238 .25136 L
.21261 .25801 L
.21284 .26758 L
.21308 .27995 L
.21331 .29324 L
.21354 .3052 L
.21377 .31013 L
.21401 .31487 L
.21424 .31171 L
.21447 .3051 L
.2147 .28631 L
.21494 .2665 L
.21517 .23703 L
.2154 .20637 L
.21563 .16772 L
.21587 .13713 L
.2161 .10753 L
.21633 .08737 L
.21656 .06798 L
.2168 .0614 L
.21703 .05852 L
.21726 .06342 L
.21749 .06782 L
.21773 .07909 L
.21796 .09101 L
.21819 .10178 L
.21842 .10897 L
.21866 .11468 L
.21889 .11987 L
.21912 .11928 L
.21935 .1165 L
.21959 .11244 L
.21982 .11227 L
.22005 .11136 L
.22028 .11224 L
.22052 .11291 L
.22075 .11604 L
.22098 .11944 L
.22121 .12418 L
.22145 .12867 L
Mistroke
.22168 .13384 L
.22191 .13871 L
.22214 .14388 L
.22238 .14746 L
.22261 .14948 L
.22284 .1493 L
.22307 .14763 L
.22331 .14557 L
.22354 .14287 L
.22377 .14028 L
.224 .13626 L
.22424 .13295 L
.22447 .12807 L
.2247 .12392 L
.22493 .11769 L
.22517 .11276 L
.2254 .10646 L
.22563 .10187 L
.22586 .09644 L
.2261 .09305 L
.22633 .08948 L
.22656 .08773 L
.2268 .08601 L
.22703 .08555 L
.22726 .08528 L
.22749 .0856 L
.22773 .08651 L
.22796 .0876 L
.22819 .08993 L
.22842 .09229 L
.22866 .09624 L
.22889 .09927 L
.22912 .10374 L
.22935 .10746 L
.22959 .11294 L
.22982 .1166 L
.23005 .12139 L
.23028 .12531 L
.23052 .1309 L
.23075 .13427 L
.23098 .13795 L
.23121 .14068 L
.23145 .14449 L
.23168 .14588 L
.23191 .14669 L
.23214 .14669 L
.23238 .1476 L
.23261 .14723 L
.23284 .14677 L
.23307 .14658 L
Mistroke
.23331 .14742 L
.23354 .1477 L
.23377 .14751 L
.234 .1473 L
.23424 .14745 L
.23447 .14771 L
.2347 .14791 L
.23493 .14811 L
.23517 .14833 L
.2354 .14882 L
.23563 .14905 L
.23586 .14861 L
.2361 .14736 L
.23633 .14702 L
.23656 .14684 L
.23679 .14638 L
.23703 .14467 L
.23726 .14404 L
.23749 .14291 L
.23772 .14128 L
.23796 .13751 L
.23819 .13558 L
.23842 .13325 L
.23865 .13105 L
.23889 .12634 L
.23912 .12348 L
.23935 .11949 L
.23958 .11537 L
.23982 .10838 L
.24005 .10433 L
.24028 .10022 L
.24051 .09713 L
.24075 .0917 L
.24098 .08899 L
.24121 .08561 L
.24144 .08248 L
.24168 .07668 L
.24191 .07388 L
.24214 .07138 L
.24237 .06969 L
.24261 .06596 L
.24284 .0643 L
.24307 .06225 L
.2433 .05994 L
.24354 .05551 L
.24377 .0533 L
.244 .0519 L
.24423 .05117 L
.24447 .04929 L
.2447 .04871 L
Mistroke
.24493 .04801 L
.24516 .04701 L
.2454 .04462 L
.24563 .04356 L
.24586 .04316 L
.24609 .0432 L
.24633 .04258 L
.24656 .04241 L
.24679 .04194 L
.24702 .04091 L
.24726 .03904 L
.24749 .03795 L
.24772 .03756 L
.24795 .03767 L
.24819 .03774 L
.24842 .03812 L
.24865 .03836 L
.24888 .03823 L
.24912 .03755 L
.24935 .03731 L
.24958 .03741 L
.24981 .03769 L
.25005 .0378 L
.25028 .03798 L
.25051 .0379 L
.25074 .03733 L
.25098 .03623 L
.25121 .03553 L
.25144 .03513 L
.25167 .03493 L
.25191 .03455 L
.25214 .03456 L
.25237 .03442 L
.2526 .03413 L
.25284 .0332 L
.25307 .03277 L
.2533 .03226 L
.25353 .03185 L
.25377 .03083 L
.254 .03023 L
.25423 .02931 L
.25446 .02829 L
.2547 .02654 L
.25493 .02541 L
.25516 .02428 L
.25539 .02341 L
.25563 .02209 L
.25586 .02144 L
.25609 .02074 L
.25632 .02024 L
Mistroke
.25656 .01923 L
.25679 .01878 L
.25702 .01829 L
.25725 .01796 L
.25749 .01725 L
.25772 .01691 L
.25795 .01658 L
.25818 .01632 L
.25842 .01581 L
.25865 .01549 L
.25888 .01522 L
.25911 .01504 L
.25935 .01483 L
.25958 .01472 L
.25981 .01478 L
.26004 .01501 L
.26028 .01542 L
.26051 .01564 L
.26074 .01593 L
.26097 .01623 L
.26121 .01685 L
.26144 .01721 L
.26167 .0178 L
.2619 .01852 L
.26214 .01975 L
.26237 .02039 L
.2626 .02098 L
.26283 .02146 L
.26307 .02248 L
.2633 .02294 L
.26353 .02364 L
.26376 .02447 L
.264 .02612 L
.26423 .0269 L
.26446 .02765 L
.26469 .02825 L
.26493 .02967 L
.26516 .03039 L
.26539 .03142 L
.26563 .03266 L
.26586 .03491 L
.26609 .0361 L
.26632 .0371 L
.26656 .03781 L
.26679 .03931 L
.26702 .03995 L
.26725 .04085 L
.26749 .04188 L
.26772 .044 L
.26795 .04502 L
Mistroke
.26818 .04592 L
.26842 .04656 L
.26865 .04809 L
.26888 .04885 L
.26911 .04994 L
.26935 .05124 L
.26958 .05358 L
.26981 .05486 L
.27004 .05585 L
.27028 .05647 L
.27051 .05773 L
.27074 .05819 L
.27097 .05882 L
.27121 .05956 L
.27144 .0612 L
.27167 .06196 L
.2719 .06255 L
.27214 .06292 L
.27237 .06393 L
.2726 .06442 L
.27283 .06515 L
.27307 .0661 L
.2733 .06778 L
.27353 .06874 L
.27376 .06936 L
.274 .06965 L
.27423 .07026 L
.27446 .07037 L
.27469 .07055 L
.27493 .07081 L
.27516 .07162 L
.27539 .07194 L
.27562 .07214 L
.27586 .0722 L
.27609 .07262 L
.27632 .07288 L
.27655 .07336 L
.27679 .07407 L
.27702 .07517 L
.27725 .07587 L
.27748 .07626 L
.27772 .07638 L
.27795 .0765 L
.27818 .07635 L
.27841 .07621 L
.27865 .07614 L
.27888 .07632 L
.27911 .07624 L
.27934 .07604 L
.27958 .07584 L
Mistroke
.27981 .07582 L
.28004 .07581 L
.28027 .07599 L
.28051 .07648 L
.28074 .07727 L
.28097 .07778 L
.2812 .07803 L
.28144 .07812 L
.28167 .07828 L
.2819 .07819 L
.28213 .07819 L
.28237 .07828 L
.2826 .07877 L
.28283 .0789 L
.28306 .07904 L
.2833 .07913 L
.28353 .07966 L
.28376 .08002 L
.28399 .08071 L
.28423 .08166 L
.28446 .08317 L
.28469 .08411 L
.28492 .08486 L
.28516 .08534 L
.28539 .0861 L
.28562 .08635 L
.28585 .08672 L
.28609 .08716 L
.28632 .08818 L
.28655 .08854 L
.28678 .0888 L
.28702 .08898 L
.28725 .08971 L
.28748 .09005 L
.28771 .09066 L
.28795 .09158 L
.28818 .09325 L
.28841 .09417 L
.28864 .09483 L
.28888 .09528 L
.28911 .09623 L
.28934 .09656 L
.28957 .09707 L
.28981 .09772 L
.29004 .09923 L
.29027 .09991 L
.2905 .10054 L
.29074 .10099 L
.29097 .10221 L
.2912 .10288 L
Mistroke
.29143 .10394 L
.29167 .10522 L
.2919 .10743 L
.29213 .10872 L
.29236 .10979 L
.2926 .11048 L
.29283 .11173 L
.29306 .11223 L
.29329 .11289 L
.29353 .11362 L
.29376 .11517 L
.29399 .11584 L
.29422 .11635 L
.29446 .11664 L
.29469 .11755 L
.29492 .11793 L
.29515 .11853 L
.29539 .11939 L
.29562 .12101 L
.29585 .12188 L
.29608 .12245 L
.29632 .12278 L
.29655 .12353 L
.29678 .12375 L
.29701 .12409 L
.29725 .12456 L
.29748 .12571 L
.29771 .12625 L
.29794 .12667 L
.29818 .12692 L
.29841 .12769 L
.29864 .1281 L
.29887 .12877 L
.29911 .12962 L
.29934 .13109 L
.29957 .13198 L
.2998 .13266 L
.30004 .13307 L
.30027 .13373 L
.3005 .13395 L
.30073 .13424 L
.30097 .13456 L
.3012 .13533 L
.30143 .13564 L
.30166 .13583 L
.3019 .1359 L
.30213 .13626 L
.30236 .13638 L
.30259 .13659 L
.30283 .13698 L
Mistroke
.30306 .13772 L
.30329 .13815 L
.30352 .1384 L
.30376 .13853 L
.30399 .13881 L
.30422 .13886 L
.30445 .13893 L
.30469 .13903 L
.30492 .13942 L
.30515 .13959 L
.30539 .13975 L
.30562 .13984 L
.30585 .14013 L
.30608 .14034 L
.30632 .14066 L
.30655 .14103 L
.30678 .14159 L
.30701 .142 L
.30725 .14235 L
.30748 .14254 L
.30771 .14274 L
.30794 .1428 L
.30818 .14282 L
.30841 .14279 L
.30864 .14275 L
.30887 .14267 L
.30911 .14252 L
.30934 .14236 L
.30957 .14213 L
.3098 .14196 L
.31004 .14172 L
.31027 .14155 L
.3105 .14131 L
.31073 .14117 L
.31097 .14098 L
.3112 .14083 L
.31143 .1406 L
.31166 .14047 L
.3119 .14031 L
.31213 .14016 L
.31236 .13991 L
.31259 .13981 L
.31283 .13973 L
.31306 .13966 L
.31329 .1395 L
.31352 .13947 L
.31376 .13946 L
.31399 .13941 L
.31422 .13925 L
.31445 .13922 L
Mistroke
.31469 .13924 L
.31492 .13925 L
.31515 .13911 L
.31538 .13905 L
.31562 .13895 L
.31585 .13881 L
.31608 .13848 L
.31631 .13827 L
.31655 .13803 L
.31678 .13785 L
.31701 .13747 L
.31724 .13718 L
.31748 .13676 L
.31771 .13635 L
.31794 .13579 L
.31817 .13542 L
.31841 .1351 L
.31864 .13495 L
.31887 .13478 L
.3191 .13473 L
.31934 .13468 L
.31957 .13461 L
.3198 .13452 L
.32003 .13456 L
.32027 .13475 L
.3205 .13496 L
.32073 .1352 L
.32096 .13544 L
.3212 .13568 L
.32143 .13574 L
.32166 .13572 L
.32189 .13578 L
.32213 .13601 L
.32236 .13619 L
.32259 .1363 L
.32282 .13643 L
.32306 .13648 L
.32329 .13634 L
.32352 .13595 L
.32375 .13574 L
.32399 .13555 L
.32422 .1354 L
.32445 .13497 L
.32468 .1347 L
.32492 .13421 L
.32515 .13362 L
.32538 .13258 L
.32561 .13195 L
.32585 .1313 L
.32608 .1308 L
Mistroke
.32631 .12995 L
.32654 .12951 L
.32678 .12889 L
.32701 .12824 L
.32724 .12713 L
.32747 .12656 L
.32771 .1261 L
.32794 .1258 L
.32817 .12514 L
.3284 .12494 L
.32864 .12468 L
.32887 .12435 L
.3291 .12351 L
.32933 .12314 L
.32957 .1228 L
.3298 .1225 L
.33003 .12173 L
.33026 .12131 L
.3305 .12079 L
.33073 .12017 L
.33096 .11905 L
.33119 .11839 L
.33143 .11782 L
.33166 .11743 L
.33189 .11671 L
.33212 .11643 L
.33236 .11609 L
.33259 .11586 L
.33282 .11523 L
.33305 .1149 L
.33329 .11446 L
.33352 .1141 L
.33375 .11343 L
.33398 .11298 L
.33422 .11249 L
.33445 .11206 L
.33468 .1115 L
.33491 .11108 L
.33515 .11077 L
.33538 .11062 L
.33561 .11061 L
.33584 .11079 L
.33608 .11124 L
.33631 .11193 L
.33654 .11281 L
.33677 .11339 L
.33701 .1138 L
.33724 .11403 L
.33747 .11438 L
.3377 .1144 L
Mistroke
.33794 .11459 L
.33817 .11489 L
.3384 .11567 L
.33863 .11584 L
.33887 .11597 L
.3391 .11608 L
.33933 .11682 L
.33956 .11724 L
.3398 .11812 L
.34003 .11948 L
.34026 .12174 L
.34049 .12298 L
.34073 .12382 L
.34096 .12435 L
.34119 .12555 L
.34142 .12591 L
.34166 .12665 L
.34189 .12773 L
.34212 .13012 L
.34235 .13111 L
.34259 .13191 L
.34282 .13248 L
.34305 .13432 L
.34328 .13526 L
.34352 .13695 L
.34375 .1393 L
.34398 .14342 L
.34422 .14569 L
.34445 .14744 L
.34468 .14859 L
.34491 .15102 L
.34515 .15193 L
.34538 .15342 L
.34561 .15535 L
.34584 .1594 L
.34608 .16125 L
.34631 .16274 L
.34654 .16379 L
.34677 .16666 L
.34701 .16797 L
.34724 .17009 L
.34747 .17295 L
.3477 .1783 L
.34794 .18118 L
.34817 .1835 L
.3484 .18511 L
.34863 .18858 L
.34887 .19001 L
.3491 .1921 L
.34933 .19459 L
Mistroke
.34956 .19976 L
.3498 .20233 L
.35003 .2046 L
.35026 .20622 L
.35049 .20999 L
.35073 .21183 L
.35096 .21449 L
.35119 .2176 L
.35142 .22332 L
.35166 .22652 L
.35189 .22922 L
.35212 .23103 L
.35235 .23454 L
.35259 .23605 L
.35282 .23798 L
.35305 .24003 L
.35328 .2442 L
.35352 .24625 L
.35375 .24789 L
.35398 .24889 L
.35421 .25126 L
.35445 .25227 L
.35468 .25359 L
.35491 .25518 L
.35514 .25831 L
.35538 .26002 L
.35561 .26121 L
.35584 .26185 L
.35607 .26318 L
.35631 .26361 L
.35654 .26407 L
.35677 .26459 L
.357 .26592 L
.35724 .26659 L
.35747 .26699 L
.3577 .26708 L
.35793 .26741 L
.35817 .26753 L
.3584 .26764 L
.35863 .26781 L
.35886 .26811 L
.3591 .26844 L
.35933 .2685 L
.35956 .26834 L
.35979 .26775 L
.36003 .26731 L
.36026 .26658 L
.36049 .26568 L
.36072 .26426 L
.36096 .2635 L
Mistroke
.36119 .26274 L
.36142 .26208 L
.36165 .26071 L
.36189 .26003 L
.36212 .25899 L
.36235 .25783 L
.36258 .25567 L
.36282 .25465 L
.36305 .25369 L
.36328 .25294 L
.36351 .25115 L
.36375 .25025 L
.36398 .24887 L
.36421 .24714 L
.36444 .24407 L
.36468 .2425 L
.36491 .24129 L
.36514 .24044 L
.36537 .23852 L
.36561 .23782 L
.36584 .23675 L
.36607 .23532 L
.3663 .23226 L
.36654 .23085 L
.36677 .22974 L
.367 .22892 L
.36723 .22667 L
.36747 .22569 L
.3677 .22417 L
.36793 .2222 L
.36816 .2183 L
.3684 .21616 L
.36863 .21421 L
.36886 .21273 L
.36909 .20973 L
.36933 .20828 L
.36956 .20637 L
.36979 .20433 L
.37002 .2004 L
.37026 .19828 L
.37049 .19628 L
.37072 .19483 L
.37095 .19197 L
.37119 .19064 L
.37142 .18902 L
.37165 .18747 L
.37188 .18435 L
.37212 .18263 L
.37235 .18098 L
.37258 .17978 L
Mistroke
.37281 .17755 L
.37305 .17642 L
.37328 .17527 L
.37351 .17436 L
.37374 .17264 L
.37398 .17163 L
.37421 .17078 L
.37444 .17032 L
.37467 .16964 L
.37491 .16935 L
.37514 .16933 L
.37537 .16967 L
.3756 .1702 L
.37584 .17046 L
.37607 .17082 L
.3763 .17134 L
.37653 .17248 L
.37677 .17296 L
.377 .17382 L
.37723 .17495 L
.37746 .17732 L
.3777 .17845 L
.37793 .17983 L
.37816 .18121 L
.37839 .18423 L
.37863 .18582 L
.37886 .18804 L
.37909 .19039 L
.37932 .19484 L
.37956 .19732 L
.37979 .20007 L
.38002 .20241 L
.38025 .20682 L
.38049 .20921 L
.38072 .21215 L
.38095 .21484 L
.38118 .21974 L
.38142 .2224 L
.38165 .22515 L
.38188 .22724 L
.38211 .23113 L
.38235 .23315 L
.38258 .23545 L
.38281 .23743 L
.38305 .241 L
.38328 .24287 L
.38351 .24449 L
.38374 .24548 L
.38398 .24739 L
.38421 .24826 L
Mistroke
.38444 .24906 L
.38467 .24969 L
.38491 .25087 L
.38514 .25139 L
.38537 .25136 L
.3856 .25095 L
.38584 .25036 L
.38607 .24986 L
.3863 .2491 L
.38653 .24844 L
.38677 .24736 L
.387 .2467 L
.38723 .24546 L
.38746 .24414 L
.3877 .2419 L
.38793 .24059 L
.38816 .23903 L
.38839 .23784 L
.38863 .23568 L
.38886 .23451 L
.38909 .23287 L
.38932 .23135 L
.38956 .22862 L
.38979 .227 L
.39002 .22522 L
.39025 .22385 L
.39049 .22161 L
.39072 .22038 L
.39095 .21906 L
.39118 .21808 L
.39142 .21638 L
.39165 .21548 L
.39188 .21467 L
.39211 .21423 L
.39235 .21347 L
.39258 .21316 L
.39281 .21301 L
.39304 .21306 L
.39328 .21308 L
.39351 .21309 L
.39374 .2133 L
.39397 .21353 L
.39421 .21416 L
.39444 .21455 L
.39467 .21541 L
.3949 .21635 L
.39514 .21806 L
.39537 .21919 L
.3956 .22067 L
.39583 .22196 L
Mistroke
.39607 .22406 L
.3963 .22537 L
.39653 .22701 L
.39676 .2284 L
.397 .2306 L
.39723 .23183 L
.39746 .23313 L
.39769 .23403 L
.39793 .23557 L
.39816 .23629 L
.39839 .2371 L
.39862 .23771 L
.39886 .23889 L
.39909 .2395 L
.39932 .24005 L
.39955 .24042 L
.39979 .24106 L
.40002 .24134 L
.40025 .24143 L
.40048 .24137 L
.40072 .24132 L
.40095 .24125 L
.40118 .24099 L
.40141 .24068 L
.40165 .24013 L
.40188 .23975 L
.40211 .23913 L
.40234 .23848 L
.40258 .23738 L
.40281 .23677 L
.40304 .23604 L
.40327 .23546 L
.40351 .23433 L
.40374 .23371 L
.40397 .23278 L
.4042 .23188 L
.40444 .23026 L
.40467 .22926 L
.4049 .22814 L
.40513 .22726 L
.40537 .22585 L
.4056 .22502 L
.40583 .22412 L
.40606 .22346 L
.4063 .22237 L
.40653 .2218 L
.40676 .22128 L
.40699 .22108 L
.40723 .22067 L
.40746 .22049 L
Mistroke
.40769 .22027 L
.40792 .22016 L
.40816 .21999 L
.40839 .21981 L
.40862 .21976 L
.40885 .2198 L
.40909 .22019 L
.40932 .22039 L
.40955 .22093 L
.40978 .22155 L
.41002 .22281 L
.41025 .22378 L
.41048 .22519 L
.41071 .2266 L
.41095 .22866 L
.41118 .23 L
.41141 .23136 L
.41164 .23236 L
.41188 .23383 L
.41211 .23452 L
.41234 .23533 L
.41257 .23595 L
.41281 .23714 L
.41304 .2375 L
.41327 .23776 L
.4135 .23787 L
.41374 .23853 L
.41397 .23883 L
.4142 .23933 L
.41443 .24015 L
.41467 .24153 L
.4149 .24221 L
.41513 .2424 L
.41536 .24236 L
.4156 .24258 L
.41583 .24247 L
.41606 .24251 L
.41629 .24291 L
.41653 .24391 L
.41676 .2442 L
.41699 .24413 L
.41722 .24392 L
.41746 .2442 L
.41769 .24425 L
.41792 .24481 L
.41815 .24603 L
.41839 .24821 L
.41862 .2494 L
.41885 .2501 L
.41908 .25047 L
Mistroke
.41932 .25145 L
.41955 .25164 L
.41978 .25229 L
.42001 .25349 L
.42025 .25612 L
.42048 .25732 L
.42071 .25828 L
.42094 .25904 L
.42118 .26112 L
.42141 .262 L
.42164 .26351 L
.42188 .26567 L
.42211 .26989 L
.42234 .27215 L
.42257 .27416 L
.42281 .27574 L
.42304 .27912 L
.42327 .2806 L
.4235 .28271 L
.42374 .28499 L
.42397 .28983 L
.4242 .29238 L
.42443 .29513 L
.42467 .29736 L
.4249 .30186 L
.42513 .3044 L
.42536 .30769 L
.4256 .31093 L
.42583 .31651 L
.42606 .31977 L
.42629 .32285 L
.42653 .32498 L
.42676 .32858 L
.42699 .33025 L
.42722 .33204 L
.42746 .33343 L
.42769 .33622 L
.42792 .33747 L
.42815 .33842 L
.42839 .33886 L
.42862 .34002 L
.42885 .34054 L
.42908 .34099 L
.42932 .34152 L
.42955 .34237 L
.42978 .34285 L
.43001 .34257 L
.43025 .34191 L
.43048 .34073 L
.43071 .3398 L
Mistroke
.43094 .3385 L
.43118 .33728 L
.43141 .33547 L
.43164 .3343 L
.43187 .33269 L
.43211 .33113 L
.43234 .32866 L
.43257 .3274 L
.4328 .3261 L
.43304 .32529 L
.43327 .3235 L
.4335 .32273 L
.43373 .32141 L
.43397 .32009 L
.4342 .31743 L
.43443 .31576 L
.43466 .31394 L
.4349 .31246 L
.43513 .31011 L
.43536 .30865 L
.43559 .3071 L
.43583 .30595 L
.43606 .30423 L
.43629 .30331 L
.43652 .30261 L
.43676 .30254 L
.43699 .30239 L
.43722 .30242 L
.43745 .3024 L
.43769 .30254 L
.43792 .30285 L
.43815 .30288 L
.43838 .30322 L
.43862 .30373 L
.43885 .30511 L
.43908 .30578 L
.43931 .30694 L
.43955 .30814 L
.43978 .31068 L
.44001 .31233 L
.44024 .31472 L
.44048 .31718 L
.44071 .32118 L
.44094 .32361 L
.44117 .32617 L
.44141 .32818 L
.44164 .33152 L
.44187 .33319 L
.4421 .33517 L
.44234 .33685 L
Mistroke
.44257 .34004 L
.4428 .34146 L
.44303 .34284 L
.44327 .34385 L
.4435 .34619 L
.44373 .34734 L
.44396 .34877 L
.4442 .35038 L
.44443 .35326 L
.44466 .35474 L
.44489 .35569 L
.44513 .3562 L
.44536 .35744 L
.44559 .35781 L
.44582 .35825 L
.44606 .35885 L
.44629 .36035 L
.44652 .36092 L
.44675 .36111 L
.44699 .36104 L
.44722 .3615 L
.44745 .36171 L
.44768 .36223 L
.44792 .36323 L
.44815 .36489 L
.44838 .36586 L
.44861 .36624 L
.44885 .36619 L
.44908 .36621 L
.44931 .3659 L
.44954 .36574 L
.44978 .36593 L
.45001 .3667 L
.45024 .3669 L
.45047 .36679 L
.45071 .36659 L
.45094 .36674 L
.45117 .36672 L
.4514 .36707 L
.45164 .36804 L
.45187 .36979 L
.4521 .37079 L
.45233 .37137 L
.45257 .3717 L
.4528 .37251 L
.45303 .37263 L
.45326 .37305 L
.4535 .37377 L
.45373 .37566 L
.45396 .37652 L
Mistroke
.45419 .37743 L
.45443 .37818 L
.45466 .38009 L
.45489 .38122 L
.45512 .38299 L
.45536 .38509 L
.45559 .38865 L
.45582 .39079 L
.45605 .39273 L
.45629 .39412 L
.45652 .39649 L
.45675 .39755 L
.45698 .39891 L
.45722 .40024 L
.45745 .40293 L
.45768 .40413 L
.45791 .40516 L
.45815 .40583 L
.45838 .40761 L
.45861 .40844 L
.45884 .40965 L
.45908 .41115 L
.45931 .41391 L
.45954 .41541 L
.45977 .41647 L
.46001 .4171 L
.46024 .41844 L
.46047 .41891 L
.4607 .41955 L
.46094 .42036 L
.46117 .42214 L
.4614 .42291 L
.46164 .42334 L
.46187 .42348 L
.4621 .42423 L
.46233 .42448 L
.46257 .42501 L
.4628 .42592 L
.46303 .42766 L
.46326 .42864 L
.4635 .42922 L
.46373 .42951 L
.46396 .43017 L
.46419 .43029 L
.46443 .43056 L
.46466 .43105 L
.46489 .43229 L
.46512 .43288 L
.46536 .43331 L
.46559 .43359 L
Mistroke
.46582 .43437 L
.46605 .43466 L
.46629 .43511 L
.46652 .43578 L
.46675 .43718 L
.46698 .43799 L
.46722 .43875 L
.46745 .43935 L
.46768 .44047 L
.46791 .44098 L
.46815 .44156 L
.46838 .44203 L
.46861 .44316 L
.46884 .44384 L
.46908 .4447 L
.46931 .44541 L
.46954 .44662 L
.46977 .44741 L
.47001 .44826 L
.47024 .4488 L
.47047 .44961 L
.4707 .45024 L
.47094 .451 L
.47117 .45153 L
.4714 .45199 L
.47163 .45235 L
.47187 .45244 L
.4721 .4521 L
.47233 .45121 L
.47256 .45071 L
.4728 .45008 L
.47303 .44936 L
.47326 .44788 L
.47349 .44702 L
.47373 .44572 L
.47396 .44421 L
.47419 .44152 L
.47442 .44 L
.47466 .43835 L
.47489 .43696 L
.47512 .43433 L
.47535 .43306 L
.47559 .43139 L
.47582 .42979 L
.47605 .42658 L
.47628 .4249 L
.47652 .42296 L
.47675 .42132 L
.47698 .41811 L
.47721 .41629 L
Mistroke
.47745 .41408 L
.47768 .41205 L
.47791 .40854 L
.47814 .40656 L
.47838 .40467 L
.47861 .40335 L
.47884 .40105 L
.47907 .39992 L
.47931 .39873 L
.47954 .39784 L
.47977 .39616 L
.48 .39544 L
.48024 .39499 L
.48047 .39497 L
.4807 .39461 L
.48093 .39441 L
.48117 .39412 L
.4814 .39373 L
.48163 .39333 L
.48186 .3931 L
.4821 .39355 L
.48233 .39437 L
.48256 .39587 L
.48279 .39685 L
.48303 .39797 L
.48326 .39867 L
.48349 .40001 L
.48372 .40103 L
.48396 .4029 L
.48419 .40478 L
.48442 .40761 L
.48465 .40953 L
.48489 .4114 L
.48512 .41227 L
.48535 .41345 L
.48558 .41429 L
.48582 .41576 L
.48605 .41697 L
.48628 .41844 L
.48651 .41953 L
.48675 .42017 L
.48698 .41977 L
.48721 .41851 L
.48744 .41783 L
.48768 .41721 L
.48791 .41648 L
.48814 .41463 L
.48837 .4138 L
.48861 .41218 L
.48884 .40996 L
Mistroke
.48907 .40547 L
.4893 .40295 L
.48954 .39998 L
.48977 .39728 L
.49 .39209 L
.49023 .38939 L
.49047 .38583 L
.4907 .3824 L
.49093 .37575 L
.49116 .37199 L
.4914 .36754 L
.49163 .36373 L
.49186 .35685 L
.49209 .35306 L
.49233 .34871 L
.49256 .34518 L
.49279 .33876 L
.49302 .33511 L
.49326 .33103 L
.49349 .32785 L
.49372 .32248 L
.49395 .31952 L
.49419 .31668 L
.49442 .31497 L
.49465 .31208 L
.49488 .3105 L
.49512 .30905 L
.49535 .30836 L
.49558 .30748 L
.49581 .307 L
.49605 .30728 L
.49628 .30844 L
.49651 .3108 L
.49674 .31209 L
.49698 .31397 L
.49721 .31606 L
.49744 .32032 L
.49767 .32256 L
.49791 .326 L
.49814 .3297 L
.49837 .33683 L
.4986 .34075 L
.49884 .34557 L
.49907 .34994 L
.4993 .35826 L
.49953 .3629 L
.49977 .36881 L
.5 .37435 L
.50023 .38428 L
.50047 .38976 L
Mistroke
.5007 .39569 L
.50093 .40043 L
.50116 .40911 L
.5014 .41366 L
.50163 .41891 L
.50186 .4234 L
.50209 .43163 L
.50233 .43585 L
.50256 .43985 L
.50279 .44263 L
.50302 .44814 L
.50326 .4509 L
.50349 .45383 L
.50372 .45639 L
.50395 .46098 L
.50419 .46329 L
.50442 .46459 L
.50465 .46488 L
.50488 .46569 L
.50512 .46572 L
.50535 .46539 L
.50558 .46513 L
.50581 .46487 L
.50605 .46443 L
.50628 .46274 L
.50651 .46066 L
.50674 .4574 L
.50698 .45529 L
.50721 .45275 L
.50744 .45097 L
.50767 .44793 L
.50791 .44619 L
.50814 .44328 L
.50837 .44044 L
.5086 .43564 L
.50884 .43265 L
.50907 .42942 L
.5093 .4271 L
.50953 .42347 L
.50977 .42148 L
.51 .41913 L
.51023 .41724 L
.51046 .41411 L
.5107 .41244 L
.51093 .41102 L
.51116 .41043 L
.51139 .40937 L
.51163 .40904 L
.51186 .40879 L
.51209 .40876 L
Mistroke
.51232 .40856 L
.51256 .40836 L
.51279 .40855 L
.51302 .40894 L
.51325 .41007 L
.51349 .41072 L
.51372 .41207 L
.51395 .41353 L
.51418 .41631 L
.51442 .41809 L
.51465 .42056 L
.51488 .4229 L
.51511 .42682 L
.51535 .42921 L
.51558 .43209 L
.51581 .43455 L
.51604 .43858 L
.51628 .44078 L
.51651 .44323 L
.51674 .44509 L
.51697 .44845 L
.51721 .45007 L
.51744 .45188 L
.51767 .45327 L
.5179 .45604 L
.51814 .4575 L
.51837 .45906 L
.5186 .46033 L
.51883 .46259 L
.51907 .46377 L
.5193 .46468 L
.51953 .46521 L
.51976 .4662 L
.52 .46664 L
.52023 .46687 L
.52046 .46695 L
.52069 .46708 L
.52093 .467 L
.52116 .46642 L
.52139 .46566 L
.52162 .46446 L
.52186 .46363 L
.52209 .4625 L
.52232 .46158 L
.52255 .46009 L
.52279 .4592 L
.52302 .45788 L
.52325 .45663 L
.52348 .45455 L
.52372 .45332 L
Mistroke
.52395 .45189 L
.52418 .45078 L
.52441 .44892 L
.52465 .44798 L
.52488 .44692 L
.52511 .44606 L
.52534 .44443 L
.52558 .44358 L
.52581 .44264 L
.52604 .44189 L
.52627 .44055 L
.52651 .43991 L
.52674 .43936 L
.52697 .43901 L
.5272 .43824 L
.52744 .43784 L
.52767 .43746 L
.5279 .43704 L
.52813 .43642 L
.52837 .43617 L
.5286 .43631 L
.52883 .43661 L
.52906 .43697 L
.5293 .43742 L
.52953 .43798 L
.52976 .43833 L
.52999 .43864 L
.53023 .43896 L
.53046 .43954 L
.53069 .44005 L
.53092 .44059 L
.53116 .44095 L
.53139 .44124 L
.53162 .44122 L
.53185 .44103 L
.53209 .44082 L
.53232 .44066 L
.53255 .4405 L
.53278 .44029 L
.53302 .44019 L
.53325 .44002 L
.53348 .43982 L
.53371 .43936 L
.53395 .43907 L
.53418 .43865 L
.53441 .43829 L
.53464 .43765 L
.53488 .43733 L
.53511 .43694 L
.53534 .43668 L
Mistroke
.53557 .43609 L
.53581 .43567 L
.53604 .43498 L
.53627 .43433 L
.5365 .43335 L
.53674 .43267 L
.53697 .43203 L
.5372 .4317 L
.53743 .43132 L
.53767 .43102 L
.5379 .43061 L
.53813 .43033 L
.53836 .43013 L
.5386 .43 L
.53883 .43013 L
.53906 .43065 L
.5393 .4316 L
.53953 .43215 L
.53976 .43263 L
.53999 .43306 L
.54023 .43396 L
.54046 .43425 L
.54069 .4348 L
.54092 .43551 L
.54116 .43719 L
.54139 .43801 L
.54162 .43904 L
.54185 .44003 L
.54209 .44215 L
.54232 .44331 L
.54255 .44487 L
.54278 .44646 L
.54302 .44941 L
.54325 .45117 L
.54348 .45314 L
.54371 .45479 L
.54395 .45765 L
.54418 .45918 L
.54441 .46087 L
.54464 .46218 L
.54488 .46464 L
.54511 .46599 L
.54534 .46756 L
.54557 .46879 L
.54581 .47094 L
.54604 .47214 L
.54627 .47328 L
.5465 .474 L
.54674 .47519 L
.54697 .47592 L
Mistroke
.5472 .47662 L
.54743 .47705 L
.54767 .47751 L
.5479 .47773 L
.54813 .4775 L
.54836 .47681 L
.5486 .47556 L
.54883 .47485 L
.54906 .47403 L
.54929 .47321 L
.54953 .47154 L
.54976 .47069 L
.54999 .46926 L
.55022 .46755 L
.55046 .46435 L
.55069 .4627 L
.55092 .46094 L
.55115 .45941 L
.55139 .45622 L
.55162 .45464 L
.55185 .45243 L
.55208 .45001 L
.55232 .44539 L
.55255 .44298 L
.55278 .44053 L
.55301 .43852 L
.55325 .43441 L
.55348 .43234 L
.55371 .42968 L
.55394 .42697 L
.55418 .42185 L
.55441 .41914 L
.55464 .41653 L
.55487 .41455 L
.55511 .41063 L
.55534 .4087 L
.55557 .40635 L
.5558 .40407 L
.55604 .39974 L
.55627 .39745 L
.5565 .39542 L
.55673 .39403 L
.55697 .39127 L
.5572 .38998 L
.55743 .38855 L
.55766 .3872 L
.5579 .38457 L
.55813 .38319 L
.55836 .38221 L
.55859 .38172 L
Mistroke
.55883 .3807 L
.55906 .38038 L
.55929 .38022 L
.55952 .38012 L
.55976 .37966 L
.55999 .37945 L
.56022 .3796 L
.56045 .37995 L
.56069 .38053 L
.56092 .38092 L
.56115 .38157 L
.56138 .38227 L
.56162 .38343 L
.56185 .38395 L
.56208 .38465 L
.56231 .38542 L
.56255 .38706 L
.56278 .38787 L
.56301 .38902 L
.56324 .39031 L
.56348 .39278 L
.56371 .39398 L
.56394 .39523 L
.56417 .39635 L
.56441 .39884 L
.56464 .40007 L
.56487 .40174 L
.5651 .40352 L
.56534 .40697 L
.56557 .40878 L
.5658 .41064 L
.56603 .41217 L
.56627 .41529 L
.5665 .41697 L
.56673 .41913 L
.56696 .42133 L
.5672 .42522 L
.56743 .42733 L
.56766 .42923 L
.56789 .43052 L
.56813 .43305 L
.56836 .43418 L
.56859 .43559 L
.56882 .43696 L
.56906 .43969 L
.56929 .44101 L
.56952 .44207 L
.56975 .4427 L
.56999 .4442 L
.57022 .44494 L
Mistroke
.57045 .44586 L
.57068 .447 L
.57092 .44894 L
.57115 .44996 L
.57138 .45034 L
.57161 .45025 L
.57185 .45031 L
.57208 .44999 L
.57231 .44967 L
.57254 .44957 L
.57278 .44989 L
.57301 .44984 L
.57324 .44945 L
.57347 .44895 L
.57371 .44856 L
.57394 .4484 L
.57417 .44853 L
.5744 .44922 L
.57464 .45015 L
.57487 .45079 L
.5751 .45081 L
.57533 .4505 L
.57557 .44991 L
.5758 .44922 L
.57603 .44864 L
.57626 .44842 L
.5765 .44856 L
.57673 .44834 L
.57696 .44793 L
.57719 .44756 L
.57743 .4476 L
.57766 .44763 L
.57789 .44819 L
.57813 .44948 L
.57836 .45164 L
.57859 .45294 L
.57882 .45383 L
.57906 .45441 L
.57929 .45557 L
.57952 .45587 L
.57975 .45658 L
.57999 .45761 L
.58022 .46005 L
.58045 .46109 L
.58068 .46215 L
.58092 .46301 L
.58115 .46537 L
.58138 .46669 L
.58161 .46886 L
.58185 .47158 L
Mistroke
.58208 .47626 L
.58231 .47897 L
.58254 .48133 L
.58278 .48303 L
.58301 .48617 L
.58324 .48751 L
.58347 .48934 L
.58371 .49134 L
.58394 .49544 L
.58417 .4973 L
.5844 .49891 L
.58464 .50005 L
.58487 .503 L
.5851 .50438 L
.58533 .5064 L
.58557 .50896 L
.5858 .51374 L
.58603 .51632 L
.58626 .51837 L
.5865 .51977 L
.58673 .5227 L
.58696 .52391 L
.58719 .52554 L
.58743 .5274 L
.58766 .53133 L
.58789 .53324 L
.58812 .53484 L
.58836 .53588 L
.58859 .53844 L
.58882 .53968 L
.58905 .54147 L
.58929 .54361 L
.58952 .54753 L
.58975 .54976 L
.58998 .5515 L
.59022 .55255 L
.59045 .55453 L
.59068 .5553 L
.59091 .55626 L
.59115 .55734 L
.59138 .55963 L
.59161 .56071 L
.59184 .56141 L
.59208 .56171 L
.59231 .56265 L
.59254 .56294 L
.59277 .56335 L
.59301 .56405 L
.59324 .56552 L
.59347 .56634 L
Mistroke
.5937 .56676 L
.59394 .56688 L
.59417 .56724 L
.5944 .56723 L
.59463 .56719 L
.59487 .56723 L
.5951 .56764 L
.59533 .56787 L
.59556 .56802 L
.5958 .56805 L
.59603 .56816 L
.59626 .56828 L
.59649 .56845 L
.59673 .56862 L
.59696 .56877 L
.59719 .56905 L
.59742 .56923 L
.59766 .56924 L
.59789 .56887 L
.59812 .5686 L
.59835 .5681 L
.59859 .56738 L
.59882 .56618 L
.59905 .56551 L
.59928 .56489 L
.59952 .5644 L
.59975 .5634 L
.59998 .56291 L
.60021 .56214 L
.60045 .56129 L
.60068 .55964 L
.60091 .55885 L
.60114 .55807 L
.60138 .55748 L
.60161 .55611 L
.60184 .55539 L
.60207 .55428 L
.60231 .55292 L
.60254 .55056 L
.60277 .54931 L
.603 .54834 L
.60324 .54768 L
.60347 .54629 L
.6037 .54583 L
.60393 .54517 L
.60417 .54428 L
.6044 .54225 L
.60463 .54137 L
.60486 .54067 L
.6051 .54013 L
Mistroke
.60533 .53856 L
.60556 .53787 L
.60579 .53683 L
.60603 .53547 L
.60626 .53276 L
.60649 .53123 L
.60672 .5298 L
.60696 .52867 L
.60719 .52652 L
.60742 .52547 L
.60765 .52418 L
.60789 .52291 L
.60812 .52038 L
.60835 .51901 L
.60858 .5176 L
.60882 .51654 L
.60905 .51453 L
.60928 .51354 L
.60951 .51242 L
.60975 .51149 L
.60998 .50963 L
.61021 .50853 L
.61044 .50737 L
.61068 .50649 L
.61091 .50508 L
.61114 .50431 L
.61137 .50369 L
.61161 .50345 L
.61184 .50303 L
.61207 .50272 L
.6123 .50241 L
.61254 .5023 L
.61277 .50239 L
.613 .50241 L
.61323 .50283 L
.61347 .5037 L
.6137 .50532 L
.61393 .50614 L
.61416 .50699 L
.6144 .50783 L
.61463 .50969 L
.61486 .51054 L
.61509 .51191 L
.61533 .51361 L
.61556 .51701 L
.61579 .51875 L
.61602 .52063 L
.61626 .5223 L
.61649 .52584 L
.61672 .52763 L
Mistroke
.61695 .53006 L
.61719 .53263 L
.61742 .53755 L
.61765 .54024 L
.61789 .54309 L
.61812 .54545 L
.61835 .54997 L
.61858 .55233 L
.61882 .55522 L
.61905 .55791 L
.61928 .56291 L
.61951 .56561 L
.61975 .56835 L
.61998 .57039 L
.62021 .57422 L
.62044 .5762 L
.62068 .57841 L
.62091 .58029 L
.62114 .58374 L
.62137 .58559 L
.62161 .58719 L
.62184 .58815 L
.62207 .58993 L
.6223 .59078 L
.62254 .59153 L
.62277 .59203 L
.623 .5929 L
.62323 .59333 L
.62347 .59324 L
.6237 .59276 L
.62393 .59186 L
.62416 .59123 L
.6244 .5902 L
.62463 .58917 L
.62486 .58735 L
.62509 .58628 L
.62533 .58461 L
.62556 .58295 L
.62579 .57997 L
.62602 .57821 L
.62626 .576 L
.62649 .57408 L
.62672 .57075 L
.62695 .56892 L
.62719 .5667 L
.62742 .56481 L
.62765 .5614 L
.62788 .55952 L
.62812 .55737 L
.62835 .55558 L
Mistroke
.62858 .55245 L
.62881 .55086 L
.62905 .54928 L
.62928 .54812 L
.62951 .54589 L
.62974 .54479 L
.62998 .54367 L
.63021 .54273 L
.63044 .54099 L
.63067 .54021 L
.63091 .53979 L
.63114 .53968 L
.63137 .53922 L
.6316 .53912 L
.63184 .5391 L
.63207 .53901 L
.6323 .53874 L
.63253 .5387 L
.63277 .53911 L
.633 .53969 L
.63323 .54053 L
.63346 .54109 L
.6337 .54171 L
.63393 .54205 L
.63416 .54264 L
.63439 .54301 L
.63463 .54384 L
.63486 .54475 L
.63509 .54624 L
.63532 .54721 L
.63556 .5482 L
.63579 .5488 L
.63602 .54969 L
.63625 .55022 L
.63649 .55097 L
.63672 .55162 L
.63695 .5526 L
.63718 .55316 L
.63742 .55354 L
.63765 .55348 L
.63788 .5534 L
.63811 .5533 L
.63835 .55336 L
.63858 .55343 L
.63881 .55345 L
.63904 .5536 L
.63928 .5535 L
.63951 .55316 L
.63974 .55225 L
.63997 .55182 L
Mistroke
.64021 .55123 L
.64044 .55064 L
.64067 .5493 L
.6409 .54849 L
.64114 .54722 L
.64137 .54575 L
.6416 .54326 L
.64183 .5418 L
.64207 .54035 L
.6423 .53922 L
.64253 .53718 L
.64276 .53625 L
.643 .53504 L
.64323 .53389 L
.64346 .53154 L
.64369 .53044 L
.64393 .52929 L
.64416 .52835 L
.64439 .52627 L
.64462 .52517 L
.64486 .52377 L
.64509 .52225 L
.64532 .51956 L
.64555 .51807 L
.64579 .5168 L
.64602 .51592 L
.64625 .51425 L
.64648 .51356 L
.64672 .51278 L
.64695 .51207 L
.64718 .51046 L
.64741 .50975 L
.64765 .50915 L
.64788 .50879 L
.64811 .5078 L
.64834 .50726 L
.64858 .50654 L
.64881 .50571 L
.64904 .50434 L
.64927 .5035 L
.64951 .50299 L
.64974 .50283 L
.64997 .50264 L
.6502 .50268 L
.65044 .50278 L
.65067 .50288 L
.6509 .50289 L
.65113 .50304 L
.65137 .50344 L
.6516 .50396 L
Mistroke
.65183 .50464 L
.65206 .50504 L
.6523 .50538 L
.65253 .50544 L
.65276 .50563 L
.65299 .5057 L
.65323 .50613 L
.65346 .50667 L
.65369 .50761 L
.65392 .50824 L
.65416 .50886 L
.65439 .5092 L
.65462 .5097 L
.65485 .51009 L
.65509 .51071 L
.65532 .5113 L
.65555 .51205 L
.65578 .51253 L
.65602 .51277 L
.65625 .51256 L
.65648 .51215 L
.65672 .51192 L
.65695 .5119 L
.65718 .51189 L
.65741 .51172 L
.65765 .51178 L
.65788 .51158 L
.65811 .51102 L
.65834 .50974 L
.65858 .50914 L
.65881 .50854 L
.65904 .50796 L
.65927 .50654 L
.65951 .5059 L
.65974 .50487 L
.65997 .50354 L
.6602 .50089 L
.66044 .49945 L
.66067 .4979 L
.6609 .49653 L
.66113 .49383 L
.66137 .49248 L
.6616 .49076 L
.66183 .4891 L
.66206 .48576 L
.6623 .48391 L
.66253 .48178 L
.66276 .47997 L
.66299 .47662 L
.66323 .47473 L
Mistroke
.66346 .47252 L
.66369 .47066 L
.66392 .46738 L
.66416 .46546 L
.66439 .46343 L
.66462 .46193 L
.66485 .45948 L
.66509 .45817 L
.66532 .45695 L
.66555 .45627 L
.66578 .45509 L
.66602 .4545 L
.66625 .45402 L
.66648 .45389 L
.66671 .45377 L
.66695 .45371 L
.66718 .45401 L
.66741 .45462 L
.66764 .45588 L
.66788 .45657 L
.66811 .45765 L
.66834 .45882 L
.66857 .46115 L
.66881 .46243 L
.66904 .46427 L
.66927 .46616 L
.6695 .46969 L
.66974 .47166 L
.66997 .47406 L
.6702 .47623 L
.67043 .48022 L
.67067 .48238 L
.6709 .48499 L
.67113 .48731 L
.67136 .49161 L
.6716 .49393 L
.67183 .49654 L
.67206 .49868 L
.67229 .50266 L
.67253 .50482 L
.67276 .50723 L
.67299 .5092 L
.67322 .51273 L
.67346 .51464 L
.67369 .51652 L
.67392 .51784 L
.67415 .5202 L
.67439 .52145 L
.67462 .52264 L
.67485 .52343 L
Mistroke
.67508 .52474 L
.67532 .5254 L
.67555 .5257 L
.67578 .52556 L
.67601 .52526 L
.67625 .52501 L
.67648 .52439 L
.67671 .52367 L
.67694 .52228 L
.67718 .52142 L
.67741 .51995 L
.67764 .51841 L
.67787 .51566 L
.67811 .514 L
.67834 .51184 L
.67857 .50997 L
.6788 .5067 L
.67904 .50483 L
.67927 .50246 L
.6795 .50038 L
.67973 .49677 L
.67997 .49472 L
.6802 .4924 L
.68043 .49053 L
.68066 .48734 L
.6809 .48568 L
.68113 .48394 L
.68136 .48264 L
.68159 .48024 L
.68183 .47905 L
.68206 .47788 L
.68229 .47705 L
.68252 .47544 L
.68276 .4747 L
.68299 .47417 L
.68322 .47392 L
.68345 .4733 L
.68369 .47303 L
.68392 .47293 L
.68415 .47291 L
.68438 .47292 L
.68462 .47298 L
.68485 .47348 L
.68508 .47411 L
.68531 .47525 L
.68555 .47602 L
.68578 .47713 L
.68601 .47812 L
.68624 .47977 L
.68648 .48081 L
Mistroke
.68671 .48226 L
.68694 .48362 L
.68717 .48578 L
.68741 .48703 L
.68764 .48837 L
.68787 .48944 L
.6881 .49121 L
.68834 .49203 L
.68857 .49289 L
.6888 .49363 L
.68903 .49512 L
.68927 .49572 L
.6895 .49624 L
.68973 .4966 L
.68996 .49765 L
.6902 .498 L
.69043 .49838 L
.69066 .49871 L
.69089 .49982 L
.69113 .50064 L
.69136 .50174 L
.69159 .50274 L
.69182 .5042 L
.69206 .50526 L
.69229 .5062 L
.69252 .50656 L
.69275 .50689 L
.69299 .50721 L
.69322 .50768 L
.69345 .50796 L
.69368 .50791 L
.69392 .50794 L
.69415 .50758 L
.69438 .50696 L
.69461 .5054 L
.69485 .50415 L
.69508 .50236 L
.69531 .50104 L
.69555 .49882 L
.69578 .49716 L
.69601 .4947 L
.69624 .49297 L
.69648 .49038 L
.69671 .48799 L
.69694 .48471 L
.69717 .48218 L
.69741 .47971 L
.69764 .47786 L
.69787 .4765 L
.6981 .47627 L
Mistroke
.69834 .47735 L
.69857 .47846 L
.6988 .48031 L
.69903 .48192 L
.69927 .48511 L
.6995 .48808 L
.69973 .49289 L
.69996 .49693 L
.7002 .50269 L
.70043 .50754 L
.70066 .51359 L
.70089 .51747 L
.70113 .52158 L
.70136 .52495 L
.70159 .52905 L
.70182 .53138 L
.70206 .53251 L
.70229 .53328 L
.70252 .53296 L
.70275 .53124 L
.70299 .52641 L
.70322 .52273 L
.70345 .51719 L
.70368 .51208 L
.70392 .50311 L
.70415 .49644 L
.70438 .48701 L
.70461 .4789 L
.70485 .46687 L
.70508 .45873 L
.70531 .44917 L
.70554 .44229 L
.70578 .43293 L
.70601 .42755 L
.70624 .42163 L
.70647 .41755 L
.70671 .41205 L
.70694 .40994 L
.70717 .40914 L
.7074 .40949 L
.70764 .40985 L
.70787 .41179 L
.7081 .4154 L
.70833 .41835 L
.70857 .42159 L
.7088 .42503 L
.70903 .4305 L
.70926 .43482 L
.7095 .43958 L
.70973 .44299 L
Mistroke
.70996 .44707 L
.71019 .44935 L
.71043 .45148 L
.71066 .45248 L
.71089 .45381 L
.71112 .45459 L
.71136 .45513 L
.71159 .45474 L
.71182 .45328 L
.71205 .45143 L
.71229 .44874 L
.71252 .44618 L
.71275 .44287 L
.71298 .44044 L
.71322 .43763 L
.71345 .43571 L
.71368 .43307 L
.71391 .43116 L
.71415 .42867 L
.71438 .4271 L
.71461 .42523 L
.71484 .424 L
.71508 .42263 L
.71531 .42229 L
.71554 .42242 L
.71577 .42306 L
.71601 .42375 L
.71624 .42454 L
.71647 .42541 L
.7167 .42597 L
.71694 .42656 L
.71717 .42698 L
.7174 .42801 L
.71763 .4292 L
.71787 .43097 L
.7181 .4319 L
.71833 .43277 L
.71856 .43335 L
.7188 .43448 L
.71903 .43475 L
.71926 .43536 L
.71949 .43634 L
.71973 .4385 L
.71996 .43942 L
.72019 .44016 L
.72042 .44084 L
.72066 .44276 L
.72089 .44359 L
.72112 .44487 L
.72135 .44652 L
Mistroke
.72159 .44993 L
.72182 .45171 L
.72205 .45349 L
.72228 .45496 L
.72252 .45809 L
.72275 .45982 L
.72298 .46221 L
.72321 .46478 L
.72345 .46931 L
.72368 .4718 L
.72391 .47408 L
.72414 .47568 L
.72438 .47878 L
.72461 .48017 L
.72484 .48201 L
.72507 .48392 L
.72531 .48766 L
.72554 .48949 L
.72577 .49103 L
.726 .49206 L
.72624 .49442 L
.72647 .49546 L
.7267 .49679 L
.72693 .49838 L
.72717 .50149 L
.7274 .50312 L
.72763 .50428 L
.72786 .50496 L
.7281 .50652 L
.72833 .50708 L
.72856 .50777 L
.72879 .5086 L
.72903 .5105 L
.72926 .51145 L
.72949 .51214 L
.72972 .5125 L
.72996 .51346 L
.73019 .51394 L
.73042 .51461 L
.73065 .51544 L
.73089 .51686 L
.73112 .51776 L
.73135 .51829 L
.73158 .51844 L
.73182 .51858 L
.73205 .51844 L
.73228 .51822 L
.73251 .51798 L
.73275 .51783 L
.73298 .51766 L
Mistroke
.73321 .51736 L
.73344 .51702 L
.73368 .51652 L
.73391 .51626 L
.73414 .51595 L
.73438 .51578 L
.73461 .51536 L
.73484 .51524 L
.73507 .51488 L
.73531 .51446 L
.73554 .51351 L
.73577 .51287 L
.736 .51203 L
.73624 .51112 L
.73647 .50977 L
.7367 .50898 L
.73693 .50828 L
.73717 .50775 L
.7374 .50687 L
.73763 .50662 L
.73786 .50641 L
.7381 .50628 L
.73833 .50563 L
.73856 .5055 L
.73879 .50527 L
.73903 .50499 L
.73926 .50407 L
.73949 .50349 L
.73972 .50273 L
.73996 .50187 L
.74019 .50044 L
.74042 .49948 L
.74065 .49858 L
.74089 .49791 L
.74112 .49693 L
.74135 .49648 L
.74158 .49608 L
.74182 .49593 L
.74205 .49547 L
.74228 .49529 L
.74251 .49497 L
.74275 .49473 L
.74298 .49425 L
.74321 .4939 L
.74344 .49358 L
.74368 .49335 L
.74391 .49318 L
.74414 .49294 L
.74437 .49282 L
.74461 .49281 L
Mistroke
.74484 .49314 L
.74507 .49347 L
.7453 .4942 L
.74554 .4952 L
.74577 .49671 L
.746 .49764 L
.74623 .49845 L
.74647 .49902 L
.7467 .50001 L
.74693 .50039 L
.74716 .50102 L
.7474 .50178 L
.74763 .50333 L
.74786 .50393 L
.74809 .50442 L
.74833 .5048 L
.74856 .50602 L
.74879 .50658 L
.74902 .50757 L
.74926 .509 L
.74949 .51164 L
.74972 .51301 L
.74995 .51404 L
.75019 .51477 L
.75042 .51648 L
.75065 .51715 L
.75088 .51821 L
.75112 .51959 L
.75135 .52251 L
.75158 .5239 L
.75181 .52514 L
.75205 .52607 L
.75228 .52838 L
.75251 .52957 L
.75274 .5314 L
.75298 .53365 L
.75321 .53768 L
.75344 .53991 L
.75367 .54178 L
.75391 .54305 L
.75414 .54557 L
.75437 .54663 L
.7546 .54812 L
.75484 .54984 L
.75507 .5533 L
.7553 .55496 L
.75553 .55632 L
.75577 .55723 L
.756 .55948 L
.75623 .56049 L
Mistroke
.75646 .56196 L
.7567 .56385 L
.75693 .56741 L
.75716 .56931 L
.75739 .57073 L
.75763 .57162 L
.75786 .57358 L
.75809 .5743 L
.75832 .5753 L
.75856 .57652 L
.75879 .57923 L
.75902 .58055 L
.75925 .58161 L
.75949 .5823 L
.75972 .58403 L
.75995 .58488 L
.76018 .5861 L
.76042 .5876 L
.76065 .59033 L
.76088 .59191 L
.76111 .59313 L
.76135 .59385 L
.76158 .59515 L
.76181 .59562 L
.76204 .5962 L
.76228 .59681 L
.76251 .59823 L
.76274 .59889 L
.76297 .59936 L
.76321 .59955 L
.76344 .60017 L
.76367 .60044 L
.7639 .60082 L
.76414 .60135 L
.76437 .6023 L
.7646 .6029 L
.76483 .60322 L
.76507 .60329 L
.7653 .60332 L
.76553 .60318 L
.76576 .60292 L
.766 .60265 L
.76623 .60239 L
.76646 .60217 L
.76669 .60186 L
.76693 .60152 L
.76716 .60102 L
.76739 .60076 L
.76762 .60045 L
.76786 .60022 L
Mistroke
.76809 .59976 L
.76832 .59964 L
.76855 .59943 L
.76879 .59921 L
.76902 .5986 L
.76925 .59828 L
.76948 .59779 L
.76972 .59723 L
.76995 .59622 L
.77018 .59567 L
.77041 .59517 L
.77065 .59474 L
.77088 .5939 L
.77111 .5935 L
.77134 .59299 L
.77158 .59243 L
.77181 .59136 L
.77204 .59086 L
.77227 .59046 L
.77251 .59016 L
.77274 .5894 L
.77297 .58909 L
.7732 .58861 L
.77344 .58803 L
.77367 .58685 L
.7739 .58622 L
.77414 .58565 L
.77437 .58522 L
.7746 .5843 L
.77483 .58379 L
.77507 .58309 L
.7753 .58233 L
.77553 .58102 L
.77576 .58029 L
.776 .57972 L
.77623 .57939 L
.77646 .57876 L
.77669 .57854 L
.77693 .57822 L
.77716 .57786 L
.77739 .57709 L
.77762 .57677 L
.77786 .5766 L
.77809 .57656 L
.77832 .57628 L
.77855 .57617 L
.77879 .57594 L
.77902 .57553 L
.77925 .5748 L
.77948 .57443 L
Mistroke
.77972 .57433 L
.77995 .57439 L
.78018 .57437 L
.78041 .5745 L
.78065 .57453 L
.78088 .57439 L
.78111 .57395 L
.78134 .57382 L
.78158 .57384 L
.78181 .57394 L
.78204 .57384 L
.78227 .5738 L
.78251 .5735 L
.78274 .57288 L
.78297 .57187 L
.7832 .57127 L
.78344 .57092 L
.78367 .57078 L
.7839 .57046 L
.78413 .57051 L
.78437 .57041 L
.7846 .57009 L
.78483 .5692 L
.78506 .56886 L
.7853 .56858 L
.78553 .56829 L
.78576 .56744 L
.78599 .56708 L
.78623 .56651 L
.78646 .56561 L
.78669 .56385 L
.78692 .56292 L
.78716 .56215 L
.78739 .56152 L
.78762 .56008 L
.78785 .55951 L
.78809 .5587 L
.78832 .55791 L
.78855 .55591 L
.78878 .55485 L
.78902 .55345 L
.78925 .55228 L
.78948 .54988 L
.78971 .54817 L
.78995 .54587 L
.79018 .54371 L
.79041 .54059 L
.79064 .53849 L
.79088 .53652 L
.79111 .53531 L
Mistroke
.79134 .53386 L
.79157 .53328 L
.79181 .53283 L
.79204 .53267 L
.79227 .53238 L
.7925 .53256 L
.79274 .53323 L
.79297 .534 L
.7932 .53505 L
.79343 .53597 L
.79367 .53722 L
.7939 .53809 L
.79413 .53925 L
.79436 .5404 L
.7946 .54212 L
.79483 .54339 L
.79506 .54475 L
.79529 .54544 L
.79553 .54608 L
.79576 .54575 L
.79599 .54535 L
.79622 .54495 L
.79646 .54543 L
.79669 .54685 L
.79692 .54853 L
.79715 .54992 L
.79739 .55007 L
.79762 .55051 L
.79785 .54983 L
.79808 .54884 L
.79832 .54592 L
.79855 .54239 L
.79878 .53799 L
.79901 .53334 L
.79925 .52842 L
.79948 .52197 L
.79971 .5167 L
.79994 .51434 L
.80018 .5171 L
.80041 .52158 L
.80064 .52858 L
.80087 .53882 L
.80111 .55127 L
.80134 .56349 L
.80157 .57212 L
.8018 .58014 L
.80204 .58327 L
.80227 .58237 L
.8025 .5731 L
.80273 .56119 L
Mistroke
.80297 .543 L
.8032 .52223 L
.80343 .49676 L
.80366 .47565 L
.8039 .45649 L
.80413 .44336 L
.80436 .43206 L
.80459 .4296 L
.80483 .43049 L
.80506 .43656 L
.80529 .44216 L
.80552 .45228 L
.80576 .46188 L
.80599 .46975 L
.80622 .47326 L
.80645 .4757 L
.80669 .47618 L
.80692 .47234 L
.80715 .46467 L
.80738 .45699 L
.80762 .4505 L
.80785 .44461 L
.80808 .43813 L
.80831 .43346 L
.80855 .42962 L
.80878 .4282 L
.80901 .42688 L
.80924 .42711 L
.80948 .42728 L
.80971 .42886 L
.80994 .43083 L
.81017 .43244 L
.81041 .43354 L
.81064 .43396 L
.81087 .43506 L
.8111 .43573 L
.81134 .43779 L
.81157 .43991 L
.8118 .44366 L
.81203 .44616 L
.81227 .44933 L
.8125 .45168 L
.81273 .45529 L
.81297 .45747 L
.8132 .46058 L
.81343 .46329 L
.81366 .46765 L
.8139 .47034 L
.81413 .47311 L
.81436 .47484 L
Mistroke
.81459 .47736 L
.81483 .4789 L
.81506 .48062 L
.81529 .48181 L
.81552 .48324 L
.81576 .48389 L
.81599 .48379 L
.81622 .4827 L
.81645 .48086 L
.81669 .47957 L
.81692 .47815 L
.81715 .47683 L
.81738 .47451 L
.81762 .47348 L
.81785 .47165 L
.81808 .46962 L
.81831 .46535 L
.81855 .46315 L
.81878 .46027 L
.81901 .45764 L
.81924 .45233 L
.81948 .4493 L
.81971 .4452 L
.81994 .44111 L
.82017 .43396 L
.82041 .42984 L
.82064 .42548 L
.82087 .42202 L
.8211 .41592 L
.82134 .41277 L
.82157 .40915 L
.8218 .40607 L
.82203 .40033 L
.82227 .39753 L
.8225 .39483 L
.82273 .39292 L
.82296 .38892 L
.8232 .38693 L
.82343 .38471 L
.82366 .38255 L
.82389 .37867 L
.82413 .37668 L
.82436 .37545 L
.82459 .37495 L
.82482 .37374 L
.82506 .37347 L
.82529 .37337 L
.82552 .37321 L
.82575 .37251 L
.82599 .37238 L
Mistroke
.82622 .37297 L
.82645 .37387 L
.82668 .37499 L
.82692 .37572 L
.82715 .37648 L
.82738 .37675 L
.82761 .37731 L
.82785 .37754 L
.82808 .37858 L
.82831 .37985 L
.82854 .38214 L
.82878 .38368 L
.82901 .38537 L
.82924 .38661 L
.82947 .38845 L
.82971 .38957 L
.82994 .39105 L
.83017 .39233 L
.8304 .39433 L
.83064 .39546 L
.83087 .39644 L
.8311 .39676 L
.83133 .39734 L
.83157 .39754 L
.8318 .39794 L
.83203 .39827 L
.83226 .39886 L
.8325 .39934 L
.83273 .39961 L
.83296 .39961 L
.83319 .39918 L
.83343 .399 L
.83366 .3985 L
.83389 .3979 L
.83412 .39654 L
.83436 .39558 L
.83459 .39404 L
.83482 .39234 L
.83505 .38959 L
.83529 .38785 L
.83552 .38598 L
.83575 .38448 L
.83598 .38204 L
.83622 .3808 L
.83645 .3793 L
.83668 .378 L
.83691 .37554 L
.83715 .37443 L
.83738 .37329 L
.83761 .37242 L
Mistroke
.83784 .37041 L
.83808 .36945 L
.83831 .36821 L
.83854 .36688 L
.83877 .36437 L
.83901 .36305 L
.83924 .36197 L
.83947 .36119 L
.8397 .35958 L
.83994 .35886 L
.84017 .35805 L
.8404 .3572 L
.84063 .35545 L
.84087 .35464 L
.8411 .35407 L
.84133 .35377 L
.84156 .3529 L
.8418 .35255 L
.84203 .35206 L
.84226 .35142 L
.84249 .35014 L
.84273 .34943 L
.84296 .34896 L
.84319 .34875 L
.84342 .34827 L
.84366 .3481 L
.84389 .34788 L
.84412 .34757 L
.84435 .34692 L
.84459 .34656 L
.84482 .3464 L
.84505 .34641 L
.84528 .34638 L
.84552 .34648 L
.84575 .34661 L
.84598 .34666 L
.84621 .34663 L
.84645 .34661 L
.84668 .34669 L
.84691 .34682 L
.84714 .34703 L
.84738 .34719 L
.84761 .3474 L
.84784 .3476 L
.84807 .34788 L
.84831 .34796 L
.84854 .34803 L
.84877 .3481 L
.849 .34833 L
.84924 .34841 L
Mistroke
.84947 .34858 L
.8497 .34885 L
.84993 .34938 L
.85017 .34959 L
.8504 .34972 L
.85063 .34982 L
.85086 .3502 L
.8511 .35035 L
.85133 .35065 L
.85156 .35111 L
.8518 .35202 L
.85203 .35247 L
.85226 .35283 L
.85249 .35311 L
.85273 .35382 L
.85296 .35415 L
.85319 .35468 L
.85342 .35539 L
.85366 .35673 L
.85389 .35742 L
.85412 .358 L
.85435 .35842 L
.85459 .35939 L
.85482 .35982 L
.85505 .36049 L
.85528 .36131 L
.85552 .36291 L
.85575 .36374 L
.85598 .36451 L
.85621 .36508 L
.85645 .3663 L
.85668 .36692 L
.85691 .36781 L
.85714 .36883 L
.85738 .37064 L
.85761 .37163 L
.85784 .37243 L
.85807 .37296 L
.85831 .37402 L
.85854 .37443 L
.85877 .375 L
.859 .37567 L
.85924 .37706 L
.85947 .37771 L
.8597 .3782 L
.85993 .37852 L
.86017 .37937 L
.8604 .37973 L
.86063 .38025 L
.86086 .38094 L
Mistroke
.8611 .38228 L
.86133 .383 L
.86156 .38348 L
.86179 .38377 L
.86203 .38443 L
.86226 .38463 L
.86249 .38494 L
.86272 .38531 L
.86296 .38625 L
.86319 .38671 L
.86342 .38714 L
.86365 .38743 L
.86389 .38812 L
.86412 .38854 L
.86435 .38914 L
.86458 .38981 L
.86482 .39089 L
.86505 .39158 L
.86528 .3921 L
.86551 .39237 L
.86575 .39271 L
.86598 .39277 L
.86621 .3928 L
.86644 .39278 L
.86668 .39291 L
.86691 .39287 L
.86714 .39277 L
.86737 .39264 L
.86761 .39255 L
.86784 .3925 L
.86807 .39246 L
.8683 .39256 L
.86854 .39266 L
.86877 .39275 L
.869 .39263 L
.86923 .39244 L
.86947 .39206 L
.8697 .39173 L
.86993 .39132 L
.87016 .39093 L
.8704 .39047 L
.87063 .39014 L
.87086 .38985 L
.87109 .38963 L
.87133 .38939 L
.87156 .38941 L
.87179 .38957 L
.87202 .38987 L
.87226 .39011 L
.87249 .39038 L
Mistroke
.87272 .39051 L
.87295 .39049 L
.87319 .39024 L
.87342 .38999 L
.87365 .3897 L
.87388 .38941 L
.87412 .38905 L
.87435 .38868 L
.87458 .3883 L
.87481 .38799 L
.87505 .38773 L
.87528 .38762 L
.87551 .38765 L
.87574 .38798 L
.87598 .38844 L
.87621 .38873 L
.87644 .38879 L
.87667 .38879 L
.87691 .38885 L
.87714 .38872 L
.87737 .3887 L
.8776 .38883 L
.87784 .38937 L
.87807 .38951 L
.8783 .38968 L
.87853 .38984 L
.87877 .39055 L
.879 .39103 L
.87923 .39193 L
.87946 .39316 L
.8797 .39511 L
.87993 .39628 L
.88016 .39723 L
.88039 .39786 L
.88063 .39899 L
.88086 .3994 L
.88109 .40006 L
.88132 .40086 L
.88156 .40258 L
.88179 .40327 L
.88202 .40384 L
.88225 .40424 L
.88249 .40554 L
.88272 .40615 L
.88295 .40719 L
.88318 .40868 L
.88342 .41136 L
.88365 .4128 L
.88388 .41387 L
.88411 .41459 L
Mistroke
.88435 .4162 L
.88458 .41678 L
.88481 .4177 L
.88504 .41888 L
.88528 .42147 L
.88551 .42267 L
.88574 .42374 L
.88597 .42451 L
.88621 .42653 L
.88644 .42758 L
.88667 .42923 L
.8869 .43127 L
.88714 .43486 L
.88737 .43689 L
.8876 .43854 L
.88783 .43963 L
.88807 .44171 L
.8883 .44254 L
.88853 .44371 L
.88876 .44504 L
.889 .44783 L
.88923 .44911 L
.88946 .45013 L
.88969 .45077 L
.88993 .45251 L
.89016 .4533 L
.89039 .4545 L
.89063 .45612 L
.89086 .45911 L
.89109 .46075 L
.89132 .46191 L
.89156 .4626 L
.89179 .46411 L
.89202 .46461 L
.89225 .46536 L
.89249 .46631 L
.89272 .46848 L
.89295 .4695 L
.89318 .47028 L
.89342 .47075 L
.89365 .4721 L
.89388 .47276 L
.89411 .4738 L
.89435 .47517 L
.89458 .47761 L
.89481 .47904 L
.89504 .48011 L
.89528 .48074 L
.89551 .48189 L
.89574 .48228 L
Mistroke
.89597 .4828 L
.89621 .48341 L
.89644 .48482 L
.89667 .48545 L
.8969 .48588 L
.89714 .48608 L
.89737 .48678 L
.8976 .48706 L
.89783 .4875 L
.89807 .48817 L
.8983 .48946 L
.89853 .49022 L
.89876 .49073 L
.899 .49101 L
.89923 .49153 L
.89946 .49167 L
.89969 .49181 L
.89993 .49199 L
.90016 .49255 L
.90039 .4928 L
.90062 .493 L
.90086 .49308 L
.90109 .49338 L
.90132 .49355 L
.90155 .4938 L
.90179 .49409 L
.90202 .49457 L
.90225 .49495 L
.90248 .49526 L
.90272 .49543 L
.90295 .49553 L
.90318 .49556 L
.90341 .49549 L
.90365 .49531 L
.90388 .495 L
.90411 .49481 L
.90434 .4946 L
.90458 .49438 L
.90481 .49395 L
.90504 .49369 L
.90527 .4933 L
.90551 .49286 L
.90574 .49209 L
.90597 .49172 L
.9062 .49135 L
.90644 .49106 L
.90667 .49042 L
.9069 .49012 L
.90713 .48963 L
.90737 .48905 L
Mistroke
.9076 .48795 L
.90783 .4874 L
.90806 .48691 L
.9083 .48653 L
.90853 .48567 L
.90876 .48526 L
.90899 .48467 L
.90923 .48395 L
.90946 .48261 L
.90969 .48193 L
.90992 .4814 L
.91016 .48103 L
.91039 .48016 L
.91062 .4798 L
.91085 .47926 L
.91109 .47859 L
.91132 .47721 L
.91155 .47653 L
.91178 .47594 L
.91202 .47552 L
.91225 .47451 L
.91248 .474 L
.91271 .47324 L
.91295 .47232 L
.91318 .4707 L
.91341 .4698 L
.91364 .46911 L
.91388 .46868 L
.91411 .46781 L
.91434 .46749 L
.91457 .46701 L
.91481 .46644 L
.91504 .46521 L
.91527 .46465 L
.9155 .46425 L
.91574 .46401 L
.91597 .46332 L
.9162 .46303 L
.91643 .46256 L
.91667 .46188 L
.9169 .46061 L
.91713 .45992 L
.91736 .45947 L
.9176 .45923 L
.91783 .45865 L
.91806 .45849 L
.91829 .45822 L
.91853 .45783 L
.91876 .45688 L
.91899 .45643 L
Mistroke
.91922 .45608 L
.91946 .45586 L
.91969 .45522 L
.91992 .45489 L
.92015 .45437 L
.92039 .45368 L
.92062 .45248 L
.92085 .45177 L
.92108 .45121 L
.92132 .45088 L
.92155 .45029 L
.92178 .45009 L
.92201 .44983 L
.92225 .44954 L
.92248 .44885 L
.92271 .44855 L
.92294 .44831 L
.92318 .44816 L
.92341 .44773 L
.92364 .44752 L
.92387 .44721 L
.92411 .4468 L
.92434 .44606 L
.92457 .44562 L
.9248 .44531 L
.92504 .44513 L
.92527 .44483 L
.9255 .44475 L
.92573 .44467 L
.92597 .44461 L
.9262 .44434 L
.92643 .44424 L
.92666 .44415 L
.9269 .44412 L
.92713 .44394 L
.92736 .44381 L
.92759 .44361 L
.92783 .44336 L
.92806 .44302 L
.92829 .44276 L
.92852 .4426 L
.92876 .44255 L
.92899 .44259 L
.92922 .44267 L
.92945 .44281 L
.92969 .44299 L
.92992 .44324 L
.93015 .44345 L
.93039 .44371 L
.93062 .44395 L
Mistroke
.93085 .44429 L
.93108 .44448 L
.93132 .44469 L
.93155 .44481 L
.93178 .44504 L
.93201 .44515 L
.93225 .44533 L
.93248 .4455 L
.93271 .44583 L
.93294 .44603 L
.93318 .44627 L
.93341 .44648 L
.93364 .44678 L
.93387 .44697 L
.93411 .44714 L
.93434 .44728 L
.93457 .44747 L
.9348 .44753 L
.93504 .44751 L
.93527 .44744 L
.9355 .44738 L
.93573 .44729 L
.93597 .44719 L
.9362 .44712 L
.93643 .44706 L
.93666 .44702 L
.9369 .44695 L
.93713 .44686 L
.93736 .44674 L
.93759 .44671 L
.93783 .44671 L
.93806 .44672 L
.93829 .44668 L
.93852 .44672 L
.93876 .44672 L
.93899 .44665 L
.93922 .44643 L
.93945 .44635 L
.93969 .44626 L
.93992 .44616 L
.94015 .44586 L
.94038 .4457 L
.94062 .44545 L
.94085 .44512 L
.94108 .44454 L
.94131 .44421 L
.94155 .44391 L
.94178 .44369 L
.94201 .44325 L
.94224 .44307 L
Mistroke
.94248 .44282 L
.94271 .44257 L
.94294 .442 L
.94317 .44171 L
.94341 .44134 L
.94364 .44101 L
.94387 .44035 L
.9441 .43994 L
.94434 .43946 L
.94457 .43896 L
.9448 .43817 L
.94503 .43769 L
.94527 .43726 L
.9455 .43696 L
.94573 .43649 L
.94596 .43637 L
.9462 .43632 L
.94643 .43639 L
.94666 .43625 L
.94689 .43625 L
.94713 .43612 L
.94736 .43595 L
.94759 .43555 L
.94782 .43523 L
.94806 .43491 L
.94829 .43465 L
.94852 .43438 L
.94875 .43408 L
.94899 .43381 L
.94922 .43365 L
.94945 .43366 L
.94968 .43373 L
.94992 .43402 L
.95015 .43461 L
.95038 .4355 L
.95061 .43603 L
.95085 .43637 L
.95108 .4366 L
.95131 .43707 L
.95154 .43716 L
.95178 .43743 L
.95201 .43784 L
.95224 .4389 L
.95247 .43929 L
.95271 .43972 L
.95294 .44008 L
.95317 .44122 L
.9534 .44191 L
.95364 .44309 L
.95387 .4446 L
Mistroke
.9541 .44708 L
.95433 .44852 L
.95457 .44969 L
.9548 .45048 L
.95503 .45196 L
.95526 .45254 L
.9555 .45345 L
.95573 .45452 L
.95596 .45672 L
.95619 .45764 L
.95643 .45834 L
.95666 .45877 L
.95689 .4602 L
.95712 .46085 L
.95736 .46202 L
.95759 .46371 L
.95782 .46676 L
.95805 .46838 L
.95829 .4695 L
.95852 .47019 L
.95875 .47181 L
.95898 .47236 L
.95922 .47334 L
.95945 .47474 L
.95968 .47767 L
.95991 .47901 L
.96015 .47999 L
.96038 .48063 L
.96061 .48252 L
.96084 .48333 L
.96108 .48477 L
.96131 .48684 L
.96154 .49073 L
.96177 .49283 L
.96201 .49447 L
.96224 .49558 L
.96247 .49803 L
.9627 .499 L
.96294 .5005 L
.96317 .50238 L
.9634 .5063 L
.96363 .50827 L
.96387 .51003 L
.9641 .51134 L
.96433 .5143 L
.96456 .51572 L
.9648 .51774 L
.96503 .52011 L
.96526 .52456 L
.96549 .52703 L
Mistroke
.96573 .52919 L
.96596 .53073 L
.96619 .53372 L
.96642 .53502 L
.96666 .53662 L
.96689 .53821 L
.96712 .54163 L
.96735 .54339 L
.96759 .54509 L
.96782 .54633 L
.96805 .54891 L
.96828 .55027 L
.96852 .55189 L
.96875 .55346 L
.96898 .55624 L
.96922 .55791 L
.96945 .55929 L
.96968 .56012 L
.96991 .56141 L
.97015 .56192 L
.97038 .56226 L
.97061 .56227 L
.97084 .56256 L
.97108 .56263 L
.97131 .56256 L
.97154 .56227 L
.97177 .5618 L
.97201 .56164 L
.97224 .56128 L
.97247 .56082 L
.9727 .55967 L
.97294 .55923 L
.97317 .5584 L
.9734 .55744 L
.97363 .55523 L
.97387 .55397 L
.9741 .55218 L
.97433 .55029 L
.97456 .54686 L
.9748 .54488 L
.97503 .5426 L
.97526 .5406 L
.97549 .53703 L
.97573 .53512 L
.97596 .53286 L
.97619 .53089 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],

Cell[TextData[{
  "Here we use a different threshold (",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 3\)], "InlineFormula",
    CellTags->"S2.1.2"],
  ") with shrinking."
}], "MathCaption",
  CellTags->{"S2.1.2", "2.16"}],

Cell["Compress[Rest[wtdata], 3, Shrinking -> True];", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.2"],

Cell["A larger threshold produces a smoother signal.", "MathCaption",
  CellTags->{"S2.1.2", "2.17"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[InverseWaveletTransform[
Join[{wtdata[[1]]}, %], s4], PlotJoined -> True,
AxesLabel -> {\"x\", \"u(x)\"}]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.392422 0.142774 [
[.25632 .37992 -12 -9 ]
[.25632 .37992 12 0 ]
[.48884 .37992 -12 -9 ]
[.48884 .37992 12 0 ]
[.72135 .37992 -12 -9 ]
[.72135 .37992 12 0 ]
[.95387 .37992 -12 -9 ]
[.95387 .37992 12 0 ]
[1.025 .39242 0 -4.5 ]
[1.025 .39242 6 4.5 ]
[.01131 .10687 -12 -4.5 ]
[.01131 .10687 0 4.5 ]
[.01131 .24965 -12 -4.5 ]
[.01131 .24965 0 4.5 ]
[.01131 .5352 -6 -4.5 ]
[.01131 .5352 0 4.5 ]
[.02381 .64303 -12 0 ]
[.02381 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 .39242 m
.25632 .39867 L
s
[(1000)] .25632 .37992 0 1 Mshowa
.48884 .39242 m
.48884 .39867 L
s
[(2000)] .48884 .37992 0 1 Mshowa
.72135 .39242 m
.72135 .39867 L
s
[(3000)] .72135 .37992 0 1 Mshowa
.95387 .39242 m
.95387 .39867 L
s
[(4000)] .95387 .37992 0 1 Mshowa
.125 Mabswid
.07031 .39242 m
.07031 .39617 L
s
.11682 .39242 m
.11682 .39617 L
s
.16332 .39242 m
.16332 .39617 L
s
.20982 .39242 m
.20982 .39617 L
s
.30283 .39242 m
.30283 .39617 L
s
.34933 .39242 m
.34933 .39617 L
s
.39583 .39242 m
.39583 .39617 L
s
.44234 .39242 m
.44234 .39617 L
s
.53534 .39242 m
.53534 .39617 L
s
.58185 .39242 m
.58185 .39617 L
s
.62835 .39242 m
.62835 .39617 L
s
.67485 .39242 m
.67485 .39617 L
s
.76786 .39242 m
.76786 .39617 L
s
.81436 .39242 m
.81436 .39617 L
s
.86086 .39242 m
.86086 .39617 L
s
.90737 .39242 m
.90737 .39617 L
s
.25 Mabswid
0 .39242 m
1 .39242 L
s
[(x)] 1.025 .39242 -1 0 Mshowa
.02381 .10687 m
.03006 .10687 L
s
[(-2)] .01131 .10687 1 0 Mshowa
.02381 .24965 m
.03006 .24965 L
s
[(-1)] .01131 .24965 1 0 Mshowa
.02381 .5352 m
.03006 .5352 L
s
[(1)] .01131 .5352 1 0 Mshowa
.125 Mabswid
.02381 .13543 m
.02756 .13543 L
s
.02381 .16398 m
.02756 .16398 L
s
.02381 .19254 m
.02756 .19254 L
s
.02381 .22109 m
.02756 .22109 L
s
.02381 .2782 m
.02756 .2782 L
s
.02381 .30676 m
.02756 .30676 L
s
.02381 .33531 m
.02756 .33531 L
s
.02381 .36387 m
.02756 .36387 L
s
.02381 .42098 m
.02756 .42098 L
s
.02381 .44953 m
.02756 .44953 L
s
.02381 .47809 m
.02756 .47809 L
s
.02381 .50664 m
.02756 .50664 L
s
.02381 .07832 m
.02756 .07832 L
s
.02381 .04976 m
.02756 .04976 L
s
.02381 .02121 m
.02756 .02121 L
s
.02381 .56375 m
.02756 .56375 L
s
.02381 .59231 m
.02756 .59231 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02404 .5065 m
.02427 .50628 L
.02451 .50608 L
.02474 .50595 L
.02497 .50574 L
.0252 .50566 L
.02544 .50556 L
.02567 .50547 L
.0259 .50526 L
.02613 .5052 L
.02637 .50516 L
.0266 .50514 L
.02683 .50502 L
.02706 .50497 L
.0273 .50489 L
.02753 .50474 L
.02776 .50447 L
.02799 .50434 L
.02823 .50429 L
.02846 .50428 L
.02869 .5042 L
.02892 .50421 L
.02916 .50418 L
.02939 .50411 L
.02962 .50388 L
.02985 .50378 L
.03009 .5037 L
.03032 .50364 L
.03055 .50344 L
.03078 .50329 L
.03102 .50303 L
.03125 .50269 L
.03148 .50217 L
.03172 .50185 L
.03195 .50163 L
.03218 .50151 L
.03241 .50134 L
.03265 .50132 L
.03288 .50126 L
.03311 .50116 L
.03334 .50088 L
.03358 .50081 L
.03381 .5008 L
.03404 .50081 L
.03427 .50065 L
.03451 .5006 L
.03474 .50046 L
.03497 .50016 L
.0352 .49961 L
.03544 .49932 L
Mistroke
.03567 .49915 L
.0359 .49905 L
.03613 .49876 L
.03637 .49869 L
.0366 .49853 L
.03683 .4983 L
.03706 .49769 L
.0373 .49741 L
.03753 .4971 L
.03776 .49685 L
.03799 .49624 L
.03823 .49584 L
.03846 .49522 L
.03869 .49451 L
.03892 .49337 L
.03916 .49268 L
.03939 .49209 L
.03962 .49173 L
.03985 .49113 L
.04009 .49092 L
.04032 .49063 L
.04055 .49034 L
.04078 .48968 L
.04102 .48944 L
.04125 .4893 L
.04148 .48922 L
.04171 .48884 L
.04195 .48869 L
.04218 .48843 L
.04241 .48798 L
.04264 .48714 L
.04288 .4867 L
.04311 .48647 L
.04334 .48635 L
.04357 .48601 L
.04381 .48596 L
.04404 .48582 L
.04427 .48558 L
.0445 .48489 L
.04474 .4846 L
.04497 .48432 L
.0452 .48412 L
.04543 .48353 L
.04567 .48314 L
.0459 .48249 L
.04613 .48168 L
.04636 .48042 L
.0466 .47963 L
.04683 .47902 L
.04706 .47867 L
Mistroke
.04729 .47813 L
.04753 .47798 L
.04776 .47776 L
.04799 .47749 L
.04822 .47682 L
.04846 .47662 L
.04869 .47653 L
.04892 .4765 L
.04915 .47616 L
.04939 .47604 L
.04962 .47577 L
.04985 .47523 L
.05008 .47424 L
.05032 .47371 L
.05055 .47343 L
.05078 .47328 L
.05101 .47285 L
.05125 .47279 L
.05148 .47261 L
.05171 .47231 L
.05194 .47142 L
.05218 .47104 L
.05241 .47064 L
.05264 .47033 L
.05287 .46948 L
.05311 .46893 L
.05334 .46803 L
.05357 .46694 L
.0538 .46523 L
.05404 .46417 L
.05427 .4633 L
.0545 .46276 L
.05473 .46192 L
.05497 .46164 L
.0552 .46126 L
.05543 .46085 L
.05566 .45991 L
.0559 .45959 L
.05613 .45939 L
.05636 .4593 L
.05659 .45877 L
.05683 .45856 L
.05706 .45816 L
.05729 .45746 L
.05752 .45619 L
.05776 .4555 L
.05799 .45514 L
.05822 .45496 L
.05845 .45446 L
.05869 .4544 L
Mistroke
.05892 .45422 L
.05915 .4539 L
.05938 .45292 L
.05962 .45252 L
.05985 .45215 L
.06008 .45188 L
.06031 .45102 L
.06055 .45046 L
.06078 .44952 L
.06101 .44832 L
.06124 .44642 L
.06148 .44524 L
.06171 .44432 L
.06194 .44378 L
.06217 .44291 L
.06241 .44265 L
.06264 .44225 L
.06287 .4418 L
.0631 .44071 L
.06334 .44034 L
.06357 .44012 L
.0638 .44001 L
.06403 .43939 L
.06427 .43912 L
.0645 .43862 L
.06473 .43773 L
.06496 .43616 L
.0652 .43529 L
.06543 .43479 L
.06566 .43452 L
.06589 .43385 L
.06613 .43373 L
.06636 .43345 L
.06659 .433 L
.06682 .43174 L
.06706 .43121 L
.06729 .43073 L
.06752 .43037 L
.06775 .42928 L
.06799 .4286 L
.06822 .42748 L
.06845 .42605 L
.06868 .42373 L
.06892 .42231 L
.06915 .42118 L
.06938 .42048 L
.06961 .41932 L
.06985 .41892 L
.07008 .41835 L
.07031 .41771 L
Mistroke
.07055 .41624 L
.07078 .41568 L
.07101 .41528 L
.07124 .41506 L
.07148 .41416 L
.07171 .41376 L
.07194 .41305 L
.07217 .41195 L
.07241 .40998 L
.07264 .40889 L
.07287 .40821 L
.0731 .40782 L
.07334 .40693 L
.07357 .40672 L
.0738 .40634 L
.07403 .40578 L
.07427 .40429 L
.0745 .40367 L
.07473 .40314 L
.07496 .40279 L
.0752 .40164 L
.07543 .40098 L
.07566 .39988 L
.07589 .39843 L
.07613 .39601 L
.07636 .39456 L
.07659 .39342 L
.07682 .39273 L
.07706 .39152 L
.07729 .39111 L
.07752 .3905 L
.07775 .38981 L
.07799 .38823 L
.07822 .38759 L
.07845 .38713 L
.07868 .38687 L
.07892 .38592 L
.07915 .3855 L
.07938 .38477 L
.07961 .38366 L
.07985 .38166 L
.08008 .38054 L
.08031 .3798 L
.08054 .37936 L
.08078 .37842 L
.08101 .37816 L
.08124 .37773 L
.08147 .37714 L
.08171 .37567 L
.08194 .37503 L
Mistroke
.08217 .3745 L
.0824 .37416 L
.08264 .3731 L
.08287 .37252 L
.0831 .37157 L
.08333 .37034 L
.08357 .36821 L
.0838 .36693 L
.08403 .36592 L
.08426 .36529 L
.0845 .36419 L
.08473 .36378 L
.08496 .36323 L
.08519 .36261 L
.08543 .36123 L
.08566 .36065 L
.08589 .36021 L
.08612 .35996 L
.08636 .35917 L
.08659 .35883 L
.08682 .35826 L
.08705 .35745 L
.08729 .35594 L
.08752 .35508 L
.08775 .35449 L
.08798 .35414 L
.08822 .35343 L
.08845 .35321 L
.08868 .35291 L
.08891 .35252 L
.08915 .35156 L
.08938 .35113 L
.08961 .35079 L
.08984 .3506 L
.09008 .34999 L
.09031 .34969 L
.09054 .3492 L
.09077 .34856 L
.09101 .34741 L
.09124 .34671 L
.09147 .34615 L
.0917 .34581 L
.09194 .34524 L
.09217 .34502 L
.0924 .34476 L
.09263 .34451 L
.09287 .34394 L
.0931 .34369 L
.09333 .34352 L
.09356 .34346 L
Mistroke
.0938 .34324 L
.09403 .34317 L
.09426 .34307 L
.09449 .34291 L
.09473 .34256 L
.09496 .34234 L
.09519 .34221 L
.09542 .34215 L
.09566 .34206 L
.09589 .34205 L
.09612 .34209 L
.09635 .34214 L
.09659 .34217 L
.09682 .34219 L
.09705 .34225 L
.09728 .34233 L
.09752 .34248 L
.09775 .34258 L
.09798 .34273 L
.09821 .3429 L
.09845 .34317 L
.09868 .34328 L
.09891 .34336 L
.09914 .34341 L
.09938 .34359 L
.09961 .34364 L
.09984 .34376 L
.10007 .34396 L
.10031 .34439 L
.10054 .34458 L
.10077 .34473 L
.101 .34487 L
.10124 .34528 L
.10147 .3455 L
.1017 .34586 L
.10193 .34636 L
.10217 .3472 L
.1024 .34764 L
.10263 .34797 L
.10286 .34817 L
.1031 .34866 L
.10333 .34882 L
.10356 .34912 L
.10379 .34952 L
.10403 .3504 L
.10426 .3508 L
.10449 .35116 L
.10472 .35142 L
.10496 .35213 L
.10519 .35253 L
Mistroke
.10542 .35317 L
.10565 .35399 L
.10589 .35537 L
.10612 .35614 L
.10635 .35671 L
.10658 .35705 L
.10682 .35775 L
.10705 .35795 L
.10728 .35831 L
.10751 .35877 L
.10775 .35985 L
.10798 .36028 L
.10821 .36061 L
.10844 .36083 L
.10868 .36158 L
.10891 .36194 L
.10914 .36255 L
.10938 .36344 L
.10961 .36502 L
.10984 .36588 L
.11007 .36649 L
.11031 .36686 L
.11054 .36768 L
.11077 .36793 L
.111 .36838 L
.11124 .36896 L
.11147 .37031 L
.1117 .37093 L
.11193 .37148 L
.11217 .37187 L
.1124 .37292 L
.11263 .37352 L
.11286 .37448 L
.1131 .37568 L
.11333 .37768 L
.11356 .37886 L
.11379 .37976 L
.11403 .3803 L
.11426 .38126 L
.11449 .38156 L
.11472 .38201 L
.11496 .38255 L
.11519 .38382 L
.11542 .38432 L
.11565 .38464 L
.11589 .38483 L
.11612 .3856 L
.11635 .38594 L
.11658 .38652 L
.11682 .38745 L
Mistroke
.11705 .38914 L
.11728 .39007 L
.11751 .39068 L
.11775 .39103 L
.11798 .39183 L
.11821 .39205 L
.11844 .39243 L
.11868 .39296 L
.11891 .39429 L
.11914 .39489 L
.11937 .39544 L
.11961 .39582 L
.11984 .39688 L
.12007 .39752 L
.1203 .39854 L
.12054 .3998 L
.12077 .40185 L
.121 .4031 L
.12123 .40409 L
.12147 .40467 L
.1217 .40562 L
.12193 .40591 L
.12216 .40632 L
.1224 .40677 L
.12263 .40786 L
.12286 .40823 L
.12309 .40843 L
.12333 .40849 L
.12356 .40903 L
.12379 .40921 L
.12402 .40959 L
.12426 .41031 L
.12449 .41165 L
.12472 .41239 L
.12495 .41278 L
.12519 .41298 L
.12542 .41351 L
.12565 .41359 L
.12588 .41379 L
.12612 .41414 L
.12635 .41516 L
.12658 .41561 L
.12681 .41603 L
.12705 .41633 L
.12728 .41723 L
.12751 .4178 L
.12774 .41875 L
.12798 .41991 L
.12821 .42175 L
.12844 .42292 L
Mistroke
.12867 .42387 L
.12891 .42444 L
.12914 .42529 L
.12937 .42556 L
.1296 .42593 L
.12984 .42629 L
.13007 .4272 L
.1303 .42748 L
.13053 .42764 L
.13077 .4277 L
.131 .42817 L
.13123 .42835 L
.13146 .42868 L
.1317 .42931 L
.13193 .43047 L
.13216 .43111 L
.13239 .43142 L
.13263 .43157 L
.13286 .43198 L
.13309 .43199 L
.13332 .43207 L
.13356 .43226 L
.13379 .43303 L
.13402 .43333 L
.13425 .43366 L
.13449 .43391 L
.13472 .43472 L
.13495 .43529 L
.13518 .43621 L
.13542 .43733 L
.13565 .43903 L
.13588 .44014 L
.13611 .44104 L
.13635 .44156 L
.13658 .44229 L
.13681 .4425 L
.13704 .44277 L
.13728 .44301 L
.13751 .44367 L
.13774 .44381 L
.13797 .44385 L
.13821 .44381 L
.13844 .44411 L
.13867 .44424 L
.1389 .44454 L
.13914 .44518 L
.13937 .44623 L
.1396 .44682 L
.13983 .44704 L
.14007 .44707 L
Mistroke
.1403 .44724 L
.14053 .4471 L
.14076 .44703 L
.141 .44712 L
.14123 .44771 L
.14146 .44785 L
.14169 .44793 L
.14193 .44796 L
.14216 .44849 L
.14239 .44887 L
.14262 .44968 L
.14286 .45085 L
.14309 .45266 L
.14332 .4538 L
.14355 .45463 L
.14379 .45509 L
.14402 .45585 L
.14425 .45602 L
.14448 .45638 L
.14472 .45688 L
.14495 .4581 L
.14518 .4585 L
.14541 .45875 L
.14565 .45889 L
.14588 .45971 L
.14611 .46007 L
.14634 .46081 L
.14658 .46205 L
.14681 .46427 L
.14704 .46549 L
.14727 .46634 L
.14751 .4669 L
.14774 .46816 L
.14797 .46856 L
.1482 .46927 L
.14844 .47023 L
.14867 .47242 L
.1489 .47342 L
.14914 .47434 L
.14937 .47502 L
.1496 .47685 L
.14983 .47785 L
.15007 .47945 L
.1503 .48142 L
.15053 .48483 L
.15076 .48681 L
.151 .48847 L
.15123 .4896 L
.15146 .49167 L
.15169 .49253 L
Mistroke
.15193 .49372 L
.15216 .49503 L
.15239 .49771 L
.15262 .49893 L
.15286 .49988 L
.15309 .50048 L
.15332 .50214 L
.15355 .50284 L
.15379 .50392 L
.15402 .5054 L
.15425 .50823 L
.15448 .50975 L
.15472 .51083 L
.15495 .51152 L
.15518 .51306 L
.15541 .51363 L
.15565 .51444 L
.15588 .51548 L
.15611 .51775 L
.15634 .51885 L
.15658 .51973 L
.15681 .52029 L
.15704 .52174 L
.15727 .52243 L
.15751 .52348 L
.15774 .52479 L
.15797 .52721 L
.1582 .52861 L
.15844 .52972 L
.15867 .53041 L
.1589 .5317 L
.15913 .53221 L
.15937 .53287 L
.1596 .53359 L
.15983 .53512 L
.16006 .53588 L
.1603 .53646 L
.16053 .53679 L
.16076 .5376 L
.16099 .53792 L
.16123 .53834 L
.16146 .53887 L
.16169 .53994 L
.16192 .54056 L
.16216 .54099 L
.16239 .54123 L
.16262 .54166 L
.16285 .54176 L
.16309 .54178 L
.16332 .54175 L
Mistroke
.16355 .54194 L
.16378 .54204 L
.16402 .54214 L
.16425 .5422 L
.16448 .54231 L
.16471 .54241 L
.16495 .54245 L
.16518 .54238 L
.16541 .54221 L
.16564 .54225 L
.16588 .5423 L
.16611 .54229 L
.16634 .54197 L
.16657 .54184 L
.16681 .54149 L
.16704 .54086 L
.16727 .5397 L
.1675 .53911 L
.16774 .53861 L
.16797 .53815 L
.1682 .5371 L
.16843 .53667 L
.16867 .53598 L
.1689 .53509 L
.16913 .53324 L
.16936 .53235 L
.1696 .53144 L
.16983 .53066 L
.17006 .52887 L
.17029 .52796 L
.17053 .52665 L
.17076 .5252 L
.17099 .52244 L
.17122 .5209 L
.17146 .51933 L
.17169 .51809 L
.17192 .51573 L
.17215 .51447 L
.17239 .51287 L
.17262 .51134 L
.17285 .50857 L
.17308 .50706 L
.17332 .50561 L
.17355 .5046 L
.17378 .50273 L
.17401 .50183 L
.17425 .5008 L
.17448 .49985 L
.17471 .49806 L
.17494 .49718 L
Mistroke
.17518 .49655 L
.17541 .4962 L
.17564 .49542 L
.17587 .49519 L
.17611 .49503 L
.17634 .49483 L
.17657 .49425 L
.1768 .49404 L
.17704 .49412 L
.17727 .49433 L
.1775 .49447 L
.17773 .49465 L
.17797 .4949 L
.1782 .49509 L
.17843 .49522 L
.17866 .49525 L
.1789 .49535 L
.17913 .49554 L
.17936 .4959 L
.17959 .49597 L
.17983 .49604 L
.18006 .4961 L
.18029 .4965 L
.18052 .49656 L
.18076 .49678 L
.18099 .49715 L
.18122 .49814 L
.18145 .49879 L
.18169 .49966 L
.18192 .50059 L
.18215 .50211 L
.18238 .50304 L
.18262 .504 L
.18285 .5047 L
.18308 .50595 L
.18331 .50661 L
.18355 .50748 L
.18378 .50816 L
.18401 .50944 L
.18424 .51011 L
.18448 .51087 L
.18471 .51144 L
.18494 .51246 L
.18517 .51311 L
.18541 .51389 L
.18564 .51475 L
.18587 .51587 L
.1861 .51647 L
.18634 .51659 L
.18657 .51649 L
Mistroke
.1868 .51627 L
.18703 .51564 L
.18727 .51472 L
.1875 .51389 L
.18773 .51328 L
.18797 .51257 L
.1882 .51188 L
.18843 .51152 L
.18866 .51159 L
.1889 .51176 L
.18913 .51212 L
.18936 .51282 L
.18959 .51393 L
.18983 .51492 L
.19006 .5159 L
.19029 .51667 L
.19052 .5176 L
.19076 .51802 L
.19099 .51841 L
.19122 .5183 L
.19145 .51849 L
.19169 .51861 L
.19192 .51934 L
.19215 .52009 L
.19238 .52123 L
.19262 .52218 L
.19285 .52307 L
.19308 .52362 L
.19331 .52393 L
.19355 .52446 L
.19378 .52499 L
.19401 .52538 L
.19424 .52518 L
.19448 .52471 L
.19471 .52332 L
.19494 .52106 L
.19517 .51786 L
.19541 .51583 L
.19564 .51448 L
.19587 .51379 L
.1961 .51264 L
.19634 .51258 L
.19657 .51195 L
.1968 .51077 L
.19703 .5079 L
.19727 .50704 L
.1975 .50653 L
.19773 .50613 L
.19796 .50386 L
.1982 .50287 L
Mistroke
.19843 .50071 L
.19866 .49709 L
.19889 .49053 L
.19913 .48704 L
.19936 .48452 L
.19959 .48275 L
.19982 .47852 L
.20006 .47705 L
.20029 .47443 L
.20052 .47097 L
.20075 .46324 L
.20099 .45959 L
.20122 .45599 L
.20145 .45312 L
.20168 .44614 L
.20192 .44221 L
.20215 .4362 L
.20238 .42909 L
.20261 .41691 L
.20285 .40993 L
.20308 .40395 L
.20331 .3999 L
.20354 .39239 L
.20378 .38929 L
.20401 .38505 L
.20424 .38046 L
.20447 .37095 L
.20471 .36669 L
.20494 .36323 L
.20517 .36095 L
.2054 .35473 L
.20564 .35188 L
.20587 .34765 L
.2061 .34198 L
.20633 .33155 L
.20657 .32597 L
.2068 .32214 L
.20703 .3199 L
.20726 .31477 L
.2075 .31316 L
.20773 .3107 L
.20796 .30746 L
.20819 .29978 L
.20843 .29628 L
.20866 .29353 L
.20889 .29183 L
.20912 .28679 L
.20936 .2841 L
.20959 .27976 L
.20982 .27409 L
Mistroke
.21005 .26442 L
.21029 .25869 L
.21052 .25451 L
.21075 .2522 L
.21098 .24807 L
.21122 .24692 L
.21145 .24517 L
.21168 .24295 L
.21191 .23753 L
.21215 .23539 L
.21238 .23409 L
.21261 .23354 L
.21284 .23078 L
.21308 .22967 L
.21331 .22757 L
.21354 .22401 L
.21377 .21751 L
.21401 .2138 L
.21424 .21154 L
.21447 .21038 L
.2147 .20783 L
.21494 .2074 L
.21517 .20653 L
.2154 .20516 L
.21563 .20102 L
.21587 .19926 L
.2161 .19768 L
.21633 .19664 L
.21656 .19332 L
.2168 .19125 L
.21703 .18785 L
.21726 .18359 L
.21749 .17673 L
.21773 .17233 L
.21796 .16883 L
.21819 .16674 L
.21842 .16368 L
.21866 .16274 L
.21889 .16158 L
.21912 .16051 L
.21935 .15763 L
.21959 .1568 L
.21982 .15641 L
.22005 .15642 L
.22028 .15512 L
.22052 .15466 L
.22075 .15366 L
.22098 .15168 L
.22121 .14813 L
.22145 .14605 L
Mistroke
.22168 .14502 L
.22191 .14459 L
.22214 .14361 L
.22238 .14369 L
.22261 .14366 L
.22284 .14333 L
.22307 .14162 L
.22331 .14108 L
.22354 .14067 L
.22377 .14049 L
.224 .13911 L
.22424 .1381 L
.22447 .13619 L
.2247 .13359 L
.22493 .1296 L
.22517 .12692 L
.2254 .12486 L
.22563 .12368 L
.22586 .12215 L
.2261 .12177 L
.22633 .12124 L
.22656 .12066 L
.2268 .11908 L
.22703 .11875 L
.22726 .11876 L
.22749 .11895 L
.22773 .11835 L
.22796 .11829 L
.22819 .11784 L
.22842 .11655 L
.22866 .11405 L
.22889 .11268 L
.22912 .11198 L
.22935 .11156 L
.22959 .11041 L
.22982 .11021 L
.23005 .10976 L
.23028 .10899 L
.23052 .10672 L
.23075 .10569 L
.23098 .10457 L
.23121 .10367 L
.23145 .1013 L
.23168 .09977 L
.23191 .09735 L
.23214 .09458 L
.23238 .09015 L
.23261 .08733 L
.23284 .0848 L
.23307 .08312 L
Mistroke
.23331 .08057 L
.23354 .07949 L
.23377 .07817 L
.234 .077 L
.23424 .07459 L
.23447 .07369 L
.2347 .07309 L
.23493 .07284 L
.23517 .0717 L
.2354 .07135 L
.23563 .07079 L
.23586 .06972 L
.2361 .0676 L
.23633 .06653 L
.23656 .06611 L
.23679 .06597 L
.23703 .06532 L
.23726 .06534 L
.23749 .06527 L
.23772 .06491 L
.23796 .06358 L
.23819 .06304 L
.23842 .06264 L
.23865 .06242 L
.23889 .06143 L
.23912 .06076 L
.23935 .05956 L
.23958 .05799 L
.23982 .05549 L
.24005 .05385 L
.24028 .05253 L
.24051 .05177 L
.24075 .0507 L
.24098 .05035 L
.24121 .04985 L
.24144 .04932 L
.24168 .04812 L
.24191 .04771 L
.24214 .04752 L
.24237 .04751 L
.24261 .04706 L
.24284 .047 L
.24307 .04676 L
.2433 .0461 L
.24354 .04479 L
.24377 .0441 L
.244 .04379 L
.24423 .04364 L
.24447 .04313 L
.2447 .04311 L
Mistroke
.24493 .04299 L
.24516 .0427 L
.2454 .04166 L
.24563 .0412 L
.24586 .04072 L
.24609 .04033 L
.24633 .03925 L
.24656 .03854 L
.24679 .03742 L
.24702 .03613 L
.24726 .03407 L
.24749 .03272 L
.24772 .03148 L
.24795 .03066 L
.24819 .02946 L
.24842 .02893 L
.24865 .02831 L
.24888 .02781 L
.24912 .02679 L
.24935 .0264 L
.24958 .02612 L
.24981 .02601 L
.25005 .02556 L
.25028 .02542 L
.25051 .02521 L
.25074 .02483 L
.25098 .02409 L
.25121 .0237 L
.25144 .0236 L
.25167 .02361 L
.25191 .02354 L
.25214 .02364 L
.25237 .02379 L
.2526 .02384 L
.25284 .02371 L
.25307 .02372 L
.2533 .02384 L
.25353 .02399 L
.25377 .02404 L
.254 .02404 L
.25423 .02391 L
.25446 .02361 L
.2547 .02315 L
.25493 .0228 L
.25516 .02257 L
.25539 .02248 L
.25563 .02241 L
.25586 .02243 L
.25609 .02242 L
.25632 .02237 L
Mistroke
.25656 .02221 L
.25679 .02218 L
.25702 .02221 L
.25725 .02227 L
.25749 .02228 L
.25772 .02234 L
.25795 .02235 L
.25818 .02223 L
.25842 .02196 L
.25865 .0218 L
.25888 .02169 L
.25911 .02158 L
.25935 .02136 L
.25958 .02127 L
.25981 .02115 L
.26004 .02101 L
.26028 .02064 L
.26051 .02044 L
.26074 .0202 L
.26097 .01998 L
.26121 .01954 L
.26144 .01929 L
.26167 .01895 L
.2619 .01866 L
.26214 .01812 L
.26237 .01777 L
.2626 .01737 L
.26283 .01704 L
.26307 .01652 L
.2633 .01622 L
.26353 .0159 L
.26376 .0157 L
.264 .01538 L
.26423 .01519 L
.26446 .015 L
.26469 .0149 L
.26493 .01476 L
.26516 .01472 L
.26539 .01474 L
.26563 .01487 L
.26586 .01507 L
.26609 .01519 L
.26632 .01531 L
.26656 .01541 L
.26679 .01564 L
.26702 .01573 L
.26725 .01593 L
.26749 .01618 L
.26772 .01671 L
.26795 .01698 L
Mistroke
.26818 .01731 L
.26842 .01761 L
.26865 .01825 L
.26888 .01863 L
.26911 .0192 L
.26935 .01982 L
.26958 .02084 L
.26981 .02142 L
.27004 .02194 L
.27028 .0223 L
.27051 .02298 L
.27074 .02326 L
.27097 .02362 L
.27121 .024 L
.27144 .02481 L
.27167 .02514 L
.2719 .02543 L
.27214 .02565 L
.27237 .02625 L
.2726 .02656 L
.27283 .027 L
.27307 .02759 L
.2733 .02862 L
.27353 .02917 L
.27376 .02954 L
.274 .02975 L
.27423 .03023 L
.27446 .03036 L
.27469 .03059 L
.27493 .0309 L
.27516 .03166 L
.27539 .03199 L
.27562 .03225 L
.27586 .0324 L
.27609 .03294 L
.27632 .03325 L
.27655 .03378 L
.27679 .0345 L
.27702 .03567 L
.27725 .03636 L
.27748 .03682 L
.27772 .03705 L
.27795 .03747 L
.27818 .03753 L
.27841 .03769 L
.27865 .03794 L
.27888 .03862 L
.27911 .03884 L
.27934 .03894 L
.27958 .03897 L
Mistroke
.27981 .03935 L
.28004 .03952 L
.28027 .03987 L
.28051 .04052 L
.28074 .04166 L
.28097 .0423 L
.2812 .04268 L
.28144 .04289 L
.28167 .0434 L
.2819 .0435 L
.28213 .04375 L
.28237 .04413 L
.2826 .04514 L
.28283 .04558 L
.28306 .046 L
.2833 .04631 L
.28353 .0472 L
.28376 .04775 L
.28399 .04863 L
.28423 .04975 L
.28446 .05158 L
.28469 .05268 L
.28492 .05356 L
.28516 .05412 L
.28539 .05507 L
.28562 .05539 L
.28585 .05586 L
.28609 .05639 L
.28632 .0576 L
.28655 .05806 L
.28678 .05841 L
.28702 .05862 L
.28725 .05941 L
.28748 .05977 L
.28771 .06037 L
.28795 .06128 L
.28818 .06292 L
.28841 .06382 L
.28864 .06442 L
.28888 .06477 L
.28911 .06557 L
.28934 .06578 L
.28957 .06615 L
.28981 .06665 L
.29004 .06792 L
.29027 .06848 L
.2905 .06897 L
.29074 .06931 L
.29097 .07031 L
.2912 .07089 L
Mistroke
.29143 .07184 L
.29167 .07303 L
.2919 .075 L
.29213 .07619 L
.29236 .07711 L
.2926 .07767 L
.29283 .07861 L
.29306 .07892 L
.29329 .07936 L
.29353 .07985 L
.29376 .081 L
.29399 .08144 L
.29422 .08172 L
.29446 .08185 L
.29469 .08248 L
.29492 .08274 L
.29515 .08322 L
.29539 .08402 L
.29562 .08547 L
.29585 .08627 L
.29608 .08674 L
.29632 .08699 L
.29655 .08759 L
.29678 .0877 L
.29701 .08794 L
.29725 .08833 L
.29748 .08937 L
.29771 .08982 L
.29794 .0902 L
.29818 .09044 L
.29841 .09124 L
.29864 .09172 L
.29887 .09254 L
.29911 .09361 L
.29934 .09535 L
.29957 .09642 L
.2998 .09725 L
.30004 .09775 L
.30027 .09856 L
.3005 .09882 L
.30073 .09918 L
.30097 .09961 L
.3012 .10061 L
.30143 .10097 L
.30166 .10121 L
.3019 .10132 L
.30213 .10188 L
.30236 .1021 L
.30259 .10251 L
.30283 .10321 L
Mistroke
.30306 .10452 L
.30329 .10524 L
.30352 .10569 L
.30376 .10597 L
.30399 .10659 L
.30422 .10675 L
.30445 .10703 L
.30469 .10741 L
.30492 .10842 L
.30515 .10888 L
.30539 .10932 L
.30562 .10963 L
.30585 .11049 L
.30608 .11102 L
.30632 .11184 L
.30655 .11282 L
.30678 .11443 L
.30701 .11543 L
.30725 .11626 L
.30748 .11678 L
.30771 .11759 L
.30794 .11789 L
.30818 .11825 L
.30841 .1186 L
.30864 .1194 L
.30887 .11968 L
.30911 .11984 L
.30934 .11988 L
.30957 .12022 L
.3098 .12032 L
.31004 .12052 L
.31027 .12092 L
.3105 .12171 L
.31073 .12213 L
.31097 .12231 L
.3112 .12238 L
.31143 .12261 L
.31166 .12261 L
.3119 .12265 L
.31213 .12278 L
.31236 .12326 L
.31259 .12346 L
.31283 .12363 L
.31306 .12371 L
.31329 .12408 L
.31352 .12433 L
.31376 .12479 L
.31399 .12538 L
.31422 .12629 L
.31445 .1269 L
Mistroke
.31469 .12738 L
.31492 .12765 L
.31515 .12801 L
.31538 .1281 L
.31562 .12823 L
.31585 .12838 L
.31608 .12874 L
.31631 .12882 L
.31655 .12882 L
.31678 .12877 L
.31701 .12887 L
.31724 .12885 L
.31748 .12887 L
.31771 .12907 L
.31794 .12952 L
.31817 .12975 L
.31841 .12984 L
.31864 .12989 L
.31887 .1301 L
.3191 .13013 L
.31934 .1302 L
.31957 .13034 L
.3198 .13079 L
.32003 .13101 L
.32027 .13129 L
.3205 .13153 L
.32073 .13208 L
.32096 .13247 L
.3212 .13304 L
.32143 .13364 L
.32166 .13454 L
.32189 .13515 L
.32213 .13573 L
.32236 .13611 L
.32259 .13661 L
.32282 .13684 L
.32306 .13707 L
.32329 .13721 L
.32352 .1375 L
.32375 .13757 L
.32399 .13759 L
.32422 .13755 L
.32445 .13759 L
.32468 .13756 L
.32492 .13751 L
.32515 .13755 L
.32538 .13765 L
.32561 .13767 L
.32585 .13755 L
.32608 .1374 L
Mistroke
.32631 .13721 L
.32654 .13704 L
.32678 .13682 L
.32701 .13666 L
.32724 .13653 L
.32747 .13642 L
.32771 .13631 L
.32794 .13623 L
.32817 .13618 L
.3284 .13623 L
.32864 .1364 L
.32887 .13665 L
.3291 .13694 L
.32933 .13718 L
.32957 .13735 L
.3298 .1374 L
.33003 .13736 L
.33026 .13728 L
.3305 .1372 L
.33073 .13712 L
.33096 .13706 L
.33119 .13694 L
.33143 .13679 L
.33166 .13667 L
.33189 .13659 L
.33212 .13653 L
.33236 .13652 L
.33259 .13669 L
.33282 .13695 L
.33305 .1371 L
.33329 .13711 L
.33352 .13711 L
.33375 .13718 L
.33398 .13711 L
.33422 .13711 L
.33445 .13717 L
.33468 .13749 L
.33491 .1376 L
.33515 .13777 L
.33538 .13794 L
.33561 .13845 L
.33584 .13882 L
.33608 .13942 L
.33631 .14014 L
.33654 .14124 L
.33677 .14194 L
.33701 .14254 L
.33724 .14293 L
.33747 .14355 L
.3377 .14378 L
Mistroke
.33794 .1441 L
.33817 .14443 L
.3384 .14514 L
.33863 .14538 L
.33887 .14555 L
.3391 .14565 L
.33933 .1461 L
.33956 .14631 L
.3398 .14669 L
.34003 .14729 L
.34026 .14834 L
.34049 .1489 L
.34073 .14921 L
.34096 .14938 L
.34119 .14981 L
.34142 .1499 L
.34166 .1501 L
.34189 .15046 L
.34212 .15134 L
.34235 .1517 L
.34259 .15196 L
.34282 .15211 L
.34305 .15274 L
.34328 .15309 L
.34352 .15374 L
.34375 .15467 L
.34398 .15624 L
.34422 .15715 L
.34445 .15783 L
.34468 .15824 L
.34491 .15904 L
.34515 .1593 L
.34538 .15975 L
.34561 .16036 L
.34584 .16169 L
.34608 .16226 L
.34631 .16268 L
.34654 .16296 L
.34677 .16384 L
.34701 .16422 L
.34724 .16487 L
.34747 .16584 L
.3477 .16768 L
.34794 .16867 L
.34817 .16943 L
.3484 .16996 L
.34863 .17112 L
.34887 .17157 L
.3491 .17225 L
.34933 .17309 L
Mistroke
.34956 .1749 L
.3498 .1758 L
.35003 .17665 L
.35026 .17728 L
.35049 .17874 L
.35073 .17952 L
.35096 .18065 L
.35119 .18193 L
.35142 .18419 L
.35166 .1855 L
.35189 .18664 L
.35212 .1874 L
.35235 .18877 L
.35259 .18936 L
.35282 .19009 L
.35305 .19082 L
.35328 .19231 L
.35352 .193 L
.35375 .19354 L
.35398 .19385 L
.35421 .19468 L
.35445 .19501 L
.35468 .19546 L
.35491 .19604 L
.35514 .19718 L
.35538 .19779 L
.35561 .19816 L
.35584 .19833 L
.35607 .19873 L
.35631 .19881 L
.35654 .1989 L
.35677 .19904 L
.357 .1995 L
.35724 .1997 L
.35747 .19981 L
.3577 .19981 L
.35793 .19995 L
.35817 .20004 L
.3584 .2002 L
.35863 .20044 L
.35886 .2008 L
.3591 .20109 L
.35933 .20123 L
.35956 .20124 L
.35979 .2011 L
.36003 .20095 L
.36026 .20073 L
.36049 .20048 L
.36072 .20013 L
.36096 .19989 L
Mistroke
.36119 .19961 L
.36142 .19934 L
.36165 .19892 L
.36189 .19867 L
.36212 .19836 L
.36235 .19812 L
.36258 .19769 L
.36282 .1975 L
.36305 .19724 L
.36328 .19703 L
.36351 .1966 L
.36375 .19633 L
.36398 .19598 L
.36421 .19559 L
.36444 .19501 L
.36468 .19469 L
.36491 .1945 L
.36514 .19438 L
.36537 .19416 L
.36561 .19416 L
.36584 .19419 L
.36607 .19418 L
.3663 .19395 L
.36654 .19395 L
.36677 .19399 L
.367 .194 L
.36723 .19376 L
.36747 .19365 L
.3677 .19344 L
.36793 .1931 L
.36816 .19246 L
.3684 .19205 L
.36863 .19167 L
.36886 .19137 L
.36909 .19086 L
.36933 .1906 L
.36956 .19027 L
.36979 .18998 L
.37002 .18941 L
.37026 .1891 L
.37049 .18873 L
.37072 .18845 L
.37095 .18796 L
.37119 .18769 L
.37142 .18737 L
.37165 .18709 L
.37188 .18662 L
.37212 .18634 L
.37235 .18608 L
.37258 .18591 L
Mistroke
.37281 .18567 L
.37305 .18562 L
.37328 .18567 L
.37351 .18581 L
.37374 .18592 L
.37398 .18603 L
.37421 .18611 L
.37444 .18615 L
.37467 .18618 L
.37491 .18615 L
.37514 .1862 L
.37537 .18632 L
.3756 .18657 L
.37584 .18662 L
.37607 .18664 L
.3763 .18666 L
.37653 .18689 L
.37677 .18695 L
.377 .18713 L
.37723 .18751 L
.37746 .18825 L
.3777 .18861 L
.37793 .18889 L
.37816 .18914 L
.37839 .18978 L
.37863 .19005 L
.37886 .19051 L
.37909 .19108 L
.37932 .1923 L
.37956 .19292 L
.37979 .19359 L
.38002 .19414 L
.38025 .19533 L
.38049 .19602 L
.38072 .19699 L
.38095 .19804 L
.38118 .19985 L
.38142 .20088 L
.38165 .20185 L
.38188 .20253 L
.38211 .20376 L
.38235 .20433 L
.38258 .20506 L
.38281 .20578 L
.38305 .20718 L
.38328 .20784 L
.38351 .20837 L
.38374 .20871 L
.38398 .20956 L
.38421 .20992 L
Mistroke
.38444 .21039 L
.38467 .211 L
.38491 .21218 L
.38514 .21278 L
.38537 .21313 L
.3856 .2133 L
.38584 .21381 L
.38607 .21394 L
.3863 .21414 L
.38653 .21445 L
.38677 .21523 L
.387 .2156 L
.38723 .21586 L
.38746 .21599 L
.3877 .21643 L
.38793 .21668 L
.38816 .2171 L
.38839 .21767 L
.38863 .21859 L
.38886 .21916 L
.38909 .21954 L
.38932 .2197 L
.38956 .21994 L
.38979 .21994 L
.39002 .21998 L
.39025 .22006 L
.39049 .22038 L
.39072 .22046 L
.39095 .22045 L
.39118 .22039 L
.39142 .22046 L
.39165 .22045 L
.39188 .22051 L
.39211 .22076 L
.39235 .22122 L
.39258 .22149 L
.39281 .22159 L
.39304 .22162 L
.39328 .22173 L
.39351 .22167 L
.39374 .22165 L
.39397 .22168 L
.39421 .22196 L
.39444 .22208 L
.39467 .22225 L
.3949 .2224 L
.39514 .22282 L
.39537 .22316 L
.3956 .22369 L
.39583 .22429 L
Mistroke
.39607 .22513 L
.3963 .22573 L
.39653 .22623 L
.39676 .22654 L
.397 .22689 L
.39723 .22698 L
.39746 .22707 L
.39769 .2271 L
.39793 .22724 L
.39816 .22719 L
.39839 .22708 L
.39862 .22696 L
.39886 .22695 L
.39909 .22692 L
.39932 .22694 L
.39955 .22713 L
.39979 .22743 L
.40002 .2276 L
.40025 .22757 L
.40048 .22749 L
.40072 .2274 L
.40095 .22725 L
.40118 .22712 L
.40141 .22707 L
.40165 .22718 L
.40188 .22716 L
.40211 .22714 L
.40234 .2271 L
.40258 .22726 L
.40281 .22743 L
.40304 .22784 L
.40327 .22843 L
.40351 .22928 L
.40374 .22984 L
.40397 .23024 L
.4042 .23045 L
.40444 .23073 L
.40467 .23075 L
.4049 .23085 L
.40513 .23104 L
.40537 .23155 L
.4056 .23165 L
.40583 .23167 L
.40606 .23166 L
.4063 .23197 L
.40653 .23207 L
.40676 .23234 L
.40699 .23293 L
.40723 .23404 L
.40746 .23462 L
Mistroke
.40769 .235 L
.40792 .23526 L
.40816 .23596 L
.40839 .23618 L
.40862 .2366 L
.40885 .23716 L
.40909 .23852 L
.40932 .23917 L
.40955 .23988 L
.40978 .24045 L
.41002 .24181 L
.41025 .24263 L
.41048 .24388 L
.41071 .24528 L
.41095 .2476 L
.41118 .24898 L
.41141 .2502 L
.41164 .25102 L
.41188 .2524 L
.41211 .25297 L
.41234 .25371 L
.41257 .25444 L
.41281 .25597 L
.41304 .25659 L
.41327 .25706 L
.4135 .25734 L
.41374 .25822 L
.41397 .25859 L
.4142 .25915 L
.41443 .25999 L
.41467 .26155 L
.4149 .26236 L
.41513 .26281 L
.41536 .26302 L
.4156 .26364 L
.41583 .26375 L
.41606 .26398 L
.41629 .26437 L
.41653 .26547 L
.41676 .26595 L
.41699 .26633 L
.41722 .26656 L
.41746 .26735 L
.41769 .26784 L
.41792 .26869 L
.41815 .26981 L
.41839 .27159 L
.41862 .27269 L
.41885 .27351 L
.41908 .27394 L
Mistroke
.41932 .27462 L
.41955 .27477 L
.41978 .27503 L
.42001 .27537 L
.42025 .27626 L
.42048 .27654 L
.42071 .27666 L
.42094 .27668 L
.42118 .27712 L
.42141 .27727 L
.42164 .27762 L
.42188 .27834 L
.42211 .27967 L
.42234 .2804 L
.42257 .28079 L
.42281 .281 L
.42304 .28154 L
.42327 .2816 L
.4235 .2818 L
.42374 .28215 L
.42397 .28322 L
.4242 .28368 L
.42443 .28416 L
.42467 .28453 L
.4249 .2856 L
.42513 .2863 L
.42536 .28743 L
.4256 .28878 L
.42583 .2909 L
.42606 .29225 L
.42629 .29337 L
.42653 .29406 L
.42676 .29512 L
.42699 .29549 L
.42722 .29597 L
.42746 .29643 L
.42769 .29753 L
.42792 .29788 L
.42815 .29809 L
.42839 .29817 L
.42862 .29876 L
.42885 .299 L
.42908 .29945 L
.42932 .30025 L
.42955 .30168 L
.42978 .30246 L
.43001 .30285 L
.43025 .30303 L
.43048 .30352 L
.43071 .30355 L
Mistroke
.43094 .30369 L
.43118 .304 L
.43141 .30499 L
.43164 .30537 L
.43187 .30568 L
.43211 .30586 L
.43234 .30665 L
.43257 .30716 L
.4328 .3081 L
.43304 .30936 L
.43327 .31136 L
.4335 .31261 L
.43373 .31355 L
.43397 .3141 L
.4342 .31497 L
.43443 .31521 L
.43466 .31561 L
.4349 .31612 L
.43513 .31734 L
.43536 .31775 L
.43559 .318 L
.43583 .31811 L
.43606 .31882 L
.43629 .31909 L
.43652 .31964 L
.43676 .32063 L
.43699 .32246 L
.43722 .32346 L
.43745 .3241 L
.43769 .32451 L
.43792 .32548 L
.43815 .32576 L
.43838 .32625 L
.43862 .32694 L
.43885 .32866 L
.43908 .32946 L
.43931 .33025 L
.43955 .33086 L
.43978 .33241 L
.44001 .33333 L
.44024 .33476 L
.44048 .33645 L
.44071 .33923 L
.44094 .34092 L
.44117 .34236 L
.44141 .34329 L
.44164 .34485 L
.44187 .34546 L
.4421 .34625 L
.44234 .34705 L
Mistroke
.44257 .34875 L
.4428 .34944 L
.44303 .34994 L
.44327 .35021 L
.4435 .35116 L
.44373 .35155 L
.44396 .35216 L
.4442 .35311 L
.44443 .35487 L
.44466 .35582 L
.44489 .35635 L
.44513 .35661 L
.44536 .35729 L
.44559 .3574 L
.44582 .35762 L
.44606 .35801 L
.44629 .35915 L
.44652 .35962 L
.44675 .35999 L
.44699 .3602 L
.44722 .361 L
.44745 .36149 L
.44768 .36234 L
.44792 .36347 L
.44815 .36529 L
.44838 .36644 L
.44861 .3673 L
.44885 .36777 L
.44908 .36848 L
.44931 .36866 L
.44954 .36893 L
.44978 .36926 L
.45001 .37012 L
.45024 .37039 L
.45047 .3705 L
.45071 .3705 L
.45094 .37089 L
.45117 .371 L
.4514 .3713 L
.45164 .37192 L
.45187 .37309 L
.4521 .37374 L
.45233 .37409 L
.45257 .37427 L
.4528 .37473 L
.45303 .37477 L
.45326 .37491 L
.4535 .37517 L
.45373 .37603 L
.45396 .3764 L
Mistroke
.45419 .37678 L
.45443 .37707 L
.45466 .37792 L
.45489 .37848 L
.45512 .37939 L
.45536 .38048 L
.45559 .38219 L
.45582 .3833 L
.45605 .38423 L
.45629 .38482 L
.45652 .38569 L
.45675 .38601 L
.45698 .3864 L
.45722 .38676 L
.45745 .38757 L
.45768 .38783 L
.45791 .38798 L
.45815 .38802 L
.45838 .38841 L
.45861 .38855 L
.45884 .38882 L
.45908 .38933 L
.45931 .39027 L
.45954 .39078 L
.45977 .39101 L
.46001 .3911 L
.46024 .39136 L
.46047 .39134 L
.4607 .39137 L
.46094 .39151 L
.46117 .39207 L
.4614 .39227 L
.46164 .3924 L
.46187 .39247 L
.4621 .39289 L
.46233 .39317 L
.46257 .39373 L
.4628 .3945 L
.46303 .39571 L
.46326 .39649 L
.4635 .39709 L
.46373 .39743 L
.46396 .39794 L
.46419 .39808 L
.46443 .39832 L
.46466 .39861 L
.46489 .39931 L
.46512 .39955 L
.46536 .39967 L
.46559 .39971 L
Mistroke
.46582 .40008 L
.46605 .4002 L
.46629 .40047 L
.46652 .401 L
.46675 .40203 L
.46698 .40258 L
.46722 .40294 L
.46745 .40317 L
.46768 .40374 L
.46791 .40391 L
.46815 .4042 L
.46838 .4046 L
.46861 .40561 L
.46884 .40609 L
.46908 .40658 L
.46931 .40696 L
.46954 .4079 L
.46977 .40846 L
.47001 .4093 L
.47024 .41026 L
.47047 .41186 L
.4707 .41284 L
.47094 .41372 L
.47117 .4143 L
.4714 .41527 L
.47163 .41568 L
.47187 .4162 L
.4721 .41667 L
.47233 .41765 L
.47256 .41806 L
.4728 .41837 L
.47303 .41853 L
.47326 .41905 L
.47349 .41924 L
.47373 .41952 L
.47396 .41994 L
.47419 .42074 L
.47442 .42116 L
.47466 .42137 L
.47489 .42145 L
.47512 .42171 L
.47535 .42173 L
.47559 .42177 L
.47582 .42187 L
.47605 .42227 L
.47628 .42243 L
.47652 .42251 L
.47675 .42253 L
.47698 .42273 L
.47721 .42286 L
Mistroke
.47745 .42312 L
.47768 .42348 L
.47791 .42407 L
.47814 .42447 L
.47838 .42474 L
.47861 .42487 L
.47884 .42501 L
.47907 .42501 L
.47931 .42503 L
.47954 .42506 L
.47977 .42521 L
.48 .42523 L
.48024 .42519 L
.48047 .42512 L
.4807 .42511 L
.48093 .42506 L
.48117 .42505 L
.4814 .42515 L
.48163 .42536 L
.48186 .42549 L
.4821 .42552 L
.48233 .42552 L
.48256 .42556 L
.48279 .42552 L
.48303 .42549 L
.48326 .42548 L
.48349 .4256 L
.48372 .42564 L
.48396 .42572 L
.48419 .4258 L
.48442 .42603 L
.48465 .4262 L
.48489 .42648 L
.48512 .42677 L
.48535 .42721 L
.48558 .42752 L
.48582 .42782 L
.48605 .42802 L
.48628 .42827 L
.48651 .42838 L
.48675 .42849 L
.48698 .42853 L
.48721 .42863 L
.48744 .42863 L
.48768 .42861 L
.48791 .42858 L
.48814 .42857 L
.48837 .42855 L
.48861 .42853 L
.48884 .42855 L
Mistroke
.48907 .42857 L
.4893 .42859 L
.48954 .42853 L
.48977 .42846 L
.49 .42834 L
.49023 .42825 L
.49047 .42814 L
.4907 .42805 L
.49093 .42793 L
.49116 .42784 L
.4914 .42773 L
.49163 .42762 L
.49186 .4275 L
.49209 .42745 L
.49233 .42744 L
.49256 .42748 L
.49279 .42754 L
.49302 .42759 L
.49326 .42761 L
.49349 .4276 L
.49372 .42756 L
.49395 .42752 L
.49419 .42751 L
.49442 .42752 L
.49465 .42758 L
.49488 .42758 L
.49512 .42756 L
.49535 .42754 L
.49558 .42756 L
.49581 .42755 L
.49605 .42757 L
.49628 .42766 L
.49651 .42786 L
.49674 .42797 L
.49698 .42806 L
.49721 .42814 L
.49744 .42836 L
.49767 .42846 L
.49791 .42861 L
.49814 .42879 L
.49837 .42918 L
.4986 .42939 L
.49884 .42963 L
.49907 .42983 L
.4993 .43024 L
.49953 .43047 L
.49977 .43078 L
.5 .43108 L
.50023 .43161 L
.50047 .43192 L
Mistroke
.5007 .43225 L
.50093 .4325 L
.50116 .43293 L
.5014 .43315 L
.50163 .43341 L
.50186 .43363 L
.50209 .43401 L
.50233 .4342 L
.50256 .43437 L
.50279 .43448 L
.50302 .43469 L
.50326 .43477 L
.50349 .43484 L
.50372 .43489 L
.50395 .43502 L
.50419 .43507 L
.50442 .43508 L
.50465 .43506 L
.50488 .43506 L
.50512 .43505 L
.50535 .43501 L
.50558 .43498 L
.50581 .43493 L
.50605 .4349 L
.50628 .43483 L
.50651 .43475 L
.50674 .4346 L
.50698 .43452 L
.50721 .4344 L
.50744 .43428 L
.50767 .43408 L
.50791 .43398 L
.50814 .43385 L
.50837 .43374 L
.5086 .43352 L
.50884 .4334 L
.50907 .43325 L
.5093 .4331 L
.50953 .43284 L
.50977 .43271 L
.51 .43257 L
.51023 .43247 L
.51046 .43224 L
.5107 .43212 L
.51093 .43195 L
.51116 .43178 L
.51139 .43148 L
.51163 .43132 L
.51186 .43119 L
.51209 .43112 L
Mistroke
.51232 .43095 L
.51256 .43088 L
.51279 .43079 L
.51302 .43067 L
.51325 .43045 L
.51349 .43035 L
.51372 .43032 L
.51395 .43031 L
.51418 .43025 L
.51442 .43026 L
.51465 .43024 L
.51488 .43017 L
.51511 .42999 L
.51535 .42992 L
.51558 .42991 L
.51581 .42991 L
.51604 .42984 L
.51628 .42984 L
.51651 .42979 L
.51674 .42968 L
.51697 .42944 L
.51721 .4293 L
.51744 .4292 L
.51767 .42912 L
.5179 .42894 L
.51814 .42885 L
.51837 .4287 L
.5186 .42851 L
.51883 .42817 L
.51907 .42798 L
.5193 .4278 L
.51953 .42766 L
.51976 .42741 L
.52 .4273 L
.52023 .42715 L
.52046 .42699 L
.52069 .42667 L
.52093 .4265 L
.52116 .42634 L
.52139 .42621 L
.52162 .42596 L
.52186 .42584 L
.52209 .4257 L
.52232 .42556 L
.52255 .42529 L
.52279 .42514 L
.52302 .425 L
.52325 .42489 L
.52348 .42468 L
.52372 .42458 L
Mistroke
.52395 .42447 L
.52418 .42439 L
.52441 .42422 L
.52465 .42413 L
.52488 .42403 L
.52511 .42398 L
.52534 .42388 L
.52558 .42382 L
.52581 .42377 L
.52604 .42375 L
.52627 .42374 L
.52651 .42372 L
.52674 .42371 L
.52697 .42374 L
.5272 .42384 L
.52744 .42389 L
.52767 .42399 L
.5279 .42412 L
.52813 .42437 L
.52837 .42451 L
.5286 .42471 L
.52883 .42489 L
.52906 .42523 L
.5293 .42545 L
.52953 .42574 L
.52976 .42601 L
.52999 .42646 L
.53023 .42672 L
.53046 .42699 L
.53069 .4272 L
.53092 .42754 L
.53116 .42771 L
.53139 .42791 L
.53162 .42808 L
.53185 .4284 L
.53209 .42854 L
.53232 .42866 L
.53255 .42873 L
.53278 .42892 L
.53302 .42899 L
.53325 .42908 L
.53348 .42919 L
.53371 .42942 L
.53395 .42951 L
.53418 .42954 L
.53441 .42953 L
.53464 .42958 L
.53488 .42957 L
.53511 .42957 L
.53534 .4296 L
Mistroke
.53557 .42973 L
.53581 .42979 L
.53604 .42981 L
.53627 .42982 L
.5365 .42988 L
.53674 .42994 L
.53697 .43006 L
.5372 .43023 L
.53743 .43047 L
.53767 .43063 L
.5379 .43072 L
.53813 .43074 L
.53836 .43075 L
.5386 .4307 L
.53883 .43067 L
.53906 .43066 L
.5393 .43072 L
.53953 .43071 L
.53976 .43066 L
.53999 .43061 L
.54023 .43062 L
.54046 .43061 L
.54069 .43064 L
.54092 .43077 L
.54116 .431 L
.54139 .43113 L
.54162 .43119 L
.54185 .43121 L
.54209 .43131 L
.54232 .43131 L
.54255 .43135 L
.54278 .43143 L
.54302 .43171 L
.54325 .43184 L
.54348 .432 L
.54371 .43215 L
.54395 .43251 L
.54418 .43277 L
.54441 .43317 L
.54464 .43362 L
.54488 .4343 L
.54511 .43474 L
.54534 .43511 L
.54557 .43535 L
.54581 .4357 L
.54604 .43582 L
.54627 .43598 L
.5465 .43612 L
.54674 .43646 L
.54697 .43655 L
Mistroke
.5472 .4366 L
.54743 .43662 L
.54767 .43681 L
.5479 .43688 L
.54813 .43703 L
.54836 .43732 L
.5486 .43781 L
.54883 .43807 L
.54906 .43818 L
.54929 .43821 L
.54953 .43836 L
.54976 .43835 L
.54999 .43839 L
.55022 .4385 L
.55046 .43887 L
.55069 .43901 L
.55092 .43912 L
.55115 .43919 L
.55139 .4395 L
.55162 .43972 L
.55185 .44012 L
.55208 .44066 L
.55232 .44151 L
.55255 .44203 L
.55278 .44242 L
.55301 .44263 L
.55325 .44298 L
.55348 .44305 L
.55371 .44321 L
.55394 .44343 L
.55418 .44398 L
.55441 .44416 L
.55464 .44426 L
.55487 .44431 L
.55511 .44465 L
.55534 .44478 L
.55557 .44506 L
.5558 .44557 L
.55604 .44651 L
.55627 .44701 L
.5565 .44734 L
.55673 .44755 L
.55697 .44807 L
.5572 .44823 L
.55743 .44851 L
.55766 .44891 L
.5579 .44987 L
.55813 .45032 L
.55836 .45078 L
.55859 .45113 L
Mistroke
.55883 .45203 L
.55906 .45256 L
.55929 .45339 L
.55952 .45435 L
.55976 .45594 L
.55999 .45689 L
.56022 .4577 L
.56045 .45822 L
.56069 .4591 L
.56092 .45944 L
.56115 .45989 L
.56138 .46035 L
.56162 .46135 L
.56185 .46175 L
.56208 .46204 L
.56231 .4622 L
.56255 .46279 L
.56278 .46304 L
.56301 .46343 L
.56324 .46404 L
.56348 .46516 L
.56371 .46576 L
.56394 .4661 L
.56417 .46627 L
.56441 .46672 L
.56464 .4668 L
.56487 .46697 L
.5651 .46725 L
.56534 .46804 L
.56557 .46837 L
.5658 .46865 L
.56603 .46882 L
.56627 .4694 L
.5665 .46976 L
.56673 .47038 L
.56696 .47119 L
.5672 .47248 L
.56743 .47329 L
.56766 .47389 L
.56789 .47422 L
.56813 .47474 L
.56836 .47486 L
.56859 .47507 L
.56882 .47533 L
.56906 .47599 L
.56929 .4762 L
.56952 .4763 L
.56975 .47632 L
.56999 .47665 L
.57022 .47677 L
Mistroke
.57045 .47704 L
.57068 .47757 L
.57092 .47853 L
.57115 .47907 L
.57138 .47936 L
.57161 .47952 L
.57185 .47993 L
.57208 .47999 L
.57231 .48014 L
.57254 .48041 L
.57278 .48118 L
.57301 .48151 L
.57324 .48185 L
.57347 .48211 L
.57371 .48284 L
.57394 .48332 L
.57417 .48409 L
.5744 .48502 L
.57464 .4865 L
.57487 .48743 L
.5751 .48819 L
.57533 .48867 L
.57557 .4894 L
.5758 .48965 L
.57603 .48999 L
.57626 .49032 L
.5765 .4911 L
.57673 .49136 L
.57696 .49151 L
.57719 .49158 L
.57743 .492 L
.57766 .49216 L
.57789 .49247 L
.57813 .49302 L
.57836 .49401 L
.57859 .49455 L
.57882 .49484 L
.57906 .49497 L
.57929 .49534 L
.57952 .49538 L
.57975 .4955 L
.57999 .49574 L
.58022 .49645 L
.58045 .49674 L
.58068 .49699 L
.58092 .49715 L
.58115 .49773 L
.58138 .49811 L
.58161 .49877 L
.58185 .49963 L
Mistroke
.58208 .501 L
.58231 .50186 L
.58254 .50253 L
.58278 .50292 L
.58301 .50353 L
.58324 .50371 L
.58347 .50399 L
.58371 .50433 L
.58394 .50512 L
.58417 .50538 L
.5844 .50553 L
.58464 .5056 L
.58487 .50603 L
.5851 .50618 L
.58533 .5065 L
.58557 .5071 L
.5858 .50821 L
.58603 .50881 L
.58626 .50918 L
.5865 .50939 L
.58673 .50994 L
.58696 .51007 L
.58719 .51033 L
.58743 .51071 L
.58766 .5117 L
.58789 .51216 L
.58812 .5126 L
.58836 .51293 L
.58859 .51383 L
.58882 .51437 L
.58905 .51523 L
.58929 .51625 L
.58952 .51792 L
.58975 .51895 L
.58998 .51982 L
.59022 .52037 L
.59045 .52128 L
.59068 .52162 L
.59091 .52207 L
.59115 .52253 L
.59138 .52352 L
.59161 .52391 L
.59184 .52418 L
.59208 .52432 L
.59231 .52487 L
.59254 .52509 L
.59277 .52544 L
.59301 .52602 L
.59324 .52709 L
.59347 .52766 L
Mistroke
.5937 .52798 L
.59394 .52814 L
.59417 .52856 L
.5944 .52863 L
.59463 .52877 L
.59487 .52901 L
.5951 .52972 L
.59533 .53003 L
.59556 .53028 L
.5958 .53044 L
.59603 .53099 L
.59626 .53134 L
.59649 .53193 L
.59673 .53268 L
.59696 .53388 L
.59719 .53465 L
.59742 .53524 L
.59766 .53558 L
.59789 .53609 L
.59812 .53623 L
.59835 .53644 L
.59859 .53667 L
.59882 .53724 L
.59905 .53743 L
.59928 .53751 L
.59952 .53752 L
.59975 .53778 L
.59998 .53787 L
.60021 .53806 L
.60045 .53847 L
.60068 .53921 L
.60091 .53962 L
.60114 .53983 L
.60138 .53993 L
.60161 .54018 L
.60184 .54018 L
.60207 .54024 L
.60231 .54038 L
.60254 .54089 L
.60277 .54109 L
.603 .54128 L
.60324 .54142 L
.60347 .5419 L
.6037 .54221 L
.60393 .54275 L
.60417 .54342 L
.6044 .54449 L
.60463 .54517 L
.60486 .54573 L
.6051 .54608 L
Mistroke
.60533 .5466 L
.60556 .54677 L
.60579 .54701 L
.60603 .54725 L
.60626 .5478 L
.60649 .54798 L
.60672 .5481 L
.60696 .54814 L
.60719 .54844 L
.60742 .54856 L
.60765 .54879 L
.60789 .5492 L
.60812 .54993 L
.60835 .55033 L
.60858 .55055 L
.60882 .55066 L
.60905 .55094 L
.60928 .55097 L
.60951 .55105 L
.60975 .55121 L
.60998 .55171 L
.61021 .5519 L
.61044 .55205 L
.61068 .55215 L
.61091 .55255 L
.61114 .55279 L
.61137 .55322 L
.61161 .5538 L
.61184 .55475 L
.61207 .55533 L
.6123 .5558 L
.61254 .55608 L
.61277 .55655 L
.613 .55671 L
.61323 .55696 L
.61347 .55723 L
.6137 .55785 L
.61393 .55809 L
.61416 .55826 L
.6144 .55835 L
.61463 .55871 L
.61486 .55886 L
.61509 .55913 L
.61533 .55956 L
.61556 .56035 L
.61579 .56079 L
.61602 .56108 L
.61626 .56127 L
.61649 .56167 L
.61672 .56179 L
Mistroke
.61695 .56198 L
.61719 .56224 L
.61742 .56289 L
.61765 .56318 L
.61789 .56343 L
.61812 .5636 L
.61835 .5641 L
.61858 .56436 L
.61882 .56479 L
.61905 .56532 L
.61928 .56625 L
.61951 .56681 L
.61975 .56727 L
.61998 .56758 L
.62021 .56812 L
.62044 .56834 L
.62068 .56864 L
.62091 .56895 L
.62114 .5696 L
.62137 .56989 L
.62161 .57013 L
.62184 .57027 L
.62207 .57065 L
.6223 .57081 L
.62254 .57106 L
.62277 .57138 L
.623 .57199 L
.62323 .57233 L
.62347 .57256 L
.6237 .5727 L
.62393 .57298 L
.62416 .57308 L
.6244 .57318 L
.62463 .57332 L
.62486 .57366 L
.62509 .57381 L
.62533 .57391 L
.62556 .57396 L
.62579 .57412 L
.62602 .57419 L
.62626 .5743 L
.62649 .57445 L
.62672 .57475 L
.62695 .57494 L
.62719 .57508 L
.62742 .57516 L
.62765 .5753 L
.62788 .57535 L
.62812 .57541 L
.62835 .57546 L
Mistroke
.62858 .57557 L
.62881 .57564 L
.62905 .57568 L
.62928 .57569 L
.62951 .5757 L
.62974 .57569 L
.62998 .57568 L
.63021 .57565 L
.63044 .57562 L
.63067 .57562 L
.63091 .57561 L
.63114 .5756 L
.63137 .57553 L
.6316 .57549 L
.63184 .57541 L
.63207 .57531 L
.6323 .5751 L
.63253 .57499 L
.63277 .57487 L
.633 .57476 L
.63323 .57452 L
.63346 .57437 L
.6337 .57414 L
.63393 .57388 L
.63416 .57347 L
.63439 .57324 L
.63463 .57306 L
.63486 .57295 L
.63509 .57272 L
.63532 .57265 L
.63556 .57253 L
.63579 .57238 L
.63602 .57203 L
.63625 .5719 L
.63649 .5718 L
.63672 .57173 L
.63695 .57149 L
.63718 .57137 L
.63742 .57118 L
.63765 .57088 L
.63788 .57035 L
.63811 .57007 L
.63835 .5699 L
.63858 .5698 L
.63881 .56953 L
.63904 .56946 L
.63928 .56931 L
.63951 .56909 L
.63974 .56856 L
.63997 .56832 L
Mistroke
.64021 .56809 L
.64044 .56791 L
.64067 .56745 L
.6409 .56717 L
.64114 .56672 L
.64137 .56617 L
.6416 .56528 L
.64183 .56475 L
.64207 .56434 L
.6423 .56411 L
.64253 .56369 L
.64276 .56356 L
.643 .56337 L
.64323 .56313 L
.64346 .56257 L
.64369 .56236 L
.64393 .56223 L
.64416 .56215 L
.64439 .5618 L
.64462 .56164 L
.64486 .56136 L
.64509 .56089 L
.64532 .56006 L
.64555 .55961 L
.64579 .55934 L
.64602 .55919 L
.64625 .55882 L
.64648 .55874 L
.64672 .55857 L
.64695 .55832 L
.64718 .55763 L
.64741 .55734 L
.64765 .55706 L
.64788 .55686 L
.64811 .55627 L
.64834 .55591 L
.64858 .55531 L
.64881 .55455 L
.64904 .55334 L
.64927 .5526 L
.64951 .55203 L
.64974 .55169 L
.64997 .55113 L
.6502 .55097 L
.65044 .55071 L
.65067 .55042 L
.6509 .5497 L
.65113 .54944 L
.65137 .54929 L
.6516 .5492 L
Mistroke
.65183 .54877 L
.65206 .54858 L
.6523 .54822 L
.65253 .54763 L
.65276 .54657 L
.65299 .54599 L
.65323 .54564 L
.65346 .54544 L
.65369 .54497 L
.65392 .54488 L
.65416 .54467 L
.65439 .54435 L
.65462 .54351 L
.65485 .54314 L
.65509 .54281 L
.65532 .54257 L
.65555 .54185 L
.65578 .5414 L
.65602 .54067 L
.65625 .53974 L
.65648 .53824 L
.65672 .53732 L
.65695 .53661 L
.65718 .53617 L
.65741 .53546 L
.65765 .53523 L
.65788 .5349 L
.65811 .53452 L
.65834 .53363 L
.65858 .5333 L
.65881 .5331 L
.65904 .53299 L
.65927 .53246 L
.65951 .53224 L
.65974 .53182 L
.65997 .53114 L
.6602 .5299 L
.66044 .52921 L
.66067 .5288 L
.6609 .52857 L
.66113 .52802 L
.66137 .52789 L
.6616 .52765 L
.66183 .52728 L
.66206 .5263 L
.6623 .52588 L
.66253 .5255 L
.66276 .52523 L
.66299 .52442 L
.66323 .52393 L
Mistroke
.66346 .52313 L
.66369 .5221 L
.66392 .52043 L
.66416 .51941 L
.66439 .51861 L
.66462 .51812 L
.66485 .5173 L
.66509 .51703 L
.66532 .51664 L
.66555 .5162 L
.66578 .51519 L
.66602 .51481 L
.66625 .51456 L
.66648 .51442 L
.66671 .51383 L
.66695 .51359 L
.66718 .51314 L
.66741 .51242 L
.66764 .51111 L
.66788 .51039 L
.66811 .50994 L
.66834 .50969 L
.66857 .5091 L
.66881 .50896 L
.66904 .50871 L
.66927 .50833 L
.6695 .50733 L
.66974 .5069 L
.66997 .50651 L
.6702 .50624 L
.67043 .50544 L
.67067 .50495 L
.6709 .50416 L
.67113 .50317 L
.67136 .50154 L
.6716 .50054 L
.67183 .49974 L
.67206 .49925 L
.67229 .49845 L
.67253 .49818 L
.67276 .4978 L
.67299 .49739 L
.67322 .49644 L
.67346 .49609 L
.67369 .49585 L
.67392 .49574 L
.67415 .49522 L
.67439 .49501 L
.67462 .49463 L
.67485 .494 L
Mistroke
.67508 .49286 L
.67532 .49222 L
.67555 .49185 L
.67578 .49165 L
.67601 .49118 L
.67625 .49109 L
.67648 .49092 L
.67671 .49064 L
.67694 .48985 L
.67718 .48952 L
.67741 .48924 L
.67764 .48906 L
.67787 .48845 L
.67811 .48808 L
.67834 .48746 L
.67857 .48666 L
.6788 .48535 L
.67904 .48453 L
.67927 .48388 L
.6795 .48349 L
.67973 .48286 L
.67997 .48265 L
.6802 .48236 L
.68043 .48204 L
.68066 .4813 L
.6809 .48102 L
.68113 .48084 L
.68136 .48076 L
.68159 .48036 L
.68183 .4802 L
.68206 .4799 L
.68229 .4794 L
.68252 .4785 L
.68276 .47799 L
.68299 .47768 L
.68322 .47751 L
.68345 .47713 L
.68369 .47705 L
.68392 .47691 L
.68415 .4767 L
.68438 .47608 L
.68462 .47583 L
.68485 .47561 L
.68508 .47546 L
.68531 .47498 L
.68555 .4747 L
.68578 .47423 L
.68601 .47363 L
.68624 .47263 L
.68648 .47201 L
Mistroke
.68671 .4715 L
.68694 .47119 L
.68717 .47068 L
.68741 .47049 L
.68764 .47025 L
.68787 .47 L
.6881 .46945 L
.68834 .46923 L
.68857 .46907 L
.6888 .469 L
.68903 .46871 L
.68927 .46859 L
.6895 .46838 L
.68973 .46806 L
.68996 .46746 L
.6902 .46712 L
.69043 .46692 L
.69066 .46682 L
.69089 .4666 L
.69113 .46656 L
.69136 .46651 L
.69159 .46641 L
.69182 .4661 L
.69206 .46598 L
.69229 .46591 L
.69252 .46588 L
.69275 .46568 L
.69299 .46558 L
.69322 .46539 L
.69345 .46511 L
.69368 .46462 L
.69392 .46432 L
.69415 .46407 L
.69438 .46393 L
.69461 .46369 L
.69485 .46361 L
.69508 .46349 L
.69531 .46337 L
.69555 .46311 L
.69578 .46299 L
.69601 .46291 L
.69624 .46287 L
.69648 .46274 L
.69671 .46269 L
.69694 .4626 L
.69717 .46247 L
.69741 .46221 L
.69764 .46206 L
.69787 .46195 L
.6981 .46188 L
Mistroke
.69834 .46178 L
.69857 .46175 L
.6988 .46172 L
.69903 .46169 L
.69927 .46159 L
.6995 .46156 L
.69973 .46155 L
.69996 .46157 L
.7002 .46155 L
.70043 .46157 L
.70066 .46158 L
.70089 .46158 L
.70113 .46153 L
.70136 .4615 L
.70159 .46146 L
.70182 .46142 L
.70206 .46134 L
.70229 .46129 L
.70252 .46123 L
.70275 .46118 L
.70299 .46112 L
.70322 .46106 L
.70345 .46098 L
.70368 .46094 L
.70392 .46092 L
.70415 .46091 L
.70438 .46091 L
.70461 .46098 L
.70485 .46108 L
.70508 .46112 L
.70531 .46112 L
.70554 .46111 L
.70578 .46114 L
.70601 .46113 L
.70624 .46116 L
.70647 .46123 L
.70671 .46144 L
.70694 .46153 L
.70717 .46165 L
.7074 .46175 L
.70764 .46203 L
.70787 .46223 L
.7081 .46256 L
.70833 .46294 L
.70857 .46352 L
.7088 .46387 L
.70903 .46415 L
.70926 .4643 L
.7095 .46456 L
.70973 .46462 L
Mistroke
.70996 .46472 L
.71019 .46486 L
.71043 .4652 L
.71066 .4653 L
.71089 .46534 L
.71112 .46537 L
.71136 .4656 L
.71159 .46571 L
.71182 .46591 L
.71205 .46629 L
.71229 .46695 L
.71252 .4673 L
.71275 .46749 L
.71298 .46759 L
.71322 .4679 L
.71345 .46795 L
.71368 .4681 L
.71391 .46835 L
.71415 .469 L
.71438 .46928 L
.71461 .46956 L
.71484 .46978 L
.71508 .47041 L
.71531 .47081 L
.71554 .47146 L
.71577 .47227 L
.71601 .47355 L
.71624 .47433 L
.71647 .47494 L
.7167 .4753 L
.71694 .47591 L
.71717 .47609 L
.7174 .47638 L
.71763 .47673 L
.71787 .47754 L
.7181 .47782 L
.71833 .47799 L
.71856 .4781 L
.7188 .4786 L
.71903 .47882 L
.71926 .47923 L
.71949 .47992 L
.71973 .48114 L
.71996 .4818 L
.72019 .4822 L
.72042 .48242 L
.72066 .48298 L
.72089 .4831 L
.72112 .48337 L
.72135 .48378 L
Mistroke
.72159 .48484 L
.72182 .48531 L
.72205 .48574 L
.72228 .48606 L
.72252 .48698 L
.72275 .48755 L
.72298 .48848 L
.72321 .48965 L
.72345 .49154 L
.72368 .49269 L
.72391 .49358 L
.72414 .49413 L
.72438 .49506 L
.72461 .49535 L
.72484 .4958 L
.72507 .49632 L
.72531 .49753 L
.72554 .49799 L
.72577 .4983 L
.726 .49848 L
.72624 .49923 L
.72647 .49956 L
.7267 .50015 L
.72693 .50108 L
.72717 .50277 L
.7274 .5037 L
.72763 .50427 L
.72786 .5046 L
.7281 .50539 L
.72833 .50557 L
.72856 .50593 L
.72879 .50645 L
.72903 .50781 L
.72926 .50841 L
.72949 .50894 L
.72972 .50933 L
.72996 .51045 L
.73019 .51113 L
.73042 .51223 L
.73065 .51361 L
.73089 .51588 L
.73112 .51725 L
.73135 .51833 L
.73158 .51899 L
.73182 .52009 L
.73205 .52046 L
.73228 .52098 L
.73251 .52157 L
.73275 .52294 L
.73298 .52346 L
Mistroke
.73321 .52381 L
.73344 .524 L
.73368 .5248 L
.73391 .52516 L
.73414 .52578 L
.73438 .52679 L
.73461 .52859 L
.73484 .52959 L
.73507 .5302 L
.73531 .53053 L
.73554 .53129 L
.73577 .53145 L
.736 .53177 L
.73624 .53225 L
.73647 .53357 L
.7367 .53413 L
.73693 .5346 L
.73717 .53491 L
.7374 .53594 L
.73763 .53656 L
.73786 .53759 L
.7381 .53894 L
.73833 .54115 L
.73856 .54251 L
.73879 .54355 L
.73903 .54418 L
.73926 .54523 L
.73949 .54557 L
.73972 .54606 L
.73996 .54663 L
.74019 .54797 L
.74042 .54847 L
.74065 .54882 L
.74089 .54899 L
.74112 .54978 L
.74135 .55012 L
.74158 .55074 L
.74182 .55172 L
.74205 .55351 L
.74228 .55451 L
.74251 .55514 L
.74275 .55551 L
.74298 .55633 L
.74321 .55652 L
.74344 .55687 L
.74368 .55738 L
.74391 .5587 L
.74414 .55927 L
.74437 .55977 L
.74461 .56011 L
Mistroke
.74484 .56116 L
.74507 .56176 L
.7453 .56276 L
.74554 .56403 L
.74577 .56614 L
.746 .56743 L
.74623 .56847 L
.74647 .56911 L
.7467 .57018 L
.74693 .57056 L
.74716 .57108 L
.7474 .57165 L
.74763 .57292 L
.74786 .57343 L
.74809 .57379 L
.74833 .57397 L
.74856 .57469 L
.74879 .575 L
.74902 .57553 L
.74926 .57635 L
.74949 .57785 L
.74972 .57868 L
.74995 .57921 L
.75019 .5795 L
.75042 .58014 L
.75065 .58029 L
.75088 .58053 L
.75112 .58089 L
.75135 .58188 L
.75158 .58229 L
.75181 .58261 L
.75205 .58279 L
.75228 .58347 L
.75251 .58385 L
.75274 .5845 L
.75298 .58536 L
.75321 .58683 L
.75344 .58773 L
.75367 .58844 L
.75391 .58886 L
.75414 .58958 L
.75437 .58982 L
.7546 .59016 L
.75484 .59054 L
.75507 .5914 L
.7553 .59175 L
.75553 .592 L
.75577 .59211 L
.756 .59258 L
.75623 .59276 L
Mistroke
.75646 .59309 L
.7567 .5936 L
.75693 .59455 L
.75716 .5951 L
.75739 .59546 L
.75763 .59567 L
.75786 .5961 L
.75809 .59622 L
.75832 .59637 L
.75856 .59658 L
.75879 .59716 L
.75902 .59741 L
.75925 .59761 L
.75949 .59773 L
.75972 .59812 L
.75995 .59833 L
.76018 .59867 L
.76042 .59909 L
.76065 .59985 L
.76088 .60032 L
.76111 .60073 L
.76135 .60099 L
.76158 .6014 L
.76181 .60158 L
.76204 .60178 L
.76228 .60195 L
.76251 .60231 L
.76274 .60248 L
.76297 .6026 L
.76321 .60265 L
.76344 .60278 L
.76367 .60283 L
.7639 .6029 L
.76414 .60298 L
.76437 .60314 L
.7646 .60325 L
.76483 .6033 L
.76507 .60332 L
.7653 .6033 L
.76553 .60327 L
.76576 .60319 L
.766 .60309 L
.76623 .60293 L
.76646 .60283 L
.76669 .60268 L
.76693 .60253 L
.76716 .60227 L
.76739 .60209 L
.76762 .60184 L
.76786 .60158 L
Mistroke
.76809 .6012 L
.76832 .601 L
.76855 .60083 L
.76879 .60072 L
.76902 .6005 L
.76925 .60043 L
.76948 .60032 L
.76972 .60018 L
.76995 .59986 L
.77018 .59976 L
.77041 .59968 L
.77065 .59962 L
.77088 .59937 L
.77111 .59925 L
.77134 .59905 L
.77158 .59873 L
.77181 .59818 L
.77204 .5979 L
.77227 .59775 L
.77251 .59767 L
.77274 .59742 L
.77297 .59737 L
.7732 .59723 L
.77344 .59701 L
.77367 .59645 L
.7739 .59621 L
.77414 .59597 L
.77437 .5958 L
.7746 .5953 L
.77483 .59498 L
.77507 .59445 L
.7753 .59378 L
.77553 .59274 L
.77576 .59211 L
.776 .59166 L
.77623 .59141 L
.77646 .59098 L
.77669 .59089 L
.77693 .59071 L
.77716 .59045 L
.77739 .5898 L
.77762 .58959 L
.77786 .58947 L
.77809 .58941 L
.77832 .58898 L
.77855 .58879 L
.77879 .58842 L
.77902 .58778 L
.77925 .58663 L
.77948 .58601 L
Mistroke
.77972 .58564 L
.77995 .58542 L
.78018 .58487 L
.78041 .58475 L
.78065 .58447 L
.78088 .58406 L
.78111 .58298 L
.78134 .58251 L
.78158 .58203 L
.78181 .58166 L
.78204 .58066 L
.78227 .58003 L
.78251 .57902 L
.78274 .5778 L
.78297 .57584 L
.7832 .57466 L
.78344 .57371 L
.78367 .57314 L
.7839 .57218 L
.78413 .57188 L
.78437 .57144 L
.7846 .57094 L
.78483 .56977 L
.78506 .56936 L
.7853 .5691 L
.78553 .56895 L
.78576 .56824 L
.78599 .56793 L
.78623 .56737 L
.78646 .56643 L
.78669 .56476 L
.78692 .56385 L
.78716 .56332 L
.78739 .56305 L
.78762 .56233 L
.78785 .5622 L
.78809 .56189 L
.78832 .56139 L
.78855 .56004 L
.78878 .55947 L
.78902 .55896 L
.78925 .5586 L
.78948 .55747 L
.78971 .55676 L
.78995 .55558 L
.79018 .55407 L
.79041 .55164 L
.79064 .55016 L
.79088 .54902 L
.79111 .54835 L
Mistroke
.79134 .54723 L
.79157 .5469 L
.79181 .54639 L
.79204 .54577 L
.79227 .5443 L
.7925 .54378 L
.79274 .54345 L
.79297 .54328 L
.7932 .5424 L
.79343 .54203 L
.79367 .54133 L
.7939 .54014 L
.79413 .538 L
.79436 .53682 L
.7946 .5361 L
.79483 .53568 L
.79506 .53467 L
.79529 .53444 L
.79553 .53396 L
.79576 .53328 L
.79599 .53147 L
.79622 .53068 L
.79646 .52992 L
.79669 .52937 L
.79692 .52781 L
.79715 .52686 L
.79739 .52533 L
.79762 .52344 L
.79785 .52036 L
.79808 .51849 L
.79832 .51698 L
.79855 .51605 L
.79878 .51451 L
.79901 .51398 L
.79925 .51325 L
.79948 .51245 L
.79971 .51061 L
.79994 .50993 L
.80018 .50948 L
.80041 .50924 L
.80064 .50819 L
.80087 .50775 L
.80111 .50697 L
.80134 .50569 L
.80157 .50337 L
.8018 .5021 L
.80204 .50135 L
.80227 .50096 L
.8025 .49998 L
.80273 .49979 L
Mistroke
.80297 .49939 L
.8032 .49877 L
.80343 .49704 L
.80366 .49631 L
.8039 .49568 L
.80413 .49526 L
.80436 .49389 L
.80459 .49306 L
.80483 .49166 L
.80506 .48986 L
.80529 .48694 L
.80552 .48513 L
.80576 .48373 L
.80599 .4829 L
.80622 .48154 L
.80645 .48113 L
.80669 .48051 L
.80692 .47979 L
.80715 .47811 L
.80738 .4775 L
.80762 .47712 L
.80785 .47694 L
.80808 .476 L
.80831 .47562 L
.80855 .47491 L
.80878 .47369 L
.80901 .47145 L
.80924 .47021 L
.80948 .46946 L
.80971 .46903 L
.80994 .46803 L
.81017 .46781 L
.81041 .46738 L
.81064 .46674 L
.81087 .465 L
.8111 .46424 L
.81134 .46354 L
.81157 .46303 L
.8118 .46156 L
.81203 .46065 L
.81227 .4592 L
.8125 .4574 L
.81273 .45447 L
.81297 .45266 L
.8132 .45118 L
.81343 .45027 L
.81366 .4488 L
.8139 .44828 L
.81413 .44759 L
.81436 .44687 L
Mistroke
.81459 .44524 L
.81483 .44463 L
.81506 .44424 L
.81529 .44406 L
.81552 .44318 L
.81576 .44284 L
.81599 .44222 L
.81622 .44118 L
.81645 .43926 L
.81669 .4382 L
.81692 .43761 L
.81715 .43731 L
.81738 .43657 L
.81762 .43645 L
.81785 .43621 L
.81808 .43577 L
.81831 .43448 L
.81855 .43395 L
.81878 .43351 L
.81901 .43324 L
.81924 .43224 L
.81948 .43163 L
.81971 .43057 L
.81994 .42919 L
.82017 .42694 L
.82041 .42553 L
.82064 .42443 L
.82087 .42378 L
.8211 .42276 L
.82134 .42244 L
.82157 .42199 L
.8218 .42148 L
.82203 .42027 L
.82227 .41984 L
.8225 .41959 L
.82273 .4195 L
.82296 .41887 L
.8232 .41865 L
.82343 .4182 L
.82366 .41737 L
.82389 .41583 L
.82413 .41498 L
.82436 .41448 L
.82459 .41419 L
.82482 .41352 L
.82506 .41338 L
.82529 .41312 L
.82552 .41271 L
.82575 .41155 L
.82599 .41104 L
Mistroke
.82622 .41057 L
.82645 .41023 L
.82668 .40922 L
.82692 .4086 L
.82715 .40761 L
.82738 .4064 L
.82761 .40442 L
.82785 .40318 L
.82808 .40213 L
.82831 .40147 L
.82854 .40043 L
.82878 .40004 L
.82901 .39953 L
.82924 .39905 L
.82947 .39799 L
.82971 .39759 L
.82994 .39732 L
.83017 .3972 L
.8304 .39667 L
.83064 .39648 L
.83087 .39614 L
.8311 .39557 L
.83133 .39449 L
.83157 .3939 L
.8318 .39359 L
.83203 .39345 L
.83226 .39308 L
.8325 .39305 L
.83273 .39298 L
.83296 .3928 L
.83319 .39219 L
.83343 .39195 L
.83366 .39179 L
.83389 .3917 L
.83412 .39128 L
.83436 .39102 L
.83459 .39053 L
.83482 .38988 L
.83505 .3888 L
.83529 .38811 L
.83552 .38757 L
.83575 .38725 L
.83598 .38679 L
.83622 .38665 L
.83645 .38644 L
.83668 .38623 L
.83691 .38571 L
.83715 .38553 L
.83738 .38544 L
.83761 .38543 L
Mistroke
.83784 .38521 L
.83808 .38516 L
.83831 .38502 L
.83854 .38472 L
.83877 .38413 L
.83901 .3838 L
.83924 .38362 L
.83947 .38351 L
.8397 .38326 L
.83994 .38322 L
.84017 .38314 L
.8404 .38301 L
.84063 .38259 L
.84087 .38241 L
.8411 .38223 L
.84133 .3821 L
.84156 .38172 L
.8418 .38148 L
.84203 .38112 L
.84226 .3807 L
.84249 .38 L
.84273 .37954 L
.84296 .37912 L
.84319 .37883 L
.84342 .3784 L
.84366 .3782 L
.84389 .37798 L
.84412 .37781 L
.84435 .37747 L
.84459 .37732 L
.84482 .37721 L
.84505 .37717 L
.84528 .37705 L
.84552 .37701 L
.84575 .37698 L
.84598 .37693 L
.84621 .37679 L
.84645 .37672 L
.84668 .37671 L
.84691 .37673 L
.84714 .37675 L
.84738 .37678 L
.84761 .37686 L
.84784 .37693 L
.84807 .37703 L
.84831 .37708 L
.84854 .37718 L
.84877 .37728 L
.849 .37743 L
.84924 .37753 L
Mistroke
.84947 .37764 L
.8497 .37775 L
.84993 .37793 L
.85017 .378 L
.8504 .37806 L
.85063 .37812 L
.85086 .37825 L
.8511 .3783 L
.85133 .37837 L
.85156 .37846 L
.8518 .37866 L
.85203 .37875 L
.85226 .37882 L
.85249 .3789 L
.85273 .3791 L
.85296 .37921 L
.85319 .37939 L
.85342 .37961 L
.85366 .37998 L
.85389 .38017 L
.85412 .38031 L
.85435 .38038 L
.85459 .38055 L
.85482 .3806 L
.85505 .3807 L
.85528 .38083 L
.85552 .38114 L
.85575 .38126 L
.85598 .38137 L
.85621 .38143 L
.85645 .38166 L
.85668 .38179 L
.85691 .38202 L
.85714 .38235 L
.85738 .38287 L
.85761 .38316 L
.85784 .38335 L
.85807 .38343 L
.85831 .38361 L
.85854 .38362 L
.85877 .38369 L
.859 .38382 L
.85924 .38417 L
.85947 .38429 L
.8597 .38435 L
.85993 .38439 L
.86017 .38463 L
.8604 .38474 L
.86063 .38498 L
.86086 .38537 L
Mistroke
.8611 .38607 L
.86133 .38645 L
.86156 .3867 L
.86179 .38685 L
.86203 .38721 L
.86226 .3873 L
.86249 .3875 L
.86272 .38777 L
.86296 .38844 L
.86319 .38874 L
.86342 .38902 L
.86365 .38924 L
.86389 .38983 L
.86412 .39018 L
.86435 .39073 L
.86458 .39142 L
.86482 .39256 L
.86505 .39323 L
.86528 .39376 L
.86551 .3941 L
.86575 .39469 L
.86598 .39489 L
.86621 .39519 L
.86644 .39553 L
.86668 .3963 L
.86691 .3966 L
.86714 .39683 L
.86737 .39697 L
.86761 .39748 L
.86784 .39771 L
.86807 .3981 L
.8683 .39868 L
.86854 .39973 L
.86877 .40031 L
.869 .40069 L
.86923 .40091 L
.86947 .40142 L
.8697 .40156 L
.86993 .40181 L
.87016 .40214 L
.8704 .40298 L
.87063 .40335 L
.87086 .40367 L
.87109 .4039 L
.87133 .40456 L
.87156 .40495 L
.87179 .40557 L
.87202 .40636 L
.87226 .40765 L
.87249 .40843 L
Mistroke
.87272 .40903 L
.87295 .40938 L
.87319 .40999 L
.87342 .41018 L
.87365 .41045 L
.87388 .41077 L
.87412 .41153 L
.87435 .41181 L
.87458 .41198 L
.87481 .41207 L
.87505 .41249 L
.87528 .41267 L
.87551 .413 L
.87574 .41355 L
.87598 .41454 L
.87621 .41509 L
.87644 .41542 L
.87667 .41559 L
.87691 .416 L
.87714 .41608 L
.87737 .41625 L
.8776 .41652 L
.87784 .41726 L
.87807 .41758 L
.8783 .41786 L
.87853 .41805 L
.87877 .41865 L
.879 .41901 L
.87923 .41962 L
.87946 .42041 L
.8797 .42168 L
.87993 .42246 L
.88016 .42307 L
.88039 .42344 L
.88063 .42403 L
.88086 .42422 L
.88109 .42449 L
.88132 .42479 L
.88156 .42551 L
.88179 .42577 L
.88202 .42594 L
.88225 .42602 L
.88249 .42644 L
.88272 .42661 L
.88295 .42694 L
.88318 .42747 L
.88342 .42845 L
.88365 .42899 L
.88388 .42933 L
.88411 .42951 L
Mistroke
.88435 .42995 L
.88458 .43004 L
.88481 .43022 L
.88504 .43048 L
.88528 .43121 L
.88551 .43152 L
.88574 .43181 L
.88597 .43202 L
.88621 .43263 L
.88644 .43301 L
.88667 .43363 L
.8869 .4344 L
.88714 .43564 L
.88737 .43642 L
.8876 .43704 L
.88783 .43742 L
.88807 .43801 L
.8883 .43821 L
.88853 .43848 L
.88876 .43876 L
.889 .43942 L
.88923 .43966 L
.88946 .43979 L
.88969 .43984 L
.88993 .44018 L
.89016 .44031 L
.89039 .44056 L
.89063 .441 L
.89086 .44181 L
.89109 .44226 L
.89132 .4425 L
.89156 .44262 L
.89179 .44292 L
.89202 .44296 L
.89225 .44306 L
.89249 .44325 L
.89272 .44382 L
.89295 .44405 L
.89318 .44424 L
.89342 .44436 L
.89365 .4448 L
.89388 .44507 L
.89411 .44556 L
.89435 .4462 L
.89458 .44723 L
.89481 .44788 L
.89504 .44839 L
.89528 .44869 L
.89551 .44918 L
.89574 .44933 L
Mistroke
.89597 .44955 L
.89621 .44982 L
.89644 .45043 L
.89667 .45065 L
.8969 .45079 L
.89714 .45085 L
.89737 .45119 L
.8976 .45131 L
.89783 .45155 L
.89807 .45197 L
.8983 .45277 L
.89853 .4532 L
.89876 .45348 L
.899 .45366 L
.89923 .45408 L
.89946 .4542 L
.89969 .4544 L
.89993 .45467 L
.90016 .45537 L
.90039 .45569 L
.90062 .45602 L
.90086 .45625 L
.90109 .45687 L
.90132 .45723 L
.90155 .45779 L
.90179 .45844 L
.90202 .4595 L
.90225 .46017 L
.90248 .46074 L
.90272 .46111 L
.90295 .4617 L
.90318 .46193 L
.90341 .46222 L
.90365 .46249 L
.90388 .46307 L
.90411 .46329 L
.90434 .46344 L
.90458 .4635 L
.90481 .46377 L
.90504 .46385 L
.90527 .46398 L
.90551 .46422 L
.90574 .4647 L
.90597 .46495 L
.9062 .46506 L
.90644 .46509 L
.90667 .46522 L
.9069 .46521 L
.90713 .46521 L
.90737 .46526 L
Mistroke
.9076 .4655 L
.90783 .4656 L
.90806 .46566 L
.9083 .46569 L
.90853 .46584 L
.90876 .46596 L
.90899 .46618 L
.90923 .46646 L
.90946 .46689 L
.90969 .46719 L
.90992 .46742 L
.91016 .46753 L
.91039 .46765 L
.91062 .46766 L
.91085 .46768 L
.91109 .46769 L
.91132 .46776 L
.91155 .46775 L
.91178 .46768 L
.91202 .46761 L
.91225 .46757 L
.91248 .46751 L
.91271 .46745 L
.91295 .46749 L
.91318 .4676 L
.91341 .46765 L
.91364 .46763 L
.91388 .46761 L
.91411 .4676 L
.91434 .46756 L
.91457 .46752 L
.91481 .46751 L
.91504 .46759 L
.91527 .46763 L
.9155 .4677 L
.91574 .46778 L
.91597 .46797 L
.9162 .46813 L
.91643 .46838 L
.91667 .46865 L
.9169 .46902 L
.91713 .46929 L
.91736 .46955 L
.9176 .46972 L
.91783 .46992 L
.91806 .47 L
.91829 .47008 L
.91853 .47012 L
.91876 .47019 L
.91899 .47018 L
Mistroke
.91922 .47015 L
.91946 .4701 L
.91969 .47009 L
.91992 .47006 L
.92015 .47002 L
.92039 .47004 L
.92062 .47008 L
.92085 .47009 L
.92108 .47003 L
.92132 .46996 L
.92155 .46988 L
.92178 .4698 L
.92201 .46971 L
.92225 .46965 L
.92248 .46963 L
.92271 .4696 L
.92294 .46957 L
.92318 .46954 L
.92341 .46957 L
.92364 .46963 L
.92387 .46977 L
.92411 .46996 L
.92434 .47021 L
.92457 .47039 L
.9248 .47053 L
.92504 .4706 L
.92527 .47067 L
.9255 .47067 L
.92573 .47069 L
.92597 .47073 L
.9262 .47083 L
.92643 .47084 L
.92666 .47081 L
.9269 .47078 L
.92713 .47082 L
.92736 .47082 L
.92759 .47086 L
.92783 .471 L
.92806 .47127 L
.92829 .47141 L
.92852 .47147 L
.92876 .47151 L
.92899 .47165 L
.92922 .47168 L
.92945 .47175 L
.92969 .47189 L
.92992 .47224 L
.93015 .47241 L
.93039 .47259 L
.93062 .47274 L
Mistroke
.93085 .47313 L
.93108 .47338 L
.93132 .47376 L
.93155 .47421 L
.93178 .47494 L
.93201 .47538 L
.93225 .47577 L
.93248 .47603 L
.93271 .47647 L
.93294 .47665 L
.93318 .4769 L
.93341 .47715 L
.93364 .47766 L
.93387 .47787 L
.93411 .47804 L
.93434 .47815 L
.93457 .47847 L
.9348 .47861 L
.93504 .47883 L
.93527 .47916 L
.9355 .47975 L
.93573 .48005 L
.93597 .48024 L
.9362 .48035 L
.93643 .48061 L
.93666 .48067 L
.9369 .48079 L
.93713 .48096 L
.93736 .48141 L
.93759 .4816 L
.93783 .48176 L
.93806 .48186 L
.93829 .4822 L
.93852 .48239 L
.93876 .48272 L
.93899 .48314 L
.93922 .48384 L
.93945 .48426 L
.93969 .48458 L
.93992 .48476 L
.94015 .48508 L
.94038 .48518 L
.94062 .48533 L
.94085 .48551 L
.94108 .48594 L
.94131 .4861 L
.94155 .48621 L
.94178 .48626 L
.94201 .48649 L
.94224 .48659 L
Mistroke
.94248 .48678 L
.94271 .48709 L
.94294 .48765 L
.94317 .48796 L
.94341 .48815 L
.94364 .48826 L
.94387 .4885 L
.9441 .48855 L
.94434 .48865 L
.94457 .48882 L
.9448 .48925 L
.94503 .48944 L
.94527 .4896 L
.9455 .48971 L
.94573 .49006 L
.94596 .49026 L
.9462 .4906 L
.94643 .49103 L
.94666 .49176 L
.94689 .4922 L
.94713 .49255 L
.94736 .49277 L
.94759 .49314 L
.94782 .49327 L
.94806 .49346 L
.94829 .49366 L
.94852 .49413 L
.94875 .49431 L
.94899 .49446 L
.94922 .49454 L
.94945 .49484 L
.94968 .49497 L
.94992 .49519 L
.95015 .49551 L
.95038 .49609 L
.95061 .49642 L
.95085 .49664 L
.95108 .49677 L
.95131 .49705 L
.95154 .49712 L
.95178 .49724 L
.95201 .49739 L
.95224 .49778 L
.95247 .49795 L
.95271 .49809 L
.95294 .49819 L
.95317 .49848 L
.9534 .49864 L
.95364 .49891 L
.95387 .49925 L
Mistroke
.9541 .49982 L
.95433 .50017 L
.95457 .50045 L
.9548 .50061 L
.95503 .50088 L
.95526 .50098 L
.9555 .5011 L
.95573 .50123 L
.95596 .50153 L
.95619 .50165 L
.95643 .50172 L
.95666 .50175 L
.95689 .5019 L
.95712 .50196 L
.95736 .50208 L
.95759 .50227 L
.95782 .5026 L
.95805 .5028 L
.95829 .50291 L
.95852 .50295 L
.95875 .50306 L
.95898 .50306 L
.95922 .50308 L
.95945 .50313 L
.95968 .50329 L
.95991 .50335 L
.96015 .50337 L
.96038 .50337 L
.96061 .50345 L
.96084 .50349 L
.96108 .50359 L
.96131 .50376 L
.96154 .50404 L
.96177 .50422 L
.96201 .50435 L
.96224 .50443 L
.96247 .50455 L
.9627 .50459 L
.96294 .50465 L
.96317 .50473 L
.9634 .50492 L
.96363 .505 L
.96387 .50506 L
.9641 .5051 L
.96433 .50522 L
.96456 .50527 L
.9648 .50537 L
.96503 .50551 L
.96526 .50576 L
.96549 .50591 L
Mistroke
.96573 .50604 L
.96596 .50612 L
.96619 .50628 L
.96642 .50634 L
.96666 .50642 L
.96689 .5065 L
.96712 .50668 L
.96735 .50677 L
.96759 .50685 L
.96782 .5069 L
.96805 .50704 L
.96828 .50711 L
.96852 .50719 L
.96875 .50728 L
.96898 .50747 L
.96922 .50758 L
.96945 .50769 L
.96968 .50777 L
.96991 .50792 L
.97015 .508 L
.97038 .50809 L
.97061 .50815 L
.97084 .50826 L
.97108 .50833 L
.97131 .5084 L
.97154 .50843 L
.97177 .50848 L
.97201 .50851 L
.97224 .50852 L
.97247 .50851 L
.9727 .50849 L
.97294 .50848 L
.97317 .50848 L
.9734 .50846 L
.97363 .5084 L
.97387 .50837 L
.9741 .50831 L
.97433 .50824 L
.97456 .50807 L
.9748 .50798 L
.97503 .50785 L
.97526 .50773 L
.97549 .50749 L
.97573 .50733 L
.97596 .5071 L
.97619 .50686 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],

Cell["\<\
We can also try using the Daubechies filter of order 2 to do the \
denoising.\
\>", "MathCaption",
  CellTags->{"S2.1.2", "2.18"}],

Cell["\<\
(d2 = DaubechiesFilter[2];
 wtdata = WaveletTransform[data, d2];
 Compress[Rest[wtdata], 1.5, Shrinking -> True];)\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.2"],

Cell["\<\
Different wavelets give different \"denoised\" signals. Note that \
the signal reflects the nonsmoothness of the Daubechies wavelets \
themselves.\
\>", "MathCaption",
  CellTags->{"S2.1.2", "2.19"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[InverseWaveletTransform[
Join[{wtdata[[1]]}, %], d2],
PlotJoined -> True, AxesLabel -> {\"x\", \"u(x)\"}]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.414212 0.148386 [
[.25632 .40171 -12 -9 ]
[.25632 .40171 12 0 ]
[.48884 .40171 -12 -9 ]
[.48884 .40171 12 0 ]
[.72135 .40171 -12 -9 ]
[.72135 .40171 12 0 ]
[.95387 .40171 -12 -9 ]
[.95387 .40171 12 0 ]
[1.025 .41421 0 -4.5 ]
[1.025 .41421 6 4.5 ]
[.01131 .11744 -12 -4.5 ]
[.01131 .11744 0 4.5 ]
[.01131 .26583 -12 -4.5 ]
[.01131 .26583 0 4.5 ]
[.01131 .5626 -6 -4.5 ]
[.01131 .5626 0 4.5 ]
[.02381 .64303 -12 0 ]
[.02381 .64303 12 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 .41421 m
.25632 .42046 L
s
[(1000)] .25632 .40171 0 1 Mshowa
.48884 .41421 m
.48884 .42046 L
s
[(2000)] .48884 .40171 0 1 Mshowa
.72135 .41421 m
.72135 .42046 L
s
[(3000)] .72135 .40171 0 1 Mshowa
.95387 .41421 m
.95387 .42046 L
s
[(4000)] .95387 .40171 0 1 Mshowa
.125 Mabswid
.07031 .41421 m
.07031 .41796 L
s
.11682 .41421 m
.11682 .41796 L
s
.16332 .41421 m
.16332 .41796 L
s
.20982 .41421 m
.20982 .41796 L
s
.30283 .41421 m
.30283 .41796 L
s
.34933 .41421 m
.34933 .41796 L
s
.39583 .41421 m
.39583 .41796 L
s
.44234 .41421 m
.44234 .41796 L
s
.53534 .41421 m
.53534 .41796 L
s
.58185 .41421 m
.58185 .41796 L
s
.62835 .41421 m
.62835 .41796 L
s
.67485 .41421 m
.67485 .41796 L
s
.76786 .41421 m
.76786 .41796 L
s
.81436 .41421 m
.81436 .41796 L
s
.86086 .41421 m
.86086 .41796 L
s
.90737 .41421 m
.90737 .41796 L
s
.25 Mabswid
0 .41421 m
1 .41421 L
s
[(x)] 1.025 .41421 -1 0 Mshowa
.02381 .11744 m
.03006 .11744 L
s
[(-2)] .01131 .11744 1 0 Mshowa
.02381 .26583 m
.03006 .26583 L
s
[(-1)] .01131 .26583 1 0 Mshowa
.02381 .5626 m
.03006 .5626 L
s
[(1)] .01131 .5626 1 0 Mshowa
.125 Mabswid
.02381 .14712 m
.02756 .14712 L
s
.02381 .17679 m
.02756 .17679 L
s
.02381 .20647 m
.02756 .20647 L
s
.02381 .23615 m
.02756 .23615 L
s
.02381 .2955 m
.02756 .2955 L
s
.02381 .32518 m
.02756 .32518 L
s
.02381 .35486 m
.02756 .35486 L
s
.02381 .38453 m
.02756 .38453 L
s
.02381 .44389 m
.02756 .44389 L
s
.02381 .47357 m
.02756 .47357 L
s
.02381 .50324 m
.02756 .50324 L
s
.02381 .53292 m
.02756 .53292 L
s
.02381 .08776 m
.02756 .08776 L
s
.02381 .05809 m
.02756 .05809 L
s
.02381 .02841 m
.02756 .02841 L
s
.02381 .59227 m
.02756 .59227 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(u\\(x\\))] .02381 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02404 .55041 m
.02427 .54781 L
.02451 .54633 L
.02474 .54456 L
.02497 .54391 L
.0252 .54296 L
.02544 .54171 L
.02567 .54053 L
.0259 .54049 L
.02613 .54015 L
.02637 .5395 L
.0266 .53893 L
.02683 .53806 L
.02706 .53727 L
.0273 .53657 L
.02753 .53584 L
.02776 .53624 L
.02799 .53634 L
.02823 .53613 L
.02846 .53601 L
.02869 .53558 L
.02892 .53523 L
.02916 .53497 L
.02939 .53468 L
.02962 .5341 L
.02985 .53359 L
.03009 .53316 L
.03032 .53271 L
.03055 .53235 L
.03078 .53196 L
.03102 .53155 L
.03125 .53114 L
.03148 .53213 L
.03172 .53275 L
.03195 .533 L
.03218 .53334 L
.03241 .53331 L
.03265 .53338 L
.03288 .53355 L
.03311 .5337 L
.03334 .53346 L
.03358 .53333 L
.03381 .5333 L
.03404 .53325 L
.03427 .53329 L
.03451 .53331 L
.03474 .5333 L
.03497 .53329 L
.0352 .53291 L
.03544 .53264 L
Mistroke
.03567 .53246 L
.0359 .53226 L
.03613 .53215 L
.03637 .53202 L
.0366 .53186 L
.03683 .53171 L
.03706 .53166 L
.0373 .53159 L
.03753 .53148 L
.03776 .53139 L
.03799 .53126 L
.03823 .53115 L
.03846 .53104 L
.03869 .53093 L
.03892 .52237 L
.03916 .51607 L
.03939 .51204 L
.03962 .5074 L
.03985 .50503 L
.04009 .50204 L
.04032 .49846 L
.04055 .49503 L
.04078 .49387 L
.04102 .4921 L
.04125 .48973 L
.04148 .48751 L
.04171 .4847 L
.04195 .48204 L
.04218 .47955 L
.04241 .47701 L
.04264 .47673 L
.04288 .47585 L
.04311 .47437 L
.04334 .47304 L
.04357 .47111 L
.04381 .46934 L
.04404 .46774 L
.04427 .46609 L
.0445 .46383 L
.04474 .46174 L
.04497 .45981 L
.0452 .45784 L
.04543 .45602 L
.04567 .45417 L
.0459 .45227 L
.04613 .45038 L
.04636 .45076 L
.0466 .45053 L
.04683 .44969 L
.04706 .44902 L
Mistroke
.04729 .44774 L
.04753 .44662 L
.04776 .44566 L
.04799 .44467 L
.04822 .44306 L
.04846 .44162 L
.04869 .44034 L
.04892 .43901 L
.04915 .43785 L
.04939 .43665 L
.04962 .4354 L
.04985 .43416 L
.05008 .43232 L
.05032 .43064 L
.05055 .42912 L
.05078 .42755 L
.05101 .42616 L
.05125 .42471 L
.05148 .42323 L
.05171 .42175 L
.05194 .42044 L
.05218 .41908 L
.05241 .41768 L
.05264 .41629 L
.05287 .41486 L
.05311 .41344 L
.05334 .41204 L
.05357 .41062 L
.0538 .4199 L
.05404 .42632 L
.05427 .42987 L
.0545 .43419 L
.05473 .43564 L
.05497 .43786 L
.0552 .44085 L
.05543 .44364 L
.05566 .44356 L
.0559 .44424 L
.05613 .4457 L
.05636 .44694 L
.05659 .44896 L
.05683 .45077 L
.05706 .45237 L
.05729 .45403 L
.05752 .45283 L
.05776 .45239 L
.05799 .45272 L
.05822 .45284 L
.05845 .45373 L
.05869 .45442 L
Mistroke
.05892 .4549 L
.05915 .45544 L
.05938 .45674 L
.05962 .45784 L
.05985 .45873 L
.06008 .45968 L
.06031 .46042 L
.06055 .46121 L
.06078 .46206 L
.06101 .4629 L
.06124 .46087 L
.06148 .45961 L
.06171 .45912 L
.06194 .45842 L
.06217 .45849 L
.06241 .45835 L
.06264 .45801 L
.06287 .45772 L
.0631 .4582 L
.06334 .45848 L
.06357 .45855 L
.0638 .45867 L
.06403 .45859 L
.06427 .45856 L
.0645 .45859 L
.06473 .4586 L
.06496 .45939 L
.0652 .45996 L
.06543 .46033 L
.06566 .46076 L
.06589 .46098 L
.06613 .46125 L
.06636 .46158 L
.06659 .4619 L
.06682 .46201 L
.06706 .46217 L
.06729 .46239 L
.06752 .46259 L
.06775 .46285 L
.06799 .4631 L
.06822 .46333 L
.06845 .46356 L
.06868 .46093 L
.06892 .45907 L
.06915 .45797 L
.06938 .45667 L
.06961 .45614 L
.06985 .4554 L
.07008 .45446 L
.07031 .45357 L
Mistroke
.07055 .45345 L
.07078 .45312 L
.07101 .45258 L
.07124 .45211 L
.07148 .45142 L
.07171 .45079 L
.07194 .45022 L
.07217 .44963 L
.07241 .44981 L
.07264 .44978 L
.07287 .44955 L
.0731 .44937 L
.07334 .44899 L
.07357 .44866 L
.0738 .44839 L
.07403 .4481 L
.07427 .44761 L
.0745 .44717 L
.07473 .44679 L
.07496 .44639 L
.0752 .44605 L
.07543 .44569 L
.07566 .44532 L
.07589 .44495 L
.07613 .44535 L
.07636 .44555 L
.07659 .44553 L
.07682 .44558 L
.07706 .44542 L
.07729 .44531 L
.07752 .44526 L
.07775 .44519 L
.07799 .44492 L
.07822 .4447 L
.07845 .44454 L
.07868 .44436 L
.07892 .44424 L
.07915 .4441 L
.07938 .44395 L
.07961 .4438 L
.07985 .44345 L
.08008 .44315 L
.08031 .44291 L
.08054 .44265 L
.08078 .44245 L
.08101 .44223 L
.08124 .442 L
.08147 .44177 L
.08171 .4416 L
.08194 .44141 L
Mistroke
.08217 .44121 L
.0824 .44101 L
.08264 .44079 L
.08287 .44058 L
.0831 .44038 L
.08333 .44017 L
.08357 .4361 L
.0838 .43306 L
.08403 .43106 L
.08426 .42879 L
.0845 .42754 L
.08473 .42602 L
.08496 .42423 L
.08519 .4225 L
.08543 .42182 L
.08566 .42085 L
.08589 .41961 L
.08612 .41844 L
.08636 .417 L
.08659 .41563 L
.08682 .41433 L
.08705 .41301 L
.08729 .41273 L
.08752 .41217 L
.08775 .41134 L
.08798 .41058 L
.08822 .40954 L
.08845 .40857 L
.08868 .40768 L
.08891 .40677 L
.08915 .40558 L
.08938 .40447 L
.08961 .40343 L
.08984 .40237 L
.09008 .40139 L
.09031 .40038 L
.09054 .39936 L
.09077 .39834 L
.09101 .39836 L
.09124 .39809 L
.09147 .39756 L
.0917 .39709 L
.09194 .39635 L
.09217 .39568 L
.0924 .39509 L
.09263 .39448 L
.09287 .39359 L
.0931 .39277 L
.09333 .39203 L
.09356 .39127 L
Mistroke
.0938 .39058 L
.09403 .38987 L
.09426 .38915 L
.09449 .38842 L
.09473 .38742 L
.09496 .3865 L
.09519 .38565 L
.09542 .38478 L
.09566 .38398 L
.09589 .38317 L
.09612 .38233 L
.09635 .3815 L
.09659 .38074 L
.09682 .37997 L
.09705 .37917 L
.09728 .37838 L
.09752 .37757 L
.09775 .37677 L
.09798 .37596 L
.09821 .37516 L
.09845 .37833 L
.09868 .38044 L
.09891 .38148 L
.09914 .3828 L
.09938 .38306 L
.09961 .38361 L
.09984 .38444 L
.10007 .3852 L
.10031 .38489 L
.10054 .38487 L
.10077 .38513 L
.101 .38532 L
.10124 .38579 L
.10147 .38618 L
.1017 .3865 L
.10193 .38684 L
.10217 .38611 L
.1024 .38567 L
.10263 .38552 L
.10286 .38529 L
.1031 .38534 L
.10333 .38532 L
.10356 .38522 L
.10379 .38514 L
.10403 .38535 L
.10426 .38548 L
.10449 .38553 L
.10472 .3856 L
.10496 .3856 L
.10519 .38562 L
Mistroke
.10542 .38566 L
.10565 .38569 L
.10589 .38466 L
.10612 .38391 L
.10635 .38345 L
.10658 .38292 L
.10682 .38266 L
.10705 .38234 L
.10728 .38193 L
.10751 .38155 L
.10775 .38145 L
.10798 .38127 L
.10821 .38102 L
.10844 .38079 L
.10868 .38048 L
.10891 .38019 L
.10914 .37993 L
.10938 .37965 L
.10961 .37967 L
.10984 .3796 L
.11007 .37946 L
.11031 .37934 L
.11054 .37915 L
.11077 .37897 L
.111 .37882 L
.11124 .37866 L
.11147 .37842 L
.1117 .3782 L
.11193 .37801 L
.11217 .37781 L
.1124 .37762 L
.11263 .37744 L
.11286 .37725 L
.1131 .37706 L
.11333 .38641 L
.11356 .3932 L
.11379 .39744 L
.11403 .40236 L
.11426 .40473 L
.11449 .40778 L
.11472 .41151 L
.11496 .41507 L
.11519 .41606 L
.11542 .41774 L
.11565 .42011 L
.11589 .42229 L
.11612 .42516 L
.11635 .42784 L
.11658 .43034 L
.11682 .43289 L
Mistroke
.11705 .43288 L
.11728 .43356 L
.11751 .43493 L
.11775 .4361 L
.11798 .43797 L
.11821 .43965 L
.11844 .44115 L
.11868 .44269 L
.11891 .44493 L
.11914 .44697 L
.11937 .44884 L
.11961 .45075 L
.11984 .45248 L
.12007 .45426 L
.1203 .45609 L
.12054 .45791 L
.12077 .45716 L
.121 .45711 L
.12123 .45774 L
.12147 .45818 L
.1217 .45931 L
.12193 .46026 L
.12216 .46102 L
.1224 .46183 L
.12263 .46333 L
.12286 .46465 L
.12309 .46578 L
.12333 .46696 L
.12356 .46795 L
.12379 .469 L
.12402 .47009 L
.12426 .47117 L
.12449 .47294 L
.12472 .47452 L
.12495 .47592 L
.12519 .47737 L
.12542 .47863 L
.12565 .47995 L
.12588 .48131 L
.12612 .48266 L
.12635 .48383 L
.12658 .48504 L
.12681 .48631 L
.12705 .48756 L
.12728 .48886 L
.12751 .49015 L
.12774 .49142 L
.12798 .4927 L
.12821 .48041 L
.12844 .47175 L
Mistroke
.12867 .46673 L
.12891 .46074 L
.12914 .45838 L
.12937 .45505 L
.1296 .45075 L
.12984 .4467 L
.13007 .44629 L
.1303 .44491 L
.13053 .44255 L
.13077 .44045 L
.131 .43738 L
.13123 .43457 L
.13146 .43203 L
.1317 .42941 L
.13193 .43042 L
.13216 .43047 L
.13239 .42954 L
.13263 .42886 L
.13286 .42722 L
.13309 .42584 L
.13332 .42471 L
.13356 .42352 L
.13379 .42136 L
.13402 .41945 L
.13425 .41781 L
.13449 .41609 L
.13472 .41464 L
.13495 .41311 L
.13518 .41152 L
.13542 .40995 L
.13565 .41201 L
.13588 .41309 L
.13611 .41321 L
.13635 .41358 L
.13658 .41298 L
.13681 .41264 L
.13704 .41256 L
.13728 .41241 L
.13751 .41129 L
.13774 .41043 L
.13797 .40983 L
.13821 .40916 L
.13844 .40875 L
.13867 .40827 L
.1389 .40772 L
.13914 .40719 L
.13937 .40569 L
.1396 .40444 L
.13983 .40346 L
.14007 .40241 L
Mistroke
.1403 .40162 L
.14053 .40075 L
.14076 .39982 L
.141 .39891 L
.14123 .39826 L
.14146 .39754 L
.14169 .39675 L
.14193 .39597 L
.14216 .39513 L
.14239 .39431 L
.14262 .3935 L
.14286 .39269 L
.14309 .40419 L
.14332 .41239 L
.14355 .4173 L
.14379 .42308 L
.14402 .42557 L
.14425 .42895 L
.14448 .4332 L
.14472 .43722 L
.14495 .43794 L
.14518 .43955 L
.14541 .44204 L
.14565 .44429 L
.14588 .44742 L
.14611 .45032 L
.14634 .45298 L
.14658 .45571 L
.14681 .45514 L
.14704 .45545 L
.14727 .45664 L
.14751 .4576 L
.14774 .45944 L
.14797 .46104 L
.1482 .46241 L
.14844 .46384 L
.14867 .46616 L
.1489 .46824 L
.14914 .47008 L
.14937 .47198 L
.1496 .47365 L
.14983 .47538 L
.15007 .47718 L
.1503 .47896 L
.15053 .47744 L
.15076 .4768 L
.151 .47705 L
.15123 .47706 L
.15146 .47795 L
.15169 .47861 L
Mistroke
.15193 .47903 L
.15216 .47951 L
.15239 .48088 L
.15262 .48201 L
.15286 .4829 L
.15309 .48386 L
.15332 .48458 L
.15355 .48537 L
.15379 .48621 L
.15402 .48705 L
.15425 .48876 L
.15448 .49024 L
.15472 .49148 L
.15495 .49278 L
.15518 .49385 L
.15541 .49498 L
.15565 .49618 L
.15588 .49735 L
.15611 .49829 L
.15634 .4993 L
.15658 .50037 L
.15681 .50142 L
.15704 .50253 L
.15727 .50363 L
.15751 .50471 L
.15774 .50579 L
.15797 .50358 L
.1582 .50225 L
.15844 .5018 L
.15867 .50112 L
.1589 .50132 L
.15913 .50128 L
.15937 .50101 L
.1596 .5008 L
.15983 .50147 L
.16006 .50191 L
.1603 .50211 L
.16053 .50237 L
.16076 .5024 L
.16099 .50249 L
.16123 .50265 L
.16146 .50278 L
.16169 .5038 L
.16192 .50459 L
.16216 .50514 L
.16239 .50575 L
.16262 .50612 L
.16285 .50656 L
.16309 .50706 L
.16332 .50754 L
Mistroke
.16355 .50779 L
.16378 .5081 L
.16402 .50847 L
.16425 .50883 L
.16448 .50925 L
.16471 .50966 L
.16495 .51004 L
.16518 .51043 L
.16541 .51165 L
.16564 .51264 L
.16588 .51341 L
.16611 .51424 L
.16634 .51485 L
.16657 .51552 L
.16681 .51625 L
.16704 .51697 L
.16727 .51746 L
.1675 .51801 L
.16774 .51862 L
.16797 .51922 L
.1682 .51987 L
.16843 .52051 L
.16867 .52113 L
.1689 .52176 L
.16913 .52217 L
.16936 .52263 L
.1696 .52316 L
.16983 .52367 L
.17006 .52423 L
.17029 .52479 L
.17053 .52532 L
.17076 .52586 L
.17099 .52646 L
.17122 .52705 L
.17146 .52762 L
.17169 .52819 L
.17192 .52874 L
.17215 .5293 L
.17239 .52987 L
.17262 .53043 L
.17285 .52682 L
.17308 .52432 L
.17332 .52294 L
.17355 .52127 L
.17378 .52071 L
.17401 .51985 L
.17425 .5187 L
.17448 .51762 L
.17471 .51767 L
.17494 .51741 L
Mistroke
.17518 .51685 L
.17541 .51638 L
.17564 .5156 L
.17587 .51491 L
.17611 .51429 L
.17634 .51365 L
.17657 .51314 L
.1768 .5126 L
.17704 .51202 L
.17727 .51145 L
.1775 .51085 L
.17773 .51026 L
.17797 .50967 L
.1782 .50908 L
.17843 .50846 L
.17866 .50785 L
.1789 .50725 L
.17913 .50664 L
.17936 .50605 L
.17959 .50545 L
.17983 .50485 L
.18006 .50425 L
.18029 .50578 L
.18052 .50674 L
.18076 .50713 L
.18099 .50767 L
.18122 .50765 L
.18145 .50777 L
.18169 .50805 L
.18192 .50828 L
.18215 .50795 L
.18238 .50777 L
.18262 .50774 L
.18285 .50767 L
.18308 .50775 L
.18331 .50779 L
.18355 .5078 L
.18378 .50781 L
.18401 .50725 L
.18424 .50684 L
.18448 .50659 L
.18471 .5063 L
.18494 .50615 L
.18517 .50597 L
.18541 .50575 L
.18564 .50554 L
.18587 .50548 L
.1861 .50538 L
.18634 .50524 L
.18657 .50511 L
Mistroke
.1868 .50494 L
.18703 .50478 L
.18727 .50463 L
.1875 .50448 L
.18773 .51379 L
.18797 .52056 L
.1882 .5248 L
.18843 .52972 L
.18866 .5321 L
.1889 .53517 L
.18913 .53891 L
.18936 .54247 L
.18959 .54349 L
.18983 .5452 L
.19006 .54758 L
.19029 .54978 L
.19052 .55266 L
.19076 .55536 L
.19099 .55788 L
.19122 .56044 L
.19145 .56047 L
.19169 .56118 L
.19192 .56257 L
.19215 .56378 L
.19238 .56567 L
.19262 .56737 L
.19285 .56889 L
.19308 .57046 L
.19331 .57271 L
.19355 .57478 L
.19378 .57667 L
.19401 .5786 L
.19424 .58036 L
.19448 .58216 L
.19471 .58401 L
.19494 .58585 L
.19517 .58515 L
.19541 .58513 L
.19564 .58579 L
.19587 .58627 L
.1961 .58743 L
.19634 .5884 L
.19657 .5892 L
.1968 .59004 L
.19703 .59156 L
.19727 .5929 L
.1975 .59406 L
.19773 .59527 L
.19796 .59629 L
.1982 .59736 L
Mistroke
.19843 .59849 L
.19866 .5996 L
.19889 .59766 L
.19913 .59654 L
.19936 .59624 L
.19959 .59572 L
.19982 .59601 L
.20006 .59609 L
.20029 .59595 L
.20052 .59586 L
.20075 .59659 L
.20099 .59711 L
.20122 .5974 L
.20145 .59775 L
.20168 .59789 L
.20192 .59808 L
.20215 .59833 L
.20238 .59857 L
.20261 .5907 L
.20285 .585 L
.20308 .58148 L
.20331 .57737 L
.20354 .57544 L
.20378 .57292 L
.20401 .56982 L
.20424 .56688 L
.20447 .50655 L
.20471 .4616 L
.20494 .43203 L
.20517 .39834 L
.2054 .38002 L
.20564 .35758 L
.20587 .33103 L
.2061 .30557 L
.20633 .34303 L
.20657 .36364 L
.2068 .36738 L
.20703 .37564 L
.20726 .36705 L
.2075 .36297 L
.20773 .36341 L
.20796 .36264 L
.20819 .34501 L
.20843 .33189 L
.20866 .3233 L
.20889 .31349 L
.20912 .3082 L
.20936 .3017 L
.20959 .29399 L
.20982 .28661 L
Mistroke
.21005 .2965 L
.21029 .30177 L
.21052 .3024 L
.21075 .30428 L
.21098 .30152 L
.21122 .30001 L
.21145 .29973 L
.21168 .29913 L
.21191 .29389 L
.21215 .28989 L
.21238 .28714 L
.21261 .28405 L
.21284 .2822 L
.21308 .28002 L
.21331 .27751 L
.21354 .27509 L
.21377 .2798 L
.21401 .2826 L
.21424 .28349 L
.21447 .28489 L
.2147 .28438 L
.21494 .28438 L
.21517 .2849 L
.2154 .28527 L
.21563 .2372 L
.21587 .2021 L
.2161 .17999 L
.21633 .1544 L
.21656 .14179 L
.2168 .12571 L
.21703 .10614 L
.21726 .08751 L
.21749 .13312 L
.21773 .16152 L
.21796 .1727 L
.21819 .1885 L
.21842 .18708 L
.21866 .19027 L
.21889 .19808 L
.21912 .20465 L
.21935 .19401 L
.21959 .18798 L
.21982 .18656 L
.22005 .1839 L
.22028 .18586 L
.22052 .18658 L
.22075 .18607 L
.22098 .18589 L
.22121 .17935 L
.22145 .17451 L
Mistroke
.22168 .17138 L
.22191 .16779 L
.22214 .1659 L
.22238 .16356 L
.22261 .16076 L
.22284 .15808 L
.22307 .15711 L
.22331 .15568 L
.22354 .15379 L
.22377 .15203 L
.224 .14981 L
.22424 .14771 L
.22447 .14574 L
.2247 .14373 L
.22493 .14261 L
.22517 .14125 L
.2254 .13965 L
.22563 .13812 L
.22586 .13635 L
.2261 .13465 L
.22633 .133 L
.22656 .13134 L
.2268 .12945 L
.22703 .12761 L
.22726 .12584 L
.22749 .12406 L
.22773 .12233 L
.22796 .12059 L
.22819 .11883 L
.22842 .11708 L
.22866 .11509 L
.22889 .11316 L
.22912 .1113 L
.22935 .10942 L
.22959 .1076 L
.22982 .10577 L
.23005 .10392 L
.23028 .10207 L
.23052 .10029 L
.23075 .09849 L
.23098 .09667 L
.23121 .09486 L
.23145 .09303 L
.23168 .0912 L
.23191 .08938 L
.23214 .08756 L
.23238 .0999 L
.23261 .10844 L
.23284 .11319 L
.23307 .11896 L
Mistroke
.23331 .12093 L
.23354 .12392 L
.23377 .12793 L
.234 .13166 L
.23424 .1316 L
.23447 .13256 L
.2347 .13453 L
.23493 .13623 L
.23517 .13895 L
.2354 .14139 L
.23563 .14357 L
.23586 .14581 L
.2361 .14426 L
.23633 .14373 L
.23656 .14421 L
.23679 .14442 L
.23703 .14565 L
.23726 .14661 L
.23749 .14729 L
.23772 .14805 L
.23796 .14982 L
.23819 .15132 L
.23842 .15255 L
.23865 .15385 L
.23889 .15488 L
.23912 .15598 L
.23935 .15716 L
.23958 .15832 L
.23982 .14386 L
.24005 .13358 L
.24028 .12749 L
.24051 .12028 L
.24075 .11725 L
.24098 .1131 L
.24121 .10783 L
.24144 .10286 L
.24168 .10208 L
.24191 .10017 L
.24214 .09714 L
.24237 .09442 L
.24261 .09057 L
.24284 .08702 L
.24307 .08377 L
.2433 .08044 L
.24354 .0813 L
.24377 .08103 L
.244 .07965 L
.24423 .07856 L
.24447 .07635 L
.2447 .07444 L
Mistroke
.24493 .07284 L
.24516 .07115 L
.2454 .06834 L
.24563 .06583 L
.24586 .06363 L
.24609 .06134 L
.24633 .05935 L
.24656 .05728 L
.24679 .05513 L
.24702 .05301 L
.24726 .05818 L
.24749 .0614 L
.24772 .06266 L
.24795 .06445 L
.24819 .06428 L
.24842 .06463 L
.24865 .06551 L
.24888 .06625 L
.24912 .06503 L
.24935 .06433 L
.24958 .06416 L
.24981 .06385 L
.25005 .06407 L
.25028 .06414 L
.25051 .06407 L
.25074 .06404 L
.25098 .06205 L
.25121 .06059 L
.25144 .05965 L
.25167 .05858 L
.25191 .05802 L
.25214 .05733 L
.25237 .05649 L
.2526 .05569 L
.25284 .05542 L
.25307 .05501 L
.2533 .05445 L
.25353 .05394 L
.25377 .05328 L
.254 .05266 L
.25423 .05208 L
.25446 .05149 L
.2547 .04894 L
.25493 .04691 L
.25516 .04541 L
.25539 .04377 L
.25563 .04266 L
.25586 .0414 L
.25609 .04 L
.25632 .03864 L
Mistroke
.25656 .03781 L
.25679 .03683 L
.25702 .03572 L
.25725 .03464 L
.25749 .03342 L
.25772 .03224 L
.25795 .03109 L
.25818 .02994 L
.25842 .02931 L
.25865 .02854 L
.25888 .02763 L
.25911 .02676 L
.25935 .02574 L
.25958 .02477 L
.25981 .02383 L
.26004 .02288 L
.26028 .02179 L
.26051 .02074 L
.26074 .01973 L
.26097 .01871 L
.26121 .01772 L
.26144 .01672 L
.26167 .01572 L
.2619 .01472 L
.26214 .02738 L
.26237 .03638 L
.2626 .04172 L
.26283 .04804 L
.26307 .0507 L
.2633 .05434 L
.26353 .05896 L
.26376 .06331 L
.264 .06401 L
.26423 .06569 L
.26446 .06835 L
.26469 .07074 L
.26493 .07412 L
.26516 .07723 L
.26539 .08008 L
.26563 .083 L
.26586 .08226 L
.26609 .0825 L
.26632 .08373 L
.26656 .08469 L
.26679 .08663 L
.26702 .0883 L
.26725 .08972 L
.26749 .0912 L
.26772 .09367 L
.26795 .09587 L
Mistroke
.26818 .09781 L
.26842 .09982 L
.26865 .10157 L
.26888 .10339 L
.26911 .10528 L
.26935 .10715 L
.26958 .10536 L
.26981 .10454 L
.27004 .10471 L
.27028 .10462 L
.27051 .10551 L
.27074 .10614 L
.27097 .1065 L
.27121 .10693 L
.27144 .10835 L
.27167 .1095 L
.2719 .11039 L
.27214 .11135 L
.27237 .11204 L
.2726 .11281 L
.27283 .11365 L
.27307 .11446 L
.2733 .11626 L
.27353 .1178 L
.27376 .11907 L
.274 .12042 L
.27423 .1215 L
.27446 .12265 L
.27469 .12387 L
.27493 .12508 L
.27516 .12602 L
.27539 .12703 L
.27562 .12811 L
.27586 .12917 L
.27609 .1303 L
.27632 .13142 L
.27655 .13251 L
.27679 .13361 L
.27702 .13105 L
.27725 .12947 L
.27748 .12887 L
.27772 .12801 L
.27795 .12813 L
.27818 .12798 L
.27841 .12757 L
.27865 .12724 L
.27888 .12788 L
.27911 .12826 L
.27934 .12838 L
.27958 .12857 L
Mistroke
.27981 .1285 L
.28004 .1285 L
.28027 .12856 L
.28051 .12861 L
.28074 .12964 L
.28097 .13041 L
.2812 .13091 L
.28144 .13149 L
.28167 .1318 L
.2819 .13218 L
.28213 .13263 L
.28237 .13306 L
.2826 .13323 L
.28283 .13348 L
.28306 .13379 L
.2833 .13408 L
.28353 .13444 L
.28376 .13479 L
.28399 .13511 L
.28423 .13544 L
.28446 .13675 L
.28469 .1378 L
.28492 .13859 L
.28516 .13944 L
.28539 .14004 L
.28562 .1407 L
.28585 .14143 L
.28609 .14215 L
.28632 .1426 L
.28655 .14312 L
.28678 .14372 L
.28702 .14429 L
.28725 .14493 L
.28748 .14556 L
.28771 .14617 L
.28795 .14678 L
.28818 .14713 L
.28841 .14755 L
.28864 .14804 L
.28888 .14851 L
.28911 .14905 L
.28934 .14957 L
.28957 .15008 L
.28981 .15058 L
.29004 .15116 L
.29027 .15172 L
.2905 .15227 L
.29074 .15281 L
.29097 .15334 L
.2912 .15387 L
Mistroke
.29143 .15441 L
.29167 .15495 L
.2919 .152 L
.29213 .14998 L
.29236 .1489 L
.2926 .14757 L
.29283 .14717 L
.29306 .14652 L
.29329 .14562 L
.29353 .14479 L
.29376 .14489 L
.29399 .14475 L
.29422 .14435 L
.29446 .14402 L
.29469 .14344 L
.29492 .14292 L
.29515 .14247 L
.29539 .14201 L
.29562 .14248 L
.29585 .1427 L
.29608 .14267 L
.29632 .1427 L
.29655 .14249 L
.29678 .14234 L
.29701 .14226 L
.29725 .14216 L
.29748 .14181 L
.29771 .14153 L
.29794 .14132 L
.29818 .14108 L
.29841 .14092 L
.29864 .14073 L
.29887 .14053 L
.29911 .14034 L
.29934 .14107 L
.29957 .14156 L
.2998 .1418 L
.30004 .1421 L
.30027 .14216 L
.3005 .14228 L
.30073 .14246 L
.30097 .14263 L
.3012 .14255 L
.30143 .14254 L
.30166 .14259 L
.3019 .14263 L
.30213 .14273 L
.30236 .14282 L
.30259 .14288 L
.30283 .14296 L
Mistroke
.30306 .14278 L
.30329 .14267 L
.30352 .14262 L
.30376 .14256 L
.30399 .14256 L
.30422 .14255 L
.30445 .14252 L
.30469 .14249 L
.30492 .14253 L
.30515 .14256 L
.30539 .14256 L
.30562 .14257 L
.30585 .14256 L
.30608 .14256 L
.30632 .14256 L
.30655 .14256 L
.30678 .14349 L
.30701 .14418 L
.30725 .14461 L
.30748 .14511 L
.30771 .14536 L
.30794 .14568 L
.30818 .14606 L
.30841 .14643 L
.30864 .14654 L
.30887 .14673 L
.30911 .14698 L
.30934 .14721 L
.30957 .14751 L
.3098 .14779 L
.31004 .14805 L
.31027 .14832 L
.3105 .14834 L
.31073 .14842 L
.31097 .14858 L
.3112 .14871 L
.31143 .14891 L
.31166 .14909 L
.3119 .14926 L
.31213 .14943 L
.31236 .14967 L
.31259 .14988 L
.31283 .15009 L
.31306 .15029 L
.31329 .15048 L
.31352 .15067 L
.31376 .15087 L
.31399 .15107 L
.31422 .15101 L
.31445 .15102 L
Mistroke
.31469 .1511 L
.31492 .15117 L
.31515 .1513 L
.31538 .15141 L
.31562 .1515 L
.31585 .1516 L
.31608 .15176 L
.31631 .15191 L
.31655 .15204 L
.31678 .15217 L
.31701 .15229 L
.31724 .15241 L
.31748 .15254 L
.31771 .15266 L
.31794 .15285 L
.31817 .15302 L
.31841 .15318 L
.31864 .15334 L
.31887 .15348 L
.3191 .15363 L
.31934 .15378 L
.31957 .15393 L
.3198 .15406 L
.32003 .1542 L
.32027 .15434 L
.3205 .15449 L
.32073 .15463 L
.32096 .15478 L
.3212 .15492 L
.32143 .15506 L
.32166 .15508 L
.32189 .15514 L
.32213 .15522 L
.32236 .1553 L
.32259 .15541 L
.32282 .15551 L
.32306 .15561 L
.32329 .1557 L
.32352 .15583 L
.32375 .15595 L
.32399 .15606 L
.32422 .15617 L
.32445 .15628 L
.32468 .15639 L
.32492 .15649 L
.32515 .1566 L
.32538 .15674 L
.32561 .15688 L
.32585 .157 L
.32608 .15713 L
Mistroke
.32631 .15724 L
.32654 .15736 L
.32678 .15748 L
.32701 .15761 L
.32724 .15772 L
.32747 .15783 L
.32771 .15795 L
.32794 .15807 L
.32817 .15819 L
.3284 .1583 L
.32864 .15842 L
.32887 .15854 L
.3291 .15869 L
.32933 .15883 L
.32957 .15896 L
.3298 .1591 L
.33003 .15923 L
.33026 .15936 L
.3305 .15949 L
.33073 .15962 L
.33096 .15974 L
.33119 .15986 L
.33143 .15999 L
.33166 .16012 L
.33189 .16024 L
.33212 .16037 L
.33236 .1605 L
.33259 .16063 L
.33282 .16074 L
.33305 .16087 L
.33329 .16099 L
.33352 .16111 L
.33375 .16124 L
.33398 .16136 L
.33422 .16148 L
.33445 .16161 L
.33468 .16173 L
.33491 .16186 L
.33515 .16198 L
.33538 .16211 L
.33561 .16223 L
.33584 .16236 L
.33608 .16248 L
.33631 .16261 L
.33654 .16514 L
.33677 .16703 L
.33701 .16828 L
.33724 .16969 L
.33747 .17046 L
.3377 .17141 L
Mistroke
.33794 .17252 L
.33817 .1736 L
.3384 .17402 L
.33863 .17462 L
.33887 .17539 L
.3391 .17611 L
.33933 .17701 L
.33956 .17786 L
.3398 .17867 L
.34003 .17948 L
.34026 .17965 L
.34049 .18 L
.34073 .18052 L
.34096 .18099 L
.34119 .18163 L
.34142 .18223 L
.34166 .18278 L
.34189 .18334 L
.34212 .18408 L
.34235 .18477 L
.34259 .18541 L
.34282 .18607 L
.34305 .18668 L
.34328 .1873 L
.34352 .18794 L
.34375 .18857 L
.34398 .18856 L
.34422 .18871 L
.34445 .18905 L
.34468 .18933 L
.34491 .18979 L
.34515 .1902 L
.34538 .19057 L
.34561 .19095 L
.34584 .1915 L
.34608 .192 L
.34631 .19246 L
.34654 .19293 L
.34677 .19336 L
.34701 .19379 L
.34724 .19424 L
.34747 .19469 L
.3477 .19531 L
.34794 .19588 L
.34817 .19641 L
.3484 .19695 L
.34863 .19744 L
.34887 .19794 L
.3491 .19846 L
.34933 .19897 L
Mistroke
.34956 .19944 L
.3498 .19992 L
.35003 .20041 L
.35026 .2009 L
.35049 .2014 L
.35073 .2019 L
.35096 .2024 L
.35119 .20289 L
.35142 .20958 L
.35166 .2146 L
.35189 .21797 L
.35212 .22178 L
.35235 .22393 L
.35259 .22653 L
.35282 .22957 L
.35305 .23249 L
.35328 .23376 L
.35352 .23547 L
.35375 .23762 L
.35398 .23966 L
.35421 .24213 L
.35445 .24449 L
.35468 .24674 L
.35491 .24901 L
.35514 .24962 L
.35538 .25068 L
.35561 .25218 L
.35584 .25357 L
.35607 .2554 L
.35631 .25711 L
.35654 .2587 L
.35677 .26032 L
.357 .26238 L
.35724 .26433 L
.35747 .26616 L
.3577 .26802 L
.35793 .26976 L
.35817 .27153 L
.3584 .27334 L
.35863 .27514 L
.35886 .26856 L
.3591 .26424 L
.35933 .26215 L
.35956 .25946 L
.35979 .25901 L
.36003 .25797 L
.36026 .25632 L
.36049 .25483 L
.36072 .25559 L
.36096 .25575 L
Mistroke
.36119 .2553 L
.36142 .25502 L
.36165 .25413 L
.36189 .25341 L
.36212 .25284 L
.36235 .25223 L
.36258 .25387 L
.36282 .2549 L
.36305 .25534 L
.36328 .25593 L
.36351 .25593 L
.36375 .25608 L
.36398 .2564 L
.36421 .25667 L
.36444 .25634 L
.36468 .25618 L
.36491 .25617 L
.36514 .25612 L
.36537 .25623 L
.36561 .2563 L
.36584 .25633 L
.36607 .25637 L
.3663 .25147 L
.36654 .2479 L
.36677 .24564 L
.367 .24304 L
.36723 .24175 L
.36747 .24012 L
.3677 .23812 L
.36793 .23622 L
.36816 .23565 L
.3684 .23472 L
.36863 .23343 L
.36886 .23224 L
.36909 .2307 L
.36933 .22925 L
.36956 .2279 L
.36979 .22652 L
.37002 .22646 L
.37026 .22605 L
.37049 .22528 L
.37072 .22461 L
.37095 .22359 L
.37119 .22266 L
.37142 .22182 L
.37165 .22096 L
.37188 .21975 L
.37212 .21862 L
.37235 .2176 L
.37258 .21655 L
Mistroke
.37281 .21559 L
.37305 .21461 L
.37328 .21361 L
.37351 .21261 L
.37374 .21386 L
.37398 .21451 L
.37421 .21455 L
.37444 .21476 L
.37467 .21436 L
.37491 .21413 L
.37514 .21405 L
.37537 .21394 L
.3756 .21322 L
.37584 .21266 L
.37607 .21226 L
.3763 .21182 L
.37653 .21154 L
.37677 .21122 L
.377 .21086 L
.37723 .2105 L
.37746 .20955 L
.3777 .20875 L
.37793 .20812 L
.37816 .20744 L
.37839 .20693 L
.37863 .20637 L
.37886 .20577 L
.37909 .20518 L
.37932 .20475 L
.37956 .20428 L
.37979 .20376 L
.38002 .20326 L
.38025 .20271 L
.38049 .20218 L
.38072 .20165 L
.38095 .20113 L
.38118 .20883 L
.38142 .21434 L
.38165 .21763 L
.38188 .22152 L
.38211 .2232 L
.38235 .22547 L
.38258 .22833 L
.38281 .23103 L
.38305 .23153 L
.38328 .23262 L
.38351 .2343 L
.38374 .23582 L
.38398 .23793 L
.38421 .23989 L
Mistroke
.38444 .24168 L
.38467 .24352 L
.38491 .24315 L
.38514 .24338 L
.38537 .24419 L
.3856 .24485 L
.38584 .24609 L
.38607 .24718 L
.3863 .24811 L
.38653 .24909 L
.38677 .25065 L
.387 .25206 L
.38723 .2533 L
.38746 .25459 L
.3877 .25572 L
.38793 .2569 L
.38816 .25811 L
.38839 .25932 L
.38863 .25832 L
.38886 .25791 L
.38909 .25809 L
.38932 .25811 L
.38956 .25872 L
.38979 .25918 L
.39002 .25947 L
.39025 .25981 L
.39049 .26074 L
.39072 .26151 L
.39095 .26213 L
.39118 .26278 L
.39142 .26328 L
.39165 .26382 L
.39188 .2644 L
.39211 .26497 L
.39235 .26614 L
.39258 .26714 L
.39281 .26799 L
.39304 .26887 L
.39328 .2696 L
.39351 .27037 L
.39374 .27119 L
.39397 .27199 L
.39421 .27264 L
.39444 .27332 L
.39467 .27405 L
.3949 .27477 L
.39514 .27553 L
.39537 .27628 L
.3956 .27702 L
.39583 .27776 L
Mistroke
.39607 .27608 L
.3963 .27504 L
.39653 .27466 L
.39676 .2741 L
.397 .27419 L
.39723 .27411 L
.39746 .27385 L
.39769 .27364 L
.39793 .27408 L
.39816 .27435 L
.39839 .27444 L
.39862 .27458 L
.39886 .27454 L
.39909 .27455 L
.39932 .27461 L
.39955 .27466 L
.39979 .27535 L
.40002 .27587 L
.40025 .27622 L
.40048 .27661 L
.40072 .27683 L
.40095 .27709 L
.40118 .27741 L
.40141 .2777 L
.40165 .27783 L
.40188 .278 L
.40211 .27822 L
.40234 .27843 L
.40258 .27868 L
.40281 .27892 L
.40304 .27915 L
.40327 .27938 L
.40351 .28026 L
.40374 .28097 L
.40397 .2815 L
.4042 .28208 L
.40444 .28248 L
.40467 .28294 L
.4049 .28344 L
.40513 .28392 L
.40537 .28423 L
.4056 .28459 L
.40583 .285 L
.40606 .28539 L
.4063 .28583 L
.40653 .28626 L
.40676 .28667 L
.40699 .28709 L
.40723 .28733 L
.40746 .28762 L
Mistroke
.40769 .28796 L
.40792 .28828 L
.40816 .28866 L
.40839 .28901 L
.40862 .28936 L
.40885 .28971 L
.40909 .29011 L
.40932 .29049 L
.40955 .29086 L
.40978 .29124 L
.41002 .2916 L
.41025 .29196 L
.41048 .29233 L
.41071 .2927 L
.41095 .29289 L
.41118 .29312 L
.41141 .29341 L
.41164 .29368 L
.41188 .294 L
.41211 .2943 L
.41234 .2946 L
.41257 .2949 L
.41281 .29524 L
.41304 .29557 L
.41327 .29589 L
.4135 .29622 L
.41374 .29653 L
.41397 .29684 L
.4142 .29716 L
.41443 .29747 L
.41467 .29784 L
.4149 .29819 L
.41513 .29853 L
.41536 .29887 L
.4156 .2992 L
.41583 .29953 L
.41606 .29987 L
.41629 .3002 L
.41653 .30052 L
.41676 .30085 L
.41699 .30118 L
.41722 .30151 L
.41746 .30184 L
.41769 .30217 L
.41792 .3025 L
.41815 .30283 L
.41839 .30321 L
.41862 .30357 L
.41885 .30392 L
.41908 .30428 L
Mistroke
.41932 .30462 L
.41955 .30497 L
.41978 .30532 L
.42001 .30567 L
.42025 .306 L
.42048 .30634 L
.42071 .30669 L
.42094 .30703 L
.42118 .30737 L
.42141 .30772 L
.42164 .30806 L
.42188 .30841 L
.42211 .30874 L
.42234 .30907 L
.42257 .30941 L
.42281 .30975 L
.42304 .31009 L
.42327 .31043 L
.4235 .31076 L
.42374 .3111 L
.42397 .31144 L
.4242 .31179 L
.42443 .31213 L
.42467 .31247 L
.4249 .31281 L
.42513 .31315 L
.42536 .31349 L
.4256 .31383 L
.42583 .31421 L
.42606 .31459 L
.42629 .31495 L
.42653 .31532 L
.42676 .31567 L
.42699 .31603 L
.42722 .31639 L
.42746 .31675 L
.42769 .31709 L
.42792 .31744 L
.42815 .3178 L
.42839 .31815 L
.42862 .3185 L
.42885 .31886 L
.42908 .31921 L
.42932 .31957 L
.42955 .31991 L
.42978 .32025 L
.43001 .3206 L
.43025 .32095 L
.43048 .3213 L
.43071 .32165 L
Mistroke
.43094 .322 L
.43118 .32234 L
.43141 .3227 L
.43164 .32305 L
.43187 .3234 L
.43211 .32375 L
.43234 .3241 L
.43257 .32445 L
.4328 .3248 L
.43304 .32515 L
.43327 .32549 L
.4335 .32583 L
.43373 .32617 L
.43397 .32652 L
.4342 .32686 L
.43443 .32721 L
.43466 .32755 L
.4349 .3279 L
.43513 .32825 L
.43536 .32859 L
.43559 .32894 L
.43583 .32929 L
.43606 .32963 L
.43629 .32998 L
.43652 .33033 L
.43676 .33067 L
.43699 .33102 L
.43722 .33137 L
.43745 .33172 L
.43769 .33207 L
.43792 .33242 L
.43815 .33276 L
.43838 .33311 L
.43862 .33346 L
.43885 .33381 L
.43908 .33415 L
.43931 .3345 L
.43955 .33485 L
.43978 .3352 L
.44001 .33554 L
.44024 .33589 L
.44048 .33624 L
.44071 .34046 L
.44094 .34364 L
.44117 .34579 L
.44141 .34821 L
.44164 .34959 L
.44187 .35126 L
.4421 .3532 L
.44234 .35506 L
Mistroke
.44257 .35589 L
.4428 .357 L
.44303 .35839 L
.44327 .3597 L
.4435 .36128 L
.44373 .3628 L
.44396 .36424 L
.4442 .3657 L
.44443 .36612 L
.44466 .36682 L
.44489 .3678 L
.44513 .3687 L
.44536 .36988 L
.44559 .37099 L
.44582 .37202 L
.44606 .37308 L
.44629 .37441 L
.44652 .37566 L
.44675 .37684 L
.44699 .37804 L
.44722 .37917 L
.44745 .38032 L
.44768 .38149 L
.44792 .38265 L
.44815 .38277 L
.44838 .38317 L
.44861 .38385 L
.44885 .38446 L
.44908 .38534 L
.44931 .38615 L
.44954 .38689 L
.44978 .38764 L
.45001 .38867 L
.45024 .38963 L
.45047 .39051 L
.45071 .39142 L
.45094 .39225 L
.45117 .3931 L
.4514 .39397 L
.45164 .39483 L
.45187 .39597 L
.4521 .39704 L
.45233 .39803 L
.45257 .39904 L
.4528 .39998 L
.45303 .40094 L
.45326 .40192 L
.4535 .40289 L
.45373 .40379 L
.45396 .40471 L
Mistroke
.45419 .40564 L
.45443 .40658 L
.45466 .40753 L
.45489 .40848 L
.45512 .40942 L
.45536 .41036 L
.45559 .41027 L
.45582 .41045 L
.45605 .41091 L
.45629 .4113 L
.45652 .41197 L
.45675 .41256 L
.45698 .41307 L
.45722 .41361 L
.45745 .41443 L
.45768 .41517 L
.45791 .41583 L
.45815 .41652 L
.45838 .41713 L
.45861 .41776 L
.45884 .41841 L
.45908 .41905 L
.45931 .41998 L
.45954 .42083 L
.45977 .4216 L
.46001 .4224 L
.46024 .42312 L
.46047 .42386 L
.4607 .42462 L
.46094 .42537 L
.46117 .42605 L
.4614 .42675 L
.46164 .42747 L
.46187 .42819 L
.4621 .42892 L
.46233 .42965 L
.46257 .43037 L
.4628 .4311 L
.46303 .4321 L
.46326 .43303 L
.4635 .43388 L
.46373 .43476 L
.46396 .43556 L
.46419 .43638 L
.46443 .43722 L
.46466 .43805 L
.46489 .43881 L
.46512 .43959 L
.46536 .44039 L
.46559 .44119 L
Mistroke
.46582 .442 L
.46605 .44281 L
.46629 .44361 L
.46652 .44442 L
.46675 .44515 L
.46698 .4459 L
.46722 .44667 L
.46745 .44744 L
.46768 .44822 L
.46791 .449 L
.46815 .44978 L
.46838 .45055 L
.46861 .45135 L
.46884 .45214 L
.46908 .45292 L
.46931 .45371 L
.46954 .45449 L
.46977 .45527 L
.47001 .45606 L
.47024 .45684 L
.47047 .45091 L
.4707 .44679 L
.47094 .44445 L
.47117 .44164 L
.4714 .44063 L
.47163 .43913 L
.47187 .43715 L
.4721 .4353 L
.47233 .43525 L
.47256 .43472 L
.4728 .43371 L
.47303 .43282 L
.47326 .43145 L
.47349 .43022 L
.47373 .42911 L
.47396 .42796 L
.47419 .42862 L
.47442 .42879 L
.47466 .42848 L
.47489 .4283 L
.47512 .42764 L
.47535 .42711 L
.47559 .4267 L
.47582 .42627 L
.47605 .42535 L
.47628 .42455 L
.47652 .42389 L
.47675 .4232 L
.47698 .42263 L
.47721 .42203 L
Mistroke
.47745 .42139 L
.47768 .42076 L
.47791 .42194 L
.47814 .42262 L
.47838 .42283 L
.47861 .42317 L
.47884 .42302 L
.47907 .42301 L
.47931 .42312 L
.47954 .4232 L
.47977 .42279 L
.48 .42252 L
.48024 .42237 L
.48047 .4222 L
.4807 .42214 L
.48093 .42206 L
.48117 .42194 L
.4814 .42183 L
.48163 .42124 L
.48186 .42077 L
.4821 .42044 L
.48233 .42007 L
.48256 .41983 L
.48279 .41955 L
.48303 .41925 L
.48326 .41895 L
.48349 .41878 L
.48372 .41857 L
.48396 .41833 L
.48419 .4181 L
.48442 .41783 L
.48465 .41758 L
.48489 .41733 L
.48512 .41708 L
.48535 .41379 L
.48558 .41131 L
.48582 .40965 L
.48605 .40777 L
.48628 .4067 L
.48651 .40542 L
.48675 .40392 L
.48698 .40247 L
.48721 .40184 L
.48744 .401 L
.48768 .39993 L
.48791 .39893 L
.48814 .3977 L
.48837 .39653 L
.48861 .39543 L
.48884 .3943 L
Mistroke
.48907 .394 L
.4893 .39347 L
.48954 .39272 L
.48977 .39204 L
.49 .39113 L
.49023 .39029 L
.49047 .3895 L
.4907 .3887 L
.49093 .38767 L
.49116 .38671 L
.4914 .3858 L
.49163 .38488 L
.49186 .38402 L
.49209 .38314 L
.49233 .38225 L
.49256 .38136 L
.49279 .38129 L
.49302 .381 L
.49326 .38048 L
.49349 .38003 L
.49372 .37936 L
.49395 .37875 L
.49419 .3782 L
.49442 .37763 L
.49465 .37684 L
.49488 .37611 L
.49512 .37544 L
.49535 .37475 L
.49558 .37413 L
.49581 .37348 L
.49605 .37282 L
.49628 .37217 L
.49651 .37129 L
.49674 .37048 L
.49698 .36972 L
.49721 .36895 L
.49744 .36824 L
.49767 .36751 L
.49791 .36676 L
.49814 .36602 L
.49837 .36534 L
.4986 .36464 L
.49884 .36393 L
.49907 .36322 L
.4993 .36249 L
.49953 .36177 L
.49977 .36106 L
.5 .36034 L
.50023 .37105 L
.50047 .3787 L
Mistroke
.5007 .38328 L
.50093 .38869 L
.50116 .39103 L
.5014 .39419 L
.50163 .39818 L
.50186 .40194 L
.50209 .40265 L
.50233 .40417 L
.50256 .40652 L
.50279 .40864 L
.50302 .41158 L
.50326 .41431 L
.50349 .41681 L
.50372 .41938 L
.50395 .41888 L
.50419 .4192 L
.50442 .42035 L
.50465 .42127 L
.50488 .42301 L
.50512 .42454 L
.50535 .42584 L
.50558 .4272 L
.50581 .42938 L
.50605 .43135 L
.50628 .43309 L
.50651 .43489 L
.50674 .43648 L
.50698 .43812 L
.50721 .43982 L
.50744 .4415 L
.50767 .43798 L
.50791 .43586 L
.50814 .43512 L
.50837 .43402 L
.5086 .43431 L
.50884 .43422 L
.50907 .43377 L
.5093 .43341 L
.50953 .43445 L
.50977 .43511 L
.51 .4354 L
.51023 .43579 L
.51046 .43581 L
.5107 .43592 L
.51093 .43614 L
.51116 .43633 L
.51139 .43791 L
.51163 .43912 L
.51186 .43996 L
.51209 .4409 L
Mistroke
.51232 .44146 L
.51256 .44212 L
.51279 .44289 L
.51302 .44362 L
.51325 .44399 L
.51349 .44445 L
.51372 .44501 L
.51395 .44555 L
.51418 .44619 L
.51442 .4468 L
.51465 .44738 L
.51488 .44797 L
.51511 .44768 L
.51535 .44763 L
.51558 .44782 L
.51581 .44794 L
.51604 .44829 L
.51628 .44859 L
.51651 .44882 L
.51674 .44906 L
.51697 .44955 L
.51721 .44996 L
.51744 .45032 L
.51767 .45069 L
.5179 .451 L
.51814 .45133 L
.51837 .45167 L
.5186 .45201 L
.51883 .45258 L
.51907 .45309 L
.5193 .45354 L
.51953 .45401 L
.51976 .45441 L
.52 .45483 L
.52023 .45526 L
.52046 .45569 L
.52069 .45606 L
.52093 .45645 L
.52116 .45685 L
.52139 .45724 L
.52162 .45766 L
.52186 .45807 L
.52209 .45847 L
.52232 .45888 L
.52255 .45952 L
.52279 .4601 L
.52302 .46061 L
.52325 .46114 L
.52348 .46161 L
.52372 .4621 L
Mistroke
.52395 .4626 L
.52418 .4631 L
.52441 .46354 L
.52465 .46399 L
.52488 .46446 L
.52511 .46492 L
.52534 .4654 L
.52558 .46588 L
.52581 .46635 L
.52604 .46683 L
.52627 .46724 L
.52651 .46766 L
.52674 .46811 L
.52697 .46855 L
.5272 .469 L
.52744 .46946 L
.52767 .4699 L
.5279 .47035 L
.52813 .47082 L
.52837 .47128 L
.5286 .47174 L
.52883 .47219 L
.52906 .47265 L
.5293 .4731 L
.52953 .47356 L
.52976 .47401 L
.52999 .4722 L
.53023 .471 L
.53046 .4704 L
.53069 .46965 L
.53092 .46949 L
.53116 .46918 L
.53139 .4687 L
.53162 .46827 L
.53185 .46844 L
.53209 .46846 L
.53232 .4683 L
.53255 .4682 L
.53278 .46793 L
.53302 .4677 L
.53325 .46751 L
.53348 .46732 L
.53371 .46773 L
.53395 .46798 L
.53418 .46807 L
.53441 .4682 L
.53464 .46816 L
.53488 .46818 L
.53511 .46823 L
.53534 .46827 L
Mistroke
.53557 .46815 L
.53581 .46808 L
.53604 .46805 L
.53627 .468 L
.5365 .468 L
.53674 .46799 L
.53697 .46796 L
.5372 .46794 L
.53743 .46853 L
.53767 .46895 L
.5379 .46921 L
.53813 .46952 L
.53836 .46966 L
.5386 .46985 L
.53883 .47008 L
.53906 .47029 L
.5393 .47035 L
.53953 .47045 L
.53976 .47059 L
.53999 .47072 L
.54023 .47089 L
.54046 .47105 L
.54069 .4712 L
.54092 .47136 L
.54116 .47135 L
.54139 .47138 L
.54162 .47146 L
.54185 .47153 L
.54209 .47164 L
.54232 .47174 L
.54255 .47182 L
.54278 .47191 L
.54302 .47204 L
.54325 .47217 L
.54348 .47228 L
.54371 .47239 L
.54395 .47249 L
.54418 .4726 L
.54441 .4727 L
.54464 .47281 L
.54488 .47276 L
.54511 .47275 L
.54534 .47279 L
.54557 .47281 L
.54581 .47288 L
.54604 .47293 L
.54627 .47298 L
.5465 .47302 L
.54674 .47311 L
.54697 .47319 L
Mistroke
.5472 .47325 L
.54743 .47332 L
.54767 .47338 L
.5479 .47344 L
.54813 .4735 L
.54836 .47356 L
.5486 .47367 L
.54883 .47376 L
.54906 .47384 L
.54929 .47392 L
.54953 .474 L
.54976 .47407 L
.54999 .47415 L
.55022 .47423 L
.55046 .4743 L
.55069 .47437 L
.55092 .47444 L
.55115 .47452 L
.55139 .47459 L
.55162 .47467 L
.55185 .47474 L
.55208 .47481 L
.55232 .4728 L
.55255 .47135 L
.55278 .47045 L
.55301 .46941 L
.55325 .46892 L
.55348 .46829 L
.55371 .4675 L
.55394 .46676 L
.55418 .46657 L
.55441 .46624 L
.55464 .46575 L
.55487 .46531 L
.55511 .46471 L
.55534 .46416 L
.55557 .46364 L
.5558 .46312 L
.55604 .46315 L
.55627 .46304 L
.5565 .46277 L
.55673 .46255 L
.55697 .46217 L
.5572 .46184 L
.55743 .46154 L
.55766 .46124 L
.5579 .46078 L
.55813 .46036 L
.55836 .45999 L
.55859 .4596 L
Mistroke
.55883 .45926 L
.55906 .4589 L
.55929 .45853 L
.55952 .45817 L
.55976 .46241 L
.55999 .46542 L
.56022 .46719 L
.56045 .46929 L
.56069 .47016 L
.56092 .47136 L
.56115 .47289 L
.56138 .47433 L
.56162 .47454 L
.56185 .47508 L
.56208 .47595 L
.56231 .47673 L
.56255 .47784 L
.56278 .47886 L
.56301 .4798 L
.56324 .48076 L
.56348 .48048 L
.56371 .48054 L
.56394 .48092 L
.56417 .48122 L
.56441 .48184 L
.56464 .48238 L
.56487 .48283 L
.5651 .48331 L
.56534 .48411 L
.56557 .48483 L
.5658 .48546 L
.56603 .48611 L
.56627 .48667 L
.5665 .48726 L
.56673 .48786 L
.56696 .48847 L
.5672 .48784 L
.56743 .48754 L
.56766 .48757 L
.56789 .48751 L
.56813 .48778 L
.56836 .48797 L
.56859 .48806 L
.56882 .48818 L
.56906 .48863 L
.56929 .489 L
.56952 .48927 L
.56975 .48957 L
.56999 .48977 L
.57022 .49001 L
Mistroke
.57045 .49026 L
.57068 .49051 L
.57092 .49109 L
.57115 .49158 L
.57138 .49198 L
.57161 .49241 L
.57185 .49275 L
.57208 .49311 L
.57231 .49349 L
.57254 .49387 L
.57278 .49416 L
.57301 .49448 L
.57324 .49482 L
.57347 .49515 L
.57371 .4955 L
.57394 .49585 L
.57417 .49619 L
.5744 .49654 L
.57464 .49837 L
.57487 .4998 L
.5751 .50083 L
.57533 .50197 L
.57557 .50271 L
.5758 .50356 L
.57603 .50451 L
.57626 .50544 L
.5765 .50597 L
.57673 .5066 L
.57696 .50734 L
.57719 .50806 L
.57743 .50888 L
.57766 .50967 L
.57789 .51043 L
.57813 .5112 L
.57836 .51157 L
.57859 .51205 L
.57882 .51264 L
.57906 .5132 L
.57929 .51386 L
.57952 .51449 L
.57975 .5151 L
.57999 .51572 L
.58022 .51644 L
.58045 .51713 L
.58068 .51779 L
.58092 .51846 L
.58115 .51911 L
.58138 .51976 L
.58161 .52041 L
.58185 .52107 L
Mistroke
.58208 .52133 L
.58231 .52169 L
.58254 .52217 L
.58278 .52261 L
.58301 .52316 L
.58324 .52368 L
.58347 .52417 L
.58371 .52467 L
.58394 .52528 L
.58417 .52586 L
.5844 .52641 L
.58464 .52696 L
.58487 .52749 L
.5851 .52803 L
.58533 .52857 L
.58557 .52911 L
.5858 .52976 L
.58603 .53038 L
.58626 .53097 L
.5865 .53157 L
.58673 .53214 L
.58696 .53272 L
.58719 .53331 L
.58743 .53389 L
.58766 .53445 L
.58789 .53501 L
.58812 .53558 L
.58836 .53615 L
.58859 .53672 L
.58882 .5373 L
.58905 .53787 L
.58929 .53844 L
.58952 .53776 L
.58975 .53742 L
.58998 .53741 L
.59022 .53731 L
.59045 .53755 L
.59068 .5377 L
.59091 .53776 L
.59115 .53784 L
.59138 .53826 L
.59161 .53858 L
.59184 .53882 L
.59208 .53908 L
.59231 .53925 L
.59254 .53945 L
.59277 .53967 L
.59301 .53988 L
.59324 .54043 L
.59347 .54089 L
Mistroke
.5937 .54126 L
.59394 .54165 L
.59417 .54195 L
.5944 .54228 L
.59463 .54263 L
.59487 .54298 L
.5951 .54323 L
.59533 .54351 L
.59556 .54381 L
.5958 .54411 L
.59603 .54443 L
.59626 .54475 L
.59649 .54505 L
.59673 .54536 L
.59696 .54579 L
.59719 .54619 L
.59742 .54656 L
.59766 .54693 L
.59789 .54727 L
.59812 .54762 L
.59835 .54798 L
.59859 .54834 L
.59882 .54866 L
.59905 .54899 L
.59928 .54934 L
.59952 .54968 L
.59975 .55002 L
.59998 .55037 L
.60021 .55071 L
.60045 .55106 L
.60068 .55137 L
.60091 .55169 L
.60114 .55202 L
.60138 .55235 L
.60161 .55268 L
.60184 .55301 L
.60207 .55334 L
.60231 .55368 L
.60254 .55402 L
.60277 .55435 L
.603 .55469 L
.60324 .55503 L
.60347 .55536 L
.6037 .55569 L
.60393 .55603 L
.60417 .55636 L
.6044 .55504 L
.60463 .55416 L
.60486 .55372 L
.6051 .55316 L
Mistroke
.60533 .55305 L
.60556 .55282 L
.60579 .55247 L
.60603 .55216 L
.60626 .55229 L
.60649 .55229 L
.60672 .55218 L
.60696 .55211 L
.60719 .55191 L
.60742 .55174 L
.60765 .55161 L
.60789 .55147 L
.60812 .55177 L
.60835 .55195 L
.60858 .55202 L
.60882 .55211 L
.60905 .55209 L
.60928 .5521 L
.60951 .55214 L
.60975 .55217 L
.60998 .55209 L
.61021 .55203 L
.61044 .55201 L
.61068 .55198 L
.61091 .55198 L
.61114 .55197 L
.61137 .55195 L
.61161 .55194 L
.61184 .55237 L
.61207 .55268 L
.6123 .55287 L
.61254 .55309 L
.61277 .5532 L
.613 .55334 L
.61323 .5535 L
.61347 .55367 L
.6137 .55371 L
.61393 .55378 L
.61416 .55388 L
.6144 .55398 L
.61463 .55411 L
.61486 .55423 L
.61509 .55434 L
.61533 .55445 L
.61556 .55445 L
.61579 .55447 L
.61602 .55453 L
.61626 .55458 L
.61649 .55466 L
.61672 .55473 L
Mistroke
.61695 .5548 L
.61719 .55486 L
.61742 .55496 L
.61765 .55505 L
.61789 .55513 L
.61812 .55522 L
.61835 .55529 L
.61858 .55537 L
.61882 .55545 L
.61905 .55553 L
.61928 .55328 L
.61951 .55166 L
.61975 .55066 L
.61998 .54949 L
.62021 .54895 L
.62044 .54824 L
.62068 .54736 L
.62091 .54652 L
.62114 .54631 L
.62137 .54594 L
.62161 .54539 L
.62184 .54489 L
.62207 .54423 L
.6223 .5436 L
.62254 .54303 L
.62277 .54244 L
.623 .54247 L
.62323 .54234 L
.62347 .54204 L
.6237 .54179 L
.62393 .54136 L
.62416 .54099 L
.6244 .54065 L
.62463 .54031 L
.62486 .5398 L
.62509 .53933 L
.62533 .53891 L
.62556 .53848 L
.62579 .53809 L
.62602 .53769 L
.62626 .53727 L
.62649 .53686 L
.62672 .53708 L
.62695 .53712 L
.62719 .537 L
.62742 .53693 L
.62765 .53668 L
.62788 .53648 L
.62812 .53633 L
.62835 .53617 L
Mistroke
.62858 .53583 L
.62881 .53555 L
.62905 .5353 L
.62928 .53505 L
.62951 .53484 L
.62974 .53462 L
.62998 .53438 L
.63021 .53415 L
.63044 .53375 L
.63067 .5334 L
.63091 .53309 L
.63114 .53277 L
.63137 .53249 L
.6316 .53221 L
.63184 .53191 L
.63207 .53161 L
.6323 .53136 L
.63253 .5311 L
.63277 .53082 L
.633 .53055 L
.63323 .53026 L
.63346 .52998 L
.6337 .5297 L
.63393 .52942 L
.63416 .52977 L
.63439 .52995 L
.63463 .52996 L
.63486 .53001 L
.63509 .5299 L
.63532 .52983 L
.63556 .52981 L
.63579 .52978 L
.63602 .52957 L
.63625 .52942 L
.63649 .52931 L
.63672 .52918 L
.63695 .5291 L
.63718 .52901 L
.63742 .52891 L
.63765 .52881 L
.63788 .52854 L
.63811 .52832 L
.63835 .52814 L
.63858 .52795 L
.63881 .52781 L
.63904 .52765 L
.63928 .52748 L
.63951 .52732 L
.63974 .5272 L
.63997 .52706 L
Mistroke
.64021 .52692 L
.64044 .52678 L
.64067 .52662 L
.6409 .52647 L
.64114 .52633 L
.64137 .52618 L
.6416 .52587 L
.64183 .52559 L
.64207 .52537 L
.6423 .52513 L
.64253 .52494 L
.64276 .52473 L
.643 .52452 L
.64323 .5243 L
.64346 .52414 L
.64369 .52396 L
.64393 .52376 L
.64416 .52357 L
.64439 .52337 L
.64462 .52317 L
.64486 .52298 L
.64509 .52278 L
.64532 .52263 L
.64555 .52247 L
.64579 .52229 L
.64602 .52212 L
.64625 .52194 L
.64648 .52176 L
.64672 .52158 L
.64695 .5214 L
.64718 .52121 L
.64741 .52102 L
.64765 .52084 L
.64788 .52066 L
.64811 .52047 L
.64834 .52029 L
.64858 .52011 L
.64881 .51993 L
.64904 .521 L
.64927 .52173 L
.64951 .52213 L
.64974 .52262 L
.64997 .52277 L
.6502 .52301 L
.65044 .52334 L
.65067 .52365 L
.6509 .52362 L
.65113 .52369 L
.65137 .52384 L
.6516 .52397 L
Mistroke
.65183 .52419 L
.65206 .52438 L
.6523 .52455 L
.65253 .52473 L
.65276 .52457 L
.65299 .5245 L
.65323 .52452 L
.65346 .52452 L
.65369 .5246 L
.65392 .52467 L
.65416 .52471 L
.65439 .52475 L
.65462 .52489 L
.65485 .525 L
.65509 .52508 L
.65532 .52518 L
.65555 .52525 L
.65578 .52532 L
.65602 .5254 L
.65625 .52548 L
.65648 .52523 L
.65672 .52506 L
.65695 .52499 L
.65718 .52489 L
.65741 .52488 L
.65765 .52485 L
.65788 .52479 L
.65811 .52474 L
.65834 .52477 L
.65858 .52479 L
.65881 .52478 L
.65904 .52478 L
.65927 .52475 L
.65951 .52473 L
.65974 .52471 L
.65997 .5247 L
.6602 .52477 L
.66044 .52482 L
.66067 .52485 L
.6609 .52488 L
.66113 .52489 L
.66137 .5249 L
.6616 .52492 L
.66183 .52494 L
.66206 .52494 L
.6623 .52494 L
.66253 .52495 L
.66276 .52495 L
.66299 .52497 L
.66323 .52498 L
Mistroke
.66346 .52499 L
.66369 .525 L
.66392 .5237 L
.66416 .52275 L
.66439 .52215 L
.66462 .52146 L
.66485 .52112 L
.66509 .52069 L
.66532 .52016 L
.66555 .51966 L
.66578 .5195 L
.66602 .51926 L
.66625 .51892 L
.66648 .5186 L
.66671 .51819 L
.66695 .51781 L
.66718 .51745 L
.66741 .51708 L
.66764 .51707 L
.66788 .51696 L
.66811 .51676 L
.66834 .51658 L
.66857 .51631 L
.66881 .51606 L
.66904 .51584 L
.66927 .51561 L
.6695 .51529 L
.66974 .51499 L
.66997 .51472 L
.6702 .51444 L
.67043 .51419 L
.67067 .51393 L
.6709 .51366 L
.67113 .51339 L
.67136 .51527 L
.6716 .51658 L
.67183 .51731 L
.67206 .5182 L
.67229 .51851 L
.67253 .51897 L
.67276 .51959 L
.67299 .52016 L
.67322 .52017 L
.67346 .52032 L
.67369 .52063 L
.67392 .5209 L
.67415 .52132 L
.67439 .5217 L
.67462 .52204 L
.67485 .5224 L
Mistroke
.67508 .52217 L
.67532 .5221 L
.67555 .52219 L
.67578 .52223 L
.67601 .52243 L
.67625 .52258 L
.67648 .5227 L
.67671 .52282 L
.67694 .5231 L
.67718 .52334 L
.67741 .52354 L
.67764 .52375 L
.67787 .52391 L
.67811 .52409 L
.67834 .52428 L
.67857 .52447 L
.6788 .52305 L
.67904 .52206 L
.67927 .5215 L
.6795 .52082 L
.67973 .52058 L
.67997 .52022 L
.6802 .51974 L
.68043 .5193 L
.68066 .51929 L
.6809 .51916 L
.68113 .51891 L
.68136 .5187 L
.68159 .51837 L
.68183 .51807 L
.68206 .5178 L
.68229 .51753 L
.68252 .51768 L
.68276 .51772 L
.68299 .51765 L
.68322 .5176 L
.68345 .51744 L
.68369 .51732 L
.68392 .51722 L
.68415 .51711 L
.68438 .51689 L
.68462 .5167 L
.68485 .51654 L
.68508 .51637 L
.68531 .51623 L
.68555 .51609 L
.68578 .51593 L
.68601 .51578 L
.68624 .51606 L
.68648 .51622 L
Mistroke
.68671 .51627 L
.68694 .51635 L
.68717 .51632 L
.68741 .51631 L
.68764 .51634 L
.68787 .51635 L
.6881 .51625 L
.68834 .51619 L
.68857 .51615 L
.6888 .51611 L
.68903 .51609 L
.68927 .51607 L
.6895 .51604 L
.68973 .51601 L
.68996 .51587 L
.6902 .51576 L
.69043 .51567 L
.69066 .51558 L
.69089 .51553 L
.69113 .51546 L
.69136 .51538 L
.69159 .51531 L
.69182 .51527 L
.69206 .51522 L
.69229 .51516 L
.69252 .5151 L
.69275 .51504 L
.69299 .51497 L
.69322 .51491 L
.69345 .51485 L
.69368 .51429 L
.69392 .51386 L
.69415 .51357 L
.69438 .51324 L
.69461 .51305 L
.69485 .51282 L
.69508 .51255 L
.69531 .51229 L
.69555 .51217 L
.69578 .51201 L
.69601 .51181 L
.69624 .51163 L
.69648 .51141 L
.69671 .5112 L
.69694 .51099 L
.69717 .51079 L
.69741 .51072 L
.69764 .51061 L
.69787 .51047 L
.6981 .51034 L
Mistroke
.69834 .51017 L
.69857 .51001 L
.6988 .50986 L
.69903 .50971 L
.69927 .50952 L
.6995 .50934 L
.69973 .50917 L
.69996 .509 L
.7002 .50884 L
.70043 .50867 L
.70066 .50851 L
.70089 .50834 L
.70113 .51274 L
.70136 .51591 L
.70159 .51786 L
.70182 .52014 L
.70206 .5212 L
.70229 .52258 L
.70252 .52429 L
.70275 .52592 L
.70299 .52632 L
.70322 .52705 L
.70345 .5281 L
.70368 .52907 L
.70392 .53037 L
.70415 .53157 L
.70438 .5327 L
.70461 .53384 L
.70485 .52558 L
.70508 .51984 L
.70531 .51662 L
.70554 .51272 L
.70578 .51135 L
.70601 .50929 L
.70624 .50657 L
.70647 .50402 L
.70671 .504 L
.70694 .5033 L
.70717 .50192 L
.7074 .50073 L
.70764 .49886 L
.70787 .49717 L
.7081 .49566 L
.70833 .4941 L
.70857 .49881 L
.7088 .50185 L
.70903 .5032 L
.70926 .505 L
.7095 .50513 L
.70973 .5057 L
Mistroke
.70996 .50672 L
.71019 .50762 L
.71043 .50685 L
.71066 .50652 L
.71089 .50664 L
.71112 .50665 L
.71136 .5071 L
.71159 .50743 L
.71182 .50764 L
.71205 .50789 L
.71229 .50645 L
.71252 .50546 L
.71275 .50493 L
.71298 .50427 L
.71322 .50406 L
.71345 .50374 L
.71368 .50329 L
.71391 .50287 L
.71415 .50291 L
.71438 .50282 L
.71461 .50262 L
.71484 .50244 L
.71508 .50215 L
.71531 .50189 L
.71554 .50165 L
.71577 .50142 L
.71601 .50141 L
.71624 .50133 L
.71647 .5012 L
.7167 .50109 L
.71694 .50091 L
.71717 .50075 L
.7174 .5006 L
.71763 .50045 L
.71787 .50024 L
.7181 .50005 L
.71833 .49987 L
.71856 .49969 L
.7188 .49952 L
.71903 .49935 L
.71926 .49918 L
.71949 .49901 L
.71973 .49877 L
.71996 .49855 L
.72019 .49835 L
.72042 .49815 L
.72066 .49796 L
.72089 .49776 L
.72112 .49757 L
.72135 .49737 L
Mistroke
.72159 .49719 L
.72182 .497 L
.72205 .49681 L
.72228 .49662 L
.72252 .49643 L
.72275 .49624 L
.72298 .49605 L
.72321 .49586 L
.72345 .49912 L
.72368 .50145 L
.72391 .50286 L
.72414 .50452 L
.72438 .50526 L
.72461 .50624 L
.72484 .50747 L
.72507 .50863 L
.72531 .50887 L
.72554 .50935 L
.72577 .51009 L
.726 .51075 L
.72624 .51167 L
.72647 .51252 L
.7267 .5133 L
.72693 .5141 L
.72717 .51398 L
.7274 .5141 L
.72763 .51447 L
.72786 .51478 L
.7281 .51533 L
.72833 .51581 L
.72856 .51623 L
.72879 .51667 L
.72903 .51736 L
.72926 .51798 L
.72949 .51853 L
.72972 .5191 L
.72996 .5196 L
.73019 .52012 L
.73042 .52066 L
.73065 .5212 L
.73089 .52081 L
.73112 .52067 L
.73135 .52077 L
.73158 .52081 L
.73182 .5211 L
.73205 .52132 L
.73228 .52147 L
.73251 .52164 L
.73275 .52206 L
.73298 .52242 L
Mistroke
.73321 .5227 L
.73344 .52301 L
.73368 .52325 L
.73391 .5235 L
.73414 .52378 L
.73438 .52405 L
.73461 .52456 L
.73484 .52501 L
.73507 .5254 L
.73531 .5258 L
.73554 .52613 L
.73577 .52649 L
.736 .52686 L
.73624 .52723 L
.73647 .52753 L
.7367 .52784 L
.73693 .52818 L
.73717 .52851 L
.7374 .52886 L
.73763 .5292 L
.73786 .52954 L
.7381 .52988 L
.73833 .5311 L
.73856 .53208 L
.73879 .53283 L
.73903 .53364 L
.73926 .53422 L
.73949 .53486 L
.73972 .53556 L
.73996 .53625 L
.74019 .5367 L
.74042 .53721 L
.74065 .53778 L
.74089 .53834 L
.74112 .53897 L
.74135 .53957 L
.74158 .54016 L
.74182 .54075 L
.74205 .54111 L
.74228 .54153 L
.74251 .54201 L
.74275 .54248 L
.74298 .54301 L
.74321 .54352 L
.74344 .54402 L
.74368 .54452 L
.74391 .54508 L
.74414 .54563 L
.74437 .54616 L
.74461 .54669 L
Mistroke
.74484 .54721 L
.74507 .54773 L
.7453 .54826 L
.74554 .54878 L
.74577 .54907 L
.746 .54942 L
.74623 .54984 L
.74647 .55024 L
.7467 .5507 L
.74693 .55115 L
.74716 .55157 L
.7474 .55201 L
.74763 .5525 L
.74786 .55298 L
.74809 .55344 L
.74833 .55391 L
.74856 .55436 L
.74879 .55481 L
.74902 .55527 L
.74926 .55573 L
.74949 .55625 L
.74972 .55675 L
.74995 .55724 L
.75019 .55773 L
.75042 .55821 L
.75065 .55869 L
.75088 .55917 L
.75112 .55965 L
.75135 .56012 L
.75158 .56059 L
.75181 .56106 L
.75205 .56153 L
.75228 .56201 L
.75251 .56249 L
.75274 .56296 L
.75298 .56344 L
.75321 .56462 L
.75344 .56561 L
.75367 .56641 L
.75391 .56727 L
.75414 .56793 L
.75437 .56865 L
.7546 .56941 L
.75484 .57016 L
.75507 .57073 L
.7553 .57134 L
.75553 .57201 L
.75577 .57266 L
.756 .57336 L
.75623 .57405 L
Mistroke
.75646 .57472 L
.7567 .5754 L
.75693 .57589 L
.75716 .57643 L
.75739 .57702 L
.75763 .57759 L
.75786 .57822 L
.75809 .57884 L
.75832 .57944 L
.75856 .58004 L
.75879 .58069 L
.75902 .58133 L
.75925 .58196 L
.75949 .58259 L
.75972 .58321 L
.75995 .58383 L
.76018 .58446 L
.76042 .58508 L
.76065 .58551 L
.76088 .586 L
.76111 .58654 L
.76135 .58706 L
.76158 .58763 L
.76181 .58819 L
.76204 .58874 L
.76228 .58929 L
.76251 .58989 L
.76274 .59047 L
.76297 .59105 L
.76321 .59162 L
.76344 .59219 L
.76367 .59275 L
.7639 .59332 L
.76414 .59389 L
.76437 .59451 L
.7646 .59512 L
.76483 .59571 L
.76507 .59631 L
.7653 .59689 L
.76553 .59748 L
.76576 .59807 L
.766 .59866 L
.76623 .59924 L
.76646 .59982 L
.76669 .6004 L
.76693 .60098 L
.76716 .60157 L
.76739 .60215 L
.76762 .60273 L
.76786 .60332 L
Mistroke
.76809 .60008 L
.76832 .59786 L
.76855 .59667 L
.76879 .5952 L
.76902 .59476 L
.76925 .59404 L
.76948 .59305 L
.76972 .59213 L
.76995 .59224 L
.77018 .59207 L
.77041 .59163 L
.77065 .59126 L
.77088 .59062 L
.77111 .59005 L
.77134 .58956 L
.77158 .58904 L
.77181 .58955 L
.77204 .58979 L
.77227 .58975 L
.77251 .58978 L
.77274 .58954 L
.77297 .58938 L
.7732 .58928 L
.77344 .58917 L
.77367 .58878 L
.7739 .58847 L
.77414 .58823 L
.77437 .58797 L
.7746 .58778 L
.77483 .58758 L
.77507 .58735 L
.7753 .58713 L
.77553 .58793 L
.77576 .58846 L
.776 .58872 L
.77623 .58905 L
.77646 .5891 L
.77669 .58923 L
.77693 .58943 L
.77716 .58961 L
.77739 .58952 L
.77762 .5895 L
.77786 .58956 L
.77809 .58959 L
.77832 .5897 L
.77855 .58979 L
.77879 .58985 L
.77902 .58993 L
.77925 .58973 L
.77948 .5896 L
Mistroke
.77972 .58955 L
.77995 .58947 L
.78018 .58947 L
.78041 .58945 L
.78065 .58942 L
.78088 .58938 L
.78111 .58942 L
.78134 .58944 L
.78158 .58944 L
.78181 .58945 L
.78204 .58943 L
.78227 .58942 L
.78251 .58942 L
.78274 .58942 L
.78297 .59028 L
.7832 .5909 L
.78344 .5913 L
.78367 .59176 L
.7839 .59199 L
.78413 .59228 L
.78437 .59263 L
.7846 .59296 L
.78483 .59306 L
.78506 .59323 L
.7853 .59346 L
.78553 .59367 L
.78576 .59394 L
.78599 .5942 L
.78623 .59443 L
.78646 .59468 L
.78669 .59469 L
.78692 .59476 L
.78716 .5949 L
.78739 .59502 L
.78762 .5952 L
.78785 .59536 L
.78809 .59551 L
.78832 .59567 L
.78855 .59588 L
.78878 .59608 L
.78902 .59626 L
.78925 .59645 L
.78948 .59662 L
.78971 .59679 L
.78995 .59697 L
.79018 .59714 L
.79041 .59685 L
.79064 .59667 L
.79088 .59663 L
.79111 .59655 L
Mistroke
.79134 .5966 L
.79157 .59662 L
.79181 .5966 L
.79204 .59659 L
.79227 .59671 L
.7925 .59679 L
.79274 .59684 L
.79297 .5969 L
.7932 .59692 L
.79343 .59696 L
.79367 .597 L
.7939 .59704 L
.79413 .59721 L
.79436 .59734 L
.7946 .59744 L
.79483 .59755 L
.79506 .59763 L
.79529 .59771 L
.79553 .5978 L
.79576 .59789 L
.79599 .59795 L
.79622 .59801 L
.79646 .59809 L
.79669 .59816 L
.79692 .59824 L
.79715 .59832 L
.79739 .5984 L
.79762 .59848 L
.79785 .59314 L
.79808 .58925 L
.79832 .58681 L
.79855 .58399 L
.79878 .58261 L
.79901 .58085 L
.79925 .5787 L
.79948 .57665 L
.79971 .57606 L
.79994 .57507 L
.80018 .5737 L
.80041 .57243 L
.80064 .57077 L
.80087 .56921 L
.80111 .56776 L
.80134 .56629 L
.80157 .55764 L
.8018 .55091 L
.80204 .5461 L
.80227 .54078 L
.8025 .53738 L
.80273 .53347 L
Mistroke
.80297 .52904 L
.8032 .52475 L
.80343 .52238 L
.80366 .5195 L
.8039 .5161 L
.80413 .51283 L
.80436 .50906 L
.80459 .50542 L
.80483 .50192 L
.80506 .49838 L
.80529 .50509 L
.80552 .50905 L
.80576 .51027 L
.80599 .51222 L
.80622 .51143 L
.80645 .51137 L
.80669 .51205 L
.80692 .51253 L
.80715 .51027 L
.80738 .50874 L
.80762 .50795 L
.80785 .50696 L
.80808 .50671 L
.80831 .50626 L
.80855 .50561 L
.80878 .50501 L
.80901 .50167 L
.80924 .49907 L
.80948 .4972 L
.80971 .49513 L
.80994 .4938 L
.81017 .49227 L
.81041 .49055 L
.81064 .48888 L
.81087 .48794 L
.8111 .48681 L
.81134 .48548 L
.81157 .4842 L
.8118 .48272 L
.81203 .4813 L
.81227 .47993 L
.8125 .47855 L
.81273 .47996 L
.81297 .48063 L
.8132 .48055 L
.81343 .48066 L
.81366 .48003 L
.8139 .4796 L
.81413 .47937 L
.81436 .47908 L
Mistroke
.81459 .47804 L
.81483 .47721 L
.81506 .47658 L
.81529 .47589 L
.81552 .4754 L
.81576 .47486 L
.81599 .47427 L
.81622 .47369 L
.81645 .47236 L
.81669 .47123 L
.81692 .4703 L
.81715 .46932 L
.81738 .46854 L
.81762 .46771 L
.81785 .46682 L
.81808 .46595 L
.81831 .46527 L
.81855 .46455 L
.81878 .46377 L
.81901 .463 L
.81924 .46218 L
.81948 .46137 L
.81971 .46058 L
.81994 .45979 L
.82017 .45653 L
.82041 .45394 L
.82064 .452 L
.82087 .44989 L
.8211 .44844 L
.82134 .44681 L
.82157 .445 L
.8218 .44324 L
.82203 .44214 L
.82227 .44086 L
.8225 .43941 L
.82273 .438 L
.82296 .43642 L
.8232 .43489 L
.82343 .4334 L
.82366 .4319 L
.82389 .43421 L
.82413 .4355 L
.82436 .43577 L
.82459 .43631 L
.82482 .43583 L
.82506 .43563 L
.82529 .4357 L
.82552 .43569 L
.82575 .43467 L
.82599 .43391 L
Mistroke
.82622 .43344 L
.82645 .43288 L
.82668 .43261 L
.82692 .43225 L
.82715 .43183 L
.82738 .43142 L
.82761 .43156 L
.82785 .43155 L
.82808 .43139 L
.82831 .43128 L
.82854 .43102 L
.82878 .4308 L
.82901 .43061 L
.82924 .43042 L
.82947 .43008 L
.82971 .42978 L
.82994 .42952 L
.83017 .42925 L
.8304 .42902 L
.83064 .42878 L
.83087 .42852 L
.8311 .42827 L
.83133 .42788 L
.83157 .42752 L
.8318 .4272 L
.83203 .42688 L
.83226 .42659 L
.8325 .42629 L
.83273 .42598 L
.83296 .42567 L
.83319 .4254 L
.83343 .42512 L
.83366 .42484 L
.83389 .42455 L
.83412 .42425 L
.83436 .42396 L
.83459 .42367 L
.83482 .42338 L
.83505 .4211 L
.83529 .41935 L
.83552 .41814 L
.83575 .41678 L
.83598 .41596 L
.83622 .41499 L
.83645 .41388 L
.83668 .41281 L
.83691 .41227 L
.83715 .41159 L
.83738 .41077 L
.83761 .40998 L
Mistroke
.83784 .40905 L
.83808 .40816 L
.83831 .40731 L
.83854 .40645 L
.83877 .40612 L
.83901 .40565 L
.83924 .40503 L
.83947 .40445 L
.8397 .40373 L
.83994 .40305 L
.84017 .40241 L
.8404 .40176 L
.84063 .40096 L
.84087 .4002 L
.8411 .39948 L
.84133 .39875 L
.84156 .39806 L
.8418 .39736 L
.84203 .39665 L
.84226 .39594 L
.84249 .39547 L
.84273 .39494 L
.84296 .39435 L
.84319 .39377 L
.84342 .39313 L
.84366 .3925 L
.84389 .3919 L
.84412 .39128 L
.84435 .3906 L
.84459 .38994 L
.84482 .3893 L
.84505 .38865 L
.84528 .38802 L
.84552 .38739 L
.84575 .38675 L
.84598 .38611 L
.84621 .3854 L
.84645 .38472 L
.84668 .38405 L
.84691 .38337 L
.84714 .38272 L
.84738 .38206 L
.84761 .38139 L
.84784 .38073 L
.84807 .38008 L
.84831 .37943 L
.84854 .37877 L
.84877 .37812 L
.849 .37746 L
.84924 .3768 L
Mistroke
.84947 .37614 L
.8497 .37548 L
.84993 .37476 L
.85017 .37405 L
.8504 .37336 L
.85063 .37267 L
.85086 .372 L
.8511 .37132 L
.85133 .37063 L
.85156 .36995 L
.8518 .36928 L
.85203 .36861 L
.85226 .36794 L
.85249 .36726 L
.85273 .36658 L
.85296 .36591 L
.85319 .36523 L
.85342 .36455 L
.85366 .36389 L
.85389 .36323 L
.85412 .36256 L
.85435 .3619 L
.85459 .36122 L
.85482 .36055 L
.85505 .35988 L
.85528 .35921 L
.85552 .35854 L
.85575 .35787 L
.85598 .3572 L
.85621 .35652 L
.85645 .35585 L
.85668 .35518 L
.85691 .35451 L
.85714 .35384 L
.85738 .36438 L
.85761 .37192 L
.85784 .37646 L
.85807 .3818 L
.85831 .38413 L
.85854 .38727 L
.85877 .39122 L
.859 .39495 L
.85924 .39567 L
.85947 .3972 L
.8597 .39953 L
.85993 .40165 L
.86017 .40458 L
.8604 .40728 L
.86063 .40978 L
.86086 .41233 L
Mistroke
.8611 .41187 L
.86133 .41222 L
.86156 .41338 L
.86179 .41432 L
.86203 .41606 L
.86226 .41759 L
.86249 .4189 L
.86272 .42027 L
.86296 .42245 L
.86319 .42441 L
.86342 .42615 L
.86365 .42796 L
.86389 .42954 L
.86412 .43119 L
.86435 .43289 L
.86458 .43458 L
.86482 .43326 L
.86505 .43275 L
.86528 .43304 L
.86551 .43311 L
.86575 .43399 L
.86598 .43466 L
.86621 .43511 L
.86644 .43562 L
.86668 .43693 L
.86691 .43803 L
.86714 .43891 L
.86737 .43985 L
.86761 .44057 L
.86784 .44135 L
.86807 .44219 L
.8683 .44302 L
.86854 .44465 L
.86877 .44606 L
.869 .44726 L
.86923 .44851 L
.86947 .44955 L
.8697 .45065 L
.86993 .4518 L
.87016 .45294 L
.8704 .45387 L
.87063 .45485 L
.87086 .45589 L
.87109 .45691 L
.87133 .45799 L
.87156 .45906 L
.87179 .46011 L
.87202 .46117 L
.87226 .45922 L
.87249 .45807 L
Mistroke
.87272 .45773 L
.87295 .45717 L
.87319 .45742 L
.87342 .45746 L
.87365 .45728 L
.87388 .45715 L
.87412 .45783 L
.87435 .4583 L
.87458 .45855 L
.87481 .45885 L
.87505 .45895 L
.87528 .4591 L
.87551 .4593 L
.87574 .45949 L
.87598 .46049 L
.87621 .46127 L
.87644 .46184 L
.87667 .46246 L
.87691 .46287 L
.87714 .46333 L
.87737 .46386 L
.8776 .46437 L
.87784 .46466 L
.87807 .46501 L
.8783 .46542 L
.87853 .46581 L
.87877 .46626 L
.879 .46669 L
.87923 .46711 L
.87946 .46753 L
.8797 .46876 L
.87993 .46977 L
.88016 .47057 L
.88039 .47143 L
.88063 .47206 L
.88086 .47276 L
.88109 .47352 L
.88132 .47425 L
.88156 .47478 L
.88179 .47536 L
.88202 .476 L
.88225 .47662 L
.88249 .4773 L
.88272 .47797 L
.88295 .47862 L
.88318 .47927 L
.88342 .47971 L
.88365 .48021 L
.88388 .48076 L
.88411 .4813 L
Mistroke
.88435 .4819 L
.88458 .48248 L
.88481 .48304 L
.88504 .48361 L
.88528 .48424 L
.88551 .48485 L
.88574 .48545 L
.88597 .48605 L
.88621 .48664 L
.88644 .48722 L
.88667 .48782 L
.8869 .48841 L
.88714 .48801 L
.88737 .48788 L
.8876 .48801 L
.88783 .48807 L
.88807 .4884 L
.8883 .48865 L
.88853 .48884 L
.88876 .48904 L
.889 .48951 L
.88923 .48991 L
.88946 .49023 L
.88969 .49058 L
.88993 .49085 L
.89016 .49115 L
.89039 .49146 L
.89063 .49177 L
.89086 .49234 L
.89109 .49284 L
.89132 .49327 L
.89156 .49372 L
.89179 .4941 L
.89202 .4945 L
.89225 .49492 L
.89249 .49533 L
.89272 .49567 L
.89295 .49603 L
.89318 .49641 L
.89342 .49678 L
.89365 .49717 L
.89388 .49756 L
.89411 .49794 L
.89435 .49833 L
.89458 .49898 L
.89481 .49956 L
.89504 .50006 L
.89528 .50059 L
.89551 .50104 L
.89574 .50152 L
Mistroke
.89597 .50201 L
.89621 .5025 L
.89644 .50292 L
.89667 .50335 L
.8969 .50381 L
.89714 .50426 L
.89737 .50473 L
.8976 .50519 L
.89783 .50565 L
.89807 .50611 L
.8983 .5065 L
.89853 .50691 L
.89876 .50733 L
.899 .50776 L
.89923 .5082 L
.89946 .50863 L
.89969 .50906 L
.89993 .5095 L
.90016 .50995 L
.90039 .51039 L
.90062 .51083 L
.90086 .51128 L
.90109 .51171 L
.90132 .51215 L
.90155 .51259 L
.90179 .51303 L
.90202 .51165 L
.90225 .51076 L
.90248 .51036 L
.90272 .50982 L
.90295 .50978 L
.90318 .5096 L
.90341 .50929 L
.90365 .50901 L
.90388 .50923 L
.90411 .50931 L
.90434 .50926 L
.90458 .50925 L
.90481 .50911 L
.90504 .509 L
.90527 .50893 L
.90551 .50884 L
.90574 .50925 L
.90597 .50952 L
.9062 .50967 L
.90644 .50985 L
.90667 .50989 L
.9069 .50998 L
.90713 .51009 L
.90737 .5102 L
Mistroke
.9076 .51018 L
.90783 .51019 L
.90806 .51024 L
.9083 .51028 L
.90853 .51035 L
.90876 .51042 L
.90899 .51047 L
.90923 .51053 L
.90946 .51108 L
.90969 .51149 L
.90992 .51177 L
.91016 .51209 L
.91039 .51228 L
.91062 .5125 L
.91085 .51276 L
.91109 .51301 L
.91132 .51313 L
.91155 .51328 L
.91178 .51347 L
.91202 .51365 L
.91225 .51386 L
.91248 .51406 L
.91271 .51426 L
.91295 .51446 L
.91318 .51452 L
.91341 .51462 L
.91364 .51476 L
.91388 .51489 L
.91411 .51505 L
.91434 .5152 L
.91457 .51535 L
.91481 .51549 L
.91504 .51567 L
.91527 .51585 L
.9155 .51601 L
.91574 .51617 L
.91597 .51633 L
.9162 .51649 L
.91643 .51665 L
.91667 .51681 L
.9169 .51308 L
.91713 .51039 L
.91736 .50875 L
.9176 .50683 L
.91783 .50595 L
.91806 .50479 L
.91829 .50335 L
.91853 .50198 L
.91876 .50166 L
.91899 .50105 L
Mistroke
.91922 .50017 L
.91946 .49937 L
.91969 .49828 L
.91992 .49727 L
.92015 .49633 L
.92039 .49538 L
.92062 .49546 L
.92085 .49527 L
.92108 .49479 L
.92132 .4944 L
.92155 .49372 L
.92178 .49312 L
.92201 .49259 L
.92225 .49204 L
.92248 .49121 L
.92271 .49046 L
.92294 .48978 L
.92318 .48909 L
.92341 .48846 L
.92364 .48782 L
.92387 .48716 L
.92411 .4865 L
.92434 .48689 L
.92457 .48699 L
.9248 .48682 L
.92504 .48672 L
.92527 .48634 L
.9255 .48604 L
.92573 .48581 L
.92597 .48556 L
.9262 .48503 L
.92643 .48458 L
.92666 .4842 L
.9269 .4838 L
.92713 .48348 L
.92736 .48313 L
.92759 .48277 L
.92783 .48241 L
.92806 .48177 L
.92829 .48121 L
.92852 .48072 L
.92876 .48022 L
.92899 .47978 L
.92922 .47933 L
.92945 .47886 L
.92969 .47839 L
.92992 .478 L
.93015 .47758 L
.93039 .47715 L
.93062 .47672 L
Mistroke
.93085 .47628 L
.93108 .47583 L
.93132 .4754 L
.93155 .47496 L
.93178 .47556 L
.93201 .47588 L
.93225 .47593 L
.93248 .47605 L
.93271 .47589 L
.93294 .47581 L
.93318 .4758 L
.93341 .47577 L
.93364 .47546 L
.93387 .47522 L
.93411 .47506 L
.93434 .47488 L
.93457 .47478 L
.9348 .47466 L
.93504 .47451 L
.93527 .47437 L
.9355 .47395 L
.93573 .47361 L
.93597 .47334 L
.9362 .47305 L
.93643 .47284 L
.93666 .4726 L
.9369 .47235 L
.93713 .4721 L
.93736 .47193 L
.93759 .47173 L
.93783 .47152 L
.93806 .47131 L
.93829 .47108 L
.93852 .47086 L
.93876 .47064 L
.93899 .47042 L
.93922 .46992 L
.93945 .4695 L
.93969 .46915 L
.93992 .46878 L
.94015 .46849 L
.94038 .46817 L
.94062 .46784 L
.94085 .46751 L
.94108 .46725 L
.94131 .46698 L
.94155 .46669 L
.94178 .4664 L
.94201 .46609 L
.94224 .46579 L
Mistroke
.94248 .46549 L
.94271 .46519 L
.94294 .46496 L
.94317 .46472 L
.94341 .46445 L
.94364 .46419 L
.94387 .46391 L
.9441 .46364 L
.94434 .46337 L
.94457 .4631 L
.9448 .46281 L
.94503 .46253 L
.94527 .46225 L
.9455 .46197 L
.94573 .46169 L
.94596 .46141 L
.9462 .46113 L
.94643 .46086 L
.94666 .46695 L
.94689 .47134 L
.94713 .47402 L
.94736 .47716 L
.94759 .47859 L
.94782 .48048 L
.94806 .48282 L
.94829 .48505 L
.94852 .48556 L
.94875 .48653 L
.94899 .48796 L
.94922 .48927 L
.94945 .49104 L
.94968 .49268 L
.94992 .4942 L
.95015 .49575 L
.95038 .49559 L
.95061 .4959 L
.95085 .49666 L
.95108 .49729 L
.95131 .49839 L
.95154 .49936 L
.95178 .50021 L
.95201 .50109 L
.95224 .50243 L
.95247 .50365 L
.95271 .50475 L
.95294 .50587 L
.95317 .50688 L
.9534 .50792 L
.95364 .50899 L
.95387 .51005 L
Mistroke
.9541 .5094 L
.95433 .50922 L
.95457 .50949 L
.9548 .50963 L
.95503 .51024 L
.95526 .51072 L
.9555 .51108 L
.95573 .51147 L
.95596 .51232 L
.95619 .51305 L
.95643 .51365 L
.95666 .51429 L
.95689 .5148 L
.95712 .51535 L
.95736 .51593 L
.95759 .5165 L
.95782 .51753 L
.95805 .51844 L
.95829 .51922 L
.95852 .52004 L
.95875 .52073 L
.95898 .52146 L
.95922 .52222 L
.95945 .52297 L
.95968 .5236 L
.95991 .52426 L
.96015 .52496 L
.96038 .52564 L
.96061 .52636 L
.96084 .52707 L
.96108 .52777 L
.96131 .52847 L
.96154 .52773 L
.96177 .52738 L
.96201 .52741 L
.96224 .52734 L
.96247 .52766 L
.9627 .52787 L
.96294 .52798 L
.96317 .52812 L
.9634 .52865 L
.96363 .52907 L
.96387 .52938 L
.9641 .52973 L
.96433 .52997 L
.96456 .53024 L
.9648 .53053 L
.96503 .53082 L
.96526 .5315 L
.96549 .53207 L
Mistroke
.96573 .53254 L
.96596 .53303 L
.96619 .53342 L
.96642 .53384 L
.96666 .53429 L
.96689 .53473 L
.96712 .53507 L
.96735 .53543 L
.96759 .53583 L
.96782 .53621 L
.96805 .53663 L
.96828 .53703 L
.96852 .53743 L
.96875 .53783 L
.96898 .53861 L
.96922 .5393 L
.96945 .53988 L
.96968 .54048 L
.96991 .54099 L
.97015 .54152 L
.97038 .54208 L
.97061 .54263 L
.97084 .54308 L
.97108 .54355 L
.97131 .54405 L
.97154 .54455 L
.97177 .54507 L
.97201 .54559 L
.97224 .5461 L
.97247 .54661 L
.9727 .54702 L
.97294 .54745 L
.97317 .54792 L
.9734 .54837 L
.97363 .54885 L
.97387 .54933 L
.9741 .5498 L
.97433 .55027 L
.97456 .55077 L
.9748 .55126 L
.97503 .55174 L
.97526 .55222 L
.97549 .5527 L
.97573 .55318 L
.97596 .55366 L
.97619 .55414 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],

Cell["2.1.3 Wavelet Packet Analysis of a Speech Signal", "Subsection",
  CellTags->{"S2.1.3", "3.1"}],

Cell["\<\
Before we analyze a specific example of a speech signal, we first \
look at a simple example to illustrate the usage of some of the functions. \
\
\>", "Text",
  CellTags->{"S2.1.3", "3.2"}],

Cell["Linear Chirp", "Subsubsection",
  CellTags->{"S2.1.3", "3.3"}],

Cell[TextData[{
  "Consider a chirp signal. A chirp can be thought of as a sine signal with \
its frequency changing with time. For example, a linear chirp is ",
  Cell[BoxData[
      \(TraditionalForm\`sin \((a  t\^2)\)\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " where the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`a  t\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " is linearly dependent on time. As an example, let us look at the \
following linear chirp signal ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\) = sin \((50  \[Pi]  t\^2)\)\)], 
    "InlineFormula",
    CellTags->"S2.1.3"],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] t < 1\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". "
}], "Text",
  CellTags->{"S2.1.3", "3.4"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.3", "3.5"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.3"],

Cell["This shows a linear chirp signal.", "MathCaption",
  CellTags->{"S2.1.3", "3.6"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Sin[50Pi t^2], {t, 0, 1},
AxesLabel -> {\"t\", None}, PlotLabel -> \"linear chirp\"]\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309008 0.294315 [
[.21429 .29651 -9 -9 ]
[.21429 .29651 9 0 ]
[.40476 .29651 -9 -9 ]
[.40476 .29651 9 0 ]
[.59524 .29651 -9 -9 ]
[.59524 .29651 9 0 ]
[.78571 .29651 -9 -9 ]
[.78571 .29651 9 0 ]
[.97619 .29651 -3 -9 ]
[.97619 .29651 3 0 ]
[1.025 .30901 0 -4.5 ]
[1.025 .30901 6 4.5 ]
[.01131 .01469 -12 -4.5 ]
[.01131 .01469 0 4.5 ]
[.01131 .16185 -24 -4.5 ]
[.01131 .16185 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -36 0 ]
[.5 .63053 36 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30901 m
.21429 .31526 L
s
[(0.2)] .21429 .29651 0 1 Mshowa
.40476 .30901 m
.40476 .31526 L
s
[(0.4)] .40476 .29651 0 1 Mshowa
.59524 .30901 m
.59524 .31526 L
s
[(0.6)] .59524 .29651 0 1 Mshowa
.78571 .30901 m
.78571 .31526 L
s
[(0.8)] .78571 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(1)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.2619 .30901 m
.2619 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.5 .30901 m
.5 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.7381 .30901 m
.7381 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
[(t)] 1.025 .30901 -1 0 Mshowa
.02381 .01469 m
.03006 .01469 L
s
[(-1)] .01131 .01469 1 0 Mshowa
.02381 .16185 m
.03006 .16185 L
s
[(-0.5)] .01131 .16185 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04412 m
.02756 .04412 L
s
.02381 .07356 m
.02756 .07356 L
s
.02381 .10299 m
.02756 .10299 L
s
.02381 .13242 m
.02756 .13242 L
s
.02381 .19128 m
.02756 .19128 L
s
.02381 .22071 m
.02756 .22071 L
s
.02381 .25014 m
.02756 .25014 L
s
.02381 .27958 m
.02756 .27958 L
s
.02381 .33844 m
.02756 .33844 L
s
.02381 .36787 m
.02756 .36787 L
s
.02381 .3973 m
.02756 .3973 L
s
.02381 .42673 m
.02756 .42673 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(linear chirp)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.02499 .30908 L
.02605 .30926 L
.02729 .30963 L
.02846 .31011 L
.03053 .31131 L
.03279 .31311 L
.03527 .3157 L
.0379 .31912 L
.04262 .32703 L
.04749 .33754 L
.05205 .34954 L
.06244 .38424 L
.08445 .48401 L
.09407 .53109 L
.09916 .55396 L
.10458 .57517 L
.10736 .58427 L
.10999 .59148 L
.11234 .59664 L
.11355 .59878 L
.11489 .60068 L
.11614 .60201 L
.11731 .60285 L
.11855 .60328 L
.11924 .60332 L
.11987 .60321 L
.121 .6027 L
.12223 .60165 L
.12338 .60018 L
.12446 .59838 L
.1267 .59323 L
.12881 .58661 L
.13112 .5773 L
.13362 .5648 L
.1387 .53124 L
.14335 .49103 L
.16388 .23446 L
.16903 .16524 L
.17388 .10649 L
.17825 .06313 L
.18071 .04389 L
.1818 .03675 L
.18298 .0301 L
.18413 .02469 L
.18518 .02073 L
.18623 .01772 L
.18724 .0158 L
.1884 .01476 L
.18948 .01494 L
Mistroke
.19066 .01644 L
.19193 .01956 L
.19316 .02415 L
.19449 .03082 L
.1969 .04741 L
.19924 .06907 L
.2014 .09356 L
.21098 .24585 L
.22108 .43875 L
.22597 .51897 L
.22837 .55069 L
.23059 .57411 L
.23183 .58442 L
.23314 .59302 L
.23446 .59911 L
.23521 .60139 L
.23591 .60274 L
.23713 .60322 L
.23825 .60156 L
.23947 .59741 L
.24076 .59041 L
.24191 .58187 L
.24296 .57229 L
.24531 .54465 L
.24953 .47551 L
.25911 .26112 L
.26397 .15168 L
.26663 .10069 L
.26912 .06192 L
.27123 .0372 L
.27242 .02711 L
.27351 .02044 L
.27469 .01602 L
.27598 .01474 L
.2772 .01695 L
.27833 .022 L
.27952 .03041 L
.2808 .043 L
.28312 .07466 L
.28588 .12583 L
.28842 .18346 L
.2936 .32047 L
.29914 .46587 L
.30178 .52312 L
.30307 .54662 L
.30427 .5651 L
.30533 .57873 L
.3065 .59042 L
.30768 .59848 L
.30893 .60282 L
Mistroke
.31011 .60282 L
.3112 .59927 L
.31245 .59096 L
.31364 .57895 L
.31473 .56445 L
.31574 .54817 L
.31804 .50201 L
.32316 .36424 L
.3287 .19696 L
.33124 .12852 L
.33263 .09616 L
.33393 .07007 L
.33513 .04994 L
.33622 .03529 L
.33743 .02346 L
.33873 .01626 L
.34001 .01488 L
.34065 .01636 L
.34136 .01969 L
.34261 .02987 L
.34379 .04432 L
.34517 .06708 L
.34643 .09305 L
.34928 .16688 L
.35406 .32015 L
.35658 .40369 L
.35927 .48461 L
.36054 .51741 L
.36173 .54432 L
.3629 .56618 L
.36397 .58214 L
.36499 .59332 L
.36607 .60069 L
.36715 .60332 L
.36834 .60059 L
.36958 .59145 L
.37072 .5776 L
.37203 .55536 L
.37327 .52849 L
.37788 .39027 L
.38284 .2129 L
.38527 .13421 L
.38751 .07552 L
.38876 .05013 L
.3894 .03965 L
.39009 .03037 L
.39078 .02315 L
.39142 .01839 L
.39219 .01525 L
.39288 .0148 L
Mistroke
.39408 .0195 L
.39538 .03235 L
.39661 .05166 L
.39774 .07531 L
.40661 .38022 L
.40916 .47129 L
.41042 .51012 L
.41159 .54121 L
.41273 .56616 L
.41377 .5836 L
.41492 .59671 L
.41615 .60301 L
.41739 .60108 L
.41854 .59188 L
.4198 .57377 L
.42043 .56162 L
.42112 .54605 L
.42355 .47562 L
.42581 .39246 L
.43046 .20434 L
.43275 .12241 L
.43487 .06337 L
.43607 .03921 L
.43736 .02227 L
.43865 .01496 L
.43938 .01528 L
.44007 .01856 L
.44126 .03099 L
.44235 .04967 L
.44355 .0777 L
.44482 .11489 L
.45041 .33848 L
.45284 .44007 L
.45413 .48772 L
.45549 .53119 L
.4567 .56244 L
.45735 .57571 L
.45804 .5872 L
.45926 .60004 L
.46039 .60325 L
.46163 .59683 L
.46281 .58129 L
.46387 .55984 L
.46503 .52898 L
.46759 .43745 L
.47031 .31816 L
.47287 .20387 L
.47522 .11238 L
.47636 .07669 L
.47761 .04596 L
Mistroke
.47886 .02518 L
.47954 .01844 L
.48018 .0152 L
.48136 .0171 L
.48244 .02773 L
.48368 .05018 L
.48486 .0808 L
.48703 .15785 L
.48904 .24583 L
.49358 .45516 L
.49477 .50133 L
.49601 .54229 L
.49707 .56979 L
.49823 .59089 L
.49948 .60225 L
.50018 .60319 L
.50082 .60063 L
.50206 .58642 L
.50323 .56227 L
.50433 .53082 L
.50549 .48945 L
.50757 .39929 L
.51228 .17305 L
.51353 .12097 L
.51473 .07929 L
.51538 .06019 L
.5161 .0429 L
.51735 .02226 L
.51855 .01477 L
.51982 .02026 L
.5209 .03582 L
.5221 .06406 L
.52349 .11011 L
.52477 .16274 L
.52766 .30382 L
.5304 .44006 L
.53159 .49208 L
.53289 .53948 L
.53415 .57426 L
.53532 .59476 L
.53643 .60304 L
.53762 .59928 L
.53886 .58152 L
.54002 .55272 L
.5413 .50901 L
.54267 .45031 L
.54703 .22615 L
.54933 .11865 L
.55062 .07171 L
.55178 .04027 L
Mistroke
.55249 .02697 L
.55326 .01795 L
.55399 .01473 L
.55465 .01637 L
.55595 .03209 L
.5566 .04608 L
.55732 .06583 L
.55864 .11291 L
.56004 .17626 L
.56259 .31057 L
.56524 .45063 L
.56655 .50905 L
.56776 .55257 L
.56885 .58127 L
.57001 .59909 L
.57118 .60294 L
.57247 .59054 L
.57776 .38578 L
.58035 .24121 L
.58269 .12272 L
.58397 .07254 L
.58517 .03832 L
.58645 .01824 L
.58717 .01473 L
.58783 .0166 L
.58913 .03441 L
.58987 .05256 L
.59056 .07443 L
.59195 .13124 L
.59345 .20709 L
.59592 .34839 L
.59722 .42161 L
.5986 .49138 L
.59994 .54564 L
.60114 .58057 L
.60236 .59989 L
.6035 .60247 L
.60462 .59009 L
.6058 .56162 L
.60681 .52591 L
.60791 .47645 L
.61268 .20444 L
.61393 .1385 L
.61528 .07936 L
.61656 .03947 L
.61774 .01896 L
.61881 .01504 L
.61998 .02703 L
.62121 .05714 L
.62235 .10009 L
Mistroke
.62512 .24661 L
.62776 .40615 L
.6289 .46931 L
.63012 .52661 L
.63083 .55338 L
.63146 .5731 L
.63271 .59774 L
.63386 .60297 L
.63493 .5923 L
.6361 .56408 L
.63733 .51726 L
.63941 .40813 L
.6417 .26668 L
.64411 .1281 L
.64481 .09556 L
.64547 .06906 L
.6467 .03267 L
.64786 .01617 L
.64894 .01727 L
.65012 .0366 L
.65138 .07666 L
.65251 .12784 L
.65375 .19647 L
.65626 .35445 L
.65746 .42887 L
.6586 .49171 L
.65971 .54205 L
.66073 .57635 L
.66195 .59938 L
.66326 .60095 L
.66457 .578 L
.66523 .55763 L
.66596 .529 L
.66847 .39151 L
.67083 .2384 L
.67196 .1691 L
.67319 .10371 L
.67435 .05614 L
.67543 .02731 L
.6765 .0151 L
.67746 .01876 L
.67858 .04024 L
.67963 .07623 L
.68079 .13085 L
.682 .20177 L
.68418 .3456 L
.68654 .49051 L
.68719 .52274 L
.68787 .55184 L
.6891 .58864 L
Mistroke
.69031 .60312 L
.691 .60113 L
.69165 .59252 L
.69282 .56129 L
.69407 .50731 L
.69643 .36464 L
.69859 .21791 L
.69974 .1471 L
.70096 .08426 L
.70166 .05611 L
.7023 .03647 L
.70355 .01599 L
.70483 .02113 L
.70556 .03579 L
.70623 .05641 L
.70746 .11034 L
.70876 .18561 L
.71092 .33286 L
.71297 .46784 L
.71411 .52824 L
.71534 .57586 L
.71646 .59924 L
.7175 .60232 L
.71876 .58166 L
.7199 .54128 L
.72122 .47306 L
.72246 .39359 L
.7247 .23566 L
.72593 .15481 L
.7271 .09081 L
.72837 .04106 L
.72952 .01777 L
.7306 .01681 L
.73178 .03882 L
.73307 .08874 L
.73372 .12274 L
.73444 .16572 L
.7369 .33784 L
.73822 .43007 L
.73947 .5062 L
.74016 .54054 L
.74092 .5703 L
.74224 .60003 L
.74349 .59943 L
.7442 .5867 L
.74483 .56778 L
.74607 .51272 L
.74724 .44286 L
.74947 .28303 L
.75156 .13961 L
Mistroke
.75261 .08253 L
.75373 .0389 L
.75498 .01595 L
.75612 .02035 L
.75735 .05197 L
.75805 .08119 L
.75869 .11461 L
.76113 .2794 L
.76337 .44306 L
.76459 .51736 L
.76573 .56842 L
.76688 .59773 L
.76815 .60084 L
.76922 .57937 L
.77036 .53375 L
.77101 .49903 L
.77171 .45542 L
.77298 .36496 L
.77536 .18724 L
.77654 .11189 L
.77764 .05794 L
.77879 .02371 L
.78006 .01571 L
.78115 .03457 L
.78215 .07146 L
.7833 .13407 L
.78439 .20847 L
.78687 .39735 L
.78823 .49045 L
.78951 .55715 L
.7907 .59415 L
.79199 .60204 L
.79317 .5794 L
.79425 .5353 L
.79691 .35717 L
.79944 .16475 L
.80083 .08086 L
.80162 .04686 L
.80234 .02582 L
.80363 .01543 L
.80428 .02356 L
.80499 .04265 L
.80626 .10023 L
.80742 .17462 L
.81003 .37774 L
.81122 .46556 L
.81233 .53272 L
.81349 .58109 L
.81475 .60302 L
.81594 .59182 L
Mistroke
.81706 .55389 L
.81807 .50003 L
.81915 .4254 L
.82158 .23237 L
.82277 .1449 L
.82385 .08006 L
.82505 .03214 L
.82634 .01472 L
.82702 .02053 L
.82775 .03832 L
.82844 .06548 L
.82908 .09873 L
.83176 .29524 L
.83314 .4064 L
.83386 .46015 L
.83462 .51015 L
.83588 .5724 L
.83704 .60062 L
.83813 .59901 L
.83932 .56616 L
.84063 .49743 L
.84202 .39614 L
.84453 .19127 L
.84517 .14423 L
.84586 .09978 L
.84711 .04079 L
.84841 .0151 L
.84916 .01851 L
.84984 .03326 L
.85105 .0842 L
.85236 .16977 L
.85475 .36584 L
.85619 .47702 L
.85689 .52228 L
.85754 .55624 L
.85829 .58473 L
.85909 .60108 L
.85978 .60249 L
.86051 .59143 L
.86182 .54021 L
.86305 .46199 L
.86584 .23142 L
.8671 .13511 L
.86776 .09282 L
.86846 .05669 L
.86974 .01866 L
.87093 .01967 L
.87207 .0533 L
.87314 .11076 L
.87431 .1959 L
Mistroke
.87557 .30237 L
.87694 .41891 L
.87822 .5118 L
.87886 .54855 L
.87955 .57819 L
.88031 .59803 L
.88101 .60329 L
.88224 .58219 L
.88293 .55395 L
.88357 .51865 L
.88599 .32998 L
.88714 .22996 L
.88839 .13173 L
.88957 .06124 L
.89067 .02323 L
.89194 .0176 L
.89265 .03299 L
.89329 .0578 L
.89453 .13083 L
.89569 .22217 L
.89781 .40782 L
.89897 .49714 L
.90005 .55997 L
.90122 .59781 L
.90251 .59766 L
.9036 .56319 L
.90476 .49566 L
.90743 .27181 L
.90883 .15353 L
.9096 .09949 L
.91032 .05928 L
.91162 .01838 L
.91231 .01512 L
.91305 .02633 L
.91436 .08164 L
.91557 .16513 L
.91798 .37743 L
.91925 .48224 L
.91995 .5294 L
.92061 .56444 L
.92192 .60139 L
.9231 .59393 L
.92421 .55209 L
.92541 .47454 L
.92778 .2669 L
.92908 .15458 L
.93032 .07128 L
.93147 .02533 L
.93272 .01694 L
.93385 .04816 L
Mistroke
.9349 .10676 L
.93614 .20358 L
.93731 .30947 L
.93869 .4343 L
.93996 .52861 L
.94122 .58756 L
.94185 .60093 L
.94254 .60205 L
.94324 .58883 L
.94399 .55949 L
.94469 .5188 L
.94533 .47258 L
.94786 .24559 L
.94924 .12871 L
.95053 .0503 L
.9512 .02624 L
.95192 .01504 L
.95273 .02111 L
.95346 .0434 L
.95412 .07632 L
.95485 .12426 L
.95616 .23517 L
.95873 .46966 L
.95947 .5236 L
.96017 .56324 L
.96147 .60168 L
.9627 .59063 L
.96384 .54088 L
.96508 .45064 L
.96639 .33068 L
.96765 .21166 L
.96884 .11352 L
.9695 .07104 L
.97021 .03736 L
.97146 .01473 L
.97265 .03866 L
.97392 .10875 L
.975 .19638 L
.97619 .309 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "We sample the signal at an interval of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]  t = 1/256\)], "InlineFormula",
    CellTags->"S2.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.7"}],

Cell["data = Sin[N[50 Pi](Range[0, 255., 1.]/256)^2];", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.3"],

Cell[TextData[{
  "These data are considered to be the coefficients (apart from a \
proportionality constant which we ignore) in the expansion of the original \
continuous signal in terms of the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_\(j  k\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`j = 8\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], 255\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". In wavelet packet transforms, a set of wavelet packet coefficients is \
first calculated. The coefficients are obtained as follows. The data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_\(8  k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " are decomposed into two sets or two blocks of data, each half the size of \
the original data, by convolving with filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ", respectively. Further decomposition will split each of the two blocks \
again into two smaller blocks of size 64 using the two filters. Each \
splitting or decomposition corresponds to going to a lower resolution level. \
So we have at the top, or finest level, the original data, a list of length \
256. The next level consists of two lists, each of length 128; the next level \
four lists or blocks, each of length 64, and so on. The order of these blocks \
within each level is always such that the block obtained from convolving with \
the lowpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " is on the left of that obtained from convolving with the highpass filter \
",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". If we denote by ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[\("w"\),
            "TB"], \(n  j\)], TraditionalForm]], "InlineFormula",
    CellTags->"S2.1.3"],
  " the space spanned by the basis ",
  Cell[BoxData[
      \(TraditionalForm
      \`{w\_\(n  j  k\) = \(2\^\(j/2\)\) \(w\_n\) \((2\^j - k)\)}\_k\)], 
    "InlineFormula",
    CellTags->"S2.1.3"],
  ", the function ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  " gives the coefficients of the decomposition in the basis of ",
  Cell[BoxData[
      \(TraditionalForm
      \`{{w\_\(0  j  k\)}, {{w\_\(0, j - 1, k\)}, {w\_\(1, j - 1, k\)}}, {{
            w\_\(0, j - 2, k\)}, {w\_\(1, j - 2, k\)}, {w\_\(2, j - 2, k\)}, {
            w\_\(3, j - 2, k\)}}, \[Ellipsis]}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". "
}], "Text",
  CellTags->{"S2.1.3", "3.8"}],

Cell["\<\
For example, here are the wavelet packet coefficients up to 4 \
decompositions using the coiflet filter of order 4.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.9"}],

Cell["\<\
(c4 = CoifletFilter[4];
coef = WaveletPacketCoefficients[data, c4, 4];)\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
We see that the output consists of five levels with the first being \
the highest level.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.10"}],

Cell[CellGroupData[{

Cell["Dimensions /@ coef", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \({{1, 256}, {2, 128}, {4, 64}, {8, 32}, {16, 16}}\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "The first entry of the output is a list of 256 elements, the original data \
before any decomposition. The second entry consists of two lists of 128 \
elements. These are the coefficients of the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_\(0, 7, k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_\(1, 7, k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], 127\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". Similarly, the last entry contains the coefficients of the basis \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_\(0, 4, k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_\(1, 4, k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Ellipsis]\ \)\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`{w\_\(15, 4, k\)}\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], 15\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". "
}], "Text",
  CellTags->{"S2.1.3", "3.11"}],

Cell[TextData[{
  "We can plot the wavelet packet coefficients using ",
  StyleBox["PlotCoefficients", "MR"],
  ". Note that each sublist is flattened out and vertical lines are inserted \
showing the original grouping of the coefficients within each sublist."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.12"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[coef, Axes -> {True, False},
PlotLabel -> \"wavelet packet coefficients\"]\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.0145225 [
[.02381 .00222 -3 -9 ]
[.02381 .00222 3 0 ]
[.20982 .00222 -6 -9 ]
[.20982 .00222 6 0 ]
[.39583 .00222 -9 -9 ]
[.39583 .00222 9 0 ]
[.58185 .00222 -9 -9 ]
[.58185 .00222 9 0 ]
[.76786 .00222 -9 -9 ]
[.76786 .00222 9 0 ]
[.95387 .00222 -9 -9 ]
[.95387 .00222 9 0 ]
[.5 .63053 -81 0 ]
[.5 .63053 81 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(0)] .02381 .00222 0 1 Mshowa
.20982 .01472 m
.20982 .02097 L
s
[(50)] .20982 .00222 0 1 Mshowa
.39583 .01472 m
.39583 .02097 L
s
[(100)] .39583 .00222 0 1 Mshowa
.58185 .01472 m
.58185 .02097 L
s
[(150)] .58185 .00222 0 1 Mshowa
.76786 .01472 m
.76786 .02097 L
s
[(200)] .76786 .00222 0 1 Mshowa
.95387 .01472 m
.95387 .02097 L
s
[(250)] .95387 .00222 0 1 Mshowa
.125 Mabswid
.06101 .01472 m
.06101 .01847 L
s
.09821 .01472 m
.09821 .01847 L
s
.13542 .01472 m
.13542 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.24702 .01472 m
.24702 .01847 L
s
.28423 .01472 m
.28423 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.35863 .01472 m
.35863 .01847 L
s
.43304 .01472 m
.43304 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.50744 .01472 m
.50744 .01847 L
s
.54464 .01472 m
.54464 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.65625 .01472 m
.65625 .01847 L
s
.69345 .01472 m
.69345 .01847 L
s
.73065 .01472 m
.73065 .01847 L
s
.80506 .01472 m
.80506 .01847 L
s
.84226 .01472 m
.84226 .01847 L
s
.87946 .01472 m
.87946 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.99107 .01472 m
.99107 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
[(wavelet packet coefficients)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12173 m
.02381 .12173 L
s
.02753 .12173 m
.02753 .12177 L
s
.03125 .12173 m
.03125 .12187 L
s
.03497 .12173 m
.03497 .12205 L
s
.03869 .12173 m
.03869 .12229 L
s
.04241 .12173 m
.04241 .1226 L
s
.04613 .12173 m
.04613 .12299 L
s
.04985 .12173 m
.04985 .12344 L
s
.05357 .12173 m
.05357 .12395 L
s
.05729 .12173 m
.05729 .12454 L
s
.06101 .12173 m
.06101 .12518 L
s
.06473 .12173 m
.06473 .12589 L
s
.06845 .12173 m
.06845 .12665 L
s
.07217 .12173 m
.07217 .12746 L
s
.07589 .12173 m
.07589 .12831 L
s
.07961 .12173 m
.07961 .12919 L
s
.08333 .12173 m
.08333 .1301 L
s
.08705 .12173 m
.08705 .13101 L
s
.09077 .12173 m
.09077 .13191 L
s
.09449 .12173 m
.09449 .13279 L
s
.09821 .12173 m
.09821 .13362 L
s
.10193 .12173 m
.10193 .13438 L
s
.10565 .12173 m
.10565 .13505 L
s
.10938 .12173 m
.10938 .1356 L
s
.1131 .12173 m
.1131 .13599 L
s
.11682 .12173 m
.11682 .13622 L
s
.12054 .12173 m
.12054 .13624 L
s
.12426 .12173 m
.12426 .13603 L
s
.12798 .12173 m
.12798 .13557 L
s
.1317 .12173 m
.1317 .13484 L
s
.13542 .12173 m
.13542 .13383 L
s
.13914 .12173 m
.13914 .13253 L
s
.14286 .12173 m
.14286 .13095 L
s
.14658 .12173 m
.14658 .12909 L
s
.1503 .12173 m
.1503 .127 L
s
.15402 .12173 m
.15402 .1247 L
s
.15774 .12173 m
.15774 .12225 L
s
.16146 .12173 m
.16146 .11971 L
s
.16518 .12173 m
.16518 .11717 L
s
.1689 .12173 m
.1689 .11472 L
s
.17262 .12173 m
.17262 .11245 L
s
.17634 .12173 m
.17634 .11047 L
s
.18006 .12173 m
.18006 .10888 L
s
.18378 .12173 m
.18378 .10778 L
s
.1875 .12173 m
.1875 .10725 L
s
.19122 .12173 m
.19122 .10736 L
s
.19494 .12173 m
.19494 .10814 L
s
.19866 .12173 m
.19866 .1096 L
s
.20238 .12173 m
.20238 .11172 L
s
.2061 .12173 m
.2061 .11441 L
s
.20982 .12173 m
.20982 .11757 L
s
.21354 .12173 m
.21354 .12102 L
s
.21726 .12173 m
.21726 .12459 L
s
.22098 .12173 m
.22098 .12804 L
s
.2247 .12173 m
.2247 .13116 L
s
.22842 .12173 m
.22842 .13369 L
s
.23214 .12173 m
.23214 .13544 L
s
.23586 .12173 m
.23586 .13622 L
s
.23958 .12173 m
.23958 .13594 L
s
.2433 .12173 m
.2433 .13455 L
s
.24702 .12173 m
.24702 .13211 L
s
.25074 .12173 m
.25074 .12877 L
s
.25446 .12173 m
.25446 .12478 L
s
.25818 .12173 m
.25818 .12045 L
s
.2619 .12173 m
.2619 .11618 L
s
.26563 .12173 m
.26563 .11236 L
s
.26935 .12173 m
.26935 .10939 L
s
.27307 .12173 m
.27307 .10761 L
s
.27679 .12173 m
.27679 .10727 L
s
.28051 .12173 m
.28051 .10845 L
s
.28423 .12173 m
.28423 .1111 L
s
.28795 .12173 m
.28795 .11498 L
s
.29167 .12173 m
.29167 .11969 L
s
.29539 .12173 m
.29539 .12471 L
s
.29911 .12173 m
.29911 .12943 L
s
.30283 .12173 m
.30283 .13325 L
s
.30655 .12173 m
.30655 .13564 L
s
.31027 .12173 m
.31027 .13622 L
s
.31399 .12173 m
.31399 .13484 L
s
.31771 .12173 m
.31771 .13163 L
s
.32143 .12173 m
.32143 .12696 L
s
.32515 .12173 m
.32515 .12148 L
s
.32887 .12173 m
.32887 .11597 L
s
.33259 .12173 m
.33259 .11128 L
s
.33631 .12173 m
.33631 .10818 L
s
.34003 .12173 m
.34003 .10722 L
s
.34375 .12173 m
.34375 .10865 L
s
.34747 .12173 m
.34747 .11229 L
s
.35119 .12173 m
.35119 .1176 L
s
.35491 .12173 m
.35491 .1237 L
s
.35863 .12173 m
.35863 .12951 L
s
.36235 .12173 m
.36235 .13394 L
s
.36607 .12173 m
.36607 .13613 L
s
.36979 .12173 m
.36979 .13556 L
s
.37351 .12173 m
.37351 .13228 L
s
.37723 .12173 m
.37723 .12684 L
s
.38095 .12173 m
.38095 .12031 L
s
.38467 .12173 m
.38467 .11401 L
s
.38839 .12173 m
.38839 .1093 L
s
.39211 .12173 m
.39211 .10725 L
s
.39583 .12173 m
.39583 .10839 L
s
.39955 .12173 m
.39955 .11257 L
s
.40327 .12173 m
.40327 .11891 L
s
.40699 .12173 m
.40699 .12596 L
s
.41071 .12173 m
.41071 .13207 L
s
.41443 .12173 m
.41443 .1357 L
s
.41815 .12173 m
.41815 .13588 L
s
.42188 .12173 m
.42188 .13248 L
s
.4256 .12173 m
.4256 .12627 L
s
.42932 .12173 m
.42932 .11881 L
s
.43304 .12173 m
.43304 .11208 L
s
.43676 .12173 m
.43676 .10792 L
s
.44048 .12173 m
.44048 .10756 L
s
.4442 .12173 m
.4442 .11121 L
s
.44792 .12173 m
.44792 .11791 L
s
.45164 .12173 m
.45164 .12578 L
s
.45536 .12173 m
.45536 .13251 L
s
.45908 .12173 m
.45908 .13603 L
s
.4628 .12173 m
.4628 .13518 L
s
.46652 .12173 m
.46652 .13012 L
s
.47024 .12173 m
.47024 .12236 L
s
.47396 .12173 m
.47396 .11433 L
s
.47768 .12173 m
.47768 .10868 L
s
.4814 .12173 m
.4814 .10734 L
s
.48512 .12173 m
.48512 .11087 L
s
.48884 .12173 m
.48884 .11816 L
s
.49256 .12173 m
.49256 .12676 L
s
.49628 .12173 m
.49628 .13363 L
s
.5 .12173 m
.5 .13626 L
s
.50372 .12173 m
.50372 .13359 L
s
.50744 .12173 m
.50744 .1265 L
s
.51116 .12173 m
.51116 .11756 L
s
.51488 .12173 m
.51488 .11016 L
s
.5186 .12173 m
.5186 .10721 L
s
.52232 .12173 m
.52232 .10997 L
s
.52604 .12173 m
.52604 .11745 L
s
.52976 .12173 m
.52976 .12671 L
s
.53348 .12173 m
.53348 .13399 L
s
.5372 .12173 m
.5372 .13619 L
s
.54092 .12173 m
.54092 .1323 L
s
.54464 .12173 m
.54464 .12384 L
s
.54836 .12173 m
.54836 .11442 L
s
.55208 .12173 m
.55208 .10817 L
s
.5558 .12173 m
.5558 .10794 L
s
.55952 .12173 m
.55952 .11396 L
s
.56324 .12173 m
.56324 .12359 L
s
.56696 .12173 m
.56696 .13241 L
s
.57068 .12173 m
.57068 .13624 L
s
.5744 .12173 m
.5744 .13317 L
s
.57813 .12173 m
.57813 .12454 L
s
.58185 .12173 m
.58185 .11449 L
s
.58557 .12173 m
.58557 .10798 L
s
.58929 .12173 m
.58929 .10835 L
s
.59301 .12173 m
.59301 .11554 L
s
.59673 .12173 m
.59673 .12595 L
s
.60045 .12173 m
.60045 .13423 L
s
.60417 .12173 m
.60417 .13594 L
s
.60789 .12173 m
.60789 .13006 L
s
.61161 .12173 m
.61161 .11964 L
s
.61533 .12173 m
.61533 .11032 L
s
.61905 .12173 m
.61905 .10728 L
s
.62277 .12173 m
.62277 .11234 L
s
.62649 .12173 m
.62649 .12276 L
s
.63021 .12173 m
.63021 .13264 L
s
.63393 .12173 m
.63393 .13623 L
s
.63765 .12173 m
.63765 .1313 L
s
.64137 .12173 m
.64137 .12066 L
s
.64509 .12173 m
.64509 .11061 L
s
.64881 .12173 m
.64881 .10729 L
s
.65253 .12173 m
.65253 .11284 L
s
.65625 .12173 m
.65625 .12396 L
s
.65997 .12173 m
.65997 .13372 L
s
.66369 .12173 m
.66369 .1359 L
s
.66741 .12173 m
.66741 .12897 L
s
.67113 .12173 m
.67113 .1173 L
s
.67485 .12173 m
.67485 .1085 L
s
.67857 .12173 m
.67857 .10846 L
s
.68229 .12173 m
.68229 .11734 L
s
.68601 .12173 m
.68601 .12924 L
s
.68973 .12173 m
.68973 .13604 L
s
.69345 .12173 m
.69345 .13295 L
s
.69717 .12173 m
.69717 .12198 L
s
.70089 .12173 m
.70089 .11079 L
s
.70461 .12173 m
.70461 .10739 L
s
.70833 .12173 m
.70833 .11434 L
s
.71205 .12173 m
.71205 .12672 L
s
.71577 .12173 m
.71577 .13547 L
s
.71949 .12173 m
.71949 .13401 L
s
.72321 .12173 m
.72321 .12331 L
s
.72693 .12173 m
.72693 .11137 L
s
.73065 .12173 m
.73065 .10734 L
s
.73438 .12173 m
.73438 .11445 L
s
.7381 .12173 m
.7381 .12729 L
s
.74182 .12173 m
.74182 .13579 L
s
.74554 .12173 m
.74554 .1331 L
s
.74926 .12173 m
.74926 .12124 L
s
.75298 .12173 m
.75298 .10975 L
s
.7567 .12173 m
.7567 .10805 L
s
.76042 .12173 m
.76042 .11769 L
s
.76414 .12173 m
.76414 .13075 L
s
.76786 .12173 m
.76786 .13623 L
s
.77158 .12173 m
.77158 .12938 L
s
.7753 .12173 m
.7753 .11593 L
s
.77902 .12173 m
.77902 .10747 L
s
.78274 .12173 m
.78274 .11148 L
s
.78646 .12173 m
.78646 .12457 L
s
.79018 .12173 m
.79018 .13517 L
s
.7939 .12173 m
.7939 .13371 L
s
.79762 .12173 m
.79762 .12138 L
s
.80134 .12173 m
.80134 .10933 L
s
.80506 .12173 m
.80506 .10871 L
s
.80878 .12173 m
.80878 .12022 L
s
.8125 .12173 m
.8125 .1332 L
s
.81622 .12173 m
.81622 .13534 L
s
.81994 .12173 m
.81994 .12447 L
s
.82366 .12173 m
.82366 .11094 L
s
.82738 .12173 m
.82738 .10786 L
s
.8311 .12173 m
.8311 .11839 L
s
.83482 .12173 m
.83482 .13226 L
s
.83854 .12173 m
.83854 .13566 L
s
.84226 .12173 m
.84226 .12507 L
s
.84598 .12173 m
.84598 .11106 L
s
.8497 .12173 m
.8497 .10793 L
s
.85342 .12173 m
.85342 .11902 L
s
.85714 .12173 m
.85714 .13296 L
s
.86086 .12173 m
.86086 .13517 L
s
.86458 .12173 m
.86458 .1232 L
s
.8683 .12173 m
.8683 .10963 L
s
.87202 .12173 m
.87202 .10902 L
s
.87574 .12173 m
.87574 .12216 L
s
.87946 .12173 m
.87946 .13486 L
s
.88318 .12173 m
.88318 .13317 L
s
.8869 .12173 m
.8869 .11881 L
s
.89063 .12173 m
.89063 .10768 L
s
.89435 .12173 m
.89435 .11232 L
s
.89807 .12173 m
.89807 .12764 L
s
.90179 .12173 m
.90179 .13625 L
s
.90551 .12173 m
.90551 .12818 L
s
.90923 .12173 m
.90923 .11262 L
s
.91295 .12173 m
.91295 .10767 L
s
.91667 .12173 m
.91667 .11925 L
s
.92039 .12173 m
.92039 .1338 L
s
.92411 .12173 m
.92411 .13398 L
s
.92783 .12173 m
.92783 .11943 L
s
.93155 .12173 m
.93155 .10764 L
s
.93527 .12173 m
.93527 .11303 L
s
.93899 .12173 m
.93899 .12913 L
s
.94271 .12173 m
.94271 .1361 L
s
.94643 .12173 m
.94643 .12518 L
s
.95015 .12173 m
.95015 .1099 L
s
.95387 .12173 m
.95387 .10956 L
s
.95759 .12173 m
.95759 .12472 L
s
.96131 .12173 m
.96131 .13608 L
s
.96503 .12173 m
.96503 .12893 L
s
.96875 .12173 m
.96875 .11241 L
s
.97247 .12173 m
.97247 .10807 L
s
.02381 .22875 m
.02381 .22404 L
s
.02753 .22875 m
.02753 .22936 L
s
.03125 .22875 m
.03125 .22954 L
s
.03497 .22875 m
.03497 .23052 L
s
.03869 .22875 m
.03869 .23189 L
s
.04241 .22875 m
.04241 .23363 L
s
.04613 .22875 m
.04613 .2357 L
s
.04985 .22875 m
.04985 .23805 L
s
.05357 .22875 m
.05357 .24058 L
s
.05729 .22875 m
.05729 .24315 L
s
.06101 .22875 m
.06101 .24556 L
s
.06473 .22875 m
.06473 .24758 L
s
.06845 .22875 m
.06845 .24892 L
s
.07217 .22875 m
.07217 .24927 L
s
.07589 .22875 m
.07589 .24832 L
s
.07961 .22875 m
.07961 .24586 L
s
.08333 .22875 m
.08333 .24178 L
s
.08705 .22875 m
.08705 .2362 L
s
.09077 .22875 m
.09077 .22948 L
s
.09449 .22875 m
.09449 .2223 L
s
.09821 .22875 m
.09821 .21563 L
s
.10193 .22875 m
.10193 .21058 L
s
.10565 .22875 m
.10565 .20827 L
s
.10938 .22875 m
.10938 .20953 L
s
.1131 .22875 m
.1131 .21459 L
s
.11682 .22875 m
.11682 .22286 L
s
.12054 .22875 m
.12054 .23279 L
s
.12426 .22875 m
.12426 .24208 L
s
.12798 .22875 m
.12798 .24813 L
s
.1317 .22875 m
.1317 .24884 L
s
.13542 .22875 m
.13542 .24343 L
s
.13914 .22875 m
.13914 .23306 L
s
.14286 .22875 m
.14286 .22089 L
s
.14658 .22875 m
.14658 .2113 L
s
.1503 .22875 m
.1503 .20829 L
s
.15402 .22875 m
.15402 .21371 L
s
.15774 .22875 m
.15774 .22586 L
s
.16146 .22875 m
.16146 .23964 L
s
.16518 .22875 m
.16518 .24841 L
s
.1689 .22875 m
.1689 .24729 L
s
.17262 .22875 m
.17262 .23615 L
s
.17634 .22875 m
.17634 .2206 L
s
.18006 .22875 m
.18006 .20958 L
s
.18378 .22875 m
.18378 .21024 L
s
.1875 .22875 m
.1875 .22291 L
s
.19122 .22875 m
.19122 .23974 L
s
.19494 .22875 m
.19494 .24911 L
s
.19866 .22875 m
.19866 .24367 L
s
.20238 .22875 m
.20238 .22675 L
s
.2061 .22875 m
.2061 .21117 L
s
.20982 .22875 m
.20982 .20989 L
s
.21354 .22875 m
.21354 .22475 L
s
.21726 .22875 m
.21726 .24335 L
s
.22098 .22875 m
.22098 .24876 L
s
.2247 .22875 m
.2247 .23517 L
s
.22842 .22875 m
.22842 .21511 L
s
.23214 .22875 m
.23214 .20872 L
s
.23586 .22875 m
.23586 .22333 L
s
.23958 .22875 m
.23958 .24398 L
s
.2433 .22875 m
.2433 .24777 L
s
.24702 .22875 m
.24702 .22965 L
s
.25074 .22875 m
.25074 .21031 L
s
.25446 .22875 m
.25446 .21339 L
s
.25818 .22875 m
.25818 .23584 L
s
.2619 .22875 m
.2619 .24928 L
s
.26563 .22875 m
.26563 .2355 L
s
.26935 .22875 m
.26935 .21241 L
s
.27307 .22875 m
.27307 .21212 L
s
.27679 .22875 m
.27679 .23577 L
s
.28051 .22875 m
.28051 .24918 L
s
.28423 .22875 m
.28423 .23175 L
s
.28795 .22875 m
.28795 .2096 L
s
.29167 .22875 m
.29167 .21777 L
s
.29539 .22875 m
.29539 .24381 L
s
.29911 .22875 m
.29911 .2449 L
s
.30283 .22875 m
.30283 .21855 L
s
.30655 .22875 m
.30655 .20987 L
s
.31027 .22875 m
.31027 .23469 L
s
.31399 .22875 m
.31399 .24878 L
s
.31771 .22875 m
.31771 .22582 L
s
.32143 .22875 m
.32143 .20839 L
s
.32515 .22875 m
.32515 .23019 L
s
.32887 .22875 m
.32887 .24916 L
s
.33259 .22875 m
.33259 .22725 L
s
.33631 .22875 m
.33631 .20844 L
s
.34003 .22875 m
.34003 .23188 L
s
.34375 .22875 m
.34375 .24866 L
s
.34747 .22875 m
.34747 .22252 L
s
.35119 .22875 m
.35119 .21012 L
s
.35491 .22875 m
.35491 .23929 L
s
.35863 .22875 m
.35863 .24446 L
s
.36235 .22875 m
.36235 .21341 L
s
.36607 .22875 m
.36607 .21843 L
s
.36979 .22875 m
.36979 .24797 L
s
.37351 .22875 m
.37351 .23093 L
s
.37723 .22875 m
.37723 .20866 L
s
.38095 .22875 m
.38095 .23654 L
s
.38467 .22875 m
.38467 .24455 L
s
.38839 .22875 m
.38839 .21204 L
s
.39211 .22875 m
.39211 .2232 L
s
.39583 .22875 m
.39583 .24888 L
s
.39955 .22875 m
.39955 .22063 L
s
.40327 .22875 m
.40327 .21461 L
s
.40699 .22875 m
.40699 .24737 L
s
.41071 .22875 m
.41071 .22816 L
s
.41443 .22875 m
.41443 .21084 L
s
.41815 .22875 m
.41815 .2446 L
s
.42188 .22875 m
.42188 .2324 L
s
.4256 .22875 m
.4256 .20977 L
s
.42932 .22875 m
.42932 .24326 L
s
.43304 .22875 m
.43304 .23316 L
s
.43676 .22875 m
.43676 .20999 L
s
.44048 .22875 m
.44048 .24414 L
s
.4442 .22875 m
.4442 .23055 L
s
.44792 .22875 m
.44792 .21164 L
s
.45164 .22875 m
.45164 .24658 L
s
.45536 .22875 m
.45536 .2246 L
s
.45908 .22875 m
.45908 .21628 L
s
.4628 .22875 m
.4628 .24821 L
s
.46652 .22875 m
.46652 .21637 L
s
.47024 .22875 m
.47024 .22572 L
s
.47396 .22875 m
.47396 .24485 L
s
.47768 .22875 m
.47768 .21003 L
s
.4814 .22875 m
.4814 .23878 L
s
.48512 .22875 m
.48512 .23296 L
s
.48884 .22875 m
.48884 .21301 L
s
.49256 .22875 m
.49256 .24745 L
s
.49628 .22875 m
.49628 .21697 L
s
.5 .22875 m
.5 .2282 L
s
.50372 .22875 m
.50372 .22903 L
s
.50744 .22875 m
.50744 .22873 L
s
.51116 .22875 m
.51116 .22875 L
s
.51488 .22875 m
.51488 .22875 L
s
.5186 .22875 m
.5186 .22875 L
s
.52232 .22875 m
.52232 .22875 L
s
.52604 .22875 m
.52604 .22875 L
s
.52976 .22875 m
.52976 .22875 L
s
.53348 .22875 m
.53348 .22875 L
s
.5372 .22875 m
.5372 .22875 L
s
.54092 .22875 m
.54092 .22875 L
s
.54464 .22875 m
.54464 .22875 L
s
.54836 .22875 m
.54836 .22875 L
s
.55208 .22875 m
.55208 .22875 L
s
.5558 .22875 m
.5558 .22875 L
s
.55952 .22875 m
.55952 .22875 L
s
.56324 .22875 m
.56324 .22875 L
s
.56696 .22875 m
.56696 .22875 L
s
.57068 .22875 m
.57068 .22875 L
s
.5744 .22875 m
.5744 .22876 L
s
.57813 .22875 m
.57813 .22876 L
s
.58185 .22875 m
.58185 .22877 L
s
.58557 .22875 m
.58557 .22877 L
s
.58929 .22875 m
.58929 .22877 L
s
.59301 .22875 m
.59301 .22876 L
s
.59673 .22875 m
.59673 .22875 L
s
.60045 .22875 m
.60045 .22873 L
s
.60417 .22875 m
.60417 .22872 L
s
.60789 .22875 m
.60789 .22871 L
s
.61161 .22875 m
.61161 .22872 L
s
.61533 .22875 m
.61533 .22874 L
s
.61905 .22875 m
.61905 .22878 L
s
.62277 .22875 m
.62277 .22882 L
s
.62649 .22875 m
.62649 .22883 L
s
.63021 .22875 m
.63021 .22881 L
s
.63393 .22875 m
.63393 .22875 L
s
.63765 .22875 m
.63765 .22868 L
s
.64137 .22875 m
.64137 .22863 L
s
.64509 .22875 m
.64509 .22865 L
s
.64881 .22875 m
.64881 .22874 L
s
.65253 .22875 m
.65253 .22886 L
s
.65625 .22875 m
.65625 .22893 L
s
.65997 .22875 m
.65997 .22889 L
s
.66369 .22875 m
.66369 .22874 L
s
.66741 .22875 m
.66741 .22857 L
s
.67113 .22875 m
.67113 .22851 L
s
.67485 .22875 m
.67485 .22864 L
s
.67857 .22875 m
.67857 .2289 L
s
.68229 .22875 m
.68229 .22907 L
s
.68601 .22875 m
.68601 .22898 L
s
.68973 .22875 m
.68973 .22866 L
s
.69345 .22875 m
.69345 .22838 L
s
.69717 .22875 m
.69717 .22843 L
s
.70089 .22875 m
.70089 .22884 L
s
.70461 .22875 m
.70461 .22921 L
s
.70833 .22875 m
.70833 .22913 L
s
.71205 .22875 m
.71205 .2286 L
s
.71577 .22875 m
.71577 .22817 L
s
.71949 .22875 m
.71949 .22839 L
s
.72321 .22875 m
.72321 .2291 L
s
.72693 .22875 m
.72693 .22946 L
s
.73065 .22875 m
.73065 .22893 L
s
.73438 .22875 m
.73438 .22808 L
s
.7381 .22875 m
.7381 .22807 L
s
.74182 .22875 m
.74182 .22903 L
s
.74554 .22875 m
.74554 .22971 L
s
.74926 .22875 m
.74926 .22902 L
s
.75298 .22875 m
.75298 .22784 L
s
.7567 .22875 m
.7567 .22797 L
s
.76042 .22875 m
.76042 .22939 L
s
.76414 .22875 m
.76414 .22991 L
s
.76786 .22875 m
.76786 .22853 L
s
.77158 .22875 m
.77158 .22738 L
s
.7753 .22875 m
.7753 .22854 L
s
.77902 .22875 m
.77902 .23021 L
s
.78274 .22875 m
.78274 .22935 L
s
.78646 .22875 m
.78646 .22728 L
s
.79018 .22875 m
.79018 .22784 L
s
.7939 .22875 m
.7939 .23024 L
s
.79762 .22875 m
.79762 .22989 L
s
.80134 .22875 m
.80134 .22719 L
s
.80506 .22875 m
.80506 .2275 L
s
.80878 .22875 m
.80878 .23049 L
s
.8125 .22875 m
.8125 .23 L
s
.81622 .22875 m
.81622 .22674 L
s
.81994 .22875 m
.81994 .22769 L
s
.82366 .22875 m
.82366 .23113 L
s
.82738 .22875 m
.82738 .22936 L
s
.8311 .22875 m
.8311 .22603 L
s
.83482 .22875 m
.83482 .22892 L
s
.83854 .22875 m
.83854 .23162 L
s
.84226 .22875 m
.84226 .22748 L
s
.84598 .22875 m
.84598 .22622 L
s
.8497 .22875 m
.8497 .23127 L
s
.85342 .22875 m
.85342 .23021 L
s
.85714 .22875 m
.85714 .22529 L
s
.86086 .22875 m
.86086 .22918 L
s
.86458 .22875 m
.86458 .23218 L
s
.8683 .22875 m
.8683 .22609 L
s
.87202 .22875 m
.87202 .22694 L
s
.87574 .22875 m
.87574 .23287 L
s
.87946 .22875 m
.87946 .22756 L
s
.88318 .22875 m
.88318 .22535 L
s
.8869 .22875 m
.8869 .23283 L
s
.89063 .22875 m
.89063 .22883 L
s
.89435 .22875 m
.89435 .2244 L
s
.89807 .22875 m
.89807 .23273 L
s
.90179 .22875 m
.90179 .22948 L
s
.90551 .22875 m
.90551 .22386 L
s
.90923 .22875 m
.90923 .23304 L
s
.91295 .22875 m
.91295 .2293 L
s
.91667 .22875 m
.91667 .22368 L
s
.92039 .22875 m
.92039 .23391 L
s
.92411 .22875 m
.92411 .22804 L
s
.92783 .22875 m
.92783 .22425 L
s
.93155 .22875 m
.93155 .23501 L
s
.93527 .22875 m
.93527 .22559 L
s
.93899 .22875 m
.93899 .22634 L
s
.94271 .22875 m
.94271 .23518 L
s
.94643 .22875 m
.94643 .22262 L
s
.95015 .22875 m
.95015 .23052 L
s
.95387 .22875 m
.95387 .2326 L
s
.95759 .22875 m
.95759 .22146 L
s
.96131 .22875 m
.96131 .23537 L
s
.96503 .22875 m
.96503 .22647 L
s
.96875 .22875 m
.96875 .22564 L
s
.97247 .22875 m
.97247 .2355 L
s
.02381 .33577 m
.02381 .32703 L
s
.02753 .33577 m
.02753 .33815 L
s
.03125 .33577 m
.03125 .34012 L
s
.03497 .33577 m
.03497 .3456 L
s
.03869 .33577 m
.03869 .3525 L
s
.04241 .33577 m
.04241 .35954 L
s
.04613 .33577 m
.04613 .36429 L
s
.04985 .33577 m
.04985 .36345 L
s
.05357 .33577 m
.05357 .3542 L
s
.05729 .33577 m
.05729 .3368 L
s
.06101 .33577 m
.06101 .31721 L
s
.06473 .33577 m
.06473 .30681 L
s
.06845 .33577 m
.06845 .31574 L
s
.07217 .33577 m
.07217 .34147 L
s
.07589 .33577 m
.07589 .36317 L
s
.07961 .33577 m
.07961 .35653 L
s
.08333 .33577 m
.08333 .32467 L
s
.08705 .33577 m
.08705 .30686 L
s
.09077 .33577 m
.09077 .3317 L
s
.09449 .33577 m
.09449 .36353 L
s
.09821 .33577 m
.09821 .34616 L
s
.10193 .33577 m
.10193 .30876 L
s
.10565 .33577 m
.10565 .32765 L
s
.10938 .33577 m
.10938 .36431 L
s
.1131 .33577 m
.1131 .33278 L
s
.11682 .33577 m
.11682 .30964 L
s
.12054 .33577 m
.12054 .35618 L
s
.12426 .33577 m
.12426 .34423 L
s
.12798 .33577 m
.12798 .30858 L
s
.1317 .33577 m
.1317 .35666 L
s
.13542 .33577 m
.13542 .33634 L
s
.13914 .33577 m
.13914 .31604 L
s
.14286 .33577 m
.14286 .36234 L
s
.14658 .33577 m
.14658 .31446 L
s
.1503 .33577 m
.1503 .34543 L
s
.15402 .33577 m
.15402 .33836 L
s
.15774 .33577 m
.15774 .32372 L
s
.16146 .33577 m
.16146 .35362 L
s
.16518 .33577 m
.16518 .3152 L
s
.1689 .33577 m
.1689 .35706 L
s
.17262 .33577 m
.17262 .31482 L
s
.17634 .33577 m
.17634 .35594 L
s
.18006 .33577 m
.18006 .31666 L
s
.18378 .33577 m
.18378 .35341 L
s
.1875 .33577 m
.1875 .3204 L
s
.19122 .33577 m
.19122 .34761 L
s
.19494 .33577 m
.19494 .32901 L
s
.19866 .33577 m
.19866 .33618 L
s
.20238 .33577 m
.20238 .34187 L
s
.2061 .33577 m
.2061 .32504 L
s
.20982 .33577 m
.20982 .34703 L
s
.21354 .33577 m
.21354 .32904 L
s
.21726 .33577 m
.21726 .33484 L
s
.22098 .33577 m
.22098 .34285 L
s
.2247 .33577 m
.2247 .32863 L
s
.22842 .33577 m
.22842 .33694 L
s
.23214 .33577 m
.23214 .34062 L
s
.23586 .33577 m
.23586 .33125 L
s
.23958 .33577 m
.23958 .3347 L
s
.2433 .33577 m
.2433 .33976 L
s
.24702 .33577 m
.24702 .3352 L
s
.25074 .33577 m
.25074 .33299 L
s
.25446 .33577 m
.25446 .3362 L
s
.25818 .33577 m
.25818 .33932 L
s
.2619 .33577 m
.2619 .33194 L
s
.26563 .33577 m
.26563 .33644 L
s
.26935 .33577 m
.26935 .33571 L
s
.27307 .33577 m
.27307 .3358 L
s
.27679 .33577 m
.27679 .33579 L
s
.28051 .33577 m
.28051 .33578 L
s
.28423 .33577 m
.28423 .33574 L
s
.28795 .33577 m
.28795 .33567 L
s
.29167 .33577 m
.29167 .33564 L
s
.29539 .33577 m
.29539 .33571 L
s
.29911 .33577 m
.29911 .33593 L
s
.30283 .33577 m
.30283 .33616 L
s
.30655 .33577 m
.30655 .33607 L
s
.31027 .33577 m
.31027 .33549 L
s
.31399 .33577 m
.31399 .33491 L
s
.31771 .33577 m
.31771 .33537 L
s
.32143 .33577 m
.32143 .33682 L
s
.32515 .33577 m
.32515 .3371 L
s
.32887 .33577 m
.32887 .33482 L
s
.33259 .33577 m
.33259 .33353 L
s
.33631 .33577 m
.33631 .33686 L
s
.34003 .33577 m
.34003 .33885 L
s
.34375 .33577 m
.34375 .33362 L
s
.34747 .33577 m
.34747 .33252 L
s
.35119 .33577 m
.35119 .34036 L
s
.35491 .33577 m
.35491 .33666 L
s
.35863 .33577 m
.35863 .32931 L
s
.36235 .33577 m
.36235 .34112 L
s
.36607 .33577 m
.36607 .33744 L
s
.36979 .33577 m
.36979 .32745 L
s
.37351 .33577 m
.37351 .34525 L
s
.37723 .33577 m
.37723 .33111 L
s
.38095 .33577 m
.38095 .33272 L
s
.38467 .33577 m
.38467 .34576 L
s
.38839 .33577 m
.38839 .32185 L
s
.39211 .33577 m
.39211 .3503 L
s
.39583 .33577 m
.39583 .32308 L
s
.39955 .33577 m
.39955 .34543 L
s
.40327 .33577 m
.40327 .32923 L
s
.40699 .33577 m
.40699 .33987 L
s
.41071 .33577 m
.41071 .33299 L
s
.41443 .33577 m
.41443 .33867 L
s
.41815 .33577 m
.41815 .33113 L
s
.42188 .33577 m
.42188 .34387 L
s
.4256 .33577 m
.4256 .32271 L
s
.42932 .33577 m
.42932 .35453 L
s
.43304 .33577 m
.43304 .31227 L
s
.43676 .33577 m
.43676 .36043 L
s
.44048 .33577 m
.44048 .31643 L
s
.4442 .33577 m
.4442 .3421 L
s
.44792 .33577 m
.44792 .34708 L
s
.45164 .33577 m
.45164 .31084 L
s
.45536 .33577 m
.45536 .35957 L
s
.45908 .33577 m
.45908 .33131 L
s
.4628 .33577 m
.4628 .31564 L
s
.46652 .33577 m
.46652 .36155 L
s
.47024 .33577 m
.47024 .33354 L
s
.47396 .33577 m
.47396 .31083 L
s
.47768 .33577 m
.47768 .3531 L
s
.4814 .33577 m
.4814 .35324 L
s
.48512 .33577 m
.48512 .31316 L
s
.48884 .33577 m
.48884 .32159 L
s
.49256 .33577 m
.49256 .35838 L
s
.49628 .33577 m
.49628 .34954 L
s
.5 .33577 m
.5 .33845 L
s
.50372 .33577 m
.50372 .33557 L
s
.50744 .33577 m
.50744 .33575 L
s
.51116 .33577 m
.51116 .33577 L
s
.51488 .33577 m
.51488 .33577 L
s
.5186 .33577 m
.5186 .33577 L
s
.52232 .33577 m
.52232 .33577 L
s
.52604 .33577 m
.52604 .33577 L
s
.52976 .33577 m
.52976 .33576 L
s
.53348 .33577 m
.53348 .33576 L
s
.5372 .33577 m
.5372 .33578 L
s
.54092 .33577 m
.54092 .33579 L
s
.54464 .33577 m
.54464 .3358 L
s
.54836 .33577 m
.54836 .33577 L
s
.55208 .33577 m
.55208 .33572 L
s
.5558 .33577 m
.5558 .33572 L
s
.55952 .33577 m
.55952 .33581 L
s
.56324 .33577 m
.56324 .33588 L
s
.56696 .33577 m
.56696 .33577 L
s
.57068 .33577 m
.57068 .3356 L
s
.5744 .33577 m
.5744 .33575 L
s
.57813 .33577 m
.57813 .33602 L
s
.58185 .33577 m
.58185 .33575 L
s
.58557 .33577 m
.58557 .33543 L
s
.58929 .33577 m
.58929 .33598 L
s
.59301 .33577 m
.59301 .33608 L
s
.59673 .33577 m
.59673 .33524 L
s
.60045 .33577 m
.60045 .3359 L
s
.60417 .33577 m
.60417 .33628 L
s
.60789 .33577 m
.60789 .33498 L
s
.61161 .33577 m
.61161 .33627 L
s
.61533 .33577 m
.61533 .33595 L
s
.61905 .33577 m
.61905 .33492 L
s
.62277 .33577 m
.62277 .33698 L
s
.62649 .33577 m
.62649 .33458 L
s
.63021 .33577 m
.63021 .33664 L
s
.63393 .33577 m
.63393 .33538 L
s
.63765 .33577 m
.63765 .33568 L
s
.64137 .33577 m
.64137 .33627 L
s
.64509 .33577 m
.64509 .33497 L
s
.64881 .33577 m
.64881 .33676 L
s
.65253 .33577 m
.65253 .33473 L
s
.65625 .33577 m
.65625 .33672 L
s
.65997 .33577 m
.65997 .33509 L
s
.66369 .33577 m
.66369 .33599 L
s
.66741 .33577 m
.66741 .33622 L
s
.67113 .33577 m
.67113 .33454 L
s
.67485 .33577 m
.67485 .33772 L
s
.67857 .33577 m
.67857 .33349 L
s
.68229 .33577 m
.68229 .33766 L
s
.68601 .33577 m
.68601 .33508 L
s
.68973 .33577 m
.68973 .33487 L
s
.69345 .33577 m
.69345 .33776 L
s
.69717 .33577 m
.69717 .33411 L
s
.70089 .33577 m
.70089 .33577 L
s
.70461 .33577 m
.70461 .33734 L
s
.70833 .33577 m
.70833 .33439 L
s
.71205 .33577 m
.71205 .33539 L
s
.71577 .33577 m
.71577 .33721 L
s
.71949 .33577 m
.71949 .33543 L
s
.72321 .33577 m
.72321 .33469 L
s
.72693 .33577 m
.72693 .33624 L
s
.73065 .33577 m
.73065 .33677 L
s
.73438 .33577 m
.73438 .33512 L
s
.7381 .33577 m
.7381 .33609 L
s
.74182 .33577 m
.74182 .33563 L
s
.74554 .33577 m
.74554 .33578 L
s
.74926 .33577 m
.74926 .33577 L
s
.75298 .33577 m
.75298 .33577 L
s
.7567 .33577 m
.7567 .33577 L
s
.76042 .33577 m
.76042 .33577 L
s
.76414 .33577 m
.76414 .33577 L
s
.76786 .33577 m
.76786 .33577 L
s
.77158 .33577 m
.77158 .33577 L
s
.7753 .33577 m
.7753 .33577 L
s
.77902 .33577 m
.77902 .33577 L
s
.78274 .33577 m
.78274 .33577 L
s
.78646 .33577 m
.78646 .33577 L
s
.79018 .33577 m
.79018 .33577 L
s
.7939 .33577 m
.7939 .33578 L
s
.79762 .33577 m
.79762 .33577 L
s
.80134 .33577 m
.80134 .33576 L
s
.80506 .33577 m
.80506 .33578 L
s
.80878 .33577 m
.80878 .33579 L
s
.8125 .33577 m
.8125 .33576 L
s
.81622 .33577 m
.81622 .33574 L
s
.81994 .33577 m
.81994 .3358 L
s
.82366 .33577 m
.82366 .33581 L
s
.82738 .33577 m
.82738 .33569 L
s
.8311 .33577 m
.8311 .33578 L
s
.83482 .33577 m
.83482 .3359 L
s
.83854 .33577 m
.83854 .3356 L
s
.84226 .33577 m
.84226 .33581 L
s
.84598 .33577 m
.84598 .33596 L
s
.8497 .33577 m
.8497 .3354 L
s
.85342 .33577 m
.85342 .33614 L
s
.85714 .33577 m
.85714 .33562 L
s
.86086 .33577 m
.86086 .33558 L
s
.86458 .33577 m
.86458 .33634 L
s
.8683 .33577 m
.8683 .33489 L
s
.87202 .33577 m
.87202 .33687 L
s
.87574 .33577 m
.87574 .33453 L
s
.87946 .33577 m
.87946 .3371 L
s
.88318 .33577 m
.88318 .33435 L
s
.8869 .33577 m
.8869 .33734 L
s
.89063 .33577 m
.89063 .33396 L
s
.89435 .33577 m
.89435 .33796 L
s
.89807 .33577 m
.89807 .33312 L
s
.90179 .33577 m
.90179 .33889 L
s
.90551 .33577 m
.90551 .33241 L
s
.90923 .33577 m
.90923 .33879 L
s
.91295 .33577 m
.91295 .33404 L
s
.91667 .33577 m
.91667 .33515 L
s
.92039 .33577 m
.92039 .33926 L
s
.92411 .33577 m
.92411 .33037 L
s
.92783 .33577 m
.92783 .34025 L
s
.93155 .33577 m
.93155 .33574 L
s
.93527 .33577 m
.93527 .33034 L
s
.93899 .33577 m
.93899 .34245 L
s
.94271 .33577 m
.94271 .33507 L
s
.94643 .33577 m
.94643 .3286 L
s
.95015 .33577 m
.95015 .34203 L
s
.95387 .33577 m
.95387 .34023 L
s
.95759 .33577 m
.95759 .32675 L
s
.96131 .33577 m
.96131 .33327 L
s
.96503 .33577 m
.96503 .34604 L
s
.96875 .33577 m
.96875 .33881 L
s
.97247 .33577 m
.97247 .32843 L
s
.02381 .44279 m
.02381 .43766 L
s
.02753 .44279 m
.02753 .44989 L
s
.03125 .44279 m
.03125 .46623 L
s
.03497 .44279 m
.03497 .48318 L
s
.03869 .44279 m
.03869 .46888 L
s
.04241 .44279 m
.04241 .41611 L
s
.04613 .44279 m
.04613 .41545 L
s
.04985 .44279 m
.04985 .48079 L
s
.05357 .44279 m
.05357 .42606 L
s
.05729 .44279 m
.05729 .44103 L
s
.06101 .44279 m
.06101 .45064 L
s
.06473 .44279 m
.06473 .43809 L
s
.06845 .44279 m
.06845 .43975 L
s
.07217 .44279 m
.07217 .4524 L
s
.07589 .44279 m
.07589 .43395 L
s
.07961 .44279 m
.07961 .44439 L
s
.08333 .44279 m
.08333 .44547 L
s
.08705 .44279 m
.08705 .44205 L
s
.09077 .44279 m
.09077 .44205 L
s
.09449 .44279 m
.09449 .44278 L
s
.09821 .44279 m
.09821 .44296 L
s
.10193 .44279 m
.10193 .4429 L
s
.10565 .44279 m
.10565 .44272 L
s
.10938 .44279 m
.10938 .44242 L
s
.1131 .44279 m
.1131 .44271 L
s
.11682 .44279 m
.11682 .44393 L
s
.12054 .44279 m
.12054 .44273 L
s
.12426 .44279 m
.12426 .44063 L
s
.12798 .44279 m
.12798 .44528 L
s
.1317 .44279 m
.1317 .4416 L
s
.13542 .44279 m
.13542 .44259 L
s
.13914 .44279 m
.13914 .44403 L
s
.14286 .44279 m
.14286 .43878 L
s
.14658 .44279 m
.14658 .44365 L
s
.1503 .44279 m
.1503 .44293 L
s
.15402 .44279 m
.15402 .44125 L
s
.15774 .44279 m
.15774 .44123 L
s
.16146 .44279 m
.16146 .44829 L
s
.16518 .44279 m
.16518 .44171 L
s
.1689 .44279 m
.1689 .43302 L
s
.17262 .44279 m
.17262 .46164 L
s
.17634 .44279 m
.17634 .41873 L
s
.18006 .44279 m
.18006 .47142 L
s
.18378 .44279 m
.18378 .4089 L
s
.1875 .44279 m
.1875 .47543 L
s
.19122 .44279 m
.19122 .43303 L
s
.19494 .44279 m
.19494 .41271 L
s
.19866 .44279 m
.19866 .47053 L
s
.20238 .44279 m
.20238 .47312 L
s
.2061 .44279 m
.2061 .43909 L
s
.20982 .44279 m
.20982 .41753 L
s
.21354 .44279 m
.21354 .4127 L
s
.21726 .44279 m
.21726 .41428 L
s
.22098 .44279 m
.22098 .41783 L
s
.2247 .44279 m
.2247 .42604 L
s
.22842 .44279 m
.22842 .44226 L
s
.23214 .44279 m
.23214 .45798 L
s
.23586 .44279 m
.23586 .45215 L
s
.23958 .44279 m
.23958 .43295 L
s
.2433 .44279 m
.2433 .44121 L
s
.24702 .44279 m
.24702 .44874 L
s
.25074 .44279 m
.25074 .43793 L
s
.25446 .44279 m
.25446 .44605 L
s
.25818 .44279 m
.25818 .43624 L
s
.2619 .44279 m
.2619 .44397 L
s
.26563 .44279 m
.26563 .44307 L
s
.26935 .44279 m
.26935 .44274 L
s
.27307 .44279 m
.27307 .44274 L
s
.27679 .44279 m
.27679 .44259 L
s
.28051 .44279 m
.28051 .44303 L
s
.28423 .44279 m
.28423 .44318 L
s
.28795 .44279 m
.28795 .44158 L
s
.29167 .44279 m
.29167 .44437 L
s
.29539 .44279 m
.29539 .44118 L
s
.29911 .44279 m
.29911 .44459 L
s
.30283 .44279 m
.30283 .44035 L
s
.30655 .44279 m
.30655 .44582 L
s
.31027 .44279 m
.31027 .44047 L
s
.31399 .44279 m
.31399 .44276 L
s
.31771 .44279 m
.31771 .44431 L
s
.32143 .44279 m
.32143 .44237 L
s
.32515 .44279 m
.32515 .44221 L
s
.32887 .44279 m
.32887 .4428 L
s
.33259 .44279 m
.33259 .44292 L
s
.33631 .44279 m
.33631 .44285 L
s
.34003 .44279 m
.34003 .44292 L
s
.34375 .44279 m
.34375 .44318 L
s
.34747 .44279 m
.34747 .44287 L
s
.35119 .44279 m
.35119 .441 L
s
.35491 .44279 m
.35491 .44206 L
s
.35863 .44279 m
.35863 .44907 L
s
.36235 .44279 m
.36235 .43728 L
s
.36607 .44279 m
.36607 .43943 L
s
.36979 .44279 m
.36979 .45647 L
s
.37351 .44279 m
.37351 .42244 L
s
.37723 .44279 m
.37723 .46276 L
s
.38095 .44279 m
.38095 .44057 L
s
.38467 .44279 m
.38467 .44283 L
s
.38839 .44279 m
.38839 .44276 L
s
.39211 .44279 m
.39211 .44279 L
s
.39583 .44279 m
.39583 .44286 L
s
.39955 .44279 m
.39955 .44269 L
s
.40327 .44279 m
.40327 .44274 L
s
.40699 .44279 m
.40699 .44328 L
s
.41071 .44279 m
.41071 .44156 L
s
.41443 .44279 m
.41443 .44503 L
s
.41815 .44279 m
.41815 .43935 L
s
.42188 .44279 m
.42188 .44676 L
s
.4256 .44279 m
.4256 .44172 L
s
.42932 .44279 m
.42932 .43538 L
s
.43304 .44279 m
.43304 .45435 L
s
.43676 .44279 m
.43676 .44946 L
s
.44048 .44279 m
.44048 .42867 L
s
.4442 .44279 m
.4442 .42223 L
s
.44792 .44279 m
.44792 .42914 L
s
.45164 .44279 m
.45164 .43701 L
s
.45536 .44279 m
.45536 .4387 L
s
.45908 .44279 m
.45908 .43135 L
s
.4628 .44279 m
.4628 .41621 L
s
.46652 .44279 m
.46652 .40785 L
s
.47024 .44279 m
.47024 .43414 L
s
.47396 .44279 m
.47396 .47803 L
s
.47768 .44279 m
.47768 .44803 L
s
.4814 .44279 m
.4814 .40882 L
s
.48512 .44279 m
.48512 .47452 L
s
.48884 .44279 m
.48884 .42245 L
s
.49256 .44279 m
.49256 .45563 L
s
.49628 .44279 m
.49628 .43949 L
s
.5 .44279 m
.5 .44453 L
s
.50372 .44279 m
.50372 .44256 L
s
.50744 .44279 m
.50744 .44285 L
s
.51116 .44279 m
.51116 .44279 L
s
.51488 .44279 m
.51488 .44278 L
s
.5186 .44279 m
.5186 .4428 L
s
.52232 .44279 m
.52232 .44283 L
s
.52604 .44279 m
.52604 .44271 L
s
.52976 .44279 m
.52976 .44287 L
s
.53348 .44279 m
.53348 .44274 L
s
.5372 .44279 m
.5372 .44284 L
s
.54092 .44279 m
.54092 .44269 L
s
.54464 .44279 m
.54464 .44298 L
s
.54836 .44279 m
.54836 .44256 L
s
.55208 .44279 m
.55208 .44288 L
s
.5558 .44279 m
.5558 .44289 L
s
.55952 .44279 m
.55952 .44271 L
s
.56324 .44279 m
.56324 .44275 L
s
.56696 .44279 m
.56696 .44281 L
s
.57068 .44279 m
.57068 .4428 L
s
.5744 .44279 m
.5744 .44279 L
s
.57813 .44279 m
.57813 .44279 L
s
.58185 .44279 m
.58185 .44282 L
s
.58557 .44279 m
.58557 .44284 L
s
.58929 .44279 m
.58929 .44269 L
s
.59301 .44279 m
.59301 .44259 L
s
.59673 .44279 m
.59673 .44316 L
s
.60045 .44279 m
.60045 .44286 L
s
.60417 .44279 m
.60417 .4421 L
s
.60789 .44279 m
.60789 .44377 L
s
.61161 .44279 m
.61161 .44189 L
s
.61533 .44279 m
.61533 .44343 L
s
.61905 .44279 m
.61905 .44394 L
s
.62277 .44279 m
.62277 .44263 L
s
.62649 .44279 m
.62649 .44281 L
s
.63021 .44279 m
.63021 .44279 L
s
.63393 .44279 m
.63393 .44279 L
s
.63765 .44279 m
.63765 .44279 L
s
.64137 .44279 m
.64137 .44278 L
s
.64509 .44279 m
.64509 .44283 L
s
.64881 .44279 m
.64881 .4427 L
s
.65253 .44279 m
.65253 .44295 L
s
.65625 .44279 m
.65625 .44252 L
s
.65997 .44279 m
.65997 .4432 L
s
.66369 .44279 m
.66369 .44239 L
s
.66741 .44279 m
.66741 .4426 L
s
.67113 .44279 m
.67113 .4439 L
s
.67485 .44279 m
.67485 .44254 L
s
.67857 .44279 m
.67857 .44108 L
s
.68229 .44279 m
.68229 .44157 L
s
.68601 .44279 m
.68601 .44292 L
s
.68973 .44279 m
.68973 .44393 L
s
.69345 .44279 m
.69345 .44426 L
s
.69717 .44279 m
.69717 .44376 L
s
.70089 .44279 m
.70089 .44216 L
s
.70461 .44279 m
.70461 .44002 L
s
.70833 .44279 m
.70833 .44013 L
s
.71205 .44279 m
.71205 .44409 L
s
.71577 .44279 m
.71577 .44505 L
s
.71949 .44279 m
.71949 .44068 L
s
.72321 .44279 m
.72321 .44326 L
s
.72693 .44279 m
.72693 .44326 L
s
.73065 .44279 m
.73065 .44208 L
s
.73438 .44279 m
.73438 .44488 L
s
.7381 .44279 m
.7381 .43948 L
s
.74182 .44279 m
.74182 .44307 L
s
.74554 .44279 m
.74554 .4428 L
s
.74926 .44279 m
.74926 .44279 L
s
.75298 .44279 m
.75298 .44279 L
s
.7567 .44279 m
.7567 .44279 L
s
.76042 .44279 m
.76042 .44279 L
s
.76414 .44279 m
.76414 .44279 L
s
.76786 .44279 m
.76786 .44278 L
s
.77158 .44279 m
.77158 .4428 L
s
.7753 .44279 m
.7753 .44277 L
s
.77902 .44279 m
.77902 .44283 L
s
.78274 .44279 m
.78274 .44274 L
s
.78646 .44279 m
.78646 .44281 L
s
.79018 .44279 m
.79018 .44283 L
s
.7939 .44279 m
.7939 .44275 L
s
.79762 .44279 m
.79762 .44277 L
s
.80134 .44279 m
.80134 .44281 L
s
.80506 .44279 m
.80506 .44281 L
s
.80878 .44279 m
.80878 .44279 L
s
.8125 .44279 m
.8125 .44278 L
s
.81622 .44279 m
.81622 .44275 L
s
.81994 .44279 m
.81994 .44274 L
s
.82366 .44279 m
.82366 .4429 L
s
.82738 .44279 m
.82738 .44316 L
s
.8311 .44279 m
.8311 .44226 L
s
.83482 .44279 m
.83482 .44183 L
s
.83854 .44279 m
.83854 .44578 L
s
.84226 .44279 m
.84226 .43927 L
s
.84598 .44279 m
.84598 .4453 L
s
.8497 .44279 m
.8497 .44109 L
s
.85342 .44279 m
.85342 .44676 L
s
.85714 .44279 m
.85714 .44202 L
s
.86086 .44279 m
.86086 .44297 L
s
.86458 .44279 m
.86458 .44278 L
s
.8683 .44279 m
.8683 .44279 L
s
.87202 .44279 m
.87202 .44279 L
s
.87574 .44279 m
.87574 .44279 L
s
.87946 .44279 m
.87946 .44279 L
s
.88318 .44279 m
.88318 .44279 L
s
.8869 .44279 m
.8869 .4428 L
s
.89063 .44279 m
.89063 .44277 L
s
.89435 .44279 m
.89435 .44283 L
s
.89807 .44279 m
.89807 .44273 L
s
.90179 .44279 m
.90179 .44278 L
s
.90551 .44279 m
.90551 .44303 L
s
.90923 .44279 m
.90923 .44252 L
s
.91295 .44279 m
.91295 .44228 L
s
.91667 .44279 m
.91667 .44306 L
s
.92039 .44279 m
.92039 .44403 L
s
.92411 .44279 m
.92411 .44454 L
s
.92783 .44279 m
.92783 .4448 L
s
.93155 .44279 m
.93155 .44535 L
s
.93527 .44279 m
.93527 .44655 L
s
.93899 .44279 m
.93899 .44755 L
s
.94271 .44279 m
.94271 .44523 L
s
.94643 .44279 m
.94643 .43779 L
s
.95015 .44279 m
.95015 .43661 L
s
.95387 .44279 m
.95387 .45049 L
s
.95759 .44279 m
.95759 .44321 L
s
.96131 .44279 m
.96131 .43545 L
s
.96503 .44279 m
.96503 .45265 L
s
.96875 .44279 m
.96875 .43292 L
s
.97247 .44279 m
.97247 .45132 L
s
.02381 .54981 m
.02381 .54549 L
s
.02753 .54981 m
.02753 .58792 L
s
.03125 .54981 m
.03125 .57294 L
s
.03497 .54981 m
.03497 .53162 L
s
.03869 .54981 m
.03869 .55321 L
s
.04241 .54981 m
.04241 .55211 L
s
.04613 .54981 m
.04613 .54944 L
s
.04985 .54981 m
.04985 .54736 L
s
.05357 .54981 m
.05357 .5525 L
s
.05729 .54981 m
.05729 .5485 L
s
.06101 .54981 m
.06101 .55015 L
s
.06473 .54981 m
.06473 .54954 L
s
.06845 .54981 m
.06845 .55027 L
s
.07217 .54981 m
.07217 .54921 L
s
.07589 .54981 m
.07589 .55025 L
s
.07961 .54981 m
.07961 .55035 L
s
.08333 .54981 m
.08333 .55317 L
s
.08705 .54981 m
.08705 .53635 L
s
.09077 .54981 m
.09077 .5766 L
s
.09449 .54981 m
.09449 .4963 L
s
.09821 .54981 m
.09821 .55231 L
s
.10193 .54981 m
.10193 .55645 L
s
.10565 .54981 m
.10565 .53653 L
s
.10938 .54981 m
.10938 .54692 L
s
.1131 .54981 m
.1131 .55162 L
s
.11682 .54981 m
.11682 .54931 L
s
.12054 .54981 m
.12054 .5498 L
s
.12426 .54981 m
.12426 .55016 L
s
.12798 .54981 m
.12798 .54858 L
s
.1317 .54981 m
.1317 .55251 L
s
.13542 .54981 m
.13542 .55173 L
s
.13914 .54981 m
.13914 .54539 L
s
.14286 .54981 m
.14286 .54454 L
s
.14658 .54981 m
.14658 .54991 L
s
.1503 .54981 m
.1503 .55107 L
s
.15402 .54981 m
.15402 .54758 L
s
.15774 .54981 m
.15774 .55172 L
s
.16146 .54981 m
.16146 .54625 L
s
.16518 .54981 m
.16518 .55998 L
s
.1689 .54981 m
.1689 .53004 L
s
.17262 .54981 m
.17262 .58953 L
s
.17634 .54981 m
.17634 .51485 L
s
.18006 .54981 m
.18006 .50871 L
s
.18378 .54981 m
.18378 .52713 L
s
.1875 .54981 m
.1875 .56851 L
s
.19122 .54981 m
.19122 .54337 L
s
.19494 .54981 m
.19494 .55258 L
s
.19866 .54981 m
.19866 .5476 L
s
.20238 .54981 m
.20238 .54682 L
s
.2061 .54981 m
.2061 .55156 L
s
.20982 .54981 m
.20982 .54305 L
s
.21354 .54981 m
.21354 .56288 L
s
.21726 .54981 m
.21726 .58398 L
s
.22098 .54981 m
.22098 .5993 L
s
.2247 .54981 m
.2247 .55677 L
s
.22842 .54981 m
.22842 .52594 L
s
.23214 .54981 m
.23214 .55952 L
s
.23586 .54981 m
.23586 .54879 L
s
.23958 .54981 m
.23958 .55045 L
s
.2433 .54981 m
.2433 .55051 L
s
.24702 .54981 m
.24702 .54581 L
s
.25074 .54981 m
.25074 .54864 L
s
.25446 .54981 m
.25446 .55755 L
s
.25818 .54981 m
.25818 .55429 L
s
.2619 .54981 m
.2619 .55935 L
s
.26563 .54981 m
.26563 .54861 L
s
.26935 .54981 m
.26935 .54981 L
s
.27307 .54981 m
.27307 .54973 L
s
.27679 .54981 m
.27679 .54998 L
s
.28051 .54981 m
.28051 .5495 L
s
.28423 .54981 m
.28423 .55024 L
s
.28795 .54981 m
.28795 .54952 L
s
.29167 .54981 m
.29167 .54995 L
s
.29539 .54981 m
.29539 .54962 L
s
.29911 .54981 m
.29911 .54989 L
s
.30283 .54981 m
.30283 .55049 L
s
.30655 .54981 m
.30655 .54791 L
s
.31027 .54981 m
.31027 .55153 L
s
.31399 .54981 m
.31399 .55063 L
s
.31771 .54981 m
.31771 .54733 L
s
.32143 .54981 m
.32143 .55244 L
s
.32515 .54981 m
.32515 .54917 L
s
.32887 .54981 m
.32887 .54961 L
s
.33259 .54981 m
.33259 .55145 L
s
.33631 .54981 m
.33631 .5521 L
s
.34003 .54981 m
.34003 .55335 L
s
.34375 .54981 m
.34375 .55283 L
s
.34747 .54981 m
.34747 .54806 L
s
.35119 .54981 m
.35119 .5503 L
s
.35491 .54981 m
.35491 .54966 L
s
.35863 .54981 m
.35863 .54999 L
s
.36235 .54981 m
.36235 .549 L
s
.36607 .54981 m
.36607 .55161 L
s
.36979 .54981 m
.36979 .5571 L
s
.37351 .54981 m
.37351 .52994 L
s
.37723 .54981 m
.37723 .52698 L
s
.38095 .54981 m
.38095 .54725 L
s
.38467 .54981 m
.38467 .5503 L
s
.38839 .54981 m
.38839 .54975 L
s
.39211 .54981 m
.39211 .54984 L
s
.39583 .54981 m
.39583 .54988 L
s
.39955 .54981 m
.39955 .55047 L
s
.40327 .54981 m
.40327 .5458 L
s
.40699 .54981 m
.40699 .56094 L
s
.41071 .54981 m
.41071 .53315 L
s
.41443 .54981 m
.41443 .52938 L
s
.41815 .54981 m
.41815 .54514 L
s
.42188 .54981 m
.42188 .50797 L
s
.4256 .54981 m
.4256 .54841 L
s
.42932 .54981 m
.42932 .55418 L
s
.43304 .54981 m
.43304 .55121 L
s
.43676 .54981 m
.43676 .55054 L
s
.44048 .54981 m
.44048 .54842 L
s
.4442 .54981 m
.4442 .55003 L
s
.44792 .54981 m
.44792 .54992 L
s
.45164 .54981 m
.45164 .54913 L
s
.45536 .54981 m
.45536 .54663 L
s
.45908 .54981 m
.45908 .54388 L
s
.4628 .54981 m
.4628 .56167 L
s
.46652 .54981 m
.46652 .54242 L
s
.47024 .54981 m
.47024 .55533 L
s
.47396 .54981 m
.47396 .5473 L
s
.47768 .54981 m
.47768 .54534 L
s
.4814 .54981 m
.4814 .5659 L
s
.48512 .54981 m
.48512 .51547 L
s
.48884 .54981 m
.48884 .59387 L
s
.49256 .54981 m
.49256 .58056 L
s
.49628 .54981 m
.49628 .55445 L
s
.5 .54981 m
.5 .55138 L
s
.50372 .54981 m
.50372 .54961 L
s
.50744 .54981 m
.50744 .54984 L
s
.51116 .54981 m
.51116 .54981 L
s
.51488 .54981 m
.51488 .54982 L
s
.5186 .54981 m
.5186 .54979 L
s
.52232 .54981 m
.52232 .54982 L
s
.52604 .54981 m
.52604 .54984 L
s
.52976 .54981 m
.52976 .54977 L
s
.53348 .54981 m
.53348 .54982 L
s
.5372 .54981 m
.5372 .5498 L
s
.54092 .54981 m
.54092 .54989 L
s
.54464 .54981 m
.54464 .54962 L
s
.54836 .54981 m
.54836 .55004 L
s
.55208 .54981 m
.55208 .54973 L
s
.5558 .54981 m
.5558 .54966 L
s
.55952 .54981 m
.55952 .55082 L
s
.56324 .54981 m
.56324 .54969 L
s
.56696 .54981 m
.56696 .54982 L
s
.57068 .54981 m
.57068 .54991 L
s
.5744 .54981 m
.5744 .54988 L
s
.57813 .54981 m
.57813 .54996 L
s
.58185 .54981 m
.58185 .55012 L
s
.58557 .54981 m
.58557 .54971 L
s
.58929 .54981 m
.58929 .54982 L
s
.59301 .54981 m
.59301 .5498 L
s
.59673 .54981 m
.59673 .54983 L
s
.60045 .54981 m
.60045 .54972 L
s
.60417 .54981 m
.60417 .55009 L
s
.60789 .54981 m
.60789 .54973 L
s
.61161 .54981 m
.61161 .54834 L
s
.61533 .54981 m
.61533 .54968 L
s
.61905 .54981 m
.61905 .55152 L
s
.62277 .54981 m
.62277 .54959 L
s
.62649 .54981 m
.62649 .54983 L
s
.63021 .54981 m
.63021 .54981 L
s
.63393 .54981 m
.63393 .5498 L
s
.63765 .54981 m
.63765 .5499 L
s
.64137 .54981 m
.64137 .54946 L
s
.64509 .54981 m
.64509 .55075 L
s
.64881 .54981 m
.64881 .5477 L
s
.65253 .54981 m
.65253 .54986 L
s
.65625 .54981 m
.65625 .55202 L
s
.65997 .54981 m
.65997 .54854 L
s
.66369 .54981 m
.66369 .54712 L
s
.66741 .54981 m
.66741 .55149 L
s
.67113 .54981 m
.67113 .54928 L
s
.67485 .54981 m
.67485 .5503 L
s
.67857 .54981 m
.67857 .55061 L
s
.68229 .54981 m
.68229 .54969 L
s
.68601 .54981 m
.68601 .54983 L
s
.68973 .54981 m
.68973 .54975 L
s
.69345 .54981 m
.69345 .54959 L
s
.69717 .54981 m
.69717 .54917 L
s
.70089 .54981 m
.70089 .55035 L
s
.70461 .54981 m
.70461 .5497 L
s
.70833 .54981 m
.70833 .55006 L
s
.71205 .54981 m
.71205 .54966 L
s
.71577 .54981 m
.71577 .54939 L
s
.71949 .54981 m
.71949 .55076 L
s
.72321 .54981 m
.72321 .54816 L
s
.72693 .54981 m
.72693 .553 L
s
.73065 .54981 m
.73065 .5491 L
s
.73438 .54981 m
.73438 .54832 L
s
.7381 .54981 m
.7381 .54872 L
s
.74182 .54981 m
.74182 .54996 L
s
.74554 .54981 m
.74554 .54974 L
s
.74926 .54981 m
.74926 .54981 L
s
.75298 .54981 m
.75298 .54981 L
s
.7567 .54981 m
.7567 .54982 L
s
.76042 .54981 m
.76042 .54979 L
s
.76414 .54981 m
.76414 .54983 L
s
.76786 .54981 m
.76786 .54978 L
s
.77158 .54981 m
.77158 .54983 L
s
.7753 .54981 m
.7753 .54979 L
s
.77902 .54981 m
.77902 .5498 L
s
.78274 .54981 m
.78274 .54977 L
s
.78646 .54981 m
.78646 .55015 L
s
.79018 .54981 m
.79018 .54906 L
s
.7939 .54981 m
.7939 .55139 L
s
.79762 .54981 m
.79762 .54853 L
s
.80134 .54981 m
.80134 .54994 L
s
.80506 .54981 m
.80506 .54979 L
s
.80878 .54981 m
.80878 .54981 L
s
.8125 .54981 m
.8125 .54979 L
s
.81622 .54981 m
.81622 .54976 L
s
.81994 .54981 m
.81994 .54979 L
s
.82366 .54981 m
.82366 .54985 L
s
.82738 .54981 m
.82738 .54979 L
s
.8311 .54981 m
.8311 .54981 L
s
.83482 .54981 m
.83482 .54981 L
s
.83854 .54981 m
.83854 .54979 L
s
.84226 .54981 m
.84226 .55034 L
s
.84598 .54981 m
.84598 .54572 L
s
.8497 .54981 m
.8497 .54635 L
s
.85342 .54981 m
.85342 .54494 L
s
.85714 .54981 m
.85714 .55269 L
s
.86086 .54981 m
.86086 .54941 L
s
.86458 .54981 m
.86458 .54979 L
s
.8683 .54981 m
.8683 .54981 L
s
.87202 .54981 m
.87202 .54981 L
s
.87574 .54981 m
.87574 .54979 L
s
.87946 .54981 m
.87946 .54994 L
s
.88318 .54981 m
.88318 .54942 L
s
.8869 .54981 m
.8869 .55017 L
s
.89063 .54981 m
.89063 .55227 L
s
.89435 .54981 m
.89435 .55339 L
s
.89807 .54981 m
.89807 .55686 L
s
.90179 .54981 m
.90179 .54295 L
s
.90551 .54981 m
.90551 .55396 L
s
.90923 .54981 m
.90923 .54801 L
s
.91295 .54981 m
.91295 .5498 L
s
.91667 .54981 m
.91667 .55029 L
s
.92039 .54981 m
.92039 .54963 L
s
.92411 .54981 m
.92411 .54982 L
s
.92783 .54981 m
.92783 .54982 L
s
.93155 .54981 m
.93155 .54984 L
s
.93527 .54981 m
.93527 .5499 L
s
.93899 .54981 m
.93899 .54944 L
s
.94271 .54981 m
.94271 .55022 L
s
.94643 .54981 m
.94643 .54953 L
s
.95015 .54981 m
.95015 .55 L
s
.95387 .54981 m
.95387 .55016 L
s
.95759 .54981 m
.95759 .54723 L
s
.96131 .54981 m
.96131 .55572 L
s
.96503 .54981 m
.96503 .55057 L
s
.96875 .54981 m
.96875 .53522 L
s
.97247 .54981 m
.97247 .53969 L
s
0 1 1 r
.02381 .12173 m
.97619 .12173 L
s
.02381 .22875 m
.97619 .22875 L
s
.02381 .33577 m
.97619 .33577 L
s
.02381 .44279 m
.97619 .44279 L
s
.02381 .54981 m
.97619 .54981 L
s
.49814 .28226 m
.49814 .17524 L
s
.26004 .38928 m
.26004 .28226 L
s
.49814 .38928 m
.49814 .28226 L
s
.73624 .38928 m
.73624 .28226 L
s
.141 .4963 m
.141 .38928 L
s
.26004 .4963 m
.26004 .38928 L
s
.37909 .4963 m
.37909 .38928 L
s
.49814 .4963 m
.49814 .38928 L
s
.61719 .4963 m
.61719 .38928 L
s
.73624 .4963 m
.73624 .38928 L
s
.85528 .4963 m
.85528 .38928 L
s
.08147 .60332 m
.08147 .4963 L
s
.141 .60332 m
.141 .4963 L
s
.20052 .60332 m
.20052 .4963 L
s
.26004 .60332 m
.26004 .4963 L
s
.31957 .60332 m
.31957 .4963 L
s
.37909 .60332 m
.37909 .4963 L
s
.43862 .60332 m
.43862 .4963 L
s
.49814 .60332 m
.49814 .4963 L
s
.55766 .60332 m
.55766 .4963 L
s
.61719 .60332 m
.61719 .4963 L
s
.67671 .60332 m
.67671 .4963 L
s
.73624 .60332 m
.73624 .4963 L
s
.79576 .60332 m
.79576 .4963 L
s
.85528 .60332 m
.85528 .4963 L
s
.91481 .60332 m
.91481 .4963 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "Among these coefficients there are many choices to form an orthogonal \
decomposition of our data. For example, we can choose coefficients that are \
all in the same level (",
  StyleBox["i.e.", "TI"],
  ", with same index ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.1.3"],
  "). "
}], "Text",
  CellTags->{"S2.1.3", "3.13"}],

Cell["\<\
We can choose to decompose the data using basis functions that are \
all at the same level. Here we choose a particular level that corresponds to \
doing wavelet packet decomposition three times.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.14"}],

Cell["coeflevel3 = coef[[4]];", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.3"],

Cell[TextData[{
  "Using the function ",
  StyleBox["ShowBasisPosition", "MR"],
  ", we can see graphically the basis functions or subspaces we use to \
decompose the data. The top row represents the original space, and the shaded \
areas are the subspaces chosen to split the original space."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.15"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[coeflevel3]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
We can also choose a different orthonormal basis. For example, here \
we pick out the coefficients corresponding to an arbitrarily chosen \
basis.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.16"}],

Cell["\<\
(basis = {{2,1},{4,5},{5,11},{5,12},{3,4}};
newcoef = Apply[coef[[##]]&, basis, {1}];)\
\>", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
The basis chosen above is the collection of basis functions for the \
shaded subspaces shown here. This yields another splitting of the original \
space. \
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.17"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[newcoef]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.117721 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .13244 m
.97619 .13244 L
s
.02381 .25016 m
.97619 .25016 L
s
.02381 .36788 m
.97619 .36788 L
s
.02381 .4856 m
.97619 .4856 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.08333 .01472 m
.08333 .13244 L
s
.14286 .01472 m
.14286 .25016 L
s
.20238 .01472 m
.20238 .13244 L
s
.2619 .01472 m
.2619 .36788 L
s
.32143 .01472 m
.32143 .13244 L
s
.38095 .01472 m
.38095 .25016 L
s
.44048 .01472 m
.44048 .13244 L
s
.5 .01472 m
.5 .4856 L
s
.55952 .01472 m
.55952 .13244 L
s
.61905 .01472 m
.61905 .25016 L
s
.67857 .01472 m
.67857 .13244 L
s
.7381 .01472 m
.7381 .36788 L
s
.79762 .01472 m
.79762 .13244 L
s
.85714 .01472 m
.85714 .25016 L
s
.91667 .01472 m
.91667 .13244 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .36788 translate
.47619 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .13244 translate
.11905 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.05952 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.67857 .01472 translate
.05953 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .25016 translate
.23809 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
We observe that an orthogonal basis is such that every vertical \
column is covered by one and only one row. The wavelet transform corresponds \
to a particular splitting of the original space. We illustrate this choice \
below. \
\>", "Text",
  CellTags->{"S2.1.3", "3.18"}],

Cell["This gives the wavelet transform.", "MathCaption",
  CellTags->{"S2.1.3", "3.19"}],

Cell["wtdata= WaveletTransform[data, c4];", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
This shows the splitting of space when using the wavelet basis: the \
high\[Hyphen]frequency space is left alone and the low\[Hyphen]frequency \
space gets split repeatedly.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.20"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[wtdata]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.0981006 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .11282 m
.97619 .11282 L
s
.02381 .21092 m
.97619 .21092 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .40712 m
.97619 .40712 L
s
.02381 .50522 m
.97619 .50522 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.05357 .01472 m
.05357 .11282 L
s
.08333 .01472 m
.08333 .21092 L
s
.1131 .01472 m
.1131 .11282 L
s
.14286 .01472 m
.14286 .30902 L
s
.17262 .01472 m
.17262 .11282 L
s
.20238 .01472 m
.20238 .21092 L
s
.23214 .01472 m
.23214 .11282 L
s
.2619 .01472 m
.2619 .40712 L
s
.29167 .01472 m
.29167 .11282 L
s
.32143 .01472 m
.32143 .21092 L
s
.35119 .01472 m
.35119 .11282 L
s
.38095 .01472 m
.38095 .30902 L
s
.41071 .01472 m
.41071 .11282 L
s
.44048 .01472 m
.44048 .21092 L
s
.47024 .01472 m
.47024 .11282 L
s
.5 .01472 m
.5 .50522 L
s
.52976 .01472 m
.52976 .11282 L
s
.55952 .01472 m
.55952 .21092 L
s
.58929 .01472 m
.58929 .11282 L
s
.61905 .01472 m
.61905 .30902 L
s
.64881 .01472 m
.64881 .11282 L
s
.67857 .01472 m
.67857 .21092 L
s
.70833 .01472 m
.70833 .11282 L
s
.7381 .01472 m
.7381 .40712 L
s
.76786 .01472 m
.76786 .11282 L
s
.79762 .01472 m
.79762 .21092 L
s
.82738 .01472 m
.82738 .11282 L
s
.85714 .01472 m
.85714 .30902 L
s
.8869 .01472 m
.8869 .11282 L
s
.91667 .01472 m
.91667 .21092 L
s
.94643 .01472 m
.94643 .11282 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05357 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08333 .11282 translate
.05953 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .21092 translate
.11904 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .30902 translate
.2381 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .40712 translate
.47619 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "We plot the coefficients ",
  StyleBox["coeflevel3", "MR"],
  " using ",
  StyleBox["PlotCoefficients", "MR"],
  ". Note that there are 8 lists in ",
  StyleBox["coeflevel3", "MR"],
  ", corresponding to 8 subspaces, and we stack the plots of the coefficients \
together with the leftmost list (",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ") plotted at the bottom, and the rightmost (",
  Cell[BoxData[
      \(TraditionalForm\`n = 7\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ") at the top."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.21"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[coeflevel3,  Frame -> True,
PlotLabel -> \"wavelet packet coefficients\"]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0147151 0.0145453 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -3 -9 ]
[.17262 -0.0125 3 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -81 0 ]
[.5 .63053 81 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(5)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(10)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(15)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(20)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(25)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(30)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17262 .61178 m
.17262 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.47024 .61178 m
.47024 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.91667 .61178 m
.91667 .61803 L
s
.125 Mabswid
.05357 .61428 m
.05357 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.35119 .61428 m
.35119 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.64881 .61428 m
.64881 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.94643 .61428 m
.94643 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wavelet packet coefficients)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08531 m
.02381 .08017 L
s
.05357 .08531 m
.05357 .09242 L
s
.08333 .08531 m
.08333 .10878 L
s
.1131 .08531 m
.1131 .12577 L
s
.14286 .08531 m
.14286 .11144 L
s
.17262 .08531 m
.17262 .05858 L
s
.20238 .08531 m
.20238 .05792 L
s
.23214 .08531 m
.23214 .12337 L
s
.2619 .08531 m
.2619 .06856 L
s
.29167 .08531 m
.29167 .08355 L
s
.32143 .08531 m
.32143 .09317 L
s
.35119 .08531 m
.35119 .0806 L
s
.38095 .08531 m
.38095 .08226 L
s
.41071 .08531 m
.41071 .09494 L
s
.44048 .08531 m
.44048 .07646 L
s
.47024 .08531 m
.47024 .08691 L
s
.5 .08531 m
.5 .08799 L
s
.52976 .08531 m
.52976 .08456 L
s
.55952 .08531 m
.55952 .08457 L
s
.58929 .08531 m
.58929 .08529 L
s
.61905 .08531 m
.61905 .08548 L
s
.64881 .08531 m
.64881 .08542 L
s
.67857 .08531 m
.67857 .08523 L
s
.70833 .08531 m
.70833 .08494 L
s
.7381 .08531 m
.7381 .08523 L
s
.76786 .08531 m
.76786 .08645 L
s
.79762 .08531 m
.79762 .08525 L
s
.82738 .08531 m
.82738 .08315 L
s
.85714 .08531 m
.85714 .0878 L
s
.8869 .08531 m
.8869 .08412 L
s
.91667 .08531 m
.91667 .08511 L
s
.94643 .08531 m
.94643 .08655 L
s
.02381 .16989 m
.02381 .16587 L
s
.05357 .16989 m
.05357 .17075 L
s
.08333 .16989 m
.08333 .17003 L
s
.1131 .16989 m
.1131 .16834 L
s
.14286 .16989 m
.14286 .16832 L
s
.17262 .16989 m
.17262 .17539 L
s
.20238 .16989 m
.20238 .16881 L
s
.23214 .16989 m
.23214 .1601 L
s
.2619 .16989 m
.2619 .18877 L
s
.29167 .16989 m
.29167 .14578 L
s
.32143 .16989 m
.32143 .19856 L
s
.35119 .16989 m
.35119 .13595 L
s
.38095 .16989 m
.38095 .20258 L
s
.41071 .16989 m
.41071 .16011 L
s
.44048 .16989 m
.44048 .13975 L
s
.47024 .16989 m
.47024 .19767 L
s
.5 .16989 m
.5 .20026 L
s
.52976 .16989 m
.52976 .16618 L
s
.55952 .16989 m
.55952 .14458 L
s
.58929 .16989 m
.58929 .13975 L
s
.61905 .16989 m
.61905 .14133 L
s
.64881 .16989 m
.64881 .14489 L
s
.67857 .16989 m
.67857 .15311 L
s
.70833 .16989 m
.70833 .16936 L
s
.7381 .16989 m
.7381 .1851 L
s
.76786 .16989 m
.76786 .17926 L
s
.79762 .16989 m
.79762 .16003 L
s
.82738 .16989 m
.82738 .1683 L
s
.85714 .16989 m
.85714 .17584 L
s
.8869 .16989 m
.8869 .16502 L
s
.91667 .16989 m
.91667 .17315 L
s
.94643 .16989 m
.94643 .16332 L
s
.02381 .24048 m
.02381 .24166 L
s
.05357 .24048 m
.05357 .24076 L
s
.08333 .24048 m
.08333 .24043 L
s
.1131 .24048 m
.1131 .24043 L
s
.14286 .24048 m
.14286 .24028 L
s
.17262 .24048 m
.17262 .24072 L
s
.20238 .24048 m
.20238 .24087 L
s
.23214 .24048 m
.23214 .23927 L
s
.2619 .24048 m
.2619 .24206 L
s
.29167 .24048 m
.29167 .23887 L
s
.32143 .24048 m
.32143 .24229 L
s
.35119 .24048 m
.35119 .23804 L
s
.38095 .24048 m
.38095 .24352 L
s
.41071 .24048 m
.41071 .23815 L
s
.44048 .24048 m
.44048 .24045 L
s
.47024 .24048 m
.47024 .242 L
s
.5 .24048 m
.5 .24006 L
s
.52976 .24048 m
.52976 .2399 L
s
.55952 .24048 m
.55952 .24049 L
s
.58929 .24048 m
.58929 .24061 L
s
.61905 .24048 m
.61905 .24053 L
s
.64881 .24048 m
.64881 .24061 L
s
.67857 .24048 m
.67857 .24087 L
s
.70833 .24048 m
.70833 .24056 L
s
.7381 .24048 m
.7381 .23868 L
s
.76786 .24048 m
.76786 .23974 L
s
.79762 .24048 m
.79762 .24677 L
s
.82738 .24048 m
.82738 .23496 L
s
.85714 .24048 m
.85714 .23711 L
s
.8869 .24048 m
.8869 .25418 L
s
.91667 .24048 m
.91667 .2201 L
s
.94643 .24048 m
.94643 .26048 L
s
.02381 .31107 m
.02381 .30884 L
s
.05357 .31107 m
.05357 .31111 L
s
.08333 .31107 m
.08333 .31104 L
s
.1131 .31107 m
.1131 .31107 L
s
.14286 .31107 m
.14286 .31114 L
s
.17262 .31107 m
.17262 .31097 L
s
.20238 .31107 m
.20238 .31102 L
s
.23214 .31107 m
.23214 .31157 L
s
.2619 .31107 m
.2619 .30984 L
s
.29167 .31107 m
.29167 .31331 L
s
.32143 .31107 m
.32143 .30762 L
s
.35119 .31107 m
.35119 .31505 L
s
.38095 .31107 m
.38095 .31 L
s
.41071 .31107 m
.41071 .30365 L
s
.44048 .31107 m
.44048 .32265 L
s
.47024 .31107 m
.47024 .31776 L
s
.5 .31107 m
.5 .29693 L
s
.52976 .31107 m
.52976 .29047 L
s
.55952 .31107 m
.55952 .2974 L
s
.58929 .31107 m
.58929 .30528 L
s
.61905 .31107 m
.61905 .30697 L
s
.64881 .31107 m
.64881 .29961 L
s
.67857 .31107 m
.67857 .28445 L
s
.70833 .31107 m
.70833 .27607 L
s
.7381 .31107 m
.7381 .30241 L
s
.76786 .31107 m
.76786 .34637 L
s
.79762 .31107 m
.79762 .31632 L
s
.82738 .31107 m
.82738 .27705 L
s
.85714 .31107 m
.85714 .34285 L
s
.8869 .31107 m
.8869 .2907 L
s
.91667 .31107 m
.91667 .32394 L
s
.94643 .31107 m
.94643 .30777 L
s
.02381 .38167 m
.02381 .3834 L
s
.05357 .38167 m
.05357 .38143 L
s
.08333 .38167 m
.08333 .38172 L
s
.1131 .38167 m
.1131 .38166 L
s
.14286 .38167 m
.14286 .38165 L
s
.17262 .38167 m
.17262 .38167 L
s
.20238 .38167 m
.20238 .3817 L
s
.23214 .38167 m
.23214 .38159 L
s
.2619 .38167 m
.2619 .38174 L
s
.29167 .38167 m
.29167 .38161 L
s
.32143 .38167 m
.32143 .38171 L
s
.35119 .38167 m
.35119 .38157 L
s
.38095 .38167 m
.38095 .38186 L
s
.41071 .38167 m
.41071 .38143 L
s
.44048 .38167 m
.44048 .38176 L
s
.47024 .38167 m
.47024 .38176 L
s
.5 .38167 m
.5 .38159 L
s
.52976 .38167 m
.52976 .38163 L
s
.55952 .38167 m
.55952 .38168 L
s
.58929 .38167 m
.58929 .38168 L
s
.61905 .38167 m
.61905 .38166 L
s
.64881 .38167 m
.64881 .38167 L
s
.67857 .38167 m
.67857 .3817 L
s
.70833 .38167 m
.70833 .38171 L
s
.7381 .38167 m
.7381 .38157 L
s
.76786 .38167 m
.76786 .38146 L
s
.79762 .38167 m
.79762 .38204 L
s
.82738 .38167 m
.82738 .38173 L
s
.85714 .38167 m
.85714 .38098 L
s
.8869 .38167 m
.8869 .38264 L
s
.91667 .38167 m
.91667 .38077 L
s
.94643 .38167 m
.94643 .38231 L
s
.02381 .45226 m
.02381 .45341 L
s
.05357 .45226 m
.05357 .4521 L
s
.08333 .45226 m
.08333 .45228 L
s
.1131 .45226 m
.1131 .45226 L
s
.14286 .45226 m
.14286 .45226 L
s
.17262 .45226 m
.17262 .45226 L
s
.20238 .45226 m
.20238 .45225 L
s
.23214 .45226 m
.23214 .4523 L
s
.2619 .45226 m
.2619 .45217 L
s
.29167 .45226 m
.29167 .45242 L
s
.32143 .45226 m
.32143 .45199 L
s
.35119 .45226 m
.35119 .45267 L
s
.38095 .45226 m
.38095 .45186 L
s
.41071 .45226 m
.41071 .45207 L
s
.44048 .45226 m
.44048 .45337 L
s
.47024 .45226 m
.47024 .45201 L
s
.5 .45226 m
.5 .45054 L
s
.52976 .45226 m
.52976 .45103 L
s
.55952 .45226 m
.55952 .45238 L
s
.58929 .45226 m
.58929 .4534 L
s
.61905 .45226 m
.61905 .45373 L
s
.64881 .45226 m
.64881 .45323 L
s
.67857 .45226 m
.67857 .45162 L
s
.70833 .45226 m
.70833 .44948 L
s
.7381 .45226 m
.7381 .4496 L
s
.76786 .45226 m
.76786 .45356 L
s
.79762 .45226 m
.79762 .45453 L
s
.82738 .45226 m
.82738 .45015 L
s
.85714 .45226 m
.85714 .45273 L
s
.8869 .45226 m
.8869 .45273 L
s
.91667 .45226 m
.91667 .45155 L
s
.94643 .45226 m
.94643 .45435 L
s
.02381 .52285 m
.02381 .51954 L
s
.05357 .52285 m
.05357 .52314 L
s
.08333 .52285 m
.08333 .52286 L
s
.1131 .52285 m
.1131 .52285 L
s
.14286 .52285 m
.14286 .52285 L
s
.17262 .52285 m
.17262 .52285 L
s
.20238 .52285 m
.20238 .52285 L
s
.23214 .52285 m
.23214 .52286 L
s
.2619 .52285 m
.2619 .52284 L
s
.29167 .52285 m
.29167 .52286 L
s
.32143 .52285 m
.32143 .52283 L
s
.35119 .52285 m
.35119 .52289 L
s
.38095 .52285 m
.38095 .52281 L
s
.41071 .52285 m
.41071 .52287 L
s
.44048 .52285 m
.44048 .52289 L
s
.47024 .52285 m
.47024 .52281 L
s
.5 .52285 m
.5 .52283 L
s
.52976 .52285 m
.52976 .52287 L
s
.55952 .52285 m
.55952 .52287 L
s
.58929 .52285 m
.58929 .52285 L
s
.61905 .52285 m
.61905 .52284 L
s
.64881 .52285 m
.64881 .52282 L
s
.67857 .52285 m
.67857 .5228 L
s
.70833 .52285 m
.70833 .52296 L
s
.7381 .52285 m
.7381 .52323 L
s
.76786 .52285 m
.76786 .52232 L
s
.79762 .52285 m
.79762 .52189 L
s
.82738 .52285 m
.82738 .52585 L
s
.85714 .52285 m
.85714 .51932 L
s
.8869 .52285 m
.8869 .52536 L
s
.91667 .52285 m
.91667 .52115 L
s
.94643 .52285 m
.94643 .52683 L
s
.02381 .59344 m
.02381 .59267 L
s
.05357 .59344 m
.05357 .59363 L
s
.08333 .59344 m
.08333 .59343 L
s
.1131 .59344 m
.1131 .59344 L
s
.14286 .59344 m
.14286 .59344 L
s
.17262 .59344 m
.17262 .59344 L
s
.20238 .59344 m
.20238 .59345 L
s
.23214 .59344 m
.23214 .59344 L
s
.2619 .59344 m
.2619 .59345 L
s
.29167 .59344 m
.29167 .59342 L
s
.32143 .59344 m
.32143 .59349 L
s
.35119 .59344 m
.35119 .59339 L
s
.38095 .59344 m
.38095 .59344 L
s
.41071 .59344 m
.41071 .59368 L
s
.44048 .59344 m
.44048 .59318 L
s
.47024 .59344 m
.47024 .59293 L
s
.5 .59344 m
.5 .59371 L
s
.52976 .59344 m
.52976 .59469 L
s
.55952 .59344 m
.55952 .5952 L
s
.58929 .59344 m
.58929 .59545 L
s
.61905 .59344 m
.61905 .59601 L
s
.64881 .59344 m
.64881 .59721 L
s
.67857 .59344 m
.67857 .59821 L
s
.70833 .59344 m
.70833 .59589 L
s
.7381 .59344 m
.7381 .58843 L
s
.76786 .59344 m
.76786 .58726 L
s
.79762 .59344 m
.79762 .60115 L
s
.82738 .59344 m
.82738 .59387 L
s
.85714 .59344 m
.85714 .58609 L
s
.8869 .59344 m
.8869 .60332 L
s
.91667 .59344 m
.91667 .58356 L
s
.94643 .59344 m
.94643 .60199 L
s
0 1 1 r
.02381 .08531 m
.97619 .08531 L
s
.02381 .16989 m
.97619 .16989 L
s
.02381 .24048 m
.97619 .24048 L
s
.02381 .31107 m
.97619 .31107 L
s
.02381 .38167 m
.97619 .38167 L
s
.02381 .45226 m
.97619 .45226 L
s
.02381 .52285 m
.97619 .52285 L
s
.02381 .59344 m
.97619 .59344 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "Note that the wavelet packet transform partitions the original space into \
a series of subspaces, each of which corresponds to a given frequency range. \
However, it is not necessarily true that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\&^\)\_n\) \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " is centered around a higher\[Hyphen]frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " than ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(w\&^\)\_\(n\^\[Prime]\)\) \((\[Omega])\)\)], 
    "InlineFormula",
    CellTags->"S2.1.3"],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`n > n\^\[Prime]\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". Therefore, the coefficients plotted at the top do not necessarily \
correspond to the highest\[Hyphen]frequency components. We can use the so\
\[Hyphen]called gray code ordering to order the lists of coefficients. The \
function ",
  StyleBox["GrayCodeOrder", "MR"],
  " orders the sublists from different subspaces according to increasing \
frequency (see Wickerhauser (1994))."
}], "Text",
  CellTags->{"S2.1.3", "3.22"}],

Cell[TextData[{
  "This orders the sublists in ",
  StyleBox["coeflevel3", "MR"],
  " according to increasing frequency."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.23"}],

Cell["GrayCodeOrder[coeflevel3];", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
Comparing this with the previous graph, we see the plots have been \
reordered.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.24"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[%,  Frame -> True,
PlotLabel -> \"wp decomposition coefficients\"]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0147151 0.0147492 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -3 -9 ]
[.17262 -0.0125 3 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -87 0 ]
[.5 .63053 87 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(5)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(10)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(15)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(20)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(25)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(30)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17262 .61178 m
.17262 .61803 L
s
.32143 .61178 m
.32143 .61803 L
s
.47024 .61178 m
.47024 .61803 L
s
.61905 .61178 m
.61905 .61803 L
s
.76786 .61178 m
.76786 .61803 L
s
.91667 .61178 m
.91667 .61803 L
s
.125 Mabswid
.05357 .61428 m
.05357 .61803 L
s
.08333 .61428 m
.08333 .61803 L
s
.1131 .61428 m
.1131 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.23214 .61428 m
.23214 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.29167 .61428 m
.29167 .61803 L
s
.35119 .61428 m
.35119 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.41071 .61428 m
.41071 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52976 .61428 m
.52976 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.58929 .61428 m
.58929 .61803 L
s
.64881 .61428 m
.64881 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.70833 .61428 m
.70833 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.82738 .61428 m
.82738 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.8869 .61428 m
.8869 .61803 L
s
.94643 .61428 m
.94643 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
[(wp decomposition coefficients)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0863 m
.02381 .08109 L
s
.05357 .0863 m
.05357 .09351 L
s
.08333 .0863 m
.08333 .1101 L
s
.1131 .0863 m
.1131 .12732 L
s
.14286 .0863 m
.14286 .11279 L
s
.17262 .0863 m
.17262 .0592 L
s
.20238 .0863 m
.20238 .05853 L
s
.23214 .0863 m
.23214 .12489 L
s
.2619 .0863 m
.2619 .06931 L
s
.29167 .0863 m
.29167 .08451 L
s
.32143 .0863 m
.32143 .09427 L
s
.35119 .0863 m
.35119 .08153 L
s
.38095 .0863 m
.38095 .0832 L
s
.41071 .0863 m
.41071 .09606 L
s
.44048 .0863 m
.44048 .07732 L
s
.47024 .0863 m
.47024 .08793 L
s
.5 .0863 m
.5 .08902 L
s
.52976 .0863 m
.52976 .08554 L
s
.55952 .0863 m
.55952 .08555 L
s
.58929 .0863 m
.58929 .08628 L
s
.61905 .0863 m
.61905 .08647 L
s
.64881 .0863 m
.64881 .08641 L
s
.67857 .0863 m
.67857 .08622 L
s
.70833 .0863 m
.70833 .08592 L
s
.7381 .0863 m
.7381 .08622 L
s
.76786 .0863 m
.76786 .08745 L
s
.79762 .0863 m
.79762 .08624 L
s
.82738 .0863 m
.82738 .08411 L
s
.85714 .0863 m
.85714 .08883 L
s
.8869 .0863 m
.8869 .08509 L
s
.91667 .0863 m
.91667 .08609 L
s
.94643 .0863 m
.94643 .08756 L
s
.02381 .17206 m
.02381 .16799 L
s
.05357 .17206 m
.05357 .17294 L
s
.08333 .17206 m
.08333 .17221 L
s
.1131 .17206 m
.1131 .17049 L
s
.14286 .17206 m
.14286 .17047 L
s
.17262 .17206 m
.17262 .17764 L
s
.20238 .17206 m
.20238 .17097 L
s
.23214 .17206 m
.23214 .16214 L
s
.2619 .17206 m
.2619 .1912 L
s
.29167 .17206 m
.29167 .14762 L
s
.32143 .17206 m
.32143 .20114 L
s
.35119 .17206 m
.35119 .13765 L
s
.38095 .17206 m
.38095 .20521 L
s
.41071 .17206 m
.41071 .16215 L
s
.44048 .17206 m
.44048 .14151 L
s
.47024 .17206 m
.47024 .20023 L
s
.5 .17206 m
.5 .20286 L
s
.52976 .17206 m
.52976 .1683 L
s
.55952 .17206 m
.55952 .14641 L
s
.58929 .17206 m
.58929 .1415 L
s
.61905 .17206 m
.61905 .1431 L
s
.64881 .17206 m
.64881 .14671 L
s
.67857 .17206 m
.67857 .15505 L
s
.70833 .17206 m
.70833 .17153 L
s
.7381 .17206 m
.7381 .18749 L
s
.76786 .17206 m
.76786 .18157 L
s
.79762 .17206 m
.79762 .16207 L
s
.82738 .17206 m
.82738 .17045 L
s
.85714 .17206 m
.85714 .1781 L
s
.8869 .17206 m
.8869 .16712 L
s
.91667 .17206 m
.91667 .17537 L
s
.94643 .17206 m
.94643 .16541 L
s
.02381 .24364 m
.02381 .24138 L
s
.05357 .24364 m
.05357 .24368 L
s
.08333 .24364 m
.08333 .24361 L
s
.1131 .24364 m
.1131 .24364 L
s
.14286 .24364 m
.14286 .24371 L
s
.17262 .24364 m
.17262 .24354 L
s
.20238 .24364 m
.20238 .24359 L
s
.23214 .24364 m
.23214 .24414 L
s
.2619 .24364 m
.2619 .2424 L
s
.29167 .24364 m
.29167 .24591 L
s
.32143 .24364 m
.32143 .24015 L
s
.35119 .24364 m
.35119 .24768 L
s
.38095 .24364 m
.38095 .24255 L
s
.41071 .24364 m
.41071 .23612 L
s
.44048 .24364 m
.44048 .25538 L
s
.47024 .24364 m
.47024 .25042 L
s
.5 .24364 m
.5 .2293 L
s
.52976 .24364 m
.52976 .22276 L
s
.55952 .24364 m
.55952 .22978 L
s
.58929 .24364 m
.58929 .23777 L
s
.61905 .24364 m
.61905 .23948 L
s
.64881 .24364 m
.64881 .23202 L
s
.67857 .24364 m
.67857 .21665 L
s
.70833 .24364 m
.70833 .20815 L
s
.7381 .24364 m
.7381 .23486 L
s
.76786 .24364 m
.76786 .27943 L
s
.79762 .24364 m
.79762 .24897 L
s
.82738 .24364 m
.82738 .20915 L
s
.85714 .24364 m
.85714 .27587 L
s
.8869 .24364 m
.8869 .22299 L
s
.91667 .24364 m
.91667 .25669 L
s
.94643 .24364 m
.94643 .24029 L
s
.02381 .31523 m
.02381 .31642 L
s
.05357 .31523 m
.05357 .31551 L
s
.08333 .31523 m
.08333 .31517 L
s
.1131 .31523 m
.1131 .31517 L
s
.14286 .31523 m
.14286 .31503 L
s
.17262 .31523 m
.17262 .31547 L
s
.20238 .31523 m
.20238 .31562 L
s
.23214 .31523 m
.23214 .314 L
s
.2619 .31523 m
.2619 .31683 L
s
.29167 .31523 m
.29167 .31359 L
s
.32143 .31523 m
.32143 .31706 L
s
.35119 .31523 m
.35119 .31275 L
s
.38095 .31523 m
.38095 .31831 L
s
.41071 .31523 m
.41071 .31287 L
s
.44048 .31523 m
.44048 .31519 L
s
.47024 .31523 m
.47024 .31677 L
s
.5 .31523 m
.5 .3148 L
s
.52976 .31523 m
.52976 .31464 L
s
.55952 .31523 m
.55952 .31524 L
s
.58929 .31523 m
.58929 .31536 L
s
.61905 .31523 m
.61905 .31528 L
s
.64881 .31523 m
.64881 .31536 L
s
.67857 .31523 m
.67857 .31562 L
s
.70833 .31523 m
.70833 .31531 L
s
.7381 .31523 m
.7381 .3134 L
s
.76786 .31523 m
.76786 .31448 L
s
.79762 .31523 m
.79762 .32161 L
s
.82738 .31523 m
.82738 .30963 L
s
.85714 .31523 m
.85714 .31181 L
s
.8869 .31523 m
.8869 .32912 L
s
.91667 .31523 m
.91667 .29456 L
s
.94643 .31523 m
.94643 .33551 L
s
.02381 .38681 m
.02381 .38345 L
s
.05357 .38681 m
.05357 .3871 L
s
.08333 .38681 m
.08333 .38682 L
s
.1131 .38681 m
.1131 .38681 L
s
.14286 .38681 m
.14286 .38681 L
s
.17262 .38681 m
.17262 .38681 L
s
.20238 .38681 m
.20238 .38681 L
s
.23214 .38681 m
.23214 .38681 L
s
.2619 .38681 m
.2619 .3868 L
s
.29167 .38681 m
.29167 .38682 L
s
.32143 .38681 m
.32143 .38679 L
s
.35119 .38681 m
.35119 .38684 L
s
.38095 .38681 m
.38095 .38676 L
s
.41071 .38681 m
.41071 .38683 L
s
.44048 .38681 m
.44048 .38685 L
s
.47024 .38681 m
.47024 .38677 L
s
.5 .38681 m
.5 .38679 L
s
.52976 .38681 m
.52976 .38683 L
s
.55952 .38681 m
.55952 .38682 L
s
.58929 .38681 m
.58929 .38681 L
s
.61905 .38681 m
.61905 .3868 L
s
.64881 .38681 m
.64881 .38677 L
s
.67857 .38681 m
.67857 .38676 L
s
.70833 .38681 m
.70833 .38692 L
s
.7381 .38681 m
.7381 .38719 L
s
.76786 .38681 m
.76786 .38627 L
s
.79762 .38681 m
.79762 .38583 L
s
.82738 .38681 m
.82738 .38985 L
s
.85714 .38681 m
.85714 .38323 L
s
.8869 .38681 m
.8869 .38935 L
s
.91667 .38681 m
.91667 .38509 L
s
.94643 .38681 m
.94643 .39084 L
s
.02381 .45839 m
.02381 .45761 L
s
.05357 .45839 m
.05357 .45858 L
s
.08333 .45839 m
.08333 .45838 L
s
.1131 .45839 m
.1131 .45839 L
s
.14286 .45839 m
.14286 .45839 L
s
.17262 .45839 m
.17262 .45839 L
s
.20238 .45839 m
.20238 .45839 L
s
.23214 .45839 m
.23214 .45839 L
s
.2619 .45839 m
.2619 .4584 L
s
.29167 .45839 m
.29167 .45837 L
s
.32143 .45839 m
.32143 .45843 L
s
.35119 .45839 m
.35119 .45833 L
s
.38095 .45839 m
.38095 .45838 L
s
.41071 .45839 m
.41071 .45863 L
s
.44048 .45839 m
.44048 .45812 L
s
.47024 .45839 m
.47024 .45787 L
s
.5 .45839 m
.5 .45866 L
s
.52976 .45839 m
.52976 .45965 L
s
.55952 .45839 m
.55952 .46017 L
s
.58929 .45839 m
.58929 .46043 L
s
.61905 .45839 m
.61905 .46099 L
s
.64881 .45839 m
.64881 .4622 L
s
.67857 .45839 m
.67857 .46323 L
s
.70833 .45839 m
.70833 .46087 L
s
.7381 .45839 m
.7381 .45331 L
s
.76786 .45839 m
.76786 .45211 L
s
.79762 .45839 m
.79762 .46621 L
s
.82738 .45839 m
.82738 .45882 L
s
.85714 .45839 m
.85714 .45094 L
s
.8869 .45839 m
.8869 .4684 L
s
.91667 .45839 m
.91667 .44837 L
s
.94643 .45839 m
.94643 .46706 L
s
.02381 .52997 m
.02381 .53114 L
s
.05357 .52997 m
.05357 .52981 L
s
.08333 .52997 m
.08333 .52999 L
s
.1131 .52997 m
.1131 .52997 L
s
.14286 .52997 m
.14286 .52998 L
s
.17262 .52997 m
.17262 .52997 L
s
.20238 .52997 m
.20238 .52996 L
s
.23214 .52997 m
.23214 .53002 L
s
.2619 .52997 m
.2619 .52988 L
s
.29167 .52997 m
.29167 .53013 L
s
.32143 .52997 m
.32143 .5297 L
s
.35119 .52997 m
.35119 .53039 L
s
.38095 .52997 m
.38095 .52957 L
s
.41071 .52997 m
.41071 .52978 L
s
.44048 .52997 m
.44048 .5311 L
s
.47024 .52997 m
.47024 .52972 L
s
.5 .52997 m
.5 .52823 L
s
.52976 .52997 m
.52976 .52873 L
s
.55952 .52997 m
.55952 .5301 L
s
.58929 .52997 m
.58929 .53113 L
s
.61905 .52997 m
.61905 .53147 L
s
.64881 .52997 m
.64881 .53096 L
s
.67857 .52997 m
.67857 .52933 L
s
.70833 .52997 m
.70833 .52716 L
s
.7381 .52997 m
.7381 .52727 L
s
.76786 .52997 m
.76786 .5313 L
s
.79762 .52997 m
.79762 .53227 L
s
.82738 .52997 m
.82738 .52783 L
s
.85714 .52997 m
.85714 .53045 L
s
.8869 .52997 m
.8869 .53045 L
s
.91667 .52997 m
.91667 .52925 L
s
.94643 .52997 m
.94643 .53209 L
s
.02381 .60156 m
.02381 .60332 L
s
.05357 .60156 m
.05357 .60132 L
s
.08333 .60156 m
.08333 .60161 L
s
.1131 .60156 m
.1131 .60155 L
s
.14286 .60156 m
.14286 .60154 L
s
.17262 .60156 m
.17262 .60156 L
s
.20238 .60156 m
.20238 .60159 L
s
.23214 .60156 m
.23214 .60148 L
s
.2619 .60156 m
.2619 .60163 L
s
.29167 .60156 m
.29167 .6015 L
s
.32143 .60156 m
.32143 .6016 L
s
.35119 .60156 m
.35119 .60146 L
s
.38095 .60156 m
.38095 .60175 L
s
.41071 .60156 m
.41071 .60132 L
s
.44048 .60156 m
.44048 .60165 L
s
.47024 .60156 m
.47024 .60165 L
s
.5 .60156 m
.5 .60148 L
s
.52976 .60156 m
.52976 .60152 L
s
.55952 .60156 m
.55952 .60157 L
s
.58929 .60156 m
.58929 .60157 L
s
.61905 .60156 m
.61905 .60155 L
s
.64881 .60156 m
.64881 .60156 L
s
.67857 .60156 m
.67857 .60159 L
s
.70833 .60156 m
.70833 .60161 L
s
.7381 .60156 m
.7381 .60146 L
s
.76786 .60156 m
.76786 .60135 L
s
.79762 .60156 m
.79762 .60193 L
s
.82738 .60156 m
.82738 .60162 L
s
.85714 .60156 m
.85714 .60086 L
s
.8869 .60156 m
.8869 .60255 L
s
.91667 .60156 m
.91667 .60064 L
s
.94643 .60156 m
.94643 .6022 L
s
0 1 1 r
.02381 .0863 m
.97619 .0863 L
s
.02381 .17206 m
.97619 .17206 L
s
.02381 .24364 m
.97619 .24364 L
s
.02381 .31523 m
.97619 .31523 L
s
.02381 .38681 m
.97619 .38681 L
s
.02381 .45839 m
.97619 .45839 L
s
.02381 .52997 m
.97619 .52997 L
s
.02381 .60156 m
.97619 .60156 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "We see that as the frequency increases, the location of the significant \
coefficients shifts to the right, that is, to higher ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". This shows that the frequency of the signal is increasing with time. We \
can also plot the coefficients in phase space, that is, \
time\[Hyphen]frequency space. Note that since the vertical axis represents \
frequency in a phase space plot, the coefficients from wavelet packet \
transforms should always be ordered using ",
  StyleBox["GrayCodeOrder", "MR"],
  " before using ",
  StyleBox["PhaseSpacePlot", "MR"],
  ". "
}], "Text",
  CellTags->{"S2.1.3", "3.25"}],

Cell["\<\
The plot indicates that the frequency increases roughly linearly \
with time.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.26"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[%%, AspectRatio -> 1,
Frame -> True, FrameTicks -> {Automatic, None}]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0297619 0.0238095 0.119048 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -3 -9 ]
[.17262 -0.0125 3 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(5)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(10)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(15)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(20)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(25)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(30)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.17262 .99375 m
.17262 1 L
s
.32143 .99375 m
.32143 1 L
s
.47024 .99375 m
.47024 1 L
s
.61905 .99375 m
.61905 1 L
s
.76786 .99375 m
.76786 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.05357 .99625 m
.05357 1 L
s
.08333 .99625 m
.08333 1 L
s
.1131 .99625 m
.1131 1 L
s
.14286 .99625 m
.14286 1 L
s
.20238 .99625 m
.20238 1 L
s
.23214 .99625 m
.23214 1 L
s
.2619 .99625 m
.2619 1 L
s
.29167 .99625 m
.29167 1 L
s
.35119 .99625 m
.35119 1 L
s
.38095 .99625 m
.38095 1 L
s
.41071 .99625 m
.41071 1 L
s
.44048 .99625 m
.44048 1 L
s
.5 .99625 m
.5 1 L
s
.52976 .99625 m
.52976 1 L
s
.55952 .99625 m
.55952 1 L
s
.58929 .99625 m
.58929 1 L
s
.64881 .99625 m
.64881 1 L
s
.67857 .99625 m
.67857 1 L
s
.70833 .99625 m
.70833 1 L
s
.7381 .99625 m
.7381 1 L
s
.79762 .99625 m
.79762 1 L
s
.82738 .99625 m
.82738 1 L
s
.85714 .99625 m
.85714 1 L
s
.8869 .99625 m
.8869 1 L
s
.94643 .99625 m
.94643 1 L
s
.97619 .99625 m
.97619 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DACC5500423E390086F3C6DDE9BABFF4ECFAFAFFFEFFFFFD
FFF7FFF0EDF7FEF6
pop
P
% End of image
% Start of gray image
p
.02381 .14286 translate
.95238 .11904 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E2F9FEF4F4D8F8B97751300912B9253623E54825304A86FC
91BBB8F4D4DCE8D0
pop
P
% End of image
% Start of gray image
p
.02381 .2619 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EFFFFFFFFFFFFFFCF7EFE6E3F8CAACCF996A9CD5E2AC3E02
C100D909196CA2E8
pop
P
% End of image
% Start of gray image
p
.02381 .38095 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7FDFFFFFEFEFDF7F4F4F2EEE9EFFFF4FCFBFFFFFFFFFDFF
F2FAD2D7E79C6C6E
pop
P
% End of image
% Start of gray image
p
.02381 .5 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E7FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFCF9EAE6EDF3E3
pop
P
% End of image
% Start of gray image
p
.02381 .61905 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FAFEFFFFFFFFFFFFFFFFFFFFFFFEFEFCFEF6F3F1EDE4DDEE
DBD3C8FCCAB8B8C2
pop
P
% End of image
% Start of gray image
p
.02381 .7381 translate
.95238 .11904 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F7FEFFFFFFFFFFFFFFFEFEFDFDFEF7FEF3F7FFF7F5F8FBEB
ECF6EFF0FCFCFAF0
pop
P
% End of image
% Start of gray image
p
.02381 .85714 translate
.95238 .11905 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F3FEFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFFFFFFFFFF
FFFEFDFFFBF8F9FB
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["WaveletPacketTransform", "MR"],
  " calculates the wavelet packet coefficients table and then automatically \
chooses the best basis according to the entropy criterion. "
}], "Text",
  CellTags->{"S2.1.3", "3.27"}],

Cell["\<\
This gives the wavelet packet transform using the best basis.\
\>", 
  "MathCaption",
  CellTags->{"S2.1.3", "3.28"}],

Cell["\<\
wpdata = WaveletPacketTransform[data, c4,
BoundaryCondition -> Zero];\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.1.3"],

Cell["This shows the position of the best basis.", "MathCaption",
  CellTags->{"S2.1.3", "3.29"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%, PlotLabel -> \"best basis\"]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0147151 0.0981006 [
[.5 .63053 -30 0 ]
[.5 .63053 30 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(best basis)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .11282 m
.97619 .11282 L
s
.02381 .21092 m
.97619 .21092 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .40712 m
.97619 .40712 L
s
.02381 .50522 m
.97619 .50522 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.05357 .01472 m
.05357 .11282 L
s
.08333 .01472 m
.08333 .21092 L
s
.1131 .01472 m
.1131 .11282 L
s
.14286 .01472 m
.14286 .30902 L
s
.17262 .01472 m
.17262 .11282 L
s
.20238 .01472 m
.20238 .21092 L
s
.23214 .01472 m
.23214 .11282 L
s
.2619 .01472 m
.2619 .40712 L
s
.29167 .01472 m
.29167 .11282 L
s
.32143 .01472 m
.32143 .21092 L
s
.35119 .01472 m
.35119 .11282 L
s
.38095 .01472 m
.38095 .30902 L
s
.41071 .01472 m
.41071 .11282 L
s
.44048 .01472 m
.44048 .21092 L
s
.47024 .01472 m
.47024 .11282 L
s
.5 .01472 m
.5 .50522 L
s
.52976 .01472 m
.52976 .11282 L
s
.55952 .01472 m
.55952 .21092 L
s
.58929 .01472 m
.58929 .11282 L
s
.61905 .01472 m
.61905 .30902 L
s
.64881 .01472 m
.64881 .11282 L
s
.67857 .01472 m
.67857 .21092 L
s
.70833 .01472 m
.70833 .11282 L
s
.7381 .01472 m
.7381 .40712 L
s
.76786 .01472 m
.76786 .11282 L
s
.79762 .01472 m
.79762 .21092 L
s
.82738 .01472 m
.82738 .11282 L
s
.85714 .01472 m
.85714 .30902 L
s
.8869 .01472 m
.8869 .11282 L
s
.91667 .01472 m
.91667 .21092 L
s
.94643 .01472 m
.94643 .11282 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .11282 translate
.05952 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08333 .01472 translate
.02977 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1131 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.17262 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20238 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.23214 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.02977 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.29167 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32143 .11282 translate
.05952 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .11282 translate
.05953 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.44048 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47024 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.52976 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.55952 .01472 translate
.02977 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.58929 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.64881 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.67857 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.70833 .01472 translate
.02977 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.76786 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.79762 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.82738 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8869 .01472 translate
.02977 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.91667 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.94643 .01472 translate
.02976 .0981 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
Again, the phase space plot shows that the frequency changes \
linearly with time.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.30"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[GrayCodeOrder[wpdata], AspectRatio -> 1,
Frame -> True, FrameTicks -> {Automatic, None}]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0238095 0.0595238 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -9 -9 ]
[.17262 -0.0125 9 0 ]
[.32143 -0.0125 -3 -9 ]
[.32143 -0.0125 3 0 ]
[.47024 -0.0125 -9 -9 ]
[.47024 -0.0125 9 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -12 -9 ]
[.76786 -0.0125 12 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(2.5)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(5)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(7.5)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(10)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(12.5)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(15)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.17262 .99375 m
.17262 1 L
s
.32143 .99375 m
.32143 1 L
s
.47024 .99375 m
.47024 1 L
s
.61905 .99375 m
.61905 1 L
s
.76786 .99375 m
.76786 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.05357 .99625 m
.05357 1 L
s
.08333 .99625 m
.08333 1 L
s
.1131 .99625 m
.1131 1 L
s
.14286 .99625 m
.14286 1 L
s
.20238 .99625 m
.20238 1 L
s
.23214 .99625 m
.23214 1 L
s
.2619 .99625 m
.2619 1 L
s
.29167 .99625 m
.29167 1 L
s
.35119 .99625 m
.35119 1 L
s
.38095 .99625 m
.38095 1 L
s
.41071 .99625 m
.41071 1 L
s
.44048 .99625 m
.44048 1 L
s
.5 .99625 m
.5 1 L
s
.52976 .99625 m
.52976 1 L
s
.55952 .99625 m
.55952 1 L
s
.58929 .99625 m
.58929 1 L
s
.64881 .99625 m
.64881 1 L
s
.67857 .99625 m
.67857 1 L
s
.70833 .99625 m
.70833 1 L
s
.7381 .99625 m
.7381 1 L
s
.79762 .99625 m
.79762 1 L
s
.82738 .99625 m
.82738 1 L
s
.85714 .99625 m
.85714 1 L
s
.8869 .99625 m
.8869 1 L
s
.94643 .99625 m
.94643 1 L
s
.97619 .99625 m
.97619 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .05952 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FB5C9BB1F1F6FEF5F4FAFEFEFEFDFDFE
pop
P
% End of image
% Start of gray image
p
.02381 .08333 translate
.95238 .02977 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A810BEFCF9FCF7F9
pop
P
% End of image
% Start of gray image
p
.02381 .1131 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FDE1BBE1FCFEFFF5
pop
P
% End of image
% Start of gray image
p
.02381 .14286 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FAEA11CFEEF9EEE0
pop
P
% End of image
% Start of gray image
p
.02381 .17262 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E9F19889F6F6F5FA
pop
P
% End of image
% Start of gray image
p
.02381 .20238 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FBF4EA6894F0BBFD
pop
P
% End of image
% Start of gray image
p
.02381 .23214 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFEF1C100DBF8
pop
P
% End of image
% Start of gray image
p
.02381 .2619 translate
.95238 .05953 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFDEECFB7A7EB4AF9EDF9FE
pop
P
% End of image
% Start of gray image
p
.02381 .32143 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEF9E0C9F18B62C6
pop
P
% End of image
% Start of gray image
p
.02381 .35119 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFDE7EDFAF2E839
pop
P
% End of image
% Start of gray image
p
.02381 .38095 translate
.95238 .05953 scale
16 string
16 1 8 [16 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFEF8F6F0F2F8FDFFFFFCF8E0AA99
pop
P
% End of image
% Start of gray image
p
.02381 .44048 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFEFEFEFBF7F5
pop
P
% End of image
% Start of gray image
p
.02381 .47024 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFEFDFD
pop
P
% End of image
% Start of gray image
p
.02381 .5 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .52976 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFDFA
pop
P
% End of image
% Start of gray image
p
.02381 .55952 translate
.95238 .02977 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFF7FB
pop
P
% End of image
% Start of gray image
p
.02381 .58929 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFCE5
pop
P
% End of image
% Start of gray image
p
.02381 .61905 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFEF8E6BB
pop
P
% End of image
% Start of gray image
p
.02381 .64881 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFDFDE8EBF9
pop
P
% End of image
% Start of gray image
p
.02381 .67857 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFEFFE4E3FF
pop
P
% End of image
% Start of gray image
p
.02381 .70833 translate
.95238 .02977 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFEE1FAFE
pop
P
% End of image
% Start of gray image
p
.02381 .7381 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFEF9F9F6FD
pop
P
% End of image
% Start of gray image
p
.02381 .76786 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFF8FFFBF3FF
pop
P
% End of image
% Start of gray image
p
.02381 .79762 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFDFEFFFAF0FC
pop
P
% End of image
% Start of gray image
p
.02381 .82738 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFDFFFFFFFDFE
pop
P
% End of image
% Start of gray image
p
.02381 .85714 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFEFFFFFEF9
pop
P
% End of image
% Start of gray image
p
.02381 .8869 translate
.95238 .02977 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFEFEFF
pop
P
% End of image
% Start of gray image
p
.02381 .91667 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFEFF
pop
P
% End of image
% Start of gray image
p
.02381 .94643 translate
.95238 .02976 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
We can also compare the energy concentration of coefficients from \
the wavelet transform with those from the wavelet packet transform using the \
best basis. \
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.31"}],

Cell["\<\
(wtEnergy = CumulativeEnergy[wtdata]/
(Flatten[wtdata].Flatten[wtdata]);
wpEnergy = CumulativeEnergy[wpdata]/
(Flatten[wpdata].Flatten[wpdata]);)\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
The cumulative energy curves for best basis coefficients (solid \
line) and for wavelet coefficients (dotted line) are shown here.\
\>", 
  "MathCaption",
  CellTags->{"S2.1.3", "3.32"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[wpEnergy, PlotJoined -> True,
 PlotLabel -> \"cumulative energy\"],
 ListPlot[wtEnergy]}]]\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 -6.05104 6.65436 [
[.20982 .59082 -6 -9 ]
[.20982 .59082 6 0 ]
[.39583 .59082 -9 -9 ]
[.39583 .59082 9 0 ]
[.58185 .59082 -9 -9 ]
[.58185 .59082 9 0 ]
[.76786 .59082 -9 -9 ]
[.76786 .59082 9 0 ]
[.95387 .59082 -9 -9 ]
[.95387 .59082 9 0 ]
[.01131 .07097 -24 -4.5 ]
[.01131 .07097 0 4.5 ]
[.01131 .20406 -24 -4.5 ]
[.01131 .20406 0 4.5 ]
[.01131 .33714 -24 -4.5 ]
[.01131 .33714 0 4.5 ]
[.01131 .47023 -24 -4.5 ]
[.01131 .47023 0 4.5 ]
[.5 .63053 -51 0 ]
[.5 .63053 51 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20982 .60332 m
.20982 .60957 L
s
[(50)] .20982 .59082 0 1 Mshowa
.39583 .60332 m
.39583 .60957 L
s
[(100)] .39583 .59082 0 1 Mshowa
.58185 .60332 m
.58185 .60957 L
s
[(150)] .58185 .59082 0 1 Mshowa
.76786 .60332 m
.76786 .60957 L
s
[(200)] .76786 .59082 0 1 Mshowa
.95387 .60332 m
.95387 .60957 L
s
[(250)] .95387 .59082 0 1 Mshowa
.125 Mabswid
.06101 .60332 m
.06101 .60707 L
s
.09821 .60332 m
.09821 .60707 L
s
.13542 .60332 m
.13542 .60707 L
s
.17262 .60332 m
.17262 .60707 L
s
.24702 .60332 m
.24702 .60707 L
s
.28423 .60332 m
.28423 .60707 L
s
.32143 .60332 m
.32143 .60707 L
s
.35863 .60332 m
.35863 .60707 L
s
.43304 .60332 m
.43304 .60707 L
s
.47024 .60332 m
.47024 .60707 L
s
.50744 .60332 m
.50744 .60707 L
s
.54464 .60332 m
.54464 .60707 L
s
.61905 .60332 m
.61905 .60707 L
s
.65625 .60332 m
.65625 .60707 L
s
.69345 .60332 m
.69345 .60707 L
s
.73065 .60332 m
.73065 .60707 L
s
.80506 .60332 m
.80506 .60707 L
s
.84226 .60332 m
.84226 .60707 L
s
.87946 .60332 m
.87946 .60707 L
s
.91667 .60332 m
.91667 .60707 L
s
.99107 .60332 m
.99107 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .07097 m
.03006 .07097 L
s
[(0.92)] .01131 .07097 1 0 Mshowa
.02381 .20406 m
.03006 .20406 L
s
[(0.94)] .01131 .20406 1 0 Mshowa
.02381 .33714 m
.03006 .33714 L
s
[(0.96)] .01131 .33714 1 0 Mshowa
.02381 .47023 m
.03006 .47023 L
s
[(0.98)] .01131 .47023 1 0 Mshowa
.125 Mabswid
.02381 .10424 m
.02756 .10424 L
s
.02381 .13751 m
.02756 .13751 L
s
.02381 .17079 m
.02756 .17079 L
s
.02381 .23733 m
.02756 .23733 L
s
.02381 .2706 m
.02756 .2706 L
s
.02381 .30387 m
.02756 .30387 L
s
.02381 .37042 m
.02756 .37042 L
s
.02381 .40369 m
.02756 .40369 L
s
.02381 .43696 m
.02756 .43696 L
s
.02381 .5035 m
.02756 .5035 L
s
.02381 .53678 m
.02756 .53678 L
s
.02381 .57005 m
.02756 .57005 L
s
.02381 .0377 m
.02756 .0377 L
s
.02381 .00443 m
.02756 .00443 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(cumulative energy)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.10209 0 m
.10565 .06083 L
.10938 .11936 L
.1131 .1732 L
.11682 .21841 L
.12054 .25927 L
.12426 .29164 L
.12798 .32358 L
.1317 .34217 L
.13542 .356 L
.13914 .36967 L
.14286 .38296 L
.14658 .39609 L
.1503 .4089 L
.15402 .42165 L
.15774 .43307 L
.16146 .44347 L
.16518 .45297 L
.1689 .46159 L
.17262 .46992 L
.17634 .47772 L
.18006 .48512 L
.18378 .49182 L
.1875 .49833 L
.19122 .50472 L
.19494 .51036 L
.19866 .51599 L
.20238 .5209 L
.2061 .52556 L
.20982 .52984 L
.21354 .53398 L
.21726 .53795 L
.22098 .54118 L
.2247 .54438 L
.22842 .54749 L
.23214 .55057 L
.23586 .55354 L
.23958 .55639 L
.2433 .55912 L
.24702 .56147 L
.25074 .5638 L
.25446 .56597 L
.25818 .56784 L
.2619 .56971 L
.26563 .57136 L
.26935 .57292 L
.27307 .57437 L
.27679 .5758 L
.28051 .57716 L
.28423 .57851 L
Mistroke
.28795 .57985 L
.29167 .58106 L
.29539 .58224 L
.29911 .58327 L
.30283 .58427 L
.30655 .58521 L
.31027 .58604 L
.31399 .58686 L
.31771 .58767 L
.32143 .58846 L
.32515 .58915 L
.32887 .58982 L
.33259 .59048 L
.33631 .59111 L
.34003 .59168 L
.34375 .59225 L
.34747 .59281 L
.35119 .59336 L
.35491 .5939 L
.35863 .59444 L
.36235 .59494 L
.36607 .59544 L
.36979 .59592 L
.37351 .59638 L
.37723 .59683 L
.38095 .59727 L
.38467 .59767 L
.38839 .59806 L
.39211 .59842 L
.39583 .59876 L
.39955 .5991 L
.40327 .59944 L
.40699 .59977 L
.41071 .60009 L
.41443 .60029 L
.41815 .60046 L
.42188 .60062 L
.4256 .60078 L
.42932 .60094 L
.43304 .60109 L
.43676 .6012 L
.44048 .60131 L
.4442 .60141 L
.44792 .60151 L
.45164 .60161 L
.45536 .6017 L
.45908 .60179 L
.4628 .60187 L
.46652 .60194 L
.47024 .60201 L
Mistroke
.47396 .60207 L
.47768 .60214 L
.4814 .6022 L
.48512 .60226 L
.48884 .60231 L
.49256 .60237 L
.49628 .60242 L
.5 .60248 L
.50372 .60253 L
.50744 .60257 L
.51116 .60262 L
.51488 .60266 L
.5186 .6027 L
.52232 .60273 L
.52604 .60277 L
.52976 .6028 L
.53348 .60283 L
.5372 .60286 L
.54092 .60288 L
.54464 .60291 L
.54836 .60294 L
.55208 .60297 L
.5558 .60299 L
.55952 .60302 L
.56324 .60304 L
.56696 .60306 L
.57068 .60308 L
.5744 .6031 L
.57813 .60312 L
.58185 .60314 L
.58557 .60316 L
.58929 .60317 L
.59301 .60318 L
.59673 .60319 L
.60045 .60321 L
.60417 .60321 L
.60789 .60322 L
.61161 .60323 L
.61533 .60324 L
.61905 .60325 L
.62277 .60325 L
.62649 .60326 L
.63021 .60326 L
.63393 .60327 L
.63765 .60327 L
.64137 .60328 L
.64509 .60328 L
.64881 .60328 L
.65253 .60329 L
.65625 .60329 L
Mistroke
.65997 .60329 L
.66369 .6033 L
.66741 .6033 L
.67113 .6033 L
.67485 .6033 L
.67857 .6033 L
.68229 .6033 L
.68601 .60331 L
.68973 .60331 L
.69345 .60331 L
.69717 .60331 L
.70089 .60331 L
.70461 .60331 L
.70833 .60331 L
.71205 .60331 L
.71577 .60331 L
.71949 .60331 L
.72321 .60331 L
.72693 .60331 L
.73065 .60331 L
.73438 .60331 L
.7381 .60331 L
.74182 .60331 L
.74554 .60332 L
.74926 .60332 L
.75298 .60332 L
.7567 .60332 L
.76042 .60332 L
.76414 .60332 L
.76786 .60332 L
.77158 .60332 L
.7753 .60332 L
.77902 .60332 L
.78274 .60332 L
.78646 .60332 L
.79018 .60332 L
.7939 .60332 L
.79762 .60332 L
.80134 .60332 L
.80506 .60332 L
.80878 .60332 L
.8125 .60332 L
.81622 .60332 L
.81994 .60332 L
.82366 .60332 L
.82738 .60332 L
.8311 .60332 L
.83482 .60332 L
.83854 .60332 L
.84226 .60332 L
Mistroke
.84598 .60332 L
.8497 .60332 L
.85342 .60332 L
.85714 .60332 L
.86086 .60332 L
.86458 .60332 L
.8683 .60332 L
.87202 .60332 L
.87574 .60332 L
.87946 .60332 L
.88318 .60332 L
.8869 .60332 L
.89063 .60332 L
.89435 .60332 L
.89807 .60332 L
.90179 .60332 L
.90551 .60332 L
.90923 .60332 L
.91295 .60332 L
.91667 .60332 L
.92039 .60332 L
.92411 .60332 L
.92783 .60332 L
.93155 .60332 L
.93527 .60332 L
.93899 .60332 L
.94271 .60332 L
.94643 .60332 L
.95015 .60332 L
.95387 .60332 L
.95759 .60332 L
.96131 .60332 L
.96503 .60332 L
.96875 .60332 L
.97247 .60332 L
.97619 .60332 L
Mfstroke
.008 w
.17634 .03163 Mdot
.18006 .06431 Mdot
.18378 .08979 Mdot
.1875 .11452 Mdot
.19122 .13891 Mdot
.19494 .16324 Mdot
.19866 .18707 Mdot
.20238 .21005 Mdot
.2061 .23244 Mdot
.20982 .25013 Mdot
.21354 .26688 Mdot
.21726 .28045 Mdot
.22098 .29207 Mdot
.2247 .30334 Mdot
.22842 .31451 Mdot
.23214 .32548 Mdot
.23586 .33641 Mdot
.23958 .34707 Mdot
.2433 .35765 Mdot
.24702 .36788 Mdot
.25074 .37796 Mdot
.25446 .38795 Mdot
.25818 .39757 Mdot
.2619 .40661 Mdot
.26563 .41432 Mdot
.26935 .42162 Mdot
.27307 .42842 Mdot
.27679 .43499 Mdot
.28051 .4411 Mdot
.28423 .44714 Mdot
.28795 .45269 Mdot
.29167 .4582 Mdot
.29539 .46357 Mdot
.29911 .46885 Mdot
.30283 .47403 Mdot
.30655 .47912 Mdot
.31027 .48411 Mdot
.31399 .48895 Mdot
.31771 .49364 Mdot
.32143 .49798 Mdot
.32515 .50226 Mdot
.32887 .5065 Mdot
.33259 .51061 Mdot
.33631 .51464 Mdot
.34003 .51843 Mdot
.34375 .52218 Mdot
.34747 .52568 Mdot
.35119 .52874 Mdot
.35491 .53174 Mdot
.35863 .5347 Mdot
.36235 .53764 Mdot
.36607 .54053 Mdot
.36979 .54325 Mdot
.37351 .54594 Mdot
.37723 .5485 Mdot
.38095 .55098 Mdot
.38467 .5534 Mdot
.38839 .55578 Mdot
.39211 .55794 Mdot
.39583 .56008 Mdot
.39955 .56217 Mdot
.40327 .56415 Mdot
.40699 .56604 Mdot
.41071 .56791 Mdot
.41443 .56971 Mdot
.41815 .57135 Mdot
.42188 .57297 Mdot
.4256 .57457 Mdot
.42932 .57606 Mdot
.43304 .5775 Mdot
.43676 .57883 Mdot
.44048 .58012 Mdot
.4442 .58139 Mdot
.44792 .58257 Mdot
.45164 .58364 Mdot
.45536 .58468 Mdot
.45908 .58562 Mdot
.4628 .58646 Mdot
.46652 .5873 Mdot
.47024 .5881 Mdot
.47396 .58887 Mdot
.47768 .58958 Mdot
.4814 .59022 Mdot
.48512 .59085 Mdot
.48884 .59147 Mdot
.49256 .59208 Mdot
.49628 .59265 Mdot
.5 .5932 Mdot
.50372 .59374 Mdot
.50744 .59428 Mdot
.51116 .59476 Mdot
.51488 .59521 Mdot
.5186 .59562 Mdot
.52232 .59603 Mdot
.52604 .59643 Mdot
.52976 .59682 Mdot
.53348 .59718 Mdot
.5372 .59752 Mdot
.54092 .59787 Mdot
.54464 .5982 Mdot
.54836 .5985 Mdot
.55208 .59879 Mdot
.5558 .59908 Mdot
.55952 .59936 Mdot
.56324 .5996 Mdot
.56696 .59983 Mdot
.57068 .60004 Mdot
.5744 .60025 Mdot
.57813 .60046 Mdot
.58185 .60065 Mdot
.58557 .60084 Mdot
.58929 .60099 Mdot
.59301 .60113 Mdot
.59673 .60126 Mdot
.60045 .60139 Mdot
.60417 .60151 Mdot
.60789 .60163 Mdot
.61161 .60174 Mdot
.61533 .60185 Mdot
.61905 .60196 Mdot
.62277 .60205 Mdot
.62649 .60214 Mdot
.63021 .60223 Mdot
.63393 .60231 Mdot
.63765 .60239 Mdot
.64137 .60246 Mdot
.64509 .60252 Mdot
.64881 .60257 Mdot
.65253 .60262 Mdot
.65625 .60267 Mdot
.65997 .60272 Mdot
.66369 .60276 Mdot
.66741 .6028 Mdot
.67113 .60283 Mdot
.67485 .60287 Mdot
.67857 .6029 Mdot
.68229 .60294 Mdot
.68601 .60297 Mdot
.68973 .603 Mdot
.69345 .60302 Mdot
.69717 .60305 Mdot
.70089 .60307 Mdot
.70461 .60309 Mdot
.70833 .60311 Mdot
.71205 .60313 Mdot
.71577 .60315 Mdot
.71949 .60317 Mdot
.72321 .60318 Mdot
.72693 .6032 Mdot
.73065 .60321 Mdot
.73438 .60322 Mdot
.7381 .60323 Mdot
.74182 .60324 Mdot
.74554 .60324 Mdot
.74926 .60325 Mdot
.75298 .60326 Mdot
.7567 .60326 Mdot
.76042 .60327 Mdot
.76414 .60327 Mdot
.76786 .60328 Mdot
.77158 .60328 Mdot
.7753 .60329 Mdot
.77902 .60329 Mdot
.78274 .60329 Mdot
.78646 .6033 Mdot
.79018 .6033 Mdot
.7939 .6033 Mdot
.79762 .6033 Mdot
.80134 .60331 Mdot
.80506 .60331 Mdot
.80878 .60331 Mdot
.8125 .60331 Mdot
.81622 .60331 Mdot
.81994 .60331 Mdot
.82366 .60331 Mdot
.82738 .60332 Mdot
.8311 .60332 Mdot
.83482 .60332 Mdot
.83854 .60332 Mdot
.84226 .60332 Mdot
.84598 .60332 Mdot
.8497 .60332 Mdot
.85342 .60332 Mdot
.85714 .60332 Mdot
.86086 .60332 Mdot
.86458 .60332 Mdot
.8683 .60332 Mdot
.87202 .60332 Mdot
.87574 .60332 Mdot
.87946 .60332 Mdot
.88318 .60332 Mdot
.8869 .60332 Mdot
.89063 .60332 Mdot
.89435 .60332 Mdot
.89807 .60332 Mdot
.90179 .60332 Mdot
.90551 .60332 Mdot
.90923 .60332 Mdot
.91295 .60332 Mdot
.91667 .60332 Mdot
.92039 .60332 Mdot
.92411 .60332 Mdot
.92783 .60332 Mdot
.93155 .60332 Mdot
.93527 .60332 Mdot
.93899 .60332 Mdot
.94271 .60332 Mdot
.94643 .60332 Mdot
.95015 .60332 Mdot
.95387 .60332 Mdot
.95759 .60332 Mdot
.96131 .60332 Mdot
.96503 .60332 Mdot
.96875 .60332 Mdot
.97247 .60332 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00O7goo00<007ooOol0
4Woo00<007ooOol0mGoo000OOol00`00Oomoo`0BOol00`00Oomoo`3eOol001moo`8001=oo`03001o
ogoo0?Eoo`007goo00<007ooOol04Woo00<007ooOol0mGoo000OOol00`00Oomoo`0BOol00`00Oomo
o`3eOol001moo`03001oogoo019oo`03001oogoo0?Eoo`007goo00<007ooOol04Woo00<007ooOol0
mGoo000OOol00`00Oomoo`0BOol00`00Oomoo`3eOol001moo`03001oogoo019oo`03001oogoo0?Eo
o`007goo00<007ooOol04goo00<007ooOol047oo0P00hWoo000OOol00`00Oomoo`0COol00`00Oomo
o`0@Ool2003ROol001moo`8001Aoo`03001oogoo0?Aoo`007goo00<007ooOol04goo00<007ooOol0
m7oo000OOol00`00Oomoo`0COol00`00Oomoo`3dOol001moo`03001oogoo01=oo`03001oogoo0?Ao
o`007goo00<007ooOol04goo00<007ooOol0m7oo000OOol00`00Oomoo`0COol00`00Oomoo`3dOol0
01moo`03001oogoo01=oo`03001oogoo015oo`800>5oo`001Woo0P0017oo0P000goo0`000goo1000
17oo00<007ooOol04goo00<007ooOol04Goo0P00hGoo0005Ool01000Oomoo`000goo0P001Woo00D0
07ooOomoo`0000Ioo`03001oogoo01=oo`03001oogoo0?Aoo`001Goo00@007ooOol000Uoo`<000Ao
o`03001oogoo00=oo`<001=oo`03001oogoo0?Aoo`001Goo00@007ooOol000Qoo`04001oogoo0005
Ool00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`3dOol000Eoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo01=oo`03001oogoo0?Aoo`001Woo0P002Woo0P00
17oo0P001Goo00<007ooOol04goo00<007ooOol0m7oo000OOol00`00Oomoo`0COol00`00Oomoo`0B
Ool2003POol001moo`03001oogoo01=oo`03001oogoo019oo`800>1oo`007goo00<007ooOol057oo
00<007ooOol0lgoo000OOol00`00Oomoo`0DOol00`00Oomoo`3cOol001moo`03001oogoo01Aoo`03
001oogoo0?=oo`007goo0P005Goo00<007ooOol0lgoo000OOol00`00Oomoo`0DOol00`00Oomoo`3c
Ool001moo`03001oogoo01Aoo`03001oogoo019oo`800=moo`007goo00<007ooOol057oo00<007oo
Ool04Woo0P00ggoo000OOol00`00Oomoo`0DOol00`00Oomoo`3cOol001moo`03001oogoo01Aoo`03
001oogoo0?=oo`007goo00<007ooOol057oo00<007ooOol0lgoo000OOol00`00Oomoo`0DOol00`00
Oomoo`3cOol001moo`03001oogoo01Aoo`03001oogoo0?=oo`007goo0P005Goo00<007ooOol04goo
0P00gWoo000OOol00`00Oomoo`0DOol00`00Oomoo`0COol2003NOol001moo`03001oogoo01Aoo`03
001oogoo0?=oo`007goo00<007ooOol05Goo00<007ooOol0lWoo000OOol00`00Oomoo`0EOol00`00
Oomoo`3bOol001moo`03001oogoo01Eoo`03001oogoo0?9oo`007goo00<007ooOol05Goo00<007oo
Ool04goo0P00gGoo000OOol00`00Oomoo`0EOol00`00Oomoo`0COol2003MOol001moo`03001oogoo
01Eoo`03001oogoo0?9oo`007goo0P005Woo00<007ooOol0lWoo000OOol00`00Oomoo`0EOol00`00
Oomoo`3bOol001moo`03001oogoo01Eoo`03001oogoo0?9oo`007goo00<007ooOol05Goo00<007oo
Ool057oo0P00g7oo000OOol00`00Oomoo`0EOol00`00Oomoo`0DOol2003LOol001moo`03001oogoo
01Eoo`03001oogoo0?9oo`007goo00<007ooOol05Goo00<007ooOol0lWoo0006Ool20004Ool20003
Ool30004Ool30004Ool00`00Oomoo`0FOol00`00Oomoo`3aOol000Eoo`04001oogoo0003Ool20006
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomoo`3aOol000Eoo`04001o
ogoo0009Ool30002Ool40004Ool3000FOol00`00Oomoo`3aOol000Eoo`04001oogoo0008Ool01000
Oomoo`000Woo00<007oo00001Goo00<007ooOol05Woo00<007ooOol057oo0P00fgoo0005Ool01000
Oomoo`0027oo00@007ooOol0009oo`03001oo`0000Eoo`03001oogoo01Ioo`03001oogoo01Aoo`80
0=]oo`001Woo0P002Woo0P0017oo0P001Goo00<007ooOol05Woo00<007ooOol0lGoo000OOol00`00
Oomoo`0FOol00`00Oomoo`3aOol001moo`03001oogoo01Ioo`03001oogoo0?5oo`007goo00<007oo
Ool05Woo00<007ooOol0lGoo000OOol00`00Oomoo`0FOol00`00Oomoo`0EOol2003JOol001moo`80
01Moo`03001oogoo01Eoo`800=Yoo`007goo00<007ooOol05goo00<007ooOol0l7oo000OOol00`00
Oomoo`0GOol00`00Oomoo`3`Ool001moo`03001oogoo01Moo`03001oogoo01Eoo`800=Uoo`007goo
00<007ooOol05goo00<007ooOol05Goo0P00fGoo000OOol00`00Oomoo`0GOol00`00Oomoo`3`Ool0
01moo`03001oogoo01Moo`03001oogoo0?1oo`007goo00<007ooOol05goo00<007ooOol0l7oo000O
Ool00`00Oomoo`0GOol00`00Oomoo`0FOol2003HOol001moo`8001Qoo`03001oogoo01Ioo`800=Qo
o`007goo00<007ooOol05goo00<007ooOol0l7oo000OOol00`00Oomoo`0HOol00`00Oomoo`3_Ool0
01moo`03001oogoo01Qoo`03001oogoo01Ioo`800=Moo`007goo00<007ooOol067oo00<007ooOol0
5Woo0P00egoo000OOol00`00Oomoo`0HOol00`00Oomoo`3_Ool001moo`03001oogoo01Qoo`03001o
ogoo01Moo`800=Ioo`007goo00<007ooOol067oo00<007ooOol05goo0P00eWoo000OOol00`00Oomo
o`0HOol00`00Oomoo`3_Ool001moo`8001Uoo`03001oogoo01Qoo`800=Eoo`007goo00<007ooOol0
67oo00<007ooOol067oo0P00eGoo000OOol00`00Oomoo`0IOol00`00Oomoo`3^Ool001moo`03001o
ogoo01Uoo`03001oogoo01Qoo`800=Aoo`007goo00<007ooOol06Goo00<007ooOol067oo0P00e7oo
000OOol00`00Oomoo`0IOol00`00Oomoo`3^Ool001moo`03001oogoo01Uoo`03001oogoo01Uoo`80
0==oo`001Woo0P0017oo0P000goo0`0017oo0P001Goo00<007ooOol06Goo00<007ooOol06Goo0P00
dgoo0005Ool01000Oomoo`000goo0P001Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo
01Uoo`03001oogoo0>ioo`001Goo00@007ooOol000Uoo`<0009oo`04001oogoo0004Ool3000JOol0
0`00Oomoo`0IOol2003BOol000Eoo`04001oogoo0008Ool01000Oomoo`000Woo0`001Goo00<007oo
Ool06Woo00<007ooOol06Goo0P00dWoo0005Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo00Eoo`03001oogoo01Yoo`03001oogoo0>eoo`001Woo0P002Woo0P0017oo0`0017oo00<007oo
Ool06Woo00<007ooOol06Woo0P00dGoo000OOol00`00Oomoo`0KOol00`00Oomoo`0IOol2003AOol0
01moo`03001oogoo01]oo`03001oogoo01Yoo`800=1oo`007goo00<007ooOol06goo00<007ooOol0
6Woo0P00d7oo000OOol00`00Oomoo`0KOol00`00Oomoo`3/Ool001moo`03001oogoo01aoo`03001o
ogoo01Yoo`800<moo`007goo0P007Goo00<007ooOol06Woo0P00cgoo000OOol00`00Oomoo`0LOol0
0`00Oomoo`3[Ool001moo`03001oogoo01aoo`03001oogoo01]oo`800<ioo`007goo00<007ooOol0
7Goo00<007ooOol06Woo0P00cWoo000OOol00`00Oomoo`0MOol00`00Oomoo`3ZOol001moo`03001o
ogoo01eoo`03001oogoo01]oo`800<eoo`007goo00<007ooOol07Woo00<007ooOol06Woo0P00cGoo
000OOol00`00Oomoo`0NOol00`00Oomoo`0KOol2003<Ool001moo`03001oogoo01ioo`03001oogoo
01]oo`800<aoo`007goo0P007goo00<007ooOol0jGoo000OOol00`00Oomoo`0OOol00`00Oomoo`0K
Ool2003;Ool001moo`03001oogoo01moo`03001oogoo01]oo`800<]oo`007goo00<007ooOol07goo
00<007ooOol077oo0P00bWoo000OOol00`00Oomoo`0POol00`00Oomoo`0KOol2003:Ool001moo`03
001oogoo021oo`03001oogoo01aoo`800<Uoo`007goo00<007ooOol087oo00<007ooOol077oo0P00
bGoo000OOol00`00Oomoo`0QOol00`00Oomoo`0LOol20038Ool001moo`03001oogoo025oo`03001o
ogoo01aoo`<00<Moo`007goo0P008Woo00<007ooOol07Goo0P00agoo000OOol00`00Oomoo`0ROol0
0`00Oomoo`0MOol20036Ool001moo`03001oogoo029oo`03001oogoo01eoo`800<Ioo`007goo00<0
07ooOol08Woo00<007ooOol07Woo0P00aGoo000OOol00`00Oomoo`0SOol00`00Oomoo`0MOol30034
Ool001moo`03001oogoo02=oo`03001oogoo01ioo`800<Aoo`007goo00<007ooOol08goo00<007oo
Ool07goo0P00`goo0006Ool20004Ool20003Ool30004Ool20005Ool00`00Oomoo`0TOol00`00Oomo
o`0NOol30032Ool000Eoo`04001oogoo0003Ool20006Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol097oo00<007ooOol07goo0`00`Goo0005Ool01000Oomoo`002Goo0`000Woo00@007oo
Ool000Aoo`<002Eoo`03001oogoo01moo`800<5oo`001Goo00@007ooOol000Qoo`04001oogoo0003
Ool20005Ool00`00Oomoo`0UOol00`00Oomoo`0POol20030Ool000Eoo`04001oogoo0008Ool01000
Oomoo`000Woo00@007ooOol000Aoo`03001oogoo02Ioo`03001oogoo01moo`<00;moo`001Woo0P00
2Woo0P0017oo0P001Goo00<007ooOol09Woo00<007ooOol087oo0P00_goo000OOol00`00Oomoo`0W
Ool00`00Oomoo`0POol2002nOol001moo`03001oogoo02Moo`03001oogoo021oo`<00;eoo`007goo
00<007ooOol0:7oo00<007ooOol087oo0`00_7oo000OOol00`00Oomoo`0XOol00`00Oomoo`0QOol3
002kOol001moo`03001oogoo02Uoo`03001oogoo025oo`<00;Yoo`007goo0P00:Woo00<007ooOol0
8Woo0P00^Woo000OOol00`00Oomoo`0ZOol00`00Oomoo`0ROol2002iOol001moo`03001oogoo02]o
o`03001oogoo025oo`<00;Qoo`007goo00<007ooOol0:goo00<007ooOol08Woo0`00]goo000OOol0
0`00Oomoo`0/Ool00`00Oomoo`0ROol3002fOol001moo`03001oogoo02eoo`03001oogoo029oo`<0
0;Eoo`007goo00<007ooOol0;Woo00<007ooOol08Woo0`00]7oo000OOol00`00Oomoo`0_Ool00`00
Oomoo`0ROol4002bOol001moo`03001oogoo031oo`03001oogoo029oo`@00;5oo`007goo0P00<Goo
00<007ooOol097oo0`00/7oo000OOol00`00Oomoo`0aOol2000UOol3002_Ool001moo`03001oogoo
03=oo`03001oogoo02=oo`@00:eoo`007goo00<007ooOol0=7oo00<007ooOol08goo1000[7oo000O
Ool00`00Oomoo`0eOol00`00Oomoo`0TOol4002ZOol001moo`03001oogoo03Ioo`03001oogoo02Ao
o`D00:Qoo`007goo00<007ooOol0=goo0P009Woo1000Ygoo000OOol00`00Oomoo`0iOol00`00Oomo
o`0UOol4002UOol001moo`03001oogoo02Yoo`<000Aoo`8000Moo`8001eoo`<000Aoo`P002Aoo`<0
00=oo`<000Aoo`8002=oo`@000=oo`8000Aoo`8002=oo`@0009oo`<000Aoo`8000]oo`007goo0P00
;Woo00@007ooOol0009oo`03001oogoo00Ioo`8001aoo`03001oogoo009oo`05001oogoo001oo`05
000TOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol08Goo00<007ooOol00Woo00@007oo
Ool0009oo`04001oogoo000SOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol027oo000O
Ool00`00Oomoo`0]Ool01000Oomoo`000Woo00<007ooOol027oo0`006Goo00<007ooOol00Woo00@0
07ooOol0009oo`L0025oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`0ROol01@00Oomo
ogoo00000Woo00@007ooOol0009oo`03001oogoo029oo`03001oogoo00Aoo`04001oogoo0002Ool0
0`00Oomoo`08Ool001moo`03001oogoo02Yoo`<000=oo`04001oogoo000=Ool3000FOol00`00Oomo
o`02Ool01000Oomoo`000Woo00<007ooOol01`007Woo00<007ooOol00Woo0`000goo00@007ooOol0
02Eoo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol08goo00<007ooOol00`000goo00@0
07ooOol000Yoo`007goo00<007ooOol0:Woo00<007ooOol00goo00@007ooOol0011oo`<001=oo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo1`006goo00<007ooOol00Woo00<007oo
Ool00goo00@007ooOol0029oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0029oo`04
001oogoo0002Ool00`00Oomoo`03Ool01000Oomoo`002Woo000OOol00`00Oomoo`0ZOol40003Ool2
000DOol3000?Ool20005Ool20004Ool20006Ool8000FOol20004Ool40003Ool2000TOol20004Ool2
0004Ool2000TOol20003Ool40003Ool2000;Ool001moo`03001oogoo04Yoo`D0029oo`X008moo`00
7goo00<007ooOol0Cgoo1`007goo3@00R7oo000OOol00`00Oomoo`1FOol7000MOolB001nOol001mo
o`03001oogoo05eoo`d001Moob@006Eoo`006Gooo`003`001Goo000OOol00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`03OomK0003Ool00`00Oomoo`05Ool001moo`03001oogoo02moo`03001oogoo02moo`03001o
ogoo031oo`03001oogoo02moo`03001oogoo02moo`03001oogoo00moo`007goo00<007ooOol0ogoo
2goo000OOol00`00Oomoo`3oOol;Ool00?moobeoo`00ogoo;Goo003oOol]Ool00<Qoo`<00004Ool0
0000001MOol00<]oo`03001oo`0005ioo`00KWoo0`000Woo1@0000Moo`00Ool007oo001oo`050000
0goo0000000300000goo000000030002Ool30002Ool50002Ool20004Ool40008Ool4000017oo0000
07oo0P000Woo100000=oo`0000000P000goo10000Woo00<007ooOol0Fgoo001]Ool01`00Oomoogoo
001oo`00009oo`0:001oogoo001oo`00Ool007oo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00D007ooOomoo`00009oo`05001oogooOol00004Ool20003Ool00`00Oomoo`09Ool00`00Oomo
o`03Ool01000Oomoo`000Woo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00009oo`03
001oogoo05]oo`00KGoo00<007ooOol00goo00@007ooOol0009oo`07001oo`00Ool007oo00000Woo
00<007ooOol00Woo00@007ooOomoo`@000=oo`03001oogoo00Aoo`06001oogooOol007oo0P000Woo
1@001goo1@0000Eoo`00Oomoo`00009oo`D0009oo`03001oogoo009oo`09001oogooOol007oo001o
o`0005aoo`00KGoo00L007ooOomoo`00Ool00002Ool02P00Oomoo`00Ool007oo001oo`000Woo00<0
07ooOol00Woo00<007ooOol017oo00D007ooOomoo`0000Ioo`05001oogooOol00002Ool01000Oomo
o`000goo00<007ooOol01Goo00L007ooOomoo`00Ool00002Ool01000Oomoo`000goo00<007ooOol0
0P000goo00T007ooOomoo`00Ool007oo0000G7oo001^Ool6000017oo000007oo200000=oo`000000
17oo00<007ooOol00Woo0`000Woo10000goo0P000Woo0P000Woo0P000Woo0`002Goo0`0000=oo`00
00000`000goo0`000Woo0P0000=oo`0000000Woo1P0000=oo`000000Fgoo0027Ool00`00Oomoo`08
Ool00`00Oomoo`2GOol008Eoo`<000Yoo`03001oogoo00Aoo`03001oogoo091oo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-31.4937, 0.909334, 0.996989, 
  0.000557385}},
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
The cumulative energy is related to the relative mean square error \
as we saw in the last example. \
\>", "Text",
  CellTags->{"S2.1.3", "3.33"}],

Cell[TextData[{
  "For example, this gives the error for the best basis wavelet packet \
transform with the compression ratio ",
  Cell[BoxData[
      \(TraditionalForm\`512/50 \[TildeTilde] 5\)], "InlineFormula",
    CellTags->"S2.1.3"],
  ". Although using the zero boundary condition introduces boundary effects, \
rendering the transformation not strictly \"norm\" preserving, this can be \
used, nevertheless, as a good estimate for the error."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.34"}],

Cell[CellGroupData[{

Cell["Sqrt[1-wpEnergy[[50]]]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(0.105082132608922473`\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
Here we compute the error for the wavelet transform with the same \
compression ratio. The wavelet packet transform using the best basis gives a \
smaller error, thus allowing better compression.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.35"}],

Cell[CellGroupData[{

Cell["Sqrt[1-wtEnergy[[50]]]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(0.230381384505784447`\)], "Output",
  CellLabel->"Out[23]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["A Speech Signal", "Subsubsection",
  CellTags->{"S2.1.3", "3.36"}],

Cell[TextData[{
  "In this next example we illustrate the use of wavelet packet transforms to \
analyze a speech signal. In the file ",
  StyleBox["m.dat", "MR"],
  " is the recorded sound of the word \"",
  StyleBox["Mathematica", "TI"],
  "\". The sound was recorded at a sampling rate of 8012 Hz. We will analyze \
this sound signal using wavelet and wavelet packet transforms."
}], "Text",
  CellTags->{"S2.1.3", "3.37"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.3", "3.38"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.3"],

Cell[TextData[{
  "This loads the package ",
  StyleBox["Miscellaneous`Audio`", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.39"}],

Cell["Needs[\"Miscellaneous`Audio`\"]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.3"],

Cell["This reads in the data.", "MathCaption",
  CellTags->{"S2.1.3", "3.40"}],

Cell["mdata = Get[ToFileName[{\"Wavelets\", \"Data\"},\"m.dat\"]];", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.3"],

Cell[TextData[{
  "There are ",
  Cell[BoxData[
      \(TraditionalForm\`7168 = 7\)], "InlineFormula",
    CellTags->"S2.1.3"],
  "x",
  Cell[BoxData[
      \(TraditionalForm\`2\^10\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " sample points."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.41"}],

Cell[CellGroupData[{

Cell["Length[mdata]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(7168\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "This list of numbers can be played to produce the sound \"",
  StyleBox["Mathematica", "TI"],
  "\" using ",
  StyleBox["ListPlay", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.42"}],

Cell[CellGroupData[{

Cell["ListPlay[mdata, SampleRate -> 8012, PlayRange -> All]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8012 7168 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
We use the least asymmetric filter of order 6 to do the wavelet \
transform.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.43"}],

Cell["\<\
(s6=LeastAsymmetricFilter[6];
wtdata = WaveletTransform[mdata, s6];)\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
The plot shows that the levels corresponding to low frequencies \
have very small wavelet coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.44"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[wtdata, PlotRange -> All,
Frame -> True];\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000265731 -0.0416304 1.03372e-06 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15668 -0.0125 -9 -9 ]
[.15668 -0.0125 9 0 ]
[.28954 -0.0125 -12 -9 ]
[.28954 -0.0125 12 0 ]
[.42241 -0.0125 -12 -9 ]
[.42241 -0.0125 12 0 ]
[.55527 -0.0125 -12 -9 ]
[.55527 -0.0125 12 0 ]
[.68814 -0.0125 -12 -9 ]
[.68814 -0.0125 12 0 ]
[.821 -0.0125 -12 -9 ]
[.821 -0.0125 12 0 ]
[.95387 -0.0125 -12 -9 ]
[.95387 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15668 0 m
.15668 .00625 L
s
[(500)] .15668 -0.0125 0 1 Mshowa
.28954 0 m
.28954 .00625 L
s
[(1000)] .28954 -0.0125 0 1 Mshowa
.42241 0 m
.42241 .00625 L
s
[(1500)] .42241 -0.0125 0 1 Mshowa
.55527 0 m
.55527 .00625 L
s
[(2000)] .55527 -0.0125 0 1 Mshowa
.68814 0 m
.68814 .00625 L
s
[(2500)] .68814 -0.0125 0 1 Mshowa
.821 0 m
.821 .00625 L
s
[(3000)] .821 -0.0125 0 1 Mshowa
.95387 0 m
.95387 .00625 L
s
[(3500)] .95387 -0.0125 0 1 Mshowa
.125 Mabswid
.05038 0 m
.05038 .00375 L
s
.07696 0 m
.07696 .00375 L
s
.10353 0 m
.10353 .00375 L
s
.1301 0 m
.1301 .00375 L
s
.18325 0 m
.18325 .00375 L
s
.20982 0 m
.20982 .00375 L
s
.23639 0 m
.23639 .00375 L
s
.26297 0 m
.26297 .00375 L
s
.31611 0 m
.31611 .00375 L
s
.34269 0 m
.34269 .00375 L
s
.36926 0 m
.36926 .00375 L
s
.39583 0 m
.39583 .00375 L
s
.44898 0 m
.44898 .00375 L
s
.47555 0 m
.47555 .00375 L
s
.50213 0 m
.50213 .00375 L
s
.5287 0 m
.5287 .00375 L
s
.58185 0 m
.58185 .00375 L
s
.60842 0 m
.60842 .00375 L
s
.63499 0 m
.63499 .00375 L
s
.66156 0 m
.66156 .00375 L
s
.71471 0 m
.71471 .00375 L
s
.74128 0 m
.74128 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.79443 0 m
.79443 .00375 L
s
.84758 0 m
.84758 .00375 L
s
.87415 0 m
.87415 .00375 L
s
.90072 0 m
.90072 .00375 L
s
.9273 0 m
.9273 .00375 L
s
.98044 0 m
.98044 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15668 .61178 m
.15668 .61803 L
s
.28954 .61178 m
.28954 .61803 L
s
.42241 .61178 m
.42241 .61803 L
s
.55527 .61178 m
.55527 .61803 L
s
.68814 .61178 m
.68814 .61803 L
s
.821 .61178 m
.821 .61803 L
s
.95387 .61178 m
.95387 .61803 L
s
.125 Mabswid
.05038 .61428 m
.05038 .61803 L
s
.07696 .61428 m
.07696 .61803 L
s
.10353 .61428 m
.10353 .61803 L
s
.1301 .61428 m
.1301 .61803 L
s
.18325 .61428 m
.18325 .61803 L
s
.20982 .61428 m
.20982 .61803 L
s
.23639 .61428 m
.23639 .61803 L
s
.26297 .61428 m
.26297 .61803 L
s
.31611 .61428 m
.31611 .61803 L
s
.34269 .61428 m
.34269 .61803 L
s
.36926 .61428 m
.36926 .61803 L
s
.39583 .61428 m
.39583 .61803 L
s
.44898 .61428 m
.44898 .61803 L
s
.47555 .61428 m
.47555 .61803 L
s
.50213 .61428 m
.50213 .61803 L
s
.5287 .61428 m
.5287 .61803 L
s
.58185 .61428 m
.58185 .61803 L
s
.60842 .61428 m
.60842 .61803 L
s
.63499 .61428 m
.63499 .61803 L
s
.66156 .61428 m
.66156 .61803 L
s
.71471 .61428 m
.71471 .61803 L
s
.74128 .61428 m
.74128 .61803 L
s
.76786 .61428 m
.76786 .61803 L
s
.79443 .61428 m
.79443 .61803 L
s
.84758 .61428 m
.84758 .61803 L
s
.87415 .61428 m
.87415 .61803 L
s
.90072 .61428 m
.90072 .61803 L
s
.9273 .61428 m
.9273 .61803 L
s
.98044 .61428 m
.98044 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .0161 m
.02381 .01472 L
s
.15986 .0161 m
.15986 .01473 L
s
.29592 .0161 m
.29592 .01477 L
s
.43197 .0161 m
.43197 .01476 L
s
.56803 .0161 m
.56803 .01475 L
s
.70408 .0161 m
.70408 .0148 L
s
.84014 .0161 m
.84014 .01474 L
s
.02381 .07383 m
.02381 .07376 L
s
.15986 .07383 m
.15986 .07384 L
s
.29592 .07383 m
.29592 .07374 L
s
.43197 .07383 m
.43197 .07371 L
s
.56803 .07383 m
.56803 .07382 L
s
.70408 .07383 m
.70408 .0739 L
s
.84014 .07383 m
.84014 .07382 L
s
.02381 .13156 m
.02381 .13157 L
s
.09184 .13156 m
.09184 .13143 L
s
.15986 .13156 m
.15986 .13154 L
s
.22789 .13156 m
.22789 .13155 L
s
.29592 .13156 m
.29592 .13159 L
s
.36395 .13156 m
.36395 .13155 L
s
.43197 .13156 m
.43197 .13157 L
s
.5 .13156 m
.5 .13158 L
s
.56803 .13156 m
.56803 .13148 L
s
.63605 .13156 m
.63605 .13155 L
s
.70408 .13156 m
.70408 .13159 L
s
.77211 .13156 m
.77211 .1316 L
s
.84014 .13156 m
.84014 .13152 L
s
.90816 .13156 m
.90816 .13152 L
s
.02381 .18929 m
.02381 .18928 L
s
.05782 .18929 m
.05782 .18933 L
s
.09184 .18929 m
.09184 .18928 L
s
.12585 .18929 m
.12585 .18904 L
s
.15986 .18929 m
.15986 .18938 L
s
.19388 .18929 m
.19388 .18933 L
s
.22789 .18929 m
.22789 .18928 L
s
.2619 .18929 m
.2619 .1893 L
s
.29592 .18929 m
.29592 .18925 L
s
.32993 .18929 m
.32993 .18915 L
s
.36395 .18929 m
.36395 .18932 L
s
.39796 .18929 m
.39796 .18928 L
s
.43197 .18929 m
.43197 .18929 L
s
.46599 .18929 m
.46599 .18932 L
s
.5 .18929 m
.5 .18916 L
s
.53401 .18929 m
.53401 .18935 L
s
.56803 .18929 m
.56803 .18909 L
s
.60204 .18929 m
.60204 .18941 L
s
.63605 .18929 m
.63605 .18929 L
s
.67007 .18929 m
.67007 .18922 L
s
.70408 .18929 m
.70408 .1893 L
s
.7381 .18929 m
.7381 .18928 L
s
.77211 .18929 m
.77211 .1893 L
s
.80612 .18929 m
.80612 .18925 L
s
.84014 .18929 m
.84014 .18933 L
s
.87415 .18929 m
.87415 .18924 L
s
.90816 .18929 m
.90816 .1893 L
s
.94218 .18929 m
.94218 .18923 L
s
.02381 .24702 m
.02381 .24697 L
s
.04082 .24702 m
.04082 .24702 L
s
.05782 .24702 m
.05782 .24703 L
s
.07483 .24702 m
.07483 .24713 L
s
.09184 .24702 m
.09184 .24711 L
s
.10884 .24702 m
.10884 .24698 L
s
.12585 .24702 m
.12585 .24709 L
s
.14286 .24702 m
.14286 .24685 L
s
.15986 .24702 m
.15986 .24668 L
s
.17687 .24702 m
.17687 .24705 L
s
.19388 .24702 m
.19388 .24707 L
s
.21088 .24702 m
.21088 .24701 L
s
.22789 .24702 m
.22789 .24713 L
s
.2449 .24702 m
.2449 .24719 L
s
.2619 .24702 m
.2619 .24718 L
s
.27891 .24702 m
.27891 .24705 L
s
.29592 .24702 m
.29592 .247 L
s
.31293 .24702 m
.31293 .24678 L
s
.32993 .24702 m
.32993 .24679 L
s
.34694 .24702 m
.34694 .24684 L
s
.36395 .24702 m
.36395 .24679 L
s
.38095 .24702 m
.38095 .24699 L
s
.39796 .24702 m
.39796 .24708 L
s
.41497 .24702 m
.41497 .24718 L
s
.43197 .24702 m
.43197 .24725 L
s
.44898 .24702 m
.44898 .24721 L
s
.46599 .24702 m
.46599 .24727 L
s
.48299 .24702 m
.48299 .24714 L
s
.5 .24702 m
.5 .24718 L
s
.51701 .24702 m
.51701 .24695 L
s
.53401 .24702 m
.53401 .24696 L
s
.55102 .24702 m
.55102 .24692 L
s
.56803 .24702 m
.56803 .24682 L
s
.58503 .24702 m
.58503 .24678 L
s
.60204 .24702 m
.60204 .24694 L
s
.61905 .24702 m
.61905 .2473 L
s
.63605 .24702 m
.63605 .24727 L
s
.65306 .24702 m
.65306 .24733 L
s
.67007 .24702 m
.67007 .24722 L
s
.68707 .24702 m
.68707 .24718 L
s
.70408 .24702 m
.70408 .24667 L
s
.72109 .24702 m
.72109 .24678 L
s
.7381 .24702 m
.7381 .24689 L
s
.7551 .24702 m
.7551 .24701 L
s
.77211 .24702 m
.77211 .24711 L
s
.78912 .24702 m
.78912 .2472 L
s
.80612 .24702 m
.80612 .24706 L
s
.82313 .24702 m
.82313 .24716 L
s
.84014 .24702 m
.84014 .24734 L
s
.85714 .24702 m
.85714 .24696 L
s
.87415 .24702 m
.87415 .2469 L
s
.89116 .24702 m
.89116 .24682 L
s
.90816 .24702 m
.90816 .24676 L
s
.92517 .24702 m
.92517 .24679 L
s
.94218 .24702 m
.94218 .24699 L
s
.95918 .24702 m
.95918 .24704 L
s
.02381 .30474 m
.02381 .30452 L
s
.03231 .30474 m
.03231 .30467 L
s
.04082 .30474 m
.04082 .30464 L
s
.04932 .30474 m
.04932 .30491 L
s
.05782 .30474 m
.05782 .30456 L
s
.06633 .30474 m
.06633 .3046 L
s
.07483 .30474 m
.07483 .3047 L
s
.08333 .30474 m
.08333 .30484 L
s
.09184 .30474 m
.09184 .3051 L
s
.10034 .30474 m
.10034 .30458 L
s
.10884 .30474 m
.10884 .30483 L
s
.11735 .30474 m
.11735 .30445 L
s
.12585 .30474 m
.12585 .30465 L
s
.13435 .30474 m
.13435 .30447 L
s
.14286 .30474 m
.14286 .30496 L
s
.15136 .30474 m
.15136 .30429 L
s
.15986 .30474 m
.15986 .3047 L
s
.16837 .30474 m
.16837 .30495 L
s
.17687 .30474 m
.17687 .30499 L
s
.18537 .30474 m
.18537 .3054 L
s
.19388 .30474 m
.19388 .30498 L
s
.20238 .30474 m
.20238 .30507 L
s
.21088 .30474 m
.21088 .30442 L
s
.21939 .30474 m
.21939 .30461 L
s
.22789 .30474 m
.22789 .30442 L
s
.23639 .30474 m
.23639 .30464 L
s
.2449 .30474 m
.2449 .3046 L
s
.2534 .30474 m
.2534 .30481 L
s
.2619 .30474 m
.2619 .30466 L
s
.27041 .30474 m
.27041 .30459 L
s
.27891 .30474 m
.27891 .30481 L
s
.28741 .30474 m
.28741 .30471 L
s
.29592 .30474 m
.29592 .30473 L
s
.30442 .30474 m
.30442 .3044 L
s
.31293 .30474 m
.31293 .30477 L
s
.32143 .30474 m
.32143 .30396 L
s
.32993 .30474 m
.32993 .30448 L
s
.33844 .30474 m
.33844 .30458 L
s
.34694 .30474 m
.34694 .30474 L
s
.35544 .30474 m
.35544 .30484 L
s
.36395 .30474 m
.36395 .30478 L
s
.37245 .30474 m
.37245 .30507 L
s
.38095 .30474 m
.38095 .30492 L
s
.38946 .30474 m
.38946 .30499 L
s
.39796 .30474 m
.39796 .30465 L
s
.40646 .30474 m
.40646 .30471 L
s
.41497 .30474 m
.41497 .30462 L
s
.42347 .30474 m
.42347 .30462 L
s
.43197 .30474 m
.43197 .3046 L
s
.44048 .30474 m
.44048 .3048 L
s
.44898 .30474 m
.44898 .30483 L
s
.45748 .30474 m
.45748 .30547 L
s
.46599 .30474 m
.46599 .30545 L
s
.47449 .30474 m
.47449 .30483 L
s
.48299 .30474 m
.48299 .30487 L
s
.4915 .30474 m
.4915 .30472 L
s
.5 .30474 m
.5 .30468 L
s
.5085 .30474 m
.5085 .30464 L
s
.51701 .30474 m
.51701 .30455 L
s
.52551 .30474 m
.52551 .3047 L
s
.53401 .30474 m
.53401 .30466 L
s
.54252 .30474 m
.54252 .30569 L
s
.55102 .30474 m
.55102 .30517 L
s
.55952 .30474 m
.55952 .30577 L
s
.56803 .30474 m
.56803 .30473 L
s
.57653 .30474 m
.57653 .3053 L
s
.58503 .30474 m
.58503 .30434 L
s
.59354 .30474 m
.59354 .30458 L
s
.60204 .30474 m
.60204 .30441 L
s
.61054 .30474 m
.61054 .30455 L
s
.61905 .30474 m
.61905 .30472 L
s
.62755 .30474 m
.62755 .30547 L
s
.63605 .30474 m
.63605 .30537 L
s
.64456 .30474 m
.64456 .30512 L
s
.65306 .30474 m
.65306 .30498 L
s
.66156 .30474 m
.66156 .30468 L
s
.67007 .30474 m
.67007 .30535 L
s
.67857 .30474 m
.67857 .30486 L
s
.68707 .30474 m
.68707 .30491 L
s
.69558 .30474 m
.69558 .304 L
s
.70408 .30474 m
.70408 .30382 L
s
.71259 .30474 m
.71259 .30415 L
s
.72109 .30474 m
.72109 .30458 L
s
.72959 .30474 m
.72959 .30475 L
s
.7381 .30474 m
.7381 .30471 L
s
.7466 .30474 m
.7466 .30498 L
s
.7551 .30474 m
.7551 .30469 L
s
.76361 .30474 m
.76361 .30481 L
s
.77211 .30474 m
.77211 .30436 L
s
.78061 .30474 m
.78061 .30484 L
s
.78912 .30474 m
.78912 .30447 L
s
.79762 .30474 m
.79762 .30431 L
s
.80612 .30474 m
.80612 .30445 L
s
.81463 .30474 m
.81463 .30466 L
s
.82313 .30474 m
.82313 .30483 L
s
.83163 .30474 m
.83163 .30485 L
s
.84014 .30474 m
.84014 .30468 L
s
.84864 .30474 m
.84864 .30456 L
s
.85714 .30474 m
.85714 .30452 L
s
.86565 .30474 m
.86565 .30467 L
s
.87415 .30474 m
.87415 .30525 L
s
.88265 .30474 m
.88265 .30518 L
s
.89116 .30474 m
.89116 .30517 L
s
.89966 .30474 m
.89966 .30437 L
s
.90816 .30474 m
.90816 .30445 L
s
.91667 .30474 m
.91667 .30468 L
s
.92517 .30474 m
.92517 .30461 L
s
.93367 .30474 m
.93367 .3049 L
s
.94218 .30474 m
.94218 .30459 L
s
.95068 .30474 m
.95068 .30484 L
s
.95918 .30474 m
.95918 .30434 L
s
.96769 .30474 m
.96769 .30447 L
s
.02381 .36247 m
.02381 .36282 L
s
.02806 .36247 m
.02806 .3633 L
s
.03231 .36247 m
.03231 .36209 L
s
.03656 .36247 m
.03656 .35601 L
s
.04082 .36247 m
.04082 .35063 L
s
.04507 .36247 m
.04507 .34909 L
s
.04932 .36247 m
.04932 .35006 L
s
.05357 .36247 m
.05357 .353 L
s
.05782 .36247 m
.05782 .35599 L
s
.06207 .36247 m
.06207 .35818 L
s
.06633 .36247 m
.06633 .35914 L
s
.07058 .36247 m
.07058 .35864 L
s
.07483 .36247 m
.07483 .35638 L
s
.07908 .36247 m
.07908 .35592 L
s
.08333 .36247 m
.08333 .35693 L
s
.08759 .36247 m
.08759 .35966 L
s
.09184 .36247 m
.09184 .36051 L
s
.09609 .36247 m
.09609 .36012 L
s
.10034 .36247 m
.10034 .35952 L
s
.10459 .36247 m
.10459 .35574 L
s
.10884 .36247 m
.10884 .34888 L
s
.1131 .36247 m
.1131 .34444 L
s
.11735 .36247 m
.11735 .34146 L
s
.1216 .36247 m
.1216 .33881 L
s
.12585 .36247 m
.12585 .34096 L
s
.1301 .36247 m
.1301 .34422 L
s
.13435 .36247 m
.13435 .34734 L
s
.13861 .36247 m
.13861 .34906 L
s
.14286 .36247 m
.14286 .34974 L
s
.14711 .36247 m
.14711 .35074 L
s
.15136 .36247 m
.15136 .35127 L
s
.15561 .36247 m
.15561 .35203 L
s
.15986 .36247 m
.15986 .3533 L
s
.16412 .36247 m
.16412 .35439 L
s
.16837 .36247 m
.16837 .35592 L
s
.17262 .36247 m
.17262 .35955 L
s
.17687 .36247 m
.17687 .363 L
s
.18112 .36247 m
.18112 .36596 L
s
.18537 .36247 m
.18537 .36958 L
s
.18963 .36247 m
.18963 .37626 L
s
.19388 .36247 m
.19388 .37624 L
s
.19813 .36247 m
.19813 .36381 L
s
.20238 .36247 m
.20238 .35118 L
s
.20663 .36247 m
.20663 .34956 L
s
.21088 .36247 m
.21088 .35578 L
s
.21514 .36247 m
.21514 .3631 L
s
.21939 .36247 m
.21939 .36606 L
s
.22364 .36247 m
.22364 .36539 L
s
.22789 .36247 m
.22789 .36254 L
s
.23214 .36247 m
.23214 .36196 L
s
.23639 .36247 m
.23639 .36189 L
s
.24065 .36247 m
.24065 .36129 L
s
.2449 .36247 m
.2449 .36005 L
s
.24915 .36247 m
.24915 .36085 L
s
.2534 .36247 m
.2534 .36137 L
s
.25765 .36247 m
.25765 .36276 L
s
.2619 .36247 m
.2619 .36358 L
s
.26616 .36247 m
.26616 .36385 L
s
.27041 .36247 m
.27041 .36339 L
s
.27466 .36247 m
.27466 .36319 L
s
.27891 .36247 m
.27891 .36265 L
s
.28316 .36247 m
.28316 .3629 L
s
.28741 .36247 m
.28741 .36286 L
s
.29167 .36247 m
.29167 .36293 L
s
.29592 .36247 m
.29592 .36296 L
s
.30017 .36247 m
.30017 .36186 L
s
.30442 .36247 m
.30442 .36225 L
s
.30867 .36247 m
.30867 .3623 L
s
.31293 .36247 m
.31293 .36188 L
s
.31718 .36247 m
.31718 .3617 L
s
.32143 .36247 m
.32143 .36185 L
s
.32568 .36247 m
.32568 .3575 L
s
.32993 .36247 m
.32993 .35389 L
s
.33418 .36247 m
.33418 .3557 L
s
.33844 .36247 m
.33844 .35936 L
s
.34269 .36247 m
.34269 .36363 L
s
.34694 .36247 m
.34694 .36684 L
s
.35119 .36247 m
.35119 .36921 L
s
.35544 .36247 m
.35544 .37024 L
s
.35969 .36247 m
.35969 .37163 L
s
.36395 .36247 m
.36395 .37147 L
s
.3682 .36247 m
.3682 .36909 L
s
.37245 .36247 m
.37245 .36338 L
s
.3767 .36247 m
.3767 .35795 L
s
.38095 .36247 m
.38095 .35193 L
s
.3852 .36247 m
.3852 .34655 L
s
.38946 .36247 m
.38946 .34677 L
s
.39371 .36247 m
.39371 .35348 L
s
.39796 .36247 m
.39796 .36577 L
s
.40221 .36247 m
.40221 .37915 L
s
.40646 .36247 m
.40646 .3894 L
s
.41071 .36247 m
.41071 .39082 L
s
.41497 .36247 m
.41497 .38479 L
s
.41922 .36247 m
.41922 .37434 L
s
.42347 .36247 m
.42347 .36355 L
s
.42772 .36247 m
.42772 .35476 L
s
.43197 .36247 m
.43197 .34825 L
s
.43622 .36247 m
.43622 .3456 L
s
.44048 .36247 m
.44048 .34485 L
s
.44473 .36247 m
.44473 .34567 L
s
.44898 .36247 m
.44898 .34571 L
s
.45323 .36247 m
.45323 .34553 L
s
.45748 .36247 m
.45748 .3455 L
s
.46173 .36247 m
.46173 .35325 L
s
.46599 .36247 m
.46599 .35622 L
s
.47024 .36247 m
.47024 .35648 L
s
.47449 .36247 m
.47449 .35727 L
s
.47874 .36247 m
.47874 .3565 L
s
.48299 .36247 m
.48299 .35712 L
s
.48724 .36247 m
.48724 .35694 L
s
.4915 .36247 m
.4915 .35718 L
s
.49575 .36247 m
.49575 .35651 L
s
.5 .36247 m
.5 .3577 L
s
.50425 .36247 m
.50425 .35884 L
s
.5085 .36247 m
.5085 .36127 L
s
.51276 .36247 m
.51276 .36463 L
s
.51701 .36247 m
.51701 .36895 L
s
.52126 .36247 m
.52126 .37412 L
s
.52551 .36247 m
.52551 .37714 L
s
.52976 .36247 m
.52976 .37673 L
s
.53401 .36247 m
.53401 .36865 L
s
.53827 .36247 m
.53827 .35935 L
s
.54252 .36247 m
.54252 .3541 L
s
.54677 .36247 m
.54677 .35904 L
s
.55102 .36247 m
.55102 .36736 L
s
.55527 .36247 m
.55527 .36905 L
s
.55952 .36247 m
.55952 .36367 L
s
.56378 .36247 m
.56378 .36152 L
s
.56803 .36247 m
.56803 .36446 L
s
.57228 .36247 m
.57228 .3641 L
s
.57653 .36247 m
.57653 .36164 L
s
.58078 .36247 m
.58078 .3586 L
s
.58503 .36247 m
.58503 .35933 L
s
.58929 .36247 m
.58929 .36118 L
s
.59354 .36247 m
.59354 .36311 L
s
.59779 .36247 m
.59779 .36289 L
s
.60204 .36247 m
.60204 .36209 L
s
.60629 .36247 m
.60629 .36238 L
s
.61054 .36247 m
.61054 .36285 L
s
.6148 .36247 m
.6148 .36402 L
s
.61905 .36247 m
.61905 .36295 L
s
.6233 .36247 m
.6233 .36256 L
s
.62755 .36247 m
.62755 .3612 L
s
.6318 .36247 m
.6318 .36143 L
s
.63605 .36247 m
.63605 .36211 L
s
.64031 .36247 m
.64031 .36389 L
s
.64456 .36247 m
.64456 .36823 L
s
.64881 .36247 m
.64881 .3704 L
s
.65306 .36247 m
.65306 .35963 L
s
.65731 .36247 m
.65731 .34773 L
s
.66156 .36247 m
.66156 .35379 L
s
.66582 .36247 m
.66582 .37209 L
s
.67007 .36247 m
.67007 .37893 L
s
.67432 .36247 m
.67432 .3772 L
s
.67857 .36247 m
.67857 .37831 L
s
.68282 .36247 m
.68282 .37792 L
s
.68707 .36247 m
.68707 .37139 L
s
.69133 .36247 m
.69133 .36005 L
s
.69558 .36247 m
.69558 .35227 L
s
.69983 .36247 m
.69983 .35394 L
s
.70408 .36247 m
.70408 .36364 L
s
.70833 .36247 m
.70833 .36998 L
s
.71259 .36247 m
.71259 .36695 L
s
.71684 .36247 m
.71684 .36099 L
s
.72109 .36247 m
.72109 .35802 L
s
.72534 .36247 m
.72534 .36134 L
s
.72959 .36247 m
.72959 .36548 L
s
.73384 .36247 m
.73384 .36581 L
s
.7381 .36247 m
.7381 .36413 L
s
.74235 .36247 m
.74235 .36125 L
s
.7466 .36247 m
.7466 .36066 L
s
.75085 .36247 m
.75085 .36226 L
s
.7551 .36247 m
.7551 .3636 L
s
.75935 .36247 m
.75935 .36308 L
s
.76361 .36247 m
.76361 .36257 L
s
.76786 .36247 m
.76786 .36174 L
s
.77211 .36247 m
.77211 .36199 L
s
.77636 .36247 m
.77636 .36239 L
s
.78061 .36247 m
.78061 .3629 L
s
.78486 .36247 m
.78486 .36274 L
s
.78912 .36247 m
.78912 .3632 L
s
.79337 .36247 m
.79337 .36324 L
s
.79762 .36247 m
.79762 .36292 L
s
.80187 .36247 m
.80187 .36318 L
s
.80612 .36247 m
.80612 .36109 L
s
.81037 .36247 m
.81037 .3629 L
s
.81463 .36247 m
.81463 .35969 L
s
.81888 .36247 m
.81888 .3542 L
s
.82313 .36247 m
.82313 .34902 L
s
.82738 .36247 m
.82738 .35093 L
s
.83163 .36247 m
.83163 .36137 L
s
.83588 .36247 m
.83588 .37371 L
s
.84014 .36247 m
.84014 .37502 L
s
.84439 .36247 m
.84439 .36306 L
s
.84864 .36247 m
.84864 .35144 L
s
.85289 .36247 m
.85289 .35346 L
s
.85714 .36247 m
.85714 .36201 L
s
.86139 .36247 m
.86139 .36563 L
s
.86565 .36247 m
.86565 .3626 L
s
.8699 .36247 m
.8699 .36216 L
s
.87415 .36247 m
.87415 .36301 L
s
.8784 .36247 m
.8784 .36405 L
s
.88265 .36247 m
.88265 .36327 L
s
.8869 .36247 m
.8869 .3607 L
s
.89116 .36247 m
.89116 .35961 L
s
.89541 .36247 m
.89541 .35812 L
s
.89966 .36247 m
.89966 .36294 L
s
.90391 .36247 m
.90391 .36264 L
s
.90816 .36247 m
.90816 .36316 L
s
.91241 .36247 m
.91241 .3624 L
s
.91667 .36247 m
.91667 .36245 L
s
.92092 .36247 m
.92092 .36162 L
s
.92517 .36247 m
.92517 .36246 L
s
.92942 .36247 m
.92942 .36272 L
s
.93367 .36247 m
.93367 .36307 L
s
.93793 .36247 m
.93793 .36225 L
s
.94218 .36247 m
.94218 .36233 L
s
.94643 .36247 m
.94643 .36225 L
s
.95068 .36247 m
.95068 .36217 L
s
.95493 .36247 m
.95493 .36194 L
s
.95918 .36247 m
.95918 .36246 L
s
.96344 .36247 m
.96344 .36189 L
s
.96769 .36247 m
.96769 .36176 L
s
.97194 .36247 m
.97194 .36211 L
s
.02381 .4202 m
.02381 .42004 L
s
.02594 .4202 m
.02594 .42072 L
s
.02806 .4202 m
.02806 .4203 L
s
.03019 .4202 m
.03019 .42047 L
s
.03231 .4202 m
.03231 .421 L
s
.03444 .4202 m
.03444 .4155 L
s
.03656 .4202 m
.03656 .42882 L
s
.03869 .4202 m
.03869 .41451 L
s
.04082 .4202 m
.04082 .42816 L
s
.04294 .4202 m
.04294 .41554 L
s
.04507 .4202 m
.04507 .42641 L
s
.04719 .4202 m
.04719 .41148 L
s
.04932 .4202 m
.04932 .429 L
s
.05145 .4202 m
.05145 .40771 L
s
.05357 .4202 m
.05357 .42977 L
s
.0557 .4202 m
.0557 .40578 L
s
.05782 .4202 m
.05782 .4304 L
s
.05995 .4202 m
.05995 .40432 L
s
.06207 .4202 m
.06207 .43081 L
s
.0642 .4202 m
.0642 .404 L
s
.06633 .4202 m
.06633 .43242 L
s
.06845 .4202 m
.06845 .40214 L
s
.07058 .4202 m
.07058 .43474 L
s
.0727 .4202 m
.0727 .3978 L
s
.07483 .4202 m
.07483 .43758 L
s
.07696 .4202 m
.07696 .39282 L
s
.07908 .4202 m
.07908 .43813 L
s
.08121 .4202 m
.08121 .39435 L
s
.08333 .4202 m
.08333 .43987 L
s
.08546 .4202 m
.08546 .39349 L
s
.08759 .4202 m
.08759 .44061 L
s
.08971 .4202 m
.08971 .39353 L
s
.09184 .4202 m
.09184 .44293 L
s
.09396 .4202 m
.09396 .39362 L
s
.09609 .4202 m
.09609 .44411 L
s
.09821 .4202 m
.09821 .39249 L
s
.10034 .4202 m
.10034 .44405 L
s
.10247 .4202 m
.10247 .39246 L
s
.10459 .4202 m
.10459 .44737 L
s
.10672 .4202 m
.10672 .39134 L
s
.10884 .4202 m
.10884 .44836 L
s
.11097 .4202 m
.11097 .41691 L
s
.1131 .4202 m
.1131 .43177 L
s
.11522 .4202 m
.11522 .4078 L
s
.11735 .4202 m
.11735 .43306 L
s
.11947 .4202 m
.11947 .41466 L
s
.1216 .4202 m
.1216 .43041 L
s
.12372 .4202 m
.12372 .41172 L
s
.12585 .4202 m
.12585 .42747 L
s
.12798 .4202 m
.12798 .41748 L
s
.1301 .4202 m
.1301 .42868 L
s
.13223 .4202 m
.13223 .41783 L
s
.13435 .4202 m
.13435 .42407 L
s
.13648 .4202 m
.13648 .41543 L
s
.13861 .4202 m
.13861 .42422 L
s
.14073 .4202 m
.14073 .41604 L
s
.14286 .4202 m
.14286 .42387 L
s
.14498 .4202 m
.14498 .41369 L
s
.14711 .4202 m
.14711 .42249 L
s
.14923 .4202 m
.14923 .41575 L
s
.15136 .4202 m
.15136 .4239 L
s
.15349 .4202 m
.15349 .41615 L
s
.15561 .4202 m
.15561 .4235 L
s
.15774 .4202 m
.15774 .41718 L
s
.15986 .4202 m
.15986 .42371 L
s
.16199 .4202 m
.16199 .41718 L
s
.16412 .4202 m
.16412 .42488 L
s
.16624 .4202 m
.16624 .41881 L
s
.16837 .4202 m
.16837 .42534 L
s
.17049 .4202 m
.17049 .42017 L
s
.17262 .4202 m
.17262 .42536 L
s
.17474 .4202 m
.17474 .41973 L
s
.17687 .4202 m
.17687 .42576 L
s
.179 .4202 m
.179 .41512 L
s
.18112 .4202 m
.18112 .42535 L
s
.18325 .4202 m
.18325 .41214 L
s
.18537 .4202 m
.18537 .42206 L
s
.1875 .4202 m
.1875 .41032 L
s
.18963 .4202 m
.18963 .42021 L
s
.19175 .4202 m
.19175 .4239 L
s
.19388 .4202 m
.19388 .4184 L
s
.196 .4202 m
.196 .41949 L
s
.19813 .4202 m
.19813 .41533 L
s
.20026 .4202 m
.20026 .42724 L
s
.20238 .4202 m
.20238 .41748 L
s
.20451 .4202 m
.20451 .42173 L
s
.20663 .4202 m
.20663 .41818 L
s
.20876 .4202 m
.20876 .41785 L
s
.21088 .4202 m
.21088 .42336 L
s
.21301 .4202 m
.21301 .41653 L
s
.21514 .4202 m
.21514 .42577 L
s
.21726 .4202 m
.21726 .41794 L
s
.21939 .4202 m
.21939 .42384 L
s
.22151 .4202 m
.22151 .4198 L
s
.22364 .4202 m
.22364 .42138 L
s
.22577 .4202 m
.22577 .41936 L
s
.22789 .4202 m
.22789 .42003 L
s
.23002 .4202 m
.23002 .41954 L
s
.23214 .4202 m
.23214 .42073 L
s
.23427 .4202 m
.23427 .41913 L
s
.23639 .4202 m
.23639 .4196 L
s
.23852 .4202 m
.23852 .41856 L
s
.24065 .4202 m
.24065 .42017 L
s
.24277 .4202 m
.24277 .41888 L
s
.2449 .4202 m
.2449 .42009 L
s
.24702 .4202 m
.24702 .41914 L
s
.24915 .4202 m
.24915 .42059 L
s
.25128 .4202 m
.25128 .41952 L
s
.2534 .4202 m
.2534 .42087 L
s
.25553 .4202 m
.25553 .42055 L
s
.25765 .4202 m
.25765 .42099 L
s
.25978 .4202 m
.25978 .41995 L
s
.2619 .4202 m
.2619 .42072 L
s
.26403 .4202 m
.26403 .42005 L
s
.26616 .4202 m
.26616 .42018 L
s
.26828 .4202 m
.26828 .4202 L
s
.27041 .4202 m
.27041 .41971 L
s
.27253 .4202 m
.27253 .42047 L
s
.27466 .4202 m
.27466 .41912 L
s
.27679 .4202 m
.27679 .42055 L
s
.27891 .4202 m
.27891 .42007 L
s
.28104 .4202 m
.28104 .42078 L
s
.28316 .4202 m
.28316 .42059 L
s
.28529 .4202 m
.28529 .42045 L
s
.28741 .4202 m
.28741 .42064 L
s
.28954 .4202 m
.28954 .41968 L
s
.29167 .4202 m
.29167 .42074 L
s
.29379 .4202 m
.29379 .4196 L
s
.29592 .4202 m
.29592 .42016 L
s
.29804 .4202 m
.29804 .42011 L
s
.30017 .4202 m
.30017 .42018 L
s
.3023 .4202 m
.3023 .42003 L
s
.30442 .4202 m
.30442 .42014 L
s
.30655 .4202 m
.30655 .42054 L
s
.30867 .4202 m
.30867 .41984 L
s
.3108 .4202 m
.3108 .42019 L
s
.31293 .4202 m
.31293 .42026 L
s
.31505 .4202 m
.31505 .41999 L
s
.31718 .4202 m
.31718 .42157 L
s
.3193 .4202 m
.3193 .42034 L
s
.32143 .4202 m
.32143 .41899 L
s
.32355 .4202 m
.32355 .41729 L
s
.32568 .4202 m
.32568 .43198 L
s
.32781 .4202 m
.32781 .41233 L
s
.32993 .4202 m
.32993 .43135 L
s
.33206 .4202 m
.33206 .42151 L
s
.33418 .4202 m
.33418 .43198 L
s
.33631 .4202 m
.33631 .41753 L
s
.33844 .4202 m
.33844 .43077 L
s
.34056 .4202 m
.34056 .41513 L
s
.34269 .4202 m
.34269 .4297 L
s
.34481 .4202 m
.34481 .41518 L
s
.34694 .4202 m
.34694 .42627 L
s
.34906 .4202 m
.34906 .41196 L
s
.35119 .4202 m
.35119 .42058 L
s
.35332 .4202 m
.35332 .41129 L
s
.35544 .4202 m
.35544 .41524 L
s
.35757 .4202 m
.35757 .41519 L
s
.35969 .4202 m
.35969 .41237 L
s
.36182 .4202 m
.36182 .4193 L
s
.36395 .4202 m
.36395 .41509 L
s
.36607 .4202 m
.36607 .42526 L
s
.3682 .4202 m
.3682 .41853 L
s
.37032 .4202 m
.37032 .428 L
s
.37245 .4202 m
.37245 .42117 L
s
.37457 .4202 m
.37457 .42908 L
s
.3767 .4202 m
.3767 .41341 L
s
.37883 .4202 m
.37883 .42113 L
s
.38095 .4202 m
.38095 .40871 L
s
.38308 .4202 m
.38308 .41853 L
s
.3852 .4202 m
.3852 .42524 L
s
.38733 .4202 m
.38733 .42788 L
s
.38946 .4202 m
.38946 .42853 L
s
.39158 .4202 m
.39158 .412 L
s
.39371 .4202 m
.39371 .42658 L
s
.39583 .4202 m
.39583 .40652 L
s
.39796 .4202 m
.39796 .42996 L
s
.40009 .4202 m
.40009 .4085 L
s
.40221 .4202 m
.40221 .42955 L
s
.40434 .4202 m
.40434 .41417 L
s
.40646 .4202 m
.40646 .42887 L
s
.40859 .4202 m
.40859 .42224 L
s
.41071 .4202 m
.41071 .42573 L
s
.41284 .4202 m
.41284 .42667 L
s
.41497 .4202 m
.41497 .41511 L
s
.41709 .4202 m
.41709 .42603 L
s
.41922 .4202 m
.41922 .4032 L
s
.42134 .4202 m
.42134 .42559 L
s
.42347 .4202 m
.42347 .40001 L
s
.4256 .4202 m
.4256 .42875 L
s
.42772 .4202 m
.42772 .40509 L
s
.42985 .4202 m
.42985 .43112 L
s
.43197 .4202 m
.43197 .41134 L
s
.4341 .4202 m
.4341 .43139 L
s
.43622 .4202 m
.43622 .41539 L
s
.43835 .4202 m
.43835 .42896 L
s
.44048 .4202 m
.44048 .41633 L
s
.4426 .4202 m
.4426 .42654 L
s
.44473 .4202 m
.44473 .41789 L
s
.44685 .4202 m
.44685 .4261 L
s
.44898 .4202 m
.44898 .4209 L
s
.45111 .4202 m
.45111 .42788 L
s
.45323 .4202 m
.45323 .42384 L
s
.45536 .4202 m
.45536 .42851 L
s
.45748 .4202 m
.45748 .42377 L
s
.45961 .4202 m
.45961 .42681 L
s
.46173 .4202 m
.46173 .4007 L
s
.46386 .4202 m
.46386 .43032 L
s
.46599 .4202 m
.46599 .42633 L
s
.46811 .4202 m
.46811 .43042 L
s
.47024 .4202 m
.47024 .4131 L
s
.47236 .4202 m
.47236 .42297 L
s
.47449 .4202 m
.47449 .41304 L
s
.47662 .4202 m
.47662 .42701 L
s
.47874 .4202 m
.47874 .41398 L
s
.48087 .4202 m
.48087 .42277 L
s
.48299 .4202 m
.48299 .40935 L
s
.48512 .4202 m
.48512 .41989 L
s
.48724 .4202 m
.48724 .41285 L
s
.48937 .4202 m
.48937 .42222 L
s
.4915 .4202 m
.4915 .41333 L
s
.49362 .4202 m
.49362 .42481 L
s
.49575 .4202 m
.49575 .41454 L
s
.49787 .4202 m
.49787 .42937 L
s
.5 .4202 m
.5 .4141 L
s
.50213 .4202 m
.50213 .43199 L
s
.50425 .4202 m
.50425 .41502 L
s
.50638 .4202 m
.50638 .43628 L
s
.5085 .4202 m
.5085 .41404 L
s
.51063 .4202 m
.51063 .43665 L
s
.51276 .4202 m
.51276 .41045 L
s
.51488 .4202 m
.51488 .43567 L
s
.51701 .4202 m
.51701 .40846 L
s
.51913 .4202 m
.51913 .43299 L
s
.52126 .4202 m
.52126 .40677 L
s
.52338 .4202 m
.52338 .42397 L
s
.52551 .4202 m
.52551 .40954 L
s
.52764 .4202 m
.52764 .41803 L
s
.52976 .4202 m
.52976 .4252 L
s
.53189 .4202 m
.53189 .41828 L
s
.53401 .4202 m
.53401 .44239 L
s
.53614 .4202 m
.53614 .41336 L
s
.53827 .4202 m
.53827 .43178 L
s
.54039 .4202 m
.54039 .40149 L
s
.54252 .4202 m
.54252 .41189 L
s
.54464 .4202 m
.54464 .41777 L
s
.54677 .4202 m
.54677 .41894 L
s
.54889 .4202 m
.54889 .44767 L
s
.55102 .4202 m
.55102 .41759 L
s
.55315 .4202 m
.55315 .41993 L
s
.55527 .4202 m
.55527 .41664 L
s
.5574 .4202 m
.5574 .40779 L
s
.55952 .4202 m
.55952 .43125 L
s
.56165 .4202 m
.56165 .40757 L
s
.56378 .4202 m
.56378 .42732 L
s
.5659 .4202 m
.5659 .42755 L
s
.56803 .4202 m
.56803 .42286 L
s
.57015 .4202 m
.57015 .41882 L
s
.57228 .4202 m
.57228 .41867 L
s
.5744 .4202 m
.5744 .41609 L
s
.57653 .4202 m
.57653 .42615 L
s
.57866 .4202 m
.57866 .41728 L
s
.58078 .4202 m
.58078 .41986 L
s
.58291 .4202 m
.58291 .4191 L
s
.58503 .4202 m
.58503 .41781 L
s
.58716 .4202 m
.58716 .42446 L
s
.58929 .4202 m
.58929 .41819 L
s
.59141 .4202 m
.59141 .42256 L
s
.59354 .4202 m
.59354 .419 L
s
.59566 .4202 m
.59566 .41997 L
s
.59779 .4202 m
.59779 .42112 L
s
.59991 .4202 m
.59991 .41876 L
s
.60204 .4202 m
.60204 .42136 L
s
.60417 .4202 m
.60417 .42108 L
s
.60629 .4202 m
.60629 .42112 L
s
.60842 .4202 m
.60842 .42191 L
s
.61054 .4202 m
.61054 .41803 L
s
.61267 .4202 m
.61267 .41975 L
s
.6148 .4202 m
.6148 .41925 L
s
.61692 .4202 m
.61692 .41877 L
s
.61905 .4202 m
.61905 .42222 L
s
.62117 .4202 m
.62117 .4191 L
s
.6233 .4202 m
.6233 .42209 L
s
.62543 .4202 m
.62543 .41801 L
s
.62755 .4202 m
.62755 .41934 L
s
.62968 .4202 m
.62968 .41952 L
s
.6318 .4202 m
.6318 .42092 L
s
.63393 .4202 m
.63393 .41986 L
s
.63605 .4202 m
.63605 .4195 L
s
.63818 .4202 m
.63818 .42298 L
s
.64031 .4202 m
.64031 .41978 L
s
.64243 .4202 m
.64243 .42042 L
s
.64456 .4202 m
.64456 .41535 L
s
.64668 .4202 m
.64668 .42529 L
s
.64881 .4202 m
.64881 .42204 L
s
.65094 .4202 m
.65094 .40508 L
s
.65306 .4202 m
.65306 .44122 L
s
.65519 .4202 m
.65519 .39987 L
s
.65731 .4202 m
.65731 .43292 L
s
.65944 .4202 m
.65944 .42502 L
s
.66156 .4202 m
.66156 .40065 L
s
.66369 .4202 m
.66369 .44763 L
s
.66582 .4202 m
.66582 .39281 L
s
.66794 .4202 m
.66794 .43541 L
s
.67007 .4202 m
.67007 .42147 L
s
.67219 .4202 m
.67219 .41486 L
s
.67432 .4202 m
.67432 .43077 L
s
.67645 .4202 m
.67645 .43063 L
s
.67857 .4202 m
.67857 .42522 L
s
.6807 .4202 m
.6807 .43348 L
s
.68282 .4202 m
.68282 .41666 L
s
.68495 .4202 m
.68495 .42469 L
s
.68707 .4202 m
.68707 .41235 L
s
.6892 .4202 m
.6892 .40888 L
s
.69133 .4202 m
.69133 .41285 L
s
.69345 .4202 m
.69345 .41289 L
s
.69558 .4202 m
.69558 .43503 L
s
.6977 .4202 m
.6977 .42535 L
s
.69983 .4202 m
.69983 .4254 L
s
.70196 .4202 m
.70196 .40736 L
s
.70408 .4202 m
.70408 .41737 L
s
.70621 .4202 m
.70621 .42508 L
s
.70833 .4202 m
.70833 .43305 L
s
.71046 .4202 m
.71046 .4111 L
s
.71259 .4202 m
.71259 .40428 L
s
.71471 .4202 m
.71471 .41889 L
s
.71684 .4202 m
.71684 .42736 L
s
.71896 .4202 m
.71896 .41943 L
s
.72109 .4202 m
.72109 .4179 L
s
.72321 .4202 m
.72321 .42372 L
s
.72534 .4202 m
.72534 .42447 L
s
.72747 .4202 m
.72747 .4206 L
s
.72959 .4202 m
.72959 .42 L
s
.73172 .4202 m
.73172 .41936 L
s
.73384 .4202 m
.73384 .42063 L
s
.73597 .4202 m
.73597 .4216 L
s
.7381 .4202 m
.7381 .42319 L
s
.74022 .4202 m
.74022 .42015 L
s
.74235 .4202 m
.74235 .42197 L
s
.74447 .4202 m
.74447 .41852 L
s
.7466 .4202 m
.7466 .42251 L
s
.74872 .4202 m
.74872 .41941 L
s
.75085 .4202 m
.75085 .4181 L
s
.75298 .4202 m
.75298 .41932 L
s
.7551 .4202 m
.7551 .41895 L
s
.75723 .4202 m
.75723 .4205 L
s
.75935 .4202 m
.75935 .41971 L
s
.76148 .4202 m
.76148 .42108 L
s
.76361 .4202 m
.76361 .421 L
s
.76573 .4202 m
.76573 .41944 L
s
.76786 .4202 m
.76786 .41993 L
s
.76998 .4202 m
.76998 .42076 L
s
.77211 .4202 m
.77211 .42098 L
s
.77423 .4202 m
.77423 .421 L
s
.77636 .4202 m
.77636 .42041 L
s
.77849 .4202 m
.77849 .41954 L
s
.78061 .4202 m
.78061 .41909 L
s
.78274 .4202 m
.78274 .41957 L
s
.78486 .4202 m
.78486 .4194 L
s
.78699 .4202 m
.78699 .42049 L
s
.78912 .4202 m
.78912 .42004 L
s
.79124 .4202 m
.79124 .42093 L
s
.79337 .4202 m
.79337 .41949 L
s
.79549 .4202 m
.79549 .42179 L
s
.79762 .4202 m
.79762 .42008 L
s
.79974 .4202 m
.79974 .42245 L
s
.80187 .4202 m
.80187 .42434 L
s
.804 .4202 m
.804 .41884 L
s
.80612 .4202 m
.80612 .41831 L
s
.80825 .4202 m
.80825 .42118 L
s
.81037 .4202 m
.81037 .42011 L
s
.8125 .4202 m
.8125 .41815 L
s
.81463 .4202 m
.81463 .42048 L
s
.81675 .4202 m
.81675 .42 L
s
.81888 .4202 m
.81888 .42424 L
s
.821 .4202 m
.821 .41999 L
s
.82313 .4202 m
.82313 .42625 L
s
.82526 .4202 m
.82526 .41696 L
s
.82738 .4202 m
.82738 .42627 L
s
.82951 .4202 m
.82951 .41445 L
s
.83163 .4202 m
.83163 .42945 L
s
.83376 .4202 m
.83376 .41135 L
s
.83588 .4202 m
.83588 .42025 L
s
.83801 .4202 m
.83801 .41211 L
s
.84014 .4202 m
.84014 .42313 L
s
.84226 .4202 m
.84226 .42968 L
s
.84439 .4202 m
.84439 .41192 L
s
.84651 .4202 m
.84651 .42207 L
s
.84864 .4202 m
.84864 .4192 L
s
.85077 .4202 m
.85077 .42522 L
s
.85289 .4202 m
.85289 .41405 L
s
.85502 .4202 m
.85502 .41588 L
s
.85714 .4202 m
.85714 .42586 L
s
.85927 .4202 m
.85927 .42628 L
s
.86139 .4202 m
.86139 .42106 L
s
.86352 .4202 m
.86352 .41801 L
s
.86565 .4202 m
.86565 .42465 L
s
.86777 .4202 m
.86777 .41724 L
s
.8699 .4202 m
.8699 .41728 L
s
.87202 .4202 m
.87202 .4252 L
s
.87415 .4202 m
.87415 .41914 L
s
.87628 .4202 m
.87628 .4181 L
s
.8784 .4202 m
.8784 .42328 L
s
.88053 .4202 m
.88053 .42011 L
s
.88265 .4202 m
.88265 .4235 L
s
.88478 .4202 m
.88478 .41869 L
s
.8869 .4202 m
.8869 .41638 L
s
.88903 .4202 m
.88903 .42489 L
s
.89116 .4202 m
.89116 .41949 L
s
.89328 .4202 m
.89328 .41785 L
s
.89541 .4202 m
.89541 .41674 L
s
.89753 .4202 m
.89753 .42349 L
s
.89966 .4202 m
.89966 .41838 L
s
.90179 .4202 m
.90179 .41699 L
s
.90391 .4202 m
.90391 .42166 L
s
.90604 .4202 m
.90604 .41962 L
s
.90816 .4202 m
.90816 .4181 L
s
.91029 .4202 m
.91029 .41854 L
s
.91241 .4202 m
.91241 .41855 L
s
.91454 .4202 m
.91454 .4249 L
s
.91667 .4202 m
.91667 .42008 L
s
.91879 .4202 m
.91879 .41962 L
s
.92092 .4202 m
.92092 .42025 L
s
.92304 .4202 m
.92304 .42013 L
s
.92517 .4202 m
.92517 .42097 L
s
.9273 .4202 m
.9273 .41965 L
s
.92942 .4202 m
.92942 .42093 L
s
.93155 .4202 m
.93155 .41996 L
s
.93367 .4202 m
.93367 .42039 L
s
.9358 .4202 m
.9358 .42068 L
s
.93793 .4202 m
.93793 .42028 L
s
.94005 .4202 m
.94005 .41976 L
s
.94218 .4202 m
.94218 .42007 L
s
.9443 .4202 m
.9443 .42014 L
s
.94643 .4202 m
.94643 .42027 L
s
.94855 .4202 m
.94855 .4199 L
s
.95068 .4202 m
.95068 .42016 L
s
.95281 .4202 m
.95281 .42052 L
s
.95493 .4202 m
.95493 .42061 L
s
.95706 .4202 m
.95706 .4202 L
s
.95918 .4202 m
.95918 .41947 L
s
.96131 .4202 m
.96131 .42085 L
s
.96344 .4202 m
.96344 .42015 L
s
.96556 .4202 m
.96556 .4199 L
s
.96769 .4202 m
.96769 .41956 L
s
.96981 .4202 m
.96981 .41976 L
s
.97194 .4202 m
.97194 .41976 L
s
.97406 .4202 m
.97406 .41978 L
s
.02381 .47793 m
.02381 .47773 L
s
.02487 .47793 m
.02487 .47805 L
s
.02594 .47793 m
.02594 .47776 L
s
.027 .47793 m
.027 .47815 L
s
.02806 .47793 m
.02806 .47786 L
s
.02912 .47793 m
.02912 .47797 L
s
.03019 .47793 m
.03019 .4781 L
s
.03125 .47793 m
.03125 .47784 L
s
.03231 .47793 m
.03231 .47804 L
s
.03338 .47793 m
.03338 .47792 L
s
.03444 .47793 m
.03444 .47794 L
s
.0355 .47793 m
.0355 .47746 L
s
.03656 .47793 m
.03656 .47843 L
s
.03763 .47793 m
.03763 .47797 L
s
.03869 .47793 m
.03869 .47715 L
s
.03975 .47793 m
.03975 .47824 L
s
.04082 .47793 m
.04082 .47805 L
s
.04188 .47793 m
.04188 .47829 L
s
.04294 .47793 m
.04294 .47683 L
s
.04401 .47793 m
.04401 .47925 L
s
.04507 .47793 m
.04507 .47667 L
s
.04613 .47793 m
.04613 .47978 L
s
.04719 .47793 m
.04719 .47549 L
s
.04826 .47793 m
.04826 .47947 L
s
.04932 .47793 m
.04932 .47697 L
s
.05038 .47793 m
.05038 .47967 L
s
.05145 .47793 m
.05145 .47571 L
s
.05251 .47793 m
.05251 .47872 L
s
.05357 .47793 m
.05357 .47753 L
s
.05463 .47793 m
.05463 .47902 L
s
.0557 .47793 m
.0557 .47598 L
s
.05676 .47793 m
.05676 .4789 L
s
.05782 .47793 m
.05782 .4776 L
s
.05889 .47793 m
.05889 .47877 L
s
.05995 .47793 m
.05995 .47713 L
s
.06101 .47793 m
.06101 .47801 L
s
.06207 .47793 m
.06207 .4783 L
s
.06314 .47793 m
.06314 .47824 L
s
.0642 .47793 m
.0642 .47746 L
s
.06526 .47793 m
.06526 .47771 L
s
.06633 .47793 m
.06633 .47858 L
s
.06739 .47793 m
.06739 .47802 L
s
.06845 .47793 m
.06845 .47773 L
s
.06952 .47793 m
.06952 .47741 L
s
.07058 .47793 m
.07058 .47868 L
s
.07164 .47793 m
.07164 .47827 L
s
.0727 .47793 m
.0727 .47773 L
s
.07377 .47793 m
.07377 .47728 L
s
.07483 .47793 m
.07483 .47885 L
s
.07589 .47793 m
.07589 .4784 L
s
.07696 .47793 m
.07696 .47762 L
s
.07802 .47793 m
.07802 .47704 L
s
.07908 .47793 m
.07908 .48088 L
s
.08014 .47793 m
.08014 .47652 L
s
.08121 .47793 m
.08121 .47895 L
s
.08227 .47793 m
.08227 .47631 L
s
.08333 .47793 m
.08333 .48104 L
s
.0844 .47793 m
.0844 .47618 L
s
.08546 .47793 m
.08546 .47895 L
s
.08652 .47793 m
.08652 .47607 L
s
.08759 .47793 m
.08759 .48124 L
s
.08865 .47793 m
.08865 .47574 L
s
.08971 .47793 m
.08971 .47993 L
s
.09077 .47793 m
.09077 .47524 L
s
.09184 .47793 m
.09184 .48146 L
s
.0929 .47793 m
.0929 .47536 L
s
.09396 .47793 m
.09396 .48055 L
s
.09503 .47793 m
.09503 .47506 L
s
.09609 .47793 m
.09609 .48167 L
s
.09715 .47793 m
.09715 .47565 L
s
.09821 .47793 m
.09821 .48052 L
s
.09928 .47793 m
.09928 .47478 L
s
.10034 .47793 m
.10034 .48125 L
s
.1014 .47793 m
.1014 .47545 L
s
.10247 .47793 m
.10247 .4806 L
s
.10353 .47793 m
.10353 .47503 L
s
.10459 .47793 m
.10459 .48121 L
s
.10565 .47793 m
.10565 .47611 L
s
.10672 .47793 m
.10672 .47796 L
s
.10778 .47793 m
.10778 .47832 L
s
.10884 .47793 m
.10884 .47893 L
s
.10991 .47793 m
.10991 .48229 L
s
.11097 .47793 m
.11097 .47126 L
s
.11203 .47793 m
.11203 .47972 L
s
.1131 .47793 m
.1131 .4837 L
s
.11416 .47793 m
.11416 .4727 L
s
.11522 .47793 m
.11522 .48755 L
s
.11628 .47793 m
.11628 .47114 L
s
.11735 .47793 m
.11735 .48426 L
s
.11841 .47793 m
.11841 .4817 L
s
.11947 .47793 m
.11947 .47407 L
s
.12054 .47793 m
.12054 .47394 L
s
.1216 .47793 m
.1216 .48478 L
s
.12266 .47793 m
.12266 .48674 L
s
.12372 .47793 m
.12372 .47457 L
s
.12479 .47793 m
.12479 .46784 L
s
.12585 .47793 m
.12585 .47994 L
s
.12691 .47793 m
.12691 .49154 L
s
.12798 .47793 m
.12798 .48233 L
s
.12904 .47793 m
.12904 .46237 L
s
.1301 .47793 m
.1301 .4724 L
s
.13116 .47793 m
.13116 .48924 L
s
.13223 .47793 m
.13223 .49247 L
s
.13329 .47793 m
.13329 .46465 L
s
.13435 .47793 m
.13435 .46462 L
s
.13542 .47793 m
.13542 .48543 L
s
.13648 .47793 m
.13648 .49661 L
s
.13754 .47793 m
.13754 .46937 L
s
.13861 .47793 m
.13861 .46181 L
s
.13967 .47793 m
.13967 .4821 L
s
.14073 .47793 m
.14073 .49861 L
s
.14179 .47793 m
.14179 .47108 L
s
.14286 .47793 m
.14286 .45968 L
s
.14392 .47793 m
.14392 .47946 L
s
.14498 .47793 m
.14498 .50125 L
s
.14605 .47793 m
.14605 .47355 L
s
.14711 .47793 m
.14711 .45702 L
s
.14817 .47793 m
.14817 .47905 L
s
.14923 .47793 m
.14923 .50123 L
s
.1503 .47793 m
.1503 .47274 L
s
.15136 .47793 m
.15136 .45827 L
s
.15242 .47793 m
.15242 .48297 L
s
.15349 .47793 m
.15349 .50012 L
s
.15455 .47793 m
.15455 .46709 L
s
.15561 .47793 m
.15561 .46138 L
s
.15668 .47793 m
.15668 .4905 L
s
.15774 .47793 m
.15774 .49936 L
s
.1588 .47793 m
.1588 .46105 L
s
.15986 .47793 m
.15986 .46259 L
s
.16093 .47793 m
.16093 .49881 L
s
.16199 .47793 m
.16199 .49518 L
s
.16305 .47793 m
.16305 .45641 L
s
.16412 .47793 m
.16412 .46885 L
s
.16518 .47793 m
.16518 .5012 L
s
.16624 .47793 m
.16624 .48227 L
s
.1673 .47793 m
.1673 .45672 L
s
.16837 .47793 m
.16837 .47858 L
s
.16943 .47793 m
.16943 .49856 L
s
.17049 .47793 m
.17049 .46519 L
s
.17156 .47793 m
.17156 .46319 L
s
.17262 .47793 m
.17262 .48944 L
s
.17368 .47793 m
.17368 .48591 L
s
.17474 .47793 m
.17474 .45332 L
s
.17581 .47793 m
.17581 .48096 L
s
.17687 .47793 m
.17687 .49396 L
s
.17793 .47793 m
.17793 .46875 L
s
.179 .47793 m
.179 .4568 L
s
.18006 .47793 m
.18006 .49666 L
s
.18112 .47793 m
.18112 .48436 L
s
.18219 .47793 m
.18219 .46094 L
s
.18325 .47793 m
.18325 .4698 L
s
.18431 .47793 m
.18431 .4926 L
s
.18537 .47793 m
.18537 .47796 L
s
.18644 .47793 m
.18644 .46838 L
s
.1875 .47793 m
.1875 .48303 L
s
.18856 .47793 m
.18856 .48433 L
s
.18963 .47793 m
.18963 .47821 L
s
.19069 .47793 m
.19069 .47812 L
s
.19175 .47793 m
.19175 .46858 L
s
.19281 .47793 m
.19281 .47887 L
s
.19388 .47793 m
.19388 .48848 L
s
.19494 .47793 m
.19494 .4608 L
s
.196 .47793 m
.196 .46942 L
s
.19707 .47793 m
.19707 .49003 L
s
.19813 .47793 m
.19813 .47186 L
s
.19919 .47793 m
.19919 .47522 L
s
.20026 .47793 m
.20026 .4793 L
s
.20132 .47793 m
.20132 .47188 L
s
.20238 .47793 m
.20238 .48149 L
s
.20344 .47793 m
.20344 .47945 L
s
.20451 .47793 m
.20451 .47388 L
s
.20557 .47793 m
.20557 .48023 L
s
.20663 .47793 m
.20663 .48267 L
s
.2077 .47793 m
.2077 .4757 L
s
.20876 .47793 m
.20876 .47485 L
s
.20982 .47793 m
.20982 .48224 L
s
.21088 .47793 m
.21088 .48203 L
s
.21195 .47793 m
.21195 .47236 L
s
.21301 .47793 m
.21301 .47882 L
s
.21407 .47793 m
.21407 .48308 L
s
.21514 .47793 m
.21514 .47877 L
s
.2162 .47793 m
.2162 .47535 L
s
.21726 .47793 m
.21726 .47769 L
s
.21832 .47793 m
.21832 .47881 L
s
.21939 .47793 m
.21939 .47752 L
s
.22045 .47793 m
.22045 .47686 L
s
.22151 .47793 m
.22151 .4754 L
s
.22258 .47793 m
.22258 .47849 L
s
.22364 .47793 m
.22364 .48013 L
s
.2247 .47793 m
.2247 .47669 L
s
.22577 .47793 m
.22577 .47413 L
s
.22683 .47793 m
.22683 .47953 L
s
.22789 .47793 m
.22789 .47817 L
s
.22895 .47793 m
.22895 .47785 L
s
.23002 .47793 m
.23002 .47753 L
s
.23108 .47793 m
.23108 .47882 L
s
.23214 .47793 m
.23214 .47779 L
s
.23321 .47793 m
.23321 .47906 L
s
.23427 .47793 m
.23427 .47826 L
s
.23533 .47793 m
.23533 .47832 L
s
.23639 .47793 m
.23639 .47639 L
s
.23746 .47793 m
.23746 .47837 L
s
.23852 .47793 m
.23852 .47837 L
s
.23958 .47793 m
.23958 .47827 L
s
.24065 .47793 m
.24065 .47627 L
s
.24171 .47793 m
.24171 .47928 L
s
.24277 .47793 m
.24277 .47901 L
s
.24384 .47793 m
.24384 .47657 L
s
.2449 .47793 m
.2449 .47735 L
s
.24596 .47793 m
.24596 .48058 L
s
.24702 .47793 m
.24702 .47861 L
s
.24809 .47793 m
.24809 .47633 L
s
.24915 .47793 m
.24915 .4779 L
s
.25021 .47793 m
.25021 .47961 L
s
.25128 .47793 m
.25128 .47865 L
s
.25234 .47793 m
.25234 .47467 L
s
.2534 .47793 m
.2534 .47847 L
s
.25446 .47793 m
.25446 .47922 L
s
.25553 .47793 m
.25553 .47623 L
s
.25659 .47793 m
.25659 .47598 L
s
.25765 .47793 m
.25765 .48071 L
s
.25872 .47793 m
.25872 .47811 L
s
.25978 .47793 m
.25978 .47575 L
s
.26084 .47793 m
.26084 .47826 L
s
.2619 .47793 m
.2619 .47942 L
s
.26297 .47793 m
.26297 .4776 L
s
.26403 .47793 m
.26403 .47683 L
s
.26509 .47793 m
.26509 .47815 L
s
.26616 .47793 m
.26616 .47972 L
s
.26722 .47793 m
.26722 .47818 L
s
.26828 .47793 m
.26828 .47673 L
s
.26935 .47793 m
.26935 .47884 L
s
.27041 .47793 m
.27041 .4791 L
s
.27147 .47793 m
.27147 .47754 L
s
.27253 .47793 m
.27253 .47706 L
s
.2736 .47793 m
.2736 .47832 L
s
.27466 .47793 m
.27466 .4788 L
s
.27572 .47793 m
.27572 .47775 L
s
.27679 .47793 m
.27679 .47677 L
s
.27785 .47793 m
.27785 .47858 L
s
.27891 .47793 m
.27891 .47851 L
s
.27997 .47793 m
.27997 .47617 L
s
.28104 .47793 m
.28104 .47797 L
s
.2821 .47793 m
.2821 .47864 L
s
.28316 .47793 m
.28316 .47781 L
s
.28423 .47793 m
.28423 .47676 L
s
.28529 .47793 m
.28529 .47817 L
s
.28635 .47793 m
.28635 .47816 L
s
.28741 .47793 m
.28741 .478 L
s
.28848 .47793 m
.28848 .47721 L
s
.28954 .47793 m
.28954 .47828 L
s
.2906 .47793 m
.2906 .47816 L
s
.29167 .47793 m
.29167 .47812 L
s
.29273 .47793 m
.29273 .47739 L
s
.29379 .47793 m
.29379 .47852 L
s
.29486 .47793 m
.29486 .47823 L
s
.29592 .47793 m
.29592 .47755 L
s
.29698 .47793 m
.29698 .47798 L
s
.29804 .47793 m
.29804 .47805 L
s
.29911 .47793 m
.29911 .47814 L
s
.30017 .47793 m
.30017 .47762 L
s
.30123 .47793 m
.30123 .4786 L
s
.3023 .47793 m
.3023 .47843 L
s
.30336 .47793 m
.30336 .47738 L
s
.30442 .47793 m
.30442 .4774 L
s
.30548 .47793 m
.30548 .47937 L
s
.30655 .47793 m
.30655 .47735 L
s
.30761 .47793 m
.30761 .47698 L
s
.30867 .47793 m
.30867 .47819 L
s
.30974 .47793 m
.30974 .47869 L
s
.3108 .47793 m
.3108 .47743 L
s
.31186 .47793 m
.31186 .47728 L
s
.31293 .47793 m
.31293 .47844 L
s
.31399 .47793 m
.31399 .47801 L
s
.31505 .47793 m
.31505 .47708 L
s
.31611 .47793 m
.31611 .47844 L
s
.31718 .47793 m
.31718 .47862 L
s
.31824 .47793 m
.31824 .47783 L
s
.3193 .47793 m
.3193 .47833 L
s
.32037 .47793 m
.32037 .4782 L
s
.32143 .47793 m
.32143 .47794 L
s
.32249 .47793 m
.32249 .47766 L
s
.32355 .47793 m
.32355 .4776 L
s
.32462 .47793 m
.32462 .47788 L
s
.32568 .47793 m
.32568 .47746 L
s
.32674 .47793 m
.32674 .47963 L
s
.32781 .47793 m
.32781 .4746 L
s
.32887 .47793 m
.32887 .47941 L
s
.32993 .47793 m
.32993 .47716 L
s
.33099 .47793 m
.33099 .47608 L
s
.33206 .47793 m
.33206 .47793 L
s
.33312 .47793 m
.33312 .47694 L
s
.33418 .47793 m
.33418 .47916 L
s
.33525 .47793 m
.33525 .47858 L
s
.33631 .47793 m
.33631 .47667 L
s
.33737 .47793 m
.33737 .47828 L
s
.33844 .47793 m
.33844 .48125 L
s
.3395 .47793 m
.3395 .48337 L
s
.34056 .47793 m
.34056 .47109 L
s
.34162 .47793 m
.34162 .48371 L
s
.34269 .47793 m
.34269 .47828 L
s
.34375 .47793 m
.34375 .48128 L
s
.34481 .47793 m
.34481 .4688 L
s
.34588 .47793 m
.34588 .48876 L
s
.34694 .47793 m
.34694 .47354 L
s
.348 .47793 m
.348 .47171 L
s
.34906 .47793 m
.34906 .47465 L
s
.35013 .47793 m
.35013 .48795 L
s
.35119 .47793 m
.35119 .46853 L
s
.35225 .47793 m
.35225 .47441 L
s
.35332 .47793 m
.35332 .48581 L
s
.35438 .47793 m
.35438 .47793 L
s
.35544 .47793 m
.35544 .46835 L
s
.35651 .47793 m
.35651 .48615 L
s
.35757 .47793 m
.35757 .48813 L
s
.35863 .47793 m
.35863 .46847 L
s
.35969 .47793 m
.35969 .4792 L
s
.36076 .47793 m
.36076 .48606 L
s
.36182 .47793 m
.36182 .47728 L
s
.36288 .47793 m
.36288 .46977 L
s
.36395 .47793 m
.36395 .48824 L
s
.36501 .47793 m
.36501 .47494 L
s
.36607 .47793 m
.36607 .46921 L
s
.36713 .47793 m
.36713 .47684 L
s
.3682 .47793 m
.3682 .485 L
s
.36926 .47793 m
.36926 .46861 L
s
.37032 .47793 m
.37032 .47871 L
s
.37139 .47793 m
.37139 .48437 L
s
.37245 .47793 m
.37245 .47137 L
s
.37351 .47793 m
.37351 .477 L
s
.37457 .47793 m
.37457 .48562 L
s
.37564 .47793 m
.37564 .47757 L
s
.3767 .47793 m
.3767 .47483 L
s
.37776 .47793 m
.37776 .48584 L
s
.37883 .47793 m
.37883 .47079 L
s
.37989 .47793 m
.37989 .47729 L
s
.38095 .47793 m
.38095 .48294 L
s
.38202 .47793 m
.38202 .47084 L
s
.38308 .47793 m
.38308 .47896 L
s
.38414 .47793 m
.38414 .48019 L
s
.3852 .47793 m
.3852 .47693 L
s
.38627 .47793 m
.38627 .4745 L
s
.38733 .47793 m
.38733 .48412 L
s
.38839 .47793 m
.38839 .47816 L
s
.38946 .47793 m
.38946 .47369 L
s
.39052 .47793 m
.39052 .48265 L
s
.39158 .47793 m
.39158 .47537 L
s
.39264 .47793 m
.39264 .47577 L
s
.39371 .47793 m
.39371 .47687 L
s
.39477 .47793 m
.39477 .48025 L
s
.39583 .47793 m
.39583 .47417 L
s
.3969 .47793 m
.3969 .47771 L
s
.39796 .47793 m
.39796 .48118 L
s
.39902 .47793 m
.39902 .47702 L
s
.40009 .47793 m
.40009 .47882 L
s
.40115 .47793 m
.40115 .47924 L
s
.40221 .47793 m
.40221 .47832 L
s
.40327 .47793 m
.40327 .47638 L
s
.40434 .47793 m
.40434 .48089 L
s
.4054 .47793 m
.4054 .47521 L
s
.40646 .47793 m
.40646 .47814 L
s
.40753 .47793 m
.40753 .47839 L
s
.40859 .47793 m
.40859 .47707 L
s
.40965 .47793 m
.40965 .47657 L
s
.41071 .47793 m
.41071 .47729 L
s
.41178 .47793 m
.41178 .47952 L
s
.41284 .47793 m
.41284 .47561 L
s
.4139 .47793 m
.4139 .48147 L
s
.41497 .47793 m
.41497 .47416 L
s
.41603 .47793 m
.41603 .48146 L
s
.41709 .47793 m
.41709 .47625 L
s
.41815 .47793 m
.41815 .48103 L
s
.41922 .47793 m
.41922 .47452 L
s
.42028 .47793 m
.42028 .48102 L
s
.42134 .47793 m
.42134 .4775 L
s
.42241 .47793 m
.42241 .47698 L
s
.42347 .47793 m
.42347 .47884 L
s
.42453 .47793 m
.42453 .47653 L
s
.4256 .47793 m
.4256 .47937 L
s
.42666 .47793 m
.42666 .47515 L
s
.42772 .47793 m
.42772 .48117 L
s
.42878 .47793 m
.42878 .47422 L
s
.42985 .47793 m
.42985 .47979 L
s
.43091 .47793 m
.43091 .47683 L
s
.43197 .47793 m
.43197 .48136 L
s
.43304 .47793 m
.43304 .47433 L
s
.4341 .47793 m
.4341 .48056 L
s
.43516 .47793 m
.43516 .47808 L
s
.43622 .47793 m
.43622 .47877 L
s
.43729 .47793 m
.43729 .47451 L
s
.43835 .47793 m
.43835 .48044 L
s
.43941 .47793 m
.43941 .47747 L
s
.44048 .47793 m
.44048 .47805 L
s
.44154 .47793 m
.44154 .47618 L
s
.4426 .47793 m
.4426 .47898 L
s
.44366 .47793 m
.44366 .47697 L
s
.44473 .47793 m
.44473 .47869 L
s
.44579 .47793 m
.44579 .47641 L
s
.44685 .47793 m
.44685 .47971 L
s
.44792 .47793 m
.44792 .47685 L
s
.44898 .47793 m
.44898 .47836 L
s
.45004 .47793 m
.45004 .47673 L
s
.45111 .47793 m
.45111 .47951 L
s
.45217 .47793 m
.45217 .47703 L
s
.45323 .47793 m
.45323 .47776 L
s
.45429 .47793 m
.45429 .47801 L
s
.45536 .47793 m
.45536 .47856 L
s
.45642 .47793 m
.45642 .47815 L
s
.45748 .47793 m
.45748 .47677 L
s
.45855 .47793 m
.45855 .4797 L
s
.45961 .47793 m
.45961 .47803 L
s
.46067 .47793 m
.46067 .47605 L
s
.46173 .47793 m
.46173 .47982 L
s
.4628 .47793 m
.4628 .48024 L
s
.46386 .47793 m
.46386 .47096 L
s
.46492 .47793 m
.46492 .48402 L
s
.46599 .47793 m
.46599 .48499 L
s
.46705 .47793 m
.46705 .47641 L
s
.46811 .47793 m
.46811 .47433 L
s
.46918 .47793 m
.46918 .48836 L
s
.47024 .47793 m
.47024 .48642 L
s
.4713 .47793 m
.4713 .47746 L
s
.47236 .47793 m
.47236 .46857 L
s
.47343 .47793 m
.47343 .48778 L
s
.47449 .47793 m
.47449 .49429 L
s
.47555 .47793 m
.47555 .47735 L
s
.47662 .47793 m
.47662 .46752 L
s
.47768 .47793 m
.47768 .4846 L
s
.47874 .47793 m
.47874 .49352 L
s
.4798 .47793 m
.4798 .48191 L
s
.48087 .47793 m
.48087 .46652 L
s
.48193 .47793 m
.48193 .4861 L
s
.48299 .47793 m
.48299 .49171 L
s
.48406 .47793 m
.48406 .48212 L
s
.48512 .47793 m
.48512 .46915 L
s
.48618 .47793 m
.48618 .48295 L
s
.48724 .47793 m
.48724 .49174 L
s
.48831 .47793 m
.48831 .48059 L
s
.48937 .47793 m
.48937 .47035 L
s
.49043 .47793 m
.49043 .47825 L
s
.4915 .47793 m
.4915 .48903 L
s
.49256 .47793 m
.49256 .48381 L
s
.49362 .47793 m
.49362 .47007 L
s
.49469 .47793 m
.49469 .47311 L
s
.49575 .47793 m
.49575 .48225 L
s
.49681 .47793 m
.49681 .48312 L
s
.49787 .47793 m
.49787 .47079 L
s
.49894 .47793 m
.49894 .46984 L
s
.5 .47793 m
.5 .47644 L
s
.50106 .47793 m
.50106 .48349 L
s
.50213 .47793 m
.50213 .47038 L
s
.50319 .47793 m
.50319 .4661 L
s
.50425 .47793 m
.50425 .4746 L
s
.50531 .47793 m
.50531 .48488 L
s
.50638 .47793 m
.50638 .47427 L
s
.50744 .47793 m
.50744 .46655 L
s
.5085 .47793 m
.5085 .4731 L
s
.50957 .47793 m
.50957 .48608 L
s
.51063 .47793 m
.51063 .48504 L
s
.51169 .47793 m
.51169 .47241 L
s
.51276 .47793 m
.51276 .47039 L
s
.51382 .47793 m
.51382 .48136 L
s
.51488 .47793 m
.51488 .49354 L
s
.51594 .47793 m
.51594 .4792 L
s
.51701 .47793 m
.51701 .47197 L
s
.51807 .47793 m
.51807 .47113 L
s
.51913 .47793 m
.51913 .48987 L
s
.5202 .47793 m
.5202 .48055 L
s
.52126 .47793 m
.52126 .47612 L
s
.52232 .47793 m
.52232 .46458 L
s
.52338 .47793 m
.52338 .47967 L
s
.52445 .47793 m
.52445 .48392 L
s
.52551 .47793 m
.52551 .48224 L
s
.52657 .47793 m
.52657 .47706 L
s
.52764 .47793 m
.52764 .46681 L
s
.5287 .47793 m
.5287 .48212 L
s
.52976 .47793 m
.52976 .47809 L
s
.53082 .47793 m
.53082 .49559 L
s
.53189 .47793 m
.53189 .46889 L
s
.53295 .47793 m
.53295 .47096 L
s
.53401 .47793 m
.53401 .46932 L
s
.53508 .47793 m
.53508 .48146 L
s
.53614 .47793 m
.53614 .49415 L
s
.5372 .47793 m
.5372 .47003 L
s
.53827 .47793 m
.53827 .48676 L
s
.53933 .47793 m
.53933 .45756 L
s
.54039 .47793 m
.54039 .48862 L
s
.54145 .47793 m
.54145 .47105 L
s
.54252 .47793 m
.54252 .48003 L
s
.54358 .47793 m
.54358 .48738 L
s
.54464 .47793 m
.54464 .46522 L
s
.54571 .47793 m
.54571 .49585 L
s
.54677 .47793 m
.54677 .45264 L
s
.54783 .47793 m
.54783 .48806 L
s
.54889 .47793 m
.54889 .47512 L
s
.54996 .47793 m
.54996 .47485 L
s
.55102 .47793 m
.55102 .48893 L
s
.55208 .47793 m
.55208 .45332 L
s
.55315 .47793 m
.55315 .49987 L
s
.55421 .47793 m
.55421 .47225 L
s
.55527 .47793 m
.55527 .48049 L
s
.55634 .47793 m
.55634 .47937 L
s
.5574 .47793 m
.5574 .46054 L
s
.55846 .47793 m
.55846 .48457 L
s
.55952 .47793 m
.55952 .48318 L
s
.56059 .47793 m
.56059 .48598 L
s
.56165 .47793 m
.56165 .47591 L
s
.56271 .47793 m
.56271 .476 L
s
.56378 .47793 m
.56378 .46984 L
s
.56484 .47793 m
.56484 .48255 L
s
.5659 .47793 m
.5659 .47926 L
s
.56696 .47793 m
.56696 .48016 L
s
.56803 .47793 m
.56803 .47961 L
s
.56909 .47793 m
.56909 .47142 L
s
.57015 .47793 m
.57015 .48315 L
s
.57122 .47793 m
.57122 .47648 L
s
.57228 .47793 m
.57228 .48173 L
s
.57334 .47793 m
.57334 .47543 L
s
.5744 .47793 m
.5744 .47437 L
s
.57547 .47793 m
.57547 .47814 L
s
.57653 .47793 m
.57653 .47715 L
s
.57759 .47793 m
.57759 .48029 L
s
.57866 .47793 m
.57866 .47856 L
s
.57972 .47793 m
.57972 .47698 L
s
.58078 .47793 m
.58078 .47794 L
s
.58185 .47793 m
.58185 .47424 L
s
.58291 .47793 m
.58291 .47673 L
s
.58397 .47793 m
.58397 .47903 L
s
.58503 .47793 m
.58503 .47763 L
s
.5861 .47793 m
.5861 .48105 L
s
.58716 .47793 m
.58716 .47699 L
s
.58822 .47793 m
.58822 .47879 L
s
.58929 .47793 m
.58929 .47526 L
s
.59035 .47793 m
.59035 .477 L
s
.59141 .47793 m
.59141 .48036 L
s
.59247 .47793 m
.59247 .47873 L
s
.59354 .47793 m
.59354 .47865 L
s
.5946 .47793 m
.5946 .47439 L
s
.59566 .47793 m
.59566 .47794 L
s
.59673 .47793 m
.59673 .47937 L
s
.59779 .47793 m
.59779 .47974 L
s
.59885 .47793 m
.59885 .47891 L
s
.59991 .47793 m
.59991 .4747 L
s
.60098 .47793 m
.60098 .47776 L
s
.60204 .47793 m
.60204 .47828 L
s
.6031 .47793 m
.6031 .48036 L
s
.60417 .47793 m
.60417 .47762 L
s
.60523 .47793 m
.60523 .47704 L
s
.60629 .47793 m
.60629 .47733 L
s
.60736 .47793 m
.60736 .47788 L
s
.60842 .47793 m
.60842 .48034 L
s
.60948 .47793 m
.60948 .47616 L
s
.61054 .47793 m
.61054 .479 L
s
.61161 .47793 m
.61161 .47632 L
s
.61267 .47793 m
.61267 .47904 L
s
.61373 .47793 m
.61373 .47856 L
s
.6148 .47793 m
.6148 .47712 L
s
.61586 .47793 m
.61586 .47896 L
s
.61692 .47793 m
.61692 .47691 L
s
.61798 .47793 m
.61798 .47902 L
s
.61905 .47793 m
.61905 .47625 L
s
.62011 .47793 m
.62011 .47857 L
s
.62117 .47793 m
.62117 .47839 L
s
.62224 .47793 m
.62224 .47853 L
s
.6233 .47793 m
.6233 .47852 L
s
.62436 .47793 m
.62436 .47617 L
s
.62543 .47793 m
.62543 .47823 L
s
.62649 .47793 m
.62649 .47804 L
s
.62755 .47793 m
.62755 .47881 L
s
.62861 .47793 m
.62861 .47711 L
s
.62968 .47793 m
.62968 .47827 L
s
.63074 .47793 m
.63074 .47839 L
s
.6318 .47793 m
.6318 .47668 L
s
.63287 .47793 m
.63287 .4816 L
s
.63393 .47793 m
.63393 .4744 L
s
.63499 .47793 m
.63499 .47915 L
s
.63605 .47793 m
.63605 .47854 L
s
.63712 .47793 m
.63712 .47647 L
s
.63818 .47793 m
.63818 .48067 L
s
.63924 .47793 m
.63924 .47635 L
s
.64031 .47793 m
.64031 .47873 L
s
.64137 .47793 m
.64137 .47681 L
s
.64243 .47793 m
.64243 .47746 L
s
.64349 .47793 m
.64349 .47802 L
s
.64456 .47793 m
.64456 .47818 L
s
.64562 .47793 m
.64562 .47753 L
s
.64668 .47793 m
.64668 .47809 L
s
.64775 .47793 m
.64775 .47758 L
s
.64881 .47793 m
.64881 .47667 L
s
.64987 .47793 m
.64987 .47923 L
s
.65094 .47793 m
.65094 .47966 L
s
.652 .47793 m
.652 .47495 L
s
.65306 .47793 m
.65306 .47968 L
s
.65412 .47793 m
.65412 .47995 L
s
.65519 .47793 m
.65519 .47409 L
s
.65625 .47793 m
.65625 .47945 L
s
.65731 .47793 m
.65731 .47603 L
s
.65838 .47793 m
.65838 .4782 L
s
.65944 .47793 m
.65944 .47682 L
s
.6605 .47793 m
.6605 .4796 L
s
.66156 .47793 m
.66156 .48239 L
s
.66263 .47793 m
.66263 .47285 L
s
.66369 .47793 m
.66369 .48104 L
s
.66475 .47793 m
.66475 .47994 L
s
.66582 .47793 m
.66582 .47416 L
s
.66688 .47793 m
.66688 .48022 L
s
.66794 .47793 m
.66794 .47698 L
s
.66901 .47793 m
.66901 .47803 L
s
.67007 .47793 m
.67007 .47622 L
s
.67113 .47793 m
.67113 .47917 L
s
.67219 .47793 m
.67219 .48139 L
s
.67326 .47793 m
.67326 .47382 L
s
.67432 .47793 m
.67432 .48318 L
s
.67538 .47793 m
.67538 .47483 L
s
.67645 .47793 m
.67645 .48111 L
s
.67751 .47793 m
.67751 .4778 L
s
.67857 .47793 m
.67857 .47653 L
s
.67963 .47793 m
.67963 .47967 L
s
.6807 .47793 m
.6807 .47344 L
s
.68176 .47793 m
.68176 .48206 L
s
.68282 .47793 m
.68282 .46969 L
s
.68389 .47793 m
.68389 .48558 L
s
.68495 .47793 m
.68495 .47138 L
s
.68601 .47793 m
.68601 .48489 L
s
.68707 .47793 m
.68707 .47126 L
s
.68814 .47793 m
.68814 .48307 L
s
.6892 .47793 m
.6892 .4761 L
s
.69026 .47793 m
.69026 .47775 L
s
.69133 .47793 m
.69133 .47974 L
s
.69239 .47793 m
.69239 .47445 L
s
.69345 .47793 m
.69345 .48219 L
s
.69452 .47793 m
.69452 .47263 L
s
.69558 .47793 m
.69558 .4831 L
s
.69664 .47793 m
.69664 .47593 L
s
.6977 .47793 m
.6977 .47696 L
s
.69877 .47793 m
.69877 .48048 L
s
.69983 .47793 m
.69983 .4744 L
s
.70089 .47793 m
.70089 .48007 L
s
.70196 .47793 m
.70196 .47678 L
s
.70302 .47793 m
.70302 .47824 L
s
.70408 .47793 m
.70408 .47949 L
s
.70514 .47793 m
.70514 .47548 L
s
.70621 .47793 m
.70621 .47911 L
s
.70727 .47793 m
.70727 .4778 L
s
.70833 .47793 m
.70833 .47606 L
s
.7094 .47793 m
.7094 .48241 L
s
.71046 .47793 m
.71046 .47279 L
s
.71152 .47793 m
.71152 .48128 L
s
.71259 .47793 m
.71259 .47689 L
s
.71365 .47793 m
.71365 .47694 L
s
.71471 .47793 m
.71471 .48067 L
s
.71577 .47793 m
.71577 .47502 L
s
.71684 .47793 m
.71684 .48039 L
s
.7179 .47793 m
.7179 .47804 L
s
.71896 .47793 m
.71896 .47596 L
s
.72003 .47793 m
.72003 .47816 L
s
.72109 .47793 m
.72109 .48129 L
s
.72215 .47793 m
.72215 .47638 L
s
.72321 .47793 m
.72321 .47727 L
s
.72428 .47793 m
.72428 .47723 L
s
.72534 .47793 m
.72534 .47895 L
s
.7264 .47793 m
.7264 .47893 L
s
.72747 .47793 m
.72747 .47665 L
s
.72853 .47793 m
.72853 .47765 L
s
.72959 .47793 m
.72959 .47785 L
s
.73065 .47793 m
.73065 .47917 L
s
.73172 .47793 m
.73172 .47826 L
s
.73278 .47793 m
.73278 .47739 L
s
.73384 .47793 m
.73384 .47819 L
s
.73491 .47793 m
.73491 .4775 L
s
.73597 .47793 m
.73597 .47934 L
s
.73703 .47793 m
.73703 .47685 L
s
.7381 .47793 m
.7381 .47728 L
s
.73916 .47793 m
.73916 .47891 L
s
.74022 .47793 m
.74022 .47752 L
s
.74128 .47793 m
.74128 .47819 L
s
.74235 .47793 m
.74235 .47715 L
s
.74341 .47793 m
.74341 .47839 L
s
.74447 .47793 m
.74447 .47739 L
s
.74554 .47793 m
.74554 .47857 L
s
.7466 .47793 m
.7466 .47797 L
s
.74766 .47793 m
.74766 .47822 L
s
.74872 .47793 m
.74872 .47727 L
s
.74979 .47793 m
.74979 .4787 L
s
.75085 .47793 m
.75085 .47712 L
s
.75191 .47793 m
.75191 .47889 L
s
.75298 .47793 m
.75298 .47734 L
s
.75404 .47793 m
.75404 .47809 L
s
.7551 .47793 m
.7551 .47776 L
s
.75616 .47793 m
.75616 .47794 L
s
.75723 .47793 m
.75723 .47862 L
s
.75829 .47793 m
.75829 .47729 L
s
.75935 .47793 m
.75935 .47786 L
s
.76042 .47793 m
.76042 .47768 L
s
.76148 .47793 m
.76148 .47837 L
s
.76254 .47793 m
.76254 .47798 L
s
.76361 .47793 m
.76361 .47773 L
s
.76467 .47793 m
.76467 .47792 L
s
.76573 .47793 m
.76573 .47839 L
s
.76679 .47793 m
.76679 .47753 L
s
.76786 .47793 m
.76786 .47831 L
s
.76892 .47793 m
.76892 .47757 L
s
.76998 .47793 m
.76998 .47825 L
s
.77105 .47793 m
.77105 .47778 L
s
.77211 .47793 m
.77211 .47782 L
s
.77317 .47793 m
.77317 .47801 L
s
.77423 .47793 m
.77423 .47794 L
s
.7753 .47793 m
.7753 .47837 L
s
.77636 .47793 m
.77636 .47753 L
s
.77742 .47793 m
.77742 .47841 L
s
.77849 .47793 m
.77849 .47749 L
s
.77955 .47793 m
.77955 .47831 L
s
.78061 .47793 m
.78061 .47768 L
s
.78168 .47793 m
.78168 .47805 L
s
.78274 .47793 m
.78274 .47802 L
s
.7838 .47793 m
.7838 .47801 L
s
.78486 .47793 m
.78486 .47773 L
s
.78593 .47793 m
.78593 .47815 L
s
.78699 .47793 m
.78699 .47789 L
s
.78805 .47793 m
.78805 .47801 L
s
.78912 .47793 m
.78912 .47758 L
s
.79018 .47793 m
.79018 .47755 L
s
.79124 .47793 m
.79124 .47833 L
s
.7923 .47793 m
.7923 .47748 L
s
.79337 .47793 m
.79337 .47842 L
s
.79443 .47793 m
.79443 .4771 L
s
.79549 .47793 m
.79549 .47825 L
s
.79656 .47793 m
.79656 .47768 L
s
.79762 .47793 m
.79762 .47711 L
s
.79868 .47793 m
.79868 .47825 L
s
.79974 .47793 m
.79974 .47748 L
s
.80081 .47793 m
.80081 .47975 L
s
.80187 .47793 m
.80187 .47696 L
s
.80293 .47793 m
.80293 .47788 L
s
.804 .47793 m
.804 .47971 L
s
.80506 .47793 m
.80506 .47686 L
s
.80612 .47793 m
.80612 .48078 L
s
.80719 .47793 m
.80719 .47665 L
s
.80825 .47793 m
.80825 .48091 L
s
.80931 .47793 m
.80931 .47827 L
s
.81037 .47793 m
.81037 .47766 L
s
.81144 .47793 m
.81144 .47919 L
s
.8125 .47793 m
.8125 .47592 L
s
.81356 .47793 m
.81356 .4804 L
s
.81463 .47793 m
.81463 .47553 L
s
.81569 .47793 m
.81569 .47835 L
s
.81675 .47793 m
.81675 .47865 L
s
.81781 .47793 m
.81781 .47705 L
s
.81888 .47793 m
.81888 .47937 L
s
.81994 .47793 m
.81994 .47728 L
s
.821 .47793 m
.821 .47945 L
s
.82207 .47793 m
.82207 .47838 L
s
.82313 .47793 m
.82313 .47832 L
s
.82419 .47793 m
.82419 .47948 L
s
.82526 .47793 m
.82526 .47749 L
s
.82632 .47793 m
.82632 .47651 L
s
.82738 .47793 m
.82738 .48089 L
s
.82844 .47793 m
.82844 .48118 L
s
.82951 .47793 m
.82951 .47454 L
s
.83057 .47793 m
.83057 .48166 L
s
.83163 .47793 m
.83163 .47993 L
s
.8327 .47793 m
.8327 .47591 L
s
.83376 .47793 m
.83376 .46931 L
s
.83482 .47793 m
.83482 .47818 L
s
.83588 .47793 m
.83588 .47445 L
s
.83695 .47793 m
.83695 .46582 L
s
.83801 .47793 m
.83801 .4901 L
s
.83907 .47793 m
.83907 .48482 L
s
.84014 .47793 m
.84014 .47921 L
s
.8412 .47793 m
.8412 .49235 L
s
.84226 .47793 m
.84226 .46617 L
s
.84332 .47793 m
.84332 .47681 L
s
.84439 .47793 m
.84439 .47936 L
s
.84545 .47793 m
.84545 .47353 L
s
.84651 .47793 m
.84651 .48322 L
s
.84758 .47793 m
.84758 .46085 L
s
.84864 .47793 m
.84864 .469 L
s
.8497 .47793 m
.8497 .46855 L
s
.85077 .47793 m
.85077 .47762 L
s
.85183 .47793 m
.85183 .47954 L
s
.85289 .47793 m
.85289 .46574 L
s
.85395 .47793 m
.85395 .48265 L
s
.85502 .47793 m
.85502 .48059 L
s
.85608 .47793 m
.85608 .48574 L
s
.85714 .47793 m
.85714 .48138 L
s
.85821 .47793 m
.85821 .48225 L
s
.85927 .47793 m
.85927 .48413 L
s
.86033 .47793 m
.86033 .48221 L
s
.86139 .47793 m
.86139 .48174 L
s
.86246 .47793 m
.86246 .47374 L
s
.86352 .47793 m
.86352 .48363 L
s
.86458 .47793 m
.86458 .47392 L
s
.86565 .47793 m
.86565 .46999 L
s
.86671 .47793 m
.86671 .46935 L
s
.86777 .47793 m
.86777 .48403 L
s
.86884 .47793 m
.86884 .48285 L
s
.8699 .47793 m
.8699 .48143 L
s
.87096 .47793 m
.87096 .48436 L
s
.87202 .47793 m
.87202 .47283 L
s
.87309 .47793 m
.87309 .4691 L
s
.87415 .47793 m
.87415 .47696 L
s
.87521 .47793 m
.87521 .47971 L
s
.87628 .47793 m
.87628 .48147 L
s
.87734 .47793 m
.87734 .48627 L
s
.8784 .47793 m
.8784 .47526 L
s
.87946 .47793 m
.87946 .4788 L
s
.88053 .47793 m
.88053 .47022 L
s
.88159 .47793 m
.88159 .47467 L
s
.88265 .47793 m
.88265 .47789 L
s
.88372 .47793 m
.88372 .47908 L
s
.88478 .47793 m
.88478 .48561 L
s
.88584 .47793 m
.88584 .48482 L
s
.8869 .47793 m
.8869 .48082 L
s
.88797 .47793 m
.88797 .47973 L
s
.88903 .47793 m
.88903 .47258 L
s
.89009 .47793 m
.89009 .47602 L
s
.89116 .47793 m
.89116 .48278 L
s
.89222 .47793 m
.89222 .47751 L
s
.89328 .47793 m
.89328 .47612 L
s
.89435 .47793 m
.89435 .47779 L
s
.89541 .47793 m
.89541 .47018 L
s
.89647 .47793 m
.89647 .47399 L
s
.89753 .47793 m
.89753 .47411 L
s
.8986 .47793 m
.8986 .47603 L
s
.89966 .47793 m
.89966 .48562 L
s
.90072 .47793 m
.90072 .48498 L
s
.90179 .47793 m
.90179 .48454 L
s
.90285 .47793 m
.90285 .48134 L
s
.90391 .47793 m
.90391 .47634 L
s
.90497 .47793 m
.90497 .48137 L
s
.90604 .47793 m
.90604 .47542 L
s
.9071 .47793 m
.9071 .47381 L
s
.90816 .47793 m
.90816 .47661 L
s
.90923 .47793 m
.90923 .47602 L
s
.91029 .47793 m
.91029 .47923 L
s
.91135 .47793 m
.91135 .47967 L
s
.91241 .47793 m
.91241 .47924 L
s
.91348 .47793 m
.91348 .4809 L
s
.91454 .47793 m
.91454 .47598 L
s
.9156 .47793 m
.9156 .47961 L
s
.91667 .47793 m
.91667 .48096 L
s
.91773 .47793 m
.91773 .47877 L
s
.91879 .47793 m
.91879 .47924 L
s
.91986 .47793 m
.91986 .47581 L
s
.92092 .47793 m
.92092 .47741 L
s
.92198 .47793 m
.92198 .47739 L
s
.92304 .47793 m
.92304 .47734 L
s
.92411 .47793 m
.92411 .47579 L
s
.92517 .47793 m
.92517 .47732 L
s
.92623 .47793 m
.92623 .47753 L
s
.9273 .47793 m
.9273 .47736 L
s
.92836 .47793 m
.92836 .47804 L
s
.92942 .47793 m
.92942 .47791 L
s
.93048 .47793 m
.93048 .47709 L
s
.93155 .47793 m
.93155 .47705 L
s
.93261 .47793 m
.93261 .47746 L
s
.93367 .47793 m
.93367 .47724 L
s
.93474 .47793 m
.93474 .47735 L
s
.9358 .47793 m
.9358 .47772 L
s
.93686 .47793 m
.93686 .47594 L
s
.93793 .47793 m
.93793 .47575 L
s
.93899 .47793 m
.93899 .47816 L
s
.94005 .47793 m
.94005 .47895 L
s
.94111 .47793 m
.94111 .47929 L
s
.94218 .47793 m
.94218 .47663 L
s
.94324 .47793 m
.94324 .47645 L
s
.9443 .47793 m
.9443 .4769 L
s
.94537 .47793 m
.94537 .47914 L
s
.94643 .47793 m
.94643 .47931 L
s
.94749 .47793 m
.94749 .47932 L
s
.94855 .47793 m
.94855 .47822 L
s
.94962 .47793 m
.94962 .47754 L
s
.95068 .47793 m
.95068 .47591 L
s
.95174 .47793 m
.95174 .47689 L
s
.95281 .47793 m
.95281 .47785 L
s
.95387 .47793 m
.95387 .47736 L
s
.95493 .47793 m
.95493 .47767 L
s
.95599 .47793 m
.95599 .47753 L
s
.95706 .47793 m
.95706 .47881 L
s
.95812 .47793 m
.95812 .47897 L
s
.95918 .47793 m
.95918 .47865 L
s
.96025 .47793 m
.96025 .47747 L
s
.96131 .47793 m
.96131 .47715 L
s
.96237 .47793 m
.96237 .47693 L
s
.96344 .47793 m
.96344 .47977 L
s
.9645 .47793 m
.9645 .47813 L
s
.96556 .47793 m
.96556 .47783 L
s
.96662 .47793 m
.96662 .47731 L
s
.96769 .47793 m
.96769 .47814 L
s
.96875 .47793 m
.96875 .47745 L
s
.96981 .47793 m
.96981 .47873 L
s
.97088 .47793 m
.97088 .47873 L
s
.97194 .47793 m
.97194 .47792 L
s
.973 .47793 m
.973 .47992 L
s
.97406 .47793 m
.97406 .47711 L
s
.97513 .47793 m
.97513 .47766 L
s
.02381 .53566 m
.02381 .53583 L
s
.02434 .53566 m
.02434 .53555 L
s
.02487 .53566 m
.02487 .53563 L
s
.0254 .53566 m
.0254 .53562 L
s
.02594 .53566 m
.02594 .53573 L
s
.02647 .53566 m
.02647 .5356 L
s
.027 .53566 m
.027 .53565 L
s
.02753 .53566 m
.02753 .53572 L
s
.02806 .53566 m
.02806 .53571 L
s
.02859 .53566 m
.02859 .53562 L
s
.02912 .53566 m
.02912 .53578 L
s
.02966 .53566 m
.02966 .53582 L
s
.03019 .53566 m
.03019 .53586 L
s
.03072 .53566 m
.03072 .53568 L
s
.03125 .53566 m
.03125 .5356 L
s
.03178 .53566 m
.03178 .53549 L
s
.03231 .53566 m
.03231 .53547 L
s
.03284 .53566 m
.03284 .53557 L
s
.03338 .53566 m
.03338 .53556 L
s
.03391 .53566 m
.03391 .5357 L
s
.03444 .53566 m
.03444 .53575 L
s
.03497 .53566 m
.03497 .53578 L
s
.0355 .53566 m
.0355 .53581 L
s
.03603 .53566 m
.03603 .53581 L
s
.03656 .53566 m
.03656 .53574 L
s
.0371 .53566 m
.0371 .53569 L
s
.03763 .53566 m
.03763 .53578 L
s
.03816 .53566 m
.03816 .53567 L
s
.03869 .53566 m
.03869 .53562 L
s
.03922 .53566 m
.03922 .53546 L
s
.03975 .53566 m
.03975 .53564 L
s
.04028 .53566 m
.04028 .53563 L
s
.04082 .53566 m
.04082 .53541 L
s
.04135 .53566 m
.04135 .53541 L
s
.04188 .53566 m
.04188 .5357 L
s
.04241 .53566 m
.04241 .5358 L
s
.04294 .53566 m
.04294 .53571 L
s
.04347 .53566 m
.04347 .53569 L
s
.04401 .53566 m
.04401 .53555 L
s
.04454 .53566 m
.04454 .53592 L
s
.04507 .53566 m
.04507 .5357 L
s
.0456 .53566 m
.0456 .53584 L
s
.04613 .53566 m
.04613 .5358 L
s
.04666 .53566 m
.04666 .53563 L
s
.04719 .53566 m
.04719 .5355 L
s
.04773 .53566 m
.04773 .53573 L
s
.04826 .53566 m
.04826 .5359 L
s
.04879 .53566 m
.04879 .53558 L
s
.04932 .53566 m
.04932 .53572 L
s
.04985 .53566 m
.04985 .53562 L
s
.05038 .53566 m
.05038 .53588 L
s
.05091 .53566 m
.05091 .53562 L
s
.05145 .53566 m
.05145 .53572 L
s
.05198 .53566 m
.05198 .53585 L
s
.05251 .53566 m
.05251 .53573 L
s
.05304 .53566 m
.05304 .53547 L
s
.05357 .53566 m
.05357 .53589 L
s
.0541 .53566 m
.0541 .53561 L
s
.05463 .53566 m
.05463 .53535 L
s
.05517 .53566 m
.05517 .53552 L
s
.0557 .53566 m
.0557 .53569 L
s
.05623 .53566 m
.05623 .53518 L
s
.05676 .53566 m
.05676 .53544 L
s
.05729 .53566 m
.05729 .53553 L
s
.05782 .53566 m
.05782 .53604 L
s
.05835 .53566 m
.05835 .53589 L
s
.05889 .53566 m
.05889 .53567 L
s
.05942 .53566 m
.05942 .53585 L
s
.05995 .53566 m
.05995 .536 L
s
.06048 .53566 m
.06048 .53554 L
s
.06101 .53566 m
.06101 .53551 L
s
.06154 .53566 m
.06154 .53584 L
s
.06207 .53566 m
.06207 .53611 L
s
.06261 .53566 m
.06261 .53557 L
s
.06314 .53566 m
.06314 .53552 L
s
.06367 .53566 m
.06367 .53589 L
s
.0642 .53566 m
.0642 .53562 L
s
.06473 .53566 m
.06473 .53511 L
s
.06526 .53566 m
.06526 .53568 L
s
.0658 .53566 m
.0658 .53595 L
s
.06633 .53566 m
.06633 .53595 L
s
.06686 .53566 m
.06686 .53554 L
s
.06739 .53566 m
.06739 .53581 L
s
.06792 .53566 m
.06792 .53595 L
s
.06845 .53566 m
.06845 .53569 L
s
.06898 .53566 m
.06898 .53528 L
s
.06952 .53566 m
.06952 .5358 L
s
.07005 .53566 m
.07005 .5358 L
s
.07058 .53566 m
.07058 .53551 L
s
.07111 .53566 m
.07111 .53525 L
s
.07164 .53566 m
.07164 .53591 L
s
.07217 .53566 m
.07217 .53589 L
s
.0727 .53566 m
.0727 .53536 L
s
.07324 .53566 m
.07324 .53548 L
s
.07377 .53566 m
.07377 .53619 L
s
.0743 .53566 m
.0743 .53572 L
s
.07483 .53566 m
.07483 .53532 L
s
.07536 .53566 m
.07536 .53557 L
s
.07589 .53566 m
.07589 .53625 L
s
.07642 .53566 m
.07642 .5361 L
s
.07696 .53566 m
.07696 .53548 L
s
.07749 .53566 m
.07749 .53519 L
s
.07802 .53566 m
.07802 .53606 L
s
.07855 .53566 m
.07855 .53604 L
s
.07908 .53566 m
.07908 .53553 L
s
.07961 .53566 m
.07961 .53529 L
s
.08014 .53566 m
.08014 .53584 L
s
.08068 .53566 m
.08068 .53588 L
s
.08121 .53566 m
.08121 .53534 L
s
.08174 .53566 m
.08174 .53529 L
s
.08227 .53566 m
.08227 .53619 L
s
.0828 .53566 m
.0828 .53594 L
s
.08333 .53566 m
.08333 .5354 L
s
.08386 .53566 m
.08386 .53564 L
s
.0844 .53566 m
.0844 .53618 L
s
.08493 .53566 m
.08493 .53583 L
s
.08546 .53566 m
.08546 .53515 L
s
.08599 .53566 m
.08599 .53569 L
s
.08652 .53566 m
.08652 .53622 L
s
.08705 .53566 m
.08705 .53575 L
s
.08759 .53566 m
.08759 .53493 L
s
.08812 .53566 m
.08812 .53577 L
s
.08865 .53566 m
.08865 .53612 L
s
.08918 .53566 m
.08918 .53528 L
s
.08971 .53566 m
.08971 .53527 L
s
.09024 .53566 m
.09024 .53625 L
s
.09077 .53566 m
.09077 .53633 L
s
.09131 .53566 m
.09131 .53543 L
s
.09184 .53566 m
.09184 .53536 L
s
.09237 .53566 m
.09237 .53641 L
s
.0929 .53566 m
.0929 .53587 L
s
.09343 .53566 m
.09343 .53481 L
s
.09396 .53566 m
.09396 .53518 L
s
.09449 .53566 m
.09449 .53673 L
s
.09503 .53566 m
.09503 .53558 L
s
.09556 .53566 m
.09556 .5349 L
s
.09609 .53566 m
.09609 .53557 L
s
.09662 .53566 m
.09662 .53649 L
s
.09715 .53566 m
.09715 .53551 L
s
.09768 .53566 m
.09768 .53437 L
s
.09821 .53566 m
.09821 .5358 L
s
.09875 .53566 m
.09875 .53726 L
s
.09928 .53566 m
.09928 .53532 L
s
.09981 .53566 m
.09981 .53484 L
s
.10034 .53566 m
.10034 .53597 L
s
.10087 .53566 m
.10087 .53649 L
s
.1014 .53566 m
.1014 .53528 L
s
.10193 .53566 m
.10193 .53417 L
s
.10247 .53566 m
.10247 .53592 L
s
.103 .53566 m
.103 .53704 L
s
.10353 .53566 m
.10353 .53484 L
s
.10406 .53566 m
.10406 .5345 L
s
.10459 .53566 m
.10459 .53605 L
s
.10512 .53566 m
.10512 .53672 L
s
.10565 .53566 m
.10565 .53604 L
s
.10619 .53566 m
.10619 .53338 L
s
.10672 .53566 m
.10672 .53587 L
s
.10725 .53566 m
.10725 .5379 L
s
.10778 .53566 m
.10778 .53501 L
s
.10831 .53566 m
.10831 .5343 L
s
.10884 .53566 m
.10884 .5356 L
s
.10937 .53566 m
.10937 .53649 L
s
.10991 .53566 m
.10991 .53736 L
s
.11044 .53566 m
.11044 .53117 L
s
.11097 .53566 m
.11097 .53146 L
s
.1115 .53566 m
.1115 .54066 L
s
.11203 .53566 m
.11203 .54249 L
s
.11256 .53566 m
.11256 .53485 L
s
.1131 .53566 m
.1131 .5294 L
s
.11363 .53566 m
.11363 .53215 L
s
.11416 .53566 m
.11416 .53693 L
s
.11469 .53566 m
.11469 .5278 L
s
.11522 .53566 m
.11522 .53413 L
s
.11575 .53566 m
.11575 .53827 L
s
.11628 .53566 m
.11628 .53983 L
s
.11682 .53566 m
.11682 .54031 L
s
.11735 .53566 m
.11735 .53493 L
s
.11788 .53566 m
.11788 .53426 L
s
.11841 .53566 m
.11841 .53837 L
s
.11894 .53566 m
.11894 .52747 L
s
.11947 .53566 m
.11947 .52475 L
s
.12 .53566 m
.12 .52917 L
s
.12054 .53566 m
.12054 .53438 L
s
.12107 .53566 m
.12107 .53756 L
s
.1216 .53566 m
.1216 .53705 L
s
.12213 .53566 m
.12213 .53458 L
s
.12266 .53566 m
.12266 .54528 L
s
.12319 .53566 m
.12319 .53788 L
s
.12372 .53566 m
.12372 .5282 L
s
.12426 .53566 m
.12426 .53163 L
s
.12479 .53566 m
.12479 .53013 L
s
.12532 .53566 m
.12532 .53383 L
s
.12585 .53566 m
.12585 .53641 L
s
.12638 .53566 m
.12638 .52698 L
s
.12691 .53566 m
.12691 .54729 L
s
.12744 .53566 m
.12744 .54192 L
s
.12798 .53566 m
.12798 .53256 L
s
.12851 .53566 m
.12851 .53687 L
s
.12904 .53566 m
.12904 .53004 L
s
.12957 .53566 m
.12957 .53792 L
s
.1301 .53566 m
.1301 .53983 L
s
.13063 .53566 m
.13063 .52402 L
s
.13116 .53566 m
.13116 .54785 L
s
.1317 .53566 m
.1317 .54392 L
s
.13223 .53566 m
.13223 .53871 L
s
.13276 .53566 m
.13276 .54066 L
s
.13329 .53566 m
.13329 .53088 L
s
.13382 .53566 m
.13382 .54248 L
s
.13435 .53566 m
.13435 .54338 L
s
.13489 .53566 m
.13489 .5248 L
s
.13542 .53566 m
.13542 .54798 L
s
.13595 .53566 m
.13595 .54415 L
s
.13648 .53566 m
.13648 .54157 L
s
.13701 .53566 m
.13701 .54135 L
s
.13754 .53566 m
.13754 .53185 L
s
.13807 .53566 m
.13807 .54473 L
s
.13861 .53566 m
.13861 .54476 L
s
.13914 .53566 m
.13914 .5269 L
s
.13967 .53566 m
.13967 .5456 L
s
.1402 .53566 m
.1402 .54398 L
s
.14073 .53566 m
.14073 .54235 L
s
.14126 .53566 m
.14126 .54263 L
s
.14179 .53566 m
.14179 .53244 L
s
.14233 .53566 m
.14233 .54479 L
s
.14286 .53566 m
.14286 .54548 L
s
.14339 .53566 m
.14339 .52796 L
s
.14392 .53566 m
.14392 .54609 L
s
.14445 .53566 m
.14445 .54402 L
s
.14498 .53566 m
.14498 .54334 L
s
.14551 .53566 m
.14551 .54275 L
s
.14605 .53566 m
.14605 .533 L
s
.14658 .53566 m
.14658 .54563 L
s
.14711 .53566 m
.14711 .54303 L
s
.14764 .53566 m
.14764 .52873 L
s
.14817 .53566 m
.14817 .54851 L
s
.1487 .53566 m
.1487 .54436 L
s
.14923 .53566 m
.14923 .54352 L
s
.14977 .53566 m
.14977 .5434 L
s
.1503 .53566 m
.1503 .53475 L
s
.15083 .53566 m
.15083 .54535 L
s
.15136 .53566 m
.15136 .53943 L
s
.15189 .53566 m
.15189 .52971 L
s
.15242 .53566 m
.15242 .55121 L
s
.15295 .53566 m
.15295 .54422 L
s
.15349 .53566 m
.15349 .54045 L
s
.15402 .53566 m
.15402 .54375 L
s
.15455 .53566 m
.15455 .53721 L
s
.15508 .53566 m
.15508 .54483 L
s
.15561 .53566 m
.15561 .53729 L
s
.15614 .53566 m
.15614 .53172 L
s
.15668 .53566 m
.15668 .55225 L
s
.15721 .53566 m
.15721 .54155 L
s
.15774 .53566 m
.15774 .53496 L
s
.15827 .53566 m
.15827 .54328 L
s
.1588 .53566 m
.1588 .53649 L
s
.15933 .53566 m
.15933 .54135 L
s
.15986 .53566 m
.15986 .53225 L
s
.1604 .53566 m
.1604 .53298 L
s
.16093 .53566 m
.16093 .54625 L
s
.16146 .53566 m
.16146 .53183 L
s
.16199 .53566 m
.16199 .52702 L
s
.16252 .53566 m
.16252 .53958 L
s
.16305 .53566 m
.16305 .53353 L
s
.16358 .53566 m
.16358 .53447 L
s
.16412 .53566 m
.16412 .53028 L
s
.16465 .53566 m
.16465 .53416 L
s
.16518 .53566 m
.16518 .53472 L
s
.16571 .53566 m
.16571 .52546 L
s
.16624 .53566 m
.16624 .522 L
s
.16677 .53566 m
.16677 .53564 L
s
.1673 .53566 m
.1673 .53196 L
s
.16784 .53566 m
.16784 .52627 L
s
.16837 .53566 m
.16837 .53382 L
s
.1689 .53566 m
.1689 .53585 L
s
.16943 .53566 m
.16943 .52653 L
s
.16996 .53566 m
.16996 .53383 L
s
.17049 .53566 m
.17049 .52757 L
s
.17102 .53566 m
.17102 .53619 L
s
.17156 .53566 m
.17156 .53441 L
s
.17209 .53566 m
.17209 .5241 L
s
.17262 .53566 m
.17262 .5393 L
s
.17315 .53566 m
.17315 .53572 L
s
.17368 .53566 m
.17368 .52672 L
s
.17421 .53566 m
.17421 .54543 L
s
.17474 .53566 m
.17474 .53736 L
s
.17528 .53566 m
.17528 .53574 L
s
.17581 .53566 m
.17581 .54042 L
s
.17634 .53566 m
.17634 .53014 L
s
.17687 .53566 m
.17687 .54171 L
s
.1774 .53566 m
.1774 .53574 L
s
.17793 .53566 m
.17793 .53377 L
s
.17847 .53566 m
.17847 .54422 L
s
.179 .53566 m
.179 .53336 L
s
.17953 .53566 m
.17953 .52887 L
s
.18006 .53566 m
.18006 .54035 L
s
.18059 .53566 m
.18059 .53462 L
s
.18112 .53566 m
.18112 .5364 L
s
.18165 .53566 m
.18165 .53856 L
s
.18219 .53566 m
.18219 .53958 L
s
.18272 .53566 m
.18272 .53845 L
s
.18325 .53566 m
.18325 .53693 L
s
.18378 .53566 m
.18378 .53723 L
s
.18431 .53566 m
.18431 .54195 L
s
.18484 .53566 m
.18484 .53534 L
s
.18537 .53566 m
.18537 .53247 L
s
.18591 .53566 m
.18591 .53566 L
s
.18644 .53566 m
.18644 .53585 L
s
.18697 .53566 m
.18697 .53555 L
s
.1875 .53566 m
.1875 .53936 L
s
.18803 .53566 m
.18803 .53488 L
s
.18856 .53566 m
.18856 .53476 L
s
.18909 .53566 m
.18909 .53408 L
s
.18963 .53566 m
.18963 .53565 L
s
.19016 .53566 m
.19016 .53557 L
s
.19069 .53566 m
.19069 .53181 L
s
.19122 .53566 m
.19122 .53593 L
s
.19175 .53566 m
.19175 .53104 L
s
.19228 .53566 m
.19228 .53674 L
s
.19281 .53566 m
.19281 .5322 L
s
.19335 .53566 m
.19335 .53349 L
s
.19388 .53566 m
.19388 .53347 L
s
.19441 .53566 m
.19441 .53671 L
s
.19494 .53566 m
.19494 .53324 L
s
.19547 .53566 m
.19547 .53397 L
s
.196 .53566 m
.196 .53774 L
s
.19653 .53566 m
.19653 .53232 L
s
.19707 .53566 m
.19707 .53763 L
s
.1976 .53566 m
.1976 .53664 L
s
.19813 .53566 m
.19813 .53499 L
s
.19866 .53566 m
.19866 .53513 L
s
.19919 .53566 m
.19919 .53612 L
s
.19972 .53566 m
.19972 .53192 L
s
.20026 .53566 m
.20026 .53809 L
s
.20079 .53566 m
.20079 .5354 L
s
.20132 .53566 m
.20132 .53776 L
s
.20185 .53566 m
.20185 .53659 L
s
.20238 .53566 m
.20238 .53738 L
s
.20291 .53566 m
.20291 .53654 L
s
.20344 .53566 m
.20344 .53583 L
s
.20398 .53566 m
.20398 .53454 L
s
.20451 .53566 m
.20451 .53752 L
s
.20504 .53566 m
.20504 .53216 L
s
.20557 .53566 m
.20557 .5373 L
s
.2061 .53566 m
.2061 .53328 L
s
.20663 .53566 m
.20663 .5355 L
s
.20716 .53566 m
.20716 .53628 L
s
.2077 .53566 m
.2077 .53308 L
s
.20823 .53566 m
.20823 .53603 L
s
.20876 .53566 m
.20876 .53633 L
s
.20929 .53566 m
.20929 .53228 L
s
.20982 .53566 m
.20982 .53706 L
s
.21035 .53566 m
.21035 .53493 L
s
.21088 .53566 m
.21088 .53634 L
s
.21142 .53566 m
.21142 .53674 L
s
.21195 .53566 m
.21195 .53448 L
s
.21248 .53566 m
.21248 .53612 L
s
.21301 .53566 m
.21301 .53619 L
s
.21354 .53566 m
.21354 .53366 L
s
.21407 .53566 m
.21407 .53654 L
s
.2146 .53566 m
.2146 .53531 L
s
.21514 .53566 m
.21514 .53519 L
s
.21567 .53566 m
.21567 .53621 L
s
.2162 .53566 m
.2162 .53552 L
s
.21673 .53566 m
.21673 .53774 L
s
.21726 .53566 m
.21726 .53436 L
s
.21779 .53566 m
.21779 .53633 L
s
.21832 .53566 m
.21832 .53472 L
s
.21886 .53566 m
.21886 .53483 L
s
.21939 .53566 m
.21939 .534 L
s
.21992 .53566 m
.21992 .53339 L
s
.22045 .53566 m
.22045 .53644 L
s
.22098 .53566 m
.22098 .53532 L
s
.22151 .53566 m
.22151 .53543 L
s
.22205 .53566 m
.22205 .53673 L
s
.22258 .53566 m
.22258 .53561 L
s
.22311 .53566 m
.22311 .53578 L
s
.22364 .53566 m
.22364 .53492 L
s
.22417 .53566 m
.22417 .53578 L
s
.2247 .53566 m
.2247 .53567 L
s
.22523 .53566 m
.22523 .53388 L
s
.22577 .53566 m
.22577 .5358 L
s
.2263 .53566 m
.2263 .53529 L
s
.22683 .53566 m
.22683 .53627 L
s
.22736 .53566 m
.22736 .53619 L
s
.22789 .53566 m
.22789 .5354 L
s
.22842 .53566 m
.22842 .53649 L
s
.22895 .53566 m
.22895 .53503 L
s
.22949 .53566 m
.22949 .53401 L
s
.23002 .53566 m
.23002 .53566 L
s
.23055 .53566 m
.23055 .53412 L
s
.23108 .53566 m
.23108 .53557 L
s
.23161 .53566 m
.23161 .53515 L
s
.23214 .53566 m
.23214 .5354 L
s
.23267 .53566 m
.23267 .53605 L
s
.23321 .53566 m
.23321 .53455 L
s
.23374 .53566 m
.23374 .53543 L
s
.23427 .53566 m
.23427 .53512 L
s
.2348 .53566 m
.2348 .53521 L
s
.23533 .53566 m
.23533 .53448 L
s
.23586 .53566 m
.23586 .53455 L
s
.23639 .53566 m
.23639 .53448 L
s
.23693 .53566 m
.23693 .53427 L
s
.23746 .53566 m
.23746 .53448 L
s
.23799 .53566 m
.23799 .53581 L
s
.23852 .53566 m
.23852 .53533 L
s
.23905 .53566 m
.23905 .53561 L
s
.23958 .53566 m
.23958 .53553 L
s
.24011 .53566 m
.24011 .53583 L
s
.24065 .53566 m
.24065 .53566 L
s
.24118 .53566 m
.24118 .53494 L
s
.24171 .53566 m
.24171 .53583 L
s
.24224 .53566 m
.24224 .53578 L
s
.24277 .53566 m
.24277 .53464 L
s
.2433 .53566 m
.2433 .53573 L
s
.24384 .53566 m
.24384 .53539 L
s
.24437 .53566 m
.24437 .5359 L
s
.2449 .53566 m
.2449 .53612 L
s
.24543 .53566 m
.24543 .53502 L
s
.24596 .53566 m
.24596 .53638 L
s
.24649 .53566 m
.24649 .53545 L
s
.24702 .53566 m
.24702 .53442 L
s
.24756 .53566 m
.24756 .53583 L
s
.24809 .53566 m
.24809 .53468 L
s
.24862 .53566 m
.24862 .53555 L
s
.24915 .53566 m
.24915 .53506 L
s
.24968 .53566 m
.24968 .53534 L
s
.25021 .53566 m
.25021 .53528 L
s
.25074 .53566 m
.25074 .53572 L
s
.25128 .53566 m
.25128 .53502 L
s
.25181 .53566 m
.25181 .53608 L
s
.25234 .53566 m
.25234 .53524 L
s
.25287 .53566 m
.25287 .53522 L
s
.2534 .53566 m
.2534 .53559 L
s
.25393 .53566 m
.25393 .53513 L
s
.25446 .53566 m
.25446 .53532 L
s
.255 .53566 m
.255 .53622 L
s
.25553 .53566 m
.25553 .53514 L
s
.25606 .53566 m
.25606 .53609 L
s
.25659 .53566 m
.25659 .53573 L
s
.25712 .53566 m
.25712 .53491 L
s
.25765 .53566 m
.25765 .53626 L
s
.25818 .53566 m
.25818 .53558 L
s
.25872 .53566 m
.25872 .5357 L
s
.25925 .53566 m
.25925 .53595 L
s
.25978 .53566 m
.25978 .53553 L
s
.26031 .53566 m
.26031 .53506 L
s
.26084 .53566 m
.26084 .5358 L
s
.26137 .53566 m
.26137 .53545 L
s
.2619 .53566 m
.2619 .53606 L
s
.26244 .53566 m
.26244 .53603 L
s
.26297 .53566 m
.26297 .53542 L
s
.2635 .53566 m
.2635 .53595 L
s
.26403 .53566 m
.26403 .53561 L
s
.26456 .53566 m
.26456 .53532 L
s
.26509 .53566 m
.26509 .53589 L
s
.26562 .53566 m
.26562 .53567 L
s
.26616 .53566 m
.26616 .53581 L
s
.26669 .53566 m
.26669 .53584 L
s
.26722 .53566 m
.26722 .53526 L
s
.26775 .53566 m
.26775 .53617 L
s
.26828 .53566 m
.26828 .53556 L
s
.26881 .53566 m
.26881 .53523 L
s
.26935 .53566 m
.26935 .53578 L
s
.26988 .53566 m
.26988 .53561 L
s
.27041 .53566 m
.27041 .53553 L
s
.27094 .53566 m
.27094 .53569 L
s
.27147 .53566 m
.27147 .53504 L
s
.272 .53566 m
.272 .53603 L
s
.27253 .53566 m
.27253 .53559 L
s
.27307 .53566 m
.27307 .53544 L
s
.2736 .53566 m
.2736 .53594 L
s
.27413 .53566 m
.27413 .53543 L
s
.27466 .53566 m
.27466 .53567 L
s
.27519 .53566 m
.27519 .53592 L
s
.27572 .53566 m
.27572 .53518 L
s
.27625 .53566 m
.27625 .53625 L
s
.27679 .53566 m
.27679 .53579 L
s
.27732 .53566 m
.27732 .53544 L
s
.27785 .53566 m
.27785 .53599 L
s
.27838 .53566 m
.27838 .53574 L
s
.27891 .53566 m
.27891 .53574 L
s
.27944 .53566 m
.27944 .53615 L
s
.27997 .53566 m
.27997 .53548 L
s
.28051 .53566 m
.28051 .53593 L
s
.28104 .53566 m
.28104 .53531 L
s
.28157 .53566 m
.28157 .53503 L
s
.2821 .53566 m
.2821 .5356 L
s
.28263 .53566 m
.28263 .53538 L
s
.28316 .53566 m
.28316 .53599 L
s
.28369 .53566 m
.28369 .53579 L
s
.28423 .53566 m
.28423 .53558 L
s
.28476 .53566 m
.28476 .53592 L
s
.28529 .53566 m
.28529 .53566 L
s
.28582 .53566 m
.28582 .53562 L
s
.28635 .53566 m
.28635 .53572 L
s
.28688 .53566 m
.28688 .53558 L
s
.28741 .53566 m
.28741 .53585 L
s
.28795 .53566 m
.28795 .5353 L
s
.28848 .53566 m
.28848 .53572 L
s
.28901 .53566 m
.28901 .53553 L
s
.28954 .53566 m
.28954 .5358 L
s
.29007 .53566 m
.29007 .53583 L
s
.2906 .53566 m
.2906 .5357 L
s
.29114 .53566 m
.29114 .53554 L
s
.29167 .53566 m
.29167 .53564 L
s
.2922 .53566 m
.2922 .53539 L
s
.29273 .53566 m
.29273 .53576 L
s
.29326 .53566 m
.29326 .53547 L
s
.29379 .53566 m
.29379 .53563 L
s
.29432 .53566 m
.29432 .53573 L
s
.29486 .53566 m
.29486 .53548 L
s
.29539 .53566 m
.29539 .53584 L
s
.29592 .53566 m
.29592 .5357 L
s
.29645 .53566 m
.29645 .53582 L
s
.29698 .53566 m
.29698 .53597 L
s
.29751 .53566 m
.29751 .53575 L
s
.29804 .53566 m
.29804 .53576 L
s
.29858 .53566 m
.29858 .53583 L
s
.29911 .53566 m
.29911 .53555 L
s
.29964 .53566 m
.29964 .53588 L
s
.30017 .53566 m
.30017 .53563 L
s
.3007 .53566 m
.3007 .53578 L
s
.30123 .53566 m
.30123 .53569 L
s
.30176 .53566 m
.30176 .53566 L
s
.3023 .53566 m
.3023 .53569 L
s
.30283 .53566 m
.30283 .53579 L
s
.30336 .53566 m
.30336 .5356 L
s
.30389 .53566 m
.30389 .53574 L
s
.30442 .53566 m
.30442 .53567 L
s
.30495 .53566 m
.30495 .53546 L
s
.30548 .53566 m
.30548 .5355 L
s
.30602 .53566 m
.30602 .53561 L
s
.30655 .53566 m
.30655 .53555 L
s
.30708 .53566 m
.30708 .53586 L
s
.30761 .53566 m
.30761 .53581 L
s
.30814 .53566 m
.30814 .53547 L
s
.30867 .53566 m
.30867 .5358 L
s
.3092 .53566 m
.3092 .53536 L
s
.30974 .53566 m
.30974 .5354 L
s
.31027 .53566 m
.31027 .53581 L
s
.3108 .53566 m
.3108 .53549 L
s
.31133 .53566 m
.31133 .53546 L
s
.31186 .53566 m
.31186 .53577 L
s
.31239 .53566 m
.31239 .53578 L
s
.31293 .53566 m
.31293 .5356 L
s
.31346 .53566 m
.31346 .5353 L
s
.31399 .53566 m
.31399 .53543 L
s
.31452 .53566 m
.31452 .53578 L
s
.31505 .53566 m
.31505 .53541 L
s
.31558 .53566 m
.31558 .53583 L
s
.31611 .53566 m
.31611 .53561 L
s
.31665 .53566 m
.31665 .53643 L
s
.31718 .53566 m
.31718 .5358 L
s
.31771 .53566 m
.31771 .5346 L
s
.31824 .53566 m
.31824 .53557 L
s
.31877 .53566 m
.31877 .53562 L
s
.3193 .53566 m
.3193 .53579 L
s
.31983 .53566 m
.31983 .53532 L
s
.32037 .53566 m
.32037 .53583 L
s
.3209 .53566 m
.3209 .53597 L
s
.32143 .53566 m
.32143 .53592 L
s
.32196 .53566 m
.32196 .53558 L
s
.32249 .53566 m
.32249 .53543 L
s
.32302 .53566 m
.32302 .53573 L
s
.32355 .53566 m
.32355 .53586 L
s
.32409 .53566 m
.32409 .53574 L
s
.32462 .53566 m
.32462 .53568 L
s
.32515 .53566 m
.32515 .53561 L
s
.32568 .53566 m
.32568 .53541 L
s
.32621 .53566 m
.32621 .53556 L
s
.32674 .53566 m
.32674 .53696 L
s
.32727 .53566 m
.32727 .53491 L
s
.32781 .53566 m
.32781 .53419 L
s
.32834 .53566 m
.32834 .53464 L
s
.32887 .53566 m
.32887 .53725 L
s
.3294 .53566 m
.3294 .53609 L
s
.32993 .53566 m
.32993 .53533 L
s
.33046 .53566 m
.33046 .53423 L
s
.33099 .53566 m
.33099 .53781 L
s
.33153 .53566 m
.33153 .53831 L
s
.33206 .53566 m
.33206 .53485 L
s
.33259 .53566 m
.33259 .53227 L
s
.33312 .53566 m
.33312 .53457 L
s
.33365 .53566 m
.33365 .53553 L
s
.33418 .53566 m
.33418 .53782 L
s
.33472 .53566 m
.33472 .53545 L
s
.33525 .53566 m
.33525 .54004 L
s
.33578 .53566 m
.33578 .53302 L
s
.33631 .53566 m
.33631 .53054 L
s
.33684 .53566 m
.33684 .53265 L
s
.33737 .53566 m
.33737 .53904 L
s
.3379 .53566 m
.3379 .54016 L
s
.33844 .53566 m
.33844 .53686 L
s
.33897 .53566 m
.33897 .53489 L
s
.3395 .53566 m
.3395 .53253 L
s
.34003 .53566 m
.34003 .53098 L
s
.34056 .53566 m
.34056 .53737 L
s
.34109 .53566 m
.34109 .54085 L
s
.34162 .53566 m
.34162 .54088 L
s
.34216 .53566 m
.34216 .53396 L
s
.34269 .53566 m
.34269 .53082 L
s
.34322 .53566 m
.34322 .53658 L
s
.34375 .53566 m
.34375 .53322 L
s
.34428 .53566 m
.34428 .54128 L
s
.34481 .53566 m
.34481 .53894 L
s
.34534 .53566 m
.34534 .53351 L
s
.34588 .53566 m
.34588 .53195 L
s
.34641 .53566 m
.34641 .53239 L
s
.34694 .53566 m
.34694 .5347 L
s
.34747 .53566 m
.34747 .53797 L
s
.348 .53566 m
.348 .53601 L
s
.34853 .53566 m
.34853 .53449 L
s
.34906 .53566 m
.34906 .53128 L
s
.3496 .53566 m
.3496 .53384 L
s
.35013 .53566 m
.35013 .53847 L
s
.35066 .53566 m
.35066 .54152 L
s
.35119 .53566 m
.35119 .5369 L
s
.35172 .53566 m
.35172 .53494 L
s
.35225 .53566 m
.35225 .53807 L
s
.35278 .53566 m
.35278 .53201 L
s
.35332 .53566 m
.35332 .54239 L
s
.35385 .53566 m
.35385 .53762 L
s
.35438 .53566 m
.35438 .53184 L
s
.35491 .53566 m
.35491 .53245 L
s
.35544 .53566 m
.35544 .53245 L
s
.35597 .53566 m
.35597 .53465 L
s
.35651 .53566 m
.35651 .5372 L
s
.35704 .53566 m
.35704 .53542 L
s
.35757 .53566 m
.35757 .53405 L
s
.3581 .53566 m
.3581 .53236 L
s
.35863 .53566 m
.35863 .5358 L
s
.35916 .53566 m
.35916 .53901 L
s
.35969 .53566 m
.35969 .54133 L
s
.36023 .53566 m
.36023 .53615 L
s
.36076 .53566 m
.36076 .53377 L
s
.36129 .53566 m
.36129 .53793 L
s
.36182 .53566 m
.36182 .53186 L
s
.36235 .53566 m
.36235 .54287 L
s
.36288 .53566 m
.36288 .53686 L
s
.36341 .53566 m
.36341 .53097 L
s
.36395 .53566 m
.36395 .53195 L
s
.36448 .53566 m
.36448 .53356 L
s
.36501 .53566 m
.36501 .53539 L
s
.36554 .53566 m
.36554 .53731 L
s
.36607 .53566 m
.36607 .53483 L
s
.3666 .53566 m
.3666 .53289 L
s
.36713 .53566 m
.36713 .53219 L
s
.36767 .53566 m
.36767 .53895 L
s
.3682 .53566 m
.3682 .54128 L
s
.36873 .53566 m
.36873 .54092 L
s
.36926 .53566 m
.36926 .53347 L
s
.36979 .53566 m
.36979 .53163 L
s
.37032 .53566 m
.37032 .53703 L
s
.37085 .53566 m
.37085 .53452 L
s
.37139 .53566 m
.37139 .54225 L
s
.37192 .53566 m
.37192 .53435 L
s
.37245 .53566 m
.37245 .52875 L
s
.37298 .53566 m
.37298 .53195 L
s
.37351 .53566 m
.37351 .53782 L
s
.37404 .53566 m
.37404 .53876 L
s
.37457 .53566 m
.37457 .53592 L
s
.37511 .53566 m
.37511 .53536 L
s
.37564 .53566 m
.37564 .53135 L
s
.37617 .53566 m
.37617 .53615 L
s
.3767 .53566 m
.3767 .54323 L
s
.37723 .53566 m
.37723 .5368 L
s
.37776 .53566 m
.37776 .53263 L
s
.3783 .53566 m
.3783 .53242 L
s
.37883 .53566 m
.37883 .53569 L
s
.37936 .53566 m
.37936 .53995 L
s
.37989 .53566 m
.37989 .53576 L
s
.38042 .53566 m
.38042 .53357 L
s
.38095 .53566 m
.38095 .52969 L
s
.38148 .53566 m
.38148 .53795 L
s
.38202 .53566 m
.38202 .539 L
s
.38255 .53566 m
.38255 .53502 L
s
.38308 .53566 m
.38308 .53466 L
s
.38361 .53566 m
.38361 .53367 L
s
.38414 .53566 m
.38414 .53885 L
s
.38467 .53566 m
.38467 .53684 L
s
.3852 .53566 m
.3852 .5366 L
s
.38574 .53566 m
.38574 .5334 L
s
.38627 .53566 m
.38627 .53472 L
s
.3868 .53566 m
.3868 .5376 L
s
.38733 .53566 m
.38733 .53647 L
s
.38786 .53566 m
.38786 .5337 L
s
.38839 .53566 m
.38839 .5333 L
s
.38892 .53566 m
.38892 .53717 L
s
.38946 .53566 m
.38946 .53583 L
s
.38999 .53566 m
.38999 .53657 L
s
.39052 .53566 m
.39052 .53561 L
s
.39105 .53566 m
.39105 .53463 L
s
.39158 .53566 m
.39158 .5357 L
s
.39211 .53566 m
.39211 .53882 L
s
.39264 .53566 m
.39264 .53479 L
s
.39318 .53566 m
.39318 .53405 L
s
.39371 .53566 m
.39371 .53658 L
s
.39424 .53566 m
.39424 .53522 L
s
.39477 .53566 m
.39477 .53712 L
s
.3953 .53566 m
.3953 .53637 L
s
.39583 .53566 m
.39583 .53472 L
s
.39636 .53566 m
.39636 .53379 L
s
.3969 .53566 m
.3969 .53681 L
s
.39743 .53566 m
.39743 .53568 L
s
.39796 .53566 m
.39796 .53466 L
s
.39849 .53566 m
.39849 .53583 L
s
.39902 .53566 m
.39902 .53557 L
s
.39955 .53566 m
.39955 .53549 L
s
.40009 .53566 m
.40009 .53673 L
s
.40062 .53566 m
.40062 .53501 L
s
.40115 .53566 m
.40115 .53546 L
s
.40168 .53566 m
.40168 .53566 L
s
.40221 .53566 m
.40221 .53639 L
s
.40274 .53566 m
.40274 .53599 L
s
.40327 .53566 m
.40327 .53497 L
s
.40381 .53566 m
.40381 .53548 L
s
.40434 .53566 m
.40434 .53434 L
s
.40487 .53566 m
.40487 .53648 L
s
.4054 .53566 m
.4054 .53581 L
s
.40593 .53566 m
.40593 .53607 L
s
.40646 .53566 m
.40646 .53452 L
s
.40699 .53566 m
.40699 .53588 L
s
.40753 .53566 m
.40753 .53622 L
s
.40806 .53566 m
.40806 .53582 L
s
.40859 .53566 m
.40859 .53671 L
s
.40912 .53566 m
.40912 .53581 L
s
.40965 .53566 m
.40965 .53492 L
s
.41018 .53566 m
.41018 .5352 L
s
.41071 .53566 m
.41071 .53693 L
s
.41125 .53566 m
.41125 .53533 L
s
.41178 .53566 m
.41178 .5345 L
s
.41231 .53566 m
.41231 .53538 L
s
.41284 .53566 m
.41284 .53556 L
s
.41337 .53566 m
.41337 .53545 L
s
.4139 .53566 m
.4139 .53697 L
s
.41443 .53566 m
.41443 .53553 L
s
.41497 .53566 m
.41497 .53468 L
s
.4155 .53566 m
.4155 .53586 L
s
.41603 .53566 m
.41603 .53776 L
s
.41656 .53566 m
.41656 .53552 L
s
.41709 .53566 m
.41709 .53488 L
s
.41762 .53566 m
.41762 .53556 L
s
.41815 .53566 m
.41815 .53489 L
s
.41869 .53566 m
.41869 .53558 L
s
.41922 .53566 m
.41922 .53676 L
s
.41975 .53566 m
.41975 .53567 L
s
.42028 .53566 m
.42028 .53443 L
s
.42081 .53566 m
.42081 .53519 L
s
.42134 .53566 m
.42134 .53617 L
s
.42188 .53566 m
.42188 .53601 L
s
.42241 .53566 m
.42241 .53605 L
s
.42294 .53566 m
.42294 .53699 L
s
.42347 .53566 m
.42347 .53533 L
s
.424 .53566 m
.424 .53468 L
s
.42453 .53566 m
.42453 .53589 L
s
.42506 .53566 m
.42506 .53727 L
s
.4256 .53566 m
.4256 .53511 L
s
.42613 .53566 m
.42613 .53504 L
s
.42666 .53566 m
.42666 .53574 L
s
.42719 .53566 m
.42719 .53437 L
s
.42772 .53566 m
.42772 .53547 L
s
.42825 .53566 m
.42825 .5365 L
s
.42878 .53566 m
.42878 .53593 L
s
.42932 .53566 m
.42932 .53397 L
s
.42985 .53566 m
.42985 .53538 L
s
.43038 .53566 m
.43038 .53612 L
s
.43091 .53566 m
.43091 .53596 L
s
.43144 .53566 m
.43144 .53576 L
s
.43197 .53566 m
.43197 .53683 L
s
.4325 .53566 m
.4325 .53587 L
s
.43304 .53566 m
.43304 .53404 L
s
.43357 .53566 m
.43357 .53608 L
s
.4341 .53566 m
.4341 .53759 L
s
.43463 .53566 m
.43463 .53516 L
s
.43516 .53566 m
.43516 .53486 L
s
.43569 .53566 m
.43569 .53628 L
s
.43622 .53566 m
.43622 .53519 L
s
.43676 .53566 m
.43676 .53519 L
s
.43729 .53566 m
.43729 .53612 L
s
.43782 .53566 m
.43782 .53666 L
s
.43835 .53566 m
.43835 .53453 L
s
.43888 .53566 m
.43888 .53501 L
s
.43941 .53566 m
.43941 .53602 L
s
.43994 .53566 m
.43994 .53646 L
s
.44048 .53566 m
.44048 .53456 L
s
.44101 .53566 m
.44101 .53543 L
s
.44154 .53566 m
.44154 .53733 L
s
.44207 .53566 m
.44207 .53478 L
s
.4426 .53566 m
.4426 .53459 L
s
.44313 .53566 m
.44313 .53644 L
s
.44366 .53566 m
.44366 .53671 L
s
.4442 .53566 m
.4442 .53539 L
s
.44473 .53566 m
.44473 .53472 L
s
.44526 .53566 m
.44526 .53698 L
s
.44579 .53566 m
.44579 .53599 L
s
.44632 .53566 m
.44632 .53372 L
s
.44685 .53566 m
.44685 .5363 L
s
.44739 .53566 m
.44739 .53708 L
s
.44792 .53566 m
.44792 .53531 L
s
.44845 .53566 m
.44845 .53408 L
s
.44898 .53566 m
.44898 .5366 L
s
.44951 .53566 m
.44951 .53705 L
s
.45004 .53566 m
.45004 .53422 L
s
.45057 .53566 m
.45057 .53477 L
s
.45111 .53566 m
.45111 .53732 L
s
.45164 .53566 m
.45164 .53628 L
s
.45217 .53566 m
.45217 .53418 L
s
.4527 .53566 m
.4527 .53555 L
s
.45323 .53566 m
.45323 .53726 L
s
.45376 .53566 m
.45376 .53512 L
s
.45429 .53566 m
.45429 .53449 L
s
.45483 .53566 m
.45483 .53653 L
s
.45536 .53566 m
.45536 .5371 L
s
.45589 .53566 m
.45589 .53484 L
s
.45642 .53566 m
.45642 .53463 L
s
.45695 .53566 m
.45695 .53631 L
s
.45748 .53566 m
.45748 .53647 L
s
.45801 .53566 m
.45801 .53338 L
s
.45855 .53566 m
.45855 .53521 L
s
.45908 .53566 m
.45908 .53815 L
s
.45961 .53566 m
.45961 .53487 L
s
.46014 .53566 m
.46014 .53363 L
s
.46067 .53566 m
.46067 .53607 L
s
.4612 .53566 m
.4612 .53824 L
s
.46173 .53566 m
.46173 .53784 L
s
.46227 .53566 m
.46227 .52615 L
s
.4628 .53566 m
.4628 .53603 L
s
.46333 .53566 m
.46333 .54571 L
s
.46386 .53566 m
.46386 .53641 L
s
.46439 .53566 m
.46439 .52603 L
s
.46492 .53566 m
.46492 .53411 L
s
.46545 .53566 m
.46545 .54271 L
s
.46599 .53566 m
.46599 .53462 L
s
.46652 .53566 m
.46652 .52953 L
s
.46705 .53566 m
.46705 .54102 L
s
.46758 .53566 m
.46758 .54175 L
s
.46811 .53566 m
.46811 .53332 L
s
.46864 .53566 m
.46864 .5273 L
s
.46918 .53566 m
.46918 .53513 L
s
.46971 .53566 m
.46971 .54425 L
s
.47024 .53566 m
.47024 .53091 L
s
.47077 .53566 m
.47077 .53167 L
s
.4713 .53566 m
.4713 .54444 L
s
.47183 .53566 m
.47183 .54504 L
s
.47236 .53566 m
.47236 .53152 L
s
.4729 .53566 m
.4729 .52426 L
s
.47343 .53566 m
.47343 .53513 L
s
.47396 .53566 m
.47396 .54242 L
s
.47449 .53566 m
.47449 .53382 L
s
.47502 .53566 m
.47502 .53134 L
s
.47555 .53566 m
.47555 .54298 L
s
.47608 .53566 m
.47608 .54704 L
s
.47662 .53566 m
.47662 .53283 L
s
.47715 .53566 m
.47715 .52579 L
s
.47768 .53566 m
.47768 .53408 L
s
.47821 .53566 m
.47821 .5396 L
s
.47874 .53566 m
.47874 .53522 L
s
.47927 .53566 m
.47927 .52864 L
s
.4798 .53566 m
.4798 .54352 L
s
.48034 .53566 m
.48034 .54731 L
s
.48087 .53566 m
.48087 .53625 L
s
.4814 .53566 m
.4814 .52787 L
s
.48193 .53566 m
.48193 .53159 L
s
.48246 .53566 m
.48246 .53583 L
s
.48299 .53566 m
.48299 .53637 L
s
.48352 .53566 m
.48352 .52498 L
s
.48406 .53566 m
.48406 .54012 L
s
.48459 .53566 m
.48459 .54821 L
s
.48512 .53566 m
.48512 .54198 L
s
.48565 .53566 m
.48565 .5313 L
s
.48618 .53566 m
.48618 .53135 L
s
.48671 .53566 m
.48671 .53165 L
s
.48724 .53566 m
.48724 .54006 L
s
.48778 .53566 m
.48778 .52282 L
s
.48831 .53566 m
.48831 .5309 L
s
.48884 .53566 m
.48884 .54443 L
s
.48937 .53566 m
.48937 .54532 L
s
.4899 .53566 m
.4899 .53864 L
s
.49043 .53566 m
.49043 .53581 L
s
.49097 .53566 m
.49097 .52616 L
s
.4915 .53566 m
.4915 .54525 L
s
.49203 .53566 m
.49203 .52387 L
s
.49256 .53566 m
.49256 .52261 L
s
.49309 .53566 m
.49309 .53505 L
s
.49362 .53566 m
.49362 .54209 L
s
.49415 .53566 m
.49415 .54476 L
s
.49469 .53566 m
.49469 .54354 L
s
.49522 .53566 m
.49522 .52595 L
s
.49575 .53566 m
.49575 .55038 L
s
.49628 .53566 m
.49628 .5357 L
s
.49681 .53566 m
.49681 .5244 L
s
.49734 .53566 m
.49734 .5239 L
s
.49787 .53566 m
.49787 .5298 L
s
.49841 .53566 m
.49841 .53941 L
s
.49894 .53566 m
.49894 .54589 L
s
.49947 .53566 m
.49947 .52476 L
s
.5 .53566 m
.5 .54446 L
s
.50053 .53566 m
.50053 .55132 L
s
.50106 .53566 m
.50106 .54412 L
s
.50159 .53566 m
.50159 .53312 L
s
.50213 .53566 m
.50213 .52319 L
s
.50266 .53566 m
.50266 .52904 L
s
.50319 .53566 m
.50319 .53945 L
s
.50372 .53566 m
.50372 .52577 L
s
.50425 .53566 m
.50425 .52049 L
s
.50478 .53566 m
.50478 .53441 L
s
.50531 .53566 m
.50531 .54819 L
s
.50585 .53566 m
.50585 .55202 L
s
.50638 .53566 m
.50638 .53831 L
s
.50691 .53566 m
.50691 .53889 L
s
.50744 .53566 m
.50744 .537 L
s
.50797 .53566 m
.50797 .5453 L
s
.5085 .53566 m
.5085 .52964 L
s
.50903 .53566 m
.50903 .51816 L
s
.50957 .53566 m
.50957 .52226 L
s
.5101 .53566 m
.5101 .53097 L
s
.51063 .53566 m
.51063 .53221 L
s
.51116 .53566 m
.51116 .5419 L
s
.51169 .53566 m
.51169 .52767 L
s
.51222 .53566 m
.51222 .54478 L
s
.51276 .53566 m
.51276 .55328 L
s
.51329 .53566 m
.51329 .55088 L
s
.51382 .53566 m
.51382 .54279 L
s
.51435 .53566 m
.51435 .53233 L
s
.51488 .53566 m
.51488 .53105 L
s
.51541 .53566 m
.51541 .54019 L
s
.51594 .53566 m
.51594 .53236 L
s
.51648 .53566 m
.51648 .51832 L
s
.51701 .53566 m
.51701 .51642 L
s
.51754 .53566 m
.51754 .52967 L
s
.51807 .53566 m
.51807 .54107 L
s
.5186 .53566 m
.5186 .53387 L
s
.51913 .53566 m
.51913 .53926 L
s
.51966 .53566 m
.51966 .5298 L
s
.5202 .53566 m
.5202 .54904 L
s
.52073 .53566 m
.52073 .55806 L
s
.52126 .53566 m
.52126 .54503 L
s
.52179 .53566 m
.52179 .53826 L
s
.52232 .53566 m
.52232 .54081 L
s
.52285 .53566 m
.52285 .53808 L
s
.52338 .53566 m
.52338 .5407 L
s
.52392 .53566 m
.52392 .53365 L
s
.52445 .53566 m
.52445 .52456 L
s
.52498 .53566 m
.52498 .52209 L
s
.52551 .53566 m
.52551 .52444 L
s
.52604 .53566 m
.52604 .52681 L
s
.52657 .53566 m
.52657 .52363 L
s
.5271 .53566 m
.5271 .5383 L
s
.52764 .53566 m
.52764 .53363 L
s
.52817 .53566 m
.52817 .52049 L
s
.5287 .53566 m
.5287 .53378 L
s
.52923 .53566 m
.52923 .53248 L
s
.52976 .53566 m
.52976 .54155 L
s
.53029 .53566 m
.53029 .53418 L
s
.53082 .53566 m
.53082 .53446 L
s
.53136 .53566 m
.53136 .53256 L
s
.53189 .53566 m
.53189 .5263 L
s
.53242 .53566 m
.53242 .54204 L
s
.53295 .53566 m
.53295 .53527 L
s
.53348 .53566 m
.53348 .53537 L
s
.53401 .53566 m
.53401 .53644 L
s
.53455 .53566 m
.53455 .53322 L
s
.53508 .53566 m
.53508 .53539 L
s
.53561 .53566 m
.53561 .52411 L
s
.53614 .53566 m
.53614 .53711 L
s
.53667 .53566 m
.53667 .53485 L
s
.5372 .53566 m
.5372 .53722 L
s
.53773 .53566 m
.53773 .53523 L
s
.53827 .53566 m
.53827 .53667 L
s
.5388 .53566 m
.5388 .5352 L
s
.53933 .53566 m
.53933 .5322 L
s
.53986 .53566 m
.53986 .53897 L
s
.54039 .53566 m
.54039 .53997 L
s
.54092 .53566 m
.54092 .53641 L
s
.54145 .53566 m
.54145 .53696 L
s
.54199 .53566 m
.54199 .53873 L
s
.54252 .53566 m
.54252 .53541 L
s
.54305 .53566 m
.54305 .52693 L
s
.54358 .53566 m
.54358 .53823 L
s
.54411 .53566 m
.54411 .53844 L
s
.54464 .53566 m
.54464 .54296 L
s
.54517 .53566 m
.54517 .53548 L
s
.54571 .53566 m
.54571 .54085 L
s
.54624 .53566 m
.54624 .54027 L
s
.54677 .53566 m
.54677 .53279 L
s
.5473 .53566 m
.5473 .53567 L
s
.54783 .53566 m
.54783 .53739 L
s
.54836 .53566 m
.54836 .53496 L
s
.54889 .53566 m
.54889 .53462 L
s
.54943 .53566 m
.54943 .53615 L
s
.54996 .53566 m
.54996 .5404 L
s
.55049 .53566 m
.55049 .53782 L
s
.55102 .53566 m
.55102 .53643 L
s
.55155 .53566 m
.55155 .53903 L
s
.55208 .53566 m
.55208 .53888 L
s
.55261 .53566 m
.55261 .53606 L
s
.55315 .53566 m
.55315 .53803 L
s
.55368 .53566 m
.55368 .54058 L
s
.55421 .53566 m
.55421 .53625 L
s
.55474 .53566 m
.55474 .5369 L
s
.55527 .53566 m
.55527 .53353 L
s
.5558 .53566 m
.5558 .53564 L
s
.55634 .53566 m
.55634 .53249 L
s
.55687 .53566 m
.55687 .53773 L
s
.5574 .53566 m
.5574 .53257 L
s
.55793 .53566 m
.55793 .53334 L
s
.55846 .53566 m
.55846 .53929 L
s
.55899 .53566 m
.55899 .53342 L
s
.55952 .53566 m
.55952 .53761 L
s
.56006 .53566 m
.56006 .5361 L
s
.56059 .53566 m
.56059 .53584 L
s
.56112 .53566 m
.56112 .53579 L
s
.56165 .53566 m
.56165 .53206 L
s
.56218 .53566 m
.56218 .53518 L
s
.56271 .53566 m
.56271 .53462 L
s
.56324 .53566 m
.56324 .5376 L
s
.56378 .53566 m
.56378 .53734 L
s
.56431 .53566 m
.56431 .5371 L
s
.56484 .53566 m
.56484 .53745 L
s
.56537 .53566 m
.56537 .53421 L
s
.5659 .53566 m
.5659 .53531 L
s
.56643 .53566 m
.56643 .53451 L
s
.56696 .53566 m
.56696 .53463 L
s
.5675 .53566 m
.5675 .53477 L
s
.56803 .53566 m
.56803 .53452 L
s
.56856 .53566 m
.56856 .53526 L
s
.56909 .53566 m
.56909 .53535 L
s
.56962 .53566 m
.56962 .53513 L
s
.57015 .53566 m
.57015 .53793 L
s
.57068 .53566 m
.57068 .53801 L
s
.57122 .53566 m
.57122 .5371 L
s
.57175 .53566 m
.57175 .53718 L
s
.57228 .53566 m
.57228 .53613 L
s
.57281 .53566 m
.57281 .53671 L
s
.57334 .53566 m
.57334 .53648 L
s
.57387 .53566 m
.57387 .53484 L
s
.5744 .53566 m
.5744 .53735 L
s
.57494 .53566 m
.57494 .5371 L
s
.57547 .53566 m
.57547 .53759 L
s
.576 .53566 m
.576 .5357 L
s
.57653 .53566 m
.57653 .53662 L
s
.57706 .53566 m
.57706 .53481 L
s
.57759 .53566 m
.57759 .53606 L
s
.57813 .53566 m
.57813 .53509 L
s
.57866 .53566 m
.57866 .53518 L
s
.57919 .53566 m
.57919 .53629 L
s
.57972 .53566 m
.57972 .53479 L
s
.58025 .53566 m
.58025 .53626 L
s
.58078 .53566 m
.58078 .53498 L
s
.58131 .53566 m
.58131 .53601 L
s
.58185 .53566 m
.58185 .53497 L
s
.58238 .53566 m
.58238 .53566 L
s
.58291 .53566 m
.58291 .53545 L
s
.58344 .53566 m
.58344 .53545 L
s
.58397 .53566 m
.58397 .53574 L
s
.5845 .53566 m
.5845 .53525 L
s
.58503 .53566 m
.58503 .53434 L
s
.58557 .53566 m
.58557 .53477 L
s
.5861 .53566 m
.5861 .53517 L
s
.58663 .53566 m
.58663 .53619 L
s
.58716 .53566 m
.58716 .53553 L
s
.58769 .53566 m
.58769 .53683 L
s
.58822 .53566 m
.58822 .53553 L
s
.58875 .53566 m
.58875 .53595 L
s
.58929 .53566 m
.58929 .5348 L
s
.58982 .53566 m
.58982 .53614 L
s
.59035 .53566 m
.59035 .53453 L
s
.59088 .53566 m
.59088 .53449 L
s
.59141 .53566 m
.59141 .53579 L
s
.59194 .53566 m
.59194 .53407 L
s
.59247 .53566 m
.59247 .53592 L
s
.59301 .53566 m
.59301 .5358 L
s
.59354 .53566 m
.59354 .53611 L
s
.59407 .53566 m
.59407 .5373 L
s
.5946 .53566 m
.5946 .53615 L
s
.59513 .53566 m
.59513 .53659 L
s
.59566 .53566 m
.59566 .53597 L
s
.59619 .53566 m
.59619 .53589 L
s
.59673 .53566 m
.59673 .53536 L
s
.59726 .53566 m
.59726 .53576 L
s
.59779 .53566 m
.59779 .53534 L
s
.59832 .53566 m
.59832 .53563 L
s
.59885 .53566 m
.59885 .53499 L
s
.59938 .53566 m
.59938 .536 L
s
.59991 .53566 m
.59991 .53544 L
s
.60045 .53566 m
.60045 .53587 L
s
.60098 .53566 m
.60098 .53727 L
s
.60151 .53566 m
.60151 .53642 L
s
.60204 .53566 m
.60204 .53754 L
s
.60257 .53566 m
.60257 .53569 L
s
.6031 .53566 m
.6031 .53557 L
s
.60364 .53566 m
.60364 .53679 L
s
.60417 .53566 m
.60417 .53552 L
s
.6047 .53566 m
.6047 .53664 L
s
.60523 .53566 m
.60523 .53588 L
s
.60576 .53566 m
.60576 .5367 L
s
.60629 .53566 m
.60629 .53649 L
s
.60682 .53566 m
.60682 .53524 L
s
.60736 .53566 m
.60736 .53662 L
s
.60789 .53566 m
.60789 .53578 L
s
.60842 .53566 m
.60842 .53621 L
s
.60895 .53566 m
.60895 .53528 L
s
.60948 .53566 m
.60948 .5343 L
s
.61001 .53566 m
.61001 .53564 L
s
.61054 .53566 m
.61054 .53523 L
s
.61108 .53566 m
.61108 .53626 L
s
.61161 .53566 m
.61161 .53592 L
s
.61214 .53566 m
.61214 .53639 L
s
.61267 .53566 m
.61267 .53687 L
s
.6132 .53566 m
.6132 .53629 L
s
.61373 .53566 m
.61373 .53687 L
s
.61426 .53566 m
.61426 .53653 L
s
.6148 .53566 m
.6148 .53649 L
s
.61533 .53566 m
.61533 .53635 L
s
.61586 .53566 m
.61586 .53569 L
s
.61639 .53566 m
.61639 .53587 L
s
.61692 .53566 m
.61692 .53525 L
s
.61745 .53566 m
.61745 .53597 L
s
.61798 .53566 m
.61798 .53499 L
s
.61852 .53566 m
.61852 .53542 L
s
.61905 .53566 m
.61905 .53591 L
s
.61958 .53566 m
.61958 .53553 L
s
.62011 .53566 m
.62011 .5364 L
s
.62064 .53566 m
.62064 .53541 L
s
.62117 .53566 m
.62117 .53603 L
s
.6217 .53566 m
.6217 .53565 L
s
.62224 .53566 m
.62224 .53569 L
s
.62277 .53566 m
.62277 .5359 L
s
.6233 .53566 m
.6233 .53581 L
s
.62383 .53566 m
.62383 .53611 L
s
.62436 .53566 m
.62436 .53558 L
s
.62489 .53566 m
.62489 .53565 L
s
.62543 .53566 m
.62543 .53606 L
s
.62596 .53566 m
.62596 .53548 L
s
.62649 .53566 m
.62649 .53516 L
s
.62702 .53566 m
.62702 .53499 L
s
.62755 .53566 m
.62755 .53505 L
s
.62808 .53566 m
.62808 .53542 L
s
.62861 .53566 m
.62861 .53497 L
s
.62915 .53566 m
.62915 .53555 L
s
.62968 .53566 m
.62968 .5362 L
s
.63021 .53566 m
.63021 .53601 L
s
.63074 .53566 m
.63074 .5348 L
s
.63127 .53566 m
.63127 .53505 L
s
.6318 .53566 m
.6318 .53538 L
s
.63233 .53566 m
.63233 .53478 L
s
.63287 .53566 m
.63287 .5356 L
s
.6334 .53566 m
.6334 .5363 L
s
.63393 .53566 m
.63393 .53519 L
s
.63446 .53566 m
.63446 .53543 L
s
.63499 .53566 m
.63499 .53608 L
s
.63552 .53566 m
.63552 .53574 L
s
.63605 .53566 m
.63605 .53604 L
s
.63659 .53566 m
.63659 .53578 L
s
.63712 .53566 m
.63712 .53571 L
s
.63765 .53566 m
.63765 .53475 L
s
.63818 .53566 m
.63818 .53565 L
s
.63871 .53566 m
.63871 .53535 L
s
.63924 .53566 m
.63924 .53519 L
s
.63977 .53566 m
.63977 .53566 L
s
.64031 .53566 m
.64031 .53573 L
s
.64084 .53566 m
.64084 .53535 L
s
.64137 .53566 m
.64137 .53538 L
s
.6419 .53566 m
.6419 .53581 L
s
.64243 .53566 m
.64243 .53598 L
s
.64296 .53566 m
.64296 .53576 L
s
.64349 .53566 m
.64349 .53641 L
s
.64403 .53566 m
.64403 .53571 L
s
.64456 .53566 m
.64456 .53594 L
s
.64509 .53566 m
.64509 .53593 L
s
.64562 .53566 m
.64562 .53571 L
s
.64615 .53566 m
.64615 .53599 L
s
.64668 .53566 m
.64668 .5352 L
s
.64722 .53566 m
.64722 .53592 L
s
.64775 .53566 m
.64775 .53556 L
s
.64828 .53566 m
.64828 .53531 L
s
.64881 .53566 m
.64881 .53519 L
s
.64934 .53566 m
.64934 .5356 L
s
.64987 .53566 m
.64987 .53589 L
s
.6504 .53566 m
.6504 .53552 L
s
.65094 .53566 m
.65094 .53535 L
s
.65147 .53566 m
.65147 .53576 L
s
.652 .53566 m
.652 .53573 L
s
.65253 .53566 m
.65253 .53651 L
s
.65306 .53566 m
.65306 .53543 L
s
.65359 .53566 m
.65359 .53551 L
s
.65412 .53566 m
.65412 .53529 L
s
.65466 .53566 m
.65466 .53593 L
s
.65519 .53566 m
.65519 .53465 L
s
.65572 .53566 m
.65572 .53561 L
s
.65625 .53566 m
.65625 .53589 L
s
.65678 .53566 m
.65678 .53653 L
s
.65731 .53566 m
.65731 .53544 L
s
.65784 .53566 m
.65784 .53564 L
s
.65838 .53566 m
.65838 .53672 L
s
.65891 .53566 m
.65891 .53581 L
s
.65944 .53566 m
.65944 .53569 L
s
.65997 .53566 m
.65997 .53522 L
s
.6605 .53566 m
.6605 .53656 L
s
.66103 .53566 m
.66103 .53525 L
s
.66156 .53566 m
.66156 .53586 L
s
.6621 .53566 m
.6621 .53596 L
s
.66263 .53566 m
.66263 .53511 L
s
.66316 .53566 m
.66316 .53604 L
s
.66369 .53566 m
.66369 .53521 L
s
.66422 .53566 m
.66422 .53596 L
s
.66475 .53566 m
.66475 .53512 L
s
.66528 .53566 m
.66528 .5367 L
s
.66582 .53566 m
.66582 .53605 L
s
.66635 .53566 m
.66635 .5354 L
s
.66688 .53566 m
.66688 .53562 L
s
.66741 .53566 m
.66741 .53602 L
s
.66794 .53566 m
.66794 .53605 L
s
.66847 .53566 m
.66847 .5353 L
s
.66901 .53566 m
.66901 .53533 L
s
.66954 .53566 m
.66954 .53474 L
s
.67007 .53566 m
.67007 .53557 L
s
.6706 .53566 m
.6706 .53526 L
s
.67113 .53566 m
.67113 .53579 L
s
.67166 .53566 m
.67166 .53554 L
s
.67219 .53566 m
.67219 .53558 L
s
.67273 .53566 m
.67273 .53479 L
s
.67326 .53566 m
.67326 .53493 L
s
.67379 .53566 m
.67379 .53558 L
s
.67432 .53566 m
.67432 .5358 L
s
.67485 .53566 m
.67485 .53617 L
s
.67538 .53566 m
.67538 .53518 L
s
.67591 .53566 m
.67591 .53596 L
s
.67645 .53566 m
.67645 .53412 L
s
.67698 .53566 m
.67698 .53375 L
s
.67751 .53566 m
.67751 .53596 L
s
.67804 .53566 m
.67804 .537 L
s
.67857 .53566 m
.67857 .5352 L
s
.6791 .53566 m
.6791 .53529 L
s
.67963 .53566 m
.67963 .53571 L
s
.68017 .53566 m
.68017 .53642 L
s
.6807 .53566 m
.6807 .53547 L
s
.68123 .53566 m
.68123 .53729 L
s
.68176 .53566 m
.68176 .53675 L
s
.68229 .53566 m
.68229 .53519 L
s
.68282 .53566 m
.68282 .53448 L
s
.68335 .53566 m
.68335 .53591 L
s
.68389 .53566 m
.68389 .53618 L
s
.68442 .53566 m
.68442 .53525 L
s
.68495 .53566 m
.68495 .53572 L
s
.68548 .53566 m
.68548 .53464 L
s
.68601 .53566 m
.68601 .53758 L
s
.68654 .53566 m
.68654 .53503 L
s
.68707 .53566 m
.68707 .53477 L
s
.68761 .53566 m
.68761 .53609 L
s
.68814 .53566 m
.68814 .53626 L
s
.68867 .53566 m
.68867 .53574 L
s
.6892 .53566 m
.6892 .53433 L
s
.68973 .53566 m
.68973 .53604 L
s
.69026 .53566 m
.69026 .53561 L
s
.6908 .53566 m
.6908 .53666 L
s
.69133 .53566 m
.69133 .53462 L
s
.69186 .53566 m
.69186 .5351 L
s
.69239 .53566 m
.69239 .53584 L
s
.69292 .53566 m
.69292 .53553 L
s
.69345 .53566 m
.69345 .53486 L
s
.69398 .53566 m
.69398 .53628 L
s
.69452 .53566 m
.69452 .53653 L
s
.69505 .53566 m
.69505 .53564 L
s
.69558 .53566 m
.69558 .53613 L
s
.69611 .53566 m
.69611 .5363 L
s
.69664 .53566 m
.69664 .53588 L
s
.69717 .53566 m
.69717 .53513 L
s
.6977 .53566 m
.6977 .53589 L
s
.69824 .53566 m
.69824 .53638 L
s
.69877 .53566 m
.69877 .53581 L
s
.6993 .53566 m
.6993 .53584 L
s
.69983 .53566 m
.69983 .53549 L
s
.70036 .53566 m
.70036 .53499 L
s
.70089 .53566 m
.70089 .53553 L
s
.70142 .53566 m
.70142 .53568 L
s
.70196 .53566 m
.70196 .53604 L
s
.70249 .53566 m
.70249 .53539 L
s
.70302 .53566 m
.70302 .53554 L
s
.70355 .53566 m
.70355 .53569 L
s
.70408 .53566 m
.70408 .53615 L
s
.70461 .53566 m
.70461 .53575 L
s
.70514 .53566 m
.70514 .53606 L
s
.70568 .53566 m
.70568 .53529 L
s
.70621 .53566 m
.70621 .53474 L
s
.70674 .53566 m
.70674 .53579 L
s
.70727 .53566 m
.70727 .53575 L
s
.7078 .53566 m
.7078 .53524 L
s
.70833 .53566 m
.70833 .53548 L
s
.70886 .53566 m
.70886 .53573 L
s
.7094 .53566 m
.7094 .53556 L
s
.70993 .53566 m
.70993 .53526 L
s
.71046 .53566 m
.71046 .53572 L
s
.71099 .53566 m
.71099 .53521 L
s
.71152 .53566 m
.71152 .53558 L
s
.71205 .53566 m
.71205 .53574 L
s
.71259 .53566 m
.71259 .53625 L
s
.71312 .53566 m
.71312 .53586 L
s
.71365 .53566 m
.71365 .53545 L
s
.71418 .53566 m
.71418 .53587 L
s
.71471 .53566 m
.71471 .53574 L
s
.71524 .53566 m
.71524 .53524 L
s
.71577 .53566 m
.71577 .53565 L
s
.71631 .53566 m
.71631 .5354 L
s
.71684 .53566 m
.71684 .53561 L
s
.71737 .53566 m
.71737 .53564 L
s
.7179 .53566 m
.7179 .53541 L
s
.71843 .53566 m
.71843 .53592 L
s
.71896 .53566 m
.71896 .5354 L
s
.71949 .53566 m
.71949 .53573 L
s
.72003 .53566 m
.72003 .53622 L
s
.72056 .53566 m
.72056 .53517 L
s
.72109 .53566 m
.72109 .53609 L
s
.72162 .53566 m
.72162 .53613 L
s
.72215 .53566 m
.72215 .53522 L
s
.72268 .53566 m
.72268 .53635 L
s
.72321 .53566 m
.72321 .53569 L
s
.72375 .53566 m
.72375 .53527 L
s
.72428 .53566 m
.72428 .53586 L
s
.72481 .53566 m
.72481 .53529 L
s
.72534 .53566 m
.72534 .53554 L
s
.72587 .53566 m
.72587 .53533 L
s
.7264 .53566 m
.7264 .53548 L
s
.72693 .53566 m
.72693 .53616 L
s
.72747 .53566 m
.72747 .53571 L
s
.728 .53566 m
.728 .5356 L
s
.72853 .53566 m
.72853 .53608 L
s
.72906 .53566 m
.72906 .53568 L
s
.72959 .53566 m
.72959 .53583 L
s
.73012 .53566 m
.73012 .53503 L
s
.73065 .53566 m
.73065 .5356 L
s
.73119 .53566 m
.73119 .53582 L
s
.73172 .53566 m
.73172 .53547 L
s
.73225 .53566 m
.73225 .53568 L
s
.73278 .53566 m
.73278 .53531 L
s
.73331 .53566 m
.73331 .53568 L
s
.73384 .53566 m
.73384 .53539 L
s
.73438 .53566 m
.73438 .53567 L
s
.73491 .53566 m
.73491 .53582 L
s
.73544 .53566 m
.73544 .53558 L
s
.73597 .53566 m
.73597 .53565 L
s
.7365 .53566 m
.7365 .53599 L
s
.73703 .53566 m
.73703 .5357 L
s
.73756 .53566 m
.73756 .53577 L
s
.7381 .53566 m
.7381 .53575 L
s
.73863 .53566 m
.73863 .53545 L
s
.73916 .53566 m
.73916 .53559 L
s
.73969 .53566 m
.73969 .53551 L
s
.74022 .53566 m
.74022 .53536 L
s
.74075 .53566 m
.74075 .5356 L
s
.74128 .53566 m
.74128 .53576 L
s
.74182 .53566 m
.74182 .53561 L
s
.74235 .53566 m
.74235 .53577 L
s
.74288 .53566 m
.74288 .53572 L
s
.74341 .53566 m
.74341 .5359 L
s
.74394 .53566 m
.74394 .53567 L
s
.74447 .53566 m
.74447 .53564 L
s
.745 .53566 m
.745 .536 L
s
.74554 .53566 m
.74554 .53568 L
s
.74607 .53566 m
.74607 .53578 L
s
.7466 .53566 m
.7466 .53561 L
s
.74713 .53566 m
.74713 .53576 L
s
.74766 .53566 m
.74766 .53545 L
s
.74819 .53566 m
.74819 .53554 L
s
.74872 .53566 m
.74872 .53572 L
s
.74926 .53566 m
.74926 .53555 L
s
.74979 .53566 m
.74979 .5358 L
s
.75032 .53566 m
.75032 .53575 L
s
.75085 .53566 m
.75085 .53596 L
s
.75138 .53566 m
.75138 .53566 L
s
.75191 .53566 m
.75191 .53568 L
s
.75244 .53566 m
.75244 .53585 L
s
.75298 .53566 m
.75298 .53559 L
s
.75351 .53566 m
.75351 .53558 L
s
.75404 .53566 m
.75404 .53556 L
s
.75457 .53566 m
.75457 .53563 L
s
.7551 .53566 m
.7551 .53571 L
s
.75563 .53566 m
.75563 .53548 L
s
.75616 .53566 m
.75616 .53574 L
s
.7567 .53566 m
.7567 .53552 L
s
.75723 .53566 m
.75723 .53531 L
s
.75776 .53566 m
.75776 .53564 L
s
.75829 .53566 m
.75829 .53546 L
s
.75882 .53566 m
.75882 .53579 L
s
.75935 .53566 m
.75935 .53565 L
s
.75989 .53566 m
.75989 .53566 L
s
.76042 .53566 m
.76042 .53586 L
s
.76095 .53566 m
.76095 .53565 L
s
.76148 .53566 m
.76148 .53576 L
s
.76201 .53566 m
.76201 .53567 L
s
.76254 .53566 m
.76254 .53545 L
s
.76307 .53566 m
.76307 .53558 L
s
.76361 .53566 m
.76361 .53539 L
s
.76414 .53566 m
.76414 .53564 L
s
.76467 .53566 m
.76467 .53582 L
s
.7652 .53566 m
.7652 .5356 L
s
.76573 .53566 m
.76573 .53568 L
s
.76626 .53566 m
.76626 .53569 L
s
.76679 .53566 m
.76679 .53572 L
s
.76733 .53566 m
.76733 .53569 L
s
.76786 .53566 m
.76786 .53576 L
s
.76839 .53566 m
.76839 .53567 L
s
.76892 .53566 m
.76892 .53576 L
s
.76945 .53566 m
.76945 .5356 L
s
.76998 .53566 m
.76998 .53563 L
s
.77051 .53566 m
.77051 .53552 L
s
.77105 .53566 m
.77105 .53539 L
s
.77158 .53566 m
.77158 .53543 L
s
.77211 .53566 m
.77211 .53565 L
s
.77264 .53566 m
.77264 .53555 L
s
.77317 .53566 m
.77317 .53554 L
s
.7737 .53566 m
.7737 .53556 L
s
.77423 .53566 m
.77423 .53582 L
s
.77477 .53566 m
.77477 .53574 L
s
.7753 .53566 m
.7753 .53553 L
s
.77583 .53566 m
.77583 .53577 L
s
.77636 .53566 m
.77636 .53562 L
s
.77689 .53566 m
.77689 .53572 L
s
.77742 .53566 m
.77742 .53569 L
s
.77795 .53566 m
.77795 .53572 L
s
.77849 .53566 m
.77849 .53562 L
s
.77902 .53566 m
.77902 .53566 L
s
.77955 .53566 m
.77955 .53554 L
s
.78008 .53566 m
.78008 .53564 L
s
.78061 .53566 m
.78061 .53576 L
s
.78114 .53566 m
.78114 .53547 L
s
.78168 .53566 m
.78168 .53573 L
s
.78221 .53566 m
.78221 .53581 L
s
.78274 .53566 m
.78274 .53579 L
s
.78327 .53566 m
.78327 .53577 L
s
.7838 .53566 m
.7838 .53584 L
s
.78433 .53566 m
.78433 .53571 L
s
.78486 .53566 m
.78486 .53562 L
s
.7854 .53566 m
.7854 .53547 L
s
.78593 .53566 m
.78593 .53565 L
s
.78646 .53566 m
.78646 .53544 L
s
.78699 .53566 m
.78699 .53549 L
s
.78752 .53566 m
.78752 .53556 L
s
.78805 .53566 m
.78805 .5357 L
s
.78858 .53566 m
.78858 .53573 L
s
.78912 .53566 m
.78912 .53571 L
s
.78965 .53566 m
.78965 .53562 L
s
.79018 .53566 m
.79018 .53554 L
s
.79071 .53566 m
.79071 .53568 L
s
.79124 .53566 m
.79124 .53571 L
s
.79177 .53566 m
.79177 .53576 L
s
.7923 .53566 m
.7923 .53577 L
s
.79284 .53566 m
.79284 .53581 L
s
.79337 .53566 m
.79337 .53584 L
s
.7939 .53566 m
.7939 .53557 L
s
.79443 .53566 m
.79443 .53561 L
s
.79496 .53566 m
.79496 .53458 L
s
.79549 .53566 m
.79549 .53452 L
s
.79602 .53566 m
.79602 .53609 L
s
.79656 .53566 m
.79656 .53528 L
s
.79709 .53566 m
.79709 .53528 L
s
.79762 .53566 m
.79762 .53491 L
s
.79815 .53566 m
.79815 .53629 L
s
.79868 .53566 m
.79868 .53592 L
s
.79921 .53566 m
.79921 .53558 L
s
.79974 .53566 m
.79974 .53578 L
s
.80028 .53566 m
.80028 .53607 L
s
.80081 .53566 m
.80081 .53491 L
s
.80134 .53566 m
.80134 .53527 L
s
.80187 .53566 m
.80187 .53963 L
s
.8024 .53566 m
.8024 .53618 L
s
.80293 .53566 m
.80293 .53461 L
s
.80347 .53566 m
.80347 .53551 L
s
.804 .53566 m
.804 .53627 L
s
.80453 .53566 m
.80453 .53615 L
s
.80506 .53566 m
.80506 .53566 L
s
.80559 .53566 m
.80559 .53656 L
s
.80612 .53566 m
.80612 .53522 L
s
.80665 .53566 m
.80665 .53683 L
s
.80719 .53566 m
.80719 .53583 L
s
.80772 .53566 m
.80772 .53465 L
s
.80825 .53566 m
.80825 .53643 L
s
.80878 .53566 m
.80878 .53588 L
s
.80931 .53566 m
.80931 .53531 L
s
.80984 .53566 m
.80984 .53564 L
s
.81037 .53566 m
.81037 .53551 L
s
.81091 .53566 m
.81091 .53531 L
s
.81144 .53566 m
.81144 .53544 L
s
.81197 .53566 m
.81197 .53627 L
s
.8125 .53566 m
.8125 .53512 L
s
.81303 .53566 m
.81303 .53504 L
s
.81356 .53566 m
.81356 .53671 L
s
.81409 .53566 m
.81409 .53634 L
s
.81463 .53566 m
.81463 .53572 L
s
.81516 .53566 m
.81516 .5356 L
s
.81569 .53566 m
.81569 .53543 L
s
.81622 .53566 m
.81622 .53572 L
s
.81675 .53566 m
.81675 .53581 L
s
.81728 .53566 m
.81728 .53516 L
s
.81781 .53566 m
.81781 .5352 L
s
.81835 .53566 m
.81835 .53567 L
s
.81888 .53566 m
.81888 .53573 L
s
.81941 .53566 m
.81941 .53445 L
s
.81994 .53566 m
.81994 .53518 L
s
.82047 .53566 m
.82047 .53624 L
s
.821 .53566 m
.821 .53602 L
s
.82153 .53566 m
.82153 .53524 L
s
.82207 .53566 m
.82207 .53381 L
s
.8226 .53566 m
.8226 .53611 L
s
.82313 .53566 m
.82313 .53621 L
s
.82366 .53566 m
.82366 .53545 L
s
.82419 .53566 m
.82419 .5342 L
s
.82472 .53566 m
.82472 .53619 L
s
.82526 .53566 m
.82526 .53483 L
s
.82579 .53566 m
.82579 .53669 L
s
.82632 .53566 m
.82632 .53579 L
s
.82685 .53566 m
.82685 .53576 L
s
.82738 .53566 m
.82738 .53504 L
s
.82791 .53566 m
.82791 .5359 L
s
.82844 .53566 m
.82844 .5343 L
s
.82898 .53566 m
.82898 .5385 L
s
.82951 .53566 m
.82951 .53125 L
s
.83004 .53566 m
.83004 .5344 L
s
.83057 .53566 m
.83057 .53707 L
s
.8311 .53566 m
.8311 .54018 L
s
.83163 .53566 m
.83163 .53417 L
s
.83216 .53566 m
.83216 .53477 L
s
.8327 .53566 m
.8327 .5329 L
s
.83323 .53566 m
.83323 .53918 L
s
.83376 .53566 m
.83376 .53319 L
s
.83429 .53566 m
.83429 .53981 L
s
.83482 .53566 m
.83482 .53437 L
s
.83535 .53566 m
.83535 .53517 L
s
.83588 .53566 m
.83588 .5337 L
s
.83642 .53566 m
.83642 .53768 L
s
.83695 .53566 m
.83695 .53777 L
s
.83748 .53566 m
.83748 .53254 L
s
.83801 .53566 m
.83801 .53539 L
s
.83854 .53566 m
.83854 .54224 L
s
.83907 .53566 m
.83907 .53596 L
s
.8396 .53566 m
.8396 .52689 L
s
.84014 .53566 m
.84014 .53538 L
s
.84067 .53566 m
.84067 .54397 L
s
.8412 .53566 m
.8412 .53421 L
s
.84173 .53566 m
.84173 .53573 L
s
.84226 .53566 m
.84226 .52745 L
s
.84279 .53566 m
.84279 .54248 L
s
.84332 .53566 m
.84332 .5338 L
s
.84386 .53566 m
.84386 .54279 L
s
.84439 .53566 m
.84439 .52319 L
s
.84492 .53566 m
.84492 .53639 L
s
.84545 .53566 m
.84545 .54252 L
s
.84598 .53566 m
.84598 .53829 L
s
.84651 .53566 m
.84651 .52843 L
s
.84705 .53566 m
.84705 .53603 L
s
.84758 .53566 m
.84758 .5397 L
s
.84811 .53566 m
.84811 .53536 L
s
.84864 .53566 m
.84864 .53449 L
s
.84917 .53566 m
.84917 .5325 L
s
.8497 .53566 m
.8497 .53409 L
s
.85023 .53566 m
.85023 .54359 L
s
.85077 .53566 m
.85077 .53601 L
s
.8513 .53566 m
.8513 .52764 L
s
.85183 .53566 m
.85183 .53621 L
s
.85236 .53566 m
.85236 .53912 L
s
.85289 .53566 m
.85289 .53773 L
s
.85342 .53566 m
.85342 .52706 L
s
.85395 .53566 m
.85395 .54483 L
s
.85449 .53566 m
.85449 .53099 L
s
.85502 .53566 m
.85502 .54146 L
s
.85555 .53566 m
.85555 .52435 L
s
.85608 .53566 m
.85608 .53759 L
s
.85661 .53566 m
.85661 .54048 L
s
.85714 .53566 m
.85714 .53605 L
s
.85767 .53566 m
.85767 .53206 L
s
.85821 .53566 m
.85821 .53471 L
s
.85874 .53566 m
.85874 .54065 L
s
.85927 .53566 m
.85927 .53159 L
s
.8598 .53566 m
.8598 .53664 L
s
.86033 .53566 m
.86033 .53364 L
s
.86086 .53566 m
.86086 .54459 L
s
.86139 .53566 m
.86139 .53362 L
s
.86193 .53566 m
.86193 .53071 L
s
.86246 .53566 m
.86246 .53371 L
s
.86299 .53566 m
.86299 .54222 L
s
.86352 .53566 m
.86352 .53677 L
s
.86405 .53566 m
.86405 .53141 L
s
.86458 .53566 m
.86458 .53448 L
s
.86511 .53566 m
.86511 .5398 L
s
.86565 .53566 m
.86565 .53681 L
s
.86618 .53566 m
.86618 .53357 L
s
.86671 .53566 m
.86671 .53595 L
s
.86724 .53566 m
.86724 .52792 L
s
.86777 .53566 m
.86777 .54381 L
s
.8683 .53566 m
.8683 .53768 L
s
.86884 .53566 m
.86884 .53354 L
s
.86937 .53566 m
.86937 .53093 L
s
.8699 .53566 m
.8699 .53862 L
s
.87043 .53566 m
.87043 .53786 L
s
.87096 .53566 m
.87096 .53433 L
s
.87149 .53566 m
.87149 .53226 L
s
.87202 .53566 m
.87202 .53663 L
s
.87256 .53566 m
.87256 .53838 L
s
.87309 .53566 m
.87309 .54043 L
s
.87362 .53566 m
.87362 .52762 L
s
.87415 .53566 m
.87415 .53287 L
s
.87468 .53566 m
.87468 .53875 L
s
.87521 .53566 m
.87521 .54166 L
s
.87574 .53566 m
.87574 .53009 L
s
.87628 .53566 m
.87628 .5334 L
s
.87681 .53566 m
.87681 .53801 L
s
.87734 .53566 m
.87734 .53934 L
s
.87787 .53566 m
.87787 .53332 L
s
.8784 .53566 m
.8784 .53484 L
s
.87893 .53566 m
.87893 .53802 L
s
.87946 .53566 m
.87946 .53388 L
s
.88 .53566 m
.88 .53519 L
s
.88053 .53566 m
.88053 .53694 L
s
.88106 .53566 m
.88106 .54024 L
s
.88159 .53566 m
.88159 .53303 L
s
.88212 .53566 m
.88212 .53025 L
s
.88265 .53566 m
.88265 .53935 L
s
.88318 .53566 m
.88318 .53753 L
s
.88372 .53566 m
.88372 .53725 L
s
.88425 .53566 m
.88425 .53006 L
s
.88478 .53566 m
.88478 .53758 L
s
.88531 .53566 m
.88531 .5358 L
s
.88584 .53566 m
.88584 .53701 L
s
.88637 .53566 m
.88637 .53631 L
s
.8869 .53566 m
.8869 .53321 L
s
.88744 .53566 m
.88744 .53338 L
s
.88797 .53566 m
.88797 .53514 L
s
.8885 .53566 m
.8885 .54183 L
s
.88903 .53566 m
.88903 .53328 L
s
.88956 .53566 m
.88956 .53144 L
s
.89009 .53566 m
.89009 .53662 L
s
.89063 .53566 m
.89063 .53795 L
s
.89116 .53566 m
.89116 .53664 L
s
.89169 .53566 m
.89169 .53386 L
s
.89222 .53566 m
.89222 .53338 L
s
.89275 .53566 m
.89275 .53968 L
s
.89328 .53566 m
.89328 .53511 L
s
.89381 .53566 m
.89381 .53502 L
s
.89435 .53566 m
.89435 .53317 L
s
.89488 .53566 m
.89488 .53729 L
s
.89541 .53566 m
.89541 .53843 L
s
.89594 .53566 m
.89594 .53437 L
s
.89647 .53566 m
.89647 .53375 L
s
.897 .53566 m
.897 .53405 L
s
.89753 .53566 m
.89753 .53975 L
s
.89807 .53566 m
.89807 .53424 L
s
.8986 .53566 m
.8986 .53613 L
s
.89913 .53566 m
.89913 .53288 L
s
.89966 .53566 m
.89966 .53928 L
s
.90019 .53566 m
.90019 .53528 L
s
.90072 .53566 m
.90072 .53531 L
s
.90125 .53566 m
.90125 .53493 L
s
.90179 .53566 m
.90179 .53342 L
s
.90232 .53566 m
.90232 .53953 L
s
.90285 .53566 m
.90285 .53733 L
s
.90338 .53566 m
.90338 .53401 L
s
.90391 .53566 m
.90391 .53187 L
s
.90444 .53566 m
.90444 .53853 L
s
.90497 .53566 m
.90497 .53677 L
s
.90551 .53566 m
.90551 .53677 L
s
.90604 .53566 m
.90604 .5313 L
s
.90657 .53566 m
.90657 .53898 L
s
.9071 .53566 m
.9071 .53454 L
s
.90763 .53566 m
.90763 .53681 L
s
.90816 .53566 m
.90816 .53448 L
s
.90869 .53566 m
.90869 .53544 L
s
.90923 .53566 m
.90923 .53744 L
s
.90976 .53566 m
.90976 .53425 L
s
.91029 .53566 m
.91029 .5372 L
s
.91082 .53566 m
.91082 .53509 L
s
.91135 .53566 m
.91135 .53551 L
s
.91188 .53566 m
.91188 .53347 L
s
.91241 .53566 m
.91241 .5367 L
s
.91295 .53566 m
.91295 .53644 L
s
.91348 .53566 m
.91348 .53595 L
s
.91401 .53566 m
.91401 .53472 L
s
.91454 .53566 m
.91454 .53458 L
s
.91507 .53566 m
.91507 .53622 L
s
.9156 .53566 m
.9156 .53745 L
s
.91614 .53566 m
.91614 .53404 L
s
.91667 .53566 m
.91667 .5342 L
s
.9172 .53566 m
.9172 .53696 L
s
.91773 .53566 m
.91773 .53595 L
s
.91826 .53566 m
.91826 .53584 L
s
.91879 .53566 m
.91879 .53403 L
s
.91932 .53566 m
.91932 .53696 L
s
.91986 .53566 m
.91986 .53526 L
s
.92039 .53566 m
.92039 .53662 L
s
.92092 .53566 m
.92092 .53433 L
s
.92145 .53566 m
.92145 .53567 L
s
.92198 .53566 m
.92198 .53613 L
s
.92251 .53566 m
.92251 .53673 L
s
.92304 .53566 m
.92304 .53435 L
s
.92358 .53566 m
.92358 .53565 L
s
.92411 .53566 m
.92411 .53592 L
s
.92464 .53566 m
.92464 .53611 L
s
.92517 .53566 m
.92517 .5362 L
s
.9257 .53566 m
.9257 .53425 L
s
.92623 .53566 m
.92623 .53608 L
s
.92676 .53566 m
.92676 .53592 L
s
.9273 .53566 m
.9273 .53593 L
s
.92783 .53566 m
.92783 .53485 L
s
.92836 .53566 m
.92836 .53592 L
s
.92889 .53566 m
.92889 .53647 L
s
.92942 .53566 m
.92942 .53586 L
s
.92995 .53566 m
.92995 .5352 L
s
.93048 .53566 m
.93048 .53538 L
s
.93102 .53566 m
.93102 .53536 L
s
.93155 .53566 m
.93155 .53611 L
s
.93208 .53566 m
.93208 .53601 L
s
.93261 .53566 m
.93261 .53539 L
s
.93314 .53566 m
.93314 .53518 L
s
.93367 .53566 m
.93367 .53658 L
s
.9342 .53566 m
.9342 .53666 L
s
.93474 .53566 m
.93474 .53301 L
s
.93527 .53566 m
.93527 .53601 L
s
.9358 .53566 m
.9358 .53742 L
s
.93633 .53566 m
.93633 .53547 L
s
.93686 .53566 m
.93686 .53422 L
s
.93739 .53566 m
.93739 .53574 L
s
.93793 .53566 m
.93793 .53701 L
s
.93846 .53566 m
.93846 .535 L
s
.93899 .53566 m
.93899 .53537 L
s
.93952 .53566 m
.93952 .53518 L
s
.94005 .53566 m
.94005 .53693 L
s
.94058 .53566 m
.94058 .53505 L
s
.94111 .53566 m
.94111 .53555 L
s
.94165 .53566 m
.94165 .53558 L
s
.94218 .53566 m
.94218 .53579 L
s
.94271 .53566 m
.94271 .53598 L
s
.94324 .53566 m
.94324 .53556 L
s
.94377 .53566 m
.94377 .53561 L
s
.9443 .53566 m
.9443 .5363 L
s
.94483 .53566 m
.94483 .5349 L
s
.94537 .53566 m
.94537 .53626 L
s
.9459 .53566 m
.9459 .53526 L
s
.94643 .53566 m
.94643 .53627 L
s
.94696 .53566 m
.94696 .53549 L
s
.94749 .53566 m
.94749 .53559 L
s
.94802 .53566 m
.94802 .53584 L
s
.94855 .53566 m
.94855 .53536 L
s
.94909 .53566 m
.94909 .53596 L
s
.94962 .53566 m
.94962 .53515 L
s
.95015 .53566 m
.95015 .53609 L
s
.95068 .53566 m
.95068 .53541 L
s
.95121 .53566 m
.95121 .53557 L
s
.95174 .53566 m
.95174 .53568 L
s
.95227 .53566 m
.95227 .53557 L
s
.95281 .53566 m
.95281 .53573 L
s
.95334 .53566 m
.95334 .53559 L
s
.95387 .53566 m
.95387 .53571 L
s
.9544 .53566 m
.9544 .53538 L
s
.95493 .53566 m
.95493 .53567 L
s
.95546 .53566 m
.95546 .53546 L
s
.95599 .53566 m
.95599 .53692 L
s
.95653 .53566 m
.95653 .5353 L
s
.95706 .53566 m
.95706 .5361 L
s
.95759 .53566 m
.95759 .5351 L
s
.95812 .53566 m
.95812 .53603 L
s
.95865 .53566 m
.95865 .53535 L
s
.95918 .53566 m
.95918 .53574 L
s
.95972 .53566 m
.95972 .5362 L
s
.96025 .53566 m
.96025 .53593 L
s
.96078 .53566 m
.96078 .53565 L
s
.96131 .53566 m
.96131 .53582 L
s
.96184 .53566 m
.96184 .53526 L
s
.96237 .53566 m
.96237 .53623 L
s
.9629 .53566 m
.9629 .53497 L
s
.96344 .53566 m
.96344 .5359 L
s
.96397 .53566 m
.96397 .53545 L
s
.9645 .53566 m
.9645 .53584 L
s
.96503 .53566 m
.96503 .53596 L
s
.96556 .53566 m
.96556 .53555 L
s
.96609 .53566 m
.96609 .5356 L
s
.96662 .53566 m
.96662 .53612 L
s
.96716 .53566 m
.96716 .5357 L
s
.96769 .53566 m
.96769 .53543 L
s
.96822 .53566 m
.96822 .5352 L
s
.96875 .53566 m
.96875 .53586 L
s
.96928 .53566 m
.96928 .53542 L
s
.96981 .53566 m
.96981 .53569 L
s
.97034 .53566 m
.97034 .53543 L
s
.97088 .53566 m
.97088 .53578 L
s
.97141 .53566 m
.97141 .53529 L
s
.97194 .53566 m
.97194 .53554 L
s
.97247 .53566 m
.97247 .53548 L
s
.973 .53566 m
.973 .53582 L
s
.97353 .53566 m
.97353 .5365 L
s
.97406 .53566 m
.97406 .53527 L
s
.9746 .53566 m
.9746 .53604 L
s
.97513 .53566 m
.97513 .5355 L
s
.97566 .53566 m
.97566 .53591 L
s
.02381 .59339 m
.02381 .59346 L
s
.02408 .59339 m
.02408 .59347 L
s
.02434 .59339 m
.02434 .59354 L
s
.02461 .59339 m
.02461 .59345 L
s
.02487 .59339 m
.02487 .59348 L
s
.02514 .59339 m
.02514 .59326 L
s
.0254 .59339 m
.0254 .59325 L
s
.02567 .59339 m
.02567 .59344 L
s
.02594 .59339 m
.02594 .59359 L
s
.0262 .59339 m
.0262 .59332 L
s
.02647 .59339 m
.02647 .59337 L
s
.02673 .59339 m
.02673 .59334 L
s
.027 .59339 m
.027 .59342 L
s
.02726 .59339 m
.02726 .59342 L
s
.02753 .59339 m
.02753 .59331 L
s
.0278 .59339 m
.0278 .59328 L
s
.02806 .59339 m
.02806 .59359 L
s
.02833 .59339 m
.02833 .59347 L
s
.02859 .59339 m
.02859 .59333 L
s
.02886 .59339 m
.02886 .59333 L
s
.02912 .59339 m
.02912 .59328 L
s
.02939 .59339 m
.02939 .59352 L
s
.02966 .59339 m
.02966 .59339 L
s
.02992 .59339 m
.02992 .59345 L
s
.03019 .59339 m
.03019 .59328 L
s
.03045 .59339 m
.03045 .59345 L
s
.03072 .59339 m
.03072 .59334 L
s
.03098 .59339 m
.03098 .5935 L
s
.03125 .59339 m
.03125 .59321 L
s
.03152 .59339 m
.03152 .5935 L
s
.03178 .59339 m
.03178 .59327 L
s
.03205 .59339 m
.03205 .5935 L
s
.03231 .59339 m
.03231 .59338 L
s
.03258 .59339 m
.03258 .5933 L
s
.03284 .59339 m
.03284 .59347 L
s
.03311 .59339 m
.03311 .59348 L
s
.03338 .59339 m
.03338 .59338 L
s
.03364 .59339 m
.03364 .59324 L
s
.03391 .59339 m
.03391 .59351 L
s
.03417 .59339 m
.03417 .59324 L
s
.03444 .59339 m
.03444 .59358 L
s
.0347 .59339 m
.0347 .59331 L
s
.03497 .59339 m
.03497 .5935 L
s
.03524 .59339 m
.03524 .59323 L
s
.0355 .59339 m
.0355 .59348 L
s
.03577 .59339 m
.03577 .59329 L
s
.03603 .59339 m
.03603 .59342 L
s
.0363 .59339 m
.0363 .59348 L
s
.03656 .59339 m
.03656 .59348 L
s
.03683 .59339 m
.03683 .59327 L
s
.0371 .59339 m
.0371 .59323 L
s
.03736 .59339 m
.03736 .59342 L
s
.03763 .59339 m
.03763 .59347 L
s
.03789 .59339 m
.03789 .59346 L
s
.03816 .59339 m
.03816 .59334 L
s
.03842 .59339 m
.03842 .59341 L
s
.03869 .59339 m
.03869 .59328 L
s
.03896 .59339 m
.03896 .59356 L
s
.03922 .59339 m
.03922 .59326 L
s
.03949 .59339 m
.03949 .59351 L
s
.03975 .59339 m
.03975 .5934 L
s
.04002 .59339 m
.04002 .59336 L
s
.04028 .59339 m
.04028 .59341 L
s
.04055 .59339 m
.04055 .59345 L
s
.04082 .59339 m
.04082 .59328 L
s
.04108 .59339 m
.04108 .59331 L
s
.04135 .59339 m
.04135 .59359 L
s
.04161 .59339 m
.04161 .59339 L
s
.04188 .59339 m
.04188 .59334 L
s
.04214 .59339 m
.04214 .5932 L
s
.04241 .59339 m
.04241 .59354 L
s
.04268 .59339 m
.04268 .59348 L
s
.04294 .59339 m
.04294 .59347 L
s
.04321 .59339 m
.04321 .59339 L
s
.04347 .59339 m
.04347 .59333 L
s
.04374 .59339 m
.04374 .5933 L
s
.04401 .59339 m
.04401 .59358 L
s
.04427 .59339 m
.04427 .59328 L
s
.04454 .59339 m
.04454 .5933 L
s
.0448 .59339 m
.0448 .59363 L
s
.04507 .59339 m
.04507 .59332 L
s
.04533 .59339 m
.04533 .59328 L
s
.0456 .59339 m
.0456 .59326 L
s
.04587 .59339 m
.04587 .5934 L
s
.04613 .59339 m
.04613 .59334 L
s
.0464 .59339 m
.0464 .59357 L
s
.04666 .59339 m
.04666 .59339 L
s
.04693 .59339 m
.04693 .59347 L
s
.04719 .59339 m
.04719 .59316 L
s
.04746 .59339 m
.04746 .59345 L
s
.04773 .59339 m
.04773 .59338 L
s
.04799 .59339 m
.04799 .59335 L
s
.04826 .59339 m
.04826 .59356 L
s
.04852 .59339 m
.04852 .5934 L
s
.04879 .59339 m
.04879 .5935 L
s
.04905 .59339 m
.04905 .59332 L
s
.04932 .59339 m
.04932 .59341 L
s
.04959 .59339 m
.04959 .59324 L
s
.04985 .59339 m
.04985 .59348 L
s
.05012 .59339 m
.05012 .5936 L
s
.05038 .59339 m
.05038 .59329 L
s
.05065 .59339 m
.05065 .59336 L
s
.05091 .59339 m
.05091 .59342 L
s
.05118 .59339 m
.05118 .59327 L
s
.05145 .59339 m
.05145 .59344 L
s
.05171 .59339 m
.05171 .59321 L
s
.05198 .59339 m
.05198 .59339 L
s
.05224 .59339 m
.05224 .59356 L
s
.05251 .59339 m
.05251 .59331 L
s
.05277 .59339 m
.05277 .59334 L
s
.05304 .59339 m
.05304 .59326 L
s
.05331 .59339 m
.05331 .59354 L
s
.05357 .59339 m
.05357 .59353 L
s
.05384 .59339 m
.05384 .59325 L
s
.0541 .59339 m
.0541 .5932 L
s
.05437 .59339 m
.05437 .59353 L
s
.05463 .59339 m
.05463 .59327 L
s
.0549 .59339 m
.0549 .59346 L
s
.05517 .59339 m
.05517 .59336 L
s
.05543 .59339 m
.05543 .5934 L
s
.0557 .59339 m
.0557 .59329 L
s
.05596 .59339 m
.05596 .59337 L
s
.05623 .59339 m
.05623 .59348 L
s
.05649 .59339 m
.05649 .59335 L
s
.05676 .59339 m
.05676 .59335 L
s
.05703 .59339 m
.05703 .59323 L
s
.05729 .59339 m
.05729 .59368 L
s
.05756 .59339 m
.05756 .59303 L
s
.05782 .59339 m
.05782 .59338 L
s
.05809 .59339 m
.05809 .59355 L
s
.05835 .59339 m
.05835 .59359 L
s
.05862 .59339 m
.05862 .59344 L
s
.05889 .59339 m
.05889 .59325 L
s
.05915 .59339 m
.05915 .59324 L
s
.05942 .59339 m
.05942 .5935 L
s
.05968 .59339 m
.05968 .59336 L
s
.05995 .59339 m
.05995 .59326 L
s
.06021 .59339 m
.06021 .59355 L
s
.06048 .59339 m
.06048 .59348 L
s
.06075 .59339 m
.06075 .59364 L
s
.06101 .59339 m
.06101 .59311 L
s
.06128 .59339 m
.06128 .59336 L
s
.06154 .59339 m
.06154 .59342 L
s
.06181 .59339 m
.06181 .59359 L
s
.06207 .59339 m
.06207 .59326 L
s
.06234 .59339 m
.06234 .59349 L
s
.06261 .59339 m
.06261 .59317 L
s
.06287 .59339 m
.06287 .59339 L
s
.06314 .59339 m
.06314 .59364 L
s
.0634 .59339 m
.0634 .59344 L
s
.06367 .59339 m
.06367 .59331 L
s
.06393 .59339 m
.06393 .59346 L
s
.0642 .59339 m
.0642 .59331 L
s
.06447 .59339 m
.06447 .59338 L
s
.06473 .59339 m
.06473 .59345 L
s
.065 .59339 m
.065 .59316 L
s
.06526 .59339 m
.06526 .59364 L
s
.06553 .59339 m
.06553 .59334 L
s
.0658 .59339 m
.0658 .59356 L
s
.06606 .59339 m
.06606 .59315 L
s
.06633 .59339 m
.06633 .59334 L
s
.06659 .59339 m
.06659 .59342 L
s
.06686 .59339 m
.06686 .59357 L
s
.06712 .59339 m
.06712 .59325 L
s
.06739 .59339 m
.06739 .59327 L
s
.06766 .59339 m
.06766 .59323 L
s
.06792 .59339 m
.06792 .59348 L
s
.06819 .59339 m
.06819 .59336 L
s
.06845 .59339 m
.06845 .59345 L
s
.06872 .59339 m
.06872 .5933 L
s
.06898 .59339 m
.06898 .59355 L
s
.06925 .59339 m
.06925 .59331 L
s
.06952 .59339 m
.06952 .59329 L
s
.06978 .59339 m
.06978 .59328 L
s
.07005 .59339 m
.07005 .59338 L
s
.07031 .59339 m
.07031 .59358 L
s
.07058 .59339 m
.07058 .59334 L
s
.07084 .59339 m
.07084 .59351 L
s
.07111 .59339 m
.07111 .59324 L
s
.07138 .59339 m
.07138 .59326 L
s
.07164 .59339 m
.07164 .59363 L
s
.07191 .59339 m
.07191 .59335 L
s
.07217 .59339 m
.07217 .59324 L
s
.07244 .59339 m
.07244 .59342 L
s
.0727 .59339 m
.0727 .59338 L
s
.07297 .59339 m
.07297 .59328 L
s
.07324 .59339 m
.07324 .59343 L
s
.0735 .59339 m
.0735 .59318 L
s
.07377 .59339 m
.07377 .59361 L
s
.07403 .59339 m
.07403 .59343 L
s
.0743 .59339 m
.0743 .59342 L
s
.07456 .59339 m
.07456 .59323 L
s
.07483 .59339 m
.07483 .59319 L
s
.0751 .59339 m
.0751 .5935 L
s
.07536 .59339 m
.07536 .5934 L
s
.07563 .59339 m
.07563 .59332 L
s
.07589 .59339 m
.07589 .5934 L
s
.07616 .59339 m
.07616 .59313 L
s
.07642 .59339 m
.07642 .59346 L
s
.07669 .59339 m
.07669 .59359 L
s
.07696 .59339 m
.07696 .59308 L
s
.07722 .59339 m
.07722 .59344 L
s
.07749 .59339 m
.07749 .5935 L
s
.07775 .59339 m
.07775 .59344 L
s
.07802 .59339 m
.07802 .59348 L
s
.07828 .59339 m
.07828 .59319 L
s
.07855 .59339 m
.07855 .59338 L
s
.07882 .59339 m
.07882 .5936 L
s
.07908 .59339 m
.07908 .59327 L
s
.07935 .59339 m
.07935 .59335 L
s
.07961 .59339 m
.07961 .59312 L
s
.07988 .59339 m
.07988 .59339 L
s
.08014 .59339 m
.08014 .59336 L
s
.08041 .59339 m
.08041 .59347 L
s
.08068 .59339 m
.08068 .59344 L
s
.08094 .59339 m
.08094 .5933 L
s
.08121 .59339 m
.08121 .59324 L
s
.08147 .59339 m
.08147 .59359 L
s
.08174 .59339 m
.08174 .59357 L
s
.082 .59339 m
.082 .5932 L
s
.08227 .59339 m
.08227 .5937 L
s
.08254 .59339 m
.08254 .59352 L
s
.0828 .59339 m
.0828 .59328 L
s
.08307 .59339 m
.08307 .5934 L
s
.08333 .59339 m
.08333 .59328 L
s
.0836 .59339 m
.0836 .59344 L
s
.08386 .59339 m
.08386 .59359 L
s
.08413 .59339 m
.08413 .59359 L
s
.0844 .59339 m
.0844 .59316 L
s
.08466 .59339 m
.08466 .59354 L
s
.08493 .59339 m
.08493 .5932 L
s
.08519 .59339 m
.08519 .59346 L
s
.08546 .59339 m
.08546 .59338 L
s
.08572 .59339 m
.08572 .59363 L
s
.08599 .59339 m
.08599 .59343 L
s
.08626 .59339 m
.08626 .59303 L
s
.08652 .59339 m
.08652 .59339 L
s
.08679 .59339 m
.08679 .59362 L
s
.08705 .59339 m
.08705 .59333 L
s
.08732 .59339 m
.08732 .59368 L
s
.08759 .59339 m
.08759 .59332 L
s
.08785 .59339 m
.08785 .59311 L
s
.08812 .59339 m
.08812 .59362 L
s
.08838 .59339 m
.08838 .59332 L
s
.08865 .59339 m
.08865 .59333 L
s
.08891 .59339 m
.08891 .59356 L
s
.08918 .59339 m
.08918 .59304 L
s
.08945 .59339 m
.08945 .59354 L
s
.08971 .59339 m
.08971 .59365 L
s
.08998 .59339 m
.08998 .59296 L
s
.09024 .59339 m
.09024 .59353 L
s
.09051 .59339 m
.09051 .59301 L
s
.09077 .59339 m
.09077 .59351 L
s
.09104 .59339 m
.09104 .59376 L
s
.09131 .59339 m
.09131 .59315 L
s
.09157 .59339 m
.09157 .5932 L
s
.09184 .59339 m
.09184 .59335 L
s
.0921 .59339 m
.0921 .5935 L
s
.09237 .59339 m
.09237 .59378 L
s
.09263 .59339 m
.09263 .59334 L
s
.0929 .59339 m
.0929 .59324 L
s
.09317 .59339 m
.09317 .59357 L
s
.09343 .59339 m
.09343 .59302 L
s
.0937 .59339 m
.0937 .59363 L
s
.09396 .59339 m
.09396 .59341 L
s
.09423 .59339 m
.09423 .5932 L
s
.09449 .59339 m
.09449 .5937 L
s
.09476 .59339 m
.09476 .59325 L
s
.09503 .59339 m
.09503 .59328 L
s
.09529 .59339 m
.09529 .59358 L
s
.09556 .59339 m
.09556 .5932 L
s
.09582 .59339 m
.09582 .59347 L
s
.09609 .59339 m
.09609 .59373 L
s
.09635 .59339 m
.09635 .59317 L
s
.09662 .59339 m
.09662 .59338 L
s
.09689 .59339 m
.09689 .59333 L
s
.09715 .59339 m
.09715 .59338 L
s
.09742 .59339 m
.09742 .5937 L
s
.09768 .59339 m
.09768 .59297 L
s
.09795 .59339 m
.09795 .5937 L
s
.09821 .59339 m
.09821 .59346 L
s
.09848 .59339 m
.09848 .59319 L
s
.09875 .59339 m
.09875 .59353 L
s
.09901 .59339 m
.09901 .59349 L
s
.09928 .59339 m
.09928 .59322 L
s
.09954 .59339 m
.09954 .59377 L
s
.09981 .59339 m
.09981 .59316 L
s
.10007 .59339 m
.10007 .59338 L
s
.10034 .59339 m
.10034 .59339 L
s
.10061 .59339 m
.10061 .59346 L
s
.10087 .59339 m
.10087 .59359 L
s
.10114 .59339 m
.10114 .59319 L
s
.1014 .59339 m
.1014 .5932 L
s
.10167 .59339 m
.10167 .59368 L
s
.10193 .59339 m
.10193 .5932 L
s
.1022 .59339 m
.1022 .59356 L
s
.10247 .59339 m
.10247 .5934 L
s
.10273 .59339 m
.10273 .59317 L
s
.103 .59339 m
.103 .59359 L
s
.10326 .59339 m
.10326 .59322 L
s
.10353 .59339 m
.10353 .59311 L
s
.10379 .59339 m
.10379 .59346 L
s
.10406 .59339 m
.10406 .59339 L
s
.10433 .59339 m
.10433 .59331 L
s
.10459 .59339 m
.10459 .59354 L
s
.10486 .59339 m
.10486 .59312 L
s
.10512 .59339 m
.10512 .59356 L
s
.10539 .59339 m
.10539 .59344 L
s
.10565 .59339 m
.10565 .59329 L
s
.10592 .59339 m
.10592 .59406 L
s
.10619 .59339 m
.10619 .59269 L
s
.10645 .59339 m
.10645 .59375 L
s
.10672 .59339 m
.10672 .59353 L
s
.10698 .59339 m
.10698 .59285 L
s
.10725 .59339 m
.10725 .59356 L
s
.10751 .59339 m
.10751 .5939 L
s
.10778 .59339 m
.10778 .59325 L
s
.10805 .59339 m
.10805 .59377 L
s
.10831 .59339 m
.10831 .593 L
s
.10858 .59339 m
.10858 .59357 L
s
.10884 .59339 m
.10884 .59356 L
s
.10911 .59339 m
.10911 .5933 L
s
.10937 .59339 m
.10937 .59354 L
s
.10964 .59339 m
.10964 .5935 L
s
.10991 .59339 m
.10991 .59315 L
s
.11017 .59339 m
.11017 .59432 L
s
.11044 .59339 m
.11044 .59254 L
s
.1107 .59339 m
.1107 .59278 L
s
.11097 .59339 m
.11097 .59486 L
s
.11124 .59339 m
.11124 .59175 L
s
.1115 .59339 m
.1115 .5949 L
s
.11177 .59339 m
.11177 .59276 L
s
.11203 .59339 m
.11203 .59279 L
s
.1123 .59339 m
.1123 .5948 L
s
.11256 .59339 m
.11256 .5913 L
s
.11283 .59339 m
.11283 .59603 L
s
.1131 .59339 m
.1131 .59076 L
s
.11336 .59339 m
.11336 .59389 L
s
.11363 .59339 m
.11363 .59418 L
s
.11389 .59339 m
.11389 .59325 L
s
.11416 .59339 m
.11416 .5935 L
s
.11442 .59339 m
.11442 .59315 L
s
.11469 .59339 m
.11469 .59366 L
s
.11496 .59339 m
.11496 .59355 L
s
.11522 .59339 m
.11522 .59515 L
s
.11549 .59339 m
.11549 .59077 L
s
.11575 .59339 m
.11575 .59508 L
s
.11602 .59339 m
.11602 .59203 L
s
.11628 .59339 m
.11628 .59427 L
s
.11655 .59339 m
.11655 .59302 L
s
.11682 .59339 m
.11682 .59249 L
s
.11708 .59339 m
.11708 .59567 L
s
.11735 .59339 m
.11735 .59029 L
s
.11761 .59339 m
.11761 .59516 L
s
.11788 .59339 m
.11788 .59293 L
s
.11814 .59339 m
.11814 .59532 L
s
.11841 .59339 m
.11841 .59062 L
s
.11868 .59339 m
.11868 .59665 L
s
.11894 .59339 m
.11894 .58927 L
s
.11921 .59339 m
.11921 .59654 L
s
.11947 .59339 m
.11947 .594 L
s
.11974 .59339 m
.11974 .59253 L
s
.12 .59339 m
.12 .59489 L
s
.12027 .59339 m
.12027 .591 L
s
.12054 .59339 m
.12054 .59662 L
s
.1208 .59339 m
.1208 .58966 L
s
.12107 .59339 m
.12107 .59585 L
s
.12133 .59339 m
.12133 .59249 L
s
.1216 .59339 m
.1216 .59376 L
s
.12186 .59339 m
.12186 .59108 L
s
.12213 .59339 m
.12213 .59517 L
s
.1224 .59339 m
.1224 .5941 L
s
.12266 .59339 m
.12266 .59139 L
s
.12293 .59339 m
.12293 .59701 L
s
.12319 .59339 m
.12319 .58761 L
s
.12346 .59339 m
.12346 .59664 L
s
.12372 .59339 m
.12372 .59113 L
s
.12399 .59339 m
.12399 .59851 L
s
.12426 .59339 m
.12426 .59045 L
s
.12452 .59339 m
.12452 .594 L
s
.12479 .59339 m
.12479 .59392 L
s
.12505 .59339 m
.12505 .59399 L
s
.12532 .59339 m
.12532 .59139 L
s
.12558 .59339 m
.12558 .59586 L
s
.12585 .59339 m
.12585 .5925 L
s
.12612 .59339 m
.12612 .59269 L
s
.12638 .59339 m
.12638 .59157 L
s
.12665 .59339 m
.12665 .59582 L
s
.12691 .59339 m
.12691 .59226 L
s
.12718 .59339 m
.12718 .5953 L
s
.12744 .59339 m
.12744 .59073 L
s
.12771 .59339 m
.12771 .59442 L
s
.12798 .59339 m
.12798 .58776 L
s
.12824 .59339 m
.12824 .59871 L
s
.12851 .59339 m
.12851 .59208 L
s
.12877 .59339 m
.12877 .59435 L
s
.12904 .59339 m
.12904 .59123 L
s
.1293 .59339 m
.1293 .59625 L
s
.12957 .59339 m
.12957 .59069 L
s
.12984 .59339 m
.12984 .59669 L
s
.1301 .59339 m
.1301 .59069 L
s
.13037 .59339 m
.13037 .59549 L
s
.13063 .59339 m
.13063 .59004 L
s
.1309 .59339 m
.1309 .59519 L
s
.13116 .59339 m
.13116 .59482 L
s
.13143 .59339 m
.13143 .59342 L
s
.1317 .59339 m
.1317 .59349 L
s
.13196 .59339 m
.13196 .59456 L
s
.13223 .59339 m
.13223 .58791 L
s
.13249 .59339 m
.13249 .59567 L
s
.13276 .59339 m
.13276 .5929 L
s
.13303 .59339 m
.13303 .59569 L
s
.13329 .59339 m
.13329 .58974 L
s
.13356 .59339 m
.13356 .59635 L
s
.13382 .59339 m
.13382 .59149 L
s
.13409 .59339 m
.13409 .59637 L
s
.13435 .59339 m
.13435 .58962 L
s
.13462 .59339 m
.13462 .59513 L
s
.13489 .59339 m
.13489 .58978 L
s
.13515 .59339 m
.13515 .59482 L
s
.13542 .59339 m
.13542 .59562 L
s
.13568 .59339 m
.13568 .59287 L
s
.13595 .59339 m
.13595 .59493 L
s
.13621 .59339 m
.13621 .59273 L
s
.13648 .59339 m
.13648 .58982 L
s
.13675 .59339 m
.13675 .5945 L
s
.13701 .59339 m
.13701 .59415 L
s
.13728 .59339 m
.13728 .59426 L
s
.13754 .59339 m
.13754 .5908 L
s
.13781 .59339 m
.13781 .5951 L
s
.13807 .59339 m
.13807 .59334 L
s
.13834 .59339 m
.13834 .59535 L
s
.13861 .59339 m
.13861 .59023 L
s
.13887 .59339 m
.13887 .59484 L
s
.13914 .59339 m
.13914 .59037 L
s
.1394 .59339 m
.1394 .5942 L
s
.13967 .59339 m
.13967 .59602 L
s
.13993 .59339 m
.13993 .59067 L
s
.1402 .59339 m
.1402 .5987 L
s
.14047 .59339 m
.14047 .59144 L
s
.14073 .59339 m
.14073 .59091 L
s
.141 .59339 m
.141 .59123 L
s
.14126 .59339 m
.14126 .59677 L
s
.14153 .59339 m
.14153 .59339 L
s
.14179 .59339 m
.14179 .59189 L
s
.14206 .59339 m
.14206 .59301 L
s
.14233 .59339 m
.14233 .59522 L
s
.14259 .59339 m
.14259 .59443 L
s
.14286 .59339 m
.14286 .59078 L
s
.14312 .59339 m
.14312 .59367 L
s
.14339 .59339 m
.14339 .59231 L
s
.14365 .59339 m
.14365 .59301 L
s
.14392 .59339 m
.14392 .59667 L
s
.14419 .59339 m
.14419 .58907 L
s
.14445 .59339 m
.14445 .60149 L
s
.14472 .59339 m
.14472 .5895 L
s
.14498 .59339 m
.14498 .59169 L
s
.14525 .59339 m
.14525 .58952 L
s
.14551 .59339 m
.14551 .59841 L
s
.14578 .59339 m
.14578 .59254 L
s
.14605 .59339 m
.14605 .59214 L
s
.14631 .59339 m
.14631 .59274 L
s
.14658 .59339 m
.14658 .59608 L
s
.14684 .59339 m
.14684 .59351 L
s
.14711 .59339 m
.14711 .58899 L
s
.14737 .59339 m
.14737 .59417 L
s
.14764 .59339 m
.14764 .59529 L
s
.14791 .59339 m
.14791 .5928 L
s
.14817 .59339 m
.14817 .59561 L
s
.14844 .59339 m
.14844 .59058 L
s
.1487 .59339 m
.1487 .6005 L
s
.14897 .59339 m
.14897 .58781 L
s
.14923 .59339 m
.14923 .59096 L
s
.1495 .59339 m
.1495 .59151 L
s
.14977 .59339 m
.14977 .59861 L
s
.15003 .59339 m
.15003 .59215 L
s
.1503 .59339 m
.1503 .59171 L
s
.15056 .59339 m
.15056 .59349 L
s
.15083 .59339 m
.15083 .59645 L
s
.15109 .59339 m
.15109 .59191 L
s
.15136 .59339 m
.15136 .58877 L
s
.15163 .59339 m
.15163 .59745 L
s
.15189 .59339 m
.15189 .59547 L
s
.15216 .59339 m
.15216 .591 L
s
.15242 .59339 m
.15242 .59298 L
s
.15269 .59339 m
.15269 .5951 L
s
.15295 .59339 m
.15295 .59519 L
s
.15322 .59339 m
.15322 .5874 L
s
.15349 .59339 m
.15349 .59123 L
s
.15375 .59339 m
.15375 .59725 L
s
.15402 .59339 m
.15402 .59581 L
s
.15428 .59339 m
.15428 .59074 L
s
.15455 .59339 m
.15455 .59196 L
s
.15482 .59339 m
.15482 .59544 L
s
.15508 .59339 m
.15508 .59403 L
s
.15535 .59339 m
.15535 .59181 L
s
.15561 .59339 m
.15561 .58992 L
s
.15588 .59339 m
.15588 .60112 L
s
.15614 .59339 m
.15614 .59341 L
s
.15641 .59339 m
.15641 .5902 L
s
.15668 .59339 m
.15668 .58995 L
s
.15694 .59339 m
.15694 .59927 L
s
.15721 .59339 m
.15721 .58682 L
s
.15747 .59339 m
.15747 .59427 L
s
.15774 .59339 m
.15774 .59385 L
s
.158 .59339 m
.158 .60075 L
s
.15827 .59339 m
.15827 .58909 L
s
.15854 .59339 m
.15854 .59191 L
s
.1588 .59339 m
.1588 .59194 L
s
.15907 .59339 m
.15907 .59753 L
s
.15933 .59339 m
.15933 .59068 L
s
.1596 .59339 m
.1596 .59313 L
s
.15986 .59339 m
.15986 .59484 L
s
.16013 .59339 m
.16013 .59741 L
s
.1604 .59339 m
.1604 .58855 L
s
.16066 .59339 m
.16066 .59098 L
s
.16093 .59339 m
.16093 .59224 L
s
.16119 .59339 m
.16119 .59989 L
s
.16146 .59339 m
.16146 .58693 L
s
.16172 .59339 m
.16172 .602 L
s
.16199 .59339 m
.16199 .59077 L
s
.16226 .59339 m
.16226 .59505 L
s
.16252 .59339 m
.16252 .58555 L
s
.16279 .59339 m
.16279 .59854 L
s
.16305 .59339 m
.16305 .5916 L
s
.16332 .59339 m
.16332 .59756 L
s
.16358 .59339 m
.16358 .58799 L
s
.16385 .59339 m
.16385 .59761 L
s
.16412 .59339 m
.16412 .59379 L
s
.16438 .59339 m
.16438 .59011 L
s
.16465 .59339 m
.16465 .59075 L
s
.16491 .59339 m
.16491 .59744 L
s
.16518 .59339 m
.16518 .593 L
s
.16544 .59339 m
.16544 .59575 L
s
.16571 .59339 m
.16571 .59194 L
s
.16598 .59339 m
.16598 .59574 L
s
.16624 .59339 m
.16624 .58787 L
s
.16651 .59339 m
.16651 .59263 L
s
.16677 .59339 m
.16677 .59411 L
s
.16704 .59339 m
.16704 .59873 L
s
.1673 .59339 m
.1673 .58889 L
s
.16757 .59339 m
.16757 .59572 L
s
.16784 .59339 m
.16784 .59066 L
s
.1681 .59339 m
.1681 .59667 L
s
.16837 .59339 m
.16837 .58989 L
s
.16863 .59339 m
.16863 .59248 L
s
.1689 .59339 m
.1689 .598 L
s
.16916 .59339 m
.16916 .59473 L
s
.16943 .59339 m
.16943 .58923 L
s
.1697 .59339 m
.1697 .59301 L
s
.16996 .59339 m
.16996 .59544 L
s
.17023 .59339 m
.17023 .58913 L
s
.17049 .59339 m
.17049 .59462 L
s
.17076 .59339 m
.17076 .59667 L
s
.17102 .59339 m
.17102 .5964 L
s
.17129 .59339 m
.17129 .59029 L
s
.17156 .59339 m
.17156 .58977 L
s
.17182 .59339 m
.17182 .59635 L
s
.17209 .59339 m
.17209 .59388 L
s
.17235 .59339 m
.17235 .59158 L
s
.17262 .59339 m
.17262 .59346 L
s
.17288 .59339 m
.17288 .59645 L
s
.17315 .59339 m
.17315 .59191 L
s
.17342 .59339 m
.17342 .58837 L
s
.17368 .59339 m
.17368 .59733 L
s
.17395 .59339 m
.17395 .59392 L
s
.17421 .59339 m
.17421 .59416 L
s
.17448 .59339 m
.17448 .59376 L
s
.17474 .59339 m
.17474 .59449 L
s
.17501 .59339 m
.17501 .58939 L
s
.17528 .59339 m
.17528 .58941 L
s
.17554 .59339 m
.17554 .59707 L
s
.17581 .59339 m
.17581 .59649 L
s
.17607 .59339 m
.17607 .59335 L
s
.17634 .59339 m
.17634 .59052 L
s
.17661 .59339 m
.17661 .59384 L
s
.17687 .59339 m
.17687 .59514 L
s
.17714 .59339 m
.17714 .59221 L
s
.1774 .59339 m
.1774 .59182 L
s
.17767 .59339 m
.17767 .59492 L
s
.17793 .59339 m
.17793 .59782 L
s
.1782 .59339 m
.1782 .58831 L
s
.17847 .59339 m
.17847 .59405 L
s
.17873 .59339 m
.17873 .59276 L
s
.179 .59339 m
.179 .59143 L
s
.17926 .59339 m
.17926 .59831 L
s
.17953 .59339 m
.17953 .59425 L
s
.17979 .59339 m
.17979 .59328 L
s
.18006 .59339 m
.18006 .58846 L
s
.18033 .59339 m
.18033 .59452 L
s
.18059 .59339 m
.18059 .59461 L
s
.18086 .59339 m
.18086 .59604 L
s
.18112 .59339 m
.18112 .5893 L
s
.18139 .59339 m
.18139 .59491 L
s
.18165 .59339 m
.18165 .59289 L
s
.18192 .59339 m
.18192 .59552 L
s
.18219 .59339 m
.18219 .59176 L
s
.18245 .59339 m
.18245 .59213 L
s
.18272 .59339 m
.18272 .59503 L
s
.18298 .59339 m
.18298 .59339 L
s
.18325 .59339 m
.18325 .59547 L
s
.18351 .59339 m
.18351 .58579 L
s
.18378 .59339 m
.18378 .60134 L
s
.18405 .59339 m
.18405 .59333 L
s
.18431 .59339 m
.18431 .59447 L
s
.18458 .59339 m
.18458 .58733 L
s
.18484 .59339 m
.18484 .59378 L
s
.18511 .59339 m
.18511 .59667 L
s
.18537 .59339 m
.18537 .59497 L
s
.18564 .59339 m
.18564 .59041 L
s
.18591 .59339 m
.18591 .59262 L
s
.18617 .59339 m
.18617 .5951 L
s
.18644 .59339 m
.18644 .59182 L
s
.1867 .59339 m
.1867 .59688 L
s
.18697 .59339 m
.18697 .59006 L
s
.18723 .59339 m
.18723 .5944 L
s
.1875 .59339 m
.1875 .59056 L
s
.18777 .59339 m
.18777 .59814 L
s
.18803 .59339 m
.18803 .59004 L
s
.1883 .59339 m
.1883 .59577 L
s
.18856 .59339 m
.18856 .59111 L
s
.18883 .59339 m
.18883 .5965 L
s
.18909 .59339 m
.18909 .59156 L
s
.18936 .59339 m
.18936 .59184 L
s
.18963 .59339 m
.18963 .59314 L
s
.18989 .59339 m
.18989 .59614 L
s
.19016 .59339 m
.19016 .59345 L
s
.19042 .59339 m
.19042 .59137 L
s
.19069 .59339 m
.19069 .59361 L
s
.19095 .59339 m
.19095 .59478 L
s
.19122 .59339 m
.19122 .59386 L
s
.19149 .59339 m
.19149 .59236 L
s
.19175 .59339 m
.19175 .59232 L
s
.19202 .59339 m
.19202 .59412 L
s
.19228 .59339 m
.19228 .59488 L
s
.19255 .59339 m
.19255 .59321 L
s
.19281 .59339 m
.19281 .59159 L
s
.19308 .59339 m
.19308 .59357 L
s
.19335 .59339 m
.19335 .59397 L
s
.19361 .59339 m
.19361 .5943 L
s
.19388 .59339 m
.19388 .59304 L
s
.19414 .59339 m
.19414 .5915 L
s
.19441 .59339 m
.19441 .59423 L
s
.19467 .59339 m
.19467 .59423 L
s
.19494 .59339 m
.19494 .59369 L
s
.19521 .59339 m
.19521 .59244 L
s
.19547 .59339 m
.19547 .59391 L
s
.19574 .59339 m
.19574 .59339 L
s
.196 .59339 m
.196 .5943 L
s
.19627 .59339 m
.19627 .59182 L
s
.19653 .59339 m
.19653 .59421 L
s
.1968 .59339 m
.1968 .59241 L
s
.19707 .59339 m
.19707 .5955 L
s
.19733 .59339 m
.19733 .59155 L
s
.1976 .59339 m
.1976 .59429 L
s
.19786 .59339 m
.19786 .59197 L
s
.19813 .59339 m
.19813 .59506 L
s
.19839 .59339 m
.19839 .59269 L
s
.19866 .59339 m
.19866 .5942 L
s
.19893 .59339 m
.19893 .59154 L
s
.19919 .59339 m
.19919 .59451 L
s
.19946 .59339 m
.19946 .59382 L
s
.19972 .59339 m
.19972 .59335 L
s
.19999 .59339 m
.19999 .59226 L
s
.20026 .59339 m
.20026 .59465 L
s
.20052 .59339 m
.20052 .59336 L
s
.20079 .59339 m
.20079 .59295 L
s
.20105 .59339 m
.20105 .59306 L
s
.20132 .59339 m
.20132 .59356 L
s
.20158 .59339 m
.20158 .5944 L
s
.20185 .59339 m
.20185 .5929 L
s
.20212 .59339 m
.20212 .59268 L
s
.20238 .59339 m
.20238 .59334 L
s
.20265 .59339 m
.20265 .59466 L
s
.20291 .59339 m
.20291 .59346 L
s
.20318 .59339 m
.20318 .59252 L
s
.20344 .59339 m
.20344 .5938 L
s
.20371 .59339 m
.20371 .5932 L
s
.20398 .59339 m
.20398 .59404 L
s
.20424 .59339 m
.20424 .59215 L
s
.20451 .59339 m
.20451 .5935 L
s
.20477 .59339 m
.20477 .59462 L
s
.20504 .59339 m
.20504 .59269 L
s
.2053 .59339 m
.2053 .59374 L
s
.20557 .59339 m
.20557 .59291 L
s
.20584 .59339 m
.20584 .59456 L
s
.2061 .59339 m
.2061 .5922 L
s
.20637 .59339 m
.20637 .59388 L
s
.20663 .59339 m
.20663 .59301 L
s
.2069 .59339 m
.2069 .59362 L
s
.20716 .59339 m
.20716 .59233 L
s
.20743 .59339 m
.20743 .59469 L
s
.2077 .59339 m
.2077 .59309 L
s
.20796 .59339 m
.20796 .59407 L
s
.20823 .59339 m
.20823 .59258 L
s
.20849 .59339 m
.20849 .59408 L
s
.20876 .59339 m
.20876 .59294 L
s
.20902 .59339 m
.20902 .5936 L
s
.20929 .59339 m
.20929 .59252 L
s
.20956 .59339 m
.20956 .59426 L
s
.20982 .59339 m
.20982 .59284 L
s
.21009 .59339 m
.21009 .59421 L
s
.21035 .59339 m
.21035 .59248 L
s
.21062 .59339 m
.21062 .59347 L
s
.21088 .59339 m
.21088 .59302 L
s
.21115 .59339 m
.21115 .59394 L
s
.21142 .59339 m
.21142 .593 L
s
.21168 .59339 m
.21168 .59412 L
s
.21195 .59339 m
.21195 .59324 L
s
.21221 .59339 m
.21221 .59337 L
s
.21248 .59339 m
.21248 .59308 L
s
.21274 .59339 m
.21274 .59344 L
s
.21301 .59339 m
.21301 .59373 L
s
.21328 .59339 m
.21328 .5935 L
s
.21354 .59339 m
.21354 .5931 L
s
.21381 .59339 m
.21381 .5934 L
s
.21407 .59339 m
.21407 .59328 L
s
.21434 .59339 m
.21434 .59373 L
s
.2146 .59339 m
.2146 .59299 L
s
.21487 .59339 m
.21487 .59393 L
s
.21514 .59339 m
.21514 .59295 L
s
.2154 .59339 m
.2154 .59443 L
s
.21567 .59339 m
.21567 .59183 L
s
.21593 .59339 m
.21593 .59389 L
s
.2162 .59339 m
.2162 .59367 L
s
.21646 .59339 m
.21646 .59343 L
s
.21673 .59339 m
.21673 .59269 L
s
.217 .59339 m
.217 .59432 L
s
.21726 .59339 m
.21726 .59288 L
s
.21753 .59339 m
.21753 .59379 L
s
.21779 .59339 m
.21779 .59283 L
s
.21806 .59339 m
.21806 .59345 L
s
.21832 .59339 m
.21832 .59335 L
s
.21859 .59339 m
.21859 .59439 L
s
.21886 .59339 m
.21886 .59268 L
s
.21912 .59339 m
.21912 .59361 L
s
.21939 .59339 m
.21939 .59309 L
s
.21965 .59339 m
.21965 .59398 L
s
.21992 .59339 m
.21992 .59216 L
s
.22018 .59339 m
.22018 .59458 L
s
.22045 .59339 m
.22045 .59262 L
s
.22072 .59339 m
.22072 .59456 L
s
.22098 .59339 m
.22098 .59205 L
s
.22125 .59339 m
.22125 .59419 L
s
.22151 .59339 m
.22151 .59264 L
s
.22178 .59339 m
.22178 .59403 L
s
.22205 .59339 m
.22205 .59347 L
s
.22231 .59339 m
.22231 .5931 L
s
.22258 .59339 m
.22258 .59369 L
s
.22284 .59339 m
.22284 .59293 L
s
.22311 .59339 m
.22311 .59384 L
s
.22337 .59339 m
.22337 .59285 L
s
.22364 .59339 m
.22364 .59431 L
s
.22391 .59339 m
.22391 .5923 L
s
.22417 .59339 m
.22417 .59449 L
s
.22444 .59339 m
.22444 .59272 L
s
.2247 .59339 m
.2247 .59353 L
s
.22497 .59339 m
.22497 .59322 L
s
.22523 .59339 m
.22523 .59316 L
s
.2255 .59339 m
.2255 .59376 L
s
.22577 .59339 m
.22577 .59362 L
s
.22603 .59339 m
.22603 .59362 L
s
.2263 .59339 m
.2263 .59207 L
s
.22656 .59339 m
.22656 .59424 L
s
.22683 .59339 m
.22683 .59369 L
s
.22709 .59339 m
.22709 .59294 L
s
.22736 .59339 m
.22736 .59335 L
s
.22763 .59339 m
.22763 .59361 L
s
.22789 .59339 m
.22789 .59369 L
s
.22816 .59339 m
.22816 .59316 L
s
.22842 .59339 m
.22842 .59344 L
s
.22869 .59339 m
.22869 .59269 L
s
.22895 .59339 m
.22895 .59419 L
s
.22922 .59339 m
.22922 .59347 L
s
.22949 .59339 m
.22949 .59333 L
s
.22975 .59339 m
.22975 .5929 L
s
.23002 .59339 m
.23002 .59391 L
s
.23028 .59339 m
.23028 .59307 L
s
.23055 .59339 m
.23055 .59333 L
s
.23081 .59339 m
.23081 .59379 L
s
.23108 .59339 m
.23108 .5928 L
s
.23135 .59339 m
.23135 .5941 L
s
.23161 .59339 m
.23161 .59258 L
s
.23188 .59339 m
.23188 .59402 L
s
.23214 .59339 m
.23214 .59299 L
s
.23241 .59339 m
.23241 .59368 L
s
.23267 .59339 m
.23267 .59302 L
s
.23294 .59339 m
.23294 .59377 L
s
.23321 .59339 m
.23321 .59344 L
s
.23347 .59339 m
.23347 .59291 L
s
.23374 .59339 m
.23374 .59382 L
s
.234 .59339 m
.234 .59284 L
s
.23427 .59339 m
.23427 .59456 L
s
.23453 .59339 m
.23453 .59239 L
s
.2348 .59339 m
.2348 .59397 L
s
.23507 .59339 m
.23507 .59249 L
s
.23533 .59339 m
.23533 .59419 L
s
.2356 .59339 m
.2356 .5929 L
s
.23586 .59339 m
.23586 .59404 L
s
.23613 .59339 m
.23613 .59293 L
s
.23639 .59339 m
.23639 .59348 L
s
.23666 .59339 m
.23666 .5935 L
s
.23693 .59339 m
.23693 .5935 L
s
.23719 .59339 m
.23719 .59305 L
s
.23746 .59339 m
.23746 .5935 L
s
.23772 .59339 m
.23772 .59359 L
s
.23799 .59339 m
.23799 .59353 L
s
.23825 .59339 m
.23825 .59296 L
s
.23852 .59339 m
.23852 .59327 L
s
.23879 .59339 m
.23879 .5932 L
s
.23905 .59339 m
.23905 .5941 L
s
.23932 .59339 m
.23932 .59321 L
s
.23958 .59339 m
.23958 .59339 L
s
.23985 .59339 m
.23985 .59286 L
s
.24011 .59339 m
.24011 .59418 L
s
.24038 .59339 m
.24038 .59275 L
s
.24065 .59339 m
.24065 .59418 L
s
.24091 .59339 m
.24091 .59269 L
s
.24118 .59339 m
.24118 .59361 L
s
.24144 .59339 m
.24144 .59301 L
s
.24171 .59339 m
.24171 .59415 L
s
.24197 .59339 m
.24197 .5929 L
s
.24224 .59339 m
.24224 .59346 L
s
.24251 .59339 m
.24251 .59352 L
s
.24277 .59339 m
.24277 .59348 L
s
.24304 .59339 m
.24304 .59318 L
s
.2433 .59339 m
.2433 .59356 L
s
.24357 .59339 m
.24357 .5931 L
s
.24384 .59339 m
.24384 .59351 L
s
.2441 .59339 m
.2441 .59323 L
s
.24437 .59339 m
.24437 .59356 L
s
.24463 .59339 m
.24463 .5934 L
s
.2449 .59339 m
.2449 .5937 L
s
.24516 .59339 m
.24516 .59301 L
s
.24543 .59339 m
.24543 .59349 L
s
.2457 .59339 m
.2457 .59294 L
s
.24596 .59339 m
.24596 .59396 L
s
.24623 .59339 m
.24623 .59297 L
s
.24649 .59339 m
.24649 .59388 L
s
.24676 .59339 m
.24676 .59315 L
s
.24702 .59339 m
.24702 .59366 L
s
.24729 .59339 m
.24729 .5929 L
s
.24756 .59339 m
.24756 .59374 L
s
.24782 .59339 m
.24782 .59333 L
s
.24809 .59339 m
.24809 .59319 L
s
.24835 .59339 m
.24835 .59346 L
s
.24862 .59339 m
.24862 .59356 L
s
.24888 .59339 m
.24888 .5935 L
s
.24915 .59339 m
.24915 .59283 L
s
.24942 .59339 m
.24942 .59383 L
s
.24968 .59339 m
.24968 .59335 L
s
.24995 .59339 m
.24995 .59349 L
s
.25021 .59339 m
.25021 .59315 L
s
.25048 .59339 m
.25048 .59344 L
s
.25074 .59339 m
.25074 .59348 L
s
.25101 .59339 m
.25101 .59348 L
s
.25128 .59339 m
.25128 .59321 L
s
.25154 .59339 m
.25154 .59297 L
s
.25181 .59339 m
.25181 .59389 L
s
.25207 .59339 m
.25207 .59348 L
s
.25234 .59339 m
.25234 .59346 L
s
.2526 .59339 m
.2526 .59311 L
s
.25287 .59339 m
.25287 .59337 L
s
.25314 .59339 m
.25314 .59331 L
s
.2534 .59339 m
.2534 .59333 L
s
.25367 .59339 m
.25367 .59353 L
s
.25393 .59339 m
.25393 .59348 L
s
.2542 .59339 m
.2542 .59312 L
s
.25446 .59339 m
.25446 .59348 L
s
.25473 .59339 m
.25473 .59354 L
s
.255 .59339 m
.255 .5934 L
s
.25526 .59339 m
.25526 .59316 L
s
.25553 .59339 m
.25553 .59342 L
s
.25579 .59339 m
.25579 .59374 L
s
.25606 .59339 m
.25606 .59305 L
s
.25632 .59339 m
.25632 .59345 L
s
.25659 .59339 m
.25659 .5934 L
s
.25686 .59339 m
.25686 .59345 L
s
.25712 .59339 m
.25712 .59331 L
s
.25739 .59339 m
.25739 .5934 L
s
.25765 .59339 m
.25765 .59324 L
s
.25792 .59339 m
.25792 .59341 L
s
.25818 .59339 m
.25818 .59368 L
s
.25845 .59339 m
.25845 .59303 L
s
.25872 .59339 m
.25872 .59384 L
s
.25898 .59339 m
.25898 .59309 L
s
.25925 .59339 m
.25925 .59335 L
s
.25951 .59339 m
.25951 .59349 L
s
.25978 .59339 m
.25978 .59346 L
s
.26004 .59339 m
.26004 .59335 L
s
.26031 .59339 m
.26031 .59324 L
s
.26058 .59339 m
.26058 .59371 L
s
.26084 .59339 m
.26084 .59315 L
s
.26111 .59339 m
.26111 .59327 L
s
.26137 .59339 m
.26137 .59364 L
s
.26164 .59339 m
.26164 .59356 L
s
.2619 .59339 m
.2619 .59315 L
s
.26217 .59339 m
.26217 .59329 L
s
.26244 .59339 m
.26244 .59353 L
s
.2627 .59339 m
.2627 .59334 L
s
.26297 .59339 m
.26297 .5934 L
s
.26323 .59339 m
.26323 .5934 L
s
.2635 .59339 m
.2635 .59335 L
s
.26376 .59339 m
.26376 .59353 L
s
.26403 .59339 m
.26403 .59332 L
s
.2643 .59339 m
.2643 .5933 L
s
.26456 .59339 m
.26456 .59345 L
s
.26483 .59339 m
.26483 .59345 L
s
.26509 .59339 m
.26509 .59342 L
s
.26536 .59339 m
.26536 .59336 L
s
.26562 .59339 m
.26562 .59331 L
s
.26589 .59339 m
.26589 .59338 L
s
.26616 .59339 m
.26616 .59357 L
s
.26642 .59339 m
.26642 .59317 L
s
.26669 .59339 m
.26669 .59344 L
s
.26695 .59339 m
.26695 .59318 L
s
.26722 .59339 m
.26722 .59355 L
s
.26749 .59339 m
.26749 .59349 L
s
.26775 .59339 m
.26775 .59344 L
s
.26802 .59339 m
.26802 .59313 L
s
.26828 .59339 m
.26828 .59344 L
s
.26855 .59339 m
.26855 .59366 L
s
.26881 .59339 m
.26881 .59322 L
s
.26908 .59339 m
.26908 .59352 L
s
.26935 .59339 m
.26935 .59311 L
s
.26961 .59339 m
.26961 .59348 L
s
.26988 .59339 m
.26988 .59348 L
s
.27014 .59339 m
.27014 .59361 L
s
.27041 .59339 m
.27041 .59311 L
s
.27067 .59339 m
.27067 .5934 L
s
.27094 .59339 m
.27094 .59351 L
s
.27121 .59339 m
.27121 .59329 L
s
.27147 .59339 m
.27147 .59324 L
s
.27174 .59339 m
.27174 .59334 L
s
.272 .59339 m
.272 .59366 L
s
.27227 .59339 m
.27227 .59332 L
s
.27253 .59339 m
.27253 .5935 L
s
.2728 .59339 m
.2728 .59317 L
s
.27307 .59339 m
.27307 .59367 L
s
.27333 .59339 m
.27333 .5931 L
s
.2736 .59339 m
.2736 .59347 L
s
.27386 .59339 m
.27386 .59355 L
s
.27413 .59339 m
.27413 .59339 L
s
.27439 .59339 m
.27439 .5931 L
s
.27466 .59339 m
.27466 .59365 L
s
.27493 .59339 m
.27493 .59325 L
s
.27519 .59339 m
.27519 .59333 L
s
.27546 .59339 m
.27546 .59348 L
s
.27572 .59339 m
.27572 .59346 L
s
.27599 .59339 m
.27599 .59322 L
s
.27625 .59339 m
.27625 .59364 L
s
.27652 .59339 m
.27652 .59332 L
s
.27679 .59339 m
.27679 .59324 L
s
.27705 .59339 m
.27705 .59355 L
s
.27732 .59339 m
.27732 .59331 L
s
.27758 .59339 m
.27758 .59331 L
s
.27785 .59339 m
.27785 .59349 L
s
.27811 .59339 m
.27811 .59351 L
s
.27838 .59339 m
.27838 .59311 L
s
.27865 .59339 m
.27865 .59364 L
s
.27891 .59339 m
.27891 .59333 L
s
.27918 .59339 m
.27918 .59338 L
s
.27944 .59339 m
.27944 .59331 L
s
.27971 .59339 m
.27971 .5936 L
s
.27997 .59339 m
.27997 .59331 L
s
.28024 .59339 m
.28024 .59327 L
s
.28051 .59339 m
.28051 .59348 L
s
.28077 .59339 m
.28077 .59323 L
s
.28104 .59339 m
.28104 .59339 L
s
.2813 .59339 m
.2813 .59364 L
s
.28157 .59339 m
.28157 .59342 L
s
.28183 .59339 m
.28183 .59318 L
s
.2821 .59339 m
.2821 .59333 L
s
.28237 .59339 m
.28237 .59353 L
s
.28263 .59339 m
.28263 .5933 L
s
.2829 .59339 m
.2829 .59351 L
s
.28316 .59339 m
.28316 .5934 L
s
.28343 .59339 m
.28343 .59349 L
s
.28369 .59339 m
.28369 .59319 L
s
.28396 .59339 m
.28396 .59347 L
s
.28423 .59339 m
.28423 .59337 L
s
.28449 .59339 m
.28449 .5933 L
s
.28476 .59339 m
.28476 .59338 L
s
.28502 .59339 m
.28502 .59332 L
s
.28529 .59339 m
.28529 .59364 L
s
.28555 .59339 m
.28555 .59324 L
s
.28582 .59339 m
.28582 .59367 L
s
.28609 .59339 m
.28609 .59301 L
s
.28635 .59339 m
.28635 .59351 L
s
.28662 .59339 m
.28662 .59343 L
s
.28688 .59339 m
.28688 .59343 L
s
.28715 .59339 m
.28715 .59325 L
s
.28741 .59339 m
.28741 .5936 L
s
.28768 .59339 m
.28768 .59323 L
s
.28795 .59339 m
.28795 .59345 L
s
.28821 .59339 m
.28821 .59336 L
s
.28848 .59339 m
.28848 .5935 L
s
.28874 .59339 m
.28874 .59318 L
s
.28901 .59339 m
.28901 .5934 L
s
.28928 .59339 m
.28928 .59347 L
s
.28954 .59339 m
.28954 .59349 L
s
.28981 .59339 m
.28981 .59329 L
s
.29007 .59339 m
.29007 .59329 L
s
.29034 .59339 m
.29034 .59358 L
s
.2906 .59339 m
.2906 .59337 L
s
.29087 .59339 m
.29087 .59339 L
s
.29114 .59339 m
.29114 .59328 L
s
.2914 .59339 m
.2914 .59324 L
s
.29167 .59339 m
.29167 .59375 L
s
.29193 .59339 m
.29193 .59338 L
s
.2922 .59339 m
.2922 .59332 L
s
.29246 .59339 m
.29246 .59328 L
s
.29273 .59339 m
.29273 .59358 L
s
.293 .59339 m
.293 .59326 L
s
.29326 .59339 m
.29326 .59346 L
s
.29353 .59339 m
.29353 .59323 L
s
.29379 .59339 m
.29379 .59349 L
s
.29406 .59339 m
.29406 .59346 L
s
.29432 .59339 m
.29432 .59326 L
s
.29459 .59339 m
.29459 .59341 L
s
.29486 .59339 m
.29486 .59329 L
s
.29512 .59339 m
.29512 .59346 L
s
.29539 .59339 m
.29539 .59342 L
s
.29565 .59339 m
.29565 .59338 L
s
.29592 .59339 m
.29592 .59342 L
s
.29618 .59339 m
.29618 .59335 L
s
.29645 .59339 m
.29645 .59355 L
s
.29672 .59339 m
.29672 .59317 L
s
.29698 .59339 m
.29698 .59338 L
s
.29725 .59339 m
.29725 .59342 L
s
.29751 .59339 m
.29751 .59351 L
s
.29778 .59339 m
.29778 .59328 L
s
.29804 .59339 m
.29804 .59357 L
s
.29831 .59339 m
.29831 .59322 L
s
.29858 .59339 m
.29858 .59314 L
s
.29884 .59339 m
.29884 .59353 L
s
.29911 .59339 m
.29911 .59366 L
s
.29937 .59339 m
.29937 .59325 L
s
.29964 .59339 m
.29964 .59343 L
s
.2999 .59339 m
.2999 .59348 L
s
.30017 .59339 m
.30017 .59325 L
s
.30044 .59339 m
.30044 .59358 L
s
.3007 .59339 m
.3007 .59306 L
s
.30097 .59339 m
.30097 .59357 L
s
.30123 .59339 m
.30123 .59338 L
s
.3015 .59339 m
.3015 .59358 L
s
.30176 .59339 m
.30176 .59313 L
s
.30203 .59339 m
.30203 .59348 L
s
.3023 .59339 m
.3023 .59341 L
s
.30256 .59339 m
.30256 .59348 L
s
.30283 .59339 m
.30283 .59327 L
s
.30309 .59339 m
.30309 .59347 L
s
.30336 .59339 m
.30336 .59344 L
s
.30362 .59339 m
.30362 .59322 L
s
.30389 .59339 m
.30389 .59353 L
s
.30416 .59339 m
.30416 .59348 L
s
.30442 .59339 m
.30442 .59312 L
s
.30469 .59339 m
.30469 .59343 L
s
.30495 .59339 m
.30495 .59353 L
s
.30522 .59339 m
.30522 .59348 L
s
.30548 .59339 m
.30548 .5934 L
s
.30575 .59339 m
.30575 .59336 L
s
.30602 .59339 m
.30602 .59322 L
s
.30628 .59339 m
.30628 .5934 L
s
.30655 .59339 m
.30655 .59344 L
s
.30681 .59339 m
.30681 .5935 L
s
.30708 .59339 m
.30708 .59323 L
s
.30734 .59339 m
.30734 .59354 L
s
.30761 .59339 m
.30761 .59334 L
s
.30788 .59339 m
.30788 .59338 L
s
.30814 .59339 m
.30814 .59323 L
s
.30841 .59339 m
.30841 .59365 L
s
.30867 .59339 m
.30867 .59336 L
s
.30894 .59339 m
.30894 .5933 L
s
.3092 .59339 m
.3092 .59337 L
s
.30947 .59339 m
.30947 .59357 L
s
.30974 .59339 m
.30974 .59338 L
s
.31 .59339 m
.31 .5933 L
s
.31027 .59339 m
.31027 .5933 L
s
.31053 .59339 m
.31053 .59346 L
s
.3108 .59339 m
.3108 .59347 L
s
.31107 .59339 m
.31107 .59338 L
s
.31133 .59339 m
.31133 .59323 L
s
.3116 .59339 m
.3116 .59349 L
s
.31186 .59339 m
.31186 .5934 L
s
.31213 .59339 m
.31213 .59346 L
s
.31239 .59339 m
.31239 .5935 L
s
.31266 .59339 m
.31266 .59338 L
s
.31293 .59339 m
.31293 .59315 L
s
.31319 .59339 m
.31319 .59333 L
s
.31346 .59339 m
.31346 .59349 L
s
.31372 .59339 m
.31372 .59347 L
s
.31399 .59339 m
.31399 .5935 L
s
.31425 .59339 m
.31425 .59274 L
s
.31452 .59339 m
.31452 .59383 L
s
.31479 .59339 m
.31479 .5933 L
s
.31505 .59339 m
.31505 .5936 L
s
.31532 .59339 m
.31532 .59352 L
s
.31558 .59339 m
.31558 .59312 L
s
.31585 .59339 m
.31585 .59322 L
s
.31611 .59339 m
.31611 .59336 L
s
.31638 .59339 m
.31638 .59363 L
s
.31665 .59339 m
.31665 .59296 L
s
.31691 .59339 m
.31691 .59405 L
s
.31718 .59339 m
.31718 .59287 L
s
.31744 .59339 m
.31744 .59378 L
s
.31771 .59339 m
.31771 .59328 L
s
.31797 .59339 m
.31797 .59345 L
s
.31824 .59339 m
.31824 .59351 L
s
.31851 .59339 m
.31851 .5932 L
s
.31877 .59339 m
.31877 .59334 L
s
.31904 .59339 m
.31904 .59352 L
s
.3193 .59339 m
.3193 .59329 L
s
.31957 .59339 m
.31957 .59344 L
s
.31983 .59339 m
.31983 .59353 L
s
.3201 .59339 m
.3201 .59333 L
s
.32037 .59339 m
.32037 .59335 L
s
.32063 .59339 m
.32063 .59322 L
s
.3209 .59339 m
.3209 .59334 L
s
.32116 .59339 m
.32116 .59349 L
s
.32143 .59339 m
.32143 .59353 L
s
.32169 .59339 m
.32169 .59343 L
s
.32196 .59339 m
.32196 .59313 L
s
.32223 .59339 m
.32223 .59359 L
s
.32249 .59339 m
.32249 .5934 L
s
.32276 .59339 m
.32276 .59323 L
s
.32302 .59339 m
.32302 .59363 L
s
.32329 .59339 m
.32329 .59349 L
s
.32355 .59339 m
.32355 .59322 L
s
.32382 .59339 m
.32382 .59347 L
s
.32409 .59339 m
.32409 .59337 L
s
.32435 .59339 m
.32435 .5934 L
s
.32462 .59339 m
.32462 .59328 L
s
.32488 .59339 m
.32488 .59338 L
s
.32515 .59339 m
.32515 .59339 L
s
.32541 .59339 m
.32541 .59369 L
s
.32568 .59339 m
.32568 .59329 L
s
.32595 .59339 m
.32595 .59331 L
s
.32621 .59339 m
.32621 .59331 L
s
.32648 .59339 m
.32648 .59352 L
s
.32674 .59339 m
.32674 .59317 L
s
.32701 .59339 m
.32701 .59395 L
s
.32727 .59339 m
.32727 .5928 L
s
.32754 .59339 m
.32754 .59329 L
s
.32781 .59339 m
.32781 .59321 L
s
.32807 .59339 m
.32807 .5934 L
s
.32834 .59339 m
.32834 .59428 L
s
.3286 .59339 m
.3286 .59254 L
s
.32887 .59339 m
.32887 .59374 L
s
.32913 .59339 m
.32913 .59346 L
s
.3294 .59339 m
.3294 .59325 L
s
.32967 .59339 m
.32967 .5935 L
s
.32993 .59339 m
.32993 .593 L
s
.3302 .59339 m
.3302 .59359 L
s
.33046 .59339 m
.33046 .59362 L
s
.33073 .59339 m
.33073 .59308 L
s
.33099 .59339 m
.33099 .59369 L
s
.33126 .59339 m
.33126 .59307 L
s
.33153 .59339 m
.33153 .59327 L
s
.33179 .59339 m
.33179 .59479 L
s
.33206 .59339 m
.33206 .59234 L
s
.33232 .59339 m
.33232 .59358 L
s
.33259 .59339 m
.33259 .59284 L
s
.33286 .59339 m
.33286 .5938 L
s
.33312 .59339 m
.33312 .59411 L
s
.33339 .59339 m
.33339 .59227 L
s
.33365 .59339 m
.33365 .59442 L
s
.33392 .59339 m
.33392 .5928 L
s
.33418 .59339 m
.33418 .5938 L
s
.33445 .59339 m
.33445 .59286 L
s
.33472 .59339 m
.33472 .59304 L
s
.33498 .59339 m
.33498 .59403 L
s
.33525 .59339 m
.33525 .59283 L
s
.33551 .59339 m
.33551 .59504 L
s
.33578 .59339 m
.33578 .59136 L
s
.33604 .59339 m
.33604 .59395 L
s
.33631 .59339 m
.33631 .59286 L
s
.33658 .59339 m
.33658 .59374 L
s
.33684 .59339 m
.33684 .59494 L
s
.33711 .59339 m
.33711 .59125 L
s
.33737 .59339 m
.33737 .59449 L
s
.33764 .59339 m
.33764 .59271 L
s
.3379 .59339 m
.3379 .59387 L
s
.33817 .59339 m
.33817 .594 L
s
.33844 .59339 m
.33844 .59222 L
s
.3387 .59339 m
.3387 .59425 L
s
.33897 .59339 m
.33897 .59247 L
s
.33923 .59339 m
.33923 .5944 L
s
.3395 .59339 m
.3395 .59313 L
s
.33976 .59339 m
.33976 .59278 L
s
.34003 .59339 m
.34003 .59459 L
s
.3403 .59339 m
.3403 .59245 L
s
.34056 .59339 m
.34056 .59502 L
s
.34083 .59339 m
.34083 .59053 L
s
.34109 .59339 m
.34109 .5942 L
s
.34136 .59339 m
.34136 .59452 L
s
.34162 .59339 m
.34162 .59291 L
s
.34189 .59339 m
.34189 .59435 L
s
.34216 .59339 m
.34216 .59078 L
s
.34242 .59339 m
.34242 .5953 L
s
.34269 .59339 m
.34269 .59327 L
s
.34295 .59339 m
.34295 .59341 L
s
.34322 .59339 m
.34322 .59322 L
s
.34348 .59339 m
.34348 .59245 L
s
.34375 .59339 m
.34375 .59421 L
s
.34402 .59339 m
.34402 .5938 L
s
.34428 .59339 m
.34428 .59331 L
s
.34455 .59339 m
.34455 .59305 L
s
.34481 .59339 m
.34481 .59309 L
s
.34508 .59339 m
.34508 .59623 L
s
.34534 .59339 m
.34534 .5907 L
s
.34561 .59339 m
.34561 .59379 L
s
.34588 .59339 m
.34588 .59234 L
s
.34614 .59339 m
.34614 .59512 L
s
.34641 .59339 m
.34641 .5944 L
s
.34667 .59339 m
.34667 .59129 L
s
.34694 .59339 m
.34694 .59392 L
s
.3472 .59339 m
.3472 .59283 L
s
.34747 .59339 m
.34747 .59473 L
s
.34774 .59339 m
.34774 .59299 L
s
.348 .59339 m
.348 .59287 L
s
.34827 .59339 m
.34827 .59298 L
s
.34853 .59339 m
.34853 .59396 L
s
.3488 .59339 m
.3488 .59367 L
s
.34906 .59339 m
.34906 .59332 L
s
.34933 .59339 m
.34933 .59283 L
s
.3496 .59339 m
.3496 .59584 L
s
.34986 .59339 m
.34986 .59073 L
s
.35013 .59339 m
.35013 .59376 L
s
.35039 .59339 m
.35039 .59209 L
s
.35066 .59339 m
.35066 .59533 L
s
.35092 .59339 m
.35092 .59446 L
s
.35119 .59339 m
.35119 .59181 L
s
.35146 .59339 m
.35146 .5938 L
s
.35172 .59339 m
.35172 .59237 L
s
.35199 .59339 m
.35199 .59449 L
s
.35225 .59339 m
.35225 .59343 L
s
.35252 .59339 m
.35252 .59359 L
s
.35278 .59339 m
.35278 .59234 L
s
.35305 .59339 m
.35305 .59398 L
s
.35332 .59339 m
.35332 .59338 L
s
.35358 .59339 m
.35358 .59406 L
s
.35385 .59339 m
.35385 .59284 L
s
.35411 .59339 m
.35411 .5953 L
s
.35438 .59339 m
.35438 .59041 L
s
.35464 .59339 m
.35464 .5942 L
s
.35491 .59339 m
.35491 .59335 L
s
.35518 .59339 m
.35518 .59442 L
s
.35544 .59339 m
.35544 .59386 L
s
.35571 .59339 m
.35571 .59147 L
s
.35597 .59339 m
.35597 .59468 L
s
.35624 .59339 m
.35624 .59308 L
s
.35651 .59339 m
.35651 .59386 L
s
.35677 .59339 m
.35677 .59259 L
s
.35704 .59339 m
.35704 .59351 L
s
.3573 .59339 m
.3573 .59284 L
s
.35757 .59339 m
.35757 .59454 L
s
.35783 .59339 m
.35783 .59274 L
s
.3581 .59339 m
.3581 .59401 L
s
.35837 .59339 m
.35837 .59265 L
s
.35863 .59339 m
.35863 .59524 L
s
.3589 .59339 m
.3589 .59048 L
s
.35916 .59339 m
.35916 .59449 L
s
.35943 .59339 m
.35943 .59338 L
s
.35969 .59339 m
.35969 .59427 L
s
.35996 .59339 m
.35996 .59374 L
s
.36023 .59339 m
.36023 .59166 L
s
.36049 .59339 m
.36049 .59479 L
s
.36076 .59339 m
.36076 .59299 L
s
.36102 .59339 m
.36102 .59406 L
s
.36129 .59339 m
.36129 .59284 L
s
.36155 .59339 m
.36155 .59285 L
s
.36182 .59339 m
.36182 .59285 L
s
.36209 .59339 m
.36209 .5945 L
s
.36235 .59339 m
.36235 .59308 L
s
.36262 .59339 m
.36262 .59424 L
s
.36288 .59339 m
.36288 .59239 L
s
.36315 .59339 m
.36315 .5955 L
s
.36341 .59339 m
.36341 .5903 L
s
.36368 .59339 m
.36368 .59406 L
s
.36395 .59339 m
.36395 .59367 L
s
.36421 .59339 m
.36421 .59382 L
s
.36448 .59339 m
.36448 .59411 L
s
.36474 .59339 m
.36474 .59171 L
s
.36501 .59339 m
.36501 .59499 L
s
.36527 .59339 m
.36527 .59259 L
s
.36554 .59339 m
.36554 .59352 L
s
.36581 .59339 m
.36581 .59331 L
s
.36607 .59339 m
.36607 .5934 L
s
.36634 .59339 m
.36634 .59296 L
s
.3666 .59339 m
.3666 .59442 L
s
.36687 .59339 m
.36687 .59181 L
s
.36713 .59339 m
.36713 .59543 L
s
.3674 .59339 m
.3674 .5921 L
s
.36767 .59339 m
.36767 .59495 L
s
.36793 .59339 m
.36793 .59032 L
s
.3682 .59339 m
.3682 .59459 L
s
.36846 .59339 m
.36846 .59439 L
s
.36873 .59339 m
.36873 .59225 L
s
.36899 .59339 m
.36899 .59447 L
s
.36926 .59339 m
.36926 .59179 L
s
.36953 .59339 m
.36953 .59537 L
s
.36979 .59339 m
.36979 .59213 L
s
.37006 .59339 m
.37006 .59308 L
s
.37032 .59339 m
.37032 .59419 L
s
.37059 .59339 m
.37059 .5934 L
s
.37085 .59339 m
.37085 .5934 L
s
.37112 .59339 m
.37112 .59356 L
s
.37139 .59339 m
.37139 .59248 L
s
.37165 .59339 m
.37165 .59562 L
s
.37192 .59339 m
.37192 .59072 L
s
.37218 .59339 m
.37218 .59399 L
s
.37245 .59339 m
.37245 .59256 L
s
.37271 .59339 m
.37271 .59448 L
s
.37298 .59339 m
.37298 .59441 L
s
.37325 .59339 m
.37325 .59102 L
s
.37351 .59339 m
.37351 .59496 L
s
.37378 .59339 m
.37378 .59279 L
s
.37404 .59339 m
.37404 .59403 L
s
.37431 .59339 m
.37431 .59254 L
s
.37457 .59339 m
.37457 .59291 L
s
.37484 .59339 m
.37484 .5949 L
s
.37511 .59339 m
.37511 .59261 L
s
.37537 .59339 m
.37537 .59288 L
s
.37564 .59339 m
.37564 .59423 L
s
.3759 .59339 m
.3759 .59252 L
s
.37617 .59339 m
.37617 .59515 L
s
.37643 .59339 m
.37643 .5907 L
s
.3767 .59339 m
.3767 .59356 L
s
.37697 .59339 m
.37697 .5948 L
s
.37723 .59339 m
.37723 .59287 L
s
.3775 .59339 m
.3775 .59425 L
s
.37776 .59339 m
.37776 .59167 L
s
.37803 .59339 m
.37803 .59468 L
s
.3783 .59339 m
.3783 .59379 L
s
.37856 .59339 m
.37856 .59241 L
s
.37883 .59339 m
.37883 .59399 L
s
.37909 .59339 m
.37909 .5931 L
s
.37936 .59339 m
.37936 .59364 L
s
.37962 .59339 m
.37962 .59364 L
s
.37989 .59339 m
.37989 .59254 L
s
.38016 .59339 m
.38016 .59478 L
s
.38042 .59339 m
.38042 .59234 L
s
.38069 .59339 m
.38069 .59326 L
s
.38095 .59339 m
.38095 .59358 L
s
.38122 .59339 m
.38122 .59311 L
s
.38148 .59339 m
.38148 .59481 L
s
.38175 .59339 m
.38175 .59262 L
s
.38202 .59339 m
.38202 .59341 L
s
.38228 .59339 m
.38228 .59353 L
s
.38255 .59339 m
.38255 .59266 L
s
.38281 .59339 m
.38281 .59407 L
s
.38308 .59339 m
.38308 .59369 L
s
.38334 .59339 m
.38334 .59284 L
s
.38361 .59339 m
.38361 .5937 L
s
.38388 .59339 m
.38388 .59255 L
s
.38414 .59339 m
.38414 .59442 L
s
.38441 .59339 m
.38441 .59327 L
s
.38467 .59339 m
.38467 .59282 L
s
.38494 .59339 m
.38494 .59377 L
s
.3852 .59339 m
.3852 .59264 L
s
.38547 .59339 m
.38547 .59436 L
s
.38574 .59339 m
.38574 .59237 L
s
.386 .59339 m
.386 .59351 L
s
.38627 .59339 m
.38627 .59402 L
s
.38653 .59339 m
.38653 .59277 L
s
.3868 .59339 m
.3868 .59394 L
s
.38706 .59339 m
.38706 .59324 L
s
.38733 .59339 m
.38733 .5928 L
s
.3876 .59339 m
.3876 .59394 L
s
.38786 .59339 m
.38786 .59241 L
s
.38813 .59339 m
.38813 .59391 L
s
.38839 .59339 m
.38839 .59423 L
s
.38866 .59339 m
.38866 .59246 L
s
.38892 .59339 m
.38892 .59368 L
s
.38919 .59339 m
.38919 .59331 L
s
.38946 .59339 m
.38946 .59358 L
s
.38972 .59339 m
.38972 .5932 L
s
.38999 .59339 m
.38999 .5929 L
s
.39025 .59339 m
.39025 .59378 L
s
.39052 .59339 m
.39052 .59359 L
s
.39078 .59339 m
.39078 .59359 L
s
.39105 .59339 m
.39105 .59285 L
s
.39132 .59339 m
.39132 .59321 L
s
.39158 .59339 m
.39158 .59404 L
s
.39185 .59339 m
.39185 .59327 L
s
.39211 .59339 m
.39211 .59301 L
s
.39238 .59339 m
.39238 .59388 L
s
.39264 .59339 m
.39264 .59296 L
s
.39291 .59339 m
.39291 .5938 L
s
.39318 .59339 m
.39318 .59313 L
s
.39344 .59339 m
.39344 .59324 L
s
.39371 .59339 m
.39371 .59383 L
s
.39397 .59339 m
.39397 .59311 L
s
.39424 .59339 m
.39424 .59322 L
s
.3945 .59339 m
.3945 .59334 L
s
.39477 .59339 m
.39477 .5936 L
s
.39504 .59339 m
.39504 .5936 L
s
.3953 .59339 m
.3953 .59309 L
s
.39557 .59339 m
.39557 .59354 L
s
.39583 .59339 m
.39583 .59335 L
s
.3961 .59339 m
.3961 .59361 L
s
.39636 .59339 m
.39636 .59359 L
s
.39663 .59339 m
.39663 .59322 L
s
.3969 .59339 m
.3969 .59408 L
s
.39716 .59339 m
.39716 .59285 L
s
.39743 .59339 m
.39743 .59338 L
s
.39769 .59339 m
.39769 .59325 L
s
.39796 .59339 m
.39796 .59345 L
s
.39822 .59339 m
.39822 .59339 L
s
.39849 .59339 m
.39849 .59347 L
s
.39876 .59339 m
.39876 .59305 L
s
.39902 .59339 m
.39902 .59377 L
s
.39929 .59339 m
.39929 .59298 L
s
.39955 .59339 m
.39955 .59385 L
s
.39982 .59339 m
.39982 .59318 L
s
.40009 .59339 m
.40009 .59336 L
s
.40035 .59339 m
.40035 .59374 L
s
.40062 .59339 m
.40062 .59306 L
s
.40088 .59339 m
.40088 .59359 L
s
.40115 .59339 m
.40115 .59337 L
s
.40141 .59339 m
.40141 .59354 L
s
.40168 .59339 m
.40168 .59341 L
s
.40195 .59339 m
.40195 .59331 L
s
.40221 .59339 m
.40221 .59327 L
s
.40248 .59339 m
.40248 .59392 L
s
.40274 .59339 m
.40274 .59294 L
s
.40301 .59339 m
.40301 .5935 L
s
.40327 .59339 m
.40327 .59313 L
s
.40354 .59339 m
.40354 .59349 L
s
.40381 .59339 m
.40381 .59334 L
s
.40407 .59339 m
.40407 .59351 L
s
.40434 .59339 m
.40434 .59322 L
s
.4046 .59339 m
.4046 .59327 L
s
.40487 .59339 m
.40487 .59373 L
s
.40513 .59339 m
.40513 .59327 L
s
.4054 .59339 m
.4054 .59351 L
s
.40567 .59339 m
.40567 .59352 L
s
.40593 .59339 m
.40593 .59282 L
s
.4062 .59339 m
.4062 .59353 L
s
.40646 .59339 m
.40646 .59354 L
s
.40673 .59339 m
.40673 .59338 L
s
.40699 .59339 m
.40699 .59353 L
s
.40726 .59339 m
.40726 .59302 L
s
.40753 .59339 m
.40753 .59384 L
s
.40779 .59339 m
.40779 .59318 L
s
.40806 .59339 m
.40806 .59345 L
s
.40832 .59339 m
.40832 .59329 L
s
.40859 .59339 m
.40859 .5934 L
s
.40885 .59339 m
.40885 .59374 L
s
.40912 .59339 m
.40912 .59319 L
s
.40939 .59339 m
.40939 .5936 L
s
.40965 .59339 m
.40965 .59301 L
s
.40992 .59339 m
.40992 .59335 L
s
.41018 .59339 m
.41018 .59373 L
s
.41045 .59339 m
.41045 .59336 L
s
.41071 .59339 m
.41071 .59329 L
s
.41098 .59339 m
.41098 .59349 L
s
.41125 .59339 m
.41125 .59304 L
s
.41151 .59339 m
.41151 .59369 L
s
.41178 .59339 m
.41178 .59337 L
s
.41204 .59339 m
.41204 .59341 L
s
.41231 .59339 m
.41231 .59347 L
s
.41257 .59339 m
.41257 .59322 L
s
.41284 .59339 m
.41284 .59322 L
s
.41311 .59339 m
.41311 .59309 L
s
.41337 .59339 m
.41337 .594 L
s
.41364 .59339 m
.41364 .59306 L
s
.4139 .59339 m
.4139 .59341 L
s
.41417 .59339 m
.41417 .59349 L
s
.41443 .59339 m
.41443 .59304 L
s
.4147 .59339 m
.4147 .59371 L
s
.41497 .59339 m
.41497 .5934 L
s
.41523 .59339 m
.41523 .59298 L
s
.4155 .59339 m
.4155 .59391 L
s
.41576 .59339 m
.41576 .59319 L
s
.41603 .59339 m
.41603 .59374 L
s
.41629 .59339 m
.41629 .59335 L
s
.41656 .59339 m
.41656 .59296 L
s
.41683 .59339 m
.41683 .59375 L
s
.41709 .59339 m
.41709 .59301 L
s
.41736 .59339 m
.41736 .59365 L
s
.41762 .59339 m
.41762 .59338 L
s
.41789 .59339 m
.41789 .59359 L
s
.41815 .59339 m
.41815 .59295 L
s
.41842 .59339 m
.41842 .5935 L
s
.41869 .59339 m
.41869 .59351 L
s
.41895 .59339 m
.41895 .59317 L
s
.41922 .59339 m
.41922 .59365 L
s
.41948 .59339 m
.41948 .59338 L
s
.41975 .59339 m
.41975 .59297 L
s
.42001 .59339 m
.42001 .59356 L
s
.42028 .59339 m
.42028 .59306 L
s
.42055 .59339 m
.42055 .59351 L
s
.42081 .59339 m
.42081 .59372 L
s
.42108 .59339 m
.42108 .59307 L
s
.42134 .59339 m
.42134 .59364 L
s
.42161 .59339 m
.42161 .59314 L
s
.42188 .59339 m
.42188 .59348 L
s
.42214 .59339 m
.42214 .59353 L
s
.42241 .59339 m
.42241 .59359 L
s
.42267 .59339 m
.42267 .59303 L
s
.42294 .59339 m
.42294 .59365 L
s
.4232 .59339 m
.4232 .59339 L
s
.42347 .59339 m
.42347 .59325 L
s
.42374 .59339 m
.42374 .59356 L
s
.424 .59339 m
.424 .59311 L
s
.42427 .59339 m
.42427 .59342 L
s
.42453 .59339 m
.42453 .59363 L
s
.4248 .59339 m
.4248 .59299 L
s
.42506 .59339 m
.42506 .59342 L
s
.42533 .59339 m
.42533 .59366 L
s
.4256 .59339 m
.4256 .59304 L
s
.42586 .59339 m
.42586 .59384 L
s
.42613 .59339 m
.42613 .59323 L
s
.42639 .59339 m
.42639 .59323 L
s
.42666 .59339 m
.42666 .59344 L
s
.42692 .59339 m
.42692 .59362 L
s
.42719 .59339 m
.42719 .59309 L
s
.42746 .59339 m
.42746 .59358 L
s
.42772 .59339 m
.42772 .59343 L
s
.42799 .59339 m
.42799 .59327 L
s
.42825 .59339 m
.42825 .59363 L
s
.42852 .59339 m
.42852 .59336 L
s
.42878 .59339 m
.42878 .59314 L
s
.42905 .59339 m
.42905 .59358 L
s
.42932 .59339 m
.42932 .59335 L
s
.42958 .59339 m
.42958 .59343 L
s
.42985 .59339 m
.42985 .59364 L
s
.43011 .59339 m
.43011 .59267 L
s
.43038 .59339 m
.43038 .59399 L
s
.43064 .59339 m
.43064 .59339 L
s
.43091 .59339 m
.43091 .59355 L
s
.43118 .59339 m
.43118 .59344 L
s
.43144 .59339 m
.43144 .59348 L
s
.43171 .59339 m
.43171 .59271 L
s
.43197 .59339 m
.43197 .59368 L
s
.43224 .59339 m
.43224 .59349 L
s
.4325 .59339 m
.4325 .59322 L
s
.43277 .59339 m
.43277 .59377 L
s
.43304 .59339 m
.43304 .59341 L
s
.4333 .59339 m
.4333 .59321 L
s
.43357 .59339 m
.43357 .59344 L
s
.43383 .59339 m
.43383 .59324 L
s
.4341 .59339 m
.4341 .59344 L
s
.43436 .59339 m
.43436 .59377 L
s
.43463 .59339 m
.43463 .59293 L
s
.4349 .59339 m
.4349 .59399 L
s
.43516 .59339 m
.43516 .59283 L
s
.43543 .59339 m
.43543 .5934 L
s
.43569 .59339 m
.43569 .59348 L
s
.43596 .59339 m
.43596 .59389 L
s
.43622 .59339 m
.43622 .59285 L
s
.43649 .59339 m
.43649 .59347 L
s
.43676 .59339 m
.43676 .59353 L
s
.43702 .59339 m
.43702 .59305 L
s
.43729 .59339 m
.43729 .59357 L
s
.43755 .59339 m
.43755 .59323 L
s
.43782 .59339 m
.43782 .59338 L
s
.43808 .59339 m
.43808 .59366 L
s
.43835 .59339 m
.43835 .59312 L
s
.43862 .59339 m
.43862 .59325 L
s
.43888 .59339 m
.43888 .5937 L
s
.43915 .59339 m
.43915 .59303 L
s
.43941 .59339 m
.43941 .5937 L
s
.43968 .59339 m
.43968 .59319 L
s
.43994 .59339 m
.43994 .59342 L
s
.44021 .59339 m
.44021 .59315 L
s
.44048 .59339 m
.44048 .59364 L
s
.44074 .59339 m
.44074 .59347 L
s
.44101 .59339 m
.44101 .59327 L
s
.44127 .59339 m
.44127 .59346 L
s
.44154 .59339 m
.44154 .5935 L
s
.4418 .59339 m
.4418 .59349 L
s
.44207 .59339 m
.44207 .59307 L
s
.44234 .59339 m
.44234 .59361 L
s
.4426 .59339 m
.4426 .59368 L
s
.44287 .59339 m
.44287 .59307 L
s
.44313 .59339 m
.44313 .59353 L
s
.4434 .59339 m
.4434 .59343 L
s
.44366 .59339 m
.44366 .59314 L
s
.44393 .59339 m
.44393 .59344 L
s
.4442 .59339 m
.4442 .59318 L
s
.44446 .59339 m
.44446 .59354 L
s
.44473 .59339 m
.44473 .59345 L
s
.44499 .59339 m
.44499 .59292 L
s
.44526 .59339 m
.44526 .59392 L
s
.44553 .59339 m
.44553 .5933 L
s
.44579 .59339 m
.44579 .593 L
s
.44606 .59339 m
.44606 .59393 L
s
.44632 .59339 m
.44632 .5932 L
s
.44659 .59339 m
.44659 .59313 L
s
.44685 .59339 m
.44685 .5936 L
s
.44712 .59339 m
.44712 .59325 L
s
.44739 .59339 m
.44739 .59334 L
s
.44765 .59339 m
.44765 .59363 L
s
.44792 .59339 m
.44792 .59309 L
s
.44818 .59339 m
.44818 .59384 L
s
.44845 .59339 m
.44845 .59328 L
s
.44871 .59339 m
.44871 .59293 L
s
.44898 .59339 m
.44898 .59349 L
s
.44925 .59339 m
.44925 .59376 L
s
.44951 .59339 m
.44951 .59317 L
s
.44978 .59339 m
.44978 .59343 L
s
.45004 .59339 m
.45004 .59351 L
s
.45031 .59339 m
.45031 .5934 L
s
.45057 .59339 m
.45057 .59337 L
s
.45084 .59339 m
.45084 .59315 L
s
.45111 .59339 m
.45111 .59393 L
s
.45137 .59339 m
.45137 .59324 L
s
.45164 .59339 m
.45164 .59308 L
s
.4519 .59339 m
.4519 .59372 L
s
.45217 .59339 m
.45217 .59339 L
s
.45243 .59339 m
.45243 .59298 L
s
.4527 .59339 m
.4527 .59363 L
s
.45297 .59339 m
.45297 .59328 L
s
.45323 .59339 m
.45323 .59344 L
s
.4535 .59339 m
.4535 .59374 L
s
.45376 .59339 m
.45376 .59273 L
s
.45403 .59339 m
.45403 .59365 L
s
.45429 .59339 m
.45429 .59329 L
s
.45456 .59339 m
.45456 .59316 L
s
.45483 .59339 m
.45483 .59395 L
s
.45509 .59339 m
.45509 .59337 L
s
.45536 .59339 m
.45536 .5929 L
s
.45562 .59339 m
.45562 .59391 L
s
.45589 .59339 m
.45589 .59312 L
s
.45615 .59339 m
.45615 .59374 L
s
.45642 .59339 m
.45642 .5931 L
s
.45669 .59339 m
.45669 .59338 L
s
.45695 .59339 m
.45695 .59391 L
s
.45722 .59339 m
.45722 .59307 L
s
.45748 .59339 m
.45748 .59303 L
s
.45775 .59339 m
.45775 .59389 L
s
.45801 .59339 m
.45801 .59313 L
s
.45828 .59339 m
.45828 .59345 L
s
.45855 .59339 m
.45855 .59359 L
s
.45881 .59339 m
.45881 .59316 L
s
.45908 .59339 m
.45908 .59361 L
s
.45934 .59339 m
.45934 .59348 L
s
.45961 .59339 m
.45961 .59319 L
s
.45987 .59339 m
.45987 .59352 L
s
.46014 .59339 m
.46014 .59339 L
s
.46041 .59339 m
.46041 .59306 L
s
.46067 .59339 m
.46067 .59425 L
s
.46094 .59339 m
.46094 .59249 L
s
.4612 .59339 m
.4612 .59378 L
s
.46147 .59339 m
.46147 .59389 L
s
.46173 .59339 m
.46173 .59286 L
s
.462 .59339 m
.462 .59396 L
s
.46227 .59339 m
.46227 .59261 L
s
.46253 .59339 m
.46253 .59236 L
s
.4628 .59339 m
.4628 .59627 L
s
.46306 .59339 m
.46306 .59205 L
s
.46333 .59339 m
.46333 .59324 L
s
.46359 .59339 m
.46359 .59438 L
s
.46386 .59339 m
.46386 .59213 L
s
.46413 .59339 m
.46413 .59536 L
s
.46439 .59339 m
.46439 .5917 L
s
.46466 .59339 m
.46466 .59295 L
s
.46492 .59339 m
.46492 .59572 L
s
.46519 .59339 m
.46519 .59139 L
s
.46545 .59339 m
.46545 .59421 L
s
.46572 .59339 m
.46572 .59308 L
s
.46599 .59339 m
.46599 .59345 L
s
.46625 .59339 m
.46625 .59337 L
s
.46652 .59339 m
.46652 .59482 L
s
.46678 .59339 m
.46678 .59226 L
s
.46705 .59339 m
.46705 .5945 L
s
.46732 .59339 m
.46732 .59141 L
s
.46758 .59339 m
.46758 .59248 L
s
.46785 .59339 m
.46785 .59648 L
s
.46811 .59339 m
.46811 .59114 L
s
.46838 .59339 m
.46838 .59378 L
s
.46864 .59339 m
.46864 .59324 L
s
.46891 .59339 m
.46891 .59318 L
s
.46918 .59339 m
.46918 .59552 L
s
.46944 .59339 m
.46944 .59024 L
s
.46971 .59339 m
.46971 .59452 L
s
.46997 .59339 m
.46997 .5941 L
s
.47024 .59339 m
.47024 .5938 L
s
.4705 .59339 m
.4705 .59216 L
s
.47077 .59339 m
.47077 .59552 L
s
.47104 .59339 m
.47104 .59131 L
s
.4713 .59339 m
.4713 .59467 L
s
.47157 .59339 m
.47157 .59171 L
s
.47183 .59339 m
.47183 .59238 L
s
.4721 .59339 m
.4721 .59786 L
s
.47236 .59339 m
.47236 .58989 L
s
.47263 .59339 m
.47263 .5948 L
s
.4729 .59339 m
.4729 .59238 L
s
.47316 .59339 m
.47316 .59321 L
s
.47343 .59339 m
.47343 .5958 L
s
.47369 .59339 m
.47369 .59008 L
s
.47396 .59339 m
.47396 .59494 L
s
.47422 .59339 m
.47422 .5927 L
s
.47449 .59339 m
.47449 .59403 L
s
.47476 .59339 m
.47476 .59291 L
s
.47502 .59339 m
.47502 .59545 L
s
.47529 .59339 m
.47529 .59113 L
s
.47555 .59339 m
.47555 .59493 L
s
.47582 .59339 m
.47582 .59107 L
s
.47608 .59339 m
.47608 .59265 L
s
.47635 .59339 m
.47635 .59749 L
s
.47662 .59339 m
.47662 .58978 L
s
.47688 .59339 m
.47688 .59523 L
s
.47715 .59339 m
.47715 .59204 L
s
.47741 .59339 m
.47741 .5943 L
s
.47768 .59339 m
.47768 .59495 L
s
.47794 .59339 m
.47794 .59092 L
s
.47821 .59339 m
.47821 .59421 L
s
.47848 .59339 m
.47848 .5923 L
s
.47874 .59339 m
.47874 .59459 L
s
.47901 .59339 m
.47901 .593 L
s
.47927 .59339 m
.47927 .59546 L
s
.47954 .59339 m
.47954 .59028 L
s
.4798 .59339 m
.4798 .59585 L
s
.48007 .59339 m
.48007 .59053 L
s
.48034 .59339 m
.48034 .59342 L
s
.4806 .59339 m
.4806 .59635 L
s
.48087 .59339 m
.48087 .59048 L
s
.48113 .59339 m
.48113 .59584 L
s
.4814 .59339 m
.4814 .59055 L
s
.48166 .59339 m
.48166 .59562 L
s
.48193 .59339 m
.48193 .59377 L
s
.4822 .59339 m
.4822 .59183 L
s
.48246 .59339 m
.48246 .59371 L
s
.48273 .59339 m
.48273 .59212 L
s
.48299 .59339 m
.48299 .59419 L
s
.48326 .59339 m
.48326 .59318 L
s
.48352 .59339 m
.48352 .59529 L
s
.48379 .59339 m
.48379 .59066 L
s
.48406 .59339 m
.48406 .59783 L
s
.48432 .59339 m
.48432 .58839 L
s
.48459 .59339 m
.48459 .59385 L
s
.48485 .59339 m
.48485 .5951 L
s
.48512 .59339 m
.48512 .59221 L
s
.48538 .59339 m
.48538 .59583 L
s
.48565 .59339 m
.48565 .58924 L
s
.48592 .59339 m
.48592 .59676 L
s
.48618 .59339 m
.48618 .59311 L
s
.48645 .59339 m
.48645 .59342 L
s
.48671 .59339 m
.48671 .59267 L
s
.48698 .59339 m
.48698 .59195 L
s
.48724 .59339 m
.48724 .59369 L
s
.48751 .59339 m
.48751 .59503 L
s
.48778 .59339 m
.48778 .59284 L
s
.48804 .59339 m
.48804 .59108 L
s
.48831 .59339 m
.48831 .59877 L
s
.48857 .59339 m
.48857 .5896 L
s
.48884 .59339 m
.48884 .59503 L
s
.48911 .59339 m
.48911 .59092 L
s
.48937 .59339 m
.48937 .59508 L
s
.48964 .59339 m
.48964 .59514 L
s
.4899 .59339 m
.4899 .59015 L
s
.49017 .59339 m
.49017 .59557 L
s
.49043 .59339 m
.49043 .59093 L
s
.4907 .59339 m
.4907 .59651 L
s
.49097 .59339 m
.49097 .59317 L
s
.49123 .59339 m
.49123 .59308 L
s
.4915 .59339 m
.4915 .59085 L
s
.49176 .59339 m
.49176 .59657 L
s
.49203 .59339 m
.49203 .59124 L
s
.49229 .59339 m
.49229 .59276 L
s
.49256 .59339 m
.49256 .59468 L
s
.49283 .59339 m
.49283 .59283 L
s
.49309 .59339 m
.49309 .59747 L
s
.49336 .59339 m
.49336 .587 L
s
.49362 .59339 m
.49362 .59701 L
s
.49389 .59339 m
.49389 .59211 L
s
.49415 .59339 m
.49415 .59472 L
s
.49442 .59339 m
.49442 .59299 L
s
.49469 .59339 m
.49469 .59146 L
s
.49495 .59339 m
.49495 .59516 L
s
.49522 .59339 m
.49522 .59283 L
s
.49548 .59339 m
.49548 .59469 L
s
.49575 .59339 m
.49575 .59165 L
s
.49601 .59339 m
.49601 .5963 L
s
.49628 .59339 m
.49628 .59006 L
s
.49655 .59339 m
.49655 .59787 L
s
.49681 .59339 m
.49681 .58662 L
s
.49708 .59339 m
.49708 .59615 L
s
.49734 .59339 m
.49734 .59547 L
s
.49761 .59339 m
.49761 .59131 L
s
.49787 .59339 m
.49787 .59524 L
s
.49814 .59339 m
.49814 .58874 L
s
.49841 .59339 m
.49841 .59868 L
s
.49867 .59339 m
.49867 .59079 L
s
.49894 .59339 m
.49894 .59528 L
s
.4992 .59339 m
.4992 .59208 L
s
.49947 .59339 m
.49947 .59381 L
s
.49973 .59339 m
.49973 .59172 L
s
.5 .59339 m
.5 .59721 L
s
.50027 .59339 m
.50027 .5892 L
s
.50053 .59339 m
.50053 .59337 L
s
.5008 .59339 m
.5008 .5994 L
s
.50106 .59339 m
.50106 .58999 L
s
.50133 .59339 m
.50133 .59618 L
s
.50159 .59339 m
.50159 .58587 L
s
.50186 .59339 m
.50186 .60076 L
s
.50213 .59339 m
.50213 .59137 L
s
.50239 .59339 m
.50239 .59332 L
s
.50266 .59339 m
.50266 .59285 L
s
.50292 .59339 m
.50292 .59316 L
s
.50319 .59339 m
.50319 .59387 L
s
.50345 .59339 m
.50345 .59312 L
s
.50372 .59339 m
.50372 .59378 L
s
.50399 .59339 m
.50399 .59142 L
s
.50425 .59339 m
.50425 .59727 L
s
.50452 .59339 m
.50452 .59073 L
s
.50478 .59339 m
.50478 .59819 L
s
.50505 .59339 m
.50505 .58197 L
s
.50531 .59339 m
.50531 .59984 L
s
.50558 .59339 m
.50558 .59408 L
s
.50585 .59339 m
.50585 .59421 L
s
.50611 .59339 m
.50611 .59127 L
s
.50638 .59339 m
.50638 .59132 L
s
.50664 .59339 m
.50664 .59775 L
s
.50691 .59339 m
.50691 .5909 L
s
.50717 .59339 m
.50717 .59473 L
s
.50744 .59339 m
.50744 .59248 L
s
.50771 .59339 m
.50771 .5955 L
s
.50797 .59339 m
.50797 .58886 L
s
.50824 .59339 m
.50824 .60213 L
s
.5085 .59339 m
.5085 .58309 L
s
.50877 .59339 m
.50877 .59564 L
s
.50903 .59339 m
.50903 .59294 L
s
.5093 .59339 m
.5093 .6 L
s
.50957 .59339 m
.50957 .59236 L
s
.50983 .59339 m
.50983 .58591 L
s
.5101 .59339 m
.5101 .59843 L
s
.51036 .59339 m
.51036 .59223 L
s
.51063 .59339 m
.51063 .59724 L
s
.51089 .59339 m
.51089 .58676 L
s
.51116 .59339 m
.51116 .59718 L
s
.51143 .59339 m
.51143 .59151 L
s
.51169 .59339 m
.51169 .59595 L
s
.51196 .59339 m
.51196 .59044 L
s
.51222 .59339 m
.51222 .59654 L
s
.51249 .59339 m
.51249 .58572 L
s
.51276 .59339 m
.51276 .6007 L
s
.51302 .59339 m
.51302 .59785 L
s
.51329 .59339 m
.51329 .58914 L
s
.51355 .59339 m
.51355 .59274 L
s
.51382 .59339 m
.51382 .58879 L
s
.51408 .59339 m
.51408 .60332 L
s
.51435 .59339 m
.51435 .5876 L
s
.51462 .59339 m
.51462 .59473 L
s
.51488 .59339 m
.51488 .59103 L
s
.51515 .59339 m
.51515 .59836 L
s
.51541 .59339 m
.51541 .58876 L
s
.51568 .59339 m
.51568 .59443 L
s
.51594 .59339 m
.51594 .59153 L
s
.51621 .59339 m
.51621 .59622 L
s
.51648 .59339 m
.51648 .58976 L
s
.51674 .59339 m
.51674 .59964 L
s
.51701 .59339 m
.51701 .59739 L
s
.51727 .59339 m
.51727 .58484 L
s
.51754 .59339 m
.51754 .59571 L
s
.5178 .59339 m
.5178 .58968 L
s
.51807 .59339 m
.51807 .60304 L
s
.51834 .59339 m
.51834 .58638 L
s
.5186 .59339 m
.5186 .59485 L
s
.51887 .59339 m
.51887 .59292 L
s
.51913 .59339 m
.51913 .59732 L
s
.5194 .59339 m
.5194 .58725 L
s
.51966 .59339 m
.51966 .59588 L
s
.51993 .59339 m
.51993 .59007 L
s
.5202 .59339 m
.5202 .59796 L
s
.52046 .59339 m
.52046 .58832 L
s
.52073 .59339 m
.52073 .60041 L
s
.52099 .59339 m
.52099 .59675 L
s
.52126 .59339 m
.52126 .58642 L
s
.52152 .59339 m
.52152 .59409 L
s
.52179 .59339 m
.52179 .59245 L
s
.52206 .59339 m
.52206 .60033 L
s
.52232 .59339 m
.52232 .58757 L
s
.52259 .59339 m
.52259 .5941 L
s
.52285 .59339 m
.52285 .59243 L
s
.52312 .59339 m
.52312 .59961 L
s
.52338 .59339 m
.52338 .58875 L
s
.52365 .59339 m
.52365 .59531 L
s
.52392 .59339 m
.52392 .58789 L
s
.52418 .59339 m
.52418 .60214 L
s
.52445 .59339 m
.52445 .58182 L
s
.52471 .59339 m
.52471 .59918 L
s
.52498 .59339 m
.52498 .59436 L
s
.52524 .59339 m
.52524 .59927 L
s
.52551 .59339 m
.52551 .58822 L
s
.52578 .59339 m
.52578 .59083 L
s
.52604 .59339 m
.52604 .59505 L
s
.52631 .59339 m
.52631 .59636 L
s
.52657 .59339 m
.52657 .59285 L
s
.52684 .59339 m
.52684 .58874 L
s
.5271 .59339 m
.5271 .59625 L
s
.52737 .59339 m
.52737 .59469 L
s
.52764 .59339 m
.52764 .59562 L
s
.5279 .59339 m
.5279 .58998 L
s
.52817 .59339 m
.52817 .59627 L
s
.52843 .59339 m
.52843 .59406 L
s
.5287 .59339 m
.5287 .5949 L
s
.52896 .59339 m
.52896 .58555 L
s
.52923 .59339 m
.52923 .59767 L
s
.5295 .59339 m
.5295 .5921 L
s
.52976 .59339 m
.52976 .59796 L
s
.53003 .59339 m
.53003 .5885 L
s
.53029 .59339 m
.53029 .5944 L
s
.53056 .59339 m
.53056 .59291 L
s
.53082 .59339 m
.53082 .59644 L
s
.53109 .59339 m
.53109 .59199 L
s
.53136 .59339 m
.53136 .59399 L
s
.53162 .59339 m
.53162 .58838 L
s
.53189 .59339 m
.53189 .60047 L
s
.53215 .59339 m
.53215 .59012 L
s
.53242 .59339 m
.53242 .59403 L
s
.53268 .59339 m
.53268 .58756 L
s
.53295 .59339 m
.53295 .5985 L
s
.53322 .59339 m
.53322 .59538 L
s
.53348 .59339 m
.53348 .59264 L
s
.53375 .59339 m
.53375 .58972 L
s
.53401 .59339 m
.53401 .5963 L
s
.53428 .59339 m
.53428 .59372 L
s
.53455 .59339 m
.53455 .59576 L
s
.53481 .59339 m
.53481 .59025 L
s
.53508 .59339 m
.53508 .5921 L
s
.53534 .59339 m
.53534 .59117 L
s
.53561 .59339 m
.53561 .60099 L
s
.53587 .59339 m
.53587 .58639 L
s
.53614 .59339 m
.53614 .5952 L
s
.53641 .59339 m
.53641 .58802 L
s
.53667 .59339 m
.53667 .60314 L
s
.53694 .59339 m
.53694 .59178 L
s
.5372 .59339 m
.5372 .59214 L
s
.53747 .59339 m
.53747 .58817 L
s
.53773 .59339 m
.53773 .60024 L
s
.538 .59339 m
.538 .59246 L
s
.53827 .59339 m
.53827 .59437 L
s
.53853 .59339 m
.53853 .58711 L
s
.5388 .59339 m
.5388 .59655 L
s
.53906 .59339 m
.53906 .59288 L
s
.53933 .59339 m
.53933 .60027 L
s
.53959 .59339 m
.53959 .58484 L
s
.53986 .59339 m
.53986 .59382 L
s
.54013 .59339 m
.54013 .59162 L
s
.54039 .59339 m
.54039 .60167 L
s
.54066 .59339 m
.54066 .59032 L
s
.54092 .59339 m
.54092 .59255 L
s
.54119 .59339 m
.54119 .58879 L
s
.54145 .59339 m
.54145 .60009 L
s
.54172 .59339 m
.54172 .59085 L
s
.54199 .59339 m
.54199 .59621 L
s
.54225 .59339 m
.54225 .58915 L
s
.54252 .59339 m
.54252 .59624 L
s
.54278 .59339 m
.54278 .59079 L
s
.54305 .59339 m
.54305 .6009 L
s
.54331 .59339 m
.54331 .58613 L
s
.54358 .59339 m
.54358 .59472 L
s
.54385 .59339 m
.54385 .58686 L
s
.54411 .59339 m
.54411 .60192 L
s
.54438 .59339 m
.54438 .59108 L
s
.54464 .59339 m
.54464 .59486 L
s
.54491 .59339 m
.54491 .5897 L
s
.54517 .59339 m
.54517 .59754 L
s
.54544 .59339 m
.54544 .59127 L
s
.54571 .59339 m
.54571 .59383 L
s
.54597 .59339 m
.54597 .59147 L
s
.54624 .59339 m
.54624 .59532 L
s
.5465 .59339 m
.5465 .59264 L
s
.54677 .59339 m
.54677 .5916 L
s
.54703 .59339 m
.54703 .59773 L
s
.5473 .59339 m
.5473 .59439 L
s
.54757 .59339 m
.54757 .59166 L
s
.54783 .59339 m
.54783 .58925 L
s
.5481 .59339 m
.5481 .59466 L
s
.54836 .59339 m
.54836 .59558 L
s
.54863 .59339 m
.54863 .59488 L
s
.54889 .59339 m
.54889 .58997 L
s
.54916 .59339 m
.54916 .59521 L
s
.54943 .59339 m
.54943 .59373 L
s
.54969 .59339 m
.54969 .595 L
s
.54996 .59339 m
.54996 .59109 L
s
.55022 .59339 m
.55022 .59584 L
s
.55049 .59339 m
.55049 .5887 L
s
.55075 .59339 m
.55075 .59473 L
s
.55102 .59339 m
.55102 .59143 L
s
.55129 .59339 m
.55129 .59788 L
s
.55155 .59339 m
.55155 .59267 L
s
.55182 .59339 m
.55182 .59347 L
s
.55208 .59339 m
.55208 .59089 L
s
.55235 .59339 m
.55235 .59557 L
s
.55261 .59339 m
.55261 .59203 L
s
.55288 .59339 m
.55288 .5962 L
s
.55315 .59339 m
.55315 .5896 L
s
.55341 .59339 m
.55341 .59433 L
s
.55368 .59339 m
.55368 .59268 L
s
.55394 .59339 m
.55394 .59616 L
s
.55421 .59339 m
.55421 .59208 L
s
.55447 .59339 m
.55447 .59542 L
s
.55474 .59339 m
.55474 .59041 L
s
.55501 .59339 m
.55501 .59352 L
s
.55527 .59339 m
.55527 .59284 L
s
.55554 .59339 m
.55554 .5949 L
s
.5558 .59339 m
.5558 .59378 L
s
.55607 .59339 m
.55607 .59273 L
s
.55634 .59339 m
.55634 .59345 L
s
.5566 .59339 m
.5566 .59309 L
s
.55687 .59339 m
.55687 .59339 L
s
.55713 .59339 m
.55713 .59351 L
s
.5574 .59339 m
.5574 .59421 L
s
.55766 .59339 m
.55766 .5921 L
s
.55793 .59339 m
.55793 .59322 L
s
.5582 .59339 m
.5582 .59352 L
s
.55846 .59339 m
.55846 .5951 L
s
.55873 .59339 m
.55873 .59215 L
s
.55899 .59339 m
.55899 .59273 L
s
.55926 .59339 m
.55926 .59353 L
s
.55952 .59339 m
.55952 .59458 L
s
.55979 .59339 m
.55979 .59274 L
s
.56006 .59339 m
.56006 .59343 L
s
.56032 .59339 m
.56032 .59366 L
s
.56059 .59339 m
.56059 .59341 L
s
.56085 .59339 m
.56085 .59387 L
s
.56112 .59339 m
.56112 .59271 L
s
.56138 .59339 m
.56138 .59359 L
s
.56165 .59339 m
.56165 .59362 L
s
.56192 .59339 m
.56192 .59239 L
s
.56218 .59339 m
.56218 .5942 L
s
.56245 .59339 m
.56245 .59271 L
s
.56271 .59339 m
.56271 .59509 L
s
.56298 .59339 m
.56298 .59236 L
s
.56324 .59339 m
.56324 .5938 L
s
.56351 .59339 m
.56351 .59286 L
s
.56378 .59339 m
.56378 .59327 L
s
.56404 .59339 m
.56404 .59393 L
s
.56431 .59339 m
.56431 .59352 L
s
.56457 .59339 m
.56457 .59344 L
s
.56484 .59339 m
.56484 .59175 L
s
.5651 .59339 m
.5651 .59465 L
s
.56537 .59339 m
.56537 .59297 L
s
.56564 .59339 m
.56564 .59501 L
s
.5659 .59339 m
.5659 .59133 L
s
.56617 .59339 m
.56617 .59449 L
s
.56643 .59339 m
.56643 .59273 L
s
.5667 .59339 m
.5667 .59508 L
s
.56696 .59339 m
.56696 .59171 L
s
.56723 .59339 m
.56723 .59418 L
s
.5675 .59339 m
.5675 .59203 L
s
.56776 .59339 m
.56776 .59472 L
s
.56803 .59339 m
.56803 .59313 L
s
.56829 .59339 m
.56829 .59371 L
s
.56856 .59339 m
.56856 .59249 L
s
.56882 .59339 m
.56882 .59404 L
s
.56909 .59339 m
.56909 .59394 L
s
.56936 .59339 m
.56936 .59303 L
s
.56962 .59339 m
.56962 .59304 L
s
.56989 .59339 m
.56989 .59278 L
s
.57015 .59339 m
.57015 .59425 L
s
.57042 .59339 m
.57042 .59435 L
s
.57068 .59339 m
.57068 .59246 L
s
.57095 .59339 m
.57095 .59319 L
s
.57122 .59339 m
.57122 .59353 L
s
.57148 .59339 m
.57148 .5941 L
s
.57175 .59339 m
.57175 .59219 L
s
.57201 .59339 m
.57201 .59322 L
s
.57228 .59339 m
.57228 .59387 L
s
.57254 .59339 m
.57254 .59368 L
s
.57281 .59339 m
.57281 .5935 L
s
.57308 .59339 m
.57308 .59311 L
s
.57334 .59339 m
.57334 .59364 L
s
.57361 .59339 m
.57361 .59318 L
s
.57387 .59339 m
.57387 .5938 L
s
.57414 .59339 m
.57414 .59214 L
s
.5744 .59339 m
.5744 .59445 L
s
.57467 .59339 m
.57467 .5922 L
s
.57494 .59339 m
.57494 .59475 L
s
.5752 .59339 m
.5752 .59256 L
s
.57547 .59339 m
.57547 .59363 L
s
.57573 .59339 m
.57573 .59302 L
s
.576 .59339 m
.576 .59386 L
s
.57626 .59339 m
.57626 .59323 L
s
.57653 .59339 m
.57653 .59335 L
s
.5768 .59339 m
.5768 .59338 L
s
.57706 .59339 m
.57706 .59329 L
s
.57733 .59339 m
.57733 .59377 L
s
.57759 .59339 m
.57759 .59325 L
s
.57786 .59339 m
.57786 .59358 L
s
.57813 .59339 m
.57813 .59349 L
s
.57839 .59339 m
.57839 .59328 L
s
.57866 .59339 m
.57866 .59281 L
s
.57892 .59339 m
.57892 .59355 L
s
.57919 .59339 m
.57919 .59375 L
s
.57945 .59339 m
.57945 .59343 L
s
.57972 .59339 m
.57972 .59278 L
s
.57999 .59339 m
.57999 .59371 L
s
.58025 .59339 m
.58025 .59401 L
s
.58052 .59339 m
.58052 .59313 L
s
.58078 .59339 m
.58078 .59353 L
s
.58105 .59339 m
.58105 .59326 L
s
.58131 .59339 m
.58131 .59358 L
s
.58158 .59339 m
.58158 .59309 L
s
.58185 .59339 m
.58185 .59373 L
s
.58211 .59339 m
.58211 .59339 L
s
.58238 .59339 m
.58238 .59343 L
s
.58264 .59339 m
.58264 .59271 L
s
.58291 .59339 m
.58291 .59331 L
s
.58317 .59339 m
.58317 .59375 L
s
.58344 .59339 m
.58344 .59389 L
s
.58371 .59339 m
.58371 .59262 L
s
.58397 .59339 m
.58397 .59363 L
s
.58424 .59339 m
.58424 .59279 L
s
.5845 .59339 m
.5845 .59441 L
s
.58477 .59339 m
.58477 .59294 L
s
.58503 .59339 m
.58503 .5935 L
s
.5853 .59339 m
.5853 .5924 L
s
.58557 .59339 m
.58557 .59473 L
s
.58583 .59339 m
.58583 .59282 L
s
.5861 .59339 m
.5861 .59411 L
s
.58636 .59339 m
.58636 .59188 L
s
.58663 .59339 m
.58663 .59452 L
s
.58689 .59339 m
.58689 .59284 L
s
.58716 .59339 m
.58716 .59406 L
s
.58743 .59339 m
.58743 .59249 L
s
.58769 .59339 m
.58769 .59374 L
s
.58796 .59339 m
.58796 .59352 L
s
.58822 .59339 m
.58822 .59338 L
s
.58849 .59339 m
.58849 .59357 L
s
.58875 .59339 m
.58875 .59291 L
s
.58902 .59339 m
.58902 .59361 L
s
.58929 .59339 m
.58929 .59292 L
s
.58955 .59339 m
.58955 .5944 L
s
.58982 .59339 m
.58982 .59282 L
s
.59008 .59339 m
.59008 .59334 L
s
.59035 .59339 m
.59035 .59298 L
s
.59061 .59339 m
.59061 .59427 L
s
.59088 .59339 m
.59088 .59318 L
s
.59115 .59339 m
.59115 .59317 L
s
.59141 .59339 m
.59141 .59295 L
s
.59168 .59339 m
.59168 .59377 L
s
.59194 .59339 m
.59194 .59373 L
s
.59221 .59339 m
.59221 .59289 L
s
.59247 .59339 m
.59247 .59327 L
s
.59274 .59339 m
.59274 .59332 L
s
.59301 .59339 m
.59301 .59421 L
s
.59327 .59339 m
.59327 .59306 L
s
.59354 .59339 m
.59354 .59316 L
s
.5938 .59339 m
.5938 .59344 L
s
.59407 .59339 m
.59407 .59376 L
s
.59433 .59339 m
.59433 .59347 L
s
.5946 .59339 m
.5946 .59288 L
s
.59487 .59339 m
.59487 .59365 L
s
.59513 .59339 m
.59513 .59309 L
s
.5954 .59339 m
.5954 .59386 L
s
.59566 .59339 m
.59566 .59296 L
s
.59593 .59339 m
.59593 .5936 L
s
.59619 .59339 m
.59619 .59299 L
s
.59646 .59339 m
.59646 .5938 L
s
.59673 .59339 m
.59673 .59311 L
s
.59699 .59339 m
.59699 .59374 L
s
.59726 .59339 m
.59726 .59312 L
s
.59752 .59339 m
.59752 .59312 L
s
.59779 .59339 m
.59779 .59367 L
s
.59805 .59339 m
.59805 .59409 L
s
.59832 .59339 m
.59832 .59315 L
s
.59859 .59339 m
.59859 .59276 L
s
.59885 .59339 m
.59885 .59343 L
s
.59912 .59339 m
.59912 .59411 L
s
.59938 .59339 m
.59938 .59344 L
s
.59965 .59339 m
.59965 .59251 L
s
.59991 .59339 m
.59991 .59358 L
s
.60018 .59339 m
.60018 .59349 L
s
.60045 .59339 m
.60045 .59392 L
s
.60071 .59339 m
.60071 .59304 L
s
.60098 .59339 m
.60098 .59317 L
s
.60124 .59339 m
.60124 .59307 L
s
.60151 .59339 m
.60151 .5939 L
s
.60178 .59339 m
.60178 .59343 L
s
.60204 .59339 m
.60204 .59295 L
s
.60231 .59339 m
.60231 .59356 L
s
.60257 .59339 m
.60257 .59329 L
s
.60284 .59339 m
.60284 .5937 L
s
.6031 .59339 m
.6031 .5935 L
s
.60337 .59339 m
.60337 .59279 L
s
.60364 .59339 m
.60364 .5937 L
s
.6039 .59339 m
.6039 .59334 L
s
.60417 .59339 m
.60417 .59351 L
s
.60443 .59339 m
.60443 .59308 L
s
.6047 .59339 m
.6047 .59391 L
s
.60496 .59339 m
.60496 .59285 L
s
.60523 .59339 m
.60523 .59386 L
s
.6055 .59339 m
.6055 .59326 L
s
.60576 .59339 m
.60576 .59368 L
s
.60603 .59339 m
.60603 .59306 L
s
.60629 .59339 m
.60629 .59333 L
s
.60656 .59339 m
.60656 .5936 L
s
.60682 .59339 m
.60682 .59324 L
s
.60709 .59339 m
.60709 .59339 L
s
.60736 .59339 m
.60736 .59329 L
s
.60762 .59339 m
.60762 .59364 L
s
.60789 .59339 m
.60789 .59336 L
s
.60815 .59339 m
.60815 .59364 L
s
.60842 .59339 m
.60842 .59288 L
s
.60868 .59339 m
.60868 .59379 L
s
.60895 .59339 m
.60895 .5926 L
s
.60922 .59339 m
.60922 .59391 L
s
.60948 .59339 m
.60948 .59365 L
s
.60975 .59339 m
.60975 .59361 L
s
.61001 .59339 m
.61001 .59278 L
s
.61028 .59339 m
.61028 .59333 L
s
.61054 .59339 m
.61054 .59362 L
s
.61081 .59339 m
.61081 .59342 L
s
.61108 .59339 m
.61108 .59328 L
s
.61134 .59339 m
.61134 .59331 L
s
.61161 .59339 m
.61161 .59333 L
s
.61187 .59339 m
.61187 .59357 L
s
.61214 .59339 m
.61214 .59341 L
s
.6124 .59339 m
.6124 .59354 L
s
.61267 .59339 m
.61267 .59307 L
s
.61294 .59339 m
.61294 .59387 L
s
.6132 .59339 m
.6132 .59288 L
s
.61347 .59339 m
.61347 .59361 L
s
.61373 .59339 m
.61373 .59321 L
s
.614 .59339 m
.614 .59379 L
s
.61426 .59339 m
.61426 .59259 L
s
.61453 .59339 m
.61453 .59395 L
s
.6148 .59339 m
.6148 .59319 L
s
.61506 .59339 m
.61506 .59402 L
s
.61533 .59339 m
.61533 .59266 L
s
.61559 .59339 m
.61559 .59393 L
s
.61586 .59339 m
.61586 .5928 L
s
.61612 .59339 m
.61612 .594 L
s
.61639 .59339 m
.61639 .59272 L
s
.61666 .59339 m
.61666 .59381 L
s
.61692 .59339 m
.61692 .59313 L
s
.61719 .59339 m
.61719 .59371 L
s
.61745 .59339 m
.61745 .59335 L
s
.61772 .59339 m
.61772 .59339 L
s
.61798 .59339 m
.61798 .59322 L
s
.61825 .59339 m
.61825 .59333 L
s
.61852 .59339 m
.61852 .59328 L
s
.61878 .59339 m
.61878 .59343 L
s
.61905 .59339 m
.61905 .59368 L
s
.61931 .59339 m
.61931 .59315 L
s
.61958 .59339 m
.61958 .59364 L
s
.61984 .59339 m
.61984 .5932 L
s
.62011 .59339 m
.62011 .5934 L
s
.62038 .59339 m
.62038 .59321 L
s
.62064 .59339 m
.62064 .59349 L
s
.62091 .59339 m
.62091 .59346 L
s
.62117 .59339 m
.62117 .59339 L
s
.62144 .59339 m
.62144 .59336 L
s
.6217 .59339 m
.6217 .59337 L
s
.62197 .59339 m
.62197 .59344 L
s
.62224 .59339 m
.62224 .59336 L
s
.6225 .59339 m
.6225 .59364 L
s
.62277 .59339 m
.62277 .59328 L
s
.62303 .59339 m
.62303 .59305 L
s
.6233 .59339 m
.6233 .59352 L
s
.62357 .59339 m
.62357 .59342 L
s
.62383 .59339 m
.62383 .59332 L
s
.6241 .59339 m
.6241 .59355 L
s
.62436 .59339 m
.62436 .5934 L
s
.62463 .59339 m
.62463 .59347 L
s
.62489 .59339 m
.62489 .59318 L
s
.62516 .59339 m
.62516 .59363 L
s
.62543 .59339 m
.62543 .59312 L
s
.62569 .59339 m
.62569 .59364 L
s
.62596 .59339 m
.62596 .59336 L
s
.62622 .59339 m
.62622 .59343 L
s
.62649 .59339 m
.62649 .59322 L
s
.62675 .59339 m
.62675 .59364 L
s
.62702 .59339 m
.62702 .59323 L
s
.62729 .59339 m
.62729 .59343 L
s
.62755 .59339 m
.62755 .59327 L
s
.62782 .59339 m
.62782 .59337 L
s
.62808 .59339 m
.62808 .59357 L
s
.62835 .59339 m
.62835 .59316 L
s
.62861 .59339 m
.62861 .59312 L
s
.62888 .59339 m
.62888 .59406 L
s
.62915 .59339 m
.62915 .59272 L
s
.62941 .59339 m
.62941 .59388 L
s
.62968 .59339 m
.62968 .59271 L
s
.62994 .59339 m
.62994 .59332 L
s
.63021 .59339 m
.63021 .59383 L
s
.63047 .59339 m
.63047 .59385 L
s
.63074 .59339 m
.63074 .59292 L
s
.63101 .59339 m
.63101 .59358 L
s
.63127 .59339 m
.63127 .59295 L
s
.63154 .59339 m
.63154 .5938 L
s
.6318 .59339 m
.6318 .59316 L
s
.63207 .59339 m
.63207 .5937 L
s
.63233 .59339 m
.63233 .59304 L
s
.6326 .59339 m
.6326 .59392 L
s
.63287 .59339 m
.63287 .59327 L
s
.63313 .59339 m
.63313 .59323 L
s
.6334 .59339 m
.6334 .59312 L
s
.63366 .59339 m
.63366 .59326 L
s
.63393 .59339 m
.63393 .59427 L
s
.63419 .59339 m
.63419 .59331 L
s
.63446 .59339 m
.63446 .59299 L
s
.63473 .59339 m
.63473 .59303 L
s
.63499 .59339 m
.63499 .59357 L
s
.63526 .59339 m
.63526 .59367 L
s
.63552 .59339 m
.63552 .59318 L
s
.63579 .59339 m
.63579 .59353 L
s
.63605 .59339 m
.63605 .59324 L
s
.63632 .59339 m
.63632 .59369 L
s
.63659 .59339 m
.63659 .59292 L
s
.63685 .59339 m
.63685 .59336 L
s
.63712 .59339 m
.63712 .59337 L
s
.63738 .59339 m
.63738 .59372 L
s
.63765 .59339 m
.63765 .59315 L
s
.63791 .59339 m
.63791 .59364 L
s
.63818 .59339 m
.63818 .59319 L
s
.63845 .59339 m
.63845 .59353 L
s
.63871 .59339 m
.63871 .59322 L
s
.63898 .59339 m
.63898 .59363 L
s
.63924 .59339 m
.63924 .59301 L
s
.63951 .59339 m
.63951 .59374 L
s
.63977 .59339 m
.63977 .59319 L
s
.64004 .59339 m
.64004 .5938 L
s
.64031 .59339 m
.64031 .5928 L
s
.64057 .59339 m
.64057 .59345 L
s
.64084 .59339 m
.64084 .59362 L
s
.6411 .59339 m
.6411 .59349 L
s
.64137 .59339 m
.64137 .59326 L
s
.64163 .59339 m
.64163 .5931 L
s
.6419 .59339 m
.6419 .59373 L
s
.64217 .59339 m
.64217 .59315 L
s
.64243 .59339 m
.64243 .59386 L
s
.6427 .59339 m
.6427 .59332 L
s
.64296 .59339 m
.64296 .59317 L
s
.64323 .59339 m
.64323 .59349 L
s
.64349 .59339 m
.64349 .59338 L
s
.64376 .59339 m
.64376 .59311 L
s
.64403 .59339 m
.64403 .59343 L
s
.64429 .59339 m
.64429 .5936 L
s
.64456 .59339 m
.64456 .59378 L
s
.64482 .59339 m
.64482 .59349 L
s
.64509 .59339 m
.64509 .59244 L
s
.64536 .59339 m
.64536 .59339 L
s
.64562 .59339 m
.64562 .59348 L
s
.64589 .59339 m
.64589 .59428 L
s
.64615 .59339 m
.64615 .59366 L
s
.64642 .59339 m
.64642 .59256 L
s
.64668 .59339 m
.64668 .59305 L
s
.64695 .59339 m
.64695 .59338 L
s
.64722 .59339 m
.64722 .5932 L
s
.64748 .59339 m
.64748 .59384 L
s
.64775 .59339 m
.64775 .59331 L
s
.64801 .59339 m
.64801 .59326 L
s
.64828 .59339 m
.64828 .59382 L
s
.64854 .59339 m
.64854 .59314 L
s
.64881 .59339 m
.64881 .59286 L
s
.64908 .59339 m
.64908 .59385 L
s
.64934 .59339 m
.64934 .5936 L
s
.64961 .59339 m
.64961 .5936 L
s
.64987 .59339 m
.64987 .59298 L
s
.65014 .59339 m
.65014 .59288 L
s
.6504 .59339 m
.6504 .59397 L
s
.65067 .59339 m
.65067 .59326 L
s
.65094 .59339 m
.65094 .59398 L
s
.6512 .59339 m
.6512 .59335 L
s
.65147 .59339 m
.65147 .59282 L
s
.65173 .59339 m
.65173 .59315 L
s
.652 .59339 m
.652 .59322 L
s
.65226 .59339 m
.65226 .59433 L
s
.65253 .59339 m
.65253 .59351 L
s
.6528 .59339 m
.6528 .59299 L
s
.65306 .59339 m
.65306 .59351 L
s
.65333 .59339 m
.65333 .59337 L
s
.65359 .59339 m
.65359 .59286 L
s
.65386 .59339 m
.65386 .59357 L
s
.65412 .59339 m
.65412 .59314 L
s
.65439 .59339 m
.65439 .59377 L
s
.65466 .59339 m
.65466 .59413 L
s
.65492 .59339 m
.65492 .59228 L
s
.65519 .59339 m
.65519 .59311 L
s
.65545 .59339 m
.65545 .59437 L
s
.65572 .59339 m
.65572 .59405 L
s
.65598 .59339 m
.65598 .59315 L
s
.65625 .59339 m
.65625 .59252 L
s
.65652 .59339 m
.65652 .59336 L
s
.65678 .59339 m
.65678 .59444 L
s
.65705 .59339 m
.65705 .59301 L
s
.65731 .59339 m
.65731 .59338 L
s
.65758 .59339 m
.65758 .59339 L
s
.65784 .59339 m
.65784 .59343 L
s
.65811 .59339 m
.65811 .59342 L
s
.65838 .59339 m
.65838 .59332 L
s
.65864 .59339 m
.65864 .5939 L
s
.65891 .59339 m
.65891 .5935 L
s
.65917 .59339 m
.65917 .59253 L
s
.65944 .59339 m
.65944 .59389 L
s
.6597 .59339 m
.6597 .59418 L
s
.65997 .59339 m
.65997 .59256 L
s
.66024 .59339 m
.66024 .59348 L
s
.6605 .59339 m
.6605 .59314 L
s
.66077 .59339 m
.66077 .5937 L
s
.66103 .59339 m
.66103 .5934 L
s
.6613 .59339 m
.6613 .59293 L
s
.66156 .59339 m
.66156 .59357 L
s
.66183 .59339 m
.66183 .59387 L
s
.6621 .59339 m
.6621 .59289 L
s
.66236 .59339 m
.66236 .59369 L
s
.66263 .59339 m
.66263 .59348 L
s
.66289 .59339 m
.66289 .59283 L
s
.66316 .59339 m
.66316 .59395 L
s
.66342 .59339 m
.66342 .59302 L
s
.66369 .59339 m
.66369 .59337 L
s
.66396 .59339 m
.66396 .59364 L
s
.66422 .59339 m
.66422 .59305 L
s
.66449 .59339 m
.66449 .59355 L
s
.66475 .59339 m
.66475 .59353 L
s
.66502 .59339 m
.66502 .59318 L
s
.66528 .59339 m
.66528 .59362 L
s
.66555 .59339 m
.66555 .5934 L
s
.66582 .59339 m
.66582 .59368 L
s
.66608 .59339 m
.66608 .59267 L
s
.66635 .59339 m
.66635 .5933 L
s
.66661 .59339 m
.66661 .59398 L
s
.66688 .59339 m
.66688 .59369 L
s
.66714 .59339 m
.66714 .59272 L
s
.66741 .59339 m
.66741 .59307 L
s
.66768 .59339 m
.66768 .59383 L
s
.66794 .59339 m
.66794 .5934 L
s
.66821 .59339 m
.66821 .59351 L
s
.66847 .59339 m
.66847 .59275 L
s
.66874 .59339 m
.66874 .59406 L
s
.66901 .59339 m
.66901 .59358 L
s
.66927 .59339 m
.66927 .59214 L
s
.66954 .59339 m
.66954 .59451 L
s
.6698 .59339 m
.6698 .59434 L
s
.67007 .59339 m
.67007 .59177 L
s
.67033 .59339 m
.67033 .59366 L
s
.6706 .59339 m
.6706 .59369 L
s
.67087 .59339 m
.67087 .59364 L
s
.67113 .59339 m
.67113 .59276 L
s
.6714 .59339 m
.6714 .59302 L
s
.67166 .59339 m
.67166 .59457 L
s
.67193 .59339 m
.67193 .59344 L
s
.67219 .59339 m
.67219 .59221 L
s
.67246 .59339 m
.67246 .59393 L
s
.67273 .59339 m
.67273 .59414 L
s
.67299 .59339 m
.67299 .59133 L
s
.67326 .59339 m
.67326 .59408 L
s
.67352 .59339 m
.67352 .59533 L
s
.67379 .59339 m
.67379 .59194 L
s
.67405 .59339 m
.67405 .5935 L
s
.67432 .59339 m
.67432 .59385 L
s
.67459 .59339 m
.67459 .5932 L
s
.67485 .59339 m
.67485 .59344 L
s
.67512 .59339 m
.67512 .59289 L
s
.67538 .59339 m
.67538 .59423 L
s
.67565 .59339 m
.67565 .5936 L
s
.67591 .59339 m
.67591 .59224 L
s
.67618 .59339 m
.67618 .59376 L
s
.67645 .59339 m
.67645 .59433 L
s
.67671 .59339 m
.67671 .59192 L
s
.67698 .59339 m
.67698 .59499 L
s
.67724 .59339 m
.67724 .59316 L
s
.67751 .59339 m
.67751 .58909 L
s
.67777 .59339 m
.67777 .59764 L
s
.67804 .59339 m
.67804 .59382 L
s
.67831 .59339 m
.67831 .59083 L
s
.67857 .59339 m
.67857 .5956 L
s
.67884 .59339 m
.67884 .593 L
s
.6791 .59339 m
.6791 .59281 L
s
.67937 .59339 m
.67937 .59304 L
s
.67963 .59339 m
.67963 .59344 L
s
.6799 .59339 m
.6799 .59401 L
s
.68017 .59339 m
.68017 .59294 L
s
.68043 .59339 m
.68043 .59302 L
s
.6807 .59339 m
.6807 .59459 L
s
.68096 .59339 m
.68096 .59294 L
s
.68123 .59339 m
.68123 .59199 L
s
.68149 .59339 m
.68149 .59587 L
s
.68176 .59339 m
.68176 .59047 L
s
.68203 .59339 m
.68203 .59232 L
s
.68229 .59339 m
.68229 .59863 L
s
.68256 .59339 m
.68256 .59065 L
s
.68282 .59339 m
.68282 .59211 L
s
.68309 .59339 m
.68309 .59595 L
s
.68335 .59339 m
.68335 .59205 L
s
.68362 .59339 m
.68362 .59253 L
s
.68389 .59339 m
.68389 .59386 L
s
.68415 .59339 m
.68415 .594 L
s
.68442 .59339 m
.68442 .59349 L
s
.68468 .59339 m
.68468 .59194 L
s
.68495 .59339 m
.68495 .59444 L
s
.68521 .59339 m
.68521 .59415 L
s
.68548 .59339 m
.68548 .59194 L
s
.68575 .59339 m
.68575 .59316 L
s
.68601 .59339 m
.68601 .59492 L
s
.68628 .59339 m
.68628 .59211 L
s
.68654 .59339 m
.68654 .59559 L
s
.68681 .59339 m
.68681 .59213 L
s
.68707 .59339 m
.68707 .59199 L
s
.68734 .59339 m
.68734 .59538 L
s
.68761 .59339 m
.68761 .59269 L
s
.68787 .59339 m
.68787 .59288 L
s
.68814 .59339 m
.68814 .59406 L
s
.6884 .59339 m
.6884 .59317 L
s
.68867 .59339 m
.68867 .59362 L
s
.68893 .59339 m
.68893 .59254 L
s
.6892 .59339 m
.6892 .59477 L
s
.68947 .59339 m
.68947 .59276 L
s
.68973 .59339 m
.68973 .59197 L
s
.69 .59339 m
.69 .59509 L
s
.69026 .59339 m
.69026 .59291 L
s
.69053 .59339 m
.69053 .59311 L
s
.6908 .59339 m
.6908 .59425 L
s
.69106 .59339 m
.69106 .59104 L
s
.69133 .59339 m
.69133 .59672 L
s
.69159 .59339 m
.69159 .59279 L
s
.69186 .59339 m
.69186 .59081 L
s
.69212 .59339 m
.69212 .59633 L
s
.69239 .59339 m
.69239 .59175 L
s
.69266 .59339 m
.69266 .59249 L
s
.69292 .59339 m
.69292 .59535 L
s
.69319 .59339 m
.69319 .59222 L
s
.69345 .59339 m
.69345 .59346 L
s
.69372 .59339 m
.69372 .59388 L
s
.69398 .59339 m
.69398 .5926 L
s
.69425 .59339 m
.69425 .59481 L
s
.69452 .59339 m
.69452 .59261 L
s
.69478 .59339 m
.69478 .59218 L
s
.69505 .59339 m
.69505 .59523 L
s
.69531 .59339 m
.69531 .5924 L
s
.69558 .59339 m
.69558 .59304 L
s
.69584 .59339 m
.69584 .59478 L
s
.69611 .59339 m
.69611 .59164 L
s
.69638 .59339 m
.69638 .59383 L
s
.69664 .59339 m
.69664 .59495 L
s
.69691 .59339 m
.69691 .59194 L
s
.69717 .59339 m
.69717 .59359 L
s
.69744 .59339 m
.69744 .59394 L
s
.6977 .59339 m
.6977 .5925 L
s
.69797 .59339 m
.69797 .59423 L
s
.69824 .59339 m
.69824 .59282 L
s
.6985 .59339 m
.6985 .59388 L
s
.69877 .59339 m
.69877 .59365 L
s
.69903 .59339 m
.69903 .59256 L
s
.6993 .59339 m
.6993 .59333 L
s
.69956 .59339 m
.69956 .59445 L
s
.69983 .59339 m
.69983 .59325 L
s
.7001 .59339 m
.7001 .59239 L
s
.70036 .59339 m
.70036 .59441 L
s
.70063 .59339 m
.70063 .59327 L
s
.70089 .59339 m
.70089 .59217 L
s
.70116 .59339 m
.70116 .59429 L
s
.70142 .59339 m
.70142 .59352 L
s
.70169 .59339 m
.70169 .59327 L
s
.70196 .59339 m
.70196 .5934 L
s
.70222 .59339 m
.70222 .5934 L
s
.70249 .59339 m
.70249 .59353 L
s
.70275 .59339 m
.70275 .59326 L
s
.70302 .59339 m
.70302 .59349 L
s
.70328 .59339 m
.70328 .59341 L
s
.70355 .59339 m
.70355 .5929 L
s
.70382 .59339 m
.70382 .59355 L
s
.70408 .59339 m
.70408 .59412 L
s
.70435 .59339 m
.70435 .59297 L
s
.70461 .59339 m
.70461 .59312 L
s
.70488 .59339 m
.70488 .59361 L
s
.70514 .59339 m
.70514 .59305 L
s
.70541 .59339 m
.70541 .59335 L
s
.70568 .59339 m
.70568 .59388 L
s
.70594 .59339 m
.70594 .59282 L
s
.70621 .59339 m
.70621 .5937 L
s
.70647 .59339 m
.70647 .59437 L
s
.70674 .59339 m
.70674 .59185 L
s
.707 .59339 m
.707 .59325 L
s
.70727 .59339 m
.70727 .59424 L
s
.70754 .59339 m
.70754 .59308 L
s
.7078 .59339 m
.7078 .5934 L
s
.70807 .59339 m
.70807 .59389 L
s
.70833 .59339 m
.70833 .59238 L
s
.7086 .59339 m
.7086 .59418 L
s
.70886 .59339 m
.70886 .59316 L
s
.70913 .59339 m
.70913 .59329 L
s
.7094 .59339 m
.7094 .59367 L
s
.70966 .59339 m
.70966 .59275 L
s
.70993 .59339 m
.70993 .59333 L
s
.71019 .59339 m
.71019 .59438 L
s
.71046 .59339 m
.71046 .59215 L
s
.71072 .59339 m
.71072 .59352 L
s
.71099 .59339 m
.71099 .59434 L
s
.71126 .59339 m
.71126 .59231 L
s
.71152 .59339 m
.71152 .59389 L
s
.71179 .59339 m
.71179 .59326 L
s
.71205 .59339 m
.71205 .5928 L
s
.71232 .59339 m
.71232 .59451 L
s
.71259 .59339 m
.71259 .59304 L
s
.71285 .59339 m
.71285 .59289 L
s
.71312 .59339 m
.71312 .59407 L
s
.71338 .59339 m
.71338 .59308 L
s
.71365 .59339 m
.71365 .59324 L
s
.71391 .59339 m
.71391 .59315 L
s
.71418 .59339 m
.71418 .59323 L
s
.71445 .59339 m
.71445 .59388 L
s
.71471 .59339 m
.71471 .59349 L
s
.71498 .59339 m
.71498 .59341 L
s
.71524 .59339 m
.71524 .59353 L
s
.71551 .59339 m
.71551 .59331 L
s
.71577 .59339 m
.71577 .59275 L
s
.71604 .59339 m
.71604 .59406 L
s
.71631 .59339 m
.71631 .59351 L
s
.71657 .59339 m
.71657 .59265 L
s
.71684 .59339 m
.71684 .59382 L
s
.7171 .59339 m
.7171 .59333 L
s
.71737 .59339 m
.71737 .59368 L
s
.71763 .59339 m
.71763 .593 L
s
.7179 .59339 m
.7179 .59329 L
s
.71817 .59339 m
.71817 .59359 L
s
.71843 .59339 m
.71843 .59371 L
s
.7187 .59339 m
.7187 .59316 L
s
.71896 .59339 m
.71896 .59316 L
s
.71923 .59339 m
.71923 .59354 L
s
.71949 .59339 m
.71949 .59329 L
s
.71976 .59339 m
.71976 .59348 L
s
.72003 .59339 m
.72003 .59363 L
s
.72029 .59339 m
.72029 .59279 L
s
.72056 .59339 m
.72056 .59369 L
s
.72082 .59339 m
.72082 .59363 L
s
.72109 .59339 m
.72109 .59299 L
s
.72135 .59339 m
.72135 .5933 L
s
.72162 .59339 m
.72162 .59375 L
s
.72189 .59339 m
.72189 .59326 L
s
.72215 .59339 m
.72215 .59317 L
s
.72242 .59339 m
.72242 .59424 L
s
.72268 .59339 m
.72268 .59242 L
s
.72295 .59339 m
.72295 .59351 L
s
.72321 .59339 m
.72321 .5937 L
s
.72348 .59339 m
.72348 .59306 L
s
.72375 .59339 m
.72375 .59351 L
s
.72401 .59339 m
.72401 .59342 L
s
.72428 .59339 m
.72428 .59339 L
s
.72454 .59339 m
.72454 .59361 L
s
.72481 .59339 m
.72481 .59316 L
s
.72507 .59339 m
.72507 .59378 L
s
.72534 .59339 m
.72534 .59339 L
s
.72561 .59339 m
.72561 .59285 L
s
.72587 .59339 m
.72587 .59414 L
s
.72614 .59339 m
.72614 .59314 L
s
.7264 .59339 m
.7264 .59307 L
s
.72667 .59339 m
.72667 .594 L
s
.72693 .59339 m
.72693 .59306 L
s
.7272 .59339 m
.7272 .59321 L
s
.72747 .59339 m
.72747 .5938 L
s
.72773 .59339 m
.72773 .59285 L
s
.728 .59339 m
.728 .59384 L
s
.72826 .59339 m
.72826 .59338 L
s
.72853 .59339 m
.72853 .59316 L
s
.72879 .59339 m
.72879 .59391 L
s
.72906 .59339 m
.72906 .59311 L
s
.72933 .59339 m
.72933 .59318 L
s
.72959 .59339 m
.72959 .59384 L
s
.72986 .59339 m
.72986 .59299 L
s
.73012 .59339 m
.73012 .5933 L
s
.73039 .59339 m
.73039 .59409 L
s
.73065 .59339 m
.73065 .59293 L
s
.73092 .59339 m
.73092 .59315 L
s
.73119 .59339 m
.73119 .59347 L
s
.73145 .59339 m
.73145 .59326 L
s
.73172 .59339 m
.73172 .59388 L
s
.73198 .59339 m
.73198 .59336 L
s
.73225 .59339 m
.73225 .59322 L
s
.73251 .59339 m
.73251 .59325 L
s
.73278 .59339 m
.73278 .59338 L
s
.73305 .59339 m
.73305 .59358 L
s
.73331 .59339 m
.73331 .59342 L
s
.73358 .59339 m
.73358 .59304 L
s
.73384 .59339 m
.73384 .59368 L
s
.73411 .59339 m
.73411 .59346 L
s
.73438 .59339 m
.73438 .59312 L
s
.73464 .59339 m
.73464 .59338 L
s
.73491 .59339 m
.73491 .59377 L
s
.73517 .59339 m
.73517 .59318 L
s
.73544 .59339 m
.73544 .5936 L
s
.7357 .59339 m
.7357 .59323 L
s
.73597 .59339 m
.73597 .59312 L
s
.73624 .59339 m
.73624 .5936 L
s
.7365 .59339 m
.7365 .59333 L
s
.73677 .59339 m
.73677 .59365 L
s
.73703 .59339 m
.73703 .59327 L
s
.7373 .59339 m
.7373 .59341 L
s
.73756 .59339 m
.73756 .59324 L
s
.73783 .59339 m
.73783 .59344 L
s
.7381 .59339 m
.7381 .59336 L
s
.73836 .59339 m
.73836 .59356 L
s
.73863 .59339 m
.73863 .59326 L
s
.73889 .59339 m
.73889 .59353 L
s
.73916 .59339 m
.73916 .59327 L
s
.73942 .59339 m
.73942 .59355 L
s
.73969 .59339 m
.73969 .59333 L
s
.73996 .59339 m
.73996 .5932 L
s
.74022 .59339 m
.74022 .59359 L
s
.74049 .59339 m
.74049 .59341 L
s
.74075 .59339 m
.74075 .59303 L
s
.74102 .59339 m
.74102 .59367 L
s
.74128 .59339 m
.74128 .59345 L
s
.74155 .59339 m
.74155 .59324 L
s
.74182 .59339 m
.74182 .59356 L
s
.74208 .59339 m
.74208 .59322 L
s
.74235 .59339 m
.74235 .59347 L
s
.74261 .59339 m
.74261 .59348 L
s
.74288 .59339 m
.74288 .59322 L
s
.74314 .59339 m
.74314 .59318 L
s
.74341 .59339 m
.74341 .59371 L
s
.74368 .59339 m
.74368 .59334 L
s
.74394 .59339 m
.74394 .59341 L
s
.74421 .59339 m
.74421 .59324 L
s
.74447 .59339 m
.74447 .59333 L
s
.74474 .59339 m
.74474 .59355 L
s
.745 .59339 m
.745 .59337 L
s
.74527 .59339 m
.74527 .59343 L
s
.74554 .59339 m
.74554 .59352 L
s
.7458 .59339 m
.7458 .59312 L
s
.74607 .59339 m
.74607 .5935 L
s
.74633 .59339 m
.74633 .59369 L
s
.7466 .59339 m
.7466 .593 L
s
.74686 .59339 m
.74686 .59326 L
s
.74713 .59339 m
.74713 .59356 L
s
.7474 .59339 m
.7474 .5935 L
s
.74766 .59339 m
.74766 .59347 L
s
.74793 .59339 m
.74793 .5932 L
s
.74819 .59339 m
.74819 .59331 L
s
.74846 .59339 m
.74846 .59353 L
s
.74872 .59339 m
.74872 .59344 L
s
.74899 .59339 m
.74899 .59342 L
s
.74926 .59339 m
.74926 .59333 L
s
.74952 .59339 m
.74952 .59325 L
s
.74979 .59339 m
.74979 .59375 L
s
.75005 .59339 m
.75005 .5931 L
s
.75032 .59339 m
.75032 .59333 L
s
.75058 .59339 m
.75058 .59372 L
s
.75085 .59339 m
.75085 .59336 L
s
.75112 .59339 m
.75112 .59301 L
s
.75138 .59339 m
.75138 .59361 L
s
.75165 .59339 m
.75165 .59332 L
s
.75191 .59339 m
.75191 .59333 L
s
.75218 .59339 m
.75218 .59397 L
s
.75244 .59339 m
.75244 .59278 L
s
.75271 .59339 m
.75271 .59342 L
s
.75298 .59339 m
.75298 .59348 L
s
.75324 .59339 m
.75324 .59334 L
s
.75351 .59339 m
.75351 .59356 L
s
.75377 .59339 m
.75377 .59342 L
s
.75404 .59339 m
.75404 .5932 L
s
.7543 .59339 m
.7543 .59348 L
s
.75457 .59339 m
.75457 .59338 L
s
.75484 .59339 m
.75484 .59314 L
s
.7551 .59339 m
.7551 .59352 L
s
.75537 .59339 m
.75537 .59354 L
s
.75563 .59339 m
.75563 .59345 L
s
.7559 .59339 m
.7559 .59335 L
s
.75616 .59339 m
.75616 .59324 L
s
.75643 .59339 m
.75643 .5933 L
s
.7567 .59339 m
.7567 .5934 L
s
.75696 .59339 m
.75696 .59339 L
s
.75723 .59339 m
.75723 .59362 L
s
.75749 .59339 m
.75749 .59312 L
s
.75776 .59339 m
.75776 .5934 L
s
.75803 .59339 m
.75803 .59355 L
s
.75829 .59339 m
.75829 .59339 L
s
.75856 .59339 m
.75856 .59335 L
s
.75882 .59339 m
.75882 .59349 L
s
.75909 .59339 m
.75909 .5932 L
s
.75935 .59339 m
.75935 .59377 L
s
.75962 .59339 m
.75962 .59328 L
s
.75989 .59339 m
.75989 .59328 L
s
.76015 .59339 m
.76015 .5933 L
s
.76042 .59339 m
.76042 .59349 L
s
.76068 .59339 m
.76068 .59348 L
s
.76095 .59339 m
.76095 .59332 L
s
.76121 .59339 m
.76121 .59333 L
s
.76148 .59339 m
.76148 .59344 L
s
.76175 .59339 m
.76175 .59344 L
s
.76201 .59339 m
.76201 .59325 L
s
.76228 .59339 m
.76228 .59356 L
s
.76254 .59339 m
.76254 .59318 L
s
.76281 .59339 m
.76281 .59348 L
s
.76307 .59339 m
.76307 .59341 L
s
.76334 .59339 m
.76334 .59329 L
s
.76361 .59339 m
.76361 .59338 L
s
.76387 .59339 m
.76387 .59359 L
s
.76414 .59339 m
.76414 .59324 L
s
.7644 .59339 m
.7644 .59353 L
s
.76467 .59339 m
.76467 .59345 L
s
.76493 .59339 m
.76493 .59313 L
s
.7652 .59339 m
.7652 .59352 L
s
.76547 .59339 m
.76547 .59357 L
s
.76573 .59339 m
.76573 .59328 L
s
.766 .59339 m
.766 .59338 L
s
.76626 .59339 m
.76626 .59344 L
s
.76653 .59339 m
.76653 .59331 L
s
.76679 .59339 m
.76679 .59341 L
s
.76706 .59339 m
.76706 .59335 L
s
.76733 .59339 m
.76733 .59344 L
s
.76759 .59339 m
.76759 .59339 L
s
.76786 .59339 m
.76786 .59351 L
s
.76812 .59339 m
.76812 .59325 L
s
.76839 .59339 m
.76839 .59334 L
s
.76865 .59339 m
.76865 .59348 L
s
.76892 .59339 m
.76892 .59345 L
s
.76919 .59339 m
.76919 .59331 L
s
.76945 .59339 m
.76945 .59348 L
s
.76972 .59339 m
.76972 .59334 L
s
.76998 .59339 m
.76998 .59311 L
s
.77025 .59339 m
.77025 .5937 L
s
.77051 .59339 m
.77051 .59327 L
s
.77078 .59339 m
.77078 .59332 L
s
.77105 .59339 m
.77105 .59333 L
s
.77131 .59339 m
.77131 .59356 L
s
.77158 .59339 m
.77158 .59343 L
s
.77184 .59339 m
.77184 .59336 L
s
.77211 .59339 m
.77211 .59333 L
s
.77237 .59339 m
.77237 .59322 L
s
.77264 .59339 m
.77264 .59363 L
s
.77291 .59339 m
.77291 .5935 L
s
.77317 .59339 m
.77317 .59336 L
s
.77344 .59339 m
.77344 .59315 L
s
.7737 .59339 m
.7737 .59351 L
s
.77397 .59339 m
.77397 .59352 L
s
.77423 .59339 m
.77423 .59331 L
s
.7745 .59339 m
.7745 .59335 L
s
.77477 .59339 m
.77477 .5934 L
s
.77503 .59339 m
.77503 .59338 L
s
.7753 .59339 m
.7753 .59349 L
s
.77556 .59339 m
.77556 .59326 L
s
.77583 .59339 m
.77583 .59317 L
s
.77609 .59339 m
.77609 .59367 L
s
.77636 .59339 m
.77636 .59356 L
s
.77663 .59339 m
.77663 .59314 L
s
.77689 .59339 m
.77689 .59335 L
s
.77716 .59339 m
.77716 .59352 L
s
.77742 .59339 m
.77742 .59315 L
s
.77769 .59339 m
.77769 .59359 L
s
.77795 .59339 m
.77795 .59352 L
s
.77822 .59339 m
.77822 .59321 L
s
.77849 .59339 m
.77849 .59347 L
s
.77875 .59339 m
.77875 .59334 L
s
.77902 .59339 m
.77902 .59336 L
s
.77928 .59339 m
.77928 .59332 L
s
.77955 .59339 m
.77955 .59352 L
s
.77982 .59339 m
.77982 .59345 L
s
.78008 .59339 m
.78008 .59323 L
s
.78035 .59339 m
.78035 .59343 L
s
.78061 .59339 m
.78061 .5933 L
s
.78088 .59339 m
.78088 .5932 L
s
.78114 .59339 m
.78114 .59378 L
s
.78141 .59339 m
.78141 .59347 L
s
.78168 .59339 m
.78168 .59308 L
s
.78194 .59339 m
.78194 .59339 L
s
.78221 .59339 m
.78221 .59357 L
s
.78247 .59339 m
.78247 .59335 L
s
.78274 .59339 m
.78274 .59348 L
s
.783 .59339 m
.783 .59329 L
s
.78327 .59339 m
.78327 .59319 L
s
.78354 .59339 m
.78354 .59356 L
s
.7838 .59339 m
.7838 .59342 L
s
.78407 .59339 m
.78407 .59338 L
s
.78433 .59339 m
.78433 .59332 L
s
.7846 .59339 m
.7846 .59348 L
s
.78486 .59339 m
.78486 .59339 L
s
.78513 .59339 m
.78513 .59337 L
s
.7854 .59339 m
.7854 .59331 L
s
.78566 .59339 m
.78566 .59341 L
s
.78593 .59339 m
.78593 .59335 L
s
.78619 .59339 m
.78619 .59361 L
s
.78646 .59339 m
.78646 .5934 L
s
.78672 .59339 m
.78672 .59316 L
s
.78699 .59339 m
.78699 .59355 L
s
.78726 .59339 m
.78726 .5933 L
s
.78752 .59339 m
.78752 .59346 L
s
.78779 .59339 m
.78779 .59333 L
s
.78805 .59339 m
.78805 .59335 L
s
.78832 .59339 m
.78832 .59355 L
s
.78858 .59339 m
.78858 .59338 L
s
.78885 .59339 m
.78885 .59339 L
s
.78912 .59339 m
.78912 .59332 L
s
.78938 .59339 m
.78938 .59334 L
s
.78965 .59339 m
.78965 .59362 L
s
.78991 .59339 m
.78991 .59323 L
s
.79018 .59339 m
.79018 .59321 L
s
.79044 .59339 m
.79044 .59351 L
s
.79071 .59339 m
.79071 .59352 L
s
.79098 .59339 m
.79098 .59336 L
s
.79124 .59339 m
.79124 .59335 L
s
.79151 .59339 m
.79151 .59328 L
s
.79177 .59339 m
.79177 .59357 L
s
.79204 .59339 m
.79204 .59353 L
s
.7923 .59339 m
.7923 .59316 L
s
.79257 .59339 m
.79257 .59328 L
s
.79284 .59339 m
.79284 .59339 L
s
.7931 .59339 m
.7931 .59368 L
s
.79337 .59339 m
.79337 .59339 L
s
.79363 .59339 m
.79363 .59318 L
s
.7939 .59339 m
.7939 .59346 L
s
.79416 .59339 m
.79416 .59343 L
s
.79443 .59339 m
.79443 .59327 L
s
.7947 .59339 m
.7947 .59359 L
s
.79496 .59339 m
.79496 .59338 L
s
.79523 .59339 m
.79523 .59315 L
s
.79549 .59339 m
.79549 .59416 L
s
.79576 .59339 m
.79576 .59233 L
s
.79602 .59339 m
.79602 .5936 L
s
.79629 .59339 m
.79629 .59338 L
s
.79656 .59339 m
.79656 .59384 L
s
.79682 .59339 m
.79682 .59325 L
s
.79709 .59339 m
.79709 .59359 L
s
.79735 .59339 m
.79735 .5929 L
s
.79762 .59339 m
.79762 .59377 L
s
.79788 .59339 m
.79788 .59286 L
s
.79815 .59339 m
.79815 .59417 L
s
.79842 .59339 m
.79842 .59308 L
s
.79868 .59339 m
.79868 .59325 L
s
.79895 .59339 m
.79895 .59308 L
s
.79921 .59339 m
.79921 .59366 L
s
.79948 .59339 m
.79948 .59326 L
s
.79974 .59339 m
.79974 .59381 L
s
.80001 .59339 m
.80001 .59302 L
s
.80028 .59339 m
.80028 .5936 L
s
.80054 .59339 m
.80054 .59353 L
s
.80081 .59339 m
.80081 .59321 L
s
.80107 .59339 m
.80107 .59288 L
s
.80134 .59339 m
.80134 .59447 L
s
.80161 .59339 m
.80161 .59186 L
s
.80187 .59339 m
.80187 .59489 L
s
.80214 .59339 m
.80214 .59323 L
s
.8024 .59339 m
.8024 .59296 L
s
.80267 .59339 m
.80267 .59344 L
s
.80293 .59339 m
.80293 .5936 L
s
.8032 .59339 m
.8032 .59322 L
s
.80347 .59339 m
.80347 .59395 L
s
.80373 .59339 m
.80373 .59261 L
s
.804 .59339 m
.804 .59358 L
s
.80426 .59339 m
.80426 .59287 L
s
.80453 .59339 m
.80453 .59334 L
s
.80479 .59339 m
.80479 .594 L
s
.80506 .59339 m
.80506 .59368 L
s
.80533 .59339 m
.80533 .59307 L
s
.80559 .59339 m
.80559 .593 L
s
.80586 .59339 m
.80586 .59394 L
s
.80612 .59339 m
.80612 .59316 L
s
.80639 .59339 m
.80639 .59315 L
s
.80665 .59339 m
.80665 .59317 L
s
.80692 .59339 m
.80692 .59417 L
s
.80719 .59339 m
.80719 .59289 L
s
.80745 .59339 m
.80745 .59324 L
s
.80772 .59339 m
.80772 .59315 L
s
.80798 .59339 m
.80798 .59405 L
s
.80825 .59339 m
.80825 .59332 L
s
.80851 .59339 m
.80851 .59316 L
s
.80878 .59339 m
.80878 .59332 L
s
.80905 .59339 m
.80905 .59363 L
s
.80931 .59339 m
.80931 .59328 L
s
.80958 .59339 m
.80958 .59307 L
s
.80984 .59339 m
.80984 .59342 L
s
.81011 .59339 m
.81011 .59384 L
s
.81037 .59339 m
.81037 .59343 L
s
.81064 .59339 m
.81064 .59294 L
s
.81091 .59339 m
.81091 .59398 L
s
.81117 .59339 m
.81117 .59326 L
s
.81144 .59339 m
.81144 .59307 L
s
.8117 .59339 m
.8117 .59327 L
s
.81197 .59339 m
.81197 .59364 L
s
.81223 .59339 m
.81223 .59373 L
s
.8125 .59339 m
.8125 .59291 L
s
.81277 .59339 m
.81277 .5933 L
s
.81303 .59339 m
.81303 .5936 L
s
.8133 .59339 m
.8133 .59369 L
s
.81356 .59339 m
.81356 .59345 L
s
.81383 .59339 m
.81383 .59349 L
s
.81409 .59339 m
.81409 .59294 L
s
.81436 .59339 m
.81436 .59373 L
s
.81463 .59339 m
.81463 .59278 L
s
.81489 .59339 m
.81489 .59406 L
s
.81516 .59339 m
.81516 .59319 L
s
.81542 .59339 m
.81542 .59334 L
s
.81569 .59339 m
.81569 .59289 L
s
.81595 .59339 m
.81595 .59372 L
s
.81622 .59339 m
.81622 .59387 L
s
.81649 .59339 m
.81649 .59356 L
s
.81675 .59339 m
.81675 .59255 L
s
.81702 .59339 m
.81702 .59384 L
s
.81728 .59339 m
.81728 .5933 L
s
.81755 .59339 m
.81755 .59363 L
s
.81781 .59339 m
.81781 .5929 L
s
.81808 .59339 m
.81808 .59363 L
s
.81835 .59339 m
.81835 .5933 L
s
.81861 .59339 m
.81861 .59399 L
s
.81888 .59339 m
.81888 .59265 L
s
.81914 .59339 m
.81914 .59369 L
s
.81941 .59339 m
.81941 .59326 L
s
.81967 .59339 m
.81967 .59375 L
s
.81994 .59339 m
.81994 .59294 L
s
.82021 .59339 m
.82021 .59316 L
s
.82047 .59339 m
.82047 .59346 L
s
.82074 .59339 m
.82074 .59391 L
s
.821 .59339 m
.821 .59314 L
s
.82127 .59339 m
.82127 .59373 L
s
.82153 .59339 m
.82153 .59293 L
s
.8218 .59339 m
.8218 .59333 L
s
.82207 .59339 m
.82207 .59371 L
s
.82233 .59339 m
.82233 .59318 L
s
.8226 .59339 m
.8226 .5939 L
s
.82286 .59339 m
.82286 .59273 L
s
.82313 .59339 m
.82313 .59361 L
s
.82339 .59339 m
.82339 .5936 L
s
.82366 .59339 m
.82366 .59346 L
s
.82393 .59339 m
.82393 .59339 L
s
.82419 .59339 m
.82419 .59336 L
s
.82446 .59339 m
.82446 .59339 L
s
.82472 .59339 m
.82472 .5935 L
s
.82499 .59339 m
.82499 .59277 L
s
.82526 .59339 m
.82526 .5938 L
s
.82552 .59339 m
.82552 .59311 L
s
.82579 .59339 m
.82579 .59359 L
s
.82605 .59339 m
.82605 .59343 L
s
.82632 .59339 m
.82632 .59325 L
s
.82658 .59339 m
.82658 .59309 L
s
.82685 .59339 m
.82685 .59333 L
s
.82712 .59339 m
.82712 .59381 L
s
.82738 .59339 m
.82738 .59328 L
s
.82765 .59339 m
.82765 .59303 L
s
.82791 .59339 m
.82791 .59356 L
s
.82818 .59339 m
.82818 .59354 L
s
.82844 .59339 m
.82844 .5933 L
s
.82871 .59339 m
.82871 .59312 L
s
.82898 .59339 m
.82898 .59339 L
s
.82924 .59339 m
.82924 .59441 L
s
.82951 .59339 m
.82951 .59229 L
s
.82977 .59339 m
.82977 .59301 L
s
.83004 .59339 m
.83004 .59433 L
s
.8303 .59339 m
.8303 .59233 L
s
.83057 .59339 m
.83057 .59423 L
s
.83084 .59339 m
.83084 .59282 L
s
.8311 .59339 m
.8311 .59381 L
s
.83137 .59339 m
.83137 .59377 L
s
.83163 .59339 m
.83163 .59185 L
s
.8319 .59339 m
.8319 .59482 L
s
.83216 .59339 m
.83216 .59307 L
s
.83243 .59339 m
.83243 .59302 L
s
.8327 .59339 m
.8327 .59372 L
s
.83296 .59339 m
.83296 .59312 L
s
.83323 .59339 m
.83323 .59345 L
s
.83349 .59339 m
.83349 .59284 L
s
.83376 .59339 m
.83376 .59462 L
s
.83402 .59339 m
.83402 .59277 L
s
.83429 .59339 m
.83429 .59266 L
s
.83456 .59339 m
.83456 .59371 L
s
.83482 .59339 m
.83482 .59343 L
s
.83509 .59339 m
.83509 .59375 L
s
.83535 .59339 m
.83535 .59263 L
s
.83562 .59339 m
.83562 .59382 L
s
.83588 .59339 m
.83588 .59418 L
s
.83615 .59339 m
.83615 .59221 L
s
.83642 .59339 m
.83642 .59336 L
s
.83668 .59339 m
.83668 .59379 L
s
.83695 .59339 m
.83695 .59352 L
s
.83721 .59339 m
.83721 .59308 L
s
.83748 .59339 m
.83748 .59298 L
s
.83774 .59339 m
.83774 .59406 L
s
.83801 .59339 m
.83801 .59325 L
s
.83828 .59339 m
.83828 .59271 L
s
.83854 .59339 m
.83854 .59309 L
s
.83881 .59339 m
.83881 .59508 L
s
.83907 .59339 m
.83907 .59169 L
s
.83934 .59339 m
.83934 .59498 L
s
.8396 .59339 m
.8396 .59203 L
s
.83987 .59339 m
.83987 .59257 L
s
.84014 .59339 m
.84014 .59563 L
s
.8404 .59339 m
.8404 .5914 L
s
.84067 .59339 m
.84067 .5942 L
s
.84093 .59339 m
.84093 .59383 L
s
.8412 .59339 m
.8412 .59263 L
s
.84146 .59339 m
.84146 .59433 L
s
.84173 .59339 m
.84173 .59232 L
s
.842 .59339 m
.842 .59411 L
s
.84226 .59339 m
.84226 .59383 L
s
.84253 .59339 m
.84253 .59154 L
s
.84279 .59339 m
.84279 .59464 L
s
.84306 .59339 m
.84306 .5933 L
s
.84332 .59339 m
.84332 .59311 L
s
.84359 .59339 m
.84359 .59321 L
s
.84386 .59339 m
.84386 .59291 L
s
.84412 .59339 m
.84412 .59553 L
s
.84439 .59339 m
.84439 .59177 L
s
.84465 .59339 m
.84465 .59226 L
s
.84492 .59339 m
.84492 .59626 L
s
.84518 .59339 m
.84518 .59212 L
s
.84545 .59339 m
.84545 .59335 L
s
.84572 .59339 m
.84572 .59328 L
s
.84598 .59339 m
.84598 .59278 L
s
.84625 .59339 m
.84625 .59557 L
s
.84651 .59339 m
.84651 .59162 L
s
.84678 .59339 m
.84678 .5931 L
s
.84705 .59339 m
.84705 .59457 L
s
.84731 .59339 m
.84731 .59267 L
s
.84758 .59339 m
.84758 .59364 L
s
.84784 .59339 m
.84784 .59344 L
s
.84811 .59339 m
.84811 .59278 L
s
.84837 .59339 m
.84837 .59449 L
s
.84864 .59339 m
.84864 .59264 L
s
.84891 .59339 m
.84891 .59342 L
s
.84917 .59339 m
.84917 .59363 L
s
.84944 .59339 m
.84944 .59247 L
s
.8497 .59339 m
.8497 .59472 L
s
.84997 .59339 m
.84997 .59266 L
s
.85023 .59339 m
.85023 .59374 L
s
.8505 .59339 m
.8505 .59364 L
s
.85077 .59339 m
.85077 .59178 L
s
.85103 .59339 m
.85103 .59561 L
s
.8513 .59339 m
.8513 .5926 L
s
.85156 .59339 m
.85156 .59255 L
s
.85183 .59339 m
.85183 .59486 L
s
.85209 .59339 m
.85209 .59223 L
s
.85236 .59339 m
.85236 .59384 L
s
.85263 .59339 m
.85263 .59327 L
s
.85289 .59339 m
.85289 .59299 L
s
.85316 .59339 m
.85316 .59371 L
s
.85342 .59339 m
.85342 .59348 L
s
.85369 .59339 m
.85369 .59275 L
s
.85395 .59339 m
.85395 .59432 L
s
.85422 .59339 m
.85422 .59252 L
s
.85449 .59339 m
.85449 .5932 L
s
.85475 .59339 m
.85475 .59442 L
s
.85502 .59339 m
.85502 .59229 L
s
.85528 .59339 m
.85528 .59438 L
s
.85555 .59339 m
.85555 .59242 L
s
.85581 .59339 m
.85581 .59189 L
s
.85608 .59339 m
.85608 .59587 L
s
.85635 .59339 m
.85635 .59248 L
s
.85661 .59339 m
.85661 .59369 L
s
.85688 .59339 m
.85688 .59311 L
s
.85714 .59339 m
.85714 .59292 L
s
.85741 .59339 m
.85741 .5946 L
s
.85767 .59339 m
.85767 .59228 L
s
.85794 .59339 m
.85794 .59327 L
s
.85821 .59339 m
.85821 .59448 L
s
.85847 .59339 m
.85847 .5926 L
s
.85874 .59339 m
.85874 .59322 L
s
.859 .59339 m
.859 .59397 L
s
.85927 .59339 m
.85927 .59304 L
s
.85953 .59339 m
.85953 .59328 L
s
.8598 .59339 m
.8598 .59356 L
s
.86007 .59339 m
.86007 .59334 L
s
.86033 .59339 m
.86033 .59372 L
s
.8606 .59339 m
.8606 .59271 L
s
.86086 .59339 m
.86086 .59325 L
s
.86113 .59339 m
.86113 .59373 L
s
.86139 .59339 m
.86139 .59307 L
s
.86166 .59339 m
.86166 .59539 L
s
.86193 .59339 m
.86193 .59218 L
s
.86219 .59339 m
.86219 .59252 L
s
.86246 .59339 m
.86246 .59523 L
s
.86272 .59339 m
.86272 .59205 L
s
.86299 .59339 m
.86299 .5938 L
s
.86325 .59339 m
.86325 .59371 L
s
.86352 .59339 m
.86352 .59285 L
s
.86379 .59339 m
.86379 .59419 L
s
.86405 .59339 m
.86405 .59221 L
s
.86432 .59339 m
.86432 .59383 L
s
.86458 .59339 m
.86458 .59455 L
s
.86485 .59339 m
.86485 .59197 L
s
.86511 .59339 m
.86511 .59376 L
s
.86538 .59339 m
.86538 .59393 L
s
.86565 .59339 m
.86565 .59301 L
s
.86591 .59339 m
.86591 .59343 L
s
.86618 .59339 m
.86618 .59261 L
s
.86644 .59339 m
.86644 .59438 L
s
.86671 .59339 m
.86671 .59332 L
s
.86697 .59339 m
.86697 .59232 L
s
.86724 .59339 m
.86724 .59407 L
s
.86751 .59339 m
.86751 .59298 L
s
.86777 .59339 m
.86777 .59524 L
s
.86804 .59339 m
.86804 .59259 L
s
.8683 .59339 m
.8683 .5922 L
s
.86857 .59339 m
.86857 .59502 L
s
.86884 .59339 m
.86884 .59197 L
s
.8691 .59339 m
.8691 .59428 L
s
.86937 .59339 m
.86937 .59355 L
s
.86963 .59339 m
.86963 .59267 L
s
.8699 .59339 m
.8699 .59459 L
s
.87016 .59339 m
.87016 .59254 L
s
.87043 .59339 m
.87043 .59359 L
s
.8707 .59339 m
.8707 .59434 L
s
.87096 .59339 m
.87096 .59183 L
s
.87123 .59339 m
.87123 .59369 L
s
.87149 .59339 m
.87149 .59414 L
s
.87176 .59339 m
.87176 .59311 L
s
.87202 .59339 m
.87202 .59404 L
s
.87229 .59339 m
.87229 .59211 L
s
.87256 .59339 m
.87256 .5938 L
s
.87282 .59339 m
.87282 .59466 L
s
.87309 .59339 m
.87309 .59185 L
s
.87335 .59339 m
.87335 .59537 L
s
.87362 .59339 m
.87362 .59239 L
s
.87388 .59339 m
.87388 .59313 L
s
.87415 .59339 m
.87415 .59362 L
s
.87442 .59339 m
.87442 .59219 L
s
.87468 .59339 m
.87468 .59521 L
s
.87495 .59339 m
.87495 .59235 L
s
.87521 .59339 m
.87521 .59273 L
s
.87548 .59339 m
.87548 .59507 L
s
.87574 .59339 m
.87574 .59217 L
s
.87601 .59339 m
.87601 .59339 L
s
.87628 .59339 m
.87628 .59378 L
s
.87654 .59339 m
.87654 .5929 L
s
.87681 .59339 m
.87681 .59427 L
s
.87707 .59339 m
.87707 .5924 L
s
.87734 .59339 m
.87734 .59322 L
s
.8776 .59339 m
.8776 .59456 L
s
.87787 .59339 m
.87787 .59257 L
s
.87814 .59339 m
.87814 .59352 L
s
.8784 .59339 m
.8784 .59338 L
s
.87867 .59339 m
.87867 .5935 L
s
.87893 .59339 m
.87893 .59386 L
s
.8792 .59339 m
.8792 .59332 L
s
.87946 .59339 m
.87946 .59271 L
s
.87973 .59339 m
.87973 .5935 L
s
.88 .59339 m
.88 .59402 L
s
.88026 .59339 m
.88026 .59297 L
s
.88053 .59339 m
.88053 .5937 L
s
.88079 .59339 m
.88079 .5928 L
s
.88106 .59339 m
.88106 .59334 L
s
.88132 .59339 m
.88132 .59502 L
s
.88159 .59339 m
.88159 .59207 L
s
.88186 .59339 m
.88186 .59345 L
s
.88212 .59339 m
.88212 .59384 L
s
.88239 .59339 m
.88239 .59271 L
s
.88265 .59339 m
.88265 .5945 L
s
.88292 .59339 m
.88292 .59239 L
s
.88318 .59339 m
.88318 .59374 L
s
.88345 .59339 m
.88345 .59397 L
s
.88372 .59339 m
.88372 .5924 L
s
.88398 .59339 m
.88398 .5942 L
s
.88425 .59339 m
.88425 .59338 L
s
.88451 .59339 m
.88451 .59284 L
s
.88478 .59339 m
.88478 .59414 L
s
.88504 .59339 m
.88504 .59275 L
s
.88531 .59339 m
.88531 .59401 L
s
.88558 .59339 m
.88558 .59332 L
s
.88584 .59339 m
.88584 .59313 L
s
.88611 .59339 m
.88611 .59351 L
s
.88637 .59339 m
.88637 .59321 L
s
.88664 .59339 m
.88664 .59368 L
s
.8869 .59339 m
.8869 .5929 L
s
.88717 .59339 m
.88717 .59381 L
s
.88744 .59339 m
.88744 .5935 L
s
.8877 .59339 m
.8877 .59291 L
s
.88797 .59339 m
.88797 .59436 L
s
.88823 .59339 m
.88823 .59281 L
s
.8885 .59339 m
.8885 .59366 L
s
.88876 .59339 m
.88876 .59389 L
s
.88903 .59339 m
.88903 .59222 L
s
.8893 .59339 m
.8893 .59438 L
s
.88956 .59339 m
.88956 .59314 L
s
.88983 .59339 m
.88983 .59306 L
s
.89009 .59339 m
.89009 .59416 L
s
.89036 .59339 m
.89036 .59216 L
s
.89063 .59339 m
.89063 .59414 L
s
.89089 .59339 m
.89089 .59368 L
s
.89116 .59339 m
.89116 .59242 L
s
.89142 .59339 m
.89142 .594 L
s
.89169 .59339 m
.89169 .59318 L
s
.89195 .59339 m
.89195 .59337 L
s
.89222 .59339 m
.89222 .59392 L
s
.89249 .59339 m
.89249 .59293 L
s
.89275 .59339 m
.89275 .59344 L
s
.89302 .59339 m
.89302 .59356 L
s
.89328 .59339 m
.89328 .59272 L
s
.89355 .59339 m
.89355 .59437 L
s
.89381 .59339 m
.89381 .59318 L
s
.89408 .59339 m
.89408 .5931 L
s
.89435 .59339 m
.89435 .59342 L
s
.89461 .59339 m
.89461 .59306 L
s
.89488 .59339 m
.89488 .59397 L
s
.89514 .59339 m
.89514 .5928 L
s
.89541 .59339 m
.89541 .59333 L
s
.89567 .59339 m
.89567 .59428 L
s
.89594 .59339 m
.89594 .59228 L
s
.89621 .59339 m
.89621 .59373 L
s
.89647 .59339 m
.89647 .5933 L
s
.89674 .59339 m
.89674 .59344 L
s
.897 .59339 m
.897 .59393 L
s
.89727 .59339 m
.89727 .59249 L
s
.89753 .59339 m
.89753 .59372 L
s
.8978 .59339 m
.8978 .5937 L
s
.89807 .59339 m
.89807 .59286 L
s
.89833 .59339 m
.89833 .59373 L
s
.8986 .59339 m
.8986 .59329 L
s
.89886 .59339 m
.89886 .5933 L
s
.89913 .59339 m
.89913 .59375 L
s
.89939 .59339 m
.89939 .59302 L
s
.89966 .59339 m
.89966 .59372 L
s
.89993 .59339 m
.89993 .59353 L
s
.90019 .59339 m
.90019 .59279 L
s
.90046 .59339 m
.90046 .59401 L
s
.90072 .59339 m
.90072 .59335 L
s
.90099 .59339 m
.90099 .59381 L
s
.90125 .59339 m
.90125 .59263 L
s
.90152 .59339 m
.90152 .59313 L
s
.90179 .59339 m
.90179 .59422 L
s
.90205 .59339 m
.90205 .59325 L
s
.90232 .59339 m
.90232 .59349 L
s
.90258 .59339 m
.90258 .59286 L
s
.90285 .59339 m
.90285 .59342 L
s
.90311 .59339 m
.90311 .59471 L
s
.90338 .59339 m
.90338 .59213 L
s
.90365 .59339 m
.90365 .59365 L
s
.90391 .59339 m
.90391 .59403 L
s
.90418 .59339 m
.90418 .59277 L
s
.90444 .59339 m
.90444 .59397 L
s
.90471 .59339 m
.90471 .59264 L
s
.90497 .59339 m
.90497 .59356 L
s
.90524 .59339 m
.90524 .59411 L
s
.90551 .59339 m
.90551 .59286 L
s
.90577 .59339 m
.90577 .59356 L
s
.90604 .59339 m
.90604 .59336 L
s
.9063 .59339 m
.9063 .59314 L
s
.90657 .59339 m
.90657 .59387 L
s
.90683 .59339 m
.90683 .59318 L
s
.9071 .59339 m
.9071 .59325 L
s
.90737 .59339 m
.90737 .59352 L
s
.90763 .59339 m
.90763 .59331 L
s
.9079 .59339 m
.9079 .59382 L
s
.90816 .59339 m
.90816 .59322 L
s
.90843 .59339 m
.90843 .59291 L
s
.90869 .59339 m
.90869 .59357 L
s
.90896 .59339 m
.90896 .59366 L
s
.90923 .59339 m
.90923 .59332 L
s
.90949 .59339 m
.90949 .59311 L
s
.90976 .59339 m
.90976 .59346 L
s
.91002 .59339 m
.91002 .59363 L
s
.91029 .59339 m
.91029 .59336 L
s
.91055 .59339 m
.91055 .59328 L
s
.91082 .59339 m
.91082 .59307 L
s
.91109 .59339 m
.91109 .59399 L
s
.91135 .59339 m
.91135 .59302 L
s
.91162 .59339 m
.91162 .59317 L
s
.91188 .59339 m
.91188 .59363 L
s
.91215 .59339 m
.91215 .59333 L
s
.91241 .59339 m
.91241 .5938 L
s
.91268 .59339 m
.91268 .59276 L
s
.91295 .59339 m
.91295 .59345 L
s
.91321 .59339 m
.91321 .59356 L
s
.91348 .59339 m
.91348 .59312 L
s
.91374 .59339 m
.91374 .5937 L
s
.91401 .59339 m
.91401 .59347 L
s
.91428 .59339 m
.91428 .59333 L
s
.91454 .59339 m
.91454 .59325 L
s
.91481 .59339 m
.91481 .59336 L
s
.91507 .59339 m
.91507 .59395 L
s
.91534 .59339 m
.91534 .59284 L
s
.9156 .59339 m
.9156 .59307 L
s
.91587 .59339 m
.91587 .59396 L
s
.91614 .59339 m
.91614 .59323 L
s
.9164 .59339 m
.9164 .59356 L
s
.91667 .59339 m
.91667 .5932 L
s
.91693 .59339 m
.91693 .59292 L
s
.9172 .59339 m
.9172 .59406 L
s
.91746 .59339 m
.91746 .59337 L
s
.91773 .59339 m
.91773 .59322 L
s
.918 .59339 m
.918 .5934 L
s
.91826 .59339 m
.91826 .59319 L
s
.91853 .59339 m
.91853 .59367 L
s
.91879 .59339 m
.91879 .59337 L
s
.91906 .59339 m
.91906 .59298 L
s
.91932 .59339 m
.91932 .59365 L
s
.91959 .59339 m
.91959 .59331 L
s
.91986 .59339 m
.91986 .59359 L
s
.92012 .59339 m
.92012 .59359 L
s
.92039 .59339 m
.92039 .59277 L
s
.92065 .59339 m
.92065 .59355 L
s
.92092 .59339 m
.92092 .59355 L
s
.92118 .59339 m
.92118 .5933 L
s
.92145 .59339 m
.92145 .5936 L
s
.92172 .59339 m
.92172 .59309 L
s
.92198 .59339 m
.92198 .59356 L
s
.92225 .59339 m
.92225 .5935 L
s
.92251 .59339 m
.92251 .59326 L
s
.92278 .59339 m
.92278 .59343 L
s
.92304 .59339 m
.92304 .59313 L
s
.92331 .59339 m
.92331 .59343 L
s
.92358 .59339 m
.92358 .59376 L
s
.92384 .59339 m
.92384 .59314 L
s
.92411 .59339 m
.92411 .59337 L
s
.92437 .59339 m
.92437 .59327 L
s
.92464 .59339 m
.92464 .59371 L
s
.9249 .59339 m
.9249 .59341 L
s
.92517 .59339 m
.92517 .59316 L
s
.92544 .59339 m
.92544 .59344 L
s
.9257 .59339 m
.9257 .5934 L
s
.92597 .59339 m
.92597 .59351 L
s
.92623 .59339 m
.92623 .59335 L
s
.9265 .59339 m
.9265 .59307 L
s
.92676 .59339 m
.92676 .59338 L
s
.92703 .59339 m
.92703 .59365 L
s
.9273 .59339 m
.9273 .59352 L
s
.92756 .59339 m
.92756 .59322 L
s
.92783 .59339 m
.92783 .5934 L
s
.92809 .59339 m
.92809 .59337 L
s
.92836 .59339 m
.92836 .59358 L
s
.92862 .59339 m
.92862 .59317 L
s
.92889 .59339 m
.92889 .59332 L
s
.92916 .59339 m
.92916 .59362 L
s
.92942 .59339 m
.92942 .59328 L
s
.92969 .59339 m
.92969 .59354 L
s
.92995 .59339 m
.92995 .593 L
s
.93022 .59339 m
.93022 .59354 L
s
.93048 .59339 m
.93048 .59356 L
s
.93075 .59339 m
.93075 .59338 L
s
.93102 .59339 m
.93102 .5932 L
s
.93128 .59339 m
.93128 .59323 L
s
.93155 .59339 m
.93155 .5937 L
s
.93181 .59339 m
.93181 .59361 L
s
.93208 .59339 m
.93208 .59313 L
s
.93234 .59339 m
.93234 .59334 L
s
.93261 .59339 m
.93261 .59318 L
s
.93288 .59339 m
.93288 .59366 L
s
.93314 .59339 m
.93314 .59374 L
s
.93341 .59339 m
.93341 .59301 L
s
.93367 .59339 m
.93367 .5932 L
s
.93394 .59339 m
.93394 .59371 L
s
.9342 .59339 m
.9342 .59333 L
s
.93447 .59339 m
.93447 .59373 L
s
.93474 .59339 m
.93474 .59292 L
s
.935 .59339 m
.935 .5933 L
s
.93527 .59339 m
.93527 .59408 L
s
.93553 .59339 m
.93553 .59283 L
s
.9358 .59339 m
.9358 .5935 L
s
.93607 .59339 m
.93607 .59354 L
s
.93633 .59339 m
.93633 .59318 L
s
.9366 .59339 m
.9366 .59372 L
s
.93686 .59339 m
.93686 .59321 L
s
.93713 .59339 m
.93713 .59321 L
s
.93739 .59339 m
.93739 .59361 L
s
.93766 .59339 m
.93766 .59329 L
s
.93793 .59339 m
.93793 .59367 L
s
.93819 .59339 m
.93819 .59344 L
s
.93846 .59339 m
.93846 .59287 L
s
.93872 .59339 m
.93872 .59358 L
s
.93899 .59339 m
.93899 .59365 L
s
.93925 .59339 m
.93925 .5933 L
s
.93952 .59339 m
.93952 .59336 L
s
.93979 .59339 m
.93979 .5931 L
s
.94005 .59339 m
.94005 .59362 L
s
.94032 .59339 m
.94032 .59367 L
s
.94058 .59339 m
.94058 .59319 L
s
.94085 .59339 m
.94085 .59321 L
s
.94111 .59339 m
.94111 .59333 L
s
.94138 .59339 m
.94138 .59375 L
s
.94165 .59339 m
.94165 .59348 L
s
.94191 .59339 m
.94191 .59311 L
s
.94218 .59339 m
.94218 .59339 L
s
.94244 .59339 m
.94244 .59343 L
s
.94271 .59339 m
.94271 .59343 L
s
.94297 .59339 m
.94297 .59342 L
s
.94324 .59339 m
.94324 .59321 L
s
.94351 .59339 m
.94351 .59342 L
s
.94377 .59339 m
.94377 .59375 L
s
.94404 .59339 m
.94404 .59336 L
s
.9443 .59339 m
.9443 .5931 L
s
.94457 .59339 m
.94457 .59326 L
s
.94483 .59339 m
.94483 .59346 L
s
.9451 .59339 m
.9451 .5936 L
s
.94537 .59339 m
.94537 .59345 L
s
.94563 .59339 m
.94563 .59312 L
s
.9459 .59339 m
.9459 .5933 L
s
.94616 .59339 m
.94616 .59365 L
s
.94643 .59339 m
.94643 .59366 L
s
.94669 .59339 m
.94669 .59318 L
s
.94696 .59339 m
.94696 .59309 L
s
.94723 .59339 m
.94723 .59356 L
s
.94749 .59339 m
.94749 .59352 L
s
.94776 .59339 m
.94776 .59342 L
s
.94802 .59339 m
.94802 .59327 L
s
.94829 .59339 m
.94829 .59322 L
s
.94855 .59339 m
.94855 .59358 L
s
.94882 .59339 m
.94882 .59369 L
s
.94909 .59339 m
.94909 .5932 L
s
.94935 .59339 m
.94935 .59318 L
s
.94962 .59339 m
.94962 .59354 L
s
.94988 .59339 m
.94988 .59328 L
s
.95015 .59339 m
.95015 .59371 L
s
.95041 .59339 m
.95041 .59319 L
s
.95068 .59339 m
.95068 .59313 L
s
.95095 .59339 m
.95095 .59359 L
s
.95121 .59339 m
.95121 .59359 L
s
.95148 .59339 m
.95148 .59348 L
s
.95174 .59339 m
.95174 .59333 L
s
.95201 .59339 m
.95201 .59312 L
s
.95227 .59339 m
.95227 .59346 L
s
.95254 .59339 m
.95254 .59341 L
s
.95281 .59339 m
.95281 .59324 L
s
.95307 .59339 m
.95307 .59354 L
s
.95334 .59339 m
.95334 .59359 L
s
.9536 .59339 m
.9536 .59336 L
s
.95387 .59339 m
.95387 .5932 L
s
.95413 .59339 m
.95413 .59331 L
s
.9544 .59339 m
.9544 .59357 L
s
.95467 .59339 m
.95467 .5935 L
s
.95493 .59339 m
.95493 .59362 L
s
.9552 .59339 m
.9552 .59308 L
s
.95546 .59339 m
.95546 .59328 L
s
.95573 .59339 m
.95573 .59364 L
s
.95599 .59339 m
.95599 .59347 L
s
.95626 .59339 m
.95626 .5933 L
s
.95653 .59339 m
.95653 .5933 L
s
.95679 .59339 m
.95679 .5936 L
s
.95706 .59339 m
.95706 .59334 L
s
.95732 .59339 m
.95732 .59359 L
s
.95759 .59339 m
.95759 .5931 L
s
.95786 .59339 m
.95786 .59297 L
s
.95812 .59339 m
.95812 .59383 L
s
.95839 .59339 m
.95839 .59374 L
s
.95865 .59339 m
.95865 .59309 L
s
.95892 .59339 m
.95892 .59309 L
s
.95918 .59339 m
.95918 .59361 L
s
.95945 .59339 m
.95945 .59366 L
s
.95972 .59339 m
.95972 .59324 L
s
.95998 .59339 m
.95998 .59317 L
s
.96025 .59339 m
.96025 .59329 L
s
.96051 .59339 m
.96051 .59363 L
s
.96078 .59339 m
.96078 .59355 L
s
.96104 .59339 m
.96104 .59331 L
s
.96131 .59339 m
.96131 .59305 L
s
.96158 .59339 m
.96158 .59354 L
s
.96184 .59339 m
.96184 .59358 L
s
.96211 .59339 m
.96211 .59336 L
s
.96237 .59339 m
.96237 .59327 L
s
.96264 .59339 m
.96264 .59322 L
s
.9629 .59339 m
.9629 .59369 L
s
.96317 .59339 m
.96317 .59364 L
s
.96344 .59339 m
.96344 .59311 L
s
.9637 .59339 m
.9637 .59312 L
s
.96397 .59339 m
.96397 .59328 L
s
.96423 .59339 m
.96423 .59366 L
s
.9645 .59339 m
.9645 .59364 L
s
.96476 .59339 m
.96476 .59323 L
s
.96503 .59339 m
.96503 .59321 L
s
.9653 .59339 m
.9653 .59347 L
s
.96556 .59339 m
.96556 .59368 L
s
.96583 .59339 m
.96583 .59329 L
s
.96609 .59339 m
.96609 .59325 L
s
.96636 .59339 m
.96636 .59333 L
s
.96662 .59339 m
.96662 .59349 L
s
.96689 .59339 m
.96689 .59379 L
s
.96716 .59339 m
.96716 .59311 L
s
.96742 .59339 m
.96742 .5931 L
s
.96769 .59339 m
.96769 .59342 L
s
.96795 .59339 m
.96795 .59382 L
s
.96822 .59339 m
.96822 .59341 L
s
.96848 .59339 m
.96848 .59312 L
s
.96875 .59339 m
.96875 .59341 L
s
.96902 .59339 m
.96902 .59331 L
s
.96928 .59339 m
.96928 .5937 L
s
.96955 .59339 m
.96955 .59329 L
s
.96981 .59339 m
.96981 .59317 L
s
.97008 .59339 m
.97008 .59351 L
s
.97034 .59339 m
.97034 .5936 L
s
.97061 .59339 m
.97061 .59324 L
s
.97088 .59339 m
.97088 .59315 L
s
.97114 .59339 m
.97114 .59339 L
s
.97141 .59339 m
.97141 .59373 L
s
.97167 .59339 m
.97167 .59342 L
s
.97194 .59339 m
.97194 .59337 L
s
.9722 .59339 m
.9722 .5929 L
s
.97247 .59339 m
.97247 .59354 L
s
.97274 .59339 m
.97274 .59337 L
s
.973 .59339 m
.973 .59383 L
s
.97327 .59339 m
.97327 .59306 L
s
.97353 .59339 m
.97353 .59327 L
s
.9738 .59339 m
.9738 .59336 L
s
.97406 .59339 m
.97406 .59345 L
s
.97433 .59339 m
.97433 .59347 L
s
.9746 .59339 m
.9746 .59336 L
s
.97486 .59339 m
.97486 .59337 L
s
.97513 .59339 m
.97513 .59348 L
s
.97539 .59339 m
.97539 .59342 L
s
.97566 .59339 m
.97566 .59345 L
s
.97592 .59339 m
.97592 .59301 L
s
0 1 1 r
.02381 .0161 m
.97619 .0161 L
s
.02381 .07383 m
.97619 .07383 L
s
.02381 .13156 m
.97619 .13156 L
s
.02381 .18929 m
.97619 .18929 L
s
.02381 .24702 m
.97619 .24702 L
s
.02381 .30474 m
.97619 .30474 L
s
.02381 .36247 m
.97619 .36247 L
s
.02381 .4202 m
.97619 .4202 L
s
.02381 .47793 m
.97619 .47793 L
s
.02381 .53566 m
.97619 .53566 L
s
.02381 .59339 m
.97619 .59339 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
This can also be seen from the phase space plot of the \
coefficients.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.45"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[wtdata, LogarithmicScale -> True,
AspectRatio -> 1, Frame -> True, FrameTicks -> None]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000265731 0.0238095 0.0865801 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .08658 scale
7 string
7 1 8 [7 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F3F3F4F4F4F4F3
pop
P
% End of image
% Start of gray image
p
.02381 .11039 translate
.95238 .08658 scale
7 string
7 1 8 [7 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFEFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .19697 translate
.95238 .08658 scale
14 string
14 1 8 [14 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFEFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .28355 translate
.95238 .08658 scale
28 string
28 1 8 [28 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFDFFFFFFFFFFFEFFFFFFFFFEFFFEFEFFFFFFFFFFFF
FFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .37013 translate
.95238 .08658 scale
56 string
56 1 8 [56 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFEFCFFFFFFFEFEFEFFFFFDFDFEFDFFFFFE
FDFEFDFEFEFFFFFFFEFDFFFDFDFDFEFEFCFDFEFFFFFEFFFE
FDFFFFFEFDFEFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .45671 translate
.95238 .08658 scale
112 string
112 1 8 [112 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFEFEFEFFFFFCFEFFFDFFFDFEFBFFFEFDFAFDFDFDFE
FDFFFEFFFFFEFFFFFFFCFFF9FDFEFFFFFFFDFEFDFFFFFEFE
FEFFFFF9F9FFFEFFFFFFFEFFFFF7FCF6FFFBFCFEFDFEFFF9
FAFCFDFFFAFEFEF9F7FAFEFFFFFDFFFFFCFFFDFCFDFFFFFF
FFFEFEFFFBFCFCFCFDFFFEFEFEFFFCFD
pop
P
% End of image
% Start of gray image
p
.02381 .54329 translate
.95238 .08658 scale
224 string
224 1 8 [224 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FCF8FCC6968991ABC6D9E2DDC9C5CEE7EEEBE5C48760452E
415E79898F979CA3AEB8C5E6FBE1C08585F49B8DC4FAE0E6
FFFBFAF5EAF1F6FDF6F3F7F9FEFCFCFBFBFAFEFEFAF9FAD3
B3C3E4F5D9C4BBAEB0C5F7D7A27274B0E26C11043A96F6BB
816A636A6B6969AEC8CAD1CBD0CED1CBD5DFF5ECC6987D81
C9E4B5E1D4C5F5F7EEF1F8DDE4F4FAFCFCFFFCF2FBFFF4F6
FCF3CCB9E67DB2AA6E7D7376B0EAA5B4F5BDD8F2D8F5E5E2
F1F5EFFEF6FAFFF9FBFFFCFDF9F9FCF9F3FCE7B68899F69C
90FA9EB0FBE3FEFDFBF2F8F0E6D9FBFEF9FFFFF8FFFDFAFE
FEFDFDFBFFFAF9FC
pop
P
% End of image
% Start of gray image
p
.02381 .62987 translate
.95238 .08658 scale
448 string
448 1 8 [448 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFBFFFDF8D6B3CDB9D6C8B2B191AB80A573A170935F7F39
650D611A51134B1336142B0A2C090F0006E299918DCEA5B4
BFE7B4EBDDD5DCDBDFC6EBD8DFDCE2E5E0E5D6F3D2FFD2FB
CED2D2B8EFA8FFDFEFF9D4C1E7F2EEEBE4DFCEEBDFFCF5F8
FEFAFBF6FAF1FFF4FEF6FCF9FAFCF8FDFBFEFFFFFBFDF6FC
FEFAFCFDFCFBFBFAFFFFFFFEFFFCFCFFFFFEF3FEF5E697BA
9DF497E8A2D2ABD3CAB6FCB0D3D3BAF8D2D3F1BAF7B1C3F7
9AF1D3BBB6B7C786A998ADCAB3EDCEC6D2CC69D04CB4799F
B19CD5B2DDC7EBCBF9BBDFB6E0C553A6C9A5C1E7C0C3C8E9
9FFDBEEEC3D7CDAEC997D271C96EA976978E88DEA1ECD3EE
3BC3995AB6EAF40CE8FDE0919E8FC0BEE8F3F2DBCBE6FCF6
EADAEEEBF5FDF7F3F5F8F7F0ECFCF7F3EEF6EFECF8F9F9FC
F9E7FCFED4D2EF79454B8FD5520C0D79F4D0A2A3D38AE0D8
BA9BBEBF7CD2D18EE6D48EAF72F4C0F9EBE0DAFCFEF8FCF3
E5FFF0F1EBF8EDF8F4FDFBF8F8F9FDFBF9F8FEFAF6FAF8FD
FEF9F9F1FEECDBF3EFF7FFEDFDFEDCFECAE3CACCAEB1FFB8
E6ABB6EFF7D3C9D9CDCAF8ECD8E5E6D3F6EDE4FFE2F2DED6
F9EBE1E2EFE3F3FAEDF1F1D6FEFAFFFFF9FBF9FDFEFBFFFC
FEFFFFFDFFFDFCFFF9FAFFFDFAFCFCFC
pop
P
% End of image
% Start of gray image
p
.02381 .71645 translate
.95238 .08658 scale
896 string
896 1 8 [896 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFEFEFEFFFFFEFFFFFFFFFBFBFFF9FDFEFCF6F4F4EFEAF2
F7F0ECF9FCF6EEF7FDF8F8FFFCFDFBFEFAFFFEFBF9FDFEFA
F7FBFDF8E5F3F6F1E4F0F6EFE2ECEEE8E0E9E8E6DEEBE9E4
E2E9E8E6E2EFFFFCF7D9C4F0CCD1AAC3C7DEDDDCC3B1E2A6
EE87D975CE9B7F8A89BD5AB471DB48C35EF231D946F631D1
51D33B9F6D90416A77466741AF31D943FA498E7D99B925E5
71AE4459C669B77DFFABD2C7FDFEADF7A268B494CAE7F3CA
E0F2DCEBD5ECE4D9DBCEF8D2F8E9FDF8FCF6E9FBECF4DEF1
FDFFFCF8FEF6FDFCF2FCFCFCF1F4F6F3FAE8F9F1FFF1F9E3
FBF4F0EEE7FEECFDF2FDF6FEF0FDF5F7F5FCF8FCF8FEF5FA
FAF0FFF9FEF5FDFDFFF9FCFDFEFBFAFDFCFFFEFEFDFAFBFB
FBF3FAF7FDF9FBFAFBFFF8FBF9FFFCFDFFFDFDFFFBF0E2F2
F9EFFFF7F5FAF4FCE2CFC3CCFCE2AF9FD9C8E2A7ACE0BAFF
ABB7A5ACF4B7FAB7A4E5B2F6C1ADF9C6C5F7BBFCE4B9C0FA
D3C1F6EBF7E1C9FDDAD6E9ECF6EBDEFEE3F7F8F4FCF2E5E7
FEFBF8F3FAF1EBE0DEE0F1E4E1E4FCF7F7F3F3E7E3DFEFF6
E1E0E8FEF8E1E9FBFEF0F6F7F9F2F0F6FCF5F1F7FEFFFAFE
F5F0FFEFEFEBC2CAC1F2E0A3B4FBACA86EFAA3C475DC9AB7
85DAB2D385E8BCFD9DCBBAD5D9D1C0B8F2CEBD97E2C2DF9B
D5B7C0CFBDE175F4CBC396E8EF89F0CAD9F89DDAFE63AFC2
B3E070B9B14BA1C2EDAC8F611FA6E7E49E253DCDE9F365C5
D1B8EEEEB8D7F4ECF1C6D1F3DEE9E0FEF9EBFAF7FFDFF5F6
FDE4F7F8E8F7EAF8F9E0FFF3EFF7E3FEFCEAFDF8FAFFEAF0
F6F1F6FAF8F6F6F6F1FAFBFAFAF0FDFFF8F8FCFBF4DFE0F5
FAF3E7F1F8F6FBFFFDFCFEFCF4F4F0E5F0EEDDF2EFFDF6F1
D8D2E4EEDEEBF7FFF0F5E1DBD1E4E3FEF3F0D8DBB6BCC5C2
C4D2EFFEEFE1DAD1D2EEF7E9E0EDF5FDF2EAF5FEEFD8D2E2
F6F7E7E6EAFFEEFDE2F2FAF9F6F7F4FDFFF5FDFBFDFCF3F6
FAF7FCFDF9FBFBFAFFFDFAF9F8F7FAFEFEFFF9FAFFFDFCFF
FEFFFBFCFCFCFDFEFFFFFFFCFCFBFCFCFDFEFFFFFEFEFFFF
FCFCFCFCFBF8FDFDF8FDFBEFF7FFF0F6E6F4E5FCFDF4EEEA
EAFCF9F8F3FAF2FCFCF2FCF3E5E3E1DEEEEEB3FDE19494C2
F48097F6F3D8D168B0ACFDF193D6E8BAE1D9C9DADEDACDDC
B9B3C9D4E1C7D2B1F7F0E0B6E8F8BBE3FFF5BBC2E6F0D0EF
D4FCEFFEBBDDDEEFBBC1C5E1F1E1E9DBF4EFF4F0F4E5EEF1
E5F8F4EDFBFBFAEDFAFCFAFFFFF8F8FBF9FAFEEEECFDF6F3
F4F2F6F5F3F3FDFCEEF6FFFAFDFCF8F6F9FBF9F7EFFEFFFA
FEFBF8F8FFEEF8FD
pop
P
% End of image
% Start of gray image
p
.02381 .80303 translate
.95238 .08658 scale
1792 string
1792 1 8 [1792 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFEFEFFFFFFFFFEFEFE
FFFFFEFFFFFEFFFFFDFDFFFEFFFFFFFDFFFEFEFFFEFFFDFF
FFFFFEFFFFFEFFFEFDFFFDFEFFFBFEFEFCFDFFFEFCFEFEFE
FCFFFEFDFFFBFFFDFDFEFEFDFFFCFEFEFEFCFDFDFDFEFBFF
FCFFFAFCFEFBFCFCFEFCFEFEFDFCFBFDFDFFFBFEFBFFFBFF
F9FFFBFCFCFAFAFDFDF9FEF8FBF6FFF9FFF8FEF4FEF1FCF8
FDF8FCF2FDF3F8F5FCF6FCEBFEECFAF3FFF8F0D8DAD3C3F8
C8E0F4BAF2E8DAD6F9F3E7B79FC6F4EFF3F6AAECBDDCCEEF
F9B398C8E4F5CEEBDB9893B6E4D3D5C3BB9F92B4CBCDDEAF
AFB2A7B6C4C2E3AFA8BBA3B5BBC1E8A7BEC28EB2BABBF7AA
DECB76B4D5B8F2AEF1DD6CCBF9BCF8CDE1E8A2DEB3DDEDF5
D0F2F7A586FFDFACEFFEAEEFB8FBF499DFFFB0A9F0FFD5CF
CAFFEFB4EBC3D6F6F9E6DDE7F4F2C8FDE3FFFEFEDFF9F7F1
FFFFDDFDD7F6E1ECECF6EAF1EDE2EEF7FAFBFBDEEAFDEDF7
F0F8FEF6EFE0F1EAFEFAE9FCFAE2F3F9FAF6F5FBFBEEF8FC
FBFBFEEDF4FAF7F8F1EBF9FCFDF6FFFEF9FEFFF0FEFCFAFB
FDF8FAF1FFF2FFFBFDFCF6FDFBFBF5F6F5F3F5FEFDFFFEFE
FFF9FEFEF6FFFDFDFBFAF9FEF5FEF7FFFAFDFCFFFAFCFCFC
FFFBFCFBFBFCFFF9FAFFFFFDFEFAFEFEFCFCFDFDFFFDFDFF
FEFEFCFBFFFCFEFFFEFFFAFCFFFEFDFDFFFDFBFAFEFEFDFF
FFFBFEFDFCFAFFFDFDFEFFFDFFFFFFFFFEFCFFFEFEFEFFFE
FFFDFFFEFFFFFEFEFFFEFDFFFFFEFFFEFFFEFFFFFFFEFFFF
FFFEFEFFFFFEFEFEFEFDFDFEFEFEFFFEFFFCFDFEFDFEFFF9
FEF6FFFFFEFCFEFDFDFFFDFFFEFFFFFFFDFFF4F9F2F6F1FC
FDF3ECE8F8E1F6FEECFED9E8D2E5E2D8F5F9E4D6F0D1D1F0
D5F7EACEE2ECDFE2F7EBFCF5D9EFE7CBF4F9EADFC4EEDEE3
E3F7F2FDF1E2FEE2CDFBEFEBDEC0F5D6DFEDFDF1F8E7E1E2
CED1ECDCF3F5C5F4C2DFECE4FDFDD9FBBCF5E5E3FFD9FFED
CBEBE2FAF7EEE3F5F7EBF7EEF8EEEBF2FEF7FFF6FFE3F8F1
F7FCF3F9F7EFF5FFF7FEFFFEF6FAFEFFF9FDF9FEF4F8FEFC
F5FEFAFEF6FEF9FBF4FDF5FDFFFEF4FEF7FEEDFEF9FFF9FF
F6FFF5FBFBFCFCF4FDF7FDF1FBFAFFF4FEF8FDF1FDFBFDFF
F5FEF1FCEEFBF8FAFBFBFBF7F5FAFCF8F6FDF1F8F6F9F6FD
F7F4FDEEFAF3FCF1F7F3F3F8F1FAF2FFF1FBF5F8F3F8F6FA
F8EBFCE9F9EDFCE9ECABFCA6F9AAF2C1F6C9D0C9EBB5FBB3
D5DCB2ACDB9AFBC4EFD9BF9BE6A8F1DDFCC1BA98FABADBFE
F9A1D890C7D9D9DCD88ED5B2AAE5FEABAA978CFAC7AFBAA9
7DFF9C97CBDEA59FB175B5E991C5DEA879F4906EE8E3F4AA
CA6489D6E1C8B9AF6379C0E2D7D7E26655CAD0F0E0CB8939
ACE8D2EAD3EE9D879CB195E8EE79EFE3CBF2F5E4ACC7FCFD
F9EAFD99F3F8F2FCF7FBE1E2D9F9F4E4FDB2E9E7BFFED1D7
E6FFF0F9F6FBD5ECF9E2E3FCEAD4FAF4EDFFE3EDE4EBDFEC
EEFCFEFEE0FBF6EEF1F3F0F3FCF5F6F8F5FCFDFBEBEBF3F2
FBF6F8F8F1F3EEFFF7F8FCFAFBFAF8FAF9FCF9FFFEFEFFFC
F4F8FBFBFEF5FEFDF8FBF5F5FEF1FDFEFBF1FBF7FDFDFDFF
FDFFFAFCFEFEF1F9EFFFFFF5FEF7FEF6F8FCF7FEFBFCF3FF
FCFAFDF9F5FAF5F8F8F9FFFEFCFDFAFDFDFEF9FDFCFFFFFD
FEFCFFFFFCFEFBFAFAFDF9FFFBFCF8FAFDF8FFFAFBFDFCFF
FCFEFFF7FFFDFBFFFFFDFDFEFDFFF9FFFDFDFFFDFBFDFFFC
FBFFFEFEFDFFFFF8FDFEFCFDF7FFFDF8FEFFF6FEFFFCF7FC
FEFDFBFCFBFDFBF6FCFDFFFCFCFCFDF7FFFCFEFEFFF8F9FF
FEFBFBFDF2EFFDF4FBFCFFF9FEF1F6FBF5FDFBFCFFF6EFFA
F8FCFAFFF4FCFFF7F6FAFEFEF8FAF8FFFBFAFEFBFDF9FEFE
FEFAFEFFFCFDFEFFFBFFFCFCF7FEFFFCFEFFFFFCFFFBFFFF
FAFEFEFEFFFCFFFDFFFFFDFDFDFFFBFBFCFBFCF9FFFCFEFC
FEFDFEFBFFFFFCFFFEFAFFFEFEFFFCFFFDFFFEFFFFFDFFFF
FFFEFFFEFDFFFFFFFEFFFDFFFFFDFFFEFFFFFEFEFFFFFEFF
FDFFFFFEFFFFFFFFFFFEFFFEFCFFFEFEFFFFFEFFFFFFFEFF
FDFFFEFFFFFFFFFFFFFFFFFFFFFEFDFDFFFEFEFFFEFFFEFF
FFFFFFFFFFFFFEFFFFFEFFFEFEFFFEFFFFFEFFFEFEFFFFFF
FFFFFEFFFFFFFFFEFEFFFFF6F5FCFCFCF9FAFDFFFEFCF9FC
DCFBF6FEFAFBFFF7FCF5FEF7F9FEFCFFFEFCFEFAFBFAF6FA
FFFFFDFFFEFBFBFFFFF5FBFAFCFCEFFCFBFEF3FBF8F6FEFF
FAFDF3E6D8F4F3D7F2F8E7E0EADBF4FBEEEEEDE4FDC5FDB2
FDB6F3FFB7C3EFC091F9C3E8BFFCDCFDF5E3F2B9FCB8FBE1
EDB3AED6CC9BEED5FCE0F7D3DBF7EEB0EDD4EEC5F6DAF5DB
F5EDFDBBB7EEEDD6E5ECF4E1F7E7D5B8E7E4CACEEBEBDFEB
F8EBF0FBF4D7E8D0DFEFF1CEEEFEF4FAEAEBFBC9EADAF7EB
F7F0EBDCFBFAE9F1E7F4EFF1DBF3FBE7DFFCFCF9ECDDF1F1
DEE6F6F6D9E2F6F5F5FEF0F3F2FAFEECF6F9FDF7F6FBF0F1
F3F4FDFEF1F4FCF7F4FFFBF6F4FFFDFCFBF3FCFDFDF8FDF8
FEFBFDFDFBFCFDFBF7F7E8FCF0FEF3FFF3FAFDFBF4FAFFFF
FEFDFFFFFAF9FAFCFAFEFFFEFDFDFBFCFDFFFFFFFFFFFFFD
FFFEF4FCFCFBFCFDFFFBFDFFFEFCFAF9FDFEFEFDFFFFFBFF
FDFBFEFDFFFDFEFCFEFEFEF8FCFCFEFD
pop
P
% End of image
% Start of gray image
p
.02381 .88961 translate
.95238 .08658 scale
3584 string
3584 1 8 [3584 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFEFFFFFEFEFFFEFFFFFFFFFFFFFFFEFFFFFFFFFEFFFF
FFFFFFFFFEFEFEFEFFFFFFFFFFFEFEFEFEFFFFFEFFFFFFFF
FFFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFFFFFEFEFF
FFFFFFFFFEFFFFFDFFFEFEFFFFFEFFFFFDFFFFFFFEFFFFFF
FFFEFFFEFFFFFFFEFFFEFFFEFFFFFEFEFEFEFEFEFEFFFFFF
FFFFFFFFFFFEFDFCFFFEFEFFFEFEFFFFFEFEFFFDFDFFFFFE
FEFFFEFFFDFFFFFFFFFFFFFDFDFFFEFDFFFFFEFEFEFEFFFF
FFFFFEFFFFFEFFFEFFFEFEFEFDFFFEFFFFFFFFFEFEFFFFFE
FEFFFFFFFFFDFFFEFDFFFFFFFFFEFFFEFEFFFDFFFFFFFFFF
FEFEFEFEFDFEFFFFFEFFFEFEFDFEFEFFFFFDFFFCFFFDFFFD
FFFDFDFFFFFEFCFEFDFCFEFCFEFCFDFEFFFFFCFFFEFEFCFD
FFFEFDFEFFFEFEFFFDFEFFFFFFFDFCFDFFFEFEFFFEFCFDFF
FFFFFEFEFEFDFEFEFFFEFEFEFDFFFFFFFEFDFEFFFFFAF9FC
FEFBFEFBFEFCFCFEFEFFFEFFFDF7F8FAF2F1F2FAFAF3EDE8
E8FBF8FEFFFDFDFEF0E8F1F3F8FCF8EBE4F0FBEEE7E3DBE4
FAF8F2EAE3DEEAF8FCEBF0F9EEDFCCE3EBD2E5FAFBFAEEEA
F8F9EFEAF5EFE8F6CED0F4F7ECE6E8E2E8EDE2F0F3FFFFF5
CFEBFBEBDFE5EFE5DEF0DFF3ECFBF2FAE0F6F9F8E9F0FFEE
E3F3E5F8E8E7D0EEEAECE2FFF2FCEFF6E8FDF6FCE2D9B8DD
F0DDD3F8F4FAE8FED8F9EFFAECE7C0CEEAEFD1F5F1FFE4F2
D7DBEDEAFCF0F0CAECDDEAE8F3EDFAF1E1BBFFE3E1CBC5F8
FBBED9F2F3DBE8FDF3DCD5EAF5C6C6B3E8F1BAD2F0DBD0DA
FCE2E8DCFCEBF3EBCFF9F9D0D8EBE7E2E1F7D7F4DBFCEDDA
F5E2E5E4DFE5FBEFFFE4F2D3DDFBF9FCF6DCDCDFE4FFE6FC
F0F5F2F2D8D2FAFAEED4F8FFD4F5F5E8DBF2FBEDF1F4F1FF
EDBCB9FFF6CAFCE2F1E5F9F0F2E1E2F7E6D5E2EAEBE4EFF2
FDE7FFEEFEF3FBF6F6F9F2FEF0FEFAF7FCEFF8F8FDF7FBFF
F7F2F8F7EDEFF7F3F1F9F8EFF6FCFFF5F4FFFCFDFEF7FBF9
FFF4FFF8FCFEFAF4FFF5F9FCFBF5F5FBFCFDF6F4FDFAF8F9
FBFEF8F8FBF8F7FFFCFBFCF9FEFFFDFFFDFFFDFFFFFCFCFB
FCF6F2FBFDFFF9F7FBFCFBFFFFF7F9FEFDFAF5F5F9F5F4F8
F9FAFFFDFDFBFBFBF7F6F6FAFEFEFDFCFDFDF4F8FDFBFFFE
FDFDFFF9F8FFFFFBFBFDFFFCFAF9F8FAFCFDFCFCFFFBFCFB
F5F7FAF8F8FBFAFBFFFFFFFCFEFEFEFCFEFEF9FEFFFBF9FA
F8F9FEFCF9FBFFFEFFFEFEFDFEFEFEFFFDFCFFFCFAFCFBFD
FDFBFCFFFEFFFEFFFBFCFFFFFDFFFFFFFEFCFBFFFFFDFFFF
FFFEFFFDFFFEFFFDFFFCFCFFFFFFFFFFFEFFFDFCFCFDFFFF
FFFFFEFDFDFEFDFEFDFFFEFFFFFFFFFEFFFFFFFFFFFFFFFF
FEFEFFFEFEFFFFFDFFFDFEFEFDFFFFFEFDFFFEFFFEFFFDFF
FFFEFDFDFFFEFFFDFDFEFFFFFFFEFDFFFEFEFFFFFFFEFDFD
FFFFFFFEFFFEFFFEFFFDFFFEFFFEFFFEFFFFFEFFFFFFFFFF
FDFEFDFCFEFFFFFEFEFEFFFFFFFEFFFFFFFFFFFEFFFFFEFE
FCFFFFFFFEFEFFFEFFFFFEFFFFFFFFFFFFFFFEFEFFFFFEFF
FEFEFDFEFDFEFFFFFEFEFDFEFFFEFDFFFFFFFEFFFFFEFEFF
FDFFFEFFFFFFFEFFFFFFFEFEFFFFFEFDFFFFFFFEFFFFFFFF
FFFFFEFFFFFFFFFFFDFFFFFFFFFAFCFFFEFEFDFEFFFDFCFA
FBFCFFFFFEFEFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFEFDFF
FEFFFFFFFFFFFFFDFFFFFFFEFEFBFAFFFEFFF8F8FCFFFEFE
FCFEFDFDFDFDFEF3F6FEFBFCF9F6F6FAFCFBFCFAFBF1EEFB
FBFCF2ECF6F9FBFAF5F8F7F6FDFAF5F7F1E6F8F5FBF7E8EF
FEFFFEF7F8FCFFFCFDE6E8FCF6F0F7EDFBFBF4FCFBFCFAFD
FFFBEAE8FCF4EEF6F1FCF6F6FFFEF6FAFFFAFBEFE5F8FFF6
FBEFF4FDFBF8FEFBF5FAFAF9EFE6F6FFF8FCF0F3FCFAFBFB
FBF6FDF8F7EDE4FAFDFCF9F1F1F8FEFFFFFCF6F1EDF4F2E4
F5F7F5F6F1EEF4FDF8FFFFFEF7ECE8FAF8F6F6EAF2FAFAF8
FBF2F9FBF8F8F0E8FEF3FBF8F0F4FCF7FAFDFDFDF8F3F6FE
FEFDF3F9FFFEF9F9FDFBFDF8F6FEFAFCF9F7F6FEFAFAFBFE
FAFBF7FBF8F7FDFFFEFEFBFCFEFEFBFEFAFEFCFBFCFCFDFE
FCFDFEFFFEFEFDFEFFFEFEFEF9FBFFFEFFFFFFFCFCFCFBFE
FFFCFDFEFFFEFFFFFEFBFCFFFDFFFFFEFEFEFCFEFEFEFAFE
FEFFFEFCFCFEFFFFFFFCFEFEFCFFFCFFFFFFFCFDFFFFFFFE
FEFDFAFDFFFFFCFDFFFCFBFEFCFFFCFCFCFDFFFEFCFFFEFE
FDFFFCFEFDFEFDFDFDFDFFFEFEFCFDFFFEFEFDFFFDFCFFFD
FCFCFEFEFFFDFDFEFFFEFDFFFDFEFFFFFDF9FAFFFEFFFFF9
FDFFFEFCFFFEFFFEFFFCFBFAFBFFFFFBFBFFFEFCFEFEFFFD
FDFEFDFCFDFEFFFDFDFFFEFFFFFFFDFEFDFDFEFFFDFFFEFE
FFFBFBFFFCFBFEFDFEFEFFFDFDFCFFFBFFFCFEFFFEFFFFFD
FBFEFDFDFFFCFDFFFFFCFAFDFFFDFBFFFBFBFDFCFDFFFBFD
FCFBFDFFFEFDFEFFFEFEFFFDF8F7FCFBFBFAF9F6E6F4FEF7
F4EEF0FCEBEEF8FDFFFFF3F5F6EEF7E4ECFCFEFEEDE4F5F9
FCF5EDEDF4F1F7D8E0F3F7FEEAE2F2F9FAFBEDEBF2EBF9DB
DFEFF4F7F2EAF8F6F5FCEDE4EAE6FFE5E6EAE6ECFCF2FDF4
F8FEEFE7D8D3FBF0F5EADBE2FDFFF9F3FDF1FBEBD0DEF1EA
F0F0E3ECEAE4FEFDE9E3ECFAF4FBDBC7DFF4F4FCEEF0FBF4
F0E6E2D8C3E7EDEDEFD6D1E8EFF4FCF1DEDAFFCAE1E7BDBE
EEFFFBFDFBFDFCEEDDE8D59AC6F9F8EDEDD9E9F4F7EDD7B2
A4ECFCC5F6BDD3F5DDC5DEEFE9E5E4BBBFD8DAFAD7A7CCF4
EBD3D6F6EFE6DFC8DCB4EBDFAAC1F3FBDDC9E9E2D7D3C1E2
C2F9F7C2CCF9F7C8D6EECFB299CCF7CBD2E9F1E5FBD6E6F4
ECE1E6FAF2BADAF4D7D4F7FBE4F3FAD3C1E2FACCD2EEF9DF
E6FDEBE4F4ECBCC1EFD0A9F1F4D1C3F7F7C8E3FBC2B4FCF0
B6E4F8D7C4E9E6DAE6E8BDBFF4C6B4EBF2DFDBEDFCEEEEF9
F0D9F7F0DBF4ECF2E1EFFCF1EBEAD6F4EED8F9FFE9ECF3E7
DEF7F9E7F4EDE5FEFBF2FCFAFFFDFFFEF8F4FEFEF0F4FAFE
F5FAFFFDFFFBF9FEFDF7F8F9F0F6FCFBFEFBFEFFF1F4FCF1
EDF6FAF0F1F8F3F4FDFDF8FAFBFCFCFAF8F7F7FEFEF9F5FE
FBFDFEFDFDFEFCF4F6F5F3F8FDFCFBFEFFFFFFFCFEFEFFFF
FAFEFCFFFAFDFAFDFEFEFEFDFCFFFFF9FFFCFBF9FDFAF6FC
FEF7F4FAF9F2F5FBFAF8FCFEFFFEFBFEFBF7FAFFFCF8FEFE
FCFCFCFBFEFFF8FDFDFFFCFFFBFDFDFBFCFEFCFCFDFCFDFD
FDF9FDFAFFF9FFF8FEFFFBFCFEFDFBFFFCFEFFFDFFFAFDFF
FEFDFBFBFBFEFDFDFFFEFEFFFFFDFFFDFBFCF9FBFDFEFAFF
FDFFFEFFFFFEFFFEFDFBFBFEFEFCF8FBFEFAF9FBFAFAFAFC
FDFDFFFFFEFFFFFFFDFDFDFEFFFEFFFFFFFFFFFFFFFDFEFC
FEFFFFFEFFFFFEFDFDFDFFFFFEFDFEFFFEFFFEFDFDFAFAFB
F9FFFCFBFBFEFCFCFDFDFCFBFEFEFDFEF8FFFCFCFEFDFEFE
FEFDFBFFFFFDFDFDFEFEFEFDFCFCFEFCFAFFFDFFFEFDFCFD
FBFFFEFFFFFDFFFEFCFFF7FFFFF8FDF8FDFFFEFBFFFEFCFD
FBFBFEFEFCFBFAFEFAFFFAFDFEF7FEFCFEFFFBFEFDFCF9F6
FDF7FAFDF8FFF6FCFFFFFFFFFFFBFFF8FBF8F8FFFDFDFFFB
FEFBFBFDFFFAFAFCFFFDFCFEFEFEFDFFFDF9FFFAFDFAFDFC
FFFEFAFAFEF4F6F7F1FDFDFDFAFCF5FFF5FBF9EDF9EEF3FE
FBFEFFFBF8FEF5FCF7F2F1FED9DAFCE9ECFCFAFCFFFAFBFC
F5FCF3E9E6F6D1E7F4E9F4F8FBFAFFF3F6F9F3FEF2F4ECF4
F3EEF9FBFAFEFDF8F3FAF3F0FBFDF8EBE2FAE9E5F1F8EEF5
FFFBF8F3F9F5EFF7FCF3F0FCF2F3FEFBF8F8FAFBFDF8FFF6
FEF7F6FEF5F8FEFEFFFFFEFEFFFFFBFEF9FCFDFEFDFFFBFA
FDF7F2FEF8FDFFFBF7F9FDFFFDFAFFF7F4FEF7F6FBFEFAF6
FCFBF9FDFEFDFEFBFFFFFEFFFAFAFEF9FCFFFDFCFFFEFDFD
FDFEFFFFFDFAFDFDFCFFFCFEFEF8F7FEFDFDFEFFFFFEFDFC
FFFBF9FDFDFAFDFEFCFBFBFFFDFBFDFEFBFCFFF9FBFDFFFE
FBFFFEFEFFFEFFFCFDFFFDFFFCFEFEFEFDFEFFFDFEFFFEFF
FFFEFEFEFEFEFFFEFEFFFCFDFFFEFEFEFFFFFEFEFDFFFFFE
FFFEFFFFFEFDFFFDFCFEFEFFFFFEFFFEFFFFFFFEFCFDFFFD
FFFCFEFFFFFAFAFFFFFFFEFFFEFFFFFDFEFEFFFFFEFFFFFF
FDFDFFFEFFFFFFFEFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFEFEFEFFFDFEFEFFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFF
FDFDFEFFFFFEFFFFFFFEFDFFFFFDFEFEFFFFFFFFFFFEFEFD
FEFDFFFEFDFEFEFEFFFFFFFFFEFFFEFFFFFEFCFFFDFFFEFF
FFFFFEFEFFFFFFFFFFFFFFFFFFFEFFFDFEFFFFFFFFFEFFFF
FFFFFDFEFEFEFEFFFFFFFEFEFDFFFFFDFFFEFFFFFEFEFFFD
F9F6FEFFFCFEFEFBFCFBF9FDFEFDFDFEFCFCFEFEFEFBF6F2
F2FEFCFFFEFEFBF9FEFBFFFAFDFDFCFBFDFDFEF9FBFEFDFA
FFFDFFFDFFFDFFFCFFFBFAFEFDFEFDFDFBFFFEFDFFFFFBFD
FAFAFEFFFBFDFBFEF8FCFFFDFBFDFFFAF9FDFEFCFCFDFFFB
FDFCFBFFFDFEFBFAFEFEFFFFFFFFFFFAFCFDFEFFFEFDFFFC
FFFCFEFEFFFDFFF6F6FCF7F6F8FAFCFCF2F3FDFCFDFDFFFB
F5FAF9FDFFFCF9FCF9F5FFFCFEFDFCFAFEF9FDF0F0F1F3F8
ECEEF8FCF9F7F6F9FCEFF4FFFDFEFBECF1F6E6F4FFFFFAEC
F0FDF5F9FDFFFAF6F9FFFDF7F4F9FCFDF1ECF8F8F2F5FBFE
FCFDFFFAF7F8FEF6F6F7F7F2EAF7FDFDFBF5F6FEF6F8FEFA
FCFEFEFFFDF9FEFCFDEEF5F8EFF4FCFDFBF8F5FCF5F3FCFB
FCFFF9F7FFF6F9FCEFF8F5F1F3F8FEF9F5F8FEF7F2FDF9FD
FAF4FCF4F2EEF7FDFDF5EFF6FAF1F5FFFCFBF8F7FEF5F8FE
FFFFFBFFF9FFFAFCFDFAFFF1F4FFFBFAF6F7FCFAF7F8FFFB
F9FAFAFFFDFEFEFDFBFCFFFBF7FAFDFBF5F7FDFDF9F5F9FD
F7FAFEFFFBFBFFFEFAF7FEFDFFFDFAFAFFF8F6FCFFFFFBF8
FDFDFBFDFFFFFCFCFDFEFAFAFFFCF9FDF8FEFFFBFFF4F4FD
FAFAFAF9FEF9FBFEFFFDFBFEFEFEFFFCFEFBFEFDFFFDFFFD
FFFFFDFAFCFEFDFFFCFAFFFEFDFDFFFFFEFFFBFBFDFAFEFE
FEFBFAFFFEFFFEFDFFFCFDFFFEFEFAFEFEFFFEFDFEFEFEFF
FDFFFCFDFFFEFDFFFDFFFFFEFFFDFFFDFEFEFFFFFEFEFFFD
FEFEFCFEFEFFFEFEFDFEFDFFFEFDFCFCFEFDFFFDFBFFF9FB
FFFEFEFDFEFEFEFFFDFFFBFEFDFFFFFDFDFDFEFEFFFCFFFD
FFFFFFFFFEFFFCFFFDFEFFFEFFFDFFFDFDFEFDFEFEFFFEFE
FEFDFEFEFEFEFDFEFDFEFEFFFFFDFFFFFEFEFEFFFEFFFEFF
FDFDFFFDFFFFFFFEFFFEFDFCFCFCFDFDFEFDFEFEFFFDFEFF
FDFEFEFFFEFEFDFDFDFDFFFDFDFEFEFFFDFFFEFFFFFCFDFD
FFFCFFFDFFFFFDFFFEFEFEFEFDFFFCFFFFFBFEFFFCFDFEFF
FFFFFFFFFFFFFFFC
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
This gives the wavelet packet transform using the best basis \
obtained from the entropy criterion.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.46"}],

Cell["wpdata = WaveletPacketTransform[mdata, s6];", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.3"],

Cell["The position of the chosen basis is shown here.", "MathCaption",
  CellTags->{"S2.1.3", "3.47"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[wpdata, PlotRange -> All]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000132866 0.0147151 0.0535094 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .06822 m
.97619 .06822 L
s
.02381 .12173 m
.97619 .12173 L
s
.02381 .17524 m
.97619 .17524 L
s
.02381 .22875 m
.97619 .22875 L
s
.02381 .28226 m
.97619 .28226 L
s
.02381 .33577 m
.97619 .33577 L
s
.02381 .38928 m
.97619 .38928 L
s
.02381 .44279 m
.97619 .44279 L
s
.02381 .4963 m
.97619 .4963 L
s
.02381 .54981 m
.97619 .54981 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.02474 .01472 m
.02474 .06822 L
s
.02567 .01472 m
.02567 .12173 L
s
.0266 .01472 m
.0266 .06822 L
s
.02753 .01472 m
.02753 .17524 L
s
.02846 .01472 m
.02846 .06822 L
s
.02939 .01472 m
.02939 .12173 L
s
.03032 .01472 m
.03032 .06822 L
s
.03125 .01472 m
.03125 .22875 L
s
.03218 .01472 m
.03218 .06822 L
s
.03311 .01472 m
.03311 .12173 L
s
.03404 .01472 m
.03404 .06822 L
s
.03497 .01472 m
.03497 .17524 L
s
.0359 .01472 m
.0359 .06822 L
s
.03683 .01472 m
.03683 .12173 L
s
.03776 .01472 m
.03776 .06822 L
s
.03869 .01472 m
.03869 .28226 L
s
.03962 .01472 m
.03962 .06822 L
s
.04055 .01472 m
.04055 .12173 L
s
.04148 .01472 m
.04148 .06822 L
s
.04241 .01472 m
.04241 .17524 L
s
.04334 .01472 m
.04334 .06822 L
s
.04427 .01472 m
.04427 .12173 L
s
.0452 .01472 m
.0452 .06822 L
s
.04613 .01472 m
.04613 .22875 L
s
.04706 .01472 m
.04706 .06822 L
s
.04799 .01472 m
.04799 .12173 L
s
.04892 .01472 m
.04892 .06822 L
s
.04985 .01472 m
.04985 .17524 L
s
.05078 .01472 m
.05078 .06822 L
s
.05171 .01472 m
.05171 .12173 L
s
.05264 .01472 m
.05264 .06822 L
s
.05357 .01472 m
.05357 .33577 L
s
.0545 .01472 m
.0545 .06822 L
s
.05543 .01472 m
.05543 .12173 L
s
.05636 .01472 m
.05636 .06822 L
s
.05729 .01472 m
.05729 .17524 L
s
.05822 .01472 m
.05822 .06822 L
s
.05915 .01472 m
.05915 .12173 L
s
.06008 .01472 m
.06008 .06822 L
s
.06101 .01472 m
.06101 .22875 L
s
.06194 .01472 m
.06194 .06822 L
s
.06287 .01472 m
.06287 .12173 L
s
.0638 .01472 m
.0638 .06822 L
s
.06473 .01472 m
.06473 .17524 L
s
.06566 .01472 m
.06566 .06822 L
s
.06659 .01472 m
.06659 .12173 L
s
.06752 .01472 m
.06752 .06822 L
s
.06845 .01472 m
.06845 .28226 L
s
.06938 .01472 m
.06938 .06822 L
s
.07031 .01472 m
.07031 .12173 L
s
.07124 .01472 m
.07124 .06822 L
s
.07217 .01472 m
.07217 .17524 L
s
.0731 .01472 m
.0731 .06822 L
s
.07403 .01472 m
.07403 .12173 L
s
.07496 .01472 m
.07496 .06822 L
s
.07589 .01472 m
.07589 .22875 L
s
.07682 .01472 m
.07682 .06822 L
s
.07775 .01472 m
.07775 .12173 L
s
.07868 .01472 m
.07868 .06822 L
s
.07961 .01472 m
.07961 .17524 L
s
.08054 .01472 m
.08054 .06822 L
s
.08147 .01472 m
.08147 .12173 L
s
.0824 .01472 m
.0824 .06822 L
s
.08333 .01472 m
.08333 .38928 L
s
.08426 .01472 m
.08426 .06822 L
s
.08519 .01472 m
.08519 .12173 L
s
.08612 .01472 m
.08612 .06822 L
s
.08705 .01472 m
.08705 .17524 L
s
.08798 .01472 m
.08798 .06822 L
s
.08891 .01472 m
.08891 .12173 L
s
.08984 .01472 m
.08984 .06822 L
s
.09077 .01472 m
.09077 .22875 L
s
.0917 .01472 m
.0917 .06822 L
s
.09263 .01472 m
.09263 .12173 L
s
.09356 .01472 m
.09356 .06822 L
s
.09449 .01472 m
.09449 .17524 L
s
.09542 .01472 m
.09542 .06822 L
s
.09635 .01472 m
.09635 .12173 L
s
.09728 .01472 m
.09728 .06822 L
s
.09821 .01472 m
.09821 .28226 L
s
.09914 .01472 m
.09914 .06822 L
s
.10007 .01472 m
.10007 .12173 L
s
.101 .01472 m
.101 .06822 L
s
.10193 .01472 m
.10193 .17524 L
s
.10286 .01472 m
.10286 .06822 L
s
.10379 .01472 m
.10379 .12173 L
s
.10472 .01472 m
.10472 .06822 L
s
.10565 .01472 m
.10565 .22875 L
s
.10658 .01472 m
.10658 .06822 L
s
.10751 .01472 m
.10751 .12173 L
s
.10844 .01472 m
.10844 .06822 L
s
.10937 .01472 m
.10937 .17524 L
s
.11031 .01472 m
.11031 .06822 L
s
.11124 .01472 m
.11124 .12173 L
s
.11217 .01472 m
.11217 .06822 L
s
.1131 .01472 m
.1131 .33577 L
s
.11403 .01472 m
.11403 .06822 L
s
.11496 .01472 m
.11496 .12173 L
s
.11589 .01472 m
.11589 .06822 L
s
.11682 .01472 m
.11682 .17524 L
s
.11775 .01472 m
.11775 .06822 L
s
.11868 .01472 m
.11868 .12173 L
s
.11961 .01472 m
.11961 .06822 L
s
.12054 .01472 m
.12054 .22875 L
s
.12147 .01472 m
.12147 .06822 L
s
.1224 .01472 m
.1224 .12173 L
s
.12333 .01472 m
.12333 .06822 L
s
.12426 .01472 m
.12426 .17524 L
s
.12519 .01472 m
.12519 .06822 L
s
.12612 .01472 m
.12612 .12173 L
s
.12705 .01472 m
.12705 .06822 L
s
.12798 .01472 m
.12798 .28226 L
s
.12891 .01472 m
.12891 .06822 L
s
.12984 .01472 m
.12984 .12173 L
s
.13077 .01472 m
.13077 .06822 L
s
.1317 .01472 m
.1317 .17524 L
s
.13263 .01472 m
.13263 .06822 L
s
.13356 .01472 m
.13356 .12173 L
s
.13449 .01472 m
.13449 .06822 L
s
.13542 .01472 m
.13542 .22875 L
s
.13635 .01472 m
.13635 .06822 L
s
.13728 .01472 m
.13728 .12173 L
s
.13821 .01472 m
.13821 .06822 L
s
.13914 .01472 m
.13914 .17524 L
s
.14007 .01472 m
.14007 .06822 L
s
.141 .01472 m
.141 .12173 L
s
.14193 .01472 m
.14193 .06822 L
s
.14286 .01472 m
.14286 .44279 L
s
.14379 .01472 m
.14379 .06822 L
s
.14472 .01472 m
.14472 .12173 L
s
.14565 .01472 m
.14565 .06822 L
s
.14658 .01472 m
.14658 .17524 L
s
.14751 .01472 m
.14751 .06822 L
s
.14844 .01472 m
.14844 .12173 L
s
.14937 .01472 m
.14937 .06822 L
s
.1503 .01472 m
.1503 .22875 L
s
.15123 .01472 m
.15123 .06822 L
s
.15216 .01472 m
.15216 .12173 L
s
.15309 .01472 m
.15309 .06822 L
s
.15402 .01472 m
.15402 .17524 L
s
.15495 .01472 m
.15495 .06822 L
s
.15588 .01472 m
.15588 .12173 L
s
.15681 .01472 m
.15681 .06822 L
s
.15774 .01472 m
.15774 .28226 L
s
.15867 .01472 m
.15867 .06822 L
s
.1596 .01472 m
.1596 .12173 L
s
.16053 .01472 m
.16053 .06822 L
s
.16146 .01472 m
.16146 .17524 L
s
.16239 .01472 m
.16239 .06822 L
s
.16332 .01472 m
.16332 .12173 L
s
.16425 .01472 m
.16425 .06822 L
s
.16518 .01472 m
.16518 .22875 L
s
.16611 .01472 m
.16611 .06822 L
s
.16704 .01472 m
.16704 .12173 L
s
.16797 .01472 m
.16797 .06822 L
s
.1689 .01472 m
.1689 .17524 L
s
.16983 .01472 m
.16983 .06822 L
s
.17076 .01472 m
.17076 .12173 L
s
.17169 .01472 m
.17169 .06822 L
s
.17262 .01472 m
.17262 .33577 L
s
.17355 .01472 m
.17355 .06822 L
s
.17448 .01472 m
.17448 .12173 L
s
.17541 .01472 m
.17541 .06822 L
s
.17634 .01472 m
.17634 .17524 L
s
.17727 .01472 m
.17727 .06822 L
s
.1782 .01472 m
.1782 .12173 L
s
.17913 .01472 m
.17913 .06822 L
s
.18006 .01472 m
.18006 .22875 L
s
.18099 .01472 m
.18099 .06822 L
s
.18192 .01472 m
.18192 .12173 L
s
.18285 .01472 m
.18285 .06822 L
s
.18378 .01472 m
.18378 .17524 L
s
.18471 .01472 m
.18471 .06822 L
s
.18564 .01472 m
.18564 .12173 L
s
.18657 .01472 m
.18657 .06822 L
s
.1875 .01472 m
.1875 .28226 L
s
.18843 .01472 m
.18843 .06822 L
s
.18936 .01472 m
.18936 .12173 L
s
.19029 .01472 m
.19029 .06822 L
s
.19122 .01472 m
.19122 .17524 L
s
.19215 .01472 m
.19215 .06822 L
s
.19308 .01472 m
.19308 .12173 L
s
.19401 .01472 m
.19401 .06822 L
s
.19494 .01472 m
.19494 .22875 L
s
.19587 .01472 m
.19587 .06822 L
s
.1968 .01472 m
.1968 .12173 L
s
.19773 .01472 m
.19773 .06822 L
s
.19866 .01472 m
.19866 .17524 L
s
.19959 .01472 m
.19959 .06822 L
s
.20052 .01472 m
.20052 .12173 L
s
.20145 .01472 m
.20145 .06822 L
s
.20238 .01472 m
.20238 .38928 L
s
.20331 .01472 m
.20331 .06822 L
s
.20424 .01472 m
.20424 .12173 L
s
.20517 .01472 m
.20517 .06822 L
s
.2061 .01472 m
.2061 .17524 L
s
.20703 .01472 m
.20703 .06822 L
s
.20796 .01472 m
.20796 .12173 L
s
.20889 .01472 m
.20889 .06822 L
s
.20982 .01472 m
.20982 .22875 L
s
.21075 .01472 m
.21075 .06822 L
s
.21168 .01472 m
.21168 .12173 L
s
.21261 .01472 m
.21261 .06822 L
s
.21354 .01472 m
.21354 .17524 L
s
.21447 .01472 m
.21447 .06822 L
s
.2154 .01472 m
.2154 .12173 L
s
.21633 .01472 m
.21633 .06822 L
s
.21726 .01472 m
.21726 .28226 L
s
.21819 .01472 m
.21819 .06822 L
s
.21912 .01472 m
.21912 .12173 L
s
.22005 .01472 m
.22005 .06822 L
s
.22098 .01472 m
.22098 .17524 L
s
.22191 .01472 m
.22191 .06822 L
s
.22284 .01472 m
.22284 .12173 L
s
.22377 .01472 m
.22377 .06822 L
s
.2247 .01472 m
.2247 .22875 L
s
.22563 .01472 m
.22563 .06822 L
s
.22656 .01472 m
.22656 .12173 L
s
.22749 .01472 m
.22749 .06822 L
s
.22842 .01472 m
.22842 .17524 L
s
.22935 .01472 m
.22935 .06822 L
s
.23028 .01472 m
.23028 .12173 L
s
.23121 .01472 m
.23121 .06822 L
s
.23214 .01472 m
.23214 .33577 L
s
.23307 .01472 m
.23307 .06822 L
s
.234 .01472 m
.234 .12173 L
s
.23493 .01472 m
.23493 .06822 L
s
.23586 .01472 m
.23586 .17524 L
s
.23679 .01472 m
.23679 .06822 L
s
.23772 .01472 m
.23772 .12173 L
s
.23865 .01472 m
.23865 .06822 L
s
.23958 .01472 m
.23958 .22875 L
s
.24051 .01472 m
.24051 .06822 L
s
.24144 .01472 m
.24144 .12173 L
s
.24237 .01472 m
.24237 .06822 L
s
.2433 .01472 m
.2433 .17524 L
s
.24423 .01472 m
.24423 .06822 L
s
.24516 .01472 m
.24516 .12173 L
s
.24609 .01472 m
.24609 .06822 L
s
.24702 .01472 m
.24702 .28226 L
s
.24795 .01472 m
.24795 .06822 L
s
.24888 .01472 m
.24888 .12173 L
s
.24981 .01472 m
.24981 .06822 L
s
.25074 .01472 m
.25074 .17524 L
s
.25167 .01472 m
.25167 .06822 L
s
.2526 .01472 m
.2526 .12173 L
s
.25353 .01472 m
.25353 .06822 L
s
.25446 .01472 m
.25446 .22875 L
s
.25539 .01472 m
.25539 .06822 L
s
.25632 .01472 m
.25632 .12173 L
s
.25725 .01472 m
.25725 .06822 L
s
.25818 .01472 m
.25818 .17524 L
s
.25911 .01472 m
.25911 .06822 L
s
.26004 .01472 m
.26004 .12173 L
s
.26097 .01472 m
.26097 .06822 L
s
.2619 .01472 m
.2619 .4963 L
s
.26283 .01472 m
.26283 .06822 L
s
.26376 .01472 m
.26376 .12173 L
s
.26469 .01472 m
.26469 .06822 L
s
.26562 .01472 m
.26562 .17524 L
s
.26656 .01472 m
.26656 .06822 L
s
.26749 .01472 m
.26749 .12173 L
s
.26842 .01472 m
.26842 .06822 L
s
.26935 .01472 m
.26935 .22875 L
s
.27028 .01472 m
.27028 .06822 L
s
.27121 .01472 m
.27121 .12173 L
s
.27214 .01472 m
.27214 .06822 L
s
.27307 .01472 m
.27307 .17524 L
s
.274 .01472 m
.274 .06822 L
s
.27493 .01472 m
.27493 .12173 L
s
.27586 .01472 m
.27586 .06822 L
s
.27679 .01472 m
.27679 .28226 L
s
.27772 .01472 m
.27772 .06822 L
s
.27865 .01472 m
.27865 .12173 L
s
.27958 .01472 m
.27958 .06822 L
s
.28051 .01472 m
.28051 .17524 L
s
.28144 .01472 m
.28144 .06822 L
s
.28237 .01472 m
.28237 .12173 L
s
.2833 .01472 m
.2833 .06822 L
s
.28423 .01472 m
.28423 .22875 L
s
.28516 .01472 m
.28516 .06822 L
s
.28609 .01472 m
.28609 .12173 L
s
.28702 .01472 m
.28702 .06822 L
s
.28795 .01472 m
.28795 .17524 L
s
.28888 .01472 m
.28888 .06822 L
s
.28981 .01472 m
.28981 .12173 L
s
.29074 .01472 m
.29074 .06822 L
s
.29167 .01472 m
.29167 .33577 L
s
.2926 .01472 m
.2926 .06822 L
s
.29353 .01472 m
.29353 .12173 L
s
.29446 .01472 m
.29446 .06822 L
s
.29539 .01472 m
.29539 .17524 L
s
.29632 .01472 m
.29632 .06822 L
s
.29725 .01472 m
.29725 .12173 L
s
.29818 .01472 m
.29818 .06822 L
s
.29911 .01472 m
.29911 .22875 L
s
.30004 .01472 m
.30004 .06822 L
s
.30097 .01472 m
.30097 .12173 L
s
.3019 .01472 m
.3019 .06822 L
s
.30283 .01472 m
.30283 .17524 L
s
.30376 .01472 m
.30376 .06822 L
s
.30469 .01472 m
.30469 .12173 L
s
.30562 .01472 m
.30562 .06822 L
s
.30655 .01472 m
.30655 .28226 L
s
.30748 .01472 m
.30748 .06822 L
s
.30841 .01472 m
.30841 .12173 L
s
.30934 .01472 m
.30934 .06822 L
s
.31027 .01472 m
.31027 .17524 L
s
.3112 .01472 m
.3112 .06822 L
s
.31213 .01472 m
.31213 .12173 L
s
.31306 .01472 m
.31306 .06822 L
s
.31399 .01472 m
.31399 .22875 L
s
.31492 .01472 m
.31492 .06822 L
s
.31585 .01472 m
.31585 .12173 L
s
.31678 .01472 m
.31678 .06822 L
s
.31771 .01472 m
.31771 .17524 L
s
.31864 .01472 m
.31864 .06822 L
s
.31957 .01472 m
.31957 .12173 L
s
.3205 .01472 m
.3205 .06822 L
s
.32143 .01472 m
.32143 .38928 L
s
.32236 .01472 m
.32236 .06822 L
s
.32329 .01472 m
.32329 .12173 L
s
.32422 .01472 m
.32422 .06822 L
s
.32515 .01472 m
.32515 .17524 L
s
.32608 .01472 m
.32608 .06822 L
s
.32701 .01472 m
.32701 .12173 L
s
.32794 .01472 m
.32794 .06822 L
s
.32887 .01472 m
.32887 .22875 L
s
.3298 .01472 m
.3298 .06822 L
s
.33073 .01472 m
.33073 .12173 L
s
.33166 .01472 m
.33166 .06822 L
s
.33259 .01472 m
.33259 .17524 L
s
.33352 .01472 m
.33352 .06822 L
s
.33445 .01472 m
.33445 .12173 L
s
.33538 .01472 m
.33538 .06822 L
s
.33631 .01472 m
.33631 .28226 L
s
.33724 .01472 m
.33724 .06822 L
s
.33817 .01472 m
.33817 .12173 L
s
.3391 .01472 m
.3391 .06822 L
s
.34003 .01472 m
.34003 .17524 L
s
.34096 .01472 m
.34096 .06822 L
s
.34189 .01472 m
.34189 .12173 L
s
.34282 .01472 m
.34282 .06822 L
s
.34375 .01472 m
.34375 .22875 L
s
.34468 .01472 m
.34468 .06822 L
s
.34561 .01472 m
.34561 .12173 L
s
.34654 .01472 m
.34654 .06822 L
s
.34747 .01472 m
.34747 .17524 L
s
.3484 .01472 m
.3484 .06822 L
s
.34933 .01472 m
.34933 .12173 L
s
.35026 .01472 m
.35026 .06822 L
s
.35119 .01472 m
.35119 .33577 L
s
.35212 .01472 m
.35212 .06822 L
s
.35305 .01472 m
.35305 .12173 L
s
.35398 .01472 m
.35398 .06822 L
s
.35491 .01472 m
.35491 .17524 L
s
.35584 .01472 m
.35584 .06822 L
s
.35677 .01472 m
.35677 .12173 L
s
.3577 .01472 m
.3577 .06822 L
s
.35863 .01472 m
.35863 .22875 L
s
.35956 .01472 m
.35956 .06822 L
s
.36049 .01472 m
.36049 .12173 L
s
.36142 .01472 m
.36142 .06822 L
s
.36235 .01472 m
.36235 .17524 L
s
.36328 .01472 m
.36328 .06822 L
s
.36421 .01472 m
.36421 .12173 L
s
.36514 .01472 m
.36514 .06822 L
s
.36607 .01472 m
.36607 .28226 L
s
.367 .01472 m
.367 .06822 L
s
.36793 .01472 m
.36793 .12173 L
s
.36886 .01472 m
.36886 .06822 L
s
.36979 .01472 m
.36979 .17524 L
s
.37072 .01472 m
.37072 .06822 L
s
.37165 .01472 m
.37165 .12173 L
s
.37258 .01472 m
.37258 .06822 L
s
.37351 .01472 m
.37351 .22875 L
s
.37444 .01472 m
.37444 .06822 L
s
.37537 .01472 m
.37537 .12173 L
s
.3763 .01472 m
.3763 .06822 L
s
.37723 .01472 m
.37723 .17524 L
s
.37816 .01472 m
.37816 .06822 L
s
.37909 .01472 m
.37909 .12173 L
s
.38002 .01472 m
.38002 .06822 L
s
.38095 .01472 m
.38095 .44279 L
s
.38188 .01472 m
.38188 .06822 L
s
.38281 .01472 m
.38281 .12173 L
s
.38374 .01472 m
.38374 .06822 L
s
.38467 .01472 m
.38467 .17524 L
s
.3856 .01472 m
.3856 .06822 L
s
.38653 .01472 m
.38653 .12173 L
s
.38746 .01472 m
.38746 .06822 L
s
.38839 .01472 m
.38839 .22875 L
s
.38932 .01472 m
.38932 .06822 L
s
.39025 .01472 m
.39025 .12173 L
s
.39118 .01472 m
.39118 .06822 L
s
.39211 .01472 m
.39211 .17524 L
s
.39304 .01472 m
.39304 .06822 L
s
.39397 .01472 m
.39397 .12173 L
s
.3949 .01472 m
.3949 .06822 L
s
.39583 .01472 m
.39583 .28226 L
s
.39676 .01472 m
.39676 .06822 L
s
.39769 .01472 m
.39769 .12173 L
s
.39862 .01472 m
.39862 .06822 L
s
.39955 .01472 m
.39955 .17524 L
s
.40048 .01472 m
.40048 .06822 L
s
.40141 .01472 m
.40141 .12173 L
s
.40234 .01472 m
.40234 .06822 L
s
.40327 .01472 m
.40327 .22875 L
s
.4042 .01472 m
.4042 .06822 L
s
.40513 .01472 m
.40513 .12173 L
s
.40606 .01472 m
.40606 .06822 L
s
.40699 .01472 m
.40699 .17524 L
s
.40792 .01472 m
.40792 .06822 L
s
.40885 .01472 m
.40885 .12173 L
s
.40978 .01472 m
.40978 .06822 L
s
.41071 .01472 m
.41071 .33577 L
s
.41164 .01472 m
.41164 .06822 L
s
.41257 .01472 m
.41257 .12173 L
s
.4135 .01472 m
.4135 .06822 L
s
.41443 .01472 m
.41443 .17524 L
s
.41536 .01472 m
.41536 .06822 L
s
.41629 .01472 m
.41629 .12173 L
s
.41722 .01472 m
.41722 .06822 L
s
.41815 .01472 m
.41815 .22875 L
s
.41908 .01472 m
.41908 .06822 L
s
.42001 .01472 m
.42001 .12173 L
s
.42094 .01472 m
.42094 .06822 L
s
.42188 .01472 m
.42188 .17524 L
s
.42281 .01472 m
.42281 .06822 L
s
.42374 .01472 m
.42374 .12173 L
s
.42467 .01472 m
.42467 .06822 L
s
.4256 .01472 m
.4256 .28226 L
s
.42653 .01472 m
.42653 .06822 L
s
.42746 .01472 m
.42746 .12173 L
s
.42839 .01472 m
.42839 .06822 L
s
.42932 .01472 m
.42932 .17524 L
s
.43025 .01472 m
.43025 .06822 L
s
.43118 .01472 m
.43118 .12173 L
s
.43211 .01472 m
.43211 .06822 L
s
.43304 .01472 m
.43304 .22875 L
s
.43397 .01472 m
.43397 .06822 L
s
.4349 .01472 m
.4349 .12173 L
s
.43583 .01472 m
.43583 .06822 L
s
.43676 .01472 m
.43676 .17524 L
s
.43769 .01472 m
.43769 .06822 L
s
.43862 .01472 m
.43862 .12173 L
s
.43955 .01472 m
.43955 .06822 L
s
.44048 .01472 m
.44048 .38928 L
s
.44141 .01472 m
.44141 .06822 L
s
.44234 .01472 m
.44234 .12173 L
s
.44327 .01472 m
.44327 .06822 L
s
.4442 .01472 m
.4442 .17524 L
s
.44513 .01472 m
.44513 .06822 L
s
.44606 .01472 m
.44606 .12173 L
s
.44699 .01472 m
.44699 .06822 L
s
.44792 .01472 m
.44792 .22875 L
s
.44885 .01472 m
.44885 .06822 L
s
.44978 .01472 m
.44978 .12173 L
s
.45071 .01472 m
.45071 .06822 L
s
.45164 .01472 m
.45164 .17524 L
s
.45257 .01472 m
.45257 .06822 L
s
.4535 .01472 m
.4535 .12173 L
s
.45443 .01472 m
.45443 .06822 L
s
.45536 .01472 m
.45536 .28226 L
s
.45629 .01472 m
.45629 .06822 L
s
.45722 .01472 m
.45722 .12173 L
s
.45815 .01472 m
.45815 .06822 L
s
.45908 .01472 m
.45908 .17524 L
s
.46001 .01472 m
.46001 .06822 L
s
.46094 .01472 m
.46094 .12173 L
s
.46187 .01472 m
.46187 .06822 L
s
.4628 .01472 m
.4628 .22875 L
s
.46373 .01472 m
.46373 .06822 L
s
.46466 .01472 m
.46466 .12173 L
s
.46559 .01472 m
.46559 .06822 L
s
.46652 .01472 m
.46652 .17524 L
s
.46745 .01472 m
.46745 .06822 L
s
.46838 .01472 m
.46838 .12173 L
s
.46931 .01472 m
.46931 .06822 L
s
.47024 .01472 m
.47024 .33577 L
s
.47117 .01472 m
.47117 .06822 L
s
.4721 .01472 m
.4721 .12173 L
s
.47303 .01472 m
.47303 .06822 L
s
.47396 .01472 m
.47396 .17524 L
s
.47489 .01472 m
.47489 .06822 L
s
.47582 .01472 m
.47582 .12173 L
s
.47675 .01472 m
.47675 .06822 L
s
.47768 .01472 m
.47768 .22875 L
s
.47861 .01472 m
.47861 .06822 L
s
.47954 .01472 m
.47954 .12173 L
s
.48047 .01472 m
.48047 .06822 L
s
.4814 .01472 m
.4814 .17524 L
s
.48233 .01472 m
.48233 .06822 L
s
.48326 .01472 m
.48326 .12173 L
s
.48419 .01472 m
.48419 .06822 L
s
.48512 .01472 m
.48512 .28226 L
s
.48605 .01472 m
.48605 .06822 L
s
.48698 .01472 m
.48698 .12173 L
s
.48791 .01472 m
.48791 .06822 L
s
.48884 .01472 m
.48884 .17524 L
s
.48977 .01472 m
.48977 .06822 L
s
.4907 .01472 m
.4907 .12173 L
s
.49163 .01472 m
.49163 .06822 L
s
.49256 .01472 m
.49256 .22875 L
s
.49349 .01472 m
.49349 .06822 L
s
.49442 .01472 m
.49442 .12173 L
s
.49535 .01472 m
.49535 .06822 L
s
.49628 .01472 m
.49628 .17524 L
s
.49721 .01472 m
.49721 .06822 L
s
.49814 .01472 m
.49814 .12173 L
s
.49907 .01472 m
.49907 .06822 L
s
.5 .01472 m
.5 .54981 L
s
.50093 .01472 m
.50093 .06822 L
s
.50186 .01472 m
.50186 .12173 L
s
.50279 .01472 m
.50279 .06822 L
s
.50372 .01472 m
.50372 .17524 L
s
.50465 .01472 m
.50465 .06822 L
s
.50558 .01472 m
.50558 .12173 L
s
.50651 .01472 m
.50651 .06822 L
s
.50744 .01472 m
.50744 .22875 L
s
.50837 .01472 m
.50837 .06822 L
s
.5093 .01472 m
.5093 .12173 L
s
.51023 .01472 m
.51023 .06822 L
s
.51116 .01472 m
.51116 .17524 L
s
.51209 .01472 m
.51209 .06822 L
s
.51302 .01472 m
.51302 .12173 L
s
.51395 .01472 m
.51395 .06822 L
s
.51488 .01472 m
.51488 .28226 L
s
.51581 .01472 m
.51581 .06822 L
s
.51674 .01472 m
.51674 .12173 L
s
.51767 .01472 m
.51767 .06822 L
s
.5186 .01472 m
.5186 .17524 L
s
.51953 .01472 m
.51953 .06822 L
s
.52046 .01472 m
.52046 .12173 L
s
.52139 .01472 m
.52139 .06822 L
s
.52232 .01472 m
.52232 .22875 L
s
.52325 .01472 m
.52325 .06822 L
s
.52418 .01472 m
.52418 .12173 L
s
.52511 .01472 m
.52511 .06822 L
s
.52604 .01472 m
.52604 .17524 L
s
.52697 .01472 m
.52697 .06822 L
s
.5279 .01472 m
.5279 .12173 L
s
.52883 .01472 m
.52883 .06822 L
s
.52976 .01472 m
.52976 .33577 L
s
.53069 .01472 m
.53069 .06822 L
s
.53162 .01472 m
.53162 .12173 L
s
.53255 .01472 m
.53255 .06822 L
s
.53348 .01472 m
.53348 .17524 L
s
.53441 .01472 m
.53441 .06822 L
s
.53534 .01472 m
.53534 .12173 L
s
.53627 .01472 m
.53627 .06822 L
s
.5372 .01472 m
.5372 .22875 L
s
.53813 .01472 m
.53813 .06822 L
s
.53906 .01472 m
.53906 .12173 L
s
.53999 .01472 m
.53999 .06822 L
s
.54092 .01472 m
.54092 .17524 L
s
.54185 .01472 m
.54185 .06822 L
s
.54278 .01472 m
.54278 .12173 L
s
.54371 .01472 m
.54371 .06822 L
s
.54464 .01472 m
.54464 .28226 L
s
.54557 .01472 m
.54557 .06822 L
s
.5465 .01472 m
.5465 .12173 L
s
.54743 .01472 m
.54743 .06822 L
s
.54836 .01472 m
.54836 .17524 L
s
.54929 .01472 m
.54929 .06822 L
s
.55022 .01472 m
.55022 .12173 L
s
.55115 .01472 m
.55115 .06822 L
s
.55208 .01472 m
.55208 .22875 L
s
.55301 .01472 m
.55301 .06822 L
s
.55394 .01472 m
.55394 .12173 L
s
.55487 .01472 m
.55487 .06822 L
s
.5558 .01472 m
.5558 .17524 L
s
.55673 .01472 m
.55673 .06822 L
s
.55766 .01472 m
.55766 .12173 L
s
.55859 .01472 m
.55859 .06822 L
s
.55952 .01472 m
.55952 .38928 L
s
.56045 .01472 m
.56045 .06822 L
s
.56138 .01472 m
.56138 .12173 L
s
.56231 .01472 m
.56231 .06822 L
s
.56324 .01472 m
.56324 .17524 L
s
.56417 .01472 m
.56417 .06822 L
s
.5651 .01472 m
.5651 .12173 L
s
.56603 .01472 m
.56603 .06822 L
s
.56696 .01472 m
.56696 .22875 L
s
.56789 .01472 m
.56789 .06822 L
s
.56882 .01472 m
.56882 .12173 L
s
.56975 .01472 m
.56975 .06822 L
s
.57068 .01472 m
.57068 .17524 L
s
.57161 .01472 m
.57161 .06822 L
s
.57254 .01472 m
.57254 .12173 L
s
.57347 .01472 m
.57347 .06822 L
s
.5744 .01472 m
.5744 .28226 L
s
.57533 .01472 m
.57533 .06822 L
s
.57626 .01472 m
.57626 .12173 L
s
.57719 .01472 m
.57719 .06822 L
s
.57813 .01472 m
.57813 .17524 L
s
.57906 .01472 m
.57906 .06822 L
s
.57999 .01472 m
.57999 .12173 L
s
.58092 .01472 m
.58092 .06822 L
s
.58185 .01472 m
.58185 .22875 L
s
.58278 .01472 m
.58278 .06822 L
s
.58371 .01472 m
.58371 .12173 L
s
.58464 .01472 m
.58464 .06822 L
s
.58557 .01472 m
.58557 .17524 L
s
.5865 .01472 m
.5865 .06822 L
s
.58743 .01472 m
.58743 .12173 L
s
.58836 .01472 m
.58836 .06822 L
s
.58929 .01472 m
.58929 .33577 L
s
.59022 .01472 m
.59022 .06822 L
s
.59115 .01472 m
.59115 .12173 L
s
.59208 .01472 m
.59208 .06822 L
s
.59301 .01472 m
.59301 .17524 L
s
.59394 .01472 m
.59394 .06822 L
s
.59487 .01472 m
.59487 .12173 L
s
.5958 .01472 m
.5958 .06822 L
s
.59673 .01472 m
.59673 .22875 L
s
.59766 .01472 m
.59766 .06822 L
s
.59859 .01472 m
.59859 .12173 L
s
.59952 .01472 m
.59952 .06822 L
s
.60045 .01472 m
.60045 .17524 L
s
.60138 .01472 m
.60138 .06822 L
s
.60231 .01472 m
.60231 .12173 L
s
.60324 .01472 m
.60324 .06822 L
s
.60417 .01472 m
.60417 .28226 L
s
.6051 .01472 m
.6051 .06822 L
s
.60603 .01472 m
.60603 .12173 L
s
.60696 .01472 m
.60696 .06822 L
s
.60789 .01472 m
.60789 .17524 L
s
.60882 .01472 m
.60882 .06822 L
s
.60975 .01472 m
.60975 .12173 L
s
.61068 .01472 m
.61068 .06822 L
s
.61161 .01472 m
.61161 .22875 L
s
.61254 .01472 m
.61254 .06822 L
s
.61347 .01472 m
.61347 .12173 L
s
.6144 .01472 m
.6144 .06822 L
s
.61533 .01472 m
.61533 .17524 L
s
.61626 .01472 m
.61626 .06822 L
s
.61719 .01472 m
.61719 .12173 L
s
.61812 .01472 m
.61812 .06822 L
s
.61905 .01472 m
.61905 .44279 L
s
.61998 .01472 m
.61998 .06822 L
s
.62091 .01472 m
.62091 .12173 L
s
.62184 .01472 m
.62184 .06822 L
s
.62277 .01472 m
.62277 .17524 L
s
.6237 .01472 m
.6237 .06822 L
s
.62463 .01472 m
.62463 .12173 L
s
.62556 .01472 m
.62556 .06822 L
s
.62649 .01472 m
.62649 .22875 L
s
.62742 .01472 m
.62742 .06822 L
s
.62835 .01472 m
.62835 .12173 L
s
.62928 .01472 m
.62928 .06822 L
s
.63021 .01472 m
.63021 .17524 L
s
.63114 .01472 m
.63114 .06822 L
s
.63207 .01472 m
.63207 .12173 L
s
.633 .01472 m
.633 .06822 L
s
.63393 .01472 m
.63393 .28226 L
s
.63486 .01472 m
.63486 .06822 L
s
.63579 .01472 m
.63579 .12173 L
s
.63672 .01472 m
.63672 .06822 L
s
.63765 .01472 m
.63765 .17524 L
s
.63858 .01472 m
.63858 .06822 L
s
.63951 .01472 m
.63951 .12173 L
s
.64044 .01472 m
.64044 .06822 L
s
.64137 .01472 m
.64137 .22875 L
s
.6423 .01472 m
.6423 .06822 L
s
.64323 .01472 m
.64323 .12173 L
s
.64416 .01472 m
.64416 .06822 L
s
.64509 .01472 m
.64509 .17524 L
s
.64602 .01472 m
.64602 .06822 L
s
.64695 .01472 m
.64695 .12173 L
s
.64788 .01472 m
.64788 .06822 L
s
.64881 .01472 m
.64881 .33577 L
s
.64974 .01472 m
.64974 .06822 L
s
.65067 .01472 m
.65067 .12173 L
s
.6516 .01472 m
.6516 .06822 L
s
.65253 .01472 m
.65253 .17524 L
s
.65346 .01472 m
.65346 .06822 L
s
.65439 .01472 m
.65439 .12173 L
s
.65532 .01472 m
.65532 .06822 L
s
.65625 .01472 m
.65625 .22875 L
s
.65718 .01472 m
.65718 .06822 L
s
.65811 .01472 m
.65811 .12173 L
s
.65904 .01472 m
.65904 .06822 L
s
.65997 .01472 m
.65997 .17524 L
s
.6609 .01472 m
.6609 .06822 L
s
.66183 .01472 m
.66183 .12173 L
s
.66276 .01472 m
.66276 .06822 L
s
.66369 .01472 m
.66369 .28226 L
s
.66462 .01472 m
.66462 .06822 L
s
.66555 .01472 m
.66555 .12173 L
s
.66648 .01472 m
.66648 .06822 L
s
.66741 .01472 m
.66741 .17524 L
s
.66834 .01472 m
.66834 .06822 L
s
.66927 .01472 m
.66927 .12173 L
s
.6702 .01472 m
.6702 .06822 L
s
.67113 .01472 m
.67113 .22875 L
s
.67206 .01472 m
.67206 .06822 L
s
.67299 .01472 m
.67299 .12173 L
s
.67392 .01472 m
.67392 .06822 L
s
.67485 .01472 m
.67485 .17524 L
s
.67578 .01472 m
.67578 .06822 L
s
.67671 .01472 m
.67671 .12173 L
s
.67764 .01472 m
.67764 .06822 L
s
.67857 .01472 m
.67857 .38928 L
s
.6795 .01472 m
.6795 .06822 L
s
.68043 .01472 m
.68043 .12173 L
s
.68136 .01472 m
.68136 .06822 L
s
.68229 .01472 m
.68229 .17524 L
s
.68322 .01472 m
.68322 .06822 L
s
.68415 .01472 m
.68415 .12173 L
s
.68508 .01472 m
.68508 .06822 L
s
.68601 .01472 m
.68601 .22875 L
s
.68694 .01472 m
.68694 .06822 L
s
.68787 .01472 m
.68787 .12173 L
s
.6888 .01472 m
.6888 .06822 L
s
.68973 .01472 m
.68973 .17524 L
s
.69066 .01472 m
.69066 .06822 L
s
.69159 .01472 m
.69159 .12173 L
s
.69252 .01472 m
.69252 .06822 L
s
.69345 .01472 m
.69345 .28226 L
s
.69438 .01472 m
.69438 .06822 L
s
.69531 .01472 m
.69531 .12173 L
s
.69624 .01472 m
.69624 .06822 L
s
.69717 .01472 m
.69717 .17524 L
s
.6981 .01472 m
.6981 .06822 L
s
.69903 .01472 m
.69903 .12173 L
s
.69996 .01472 m
.69996 .06822 L
s
.70089 .01472 m
.70089 .22875 L
s
.70182 .01472 m
.70182 .06822 L
s
.70275 .01472 m
.70275 .12173 L
s
.70368 .01472 m
.70368 .06822 L
s
.70461 .01472 m
.70461 .17524 L
s
.70554 .01472 m
.70554 .06822 L
s
.70647 .01472 m
.70647 .12173 L
s
.7074 .01472 m
.7074 .06822 L
s
.70833 .01472 m
.70833 .33577 L
s
.70926 .01472 m
.70926 .06822 L
s
.71019 .01472 m
.71019 .12173 L
s
.71112 .01472 m
.71112 .06822 L
s
.71205 .01472 m
.71205 .17524 L
s
.71298 .01472 m
.71298 .06822 L
s
.71391 .01472 m
.71391 .12173 L
s
.71484 .01472 m
.71484 .06822 L
s
.71577 .01472 m
.71577 .22875 L
s
.7167 .01472 m
.7167 .06822 L
s
.71763 .01472 m
.71763 .12173 L
s
.71856 .01472 m
.71856 .06822 L
s
.71949 .01472 m
.71949 .17524 L
s
.72042 .01472 m
.72042 .06822 L
s
.72135 .01472 m
.72135 .12173 L
s
.72228 .01472 m
.72228 .06822 L
s
.72321 .01472 m
.72321 .28226 L
s
.72414 .01472 m
.72414 .06822 L
s
.72507 .01472 m
.72507 .12173 L
s
.726 .01472 m
.726 .06822 L
s
.72693 .01472 m
.72693 .17524 L
s
.72786 .01472 m
.72786 .06822 L
s
.72879 .01472 m
.72879 .12173 L
s
.72972 .01472 m
.72972 .06822 L
s
.73065 .01472 m
.73065 .22875 L
s
.73158 .01472 m
.73158 .06822 L
s
.73251 .01472 m
.73251 .12173 L
s
.73344 .01472 m
.73344 .06822 L
s
.73438 .01472 m
.73438 .17524 L
s
.73531 .01472 m
.73531 .06822 L
s
.73624 .01472 m
.73624 .12173 L
s
.73717 .01472 m
.73717 .06822 L
s
.7381 .01472 m
.7381 .4963 L
s
.73903 .01472 m
.73903 .06822 L
s
.73996 .01472 m
.73996 .12173 L
s
.74089 .01472 m
.74089 .06822 L
s
.74182 .01472 m
.74182 .17524 L
s
.74275 .01472 m
.74275 .06822 L
s
.74368 .01472 m
.74368 .12173 L
s
.74461 .01472 m
.74461 .06822 L
s
.74554 .01472 m
.74554 .22875 L
s
.74647 .01472 m
.74647 .06822 L
s
.7474 .01472 m
.7474 .12173 L
s
.74833 .01472 m
.74833 .06822 L
s
.74926 .01472 m
.74926 .17524 L
s
.75019 .01472 m
.75019 .06822 L
s
.75112 .01472 m
.75112 .12173 L
s
.75205 .01472 m
.75205 .06822 L
s
.75298 .01472 m
.75298 .28226 L
s
.75391 .01472 m
.75391 .06822 L
s
.75484 .01472 m
.75484 .12173 L
s
.75577 .01472 m
.75577 .06822 L
s
.7567 .01472 m
.7567 .17524 L
s
.75763 .01472 m
.75763 .06822 L
s
.75856 .01472 m
.75856 .12173 L
s
.75949 .01472 m
.75949 .06822 L
s
.76042 .01472 m
.76042 .22875 L
s
.76135 .01472 m
.76135 .06822 L
s
.76228 .01472 m
.76228 .12173 L
s
.76321 .01472 m
.76321 .06822 L
s
.76414 .01472 m
.76414 .17524 L
s
.76507 .01472 m
.76507 .06822 L
s
.766 .01472 m
.766 .12173 L
s
.76693 .01472 m
.76693 .06822 L
s
.76786 .01472 m
.76786 .33577 L
s
.76879 .01472 m
.76879 .06822 L
s
.76972 .01472 m
.76972 .12173 L
s
.77065 .01472 m
.77065 .06822 L
s
.77158 .01472 m
.77158 .17524 L
s
.77251 .01472 m
.77251 .06822 L
s
.77344 .01472 m
.77344 .12173 L
s
.77437 .01472 m
.77437 .06822 L
s
.7753 .01472 m
.7753 .22875 L
s
.77623 .01472 m
.77623 .06822 L
s
.77716 .01472 m
.77716 .12173 L
s
.77809 .01472 m
.77809 .06822 L
s
.77902 .01472 m
.77902 .17524 L
s
.77995 .01472 m
.77995 .06822 L
s
.78088 .01472 m
.78088 .12173 L
s
.78181 .01472 m
.78181 .06822 L
s
.78274 .01472 m
.78274 .28226 L
s
.78367 .01472 m
.78367 .06822 L
s
.7846 .01472 m
.7846 .12173 L
s
.78553 .01472 m
.78553 .06822 L
s
.78646 .01472 m
.78646 .17524 L
s
.78739 .01472 m
.78739 .06822 L
s
.78832 .01472 m
.78832 .12173 L
s
.78925 .01472 m
.78925 .06822 L
s
.79018 .01472 m
.79018 .22875 L
s
.79111 .01472 m
.79111 .06822 L
s
.79204 .01472 m
.79204 .12173 L
s
.79297 .01472 m
.79297 .06822 L
s
.7939 .01472 m
.7939 .17524 L
s
.79483 .01472 m
.79483 .06822 L
s
.79576 .01472 m
.79576 .12173 L
s
.79669 .01472 m
.79669 .06822 L
s
.79762 .01472 m
.79762 .38928 L
s
.79855 .01472 m
.79855 .06822 L
s
.79948 .01472 m
.79948 .12173 L
s
.80041 .01472 m
.80041 .06822 L
s
.80134 .01472 m
.80134 .17524 L
s
.80227 .01472 m
.80227 .06822 L
s
.8032 .01472 m
.8032 .12173 L
s
.80413 .01472 m
.80413 .06822 L
s
.80506 .01472 m
.80506 .22875 L
s
.80599 .01472 m
.80599 .06822 L
s
.80692 .01472 m
.80692 .12173 L
s
.80785 .01472 m
.80785 .06822 L
s
.80878 .01472 m
.80878 .17524 L
s
.80971 .01472 m
.80971 .06822 L
s
.81064 .01472 m
.81064 .12173 L
s
.81157 .01472 m
.81157 .06822 L
s
.8125 .01472 m
.8125 .28226 L
s
.81343 .01472 m
.81343 .06822 L
s
.81436 .01472 m
.81436 .12173 L
s
.81529 .01472 m
.81529 .06822 L
s
.81622 .01472 m
.81622 .17524 L
s
.81715 .01472 m
.81715 .06822 L
s
.81808 .01472 m
.81808 .12173 L
s
.81901 .01472 m
.81901 .06822 L
s
.81994 .01472 m
.81994 .22875 L
s
.82087 .01472 m
.82087 .06822 L
s
.8218 .01472 m
.8218 .12173 L
s
.82273 .01472 m
.82273 .06822 L
s
.82366 .01472 m
.82366 .17524 L
s
.82459 .01472 m
.82459 .06822 L
s
.82552 .01472 m
.82552 .12173 L
s
.82645 .01472 m
.82645 .06822 L
s
.82738 .01472 m
.82738 .33577 L
s
.82831 .01472 m
.82831 .06822 L
s
.82924 .01472 m
.82924 .12173 L
s
.83017 .01472 m
.83017 .06822 L
s
.8311 .01472 m
.8311 .17524 L
s
.83203 .01472 m
.83203 .06822 L
s
.83296 .01472 m
.83296 .12173 L
s
.83389 .01472 m
.83389 .06822 L
s
.83482 .01472 m
.83482 .22875 L
s
.83575 .01472 m
.83575 .06822 L
s
.83668 .01472 m
.83668 .12173 L
s
.83761 .01472 m
.83761 .06822 L
s
.83854 .01472 m
.83854 .17524 L
s
.83947 .01472 m
.83947 .06822 L
s
.8404 .01472 m
.8404 .12173 L
s
.84133 .01472 m
.84133 .06822 L
s
.84226 .01472 m
.84226 .28226 L
s
.84319 .01472 m
.84319 .06822 L
s
.84412 .01472 m
.84412 .12173 L
s
.84505 .01472 m
.84505 .06822 L
s
.84598 .01472 m
.84598 .17524 L
s
.84691 .01472 m
.84691 .06822 L
s
.84784 .01472 m
.84784 .12173 L
s
.84877 .01472 m
.84877 .06822 L
s
.8497 .01472 m
.8497 .22875 L
s
.85063 .01472 m
.85063 .06822 L
s
.85156 .01472 m
.85156 .12173 L
s
.85249 .01472 m
.85249 .06822 L
s
.85342 .01472 m
.85342 .17524 L
s
.85435 .01472 m
.85435 .06822 L
s
.85528 .01472 m
.85528 .12173 L
s
.85621 .01472 m
.85621 .06822 L
s
.85714 .01472 m
.85714 .44279 L
s
.85807 .01472 m
.85807 .06822 L
s
.859 .01472 m
.859 .12173 L
s
.85993 .01472 m
.85993 .06822 L
s
.86086 .01472 m
.86086 .17524 L
s
.86179 .01472 m
.86179 .06822 L
s
.86272 .01472 m
.86272 .12173 L
s
.86365 .01472 m
.86365 .06822 L
s
.86458 .01472 m
.86458 .22875 L
s
.86551 .01472 m
.86551 .06822 L
s
.86644 .01472 m
.86644 .12173 L
s
.86737 .01472 m
.86737 .06822 L
s
.8683 .01472 m
.8683 .17524 L
s
.86923 .01472 m
.86923 .06822 L
s
.87016 .01472 m
.87016 .12173 L
s
.87109 .01472 m
.87109 .06822 L
s
.87202 .01472 m
.87202 .28226 L
s
.87295 .01472 m
.87295 .06822 L
s
.87388 .01472 m
.87388 .12173 L
s
.87481 .01472 m
.87481 .06822 L
s
.87574 .01472 m
.87574 .17524 L
s
.87667 .01472 m
.87667 .06822 L
s
.8776 .01472 m
.8776 .12173 L
s
.87853 .01472 m
.87853 .06822 L
s
.87946 .01472 m
.87946 .22875 L
s
.88039 .01472 m
.88039 .06822 L
s
.88132 .01472 m
.88132 .12173 L
s
.88225 .01472 m
.88225 .06822 L
s
.88318 .01472 m
.88318 .17524 L
s
.88411 .01472 m
.88411 .06822 L
s
.88504 .01472 m
.88504 .12173 L
s
.88597 .01472 m
.88597 .06822 L
s
.8869 .01472 m
.8869 .33577 L
s
.88783 .01472 m
.88783 .06822 L
s
.88876 .01472 m
.88876 .12173 L
s
.88969 .01472 m
.88969 .06822 L
s
.89063 .01472 m
.89063 .17524 L
s
.89156 .01472 m
.89156 .06822 L
s
.89249 .01472 m
.89249 .12173 L
s
.89342 .01472 m
.89342 .06822 L
s
.89435 .01472 m
.89435 .22875 L
s
.89528 .01472 m
.89528 .06822 L
s
.89621 .01472 m
.89621 .12173 L
s
.89714 .01472 m
.89714 .06822 L
s
.89807 .01472 m
.89807 .17524 L
s
.899 .01472 m
.899 .06822 L
s
.89993 .01472 m
.89993 .12173 L
s
.90086 .01472 m
.90086 .06822 L
s
.90179 .01472 m
.90179 .28226 L
s
.90272 .01472 m
.90272 .06822 L
s
.90365 .01472 m
.90365 .12173 L
s
.90458 .01472 m
.90458 .06822 L
s
.90551 .01472 m
.90551 .17524 L
s
.90644 .01472 m
.90644 .06822 L
s
.90737 .01472 m
.90737 .12173 L
s
.9083 .01472 m
.9083 .06822 L
s
.90923 .01472 m
.90923 .22875 L
s
.91016 .01472 m
.91016 .06822 L
s
.91109 .01472 m
.91109 .12173 L
s
.91202 .01472 m
.91202 .06822 L
s
.91295 .01472 m
.91295 .17524 L
s
.91388 .01472 m
.91388 .06822 L
s
.91481 .01472 m
.91481 .12173 L
s
.91574 .01472 m
.91574 .06822 L
s
.91667 .01472 m
.91667 .38928 L
s
.9176 .01472 m
.9176 .06822 L
s
.91853 .01472 m
.91853 .12173 L
s
.91946 .01472 m
.91946 .06822 L
s
.92039 .01472 m
.92039 .17524 L
s
.92132 .01472 m
.92132 .06822 L
s
.92225 .01472 m
.92225 .12173 L
s
.92318 .01472 m
.92318 .06822 L
s
.92411 .01472 m
.92411 .22875 L
s
.92504 .01472 m
.92504 .06822 L
s
.92597 .01472 m
.92597 .12173 L
s
.9269 .01472 m
.9269 .06822 L
s
.92783 .01472 m
.92783 .17524 L
s
.92876 .01472 m
.92876 .06822 L
s
.92969 .01472 m
.92969 .12173 L
s
.93062 .01472 m
.93062 .06822 L
s
.93155 .01472 m
.93155 .28226 L
s
.93248 .01472 m
.93248 .06822 L
s
.93341 .01472 m
.93341 .12173 L
s
.93434 .01472 m
.93434 .06822 L
s
.93527 .01472 m
.93527 .17524 L
s
.9362 .01472 m
.9362 .06822 L
s
.93713 .01472 m
.93713 .12173 L
s
.93806 .01472 m
.93806 .06822 L
s
.93899 .01472 m
.93899 .22875 L
s
.93992 .01472 m
.93992 .06822 L
s
.94085 .01472 m
.94085 .12173 L
s
.94178 .01472 m
.94178 .06822 L
s
.94271 .01472 m
.94271 .17524 L
s
.94364 .01472 m
.94364 .06822 L
s
.94457 .01472 m
.94457 .12173 L
s
.9455 .01472 m
.9455 .06822 L
s
.94643 .01472 m
.94643 .33577 L
s
.94736 .01472 m
.94736 .06822 L
s
.94829 .01472 m
.94829 .12173 L
s
.94922 .01472 m
.94922 .06822 L
s
.95015 .01472 m
.95015 .17524 L
s
.95108 .01472 m
.95108 .06822 L
s
.95201 .01472 m
.95201 .12173 L
s
.95294 .01472 m
.95294 .06822 L
s
.95387 .01472 m
.95387 .22875 L
s
.9548 .01472 m
.9548 .06822 L
s
.95573 .01472 m
.95573 .12173 L
s
.95666 .01472 m
.95666 .06822 L
s
.95759 .01472 m
.95759 .17524 L
s
.95852 .01472 m
.95852 .06822 L
s
.95945 .01472 m
.95945 .12173 L
s
.96038 .01472 m
.96038 .06822 L
s
.96131 .01472 m
.96131 .28226 L
s
.96224 .01472 m
.96224 .06822 L
s
.96317 .01472 m
.96317 .12173 L
s
.9641 .01472 m
.9641 .06822 L
s
.96503 .01472 m
.96503 .17524 L
s
.96596 .01472 m
.96596 .06822 L
s
.96689 .01472 m
.96689 .12173 L
s
.96782 .01472 m
.96782 .06822 L
s
.96875 .01472 m
.96875 .22875 L
s
.96968 .01472 m
.96968 .06822 L
s
.97061 .01472 m
.97061 .12173 L
s
.97154 .01472 m
.97154 .06822 L
s
.97247 .01472 m
.97247 .17524 L
s
.9734 .01472 m
.9734 .06822 L
s
.97433 .01472 m
.97433 .12173 L
s
.97526 .01472 m
.97526 .06822 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.02474 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.02567 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.02753 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03125 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03218 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03311 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03404 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03497 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.0359 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03683 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03869 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03962 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04055 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04148 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04241 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04427 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04613 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04799 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04985 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05078 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05171 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05264 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05357 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.06101 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.06845 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.07031 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.07217 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.07589 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.07961 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08054 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08147 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.0824 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08333 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08705 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09077 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09263 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09449 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09821 .22875 translate
.01489 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1131 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.11682 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.11868 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.11961 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.12054 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.12798 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.13542 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.13914 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1503 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.15216 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.15402 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.15774 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.16518 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1689 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.17076 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.17262 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.18006 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1875 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.19494 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20238 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20982 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.21354 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.21726 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2247 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.23214 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.23958 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.24702 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .17524 translate
.00745 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.26935 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.27307 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.27679 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.28423 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.29167 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.29911 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.30283 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.30655 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.31399 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.31771 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32143 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32887 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.33259 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.33631 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.33817 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.3391 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.34003 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.34189 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.34375 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.34747 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.35119 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.35863 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.36235 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.36607 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38839 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.39211 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.39583 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.40327 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.40699 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.40885 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41071 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41443 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41536 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41629 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.41815 .12173 translate
.00373 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.42188 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.42374 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.4256 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.43304 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.44048 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.44792 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.45164 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.45536 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.4628 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47024 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47768 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.48512 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.51488 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.52976 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.54464 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.55952 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5744 .22875 translate
.01489 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.58929 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.60417 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61161 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.63393 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.64881 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.66369 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.67857 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.69345 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.70833 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.71577 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.72321 .22875 translate
.01489 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.75298 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.76042 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.76786 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7753 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.77902 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.78088 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.78181 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.78274 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.79018 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7939 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.79762 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.80506 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.80878 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8125 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.82738 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.83482 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.83854 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.84226 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8497 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.86458 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.87202 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.87946 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8869 .22875 translate
.01489 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.90179 .22875 translate
.01488 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.91667 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.92039 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.92225 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.92411 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.93155 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.93341 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.93434 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.93527 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.93899 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.94643 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.95387 .12173 translate
.00372 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.95759 .06822 translate
.00186 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.95945 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.96038 .01472 translate
.00093 .0535 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.96131 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.96875 .17524 translate
.00744 .05351 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
We see the original space is split into much finer subspaces than \
in the case of the wavelet transform.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.48"}],

Cell[CellGroupData[{

Cell["Length[wpdata]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(176\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "Due to the large number of sublists we cannot stack all 176 plots of \
coefficients together using ",
  StyleBox["PlotCoefficients", "MR"],
  " or ",
  StyleBox["PhaseSpacePlot", "MR"],
  " and discern anything useful. We can, of course, take a few lists at a \
time and plot them separately. "
}], "Text",
  CellTags->{"S2.1.3", "3.49"}],

Cell["Here we look at the energy distribution of the coefficients.", 
  "MathCaption",
  CellTags->{"S2.1.3", "3.50"}],

Cell["ewp = CumulativeEnergy[wpdata]/(mdata.mdata);", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
We plot the normalized cumulative energies from both wavelet \
transform coefficients (dashed line) and from wavelet packet transform \
coefficients (solid line) together.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.51"}],

Cell[CellGroupData[{

Cell["\<\
Show[Block[{$DisplayFunction = Identity},
{ListPlot[ewp, PlotJoined -> True,
 PlotLabel -> \"cumulative energy\"],
 ListPlot[CumulativeEnergy[wtdata]/
 (Flatten[wtdata].Flatten[wtdata]),
 PlotJoined -> True, PlotStyle -> Dashing[{0.02}]]}]]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000132866 -7.91395 8.51727 [
[.15668 .59082 -12 -9 ]
[.15668 .59082 12 0 ]
[.28954 .59082 -12 -9 ]
[.28954 .59082 12 0 ]
[.42241 .59082 -12 -9 ]
[.42241 .59082 12 0 ]
[.55527 .59082 -12 -9 ]
[.55527 .59082 12 0 ]
[.68814 .59082 -12 -9 ]
[.68814 .59082 12 0 ]
[.821 .59082 -12 -9 ]
[.821 .59082 12 0 ]
[.95387 .59082 -12 -9 ]
[.95387 .59082 12 0 ]
[.01131 .00711 -24 -4.5 ]
[.01131 .00711 0 4.5 ]
[.01131 .09228 -24 -4.5 ]
[.01131 .09228 0 4.5 ]
[.01131 .17746 -24 -4.5 ]
[.01131 .17746 0 4.5 ]
[.01131 .26263 -24 -4.5 ]
[.01131 .26263 0 4.5 ]
[.01131 .3478 -24 -4.5 ]
[.01131 .3478 0 4.5 ]
[.01131 .43297 -24 -4.5 ]
[.01131 .43297 0 4.5 ]
[.01131 .51815 -24 -4.5 ]
[.01131 .51815 0 4.5 ]
[.5 .63053 -51 0 ]
[.5 .63053 51 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15668 .60332 m
.15668 .60957 L
s
[(1000)] .15668 .59082 0 1 Mshowa
.28954 .60332 m
.28954 .60957 L
s
[(2000)] .28954 .59082 0 1 Mshowa
.42241 .60332 m
.42241 .60957 L
s
[(3000)] .42241 .59082 0 1 Mshowa
.55527 .60332 m
.55527 .60957 L
s
[(4000)] .55527 .59082 0 1 Mshowa
.68814 .60332 m
.68814 .60957 L
s
[(5000)] .68814 .59082 0 1 Mshowa
.821 .60332 m
.821 .60957 L
s
[(6000)] .821 .59082 0 1 Mshowa
.95387 .60332 m
.95387 .60957 L
s
[(7000)] .95387 .59082 0 1 Mshowa
.125 Mabswid
.05038 .60332 m
.05038 .60707 L
s
.07696 .60332 m
.07696 .60707 L
s
.10353 .60332 m
.10353 .60707 L
s
.1301 .60332 m
.1301 .60707 L
s
.18325 .60332 m
.18325 .60707 L
s
.20982 .60332 m
.20982 .60707 L
s
.23639 .60332 m
.23639 .60707 L
s
.26297 .60332 m
.26297 .60707 L
s
.31611 .60332 m
.31611 .60707 L
s
.34269 .60332 m
.34269 .60707 L
s
.36926 .60332 m
.36926 .60707 L
s
.39583 .60332 m
.39583 .60707 L
s
.44898 .60332 m
.44898 .60707 L
s
.47555 .60332 m
.47555 .60707 L
s
.50213 .60332 m
.50213 .60707 L
s
.5287 .60332 m
.5287 .60707 L
s
.58185 .60332 m
.58185 .60707 L
s
.60842 .60332 m
.60842 .60707 L
s
.63499 .60332 m
.63499 .60707 L
s
.66156 .60332 m
.66156 .60707 L
s
.71471 .60332 m
.71471 .60707 L
s
.74128 .60332 m
.74128 .60707 L
s
.76786 .60332 m
.76786 .60707 L
s
.79443 .60332 m
.79443 .60707 L
s
.84758 .60332 m
.84758 .60707 L
s
.87415 .60332 m
.87415 .60707 L
s
.90072 .60332 m
.90072 .60707 L
s
.9273 .60332 m
.9273 .60707 L
s
.98044 .60332 m
.98044 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .00711 m
.03006 .00711 L
s
[(0.93)] .01131 .00711 1 0 Mshowa
.02381 .09228 m
.03006 .09228 L
s
[(0.94)] .01131 .09228 1 0 Mshowa
.02381 .17746 m
.03006 .17746 L
s
[(0.95)] .01131 .17746 1 0 Mshowa
.02381 .26263 m
.03006 .26263 L
s
[(0.96)] .01131 .26263 1 0 Mshowa
.02381 .3478 m
.03006 .3478 L
s
[(0.97)] .01131 .3478 1 0 Mshowa
.02381 .43297 m
.03006 .43297 L
s
[(0.98)] .01131 .43297 1 0 Mshowa
.02381 .51815 m
.03006 .51815 L
s
[(0.99)] .01131 .51815 1 0 Mshowa
.125 Mabswid
.02381 .02414 m
.02756 .02414 L
s
.02381 .04118 m
.02756 .04118 L
s
.02381 .05821 m
.02756 .05821 L
s
.02381 .07525 m
.02756 .07525 L
s
.02381 .10932 m
.02756 .10932 L
s
.02381 .12635 m
.02756 .12635 L
s
.02381 .14339 m
.02756 .14339 L
s
.02381 .16042 m
.02756 .16042 L
s
.02381 .19449 m
.02756 .19449 L
s
.02381 .21152 m
.02756 .21152 L
s
.02381 .22856 m
.02756 .22856 L
s
.02381 .24559 m
.02756 .24559 L
s
.02381 .27966 m
.02756 .27966 L
s
.02381 .2967 m
.02756 .2967 L
s
.02381 .31373 m
.02756 .31373 L
s
.02381 .33077 m
.02756 .33077 L
s
.02381 .36484 m
.02756 .36484 L
s
.02381 .38187 m
.02756 .38187 L
s
.02381 .3989 m
.02756 .3989 L
s
.02381 .41594 m
.02756 .41594 L
s
.02381 .45001 m
.02756 .45001 L
s
.02381 .46704 m
.02756 .46704 L
s
.02381 .48408 m
.02756 .48408 L
s
.02381 .50111 m
.02756 .50111 L
s
.02381 .53518 m
.02756 .53518 L
s
.02381 .55222 m
.02756 .55222 L
s
.02381 .56925 m
.02756 .56925 L
s
.02381 .58628 m
.02756 .58628 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(cumulative energy)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.09219 0 m
.09224 .00051 L
.09237 .0019 L
.0925 .0033 L
.09263 .00469 L
.09277 .00608 L
.0929 .00746 L
.09303 .00883 L
.09317 .0102 L
.0933 .01156 L
.09343 .01292 L
.09356 .01428 L
.0937 .01563 L
.09383 .01699 L
.09396 .01834 L
.0941 .01968 L
.09423 .02103 L
.09436 .02237 L
.09449 .02371 L
.09463 .02504 L
.09476 .02635 L
.09489 .02766 L
.09503 .02896 L
.09516 .03026 L
.09529 .03157 L
.09542 .03286 L
.09556 .03416 L
.09569 .03546 L
.09582 .03675 L
.09596 .03804 L
.09609 .03934 L
.09622 .04062 L
.09635 .04191 L
.09649 .04319 L
.09662 .04448 L
.09675 .04576 L
.09689 .04702 L
.09702 .04828 L
.09715 .04954 L
.09728 .05079 L
.09742 .05203 L
.09755 .05327 L
.09768 .0545 L
.09782 .05572 L
.09795 .05695 L
.09808 .05817 L
.09821 .05939 L
.09835 .06062 L
.09848 .06184 L
.09861 .06306 L
Mistroke
.09875 .06427 L
.09888 .06549 L
.09901 .0667 L
.09914 .06791 L
.09928 .06911 L
.09941 .07031 L
.09954 .07151 L
.09968 .0727 L
.09981 .0739 L
.09994 .07509 L
.10007 .07628 L
.10021 .07747 L
.10034 .07865 L
.10047 .07983 L
.10061 .08101 L
.10074 .08218 L
.10087 .08334 L
.101 .0845 L
.10114 .08566 L
.10127 .08681 L
.1014 .08797 L
.10154 .08912 L
.10167 .09027 L
.1018 .09142 L
.10193 .09256 L
.10207 .09371 L
.1022 .09484 L
.10233 .09598 L
.10247 .09711 L
.1026 .09823 L
.10273 .09936 L
.10286 .10048 L
.103 .10161 L
.10313 .10273 L
.10326 .10385 L
.1034 .10496 L
.10353 .10608 L
.10366 .10719 L
.10379 .1083 L
.10393 .10941 L
.10406 .11052 L
.10419 .11162 L
.10433 .11272 L
.10446 .11383 L
.10459 .11493 L
.10472 .11602 L
.10486 .11711 L
.10499 .1182 L
.10512 .11928 L
.10526 .12036 L
Mistroke
.10539 .12143 L
.10552 .1225 L
.10565 .12357 L
.10579 .12464 L
.10592 .1257 L
.10605 .12676 L
.10619 .12781 L
.10632 .12887 L
.10645 .12992 L
.10658 .13096 L
.10672 .132 L
.10685 .13304 L
.10698 .13408 L
.10712 .13511 L
.10725 .13614 L
.10738 .13717 L
.10751 .1382 L
.10765 .13922 L
.10778 .14024 L
.10791 .14126 L
.10805 .14228 L
.10818 .14329 L
.10831 .14431 L
.10844 .14531 L
.10858 .1463 L
.10871 .1473 L
.10884 .14829 L
.10898 .14927 L
.10911 .15024 L
.10924 .15121 L
.10937 .15218 L
.10951 .15315 L
.10964 .15412 L
.10977 .15508 L
.10991 .15605 L
.11004 .15701 L
.11017 .15797 L
.11031 .15894 L
.11044 .1599 L
.11057 .16086 L
.1107 .16181 L
.11084 .16277 L
.11097 .16372 L
.1111 .16467 L
.11124 .16562 L
.11137 .16656 L
.1115 .1675 L
.11163 .16844 L
.11177 .16938 L
.1119 .17031 L
Mistroke
.11203 .17125 L
.11217 .17218 L
.1123 .1731 L
.11243 .17402 L
.11256 .17494 L
.1127 .17586 L
.11283 .17678 L
.11296 .1777 L
.1131 .17862 L
.11323 .17953 L
.11336 .18044 L
.11349 .18135 L
.11363 .18226 L
.11376 .18317 L
.11389 .18407 L
.11403 .18497 L
.11416 .18586 L
.11429 .18676 L
.11442 .18765 L
.11456 .18854 L
.11469 .18942 L
.11482 .19031 L
.11496 .19118 L
.11509 .19205 L
.11522 .19292 L
.11535 .19378 L
.11549 .19464 L
.11562 .1955 L
.11575 .19636 L
.11589 .19721 L
.11602 .19806 L
.11615 .19891 L
.11628 .19975 L
.11642 .20059 L
.11655 .20142 L
.11668 .20224 L
.11682 .20307 L
.11695 .20388 L
.11708 .2047 L
.11721 .20552 L
.11735 .20633 L
.11748 .20715 L
.11761 .20796 L
.11775 .20877 L
.11788 .20958 L
.11801 .21039 L
.11814 .2112 L
.11828 .21201 L
.11841 .21281 L
.11854 .21361 L
Mistroke
.11868 .21442 L
.11881 .21522 L
.11894 .21601 L
.11907 .21681 L
.11921 .21761 L
.11934 .2184 L
.11947 .2192 L
.11961 .21999 L
.11974 .22078 L
.11987 .22157 L
.12 .22235 L
.12014 .22313 L
.12027 .22391 L
.1204 .22468 L
.12054 .22546 L
.12067 .22623 L
.1208 .227 L
.12093 .22776 L
.12107 .22852 L
.1212 .22927 L
.12133 .23003 L
.12147 .23079 L
.1216 .23153 L
.12173 .23228 L
.12186 .23303 L
.122 .23377 L
.12213 .23451 L
.12226 .23526 L
.1224 .236 L
.12253 .23674 L
.12266 .23747 L
.12279 .23821 L
.12293 .23893 L
.12306 .23965 L
.12319 .24037 L
.12333 .24108 L
.12346 .24179 L
.12359 .2425 L
.12372 .24321 L
.12386 .24392 L
.12399 .24462 L
.12412 .24532 L
.12426 .24603 L
.12439 .24673 L
.12452 .24743 L
.12465 .24813 L
.12479 .24883 L
.12492 .24953 L
.12505 .25022 L
.12519 .25092 L
Mistroke
.12532 .25161 L
.12545 .25231 L
.12558 .253 L
.12572 .25368 L
.12585 .25436 L
.12598 .25504 L
.12612 .25571 L
.12625 .25638 L
.12638 .25705 L
.12651 .25772 L
.12665 .25839 L
.12678 .25906 L
.12691 .25973 L
.12705 .2604 L
.12718 .26107 L
.12731 .26173 L
.12744 .2624 L
.12758 .26307 L
.12771 .26373 L
.12784 .26439 L
.12798 .26506 L
.12811 .26572 L
.12824 .26638 L
.12837 .26704 L
.12851 .2677 L
.12864 .26835 L
.12877 .26901 L
.12891 .26966 L
.12904 .27032 L
.12917 .27097 L
.1293 .27162 L
.12944 .27228 L
.12957 .27293 L
.1297 .27357 L
.12984 .27422 L
.12997 .27486 L
.1301 .2755 L
.13023 .27614 L
.13037 .27678 L
.1305 .27741 L
.13063 .27804 L
.13077 .27867 L
.1309 .27929 L
.13103 .27992 L
.13116 .28054 L
.1313 .28116 L
.13143 .28178 L
.13156 .2824 L
.1317 .28302 L
.13183 .28364 L
Mistroke
.13196 .28426 L
.1321 .28488 L
.13223 .28549 L
.13236 .2861 L
.13249 .28671 L
.13263 .28732 L
.13276 .28793 L
.13289 .28854 L
.13303 .28914 L
.13316 .28975 L
.13329 .29036 L
.13342 .29096 L
.13356 .29156 L
.13369 .29216 L
.13382 .29276 L
.13396 .29336 L
.13409 .29395 L
.13422 .29455 L
.13435 .29514 L
.13449 .29573 L
.13462 .29632 L
.13475 .29691 L
.13489 .2975 L
.13502 .29809 L
.13515 .29867 L
.13528 .29926 L
.13542 .29985 L
.13555 .30043 L
.13568 .30101 L
.13582 .3016 L
.13595 .30218 L
.13608 .30275 L
.13621 .30333 L
.13635 .30391 L
.13648 .30448 L
.13661 .30505 L
.13675 .30562 L
.13688 .30619 L
.13701 .30676 L
.13714 .30733 L
.13728 .30789 L
.13741 .30846 L
.13754 .30902 L
.13768 .30959 L
.13781 .31015 L
.13794 .3107 L
.13807 .31126 L
.13821 .31181 L
.13834 .31236 L
.13847 .31292 L
Mistroke
.13861 .31347 L
.13874 .31401 L
.13887 .31456 L
.139 .3151 L
.13914 .31564 L
.13927 .31618 L
.1394 .31672 L
.13954 .31726 L
.13967 .3178 L
.1398 .31834 L
.13993 .31887 L
.14007 .31941 L
.1402 .31994 L
.14033 .32048 L
.14047 .32101 L
.1406 .32154 L
.14073 .32207 L
.14086 .3226 L
.141 .32313 L
.14113 .32366 L
.14126 .32419 L
.1414 .32471 L
.14153 .32523 L
.14166 .32575 L
.14179 .32627 L
.14193 .32679 L
.14206 .32731 L
.14219 .32782 L
.14233 .32834 L
.14246 .32885 L
.14259 .32937 L
.14272 .32988 L
.14286 .33039 L
.14299 .33091 L
.14312 .33142 L
.14326 .33193 L
.14339 .33244 L
.14352 .33295 L
.14365 .33345 L
.14379 .33396 L
.14392 .33446 L
.14405 .33496 L
.14419 .33546 L
.14432 .33596 L
.14445 .33646 L
.14458 .33696 L
.14472 .33745 L
.14485 .33794 L
.14498 .33843 L
.14512 .33891 L
Mistroke
.14525 .3394 L
.14538 .33989 L
.14551 .34037 L
.14565 .34086 L
.14578 .34134 L
.14591 .34183 L
.14605 .34231 L
.14618 .34279 L
.14631 .34327 L
.14644 .34375 L
.14658 .34423 L
.14671 .34471 L
.14684 .34519 L
.14698 .34567 L
.14711 .34614 L
.14724 .34662 L
.14737 .34709 L
.14751 .34756 L
.14764 .34804 L
.14777 .34851 L
.14791 .34898 L
.14804 .34945 L
.14817 .34993 L
.1483 .3504 L
.14844 .35086 L
.14857 .35133 L
.1487 .3518 L
.14884 .35226 L
.14897 .35273 L
.1491 .35319 L
.14923 .35365 L
.14937 .35412 L
.1495 .35458 L
.14963 .35504 L
.14977 .3555 L
.1499 .35596 L
.15003 .35641 L
.15016 .35687 L
.1503 .35733 L
.15043 .35779 L
.15056 .35824 L
.1507 .3587 L
.15083 .35915 L
.15096 .35961 L
.15109 .36006 L
.15123 .36051 L
.15136 .36097 L
.15149 .36142 L
.15163 .36187 L
.15176 .36232 L
Mistroke
.15189 .36277 L
.15202 .36322 L
.15216 .36366 L
.15229 .36411 L
.15242 .36456 L
.15256 .365 L
.15269 .36544 L
.15282 .36588 L
.15295 .36633 L
.15309 .36676 L
.15322 .3672 L
.15335 .36763 L
.15349 .36807 L
.15362 .3685 L
.15375 .36893 L
.15388 .36936 L
.15402 .36979 L
.15415 .37022 L
.15428 .37064 L
.15442 .37107 L
.15455 .3715 L
.15468 .37192 L
.15482 .37235 L
.15495 .37277 L
.15508 .3732 L
.15521 .37362 L
.15535 .37404 L
.15548 .37446 L
.15561 .37488 L
.15575 .3753 L
.15588 .37572 L
.15601 .37614 L
.15614 .37655 L
.15628 .37697 L
.15641 .37738 L
.15654 .37779 L
.15668 .3782 L
.15681 .37861 L
.15694 .37902 L
.15707 .37943 L
.15721 .37984 L
.15734 .38025 L
.15747 .38065 L
.15761 .38106 L
.15774 .38146 L
.15787 .38186 L
.158 .38226 L
.15814 .38266 L
.15827 .38306 L
.1584 .38346 L
Mistroke
.15854 .38385 L
.15867 .38425 L
.1588 .38464 L
.15893 .38503 L
.15907 .38542 L
.1592 .38581 L
.15933 .3862 L
.15947 .38659 L
.1596 .38698 L
.15973 .38736 L
.15986 .38775 L
.16 .38813 L
.16013 .38851 L
.16026 .3889 L
.1604 .38928 L
.16053 .38966 L
.16066 .39004 L
.16079 .39041 L
.16093 .39079 L
.16106 .39117 L
.16119 .39155 L
.16133 .39192 L
.16146 .3923 L
.16159 .39268 L
.16172 .39305 L
.16186 .39343 L
.16199 .3938 L
.16212 .39417 L
.16226 .39454 L
.16239 .39491 L
.16252 .39528 L
.16265 .39565 L
.16279 .39602 L
.16292 .39638 L
.16305 .39675 L
.16319 .39711 L
.16332 .39747 L
.16345 .39783 L
.16358 .39819 L
.16372 .39855 L
.16385 .39891 L
.16398 .39927 L
.16412 .39963 L
.16425 .39999 L
.16438 .40034 L
.16451 .4007 L
.16465 .40105 L
.16478 .4014 L
.16491 .40175 L
.16505 .4021 L
Mistroke
.16518 .40245 L
.16531 .40279 L
.16544 .40314 L
.16558 .40348 L
.16571 .40382 L
.16584 .40416 L
.16598 .40451 L
.16611 .40485 L
.16624 .40519 L
.16637 .40553 L
.16651 .40587 L
.16664 .40621 L
.16677 .40655 L
.16691 .40688 L
.16704 .40722 L
.16717 .40755 L
.1673 .40788 L
.16744 .40822 L
.16757 .40855 L
.1677 .40888 L
.16784 .40921 L
.16797 .40954 L
.1681 .40987 L
.16823 .4102 L
.16837 .41053 L
.1685 .41086 L
.16863 .41119 L
.16877 .41151 L
.1689 .41184 L
.16903 .41216 L
.16916 .41249 L
.1693 .41281 L
.16943 .41314 L
.16956 .41346 L
.1697 .41378 L
.16983 .4141 L
.16996 .41442 L
.17009 .41474 L
.17023 .41506 L
.17036 .41537 L
.17049 .41569 L
.17063 .416 L
.17076 .41632 L
.17089 .41663 L
.17102 .41694 L
.17116 .41726 L
.17129 .41757 L
.17142 .41788 L
.17156 .41819 L
.17169 .4185 L
Mistroke
.17182 .41881 L
.17195 .41912 L
.17209 .41943 L
.17222 .41974 L
.17235 .42005 L
.17249 .42035 L
.17262 .42066 L
.17275 .42097 L
.17288 .42127 L
.17302 .42158 L
.17315 .42188 L
.17328 .42219 L
.17342 .42249 L
.17355 .42279 L
.17368 .42309 L
.17381 .42339 L
.17395 .42369 L
.17408 .42399 L
.17421 .42429 L
.17435 .42458 L
.17448 .42488 L
.17461 .42518 L
.17474 .42547 L
.17488 .42577 L
.17501 .42607 L
.17514 .42636 L
.17528 .42666 L
.17541 .42695 L
.17554 .42725 L
.17567 .42754 L
.17581 .42784 L
.17594 .42813 L
.17607 .42842 L
.17621 .42872 L
.17634 .42901 L
.17647 .4293 L
.17661 .4296 L
.17674 .42989 L
.17687 .43018 L
.177 .43047 L
.17714 .43076 L
.17727 .43105 L
.1774 .43134 L
.17754 .43163 L
.17767 .43192 L
.1778 .43221 L
.17793 .4325 L
.17807 .43279 L
.1782 .43308 L
.17833 .43336 L
Mistroke
.17847 .43365 L
.1786 .43393 L
.17873 .43421 L
.17886 .4345 L
.179 .43478 L
.17913 .43506 L
.17926 .43534 L
.1794 .43562 L
.17953 .4359 L
.17966 .43618 L
.17979 .43646 L
.17993 .43674 L
.18006 .43702 L
.18019 .4373 L
.18033 .43757 L
.18046 .43785 L
.18059 .43813 L
.18072 .4384 L
.18086 .43868 L
.18099 .43896 L
.18112 .43923 L
.18126 .4395 L
.18139 .43978 L
.18152 .44005 L
.18165 .44032 L
.18179 .44059 L
.18192 .44086 L
.18205 .44113 L
.18219 .4414 L
.18232 .44167 L
.18245 .44194 L
.18258 .44221 L
.18272 .44248 L
.18285 .44274 L
.18298 .44301 L
.18312 .44327 L
.18325 .44354 L
.18338 .4438 L
.18351 .44407 L
.18365 .44433 L
.18378 .44459 L
.18391 .44486 L
.18405 .44512 L
.18418 .44538 L
.18431 .44564 L
.18444 .44591 L
.18458 .44617 L
.18471 .44643 L
.18484 .44669 L
.18498 .44695 L
Mistroke
.18511 .44721 L
.18524 .44747 L
.18537 .44772 L
.18551 .44798 L
.18564 .44824 L
.18577 .4485 L
.18591 .44875 L
.18604 .44901 L
.18617 .44926 L
.1863 .44952 L
.18644 .44977 L
.18657 .45002 L
.1867 .45028 L
.18684 .45053 L
.18697 .45078 L
.1871 .45103 L
.18723 .45128 L
.18737 .45153 L
.1875 .45177 L
.18763 .45202 L
.18777 .45227 L
.1879 .45252 L
.18803 .45276 L
.18816 .45301 L
.1883 .45325 L
.18843 .4535 L
.18856 .45374 L
.1887 .45398 L
.18883 .45423 L
.18896 .45447 L
.18909 .45471 L
.18923 .45496 L
.18936 .4552 L
.18949 .45544 L
.18963 .45568 L
.18976 .45592 L
.18989 .45617 L
.19002 .45641 L
.19016 .45665 L
.19029 .45689 L
.19042 .45713 L
.19056 .45737 L
.19069 .4576 L
.19082 .45784 L
.19095 .45808 L
.19109 .45832 L
.19122 .45856 L
.19135 .45879 L
.19149 .45903 L
.19162 .45927 L
Mistroke
.19175 .4595 L
.19188 .45973 L
.19202 .45997 L
.19215 .4602 L
.19228 .46043 L
.19242 .46066 L
.19255 .46089 L
.19268 .46112 L
.19281 .46135 L
.19295 .46158 L
.19308 .46181 L
.19321 .46204 L
.19335 .46227 L
.19348 .4625 L
.19361 .46273 L
.19374 .46296 L
.19388 .46319 L
.19401 .46342 L
.19414 .46364 L
.19428 .46387 L
.19441 .4641 L
.19454 .46432 L
.19467 .46455 L
.19481 .46477 L
.19494 .46499 L
.19507 .46522 L
.19521 .46544 L
.19534 .46566 L
.19547 .46588 L
.1956 .4661 L
.19574 .46632 L
.19587 .46654 L
.196 .46676 L
.19614 .46698 L
.19627 .4672 L
.1964 .46741 L
.19653 .46763 L
.19667 .46785 L
.1968 .46806 L
.19693 .46828 L
.19707 .4685 L
.1972 .46871 L
.19733 .46892 L
.19746 .46914 L
.1976 .46935 L
.19773 .46956 L
.19786 .46978 L
.198 .46999 L
.19813 .4702 L
.19826 .47041 L
Mistroke
.19839 .47062 L
.19853 .47083 L
.19866 .47103 L
.19879 .47124 L
.19893 .47145 L
.19906 .47166 L
.19919 .47186 L
.19933 .47207 L
.19946 .47228 L
.19959 .47248 L
.19972 .47269 L
.19986 .4729 L
.19999 .4731 L
.20012 .47331 L
.20026 .47351 L
.20039 .47372 L
.20052 .47392 L
.20065 .47413 L
.20079 .47433 L
.20092 .47453 L
.20105 .47474 L
.20119 .47494 L
.20132 .47514 L
.20145 .47534 L
.20158 .47555 L
.20172 .47575 L
.20185 .47595 L
.20198 .47615 L
.20212 .47635 L
.20225 .47655 L
.20238 .47675 L
.20251 .47695 L
.20265 .47715 L
.20278 .47735 L
.20291 .47755 L
.20305 .47774 L
.20318 .47794 L
.20331 .47813 L
.20344 .47833 L
.20358 .47852 L
.20371 .47871 L
.20384 .47891 L
.20398 .4791 L
.20411 .4793 L
.20424 .47949 L
.20437 .47968 L
.20451 .47987 L
.20464 .48007 L
.20477 .48026 L
.20491 .48045 L
Mistroke
.20504 .48064 L
.20517 .48083 L
.2053 .48102 L
.20544 .48121 L
.20557 .4814 L
.2057 .48158 L
.20584 .48177 L
.20597 .48196 L
.2061 .48214 L
.20623 .48233 L
.20637 .48251 L
.2065 .4827 L
.20663 .48289 L
.20677 .48307 L
.2069 .48326 L
.20703 .48344 L
.20716 .48362 L
.2073 .48381 L
.20743 .48399 L
.20756 .48417 L
.2077 .48435 L
.20783 .48453 L
.20796 .48471 L
.20809 .48489 L
.20823 .48507 L
.20836 .48525 L
.20849 .48543 L
.20863 .48561 L
.20876 .48579 L
.20889 .48597 L
.20902 .48615 L
.20916 .48633 L
.20929 .48651 L
.20942 .48668 L
.20956 .48686 L
.20969 .48704 L
.20982 .48722 L
.20995 .48739 L
.21009 .48757 L
.21022 .48775 L
.21035 .48793 L
.21049 .4881 L
.21062 .48828 L
.21075 .48845 L
.21088 .48863 L
.21102 .4888 L
.21115 .48898 L
.21128 .48915 L
.21142 .48932 L
.21155 .4895 L
Mistroke
.21168 .48967 L
.21181 .48984 L
.21195 .49002 L
.21208 .49019 L
.21221 .49036 L
.21235 .49053 L
.21248 .4907 L
.21261 .49087 L
.21274 .49105 L
.21288 .49122 L
.21301 .49139 L
.21314 .49156 L
.21328 .49173 L
.21341 .4919 L
.21354 .49207 L
.21367 .49224 L
.21381 .4924 L
.21394 .49257 L
.21407 .49274 L
.21421 .49291 L
.21434 .49308 L
.21447 .49324 L
.2146 .49341 L
.21474 .49357 L
.21487 .49374 L
.215 .49391 L
.21514 .49407 L
.21527 .49424 L
.2154 .4944 L
.21553 .49457 L
.21567 .49473 L
.2158 .49489 L
.21593 .49506 L
.21607 .49522 L
.2162 .49538 L
.21633 .49555 L
.21646 .49571 L
.2166 .49587 L
.21673 .49603 L
.21686 .49619 L
.217 .49635 L
.21713 .49651 L
.21726 .49667 L
.21739 .49683 L
.21753 .49699 L
.21766 .49714 L
.21779 .4973 L
.21793 .49746 L
.21806 .49762 L
.21819 .49778 L
Mistroke
.21832 .49793 L
.21846 .49809 L
.21859 .49825 L
.21872 .4984 L
.21886 .49856 L
.21899 .49872 L
.21912 .49887 L
.21925 .49903 L
.21939 .49918 L
.21952 .49934 L
.21965 .49949 L
.21979 .49965 L
.21992 .4998 L
.22005 .49996 L
.22018 .50011 L
.22032 .50026 L
.22045 .50042 L
.22058 .50057 L
.22072 .50072 L
.22085 .50088 L
.22098 .50103 L
.22112 .50118 L
.22125 .50133 L
.22138 .50149 L
.22151 .50164 L
.22165 .50179 L
.22178 .50194 L
.22191 .50209 L
.22205 .50224 L
.22218 .50239 L
.22231 .50254 L
.22244 .50269 L
.22258 .50284 L
.22271 .50299 L
.22284 .50314 L
.22298 .50329 L
.22311 .50344 L
.22324 .50359 L
.22337 .50373 L
.22351 .50388 L
.22364 .50403 L
.22377 .50417 L
.22391 .50432 L
.22404 .50447 L
.22417 .50461 L
.2243 .50476 L
.22444 .5049 L
.22457 .50505 L
.2247 .50519 L
.22484 .50534 L
Mistroke
.22497 .50548 L
.2251 .50563 L
.22523 .50577 L
.22537 .50592 L
.2255 .50606 L
.22563 .5062 L
.22577 .50635 L
.2259 .50649 L
.22603 .50663 L
.22616 .50677 L
.2263 .50691 L
.22643 .50705 L
.22656 .5072 L
.2267 .50734 L
.22683 .50748 L
.22696 .50762 L
.22709 .50775 L
.22723 .50789 L
.22736 .50803 L
.22749 .50817 L
.22763 .50831 L
.22776 .50845 L
.22789 .50858 L
.22802 .50872 L
.22816 .50886 L
.22829 .509 L
.22842 .50913 L
.22856 .50927 L
.22869 .50941 L
.22882 .50954 L
.22895 .50968 L
.22909 .50982 L
.22922 .50995 L
.22935 .51009 L
.22949 .51022 L
.22962 .51036 L
.22975 .51049 L
.22988 .51063 L
.23002 .51076 L
.23015 .5109 L
.23028 .51103 L
.23042 .51116 L
.23055 .5113 L
.23068 .51143 L
.23081 .51156 L
.23095 .5117 L
.23108 .51183 L
.23121 .51196 L
.23135 .51209 L
.23148 .51222 L
Mistroke
.23161 .51235 L
.23174 .51249 L
.23188 .51262 L
.23201 .51275 L
.23214 .51288 L
.23228 .51301 L
.23241 .51314 L
.23254 .51327 L
.23267 .5134 L
.23281 .51353 L
.23294 .51366 L
.23307 .51379 L
.23321 .51392 L
.23334 .51405 L
.23347 .51418 L
.2336 .51431 L
.23374 .51443 L
.23387 .51456 L
.234 .51469 L
.23414 .51482 L
.23427 .51494 L
.2344 .51507 L
.23453 .5152 L
.23467 .51533 L
.2348 .51545 L
.23493 .51558 L
.23507 .51571 L
.2352 .51583 L
.23533 .51596 L
.23546 .51608 L
.2356 .51621 L
.23573 .51634 L
.23586 .51646 L
.236 .51659 L
.23613 .51671 L
.23626 .51684 L
.23639 .51696 L
.23653 .51709 L
.23666 .51721 L
.23679 .51734 L
.23693 .51746 L
.23706 .51758 L
.23719 .51771 L
.23732 .51783 L
.23746 .51796 L
.23759 .51808 L
.23772 .5182 L
.23786 .51833 L
.23799 .51845 L
.23812 .51857 L
Mistroke
.23825 .5187 L
.23839 .51882 L
.23852 .51894 L
.23865 .51906 L
.23879 .51919 L
.23892 .51931 L
.23905 .51943 L
.23918 .51955 L
.23932 .51968 L
.23945 .5198 L
.23958 .51992 L
.23972 .52004 L
.23985 .52016 L
.23998 .52028 L
.24011 .5204 L
.24025 .52052 L
.24038 .52064 L
.24051 .52076 L
.24065 .52088 L
.24078 .521 L
.24091 .52112 L
.24104 .52124 L
.24118 .52136 L
.24131 .52148 L
.24144 .5216 L
.24158 .52171 L
.24171 .52183 L
.24184 .52195 L
.24197 .52207 L
.24211 .52218 L
.24224 .5223 L
.24237 .52242 L
.24251 .52254 L
.24264 .52265 L
.24277 .52277 L
.2429 .52289 L
.24304 .523 L
.24317 .52312 L
.2433 .52324 L
.24344 .52335 L
.24357 .52347 L
.2437 .52358 L
.24384 .5237 L
.24397 .52381 L
.2441 .52393 L
.24423 .52404 L
.24437 .52415 L
.2445 .52427 L
.24463 .52438 L
.24477 .52449 L
Mistroke
.2449 .52461 L
.24503 .52472 L
.24516 .52483 L
.2453 .52494 L
.24543 .52506 L
.24556 .52517 L
.2457 .52528 L
.24583 .52539 L
.24596 .5255 L
.24609 .52562 L
.24623 .52573 L
.24636 .52584 L
.24649 .52595 L
.24663 .52606 L
.24676 .52617 L
.24689 .52628 L
.24702 .52639 L
.24716 .5265 L
.24729 .52661 L
.24742 .52672 L
.24756 .52684 L
.24769 .52695 L
.24782 .52706 L
.24795 .52717 L
.24809 .52728 L
.24822 .52738 L
.24835 .52749 L
.24849 .5276 L
.24862 .52771 L
.24875 .52782 L
.24888 .52793 L
.24902 .52804 L
.24915 .52815 L
.24928 .52825 L
.24942 .52836 L
.24955 .52847 L
.24968 .52858 L
.24981 .52868 L
.24995 .52879 L
.25008 .52889 L
.25021 .529 L
.25035 .52911 L
.25048 .52921 L
.25061 .52932 L
.25074 .52942 L
.25088 .52953 L
.25101 .52963 L
.25114 .52974 L
.25128 .52984 L
.25141 .52994 L
Mistroke
.25154 .53005 L
.25167 .53015 L
.25181 .53026 L
.25194 .53036 L
.25207 .53047 L
.25221 .53057 L
.25234 .53067 L
.25247 .53078 L
.2526 .53088 L
.25274 .53098 L
.25287 .53109 L
.253 .53119 L
.25314 .53129 L
.25327 .53139 L
.2534 .5315 L
.25353 .5316 L
.25367 .5317 L
.2538 .5318 L
.25393 .53191 L
.25407 .53201 L
.2542 .53211 L
.25433 .53221 L
.25446 .53231 L
.2546 .53241 L
.25473 .53251 L
.25486 .53261 L
.255 .53271 L
.25513 .53281 L
.25526 .53291 L
.25539 .53301 L
.25553 .53311 L
.25566 .53321 L
.25579 .53331 L
.25593 .53341 L
.25606 .53351 L
.25619 .53361 L
.25632 .53371 L
.25646 .53381 L
.25659 .5339 L
.25672 .534 L
.25686 .5341 L
.25699 .5342 L
.25712 .5343 L
.25725 .5344 L
.25739 .53449 L
.25752 .53459 L
.25765 .53469 L
.25779 .53478 L
.25792 .53488 L
.25805 .53498 L
Mistroke
.25818 .53508 L
.25832 .53517 L
.25845 .53527 L
.25858 .53536 L
.25872 .53546 L
.25885 .53556 L
.25898 .53565 L
.25911 .53575 L
.25925 .53584 L
.25938 .53594 L
.25951 .53604 L
.25965 .53613 L
.25978 .53623 L
.25991 .53632 L
.26004 .53642 L
.26018 .53651 L
.26031 .53661 L
.26044 .5367 L
.26058 .5368 L
.26071 .53689 L
.26084 .53698 L
.26097 .53708 L
.26111 .53717 L
.26124 .53726 L
.26137 .53736 L
.26151 .53745 L
.26164 .53754 L
.26177 .53763 L
.2619 .53773 L
.26204 .53782 L
.26217 .53791 L
.2623 .538 L
.26244 .5381 L
.26257 .53819 L
.2627 .53828 L
.26283 .53837 L
.26297 .53846 L
.2631 .53855 L
.26323 .53864 L
.26337 .53874 L
.2635 .53883 L
.26363 .53892 L
.26376 .53901 L
.2639 .5391 L
.26403 .53919 L
.26416 .53928 L
.2643 .53937 L
.26443 .53946 L
.26456 .53955 L
.26469 .53964 L
Mistroke
.26483 .53973 L
.26496 .53982 L
.26509 .53991 L
.26523 .54 L
.26536 .54009 L
.26549 .54018 L
.26562 .54027 L
.26576 .54036 L
.26589 .54045 L
.26602 .54054 L
.26616 .54063 L
.26629 .54071 L
.26642 .5408 L
.26656 .54089 L
.26669 .54098 L
.26682 .54107 L
.26695 .54115 L
.26709 .54124 L
.26722 .54133 L
.26735 .54142 L
.26749 .5415 L
.26762 .54159 L
.26775 .54168 L
.26788 .54176 L
.26802 .54185 L
.26815 .54193 L
.26828 .54202 L
.26842 .5421 L
.26855 .54219 L
.26868 .54227 L
.26881 .54236 L
.26895 .54244 L
.26908 .54253 L
.26921 .54261 L
.26935 .5427 L
.26948 .54278 L
.26961 .54286 L
.26974 .54295 L
.26988 .54303 L
.27001 .54311 L
.27014 .5432 L
.27028 .54328 L
.27041 .54336 L
.27054 .54344 L
.27067 .54353 L
.27081 .54361 L
.27094 .54369 L
.27107 .54377 L
.27121 .54386 L
.27134 .54394 L
Mistroke
.27147 .54402 L
.2716 .5441 L
.27174 .54418 L
.27187 .54426 L
.272 .54434 L
.27214 .54442 L
.27227 .5445 L
.2724 .54458 L
.27253 .54466 L
.27267 .54474 L
.2728 .54482 L
.27293 .5449 L
.27307 .54498 L
.2732 .54506 L
.27333 .54514 L
.27346 .54522 L
.2736 .5453 L
.27373 .54538 L
.27386 .54545 L
.274 .54553 L
.27413 .54561 L
.27426 .54569 L
.27439 .54576 L
.27453 .54584 L
.27466 .54592 L
.27479 .546 L
.27493 .54607 L
.27506 .54615 L
.27519 .54623 L
.27532 .54631 L
.27546 .54638 L
.27559 .54646 L
.27572 .54654 L
.27586 .54661 L
.27599 .54669 L
.27612 .54676 L
.27625 .54684 L
.27639 .54692 L
.27652 .54699 L
.27665 .54707 L
.27679 .54714 L
.27692 .54722 L
.27705 .54729 L
.27718 .54737 L
.27732 .54744 L
.27745 .54752 L
.27758 .54759 L
.27772 .54767 L
.27785 .54774 L
.27798 .54782 L
Mistroke
.27811 .54789 L
.27825 .54797 L
.27838 .54804 L
.27851 .54811 L
.27865 .54819 L
.27878 .54826 L
.27891 .54834 L
.27904 .54841 L
.27918 .54848 L
.27931 .54856 L
.27944 .54863 L
.27958 .5487 L
.27971 .54878 L
.27984 .54885 L
.27997 .54892 L
.28011 .549 L
.28024 .54907 L
.28037 .54914 L
.28051 .54922 L
.28064 .54929 L
.28077 .54936 L
.2809 .54943 L
.28104 .5495 L
.28117 .54958 L
.2813 .54965 L
.28144 .54972 L
.28157 .54979 L
.2817 .54986 L
.28183 .54994 L
.28197 .55001 L
.2821 .55008 L
.28223 .55015 L
.28237 .55022 L
.2825 .55029 L
.28263 .55036 L
.28276 .55043 L
.2829 .55051 L
.28303 .55058 L
.28316 .55065 L
.2833 .55072 L
.28343 .55079 L
.28356 .55086 L
.28369 .55093 L
.28383 .551 L
.28396 .55107 L
.28409 .55114 L
.28423 .55121 L
.28436 .55128 L
.28449 .55135 L
.28462 .55141 L
Mistroke
.28476 .55148 L
.28489 .55155 L
.28502 .55162 L
.28516 .55169 L
.28529 .55176 L
.28542 .55183 L
.28555 .55189 L
.28569 .55196 L
.28582 .55203 L
.28595 .5521 L
.28609 .55216 L
.28622 .55223 L
.28635 .5523 L
.28648 .55236 L
.28662 .55243 L
.28675 .5525 L
.28688 .55256 L
.28702 .55263 L
.28715 .5527 L
.28728 .55276 L
.28741 .55283 L
.28755 .55289 L
.28768 .55296 L
.28781 .55302 L
.28795 .55309 L
.28808 .55316 L
.28821 .55322 L
.28835 .55329 L
.28848 .55335 L
.28861 .55342 L
.28874 .55348 L
.28888 .55355 L
.28901 .55361 L
.28914 .55367 L
.28928 .55374 L
.28941 .5538 L
.28954 .55387 L
.28967 .55393 L
.28981 .55399 L
.28994 .55406 L
.29007 .55412 L
.29021 .55419 L
.29034 .55425 L
.29047 .55431 L
.2906 .55438 L
.29074 .55444 L
.29087 .5545 L
.291 .55457 L
.29114 .55463 L
.29127 .55469 L
Mistroke
.2914 .55475 L
.29153 .55482 L
.29167 .55488 L
.2918 .55494 L
.29193 .555 L
.29207 .55507 L
.2922 .55513 L
.29233 .55519 L
.29246 .55525 L
.2926 .55532 L
.29273 .55538 L
.29286 .55544 L
.293 .5555 L
.29313 .55557 L
.29326 .55563 L
.29339 .55569 L
.29353 .55575 L
.29366 .55581 L
.29379 .55587 L
.29393 .55594 L
.29406 .556 L
.29419 .55606 L
.29432 .55612 L
.29446 .55618 L
.29459 .55624 L
.29472 .5563 L
.29486 .55637 L
.29499 .55643 L
.29512 .55649 L
.29525 .55655 L
.29539 .55661 L
.29552 .55667 L
.29565 .55673 L
.29579 .55679 L
.29592 .55685 L
.29605 .55691 L
.29618 .55697 L
.29632 .55703 L
.29645 .55709 L
.29658 .55715 L
.29672 .55721 L
.29685 .55727 L
.29698 .55733 L
.29711 .55739 L
.29725 .55745 L
.29738 .55751 L
.29751 .55757 L
.29765 .55763 L
.29778 .55769 L
.29791 .55775 L
Mistroke
.29804 .5578 L
.29818 .55786 L
.29831 .55792 L
.29844 .55798 L
.29858 .55804 L
.29871 .5581 L
.29884 .55815 L
.29897 .55821 L
.29911 .55827 L
.29924 .55833 L
.29937 .55839 L
.29951 .55844 L
.29964 .5585 L
.29977 .55856 L
.2999 .55862 L
.30004 .55868 L
.30017 .55873 L
.3003 .55879 L
.30044 .55885 L
.30057 .5589 L
.3007 .55896 L
.30083 .55902 L
.30097 .55907 L
.3011 .55913 L
.30123 .55919 L
.30137 .55924 L
.3015 .5593 L
.30163 .55936 L
.30176 .55941 L
.3019 .55947 L
.30203 .55952 L
.30216 .55958 L
.3023 .55964 L
.30243 .55969 L
.30256 .55975 L
.30269 .5598 L
.30283 .55986 L
.30296 .55991 L
.30309 .55997 L
.30323 .56002 L
.30336 .56008 L
.30349 .56013 L
.30362 .56019 L
.30376 .56024 L
.30389 .5603 L
.30402 .56035 L
.30416 .56041 L
.30429 .56046 L
.30442 .56052 L
.30455 .56057 L
Mistroke
.30469 .56063 L
.30482 .56068 L
.30495 .56074 L
.30509 .56079 L
.30522 .56085 L
.30535 .5609 L
.30548 .56096 L
.30562 .56101 L
.30575 .56106 L
.30588 .56112 L
.30602 .56117 L
.30615 .56123 L
.30628 .56128 L
.30641 .56133 L
.30655 .56139 L
.30668 .56144 L
.30681 .5615 L
.30695 .56155 L
.30708 .5616 L
.30721 .56166 L
.30734 .56171 L
.30748 .56177 L
.30761 .56182 L
.30774 .56187 L
.30788 .56193 L
.30801 .56198 L
.30814 .56203 L
.30827 .56209 L
.30841 .56214 L
.30854 .56219 L
.30867 .56225 L
.30881 .5623 L
.30894 .56235 L
.30907 .5624 L
.3092 .56246 L
.30934 .56251 L
.30947 .56256 L
.3096 .56261 L
.30974 .56267 L
.30987 .56272 L
.31 .56277 L
.31013 .56282 L
.31027 .56288 L
.3104 .56293 L
.31053 .56298 L
.31067 .56303 L
.3108 .56309 L
.31093 .56314 L
.31107 .56319 L
.3112 .56324 L
Mistroke
.31133 .56329 L
.31146 .56334 L
.3116 .5634 L
.31173 .56345 L
.31186 .5635 L
.312 .56355 L
.31213 .5636 L
.31226 .56365 L
.31239 .5637 L
.31253 .56375 L
.31266 .56381 L
.31279 .56386 L
.31293 .56391 L
.31306 .56396 L
.31319 .56401 L
.31332 .56406 L
.31346 .56411 L
.31359 .56416 L
.31372 .56421 L
.31386 .56426 L
.31399 .56431 L
.31412 .56436 L
.31425 .56441 L
.31439 .56446 L
.31452 .56451 L
.31465 .56456 L
.31479 .56461 L
.31492 .56466 L
.31505 .56471 L
.31518 .56476 L
.31532 .56481 L
.31545 .56486 L
.31558 .56491 L
.31572 .56496 L
.31585 .56501 L
.31598 .56506 L
.31611 .5651 L
.31625 .56515 L
.31638 .5652 L
.31651 .56525 L
.31665 .5653 L
.31678 .56535 L
.31691 .5654 L
.31704 .56545 L
.31718 .56549 L
.31731 .56554 L
.31744 .56559 L
.31758 .56564 L
.31771 .56569 L
.31784 .56574 L
Mistroke
.31797 .56579 L
.31811 .56583 L
.31824 .56588 L
.31837 .56593 L
.31851 .56598 L
.31864 .56603 L
.31877 .56607 L
.3189 .56612 L
.31904 .56617 L
.31917 .56622 L
.3193 .56627 L
.31944 .56631 L
.31957 .56636 L
.3197 .56641 L
.31983 .56646 L
.31997 .5665 L
.3201 .56655 L
.32023 .5666 L
.32037 .56664 L
.3205 .56669 L
.32063 .56674 L
.32076 .56678 L
.3209 .56683 L
.32103 .56688 L
.32116 .56692 L
.3213 .56697 L
.32143 .56702 L
.32156 .56706 L
.32169 .56711 L
.32183 .56716 L
.32196 .5672 L
.32209 .56725 L
.32223 .5673 L
.32236 .56734 L
.32249 .56739 L
.32262 .56743 L
.32276 .56748 L
.32289 .56753 L
.32302 .56757 L
.32316 .56762 L
.32329 .56766 L
.32342 .56771 L
.32355 .56775 L
.32369 .5678 L
.32382 .56784 L
.32395 .56789 L
.32409 .56793 L
.32422 .56798 L
.32435 .56802 L
.32448 .56807 L
Mistroke
.32462 .56811 L
.32475 .56816 L
.32488 .5682 L
.32502 .56825 L
.32515 .56829 L
.32528 .56834 L
.32541 .56838 L
.32555 .56843 L
.32568 .56847 L
.32581 .56852 L
.32595 .56856 L
.32608 .56861 L
.32621 .56865 L
.32634 .56869 L
.32648 .56874 L
.32661 .56878 L
.32674 .56883 L
.32688 .56887 L
.32701 .56892 L
.32714 .56896 L
.32727 .569 L
.32741 .56905 L
.32754 .56909 L
.32767 .56913 L
.32781 .56918 L
.32794 .56922 L
.32807 .56927 L
.3282 .56931 L
.32834 .56935 L
.32847 .5694 L
.3286 .56944 L
.32874 .56948 L
.32887 .56953 L
.329 .56957 L
.32913 .56961 L
.32927 .56966 L
.3294 .5697 L
.32953 .56974 L
.32967 .56978 L
.3298 .56983 L
.32993 .56987 L
.33006 .56991 L
.3302 .56995 L
.33033 .57 L
.33046 .57004 L
.3306 .57008 L
.33073 .57012 L
.33086 .57017 L
.33099 .57021 L
.33113 .57025 L
Mistroke
.33126 .57029 L
.33139 .57034 L
.33153 .57038 L
.33166 .57042 L
.33179 .57046 L
.33192 .5705 L
.33206 .57054 L
.33219 .57059 L
.33232 .57063 L
.33246 .57067 L
.33259 .57071 L
.33272 .57075 L
.33286 .57079 L
.33299 .57083 L
.33312 .57087 L
.33325 .57092 L
.33339 .57096 L
.33352 .571 L
.33365 .57104 L
.33379 .57108 L
.33392 .57112 L
.33405 .57116 L
.33418 .5712 L
.33432 .57124 L
.33445 .57128 L
.33458 .57132 L
.33472 .57136 L
.33485 .5714 L
.33498 .57144 L
.33511 .57148 L
.33525 .57152 L
.33538 .57156 L
.33551 .5716 L
.33565 .57164 L
.33578 .57168 L
.33591 .57172 L
.33604 .57176 L
.33618 .5718 L
.33631 .57184 L
.33644 .57188 L
.33658 .57192 L
.33671 .57196 L
.33684 .572 L
.33697 .57204 L
.33711 .57208 L
.33724 .57211 L
.33737 .57215 L
.33751 .57219 L
.33764 .57223 L
.33777 .57227 L
Mistroke
.3379 .57231 L
.33804 .57235 L
.33817 .57239 L
.3383 .57243 L
.33844 .57247 L
.33857 .5725 L
.3387 .57254 L
.33883 .57258 L
.33897 .57262 L
.3391 .57266 L
.33923 .5727 L
.33937 .57274 L
.3395 .57277 L
.33963 .57281 L
.33976 .57285 L
.3399 .57289 L
.34003 .57293 L
.34016 .57297 L
.3403 .573 L
.34043 .57304 L
.34056 .57308 L
.34069 .57312 L
.34083 .57316 L
.34096 .57319 L
.34109 .57323 L
.34123 .57327 L
.34136 .57331 L
.34149 .57335 L
.34162 .57338 L
.34176 .57342 L
.34189 .57346 L
.34202 .5735 L
.34216 .57353 L
.34229 .57357 L
.34242 .57361 L
.34255 .57365 L
.34269 .57368 L
.34282 .57372 L
.34295 .57376 L
.34309 .5738 L
.34322 .57383 L
.34335 .57387 L
.34348 .57391 L
.34362 .57395 L
.34375 .57398 L
.34388 .57402 L
.34402 .57406 L
.34415 .57409 L
.34428 .57413 L
.34441 .57417 L
Mistroke
.34455 .57421 L
.34468 .57424 L
.34481 .57428 L
.34495 .57432 L
.34508 .57435 L
.34521 .57439 L
.34534 .57442 L
.34548 .57446 L
.34561 .5745 L
.34574 .57453 L
.34588 .57457 L
.34601 .5746 L
.34614 .57464 L
.34627 .57468 L
.34641 .57471 L
.34654 .57475 L
.34667 .57478 L
.34681 .57482 L
.34694 .57485 L
.34707 .57489 L
.3472 .57493 L
.34734 .57496 L
.34747 .575 L
.3476 .57503 L
.34774 .57507 L
.34787 .5751 L
.348 .57514 L
.34813 .57517 L
.34827 .57521 L
.3484 .57524 L
.34853 .57528 L
.34867 .57531 L
.3488 .57535 L
.34893 .57539 L
.34906 .57542 L
.3492 .57546 L
.34933 .57549 L
.34946 .57552 L
.3496 .57556 L
.34973 .57559 L
.34986 .57563 L
.34999 .57566 L
.35013 .5757 L
.35026 .57573 L
.35039 .57577 L
.35053 .5758 L
.35066 .57584 L
.35079 .57587 L
.35092 .5759 L
.35106 .57594 L
Mistroke
.35119 .57597 L
.35132 .57601 L
.35146 .57604 L
.35159 .57608 L
.35172 .57611 L
.35185 .57614 L
.35199 .57618 L
.35212 .57621 L
.35225 .57625 L
.35239 .57628 L
.35252 .57631 L
.35265 .57635 L
.35278 .57638 L
.35292 .57642 L
.35305 .57645 L
.35318 .57648 L
.35332 .57652 L
.35345 .57655 L
.35358 .57658 L
.35371 .57662 L
.35385 .57665 L
.35398 .57669 L
.35411 .57672 L
.35425 .57675 L
.35438 .57679 L
.35451 .57682 L
.35464 .57685 L
.35478 .57689 L
.35491 .57692 L
.35504 .57695 L
.35518 .57699 L
.35531 .57702 L
.35544 .57706 L
.35558 .57709 L
.35571 .57712 L
.35584 .57716 L
.35597 .57719 L
.35611 .57722 L
.35624 .57726 L
.35637 .57729 L
.35651 .57732 L
.35664 .57736 L
.35677 .57739 L
.3569 .57742 L
.35704 .57745 L
.35717 .57749 L
.3573 .57752 L
.35744 .57755 L
.35757 .57759 L
.3577 .57762 L
Mistroke
.35783 .57765 L
.35797 .57769 L
.3581 .57772 L
.35823 .57775 L
.35837 .57778 L
.3585 .57782 L
.35863 .57785 L
.35876 .57788 L
.3589 .57791 L
.35903 .57795 L
.35916 .57798 L
.3593 .57801 L
.35943 .57804 L
.35956 .57808 L
.35969 .57811 L
.35983 .57814 L
.35996 .57817 L
.36009 .5782 L
.36023 .57824 L
.36036 .57827 L
.36049 .5783 L
.36062 .57833 L
.36076 .57836 L
.36089 .5784 L
.36102 .57843 L
.36116 .57846 L
.36129 .57849 L
.36142 .57852 L
.36155 .57855 L
.36169 .57859 L
.36182 .57862 L
.36195 .57865 L
.36209 .57868 L
.36222 .57871 L
.36235 .57874 L
.36248 .57877 L
.36262 .5788 L
.36275 .57884 L
.36288 .57887 L
.36302 .5789 L
.36315 .57893 L
.36328 .57896 L
.36341 .57899 L
.36355 .57902 L
.36368 .57905 L
.36381 .57908 L
.36395 .57911 L
.36408 .57915 L
.36421 .57918 L
.36434 .57921 L
Mistroke
.36448 .57924 L
.36461 .57927 L
.36474 .5793 L
.36488 .57933 L
.36501 .57936 L
.36514 .57939 L
.36527 .57942 L
.36541 .57945 L
.36554 .57948 L
.36567 .57951 L
.36581 .57954 L
.36594 .57957 L
.36607 .5796 L
.3662 .57963 L
.36634 .57966 L
.36647 .57969 L
.3666 .57972 L
.36674 .57975 L
.36687 .57978 L
.367 .57981 L
.36713 .57984 L
.36727 .57987 L
.3674 .5799 L
.36753 .57993 L
.36767 .57996 L
.3678 .57999 L
.36793 .58002 L
.36806 .58005 L
.3682 .58008 L
.36833 .58011 L
.36846 .58014 L
.3686 .58017 L
.36873 .5802 L
.36886 .58023 L
.36899 .58026 L
.36913 .58029 L
.36926 .58032 L
.36939 .58035 L
.36953 .58038 L
.36966 .58041 L
.36979 .58044 L
.36992 .58046 L
.37006 .58049 L
.37019 .58052 L
.37032 .58055 L
.37046 .58058 L
.37059 .58061 L
.37072 .58064 L
.37085 .58067 L
.37099 .5807 L
Mistroke
.37112 .58073 L
.37125 .58076 L
.37139 .58078 L
.37152 .58081 L
.37165 .58084 L
.37178 .58087 L
.37192 .5809 L
.37205 .58093 L
.37218 .58096 L
.37232 .58099 L
.37245 .58101 L
.37258 .58104 L
.37271 .58107 L
.37285 .5811 L
.37298 .58113 L
.37311 .58116 L
.37325 .58119 L
.37338 .58121 L
.37351 .58124 L
.37364 .58127 L
.37378 .5813 L
.37391 .58133 L
.37404 .58136 L
.37418 .58138 L
.37431 .58141 L
.37444 .58144 L
.37457 .58147 L
.37471 .5815 L
.37484 .58153 L
.37497 .58155 L
.37511 .58158 L
.37524 .58161 L
.37537 .58164 L
.3755 .58166 L
.37564 .58169 L
.37577 .58172 L
.3759 .58175 L
.37604 .58178 L
.37617 .5818 L
.3763 .58183 L
.37643 .58186 L
.37657 .58189 L
.3767 .58191 L
.37683 .58194 L
.37697 .58197 L
.3771 .58199 L
.37723 .58202 L
.37737 .58205 L
.3775 .58208 L
.37763 .5821 L
Mistroke
.37776 .58213 L
.3779 .58216 L
.37803 .58218 L
.37816 .58221 L
.3783 .58224 L
.37843 .58226 L
.37856 .58229 L
.37869 .58232 L
.37883 .58234 L
.37896 .58237 L
.37909 .5824 L
.37923 .58242 L
.37936 .58245 L
.37949 .58248 L
.37962 .5825 L
.37976 .58253 L
.37989 .58256 L
.38002 .58258 L
.38016 .58261 L
.38029 .58264 L
.38042 .58266 L
.38055 .58269 L
.38069 .58271 L
.38082 .58274 L
.38095 .58277 L
.38109 .58279 L
.38122 .58282 L
.38135 .58285 L
.38148 .58287 L
.38162 .5829 L
.38175 .58292 L
.38188 .58295 L
.38202 .58298 L
.38215 .583 L
.38228 .58303 L
.38241 .58305 L
.38255 .58308 L
.38268 .5831 L
.38281 .58313 L
.38295 .58315 L
.38308 .58318 L
.38321 .5832 L
.38334 .58323 L
.38348 .58326 L
.38361 .58328 L
.38374 .58331 L
.38388 .58333 L
.38401 .58336 L
.38414 .58338 L
.38427 .58341 L
Mistroke
.38441 .58343 L
.38454 .58346 L
.38467 .58348 L
.38481 .58351 L
.38494 .58353 L
.38507 .58356 L
.3852 .58358 L
.38534 .58361 L
.38547 .58363 L
.3856 .58365 L
.38574 .58368 L
.38587 .5837 L
.386 .58373 L
.38613 .58375 L
.38627 .58378 L
.3864 .5838 L
.38653 .58383 L
.38667 .58385 L
.3868 .58388 L
.38693 .5839 L
.38706 .58392 L
.3872 .58395 L
.38733 .58397 L
.38746 .584 L
.3876 .58402 L
.38773 .58405 L
.38786 .58407 L
.38799 .58409 L
.38813 .58412 L
.38826 .58414 L
.38839 .58417 L
.38853 .58419 L
.38866 .58421 L
.38879 .58424 L
.38892 .58426 L
.38906 .58429 L
.38919 .58431 L
.38932 .58433 L
.38946 .58436 L
.38959 .58438 L
.38972 .5844 L
.38985 .58443 L
.38999 .58445 L
.39012 .58447 L
.39025 .5845 L
.39039 .58452 L
.39052 .58455 L
.39065 .58457 L
.39078 .58459 L
.39092 .58462 L
Mistroke
.39105 .58464 L
.39118 .58466 L
.39132 .58469 L
.39145 .58471 L
.39158 .58473 L
.39171 .58476 L
.39185 .58478 L
.39198 .5848 L
.39211 .58482 L
.39225 .58485 L
.39238 .58487 L
.39251 .58489 L
.39264 .58492 L
.39278 .58494 L
.39291 .58496 L
.39304 .58499 L
.39318 .58501 L
.39331 .58503 L
.39344 .58505 L
.39357 .58508 L
.39371 .5851 L
.39384 .58512 L
.39397 .58515 L
.39411 .58517 L
.39424 .58519 L
.39437 .58521 L
.3945 .58524 L
.39464 .58526 L
.39477 .58528 L
.3949 .5853 L
.39504 .58532 L
.39517 .58535 L
.3953 .58537 L
.39543 .58539 L
.39557 .58541 L
.3957 .58544 L
.39583 .58546 L
.39597 .58548 L
.3961 .5855 L
.39623 .58552 L
.39636 .58555 L
.3965 .58557 L
.39663 .58559 L
.39676 .58561 L
.3969 .58563 L
.39703 .58566 L
.39716 .58568 L
.39729 .5857 L
.39743 .58572 L
.39756 .58574 L
Mistroke
.39769 .58577 L
.39783 .58579 L
.39796 .58581 L
.39809 .58583 L
.39822 .58585 L
.39836 .58588 L
.39849 .5859 L
.39862 .58592 L
.39876 .58594 L
.39889 .58596 L
.39902 .58598 L
.39915 .58601 L
.39929 .58603 L
.39942 .58605 L
.39955 .58607 L
.39969 .58609 L
.39982 .58611 L
.39995 .58613 L
.40009 .58616 L
.40022 .58618 L
.40035 .5862 L
.40048 .58622 L
.40062 .58624 L
.40075 .58626 L
.40088 .58628 L
.40102 .5863 L
.40115 .58633 L
.40128 .58635 L
.40141 .58637 L
.40155 .58639 L
.40168 .58641 L
.40181 .58643 L
.40195 .58645 L
.40208 .58647 L
.40221 .58649 L
.40234 .58652 L
.40248 .58654 L
.40261 .58656 L
.40274 .58658 L
.40288 .5866 L
.40301 .58662 L
.40314 .58664 L
.40327 .58666 L
.40341 .58668 L
.40354 .5867 L
.40367 .58672 L
.40381 .58674 L
.40394 .58676 L
.40407 .58678 L
.4042 .58681 L
Mistroke
.40434 .58683 L
.40447 .58685 L
.4046 .58687 L
.40474 .58689 L
.40487 .58691 L
.405 .58693 L
.40513 .58695 L
.40527 .58697 L
.4054 .58699 L
.40553 .58701 L
.40567 .58703 L
.4058 .58705 L
.40593 .58707 L
.40606 .58709 L
.4062 .58711 L
.40633 .58713 L
.40646 .58715 L
.4066 .58717 L
.40673 .58719 L
.40686 .58721 L
.40699 .58723 L
.40713 .58725 L
.40726 .58727 L
.40739 .58729 L
.40753 .58731 L
.40766 .58733 L
.40779 .58735 L
.40792 .58737 L
.40806 .58739 L
.40819 .58741 L
.40832 .58743 L
.40846 .58745 L
.40859 .58747 L
.40872 .58749 L
.40885 .58751 L
.40899 .58753 L
.40912 .58755 L
.40925 .58757 L
.40939 .58759 L
.40952 .58761 L
.40965 .58763 L
.40978 .58765 L
.40992 .58767 L
.41005 .58769 L
.41018 .58771 L
.41032 .58773 L
.41045 .58775 L
.41058 .58777 L
.41071 .58779 L
.41085 .58781 L
Mistroke
.41098 .58783 L
.41111 .58785 L
.41125 .58787 L
.41138 .58789 L
.41151 .58791 L
.41164 .58792 L
.41178 .58794 L
.41191 .58796 L
.41204 .58798 L
.41218 .588 L
.41231 .58802 L
.41244 .58804 L
.41257 .58806 L
.41271 .58808 L
.41284 .5881 L
.41297 .58812 L
.41311 .58814 L
.41324 .58816 L
.41337 .58817 L
.4135 .58819 L
.41364 .58821 L
.41377 .58823 L
.4139 .58825 L
.41404 .58827 L
.41417 .58829 L
.4143 .58831 L
.41443 .58833 L
.41457 .58835 L
.4147 .58837 L
.41483 .58838 L
.41497 .5884 L
.4151 .58842 L
.41523 .58844 L
.41536 .58846 L
.4155 .58848 L
.41563 .5885 L
.41576 .58852 L
.4159 .58853 L
.41603 .58855 L
.41616 .58857 L
.41629 .58859 L
.41643 .58861 L
.41656 .58863 L
.41669 .58865 L
.41683 .58867 L
.41696 .58868 L
.41709 .5887 L
.41722 .58872 L
.41736 .58874 L
.41749 .58876 L
Mistroke
.41762 .58878 L
.41776 .5888 L
.41789 .58881 L
.41802 .58883 L
.41815 .58885 L
.41829 .58887 L
.41842 .58889 L
.41855 .58891 L
.41869 .58893 L
.41882 .58894 L
.41895 .58896 L
.41908 .58898 L
.41922 .589 L
.41935 .58902 L
.41948 .58904 L
.41962 .58905 L
.41975 .58907 L
.41988 .58909 L
.42001 .58911 L
.42015 .58913 L
.42028 .58915 L
.42041 .58916 L
.42055 .58918 L
.42068 .5892 L
.42081 .58922 L
.42094 .58924 L
.42108 .58925 L
.42121 .58927 L
.42134 .58929 L
.42148 .58931 L
.42161 .58933 L
.42174 .58934 L
.42188 .58936 L
.42201 .58938 L
.42214 .5894 L
.42227 .58942 L
.42241 .58943 L
.42254 .58945 L
.42267 .58947 L
.42281 .58949 L
.42294 .5895 L
.42307 .58952 L
.4232 .58954 L
.42334 .58956 L
.42347 .58958 L
.4236 .58959 L
.42374 .58961 L
.42387 .58963 L
.424 .58965 L
.42413 .58966 L
Mistroke
.42427 .58968 L
.4244 .5897 L
.42453 .58972 L
.42467 .58973 L
.4248 .58975 L
.42493 .58977 L
.42506 .58979 L
.4252 .5898 L
.42533 .58982 L
.42546 .58984 L
.4256 .58986 L
.42573 .58987 L
.42586 .58989 L
.42599 .58991 L
.42613 .58992 L
.42626 .58994 L
.42639 .58996 L
.42653 .58998 L
.42666 .58999 L
.42679 .59001 L
.42692 .59003 L
.42706 .59004 L
.42719 .59006 L
.42732 .59008 L
.42746 .5901 L
.42759 .59011 L
.42772 .59013 L
.42785 .59015 L
.42799 .59016 L
.42812 .59018 L
.42825 .5902 L
.42839 .59021 L
.42852 .59023 L
.42865 .59025 L
.42878 .59026 L
.42892 .59028 L
.42905 .5903 L
.42918 .59031 L
.42932 .59033 L
.42945 .59035 L
.42958 .59036 L
.42971 .59038 L
.42985 .5904 L
.42998 .59041 L
.43011 .59043 L
.43025 .59045 L
.43038 .59046 L
.43051 .59048 L
.43064 .59049 L
.43078 .59051 L
Mistroke
.43091 .59053 L
.43104 .59054 L
.43118 .59056 L
.43131 .59058 L
.43144 .59059 L
.43157 .59061 L
.43171 .59062 L
.43184 .59064 L
.43197 .59066 L
.43211 .59067 L
.43224 .59069 L
.43237 .5907 L
.4325 .59072 L
.43264 .59074 L
.43277 .59075 L
.4329 .59077 L
.43304 .59078 L
.43317 .5908 L
.4333 .59082 L
.43343 .59083 L
.43357 .59085 L
.4337 .59086 L
.43383 .59088 L
.43397 .5909 L
.4341 .59091 L
.43423 .59093 L
.43436 .59094 L
.4345 .59096 L
.43463 .59097 L
.43476 .59099 L
.4349 .591 L
.43503 .59102 L
.43516 .59104 L
.43529 .59105 L
.43543 .59107 L
.43556 .59108 L
.43569 .5911 L
.43583 .59111 L
.43596 .59113 L
.43609 .59114 L
.43622 .59116 L
.43636 .59117 L
.43649 .59119 L
.43662 .5912 L
.43676 .59122 L
.43689 .59123 L
.43702 .59125 L
.43715 .59126 L
.43729 .59128 L
.43742 .5913 L
Mistroke
.43755 .59131 L
.43769 .59133 L
.43782 .59134 L
.43795 .59136 L
.43808 .59137 L
.43822 .59139 L
.43835 .5914 L
.43848 .59142 L
.43862 .59143 L
.43875 .59145 L
.43888 .59146 L
.43901 .59147 L
.43915 .59149 L
.43928 .5915 L
.43941 .59152 L
.43955 .59153 L
.43968 .59155 L
.43981 .59156 L
.43994 .59158 L
.44008 .59159 L
.44021 .59161 L
.44034 .59162 L
.44048 .59164 L
.44061 .59165 L
.44074 .59167 L
.44087 .59168 L
.44101 .5917 L
.44114 .59171 L
.44127 .59173 L
.44141 .59174 L
.44154 .59175 L
.44167 .59177 L
.4418 .59178 L
.44194 .5918 L
.44207 .59181 L
.4422 .59183 L
.44234 .59184 L
.44247 .59186 L
.4426 .59187 L
.44273 .59188 L
.44287 .5919 L
.443 .59191 L
.44313 .59193 L
.44327 .59194 L
.4434 .59196 L
.44353 .59197 L
.44366 .59199 L
.4438 .592 L
.44393 .59201 L
.44406 .59203 L
Mistroke
.4442 .59204 L
.44433 .59206 L
.44446 .59207 L
.4446 .59209 L
.44473 .5921 L
.44486 .59211 L
.44499 .59213 L
.44513 .59214 L
.44526 .59216 L
.44539 .59217 L
.44553 .59218 L
.44566 .5922 L
.44579 .59221 L
.44592 .59223 L
.44606 .59224 L
.44619 .59225 L
.44632 .59227 L
.44646 .59228 L
.44659 .5923 L
.44672 .59231 L
.44685 .59232 L
.44699 .59234 L
.44712 .59235 L
.44725 .59237 L
.44739 .59238 L
.44752 .59239 L
.44765 .59241 L
.44778 .59242 L
.44792 .59243 L
.44805 .59245 L
.44818 .59246 L
.44832 .59248 L
.44845 .59249 L
.44858 .5925 L
.44871 .59252 L
.44885 .59253 L
.44898 .59254 L
.44911 .59256 L
.44925 .59257 L
.44938 .59258 L
.44951 .5926 L
.44964 .59261 L
.44978 .59263 L
.44991 .59264 L
.45004 .59265 L
.45018 .59267 L
.45031 .59268 L
.45044 .59269 L
.45057 .59271 L
.45071 .59272 L
Mistroke
.45084 .59273 L
.45097 .59275 L
.45111 .59276 L
.45124 .59277 L
.45137 .59279 L
.4515 .5928 L
.45164 .59281 L
.45177 .59283 L
.4519 .59284 L
.45204 .59285 L
.45217 .59286 L
.4523 .59288 L
.45243 .59289 L
.45257 .5929 L
.4527 .59292 L
.45283 .59293 L
.45297 .59294 L
.4531 .59296 L
.45323 .59297 L
.45336 .59298 L
.4535 .593 L
.45363 .59301 L
.45376 .59302 L
.4539 .59303 L
.45403 .59305 L
.45416 .59306 L
.45429 .59307 L
.45443 .59309 L
.45456 .5931 L
.45469 .59311 L
.45483 .59313 L
.45496 .59314 L
.45509 .59315 L
.45522 .59316 L
.45536 .59318 L
.45549 .59319 L
.45562 .5932 L
.45576 .59321 L
.45589 .59323 L
.45602 .59324 L
.45615 .59325 L
.45629 .59327 L
.45642 .59328 L
.45655 .59329 L
.45669 .5933 L
.45682 .59332 L
.45695 .59333 L
.45708 .59334 L
.45722 .59335 L
.45735 .59337 L
Mistroke
.45748 .59338 L
.45762 .59339 L
.45775 .5934 L
.45788 .59342 L
.45801 .59343 L
.45815 .59344 L
.45828 .59345 L
.45841 .59347 L
.45855 .59348 L
.45868 .59349 L
.45881 .5935 L
.45894 .59352 L
.45908 .59353 L
.45921 .59354 L
.45934 .59355 L
.45948 .59356 L
.45961 .59358 L
.45974 .59359 L
.45987 .5936 L
.46001 .59361 L
.46014 .59363 L
.46027 .59364 L
.46041 .59365 L
.46054 .59366 L
.46067 .59367 L
.4608 .59369 L
.46094 .5937 L
.46107 .59371 L
.4612 .59372 L
.46134 .59374 L
.46147 .59375 L
.4616 .59376 L
.46173 .59377 L
.46187 .59378 L
.462 .5938 L
.46213 .59381 L
.46227 .59382 L
.4624 .59383 L
.46253 .59384 L
.46266 .59386 L
.4628 .59387 L
.46293 .59388 L
.46306 .59389 L
.4632 .5939 L
.46333 .59391 L
.46346 .59393 L
.46359 .59394 L
.46373 .59395 L
.46386 .59396 L
.46399 .59397 L
Mistroke
.46413 .59399 L
.46426 .594 L
.46439 .59401 L
.46452 .59402 L
.46466 .59403 L
.46479 .59404 L
.46492 .59406 L
.46506 .59407 L
.46519 .59408 L
.46532 .59409 L
.46545 .5941 L
.46559 .59411 L
.46572 .59413 L
.46585 .59414 L
.46599 .59415 L
.46612 .59416 L
.46625 .59417 L
.46638 .59418 L
.46652 .5942 L
.46665 .59421 L
.46678 .59422 L
.46692 .59423 L
.46705 .59424 L
.46718 .59425 L
.46732 .59426 L
.46745 .59428 L
.46758 .59429 L
.46771 .5943 L
.46785 .59431 L
.46798 .59432 L
.46811 .59433 L
.46825 .59434 L
.46838 .59436 L
.46851 .59437 L
.46864 .59438 L
.46878 .59439 L
.46891 .5944 L
.46904 .59441 L
.46918 .59442 L
.46931 .59443 L
.46944 .59445 L
.46957 .59446 L
.46971 .59447 L
.46984 .59448 L
.46997 .59449 L
.47011 .5945 L
.47024 .59451 L
.47037 .59452 L
.4705 .59453 L
.47064 .59455 L
Mistroke
.47077 .59456 L
.4709 .59457 L
.47104 .59458 L
.47117 .59459 L
.4713 .5946 L
.47143 .59461 L
.47157 .59462 L
.4717 .59463 L
.47183 .59465 L
.47197 .59466 L
.4721 .59467 L
.47223 .59468 L
.47236 .59469 L
.4725 .5947 L
.47263 .59471 L
.47276 .59472 L
.4729 .59473 L
.47303 .59475 L
.47316 .59476 L
.47329 .59477 L
.47343 .59478 L
.47356 .59479 L
.47369 .5948 L
.47383 .59481 L
.47396 .59482 L
.47409 .59483 L
.47422 .59484 L
.47436 .59485 L
.47449 .59487 L
.47462 .59488 L
.47476 .59489 L
.47489 .5949 L
.47502 .59491 L
.47515 .59492 L
.47529 .59493 L
.47542 .59494 L
.47555 .59495 L
.47569 .59496 L
.47582 .59497 L
.47595 .59498 L
.47608 .59499 L
.47622 .59501 L
.47635 .59502 L
.47648 .59503 L
.47662 .59504 L
.47675 .59505 L
.47688 .59506 L
.47701 .59507 L
.47715 .59508 L
.47728 .59509 L
Mistroke
.47741 .5951 L
.47755 .59511 L
.47768 .59512 L
.47781 .59513 L
.47794 .59514 L
.47808 .59516 L
.47821 .59517 L
.47834 .59518 L
.47848 .59519 L
.47861 .5952 L
.47874 .59521 L
.47887 .59522 L
.47901 .59523 L
.47914 .59524 L
.47927 .59525 L
.47941 .59526 L
.47954 .59527 L
.47967 .59528 L
.4798 .59529 L
.47994 .5953 L
.48007 .59531 L
.4802 .59532 L
.48034 .59533 L
.48047 .59535 L
.4806 .59536 L
.48073 .59537 L
.48087 .59538 L
.481 .59539 L
.48113 .5954 L
.48127 .59541 L
.4814 .59542 L
.48153 .59543 L
.48166 .59544 L
.4818 .59545 L
.48193 .59546 L
.48206 .59547 L
.4822 .59548 L
.48233 .59549 L
.48246 .5955 L
.48259 .59551 L
.48273 .59552 L
.48286 .59553 L
.48299 .59554 L
.48313 .59555 L
.48326 .59556 L
.48339 .59557 L
.48352 .59558 L
.48366 .59559 L
.48379 .5956 L
.48392 .59561 L
Mistroke
.48406 .59562 L
.48419 .59563 L
.48432 .59564 L
.48445 .59565 L
.48459 .59566 L
.48472 .59567 L
.48485 .59568 L
.48499 .59569 L
.48512 .5957 L
.48525 .59571 L
.48538 .59572 L
.48552 .59573 L
.48565 .59574 L
.48578 .59575 L
.48592 .59576 L
.48605 .59577 L
.48618 .59578 L
.48631 .59579 L
.48645 .5958 L
.48658 .59581 L
.48671 .59582 L
.48685 .59583 L
.48698 .59584 L
.48711 .59585 L
.48724 .59586 L
.48738 .59587 L
.48751 .59587 L
.48764 .59588 L
.48778 .59589 L
.48791 .5959 L
.48804 .59591 L
.48817 .59592 L
.48831 .59593 L
.48844 .59594 L
.48857 .59595 L
.48871 .59596 L
.48884 .59597 L
.48897 .59598 L
.48911 .59599 L
.48924 .596 L
.48937 .59601 L
.4895 .59602 L
.48964 .59603 L
.48977 .59604 L
.4899 .59605 L
.49004 .59606 L
.49017 .59607 L
.4903 .59608 L
.49043 .59609 L
.49057 .5961 L
Mistroke
.4907 .5961 L
.49083 .59611 L
.49097 .59612 L
.4911 .59613 L
.49123 .59614 L
.49136 .59615 L
.4915 .59616 L
.49163 .59617 L
.49176 .59618 L
.4919 .59619 L
.49203 .5962 L
.49216 .59621 L
.49229 .59622 L
.49243 .59623 L
.49256 .59624 L
.49269 .59625 L
.49283 .59626 L
.49296 .59626 L
.49309 .59627 L
.49322 .59628 L
.49336 .59629 L
.49349 .5963 L
.49362 .59631 L
.49376 .59632 L
.49389 .59633 L
.49402 .59634 L
.49415 .59635 L
.49429 .59636 L
.49442 .59637 L
.49455 .59638 L
.49469 .59638 L
.49482 .59639 L
.49495 .5964 L
.49508 .59641 L
.49522 .59642 L
.49535 .59643 L
.49548 .59644 L
.49562 .59645 L
.49575 .59646 L
.49588 .59647 L
.49601 .59648 L
.49615 .59649 L
.49628 .59649 L
.49641 .5965 L
.49655 .59651 L
.49668 .59652 L
.49681 .59653 L
.49694 .59654 L
.49708 .59655 L
.49721 .59656 L
Mistroke
.49734 .59657 L
.49748 .59658 L
.49761 .59658 L
.49774 .59659 L
.49787 .5966 L
.49801 .59661 L
.49814 .59662 L
.49827 .59663 L
.49841 .59664 L
.49854 .59665 L
.49867 .59666 L
.4988 .59666 L
.49894 .59667 L
.49907 .59668 L
.4992 .59669 L
.49934 .5967 L
.49947 .59671 L
.4996 .59672 L
.49973 .59673 L
.49987 .59673 L
.5 .59674 L
.50013 .59675 L
.50027 .59676 L
.5004 .59677 L
.50053 .59678 L
.50066 .59679 L
.5008 .5968 L
.50093 .59681 L
.50106 .59681 L
.5012 .59682 L
.50133 .59683 L
.50146 .59684 L
.50159 .59685 L
.50173 .59686 L
.50186 .59687 L
.50199 .59687 L
.50213 .59688 L
.50226 .59689 L
.50239 .5969 L
.50252 .59691 L
.50266 .59692 L
.50279 .59693 L
.50292 .59694 L
.50306 .59694 L
.50319 .59695 L
.50332 .59696 L
.50345 .59697 L
.50359 .59698 L
.50372 .59699 L
.50385 .59699 L
Mistroke
.50399 .597 L
.50412 .59701 L
.50425 .59702 L
.50438 .59703 L
.50452 .59704 L
.50465 .59705 L
.50478 .59705 L
.50492 .59706 L
.50505 .59707 L
.50518 .59708 L
.50531 .59709 L
.50545 .5971 L
.50558 .5971 L
.50571 .59711 L
.50585 .59712 L
.50598 .59713 L
.50611 .59714 L
.50624 .59715 L
.50638 .59715 L
.50651 .59716 L
.50664 .59717 L
.50678 .59718 L
.50691 .59719 L
.50704 .59719 L
.50717 .5972 L
.50731 .59721 L
.50744 .59722 L
.50757 .59723 L
.50771 .59724 L
.50784 .59724 L
.50797 .59725 L
.5081 .59726 L
.50824 .59727 L
.50837 .59728 L
.5085 .59728 L
.50864 .59729 L
.50877 .5973 L
.5089 .59731 L
.50903 .59732 L
.50917 .59733 L
.5093 .59733 L
.50943 .59734 L
.50957 .59735 L
.5097 .59736 L
.50983 .59737 L
.50996 .59737 L
.5101 .59738 L
.51023 .59739 L
.51036 .5974 L
.5105 .59741 L
Mistroke
.51063 .59741 L
.51076 .59742 L
.51089 .59743 L
.51103 .59744 L
.51116 .59744 L
.51129 .59745 L
.51143 .59746 L
.51156 .59747 L
.51169 .59748 L
.51183 .59748 L
.51196 .59749 L
.51209 .5975 L
.51222 .59751 L
.51236 .59751 L
.51249 .59752 L
.51262 .59753 L
.51276 .59754 L
.51289 .59755 L
.51302 .59755 L
.51315 .59756 L
.51329 .59757 L
.51342 .59758 L
.51355 .59758 L
.51369 .59759 L
.51382 .5976 L
.51395 .59761 L
.51408 .59761 L
.51422 .59762 L
.51435 .59763 L
.51448 .59764 L
.51462 .59764 L
.51475 .59765 L
.51488 .59766 L
.51501 .59767 L
.51515 .59767 L
.51528 .59768 L
.51541 .59769 L
.51555 .5977 L
.51568 .5977 L
.51581 .59771 L
.51594 .59772 L
.51608 .59773 L
.51621 .59773 L
.51634 .59774 L
.51648 .59775 L
.51661 .59776 L
.51674 .59776 L
.51687 .59777 L
.51701 .59778 L
.51714 .59779 L
Mistroke
.51727 .59779 L
.51741 .5978 L
.51754 .59781 L
.51767 .59782 L
.5178 .59782 L
.51794 .59783 L
.51807 .59784 L
.5182 .59784 L
.51834 .59785 L
.51847 .59786 L
.5186 .59787 L
.51873 .59787 L
.51887 .59788 L
.519 .59789 L
.51913 .5979 L
.51927 .5979 L
.5194 .59791 L
.51953 .59792 L
.51966 .59792 L
.5198 .59793 L
.51993 .59794 L
.52006 .59795 L
.5202 .59795 L
.52033 .59796 L
.52046 .59797 L
.52059 .59797 L
.52073 .59798 L
.52086 .59799 L
.52099 .598 L
.52113 .598 L
.52126 .59801 L
.52139 .59802 L
.52152 .59802 L
.52166 .59803 L
.52179 .59804 L
.52192 .59805 L
.52206 .59805 L
.52219 .59806 L
.52232 .59807 L
.52245 .59807 L
.52259 .59808 L
.52272 .59809 L
.52285 .5981 L
.52299 .5981 L
.52312 .59811 L
.52325 .59812 L
.52338 .59812 L
.52352 .59813 L
.52365 .59814 L
.52378 .59815 L
Mistroke
.52392 .59815 L
.52405 .59816 L
.52418 .59817 L
.52431 .59817 L
.52445 .59818 L
.52458 .59819 L
.52471 .59819 L
.52485 .5982 L
.52498 .59821 L
.52511 .59822 L
.52524 .59822 L
.52538 .59823 L
.52551 .59824 L
.52564 .59824 L
.52578 .59825 L
.52591 .59826 L
.52604 .59826 L
.52617 .59827 L
.52631 .59828 L
.52644 .59828 L
.52657 .59829 L
.52671 .5983 L
.52684 .5983 L
.52697 .59831 L
.5271 .59832 L
.52724 .59833 L
.52737 .59833 L
.5275 .59834 L
.52764 .59835 L
.52777 .59835 L
.5279 .59836 L
.52803 .59837 L
.52817 .59837 L
.5283 .59838 L
.52843 .59839 L
.52857 .59839 L
.5287 .5984 L
.52883 .59841 L
.52896 .59841 L
.5291 .59842 L
.52923 .59843 L
.52936 .59843 L
.5295 .59844 L
.52963 .59845 L
.52976 .59845 L
.52989 .59846 L
.53003 .59847 L
.53016 .59847 L
.53029 .59848 L
.53043 .59849 L
Mistroke
.53056 .59849 L
.53069 .5985 L
.53082 .59851 L
.53096 .59851 L
.53109 .59852 L
.53122 .59852 L
.53136 .59853 L
.53149 .59854 L
.53162 .59854 L
.53175 .59855 L
.53189 .59856 L
.53202 .59856 L
.53215 .59857 L
.53229 .59858 L
.53242 .59858 L
.53255 .59859 L
.53268 .5986 L
.53282 .5986 L
.53295 .59861 L
.53308 .59862 L
.53322 .59862 L
.53335 .59863 L
.53348 .59863 L
.53362 .59864 L
.53375 .59865 L
.53388 .59865 L
.53401 .59866 L
.53415 .59867 L
.53428 .59867 L
.53441 .59868 L
.53455 .59869 L
.53468 .59869 L
.53481 .5987 L
.53494 .5987 L
.53508 .59871 L
.53521 .59872 L
.53534 .59872 L
.53548 .59873 L
.53561 .59874 L
.53574 .59874 L
.53587 .59875 L
.53601 .59875 L
.53614 .59876 L
.53627 .59877 L
.53641 .59877 L
.53654 .59878 L
.53667 .59879 L
.5368 .59879 L
.53694 .5988 L
.53707 .5988 L
Mistroke
.5372 .59881 L
.53734 .59882 L
.53747 .59882 L
.5376 .59883 L
.53773 .59884 L
.53787 .59884 L
.538 .59885 L
.53813 .59885 L
.53827 .59886 L
.5384 .59887 L
.53853 .59887 L
.53866 .59888 L
.5388 .59888 L
.53893 .59889 L
.53906 .5989 L
.5392 .5989 L
.53933 .59891 L
.53946 .59891 L
.53959 .59892 L
.53973 .59893 L
.53986 .59893 L
.53999 .59894 L
.54013 .59894 L
.54026 .59895 L
.54039 .59896 L
.54052 .59896 L
.54066 .59897 L
.54079 .59897 L
.54092 .59898 L
.54106 .59899 L
.54119 .59899 L
.54132 .599 L
.54145 .599 L
.54159 .59901 L
.54172 .59902 L
.54185 .59902 L
.54199 .59903 L
.54212 .59903 L
.54225 .59904 L
.54238 .59905 L
.54252 .59905 L
.54265 .59906 L
.54278 .59906 L
.54292 .59907 L
.54305 .59907 L
.54318 .59908 L
.54331 .59909 L
.54345 .59909 L
.54358 .5991 L
.54371 .5991 L
Mistroke
.54385 .59911 L
.54398 .59912 L
.54411 .59912 L
.54424 .59913 L
.54438 .59913 L
.54451 .59914 L
.54464 .59914 L
.54478 .59915 L
.54491 .59916 L
.54504 .59916 L
.54517 .59917 L
.54531 .59917 L
.54544 .59918 L
.54557 .59918 L
.54571 .59919 L
.54584 .5992 L
.54597 .5992 L
.5461 .59921 L
.54624 .59921 L
.54637 .59922 L
.5465 .59922 L
.54664 .59923 L
.54677 .59923 L
.5469 .59924 L
.54703 .59925 L
.54717 .59925 L
.5473 .59926 L
.54743 .59926 L
.54757 .59927 L
.5477 .59927 L
.54783 .59928 L
.54796 .59929 L
.5481 .59929 L
.54823 .5993 L
.54836 .5993 L
.5485 .59931 L
.54863 .59931 L
.54876 .59932 L
.54889 .59932 L
.54903 .59933 L
.54916 .59933 L
.54929 .59934 L
.54943 .59935 L
.54956 .59935 L
.54969 .59936 L
.54982 .59936 L
.54996 .59937 L
.55009 .59937 L
.55022 .59938 L
.55036 .59938 L
Mistroke
.55049 .59939 L
.55062 .59939 L
.55075 .5994 L
.55089 .59941 L
.55102 .59941 L
.55115 .59942 L
.55129 .59942 L
.55142 .59943 L
.55155 .59943 L
.55168 .59944 L
.55182 .59944 L
.55195 .59945 L
.55208 .59945 L
.55222 .59946 L
.55235 .59947 L
.55248 .59947 L
.55261 .59948 L
.55275 .59948 L
.55288 .59949 L
.55301 .59949 L
.55315 .5995 L
.55328 .5995 L
.55341 .59951 L
.55354 .59951 L
.55368 .59952 L
.55381 .59952 L
.55394 .59953 L
.55408 .59954 L
.55421 .59954 L
.55434 .59955 L
.55447 .59955 L
.55461 .59956 L
.55474 .59956 L
.55487 .59957 L
.55501 .59957 L
.55514 .59958 L
.55527 .59958 L
.5554 .59959 L
.55554 .59959 L
.55567 .5996 L
.5558 .5996 L
.55594 .59961 L
.55607 .59961 L
.5562 .59962 L
.55634 .59962 L
.55647 .59963 L
.5566 .59964 L
.55673 .59964 L
.55687 .59965 L
.557 .59965 L
Mistroke
.55713 .59966 L
.55727 .59966 L
.5574 .59967 L
.55753 .59967 L
.55766 .59968 L
.5578 .59968 L
.55793 .59969 L
.55806 .59969 L
.5582 .5997 L
.55833 .5997 L
.55846 .59971 L
.55859 .59971 L
.55873 .59972 L
.55886 .59972 L
.55899 .59973 L
.55913 .59973 L
.55926 .59974 L
.55939 .59974 L
.55952 .59975 L
.55966 .59975 L
.55979 .59976 L
.55992 .59976 L
.56006 .59977 L
.56019 .59977 L
.56032 .59978 L
.56045 .59978 L
.56059 .59979 L
.56072 .59979 L
.56085 .5998 L
.56099 .5998 L
.56112 .59981 L
.56125 .59981 L
.56138 .59982 L
.56152 .59982 L
.56165 .59983 L
.56178 .59983 L
.56192 .59984 L
.56205 .59984 L
.56218 .59985 L
.56231 .59985 L
.56245 .59986 L
.56258 .59986 L
.56271 .59987 L
.56285 .59987 L
.56298 .59988 L
.56311 .59988 L
.56324 .59989 L
.56338 .59989 L
.56351 .5999 L
.56364 .5999 L
Mistroke
.56378 .59991 L
.56391 .59991 L
.56404 .59992 L
.56417 .59992 L
.56431 .59992 L
.56444 .59993 L
.56457 .59993 L
.56471 .59994 L
.56484 .59994 L
.56497 .59995 L
.5651 .59995 L
.56524 .59996 L
.56537 .59996 L
.5655 .59997 L
.56564 .59997 L
.56577 .59998 L
.5659 .59998 L
.56603 .59999 L
.56617 .59999 L
.5663 .6 L
.56643 .6 L
.56657 .60001 L
.5667 .60001 L
.56683 .60001 L
.56696 .60002 L
.5671 .60002 L
.56723 .60003 L
.56736 .60003 L
.5675 .60004 L
.56763 .60004 L
.56776 .60005 L
.56789 .60005 L
.56803 .60006 L
.56816 .60006 L
.56829 .60007 L
.56843 .60007 L
.56856 .60007 L
.56869 .60008 L
.56882 .60008 L
.56896 .60009 L
.56909 .60009 L
.56922 .6001 L
.56936 .6001 L
.56949 .60011 L
.56962 .60011 L
.56975 .60012 L
.56989 .60012 L
.57002 .60013 L
.57015 .60013 L
.57029 .60013 L
Mistroke
.57042 .60014 L
.57055 .60014 L
.57068 .60015 L
.57082 .60015 L
.57095 .60016 L
.57108 .60016 L
.57122 .60017 L
.57135 .60017 L
.57148 .60017 L
.57161 .60018 L
.57175 .60018 L
.57188 .60019 L
.57201 .60019 L
.57215 .6002 L
.57228 .6002 L
.57241 .60021 L
.57254 .60021 L
.57268 .60021 L
.57281 .60022 L
.57294 .60022 L
.57308 .60023 L
.57321 .60023 L
.57334 .60024 L
.57347 .60024 L
.57361 .60025 L
.57374 .60025 L
.57387 .60025 L
.57401 .60026 L
.57414 .60026 L
.57427 .60027 L
.5744 .60027 L
.57454 .60028 L
.57467 .60028 L
.5748 .60028 L
.57494 .60029 L
.57507 .60029 L
.5752 .6003 L
.57533 .6003 L
.57547 .60031 L
.5756 .60031 L
.57573 .60031 L
.57587 .60032 L
.576 .60032 L
.57613 .60033 L
.57626 .60033 L
.5764 .60034 L
.57653 .60034 L
.57666 .60034 L
.5768 .60035 L
.57693 .60035 L
Mistroke
.57706 .60036 L
.57719 .60036 L
.57733 .60036 L
.57746 .60037 L
.57759 .60037 L
.57773 .60038 L
.57786 .60038 L
.57799 .60039 L
.57813 .60039 L
.57826 .60039 L
.57839 .6004 L
.57852 .6004 L
.57866 .60041 L
.57879 .60041 L
.57892 .60041 L
.57906 .60042 L
.57919 .60042 L
.57932 .60043 L
.57945 .60043 L
.57959 .60043 L
.57972 .60044 L
.57985 .60044 L
.57999 .60045 L
.58012 .60045 L
.58025 .60046 L
.58038 .60046 L
.58052 .60046 L
.58065 .60047 L
.58078 .60047 L
.58092 .60048 L
.58105 .60048 L
.58118 .60048 L
.58131 .60049 L
.58145 .60049 L
.58158 .6005 L
.58171 .6005 L
.58185 .6005 L
.58198 .60051 L
.58211 .60051 L
.58224 .60052 L
.58238 .60052 L
.58251 .60052 L
.58264 .60053 L
.58278 .60053 L
.58291 .60054 L
.58304 .60054 L
.58317 .60054 L
.58331 .60055 L
.58344 .60055 L
.58357 .60056 L
Mistroke
.58371 .60056 L
.58384 .60056 L
.58397 .60057 L
.5841 .60057 L
.58424 .60057 L
.58437 .60058 L
.5845 .60058 L
.58464 .60059 L
.58477 .60059 L
.5849 .60059 L
.58503 .6006 L
.58517 .6006 L
.5853 .60061 L
.58543 .60061 L
.58557 .60061 L
.5857 .60062 L
.58583 .60062 L
.58596 .60063 L
.5861 .60063 L
.58623 .60063 L
.58636 .60064 L
.5865 .60064 L
.58663 .60064 L
.58676 .60065 L
.58689 .60065 L
.58703 .60066 L
.58716 .60066 L
.58729 .60066 L
.58743 .60067 L
.58756 .60067 L
.58769 .60067 L
.58782 .60068 L
.58796 .60068 L
.58809 .60069 L
.58822 .60069 L
.58836 .60069 L
.58849 .6007 L
.58862 .6007 L
.58875 .6007 L
.58889 .60071 L
.58902 .60071 L
.58915 .60072 L
.58929 .60072 L
.58942 .60072 L
.58955 .60073 L
.58968 .60073 L
.58982 .60073 L
.58995 .60074 L
.59008 .60074 L
.59022 .60075 L
Mistroke
.59035 .60075 L
.59048 .60075 L
.59061 .60076 L
.59075 .60076 L
.59088 .60076 L
.59101 .60077 L
.59115 .60077 L
.59128 .60077 L
.59141 .60078 L
.59154 .60078 L
.59168 .60079 L
.59181 .60079 L
.59194 .60079 L
.59208 .6008 L
.59221 .6008 L
.59234 .6008 L
.59247 .60081 L
.59261 .60081 L
.59274 .60081 L
.59287 .60082 L
.59301 .60082 L
.59314 .60082 L
.59327 .60083 L
.5934 .60083 L
.59354 .60084 L
.59367 .60084 L
.5938 .60084 L
.59394 .60085 L
.59407 .60085 L
.5942 .60085 L
.59433 .60086 L
.59447 .60086 L
.5946 .60086 L
.59473 .60087 L
.59487 .60087 L
.595 .60087 L
.59513 .60088 L
.59526 .60088 L
.5954 .60088 L
.59553 .60089 L
.59566 .60089 L
.5958 .60089 L
.59593 .6009 L
.59606 .6009 L
.59619 .6009 L
.59633 .60091 L
.59646 .60091 L
.59659 .60092 L
.59673 .60092 L
.59686 .60092 L
Mistroke
.59699 .60093 L
.59712 .60093 L
.59726 .60093 L
.59739 .60094 L
.59752 .60094 L
.59766 .60094 L
.59779 .60095 L
.59792 .60095 L
.59805 .60095 L
.59819 .60096 L
.59832 .60096 L
.59845 .60096 L
.59859 .60097 L
.59872 .60097 L
.59885 .60097 L
.59898 .60098 L
.59912 .60098 L
.59925 .60098 L
.59938 .60099 L
.59952 .60099 L
.59965 .60099 L
.59978 .601 L
.59991 .601 L
.60005 .601 L
.60018 .60101 L
.60031 .60101 L
.60045 .60101 L
.60058 .60102 L
.60071 .60102 L
.60085 .60102 L
.60098 .60103 L
.60111 .60103 L
.60124 .60103 L
.60138 .60104 L
.60151 .60104 L
.60164 .60104 L
.60178 .60105 L
.60191 .60105 L
.60204 .60105 L
.60217 .60106 L
.60231 .60106 L
.60244 .60106 L
.60257 .60107 L
.60271 .60107 L
.60284 .60107 L
.60297 .60108 L
.6031 .60108 L
.60324 .60108 L
.60337 .60109 L
.6035 .60109 L
Mistroke
.60364 .60109 L
.60377 .6011 L
.6039 .6011 L
.60403 .6011 L
.60417 .60111 L
.6043 .60111 L
.60443 .60111 L
.60457 .60111 L
.6047 .60112 L
.60483 .60112 L
.60496 .60112 L
.6051 .60113 L
.60523 .60113 L
.60536 .60113 L
.6055 .60114 L
.60563 .60114 L
.60576 .60114 L
.60589 .60115 L
.60603 .60115 L
.60616 .60115 L
.60629 .60116 L
.60643 .60116 L
.60656 .60116 L
.60669 .60117 L
.60682 .60117 L
.60696 .60117 L
.60709 .60117 L
.60722 .60118 L
.60736 .60118 L
.60749 .60118 L
.60762 .60119 L
.60775 .60119 L
.60789 .60119 L
.60802 .6012 L
.60815 .6012 L
.60829 .6012 L
.60842 .60121 L
.60855 .60121 L
.60868 .60121 L
.60882 .60121 L
.60895 .60122 L
.60908 .60122 L
.60922 .60122 L
.60935 .60123 L
.60948 .60123 L
.60961 .60123 L
.60975 .60124 L
.60988 .60124 L
.61001 .60124 L
.61015 .60125 L
Mistroke
.61028 .60125 L
.61041 .60125 L
.61054 .60125 L
.61068 .60126 L
.61081 .60126 L
.61094 .60126 L
.61108 .60127 L
.61121 .60127 L
.61134 .60127 L
.61147 .60128 L
.61161 .60128 L
.61174 .60128 L
.61187 .60128 L
.61201 .60129 L
.61214 .60129 L
.61227 .60129 L
.6124 .6013 L
.61254 .6013 L
.61267 .6013 L
.6128 .60131 L
.61294 .60131 L
.61307 .60131 L
.6132 .60131 L
.61333 .60132 L
.61347 .60132 L
.6136 .60132 L
.61373 .60133 L
.61387 .60133 L
.614 .60133 L
.61413 .60134 L
.61426 .60134 L
.6144 .60134 L
.61453 .60134 L
.61466 .60135 L
.6148 .60135 L
.61493 .60135 L
.61506 .60136 L
.61519 .60136 L
.61533 .60136 L
.61546 .60136 L
.61559 .60137 L
.61573 .60137 L
.61586 .60137 L
.61599 .60138 L
.61612 .60138 L
.61626 .60138 L
.61639 .60138 L
.61652 .60139 L
.61666 .60139 L
.61679 .60139 L
Mistroke
.61692 .6014 L
.61705 .6014 L
.61719 .6014 L
.61732 .6014 L
.61745 .60141 L
.61759 .60141 L
.61772 .60141 L
.61785 .60142 L
.61798 .60142 L
.61812 .60142 L
.61825 .60142 L
.61838 .60143 L
.61852 .60143 L
.61865 .60143 L
.61878 .60143 L
.61891 .60144 L
.61905 .60144 L
.61918 .60144 L
.61931 .60145 L
.61945 .60145 L
.61958 .60145 L
.61971 .60145 L
.61984 .60146 L
.61998 .60146 L
.62011 .60146 L
.62024 .60147 L
.62038 .60147 L
.62051 .60147 L
.62064 .60147 L
.62077 .60148 L
.62091 .60148 L
.62104 .60148 L
.62117 .60149 L
.62131 .60149 L
.62144 .60149 L
.62157 .60149 L
.6217 .6015 L
.62184 .6015 L
.62197 .6015 L
.6221 .6015 L
.62224 .60151 L
.62237 .60151 L
.6225 .60151 L
.62263 .60152 L
.62277 .60152 L
.6229 .60152 L
.62303 .60152 L
.62317 .60153 L
.6233 .60153 L
.62343 .60153 L
Mistroke
.62357 .60153 L
.6237 .60154 L
.62383 .60154 L
.62396 .60154 L
.6241 .60155 L
.62423 .60155 L
.62436 .60155 L
.6245 .60155 L
.62463 .60156 L
.62476 .60156 L
.62489 .60156 L
.62503 .60156 L
.62516 .60157 L
.62529 .60157 L
.62543 .60157 L
.62556 .60157 L
.62569 .60158 L
.62582 .60158 L
.62596 .60158 L
.62609 .60159 L
.62622 .60159 L
.62636 .60159 L
.62649 .60159 L
.62662 .6016 L
.62675 .6016 L
.62689 .6016 L
.62702 .6016 L
.62715 .60161 L
.62729 .60161 L
.62742 .60161 L
.62755 .60161 L
.62768 .60162 L
.62782 .60162 L
.62795 .60162 L
.62808 .60163 L
.62822 .60163 L
.62835 .60163 L
.62848 .60163 L
.62861 .60164 L
.62875 .60164 L
.62888 .60164 L
.62901 .60164 L
.62915 .60165 L
.62928 .60165 L
.62941 .60165 L
.62954 .60165 L
.62968 .60166 L
.62981 .60166 L
.62994 .60166 L
.63008 .60166 L
Mistroke
.63021 .60167 L
.63034 .60167 L
.63047 .60167 L
.63061 .60167 L
.63074 .60168 L
.63087 .60168 L
.63101 .60168 L
.63114 .60168 L
.63127 .60169 L
.6314 .60169 L
.63154 .60169 L
.63167 .60169 L
.6318 .6017 L
.63194 .6017 L
.63207 .6017 L
.6322 .6017 L
.63233 .60171 L
.63247 .60171 L
.6326 .60171 L
.63273 .60171 L
.63287 .60172 L
.633 .60172 L
.63313 .60172 L
.63326 .60172 L
.6334 .60173 L
.63353 .60173 L
.63366 .60173 L
.6338 .60173 L
.63393 .60174 L
.63406 .60174 L
.63419 .60174 L
.63433 .60174 L
.63446 .60175 L
.63459 .60175 L
.63473 .60175 L
.63486 .60175 L
.63499 .60176 L
.63512 .60176 L
.63526 .60176 L
.63539 .60176 L
.63552 .60177 L
.63566 .60177 L
.63579 .60177 L
.63592 .60177 L
.63605 .60178 L
.63619 .60178 L
.63632 .60178 L
.63645 .60178 L
.63659 .60179 L
.63672 .60179 L
Mistroke
.63685 .60179 L
.63698 .60179 L
.63712 .6018 L
.63725 .6018 L
.63738 .6018 L
.63752 .6018 L
.63765 .60181 L
.63778 .60181 L
.63791 .60181 L
.63805 .60181 L
.63818 .60181 L
.63831 .60182 L
.63845 .60182 L
.63858 .60182 L
.63871 .60182 L
.63884 .60183 L
.63898 .60183 L
.63911 .60183 L
.63924 .60183 L
.63938 .60184 L
.63951 .60184 L
.63964 .60184 L
.63977 .60184 L
.63991 .60185 L
.64004 .60185 L
.64017 .60185 L
.64031 .60185 L
.64044 .60185 L
.64057 .60186 L
.6407 .60186 L
.64084 .60186 L
.64097 .60186 L
.6411 .60187 L
.64124 .60187 L
.64137 .60187 L
.6415 .60187 L
.64163 .60188 L
.64177 .60188 L
.6419 .60188 L
.64203 .60188 L
.64217 .60188 L
.6423 .60189 L
.64243 .60189 L
.64256 .60189 L
.6427 .60189 L
.64283 .6019 L
.64296 .6019 L
.6431 .6019 L
.64323 .6019 L
.64336 .60191 L
Mistroke
.64349 .60191 L
.64363 .60191 L
.64376 .60191 L
.64389 .60191 L
.64403 .60192 L
.64416 .60192 L
.64429 .60192 L
.64442 .60192 L
.64456 .60193 L
.64469 .60193 L
.64482 .60193 L
.64496 .60193 L
.64509 .60193 L
.64522 .60194 L
.64536 .60194 L
.64549 .60194 L
.64562 .60194 L
.64575 .60195 L
.64589 .60195 L
.64602 .60195 L
.64615 .60195 L
.64629 .60195 L
.64642 .60196 L
.64655 .60196 L
.64668 .60196 L
.64682 .60196 L
.64695 .60197 L
.64708 .60197 L
.64722 .60197 L
.64735 .60197 L
.64748 .60197 L
.64761 .60198 L
.64775 .60198 L
.64788 .60198 L
.64801 .60198 L
.64815 .60198 L
.64828 .60199 L
.64841 .60199 L
.64854 .60199 L
.64868 .60199 L
.64881 .602 L
.64894 .602 L
.64908 .602 L
.64921 .602 L
.64934 .602 L
.64947 .60201 L
.64961 .60201 L
.64974 .60201 L
.64987 .60201 L
.65001 .60201 L
Mistroke
.65014 .60202 L
.65027 .60202 L
.6504 .60202 L
.65054 .60202 L
.65067 .60203 L
.6508 .60203 L
.65094 .60203 L
.65107 .60203 L
.6512 .60203 L
.65133 .60204 L
.65147 .60204 L
.6516 .60204 L
.65173 .60204 L
.65187 .60204 L
.652 .60205 L
.65213 .60205 L
.65226 .60205 L
.6524 .60205 L
.65253 .60205 L
.65266 .60206 L
.6528 .60206 L
.65293 .60206 L
.65306 .60206 L
.65319 .60206 L
.65333 .60207 L
.65346 .60207 L
.65359 .60207 L
.65373 .60207 L
.65386 .60207 L
.65399 .60208 L
.65412 .60208 L
.65426 .60208 L
.65439 .60208 L
.65452 .60208 L
.65466 .60209 L
.65479 .60209 L
.65492 .60209 L
.65505 .60209 L
.65519 .60209 L
.65532 .6021 L
.65545 .6021 L
.65559 .6021 L
.65572 .6021 L
.65585 .6021 L
.65598 .60211 L
.65612 .60211 L
.65625 .60211 L
.65638 .60211 L
.65652 .60211 L
.65665 .60212 L
Mistroke
.65678 .60212 L
.65691 .60212 L
.65705 .60212 L
.65718 .60212 L
.65731 .60213 L
.65745 .60213 L
.65758 .60213 L
.65771 .60213 L
.65784 .60213 L
.65798 .60214 L
.65811 .60214 L
.65824 .60214 L
.65838 .60214 L
.65851 .60214 L
.65864 .60215 L
.65877 .60215 L
.65891 .60215 L
.65904 .60215 L
.65917 .60215 L
.65931 .60216 L
.65944 .60216 L
.65957 .60216 L
.6597 .60216 L
.65984 .60216 L
.65997 .60217 L
.6601 .60217 L
.66024 .60217 L
.66037 .60217 L
.6605 .60217 L
.66063 .60217 L
.66077 .60218 L
.6609 .60218 L
.66103 .60218 L
.66117 .60218 L
.6613 .60218 L
.66143 .60219 L
.66156 .60219 L
.6617 .60219 L
.66183 .60219 L
.66196 .60219 L
.6621 .6022 L
.66223 .6022 L
.66236 .6022 L
.66249 .6022 L
.66263 .6022 L
.66276 .60221 L
.66289 .60221 L
.66303 .60221 L
.66316 .60221 L
.66329 .60221 L
Mistroke
.66342 .60221 L
.66356 .60222 L
.66369 .60222 L
.66382 .60222 L
.66396 .60222 L
.66409 .60222 L
.66422 .60223 L
.66435 .60223 L
.66449 .60223 L
.66462 .60223 L
.66475 .60223 L
.66489 .60224 L
.66502 .60224 L
.66515 .60224 L
.66528 .60224 L
.66542 .60224 L
.66555 .60224 L
.66568 .60225 L
.66582 .60225 L
.66595 .60225 L
.66608 .60225 L
.66621 .60225 L
.66635 .60226 L
.66648 .60226 L
.66661 .60226 L
.66675 .60226 L
.66688 .60226 L
.66701 .60226 L
.66714 .60227 L
.66728 .60227 L
.66741 .60227 L
.66754 .60227 L
.66768 .60227 L
.66781 .60227 L
.66794 .60228 L
.66808 .60228 L
.66821 .60228 L
.66834 .60228 L
.66847 .60228 L
.66861 .60229 L
.66874 .60229 L
.66887 .60229 L
.66901 .60229 L
.66914 .60229 L
.66927 .60229 L
.6694 .6023 L
.66954 .6023 L
.66967 .6023 L
.6698 .6023 L
.66994 .6023 L
Mistroke
.67007 .6023 L
.6702 .60231 L
.67033 .60231 L
.67047 .60231 L
.6706 .60231 L
.67073 .60231 L
.67087 .60232 L
.671 .60232 L
.67113 .60232 L
.67126 .60232 L
.6714 .60232 L
.67153 .60232 L
.67166 .60233 L
.6718 .60233 L
.67193 .60233 L
.67206 .60233 L
.67219 .60233 L
.67233 .60233 L
.67246 .60234 L
.67259 .60234 L
.67273 .60234 L
.67286 .60234 L
.67299 .60234 L
.67312 .60234 L
.67326 .60235 L
.67339 .60235 L
.67352 .60235 L
.67366 .60235 L
.67379 .60235 L
.67392 .60235 L
.67405 .60236 L
.67419 .60236 L
.67432 .60236 L
.67445 .60236 L
.67459 .60236 L
.67472 .60236 L
.67485 .60237 L
.67498 .60237 L
.67512 .60237 L
.67525 .60237 L
.67538 .60237 L
.67552 .60237 L
.67565 .60237 L
.67578 .60238 L
.67591 .60238 L
.67605 .60238 L
.67618 .60238 L
.67631 .60238 L
.67645 .60238 L
.67658 .60239 L
Mistroke
.67671 .60239 L
.67684 .60239 L
.67698 .60239 L
.67711 .60239 L
.67724 .60239 L
.67738 .6024 L
.67751 .6024 L
.67764 .6024 L
.67777 .6024 L
.67791 .6024 L
.67804 .6024 L
.67817 .6024 L
.67831 .60241 L
.67844 .60241 L
.67857 .60241 L
.6787 .60241 L
.67884 .60241 L
.67897 .60241 L
.6791 .60242 L
.67924 .60242 L
.67937 .60242 L
.6795 .60242 L
.67963 .60242 L
.67977 .60242 L
.6799 .60242 L
.68003 .60243 L
.68017 .60243 L
.6803 .60243 L
.68043 .60243 L
.68056 .60243 L
.6807 .60243 L
.68083 .60244 L
.68096 .60244 L
.6811 .60244 L
.68123 .60244 L
.68136 .60244 L
.68149 .60244 L
.68163 .60244 L
.68176 .60245 L
.68189 .60245 L
.68203 .60245 L
.68216 .60245 L
.68229 .60245 L
.68242 .60245 L
.68256 .60245 L
.68269 .60246 L
.68282 .60246 L
.68296 .60246 L
.68309 .60246 L
.68322 .60246 L
Mistroke
.68335 .60246 L
.68349 .60247 L
.68362 .60247 L
.68375 .60247 L
.68389 .60247 L
.68402 .60247 L
.68415 .60247 L
.68428 .60247 L
.68442 .60248 L
.68455 .60248 L
.68468 .60248 L
.68482 .60248 L
.68495 .60248 L
.68508 .60248 L
.68521 .60248 L
.68535 .60249 L
.68548 .60249 L
.68561 .60249 L
.68575 .60249 L
.68588 .60249 L
.68601 .60249 L
.68614 .60249 L
.68628 .6025 L
.68641 .6025 L
.68654 .6025 L
.68668 .6025 L
.68681 .6025 L
.68694 .6025 L
.68707 .6025 L
.68721 .60251 L
.68734 .60251 L
.68747 .60251 L
.68761 .60251 L
.68774 .60251 L
.68787 .60251 L
.688 .60251 L
.68814 .60252 L
.68827 .60252 L
.6884 .60252 L
.68854 .60252 L
.68867 .60252 L
.6888 .60252 L
.68893 .60252 L
.68907 .60252 L
.6892 .60253 L
.68933 .60253 L
.68947 .60253 L
.6896 .60253 L
.68973 .60253 L
.68987 .60253 L
Mistroke
.69 .60253 L
.69013 .60254 L
.69026 .60254 L
.6904 .60254 L
.69053 .60254 L
.69066 .60254 L
.6908 .60254 L
.69093 .60254 L
.69106 .60255 L
.69119 .60255 L
.69133 .60255 L
.69146 .60255 L
.69159 .60255 L
.69173 .60255 L
.69186 .60255 L
.69199 .60255 L
.69212 .60256 L
.69226 .60256 L
.69239 .60256 L
.69252 .60256 L
.69266 .60256 L
.69279 .60256 L
.69292 .60256 L
.69305 .60257 L
.69319 .60257 L
.69332 .60257 L
.69345 .60257 L
.69359 .60257 L
.69372 .60257 L
.69385 .60257 L
.69398 .60257 L
.69412 .60258 L
.69425 .60258 L
.69438 .60258 L
.69452 .60258 L
.69465 .60258 L
.69478 .60258 L
.69491 .60258 L
.69505 .60259 L
.69518 .60259 L
.69531 .60259 L
.69545 .60259 L
.69558 .60259 L
.69571 .60259 L
.69584 .60259 L
.69598 .60259 L
.69611 .6026 L
.69624 .6026 L
.69638 .6026 L
.69651 .6026 L
Mistroke
.69664 .6026 L
.69677 .6026 L
.69691 .6026 L
.69704 .6026 L
.69717 .60261 L
.69731 .60261 L
.69744 .60261 L
.69757 .60261 L
.6977 .60261 L
.69784 .60261 L
.69797 .60261 L
.6981 .60261 L
.69824 .60262 L
.69837 .60262 L
.6985 .60262 L
.69863 .60262 L
.69877 .60262 L
.6989 .60262 L
.69903 .60262 L
.69917 .60262 L
.6993 .60263 L
.69943 .60263 L
.69956 .60263 L
.6997 .60263 L
.69983 .60263 L
.69996 .60263 L
.7001 .60263 L
.70023 .60263 L
.70036 .60264 L
.70049 .60264 L
.70063 .60264 L
.70076 .60264 L
.70089 .60264 L
.70103 .60264 L
.70116 .60264 L
.70129 .60264 L
.70142 .60265 L
.70156 .60265 L
.70169 .60265 L
.70182 .60265 L
.70196 .60265 L
.70209 .60265 L
.70222 .60265 L
.70235 .60265 L
.70249 .60266 L
.70262 .60266 L
.70275 .60266 L
.70289 .60266 L
.70302 .60266 L
.70315 .60266 L
Mistroke
.70328 .60266 L
.70342 .60266 L
.70355 .60266 L
.70368 .60267 L
.70382 .60267 L
.70395 .60267 L
.70408 .60267 L
.70421 .60267 L
.70435 .60267 L
.70448 .60267 L
.70461 .60267 L
.70475 .60268 L
.70488 .60268 L
.70501 .60268 L
.70514 .60268 L
.70528 .60268 L
.70541 .60268 L
.70554 .60268 L
.70568 .60268 L
.70581 .60268 L
.70594 .60269 L
.70607 .60269 L
.70621 .60269 L
.70634 .60269 L
.70647 .60269 L
.70661 .60269 L
.70674 .60269 L
.70687 .60269 L
.707 .6027 L
.70714 .6027 L
.70727 .6027 L
.7074 .6027 L
.70754 .6027 L
.70767 .6027 L
.7078 .6027 L
.70793 .6027 L
.70807 .6027 L
.7082 .60271 L
.70833 .60271 L
.70847 .60271 L
.7086 .60271 L
.70873 .60271 L
.70886 .60271 L
.709 .60271 L
.70913 .60271 L
.70926 .60271 L
.7094 .60272 L
.70953 .60272 L
.70966 .60272 L
.70979 .60272 L
Mistroke
.70993 .60272 L
.71006 .60272 L
.71019 .60272 L
.71033 .60272 L
.71046 .60272 L
.71059 .60273 L
.71072 .60273 L
.71086 .60273 L
.71099 .60273 L
.71112 .60273 L
.71126 .60273 L
.71139 .60273 L
.71152 .60273 L
.71165 .60273 L
.71179 .60274 L
.71192 .60274 L
.71205 .60274 L
.71219 .60274 L
.71232 .60274 L
.71245 .60274 L
.71259 .60274 L
.71272 .60274 L
.71285 .60274 L
.71298 .60275 L
.71312 .60275 L
.71325 .60275 L
.71338 .60275 L
.71352 .60275 L
.71365 .60275 L
.71378 .60275 L
.71391 .60275 L
.71405 .60275 L
.71418 .60275 L
.71431 .60276 L
.71445 .60276 L
.71458 .60276 L
.71471 .60276 L
.71484 .60276 L
.71498 .60276 L
.71511 .60276 L
.71524 .60276 L
.71538 .60276 L
.71551 .60277 L
.71564 .60277 L
.71577 .60277 L
.71591 .60277 L
.71604 .60277 L
.71617 .60277 L
.71631 .60277 L
.71644 .60277 L
Mistroke
.71657 .60277 L
.7167 .60278 L
.71684 .60278 L
.71697 .60278 L
.7171 .60278 L
.71724 .60278 L
.71737 .60278 L
.7175 .60278 L
.71763 .60278 L
.71777 .60278 L
.7179 .60278 L
.71803 .60279 L
.71817 .60279 L
.7183 .60279 L
.71843 .60279 L
.71856 .60279 L
.7187 .60279 L
.71883 .60279 L
.71896 .60279 L
.7191 .60279 L
.71923 .60279 L
.71936 .6028 L
.71949 .6028 L
.71963 .6028 L
.71976 .6028 L
.71989 .6028 L
.72003 .6028 L
.72016 .6028 L
.72029 .6028 L
.72042 .6028 L
.72056 .6028 L
.72069 .60281 L
.72082 .60281 L
.72096 .60281 L
.72109 .60281 L
.72122 .60281 L
.72135 .60281 L
.72149 .60281 L
.72162 .60281 L
.72175 .60281 L
.72189 .60281 L
.72202 .60282 L
.72215 .60282 L
.72228 .60282 L
.72242 .60282 L
.72255 .60282 L
.72268 .60282 L
.72282 .60282 L
.72295 .60282 L
.72308 .60282 L
Mistroke
.72321 .60282 L
.72335 .60283 L
.72348 .60283 L
.72361 .60283 L
.72375 .60283 L
.72388 .60283 L
.72401 .60283 L
.72414 .60283 L
.72428 .60283 L
.72441 .60283 L
.72454 .60283 L
.72468 .60283 L
.72481 .60284 L
.72494 .60284 L
.72507 .60284 L
.72521 .60284 L
.72534 .60284 L
.72547 .60284 L
.72561 .60284 L
.72574 .60284 L
.72587 .60284 L
.726 .60284 L
.72614 .60285 L
.72627 .60285 L
.7264 .60285 L
.72654 .60285 L
.72667 .60285 L
.7268 .60285 L
.72693 .60285 L
.72707 .60285 L
.7272 .60285 L
.72733 .60285 L
.72747 .60285 L
.7276 .60286 L
.72773 .60286 L
.72786 .60286 L
.728 .60286 L
.72813 .60286 L
.72826 .60286 L
.7284 .60286 L
.72853 .60286 L
.72866 .60286 L
.72879 .60286 L
.72893 .60287 L
.72906 .60287 L
.72919 .60287 L
.72933 .60287 L
.72946 .60287 L
.72959 .60287 L
.72972 .60287 L
Mistroke
.72986 .60287 L
.72999 .60287 L
.73012 .60287 L
.73026 .60287 L
.73039 .60288 L
.73052 .60288 L
.73065 .60288 L
.73079 .60288 L
.73092 .60288 L
.73105 .60288 L
.73119 .60288 L
.73132 .60288 L
.73145 .60288 L
.73158 .60288 L
.73172 .60288 L
.73185 .60288 L
.73198 .60289 L
.73212 .60289 L
.73225 .60289 L
.73238 .60289 L
.73251 .60289 L
.73265 .60289 L
.73278 .60289 L
.73291 .60289 L
.73305 .60289 L
.73318 .60289 L
.73331 .60289 L
.73344 .6029 L
.73358 .6029 L
.73371 .6029 L
.73384 .6029 L
.73398 .6029 L
.73411 .6029 L
.73424 .6029 L
.73438 .6029 L
.73451 .6029 L
.73464 .6029 L
.73477 .6029 L
.73491 .6029 L
.73504 .60291 L
.73517 .60291 L
.73531 .60291 L
.73544 .60291 L
.73557 .60291 L
.7357 .60291 L
.73584 .60291 L
.73597 .60291 L
.7361 .60291 L
.73624 .60291 L
.73637 .60291 L
Mistroke
.7365 .60292 L
.73663 .60292 L
.73677 .60292 L
.7369 .60292 L
.73703 .60292 L
.73717 .60292 L
.7373 .60292 L
.73743 .60292 L
.73756 .60292 L
.7377 .60292 L
.73783 .60292 L
.73796 .60292 L
.7381 .60293 L
.73823 .60293 L
.73836 .60293 L
.73849 .60293 L
.73863 .60293 L
.73876 .60293 L
.73889 .60293 L
.73903 .60293 L
.73916 .60293 L
.73929 .60293 L
.73942 .60293 L
.73956 .60293 L
.73969 .60293 L
.73982 .60294 L
.73996 .60294 L
.74009 .60294 L
.74022 .60294 L
.74035 .60294 L
.74049 .60294 L
.74062 .60294 L
.74075 .60294 L
.74089 .60294 L
.74102 .60294 L
.74115 .60294 L
.74128 .60294 L
.74142 .60295 L
.74155 .60295 L
.74168 .60295 L
.74182 .60295 L
.74195 .60295 L
.74208 .60295 L
.74221 .60295 L
.74235 .60295 L
.74248 .60295 L
.74261 .60295 L
.74275 .60295 L
.74288 .60295 L
.74301 .60295 L
Mistroke
.74314 .60296 L
.74328 .60296 L
.74341 .60296 L
.74354 .60296 L
.74368 .60296 L
.74381 .60296 L
.74394 .60296 L
.74407 .60296 L
.74421 .60296 L
.74434 .60296 L
.74447 .60296 L
.74461 .60296 L
.74474 .60296 L
.74487 .60297 L
.745 .60297 L
.74514 .60297 L
.74527 .60297 L
.7454 .60297 L
.74554 .60297 L
.74567 .60297 L
.7458 .60297 L
.74593 .60297 L
.74607 .60297 L
.7462 .60297 L
.74633 .60297 L
.74647 .60297 L
.7466 .60298 L
.74673 .60298 L
.74686 .60298 L
.747 .60298 L
.74713 .60298 L
.74726 .60298 L
.7474 .60298 L
.74753 .60298 L
.74766 .60298 L
.74779 .60298 L
.74793 .60298 L
.74806 .60298 L
.74819 .60298 L
.74833 .60298 L
.74846 .60299 L
.74859 .60299 L
.74872 .60299 L
.74886 .60299 L
.74899 .60299 L
.74912 .60299 L
.74926 .60299 L
.74939 .60299 L
.74952 .60299 L
.74965 .60299 L
Mistroke
.74979 .60299 L
.74992 .60299 L
.75005 .60299 L
.75019 .60299 L
.75032 .603 L
.75045 .603 L
.75058 .603 L
.75072 .603 L
.75085 .603 L
.75098 .603 L
.75112 .603 L
.75125 .603 L
.75138 .603 L
.75151 .603 L
.75165 .603 L
.75178 .603 L
.75191 .603 L
.75205 .603 L
.75218 .60301 L
.75231 .60301 L
.75244 .60301 L
.75258 .60301 L
.75271 .60301 L
.75284 .60301 L
.75298 .60301 L
.75311 .60301 L
.75324 .60301 L
.75337 .60301 L
.75351 .60301 L
.75364 .60301 L
.75377 .60301 L
.75391 .60301 L
.75404 .60301 L
.75417 .60302 L
.7543 .60302 L
.75444 .60302 L
.75457 .60302 L
.7547 .60302 L
.75484 .60302 L
.75497 .60302 L
.7551 .60302 L
.75523 .60302 L
.75537 .60302 L
.7555 .60302 L
.75563 .60302 L
.75577 .60302 L
.7559 .60302 L
.75603 .60302 L
.75616 .60303 L
.7563 .60303 L
Mistroke
.75643 .60303 L
.75656 .60303 L
.7567 .60303 L
.75683 .60303 L
.75696 .60303 L
.7571 .60303 L
.75723 .60303 L
.75736 .60303 L
.75749 .60303 L
.75763 .60303 L
.75776 .60303 L
.75789 .60303 L
.75803 .60303 L
.75816 .60303 L
.75829 .60304 L
.75842 .60304 L
.75856 .60304 L
.75869 .60304 L
.75882 .60304 L
.75896 .60304 L
.75909 .60304 L
.75922 .60304 L
.75935 .60304 L
.75949 .60304 L
.75962 .60304 L
.75975 .60304 L
.75989 .60304 L
.76002 .60304 L
.76015 .60304 L
.76028 .60304 L
.76042 .60305 L
.76055 .60305 L
.76068 .60305 L
.76082 .60305 L
.76095 .60305 L
.76108 .60305 L
.76121 .60305 L
.76135 .60305 L
.76148 .60305 L
.76161 .60305 L
.76175 .60305 L
.76188 .60305 L
.76201 .60305 L
.76214 .60305 L
.76228 .60305 L
.76241 .60305 L
.76254 .60306 L
.76268 .60306 L
.76281 .60306 L
.76294 .60306 L
Mistroke
.76307 .60306 L
.76321 .60306 L
.76334 .60306 L
.76347 .60306 L
.76361 .60306 L
.76374 .60306 L
.76387 .60306 L
.764 .60306 L
.76414 .60306 L
.76427 .60306 L
.7644 .60306 L
.76454 .60306 L
.76467 .60306 L
.7648 .60307 L
.76493 .60307 L
.76507 .60307 L
.7652 .60307 L
.76533 .60307 L
.76547 .60307 L
.7656 .60307 L
.76573 .60307 L
.76586 .60307 L
.766 .60307 L
.76613 .60307 L
.76626 .60307 L
.7664 .60307 L
.76653 .60307 L
.76666 .60307 L
.76679 .60307 L
.76693 .60307 L
.76706 .60307 L
.76719 .60308 L
.76733 .60308 L
.76746 .60308 L
.76759 .60308 L
.76772 .60308 L
.76786 .60308 L
.76799 .60308 L
.76812 .60308 L
.76826 .60308 L
.76839 .60308 L
.76852 .60308 L
.76865 .60308 L
.76879 .60308 L
.76892 .60308 L
.76905 .60308 L
.76919 .60308 L
.76932 .60308 L
.76945 .60308 L
.76958 .60309 L
Mistroke
.76972 .60309 L
.76985 .60309 L
.76998 .60309 L
.77012 .60309 L
.77025 .60309 L
.77038 .60309 L
.77051 .60309 L
.77065 .60309 L
.77078 .60309 L
.77091 .60309 L
.77105 .60309 L
.77118 .60309 L
.77131 .60309 L
.77144 .60309 L
.77158 .60309 L
.77171 .60309 L
.77184 .60309 L
.77198 .60309 L
.77211 .60309 L
.77224 .6031 L
.77237 .6031 L
.77251 .6031 L
.77264 .6031 L
.77277 .6031 L
.77291 .6031 L
.77304 .6031 L
.77317 .6031 L
.7733 .6031 L
.77344 .6031 L
.77357 .6031 L
.7737 .6031 L
.77384 .6031 L
.77397 .6031 L
.7741 .6031 L
.77423 .6031 L
.77437 .6031 L
.7745 .6031 L
.77463 .6031 L
.77477 .60311 L
.7749 .60311 L
.77503 .60311 L
.77516 .60311 L
.7753 .60311 L
.77543 .60311 L
.77556 .60311 L
.7757 .60311 L
.77583 .60311 L
.77596 .60311 L
.77609 .60311 L
.77623 .60311 L
Mistroke
.77636 .60311 L
.77649 .60311 L
.77663 .60311 L
.77676 .60311 L
.77689 .60311 L
.77702 .60311 L
.77716 .60311 L
.77729 .60311 L
.77742 .60311 L
.77756 .60312 L
.77769 .60312 L
.77782 .60312 L
.77795 .60312 L
.77809 .60312 L
.77822 .60312 L
.77835 .60312 L
.77849 .60312 L
.77862 .60312 L
.77875 .60312 L
.77888 .60312 L
.77902 .60312 L
.77915 .60312 L
.77928 .60312 L
.77942 .60312 L
.77955 .60312 L
.77968 .60312 L
.77982 .60312 L
.77995 .60312 L
.78008 .60312 L
.78021 .60312 L
.78035 .60313 L
.78048 .60313 L
.78061 .60313 L
.78075 .60313 L
.78088 .60313 L
.78101 .60313 L
.78114 .60313 L
.78128 .60313 L
.78141 .60313 L
.78154 .60313 L
.78168 .60313 L
.78181 .60313 L
.78194 .60313 L
.78207 .60313 L
.78221 .60313 L
.78234 .60313 L
.78247 .60313 L
.78261 .60313 L
.78274 .60313 L
.78287 .60313 L
Mistroke
.783 .60313 L
.78314 .60313 L
.78327 .60314 L
.7834 .60314 L
.78354 .60314 L
.78367 .60314 L
.7838 .60314 L
.78393 .60314 L
.78407 .60314 L
.7842 .60314 L
.78433 .60314 L
.78447 .60314 L
.7846 .60314 L
.78473 .60314 L
.78486 .60314 L
.785 .60314 L
.78513 .60314 L
.78526 .60314 L
.7854 .60314 L
.78553 .60314 L
.78566 .60314 L
.78579 .60314 L
.78593 .60314 L
.78606 .60314 L
.78619 .60314 L
.78633 .60315 L
.78646 .60315 L
.78659 .60315 L
.78672 .60315 L
.78686 .60315 L
.78699 .60315 L
.78712 .60315 L
.78726 .60315 L
.78739 .60315 L
.78752 .60315 L
.78765 .60315 L
.78779 .60315 L
.78792 .60315 L
.78805 .60315 L
.78819 .60315 L
.78832 .60315 L
.78845 .60315 L
.78858 .60315 L
.78872 .60315 L
.78885 .60315 L
.78898 .60315 L
.78912 .60315 L
.78925 .60315 L
.78938 .60315 L
.78951 .60316 L
Mistroke
.78965 .60316 L
.78978 .60316 L
.78991 .60316 L
.79005 .60316 L
.79018 .60316 L
.79031 .60316 L
.79044 .60316 L
.79058 .60316 L
.79071 .60316 L
.79084 .60316 L
.79098 .60316 L
.79111 .60316 L
.79124 .60316 L
.79137 .60316 L
.79151 .60316 L
.79164 .60316 L
.79177 .60316 L
.79191 .60316 L
.79204 .60316 L
.79217 .60316 L
.7923 .60316 L
.79244 .60316 L
.79257 .60316 L
.7927 .60316 L
.79284 .60316 L
.79297 .60317 L
.7931 .60317 L
.79323 .60317 L
.79337 .60317 L
.7935 .60317 L
.79363 .60317 L
.79377 .60317 L
.7939 .60317 L
.79403 .60317 L
.79416 .60317 L
.7943 .60317 L
.79443 .60317 L
.79456 .60317 L
.7947 .60317 L
.79483 .60317 L
.79496 .60317 L
.79509 .60317 L
.79523 .60317 L
.79536 .60317 L
.79549 .60317 L
.79563 .60317 L
.79576 .60317 L
.79589 .60317 L
.79602 .60317 L
.79616 .60317 L
Mistroke
.79629 .60317 L
.79642 .60317 L
.79656 .60318 L
.79669 .60318 L
.79682 .60318 L
.79695 .60318 L
.79709 .60318 L
.79722 .60318 L
.79735 .60318 L
.79749 .60318 L
.79762 .60318 L
.79775 .60318 L
.79788 .60318 L
.79802 .60318 L
.79815 .60318 L
.79828 .60318 L
.79842 .60318 L
.79855 .60318 L
.79868 .60318 L
.79881 .60318 L
.79895 .60318 L
.79908 .60318 L
.79921 .60318 L
.79935 .60318 L
.79948 .60318 L
.79961 .60318 L
.79974 .60318 L
.79988 .60318 L
.80001 .60318 L
.80014 .60318 L
.80028 .60319 L
.80041 .60319 L
.80054 .60319 L
.80067 .60319 L
.80081 .60319 L
.80094 .60319 L
.80107 .60319 L
.80121 .60319 L
.80134 .60319 L
.80147 .60319 L
.80161 .60319 L
.80174 .60319 L
.80187 .60319 L
.802 .60319 L
.80214 .60319 L
.80227 .60319 L
.8024 .60319 L
.80254 .60319 L
.80267 .60319 L
.8028 .60319 L
Mistroke
.80293 .60319 L
.80307 .60319 L
.8032 .60319 L
.80333 .60319 L
.80347 .60319 L
.8036 .60319 L
.80373 .60319 L
.80386 .60319 L
.804 .60319 L
.80413 .60319 L
.80426 .6032 L
.8044 .6032 L
.80453 .6032 L
.80466 .6032 L
.80479 .6032 L
.80493 .6032 L
.80506 .6032 L
.80519 .6032 L
.80533 .6032 L
.80546 .6032 L
.80559 .6032 L
.80572 .6032 L
.80586 .6032 L
.80599 .6032 L
.80612 .6032 L
.80626 .6032 L
.80639 .6032 L
.80652 .6032 L
.80665 .6032 L
.80679 .6032 L
.80692 .6032 L
.80705 .6032 L
.80719 .6032 L
.80732 .6032 L
.80745 .6032 L
.80758 .6032 L
.80772 .6032 L
.80785 .6032 L
.80798 .6032 L
.80812 .6032 L
.80825 .6032 L
.80838 .60321 L
.80851 .60321 L
.80865 .60321 L
.80878 .60321 L
.80891 .60321 L
.80905 .60321 L
.80918 .60321 L
.80931 .60321 L
.80944 .60321 L
Mistroke
.80958 .60321 L
.80971 .60321 L
.80984 .60321 L
.80998 .60321 L
.81011 .60321 L
.81024 .60321 L
.81037 .60321 L
.81051 .60321 L
.81064 .60321 L
.81077 .60321 L
.81091 .60321 L
.81104 .60321 L
.81117 .60321 L
.8113 .60321 L
.81144 .60321 L
.81157 .60321 L
.8117 .60321 L
.81184 .60321 L
.81197 .60321 L
.8121 .60321 L
.81223 .60321 L
.81237 .60321 L
.8125 .60321 L
.81263 .60321 L
.81277 .60321 L
.8129 .60322 L
.81303 .60322 L
.81316 .60322 L
.8133 .60322 L
.81343 .60322 L
.81356 .60322 L
.8137 .60322 L
.81383 .60322 L
.81396 .60322 L
.81409 .60322 L
.81423 .60322 L
.81436 .60322 L
.81449 .60322 L
.81463 .60322 L
.81476 .60322 L
.81489 .60322 L
.81502 .60322 L
.81516 .60322 L
.81529 .60322 L
.81542 .60322 L
.81556 .60322 L
.81569 .60322 L
.81582 .60322 L
.81595 .60322 L
.81609 .60322 L
Mistroke
.81622 .60322 L
.81635 .60322 L
.81649 .60322 L
.81662 .60322 L
.81675 .60322 L
.81688 .60322 L
.81702 .60322 L
.81715 .60322 L
.81728 .60322 L
.81742 .60322 L
.81755 .60323 L
.81768 .60323 L
.81781 .60323 L
.81795 .60323 L
.81808 .60323 L
.81821 .60323 L
.81835 .60323 L
.81848 .60323 L
.81861 .60323 L
.81874 .60323 L
.81888 .60323 L
.81901 .60323 L
.81914 .60323 L
.81928 .60323 L
.81941 .60323 L
.81954 .60323 L
.81967 .60323 L
.81981 .60323 L
.81994 .60323 L
.82007 .60323 L
.82021 .60323 L
.82034 .60323 L
.82047 .60323 L
.8206 .60323 L
.82074 .60323 L
.82087 .60323 L
.821 .60323 L
.82114 .60323 L
.82127 .60323 L
.8214 .60323 L
.82153 .60323 L
.82167 .60323 L
.8218 .60323 L
.82193 .60323 L
.82207 .60323 L
.8222 .60323 L
.82233 .60323 L
.82246 .60323 L
.8226 .60323 L
.82273 .60324 L
Mistroke
.82286 .60324 L
.823 .60324 L
.82313 .60324 L
.82326 .60324 L
.82339 .60324 L
.82353 .60324 L
.82366 .60324 L
.82379 .60324 L
.82393 .60324 L
.82406 .60324 L
.82419 .60324 L
.82433 .60324 L
.82446 .60324 L
.82459 .60324 L
.82472 .60324 L
.82486 .60324 L
.82499 .60324 L
.82512 .60324 L
.82526 .60324 L
.82539 .60324 L
.82552 .60324 L
.82565 .60324 L
.82579 .60324 L
.82592 .60324 L
.82605 .60324 L
.82619 .60324 L
.82632 .60324 L
.82645 .60324 L
.82658 .60324 L
.82672 .60324 L
.82685 .60324 L
.82698 .60324 L
.82712 .60324 L
.82725 .60324 L
.82738 .60324 L
.82751 .60324 L
.82765 .60324 L
.82778 .60324 L
.82791 .60324 L
.82805 .60324 L
.82818 .60324 L
.82831 .60325 L
.82844 .60325 L
.82858 .60325 L
.82871 .60325 L
.82884 .60325 L
.82898 .60325 L
.82911 .60325 L
.82924 .60325 L
.82937 .60325 L
Mistroke
.82951 .60325 L
.82964 .60325 L
.82977 .60325 L
.82991 .60325 L
.83004 .60325 L
.83017 .60325 L
.8303 .60325 L
.83044 .60325 L
.83057 .60325 L
.8307 .60325 L
.83084 .60325 L
.83097 .60325 L
.8311 .60325 L
.83123 .60325 L
.83137 .60325 L
.8315 .60325 L
.83163 .60325 L
.83177 .60325 L
.8319 .60325 L
.83203 .60325 L
.83216 .60325 L
.8323 .60325 L
.83243 .60325 L
.83256 .60325 L
.8327 .60325 L
.83283 .60325 L
.83296 .60325 L
.83309 .60325 L
.83323 .60325 L
.83336 .60325 L
.83349 .60325 L
.83363 .60325 L
.83376 .60325 L
.83389 .60325 L
.83402 .60325 L
.83416 .60325 L
.83429 .60325 L
.83442 .60325 L
.83456 .60326 L
.83469 .60326 L
.83482 .60326 L
.83495 .60326 L
.83509 .60326 L
.83522 .60326 L
.83535 .60326 L
.83549 .60326 L
.83562 .60326 L
.83575 .60326 L
.83588 .60326 L
.83602 .60326 L
Mistroke
.83615 .60326 L
.83628 .60326 L
.83642 .60326 L
.83655 .60326 L
.83668 .60326 L
.83681 .60326 L
.83695 .60326 L
.83708 .60326 L
.83721 .60326 L
.83735 .60326 L
.83748 .60326 L
.83761 .60326 L
.83774 .60326 L
.83788 .60326 L
.83801 .60326 L
.83814 .60326 L
.83828 .60326 L
.83841 .60326 L
.83854 .60326 L
.83867 .60326 L
.83881 .60326 L
.83894 .60326 L
.83907 .60326 L
.83921 .60326 L
.83934 .60326 L
.83947 .60326 L
.8396 .60326 L
.83974 .60326 L
.83987 .60326 L
.84 .60326 L
.84014 .60326 L
.84027 .60326 L
.8404 .60326 L
.84053 .60326 L
.84067 .60326 L
.8408 .60326 L
.84093 .60326 L
.84107 .60326 L
.8412 .60326 L
.84133 .60326 L
.84146 .60327 L
.8416 .60327 L
.84173 .60327 L
.84186 .60327 L
.842 .60327 L
.84213 .60327 L
.84226 .60327 L
.84239 .60327 L
.84253 .60327 L
.84266 .60327 L
Mistroke
.84279 .60327 L
.84293 .60327 L
.84306 .60327 L
.84319 .60327 L
.84332 .60327 L
.84346 .60327 L
.84359 .60327 L
.84372 .60327 L
.84386 .60327 L
.84399 .60327 L
.84412 .60327 L
.84425 .60327 L
.84439 .60327 L
.84452 .60327 L
.84465 .60327 L
.84479 .60327 L
.84492 .60327 L
.84505 .60327 L
.84518 .60327 L
.84532 .60327 L
.84545 .60327 L
.84558 .60327 L
.84572 .60327 L
.84585 .60327 L
.84598 .60327 L
.84612 .60327 L
.84625 .60327 L
.84638 .60327 L
.84651 .60327 L
.84665 .60327 L
.84678 .60327 L
.84691 .60327 L
.84705 .60327 L
.84718 .60327 L
.84731 .60327 L
.84744 .60327 L
.84758 .60327 L
.84771 .60327 L
.84784 .60327 L
.84798 .60327 L
.84811 .60327 L
.84824 .60327 L
.84837 .60327 L
.84851 .60327 L
.84864 .60327 L
.84877 .60327 L
.84891 .60327 L
.84904 .60327 L
.84917 .60327 L
.8493 .60327 L
Mistroke
.84944 .60328 L
.84957 .60328 L
.8497 .60328 L
.84984 .60328 L
.84997 .60328 L
.8501 .60328 L
.85023 .60328 L
.85037 .60328 L
.8505 .60328 L
.85063 .60328 L
.85077 .60328 L
.8509 .60328 L
.85103 .60328 L
.85116 .60328 L
.8513 .60328 L
.85143 .60328 L
.85156 .60328 L
.8517 .60328 L
.85183 .60328 L
.85196 .60328 L
.85209 .60328 L
.85223 .60328 L
.85236 .60328 L
.85249 .60328 L
.85263 .60328 L
.85276 .60328 L
.85289 .60328 L
.85302 .60328 L
.85316 .60328 L
.85329 .60328 L
.85342 .60328 L
.85356 .60328 L
.85369 .60328 L
.85382 .60328 L
.85395 .60328 L
.85409 .60328 L
.85422 .60328 L
.85435 .60328 L
.85449 .60328 L
.85462 .60328 L
.85475 .60328 L
.85488 .60328 L
.85502 .60328 L
.85515 .60328 L
.85528 .60328 L
.85542 .60328 L
.85555 .60328 L
.85568 .60328 L
.85581 .60328 L
.85595 .60328 L
Mistroke
.85608 .60328 L
.85621 .60328 L
.85635 .60328 L
.85648 .60328 L
.85661 .60328 L
.85674 .60328 L
.85688 .60328 L
.85701 .60328 L
.85714 .60328 L
.85728 .60328 L
.85741 .60328 L
.85754 .60328 L
.85767 .60328 L
.85781 .60328 L
.85794 .60328 L
.85807 .60328 L
.85821 .60328 L
.85834 .60328 L
.85847 .60328 L
.8586 .60328 L
.85874 .60329 L
.85887 .60329 L
.859 .60329 L
.85914 .60329 L
.85927 .60329 L
.8594 .60329 L
.85953 .60329 L
.85967 .60329 L
.8598 .60329 L
.85993 .60329 L
.86007 .60329 L
.8602 .60329 L
.86033 .60329 L
.86046 .60329 L
.8606 .60329 L
.86073 .60329 L
.86086 .60329 L
.861 .60329 L
.86113 .60329 L
.86126 .60329 L
.86139 .60329 L
.86153 .60329 L
.86166 .60329 L
.86179 .60329 L
.86193 .60329 L
.86206 .60329 L
.86219 .60329 L
.86232 .60329 L
.86246 .60329 L
.86259 .60329 L
Mistroke
.86272 .60329 L
.86286 .60329 L
.86299 .60329 L
.86312 .60329 L
.86325 .60329 L
.86339 .60329 L
.86352 .60329 L
.86365 .60329 L
.86379 .60329 L
.86392 .60329 L
.86405 .60329 L
.86418 .60329 L
.86432 .60329 L
.86445 .60329 L
.86458 .60329 L
.86472 .60329 L
.86485 .60329 L
.86498 .60329 L
.86511 .60329 L
.86525 .60329 L
.86538 .60329 L
.86551 .60329 L
.86565 .60329 L
.86578 .60329 L
.86591 .60329 L
.86604 .60329 L
.86618 .60329 L
.86631 .60329 L
.86644 .60329 L
.86658 .60329 L
.86671 .60329 L
.86684 .60329 L
.86697 .60329 L
.86711 .60329 L
.86724 .60329 L
.86737 .60329 L
.86751 .60329 L
.86764 .60329 L
.86777 .60329 L
.8679 .60329 L
.86804 .60329 L
.86817 .60329 L
.8683 .60329 L
.86844 .60329 L
.86857 .60329 L
.8687 .60329 L
.86884 .60329 L
.86897 .60329 L
.8691 .60329 L
.86923 .60329 L
Mistroke
.86937 .60329 L
.8695 .60329 L
.86963 .60329 L
.86977 .60329 L
.8699 .60329 L
.87003 .60329 L
.87016 .60329 L
.8703 .60329 L
.87043 .60329 L
.87056 .6033 L
.8707 .6033 L
.87083 .6033 L
.87096 .6033 L
.87109 .6033 L
.87123 .6033 L
.87136 .6033 L
.87149 .6033 L
.87163 .6033 L
.87176 .6033 L
.87189 .6033 L
.87202 .6033 L
.87216 .6033 L
.87229 .6033 L
.87242 .6033 L
.87256 .6033 L
.87269 .6033 L
.87282 .6033 L
.87295 .6033 L
.87309 .6033 L
.87322 .6033 L
.87335 .6033 L
.87349 .6033 L
.87362 .6033 L
.87375 .6033 L
.87388 .6033 L
.87402 .6033 L
.87415 .6033 L
.87428 .6033 L
.87442 .6033 L
.87455 .6033 L
.87468 .6033 L
.87481 .6033 L
.87495 .6033 L
.87508 .6033 L
.87521 .6033 L
.87535 .6033 L
.87548 .6033 L
.87561 .6033 L
.87574 .6033 L
.87588 .6033 L
Mistroke
.87601 .6033 L
.87614 .6033 L
.87628 .6033 L
.87641 .6033 L
.87654 .6033 L
.87667 .6033 L
.87681 .6033 L
.87694 .6033 L
.87707 .6033 L
.87721 .6033 L
.87734 .6033 L
.87747 .6033 L
.8776 .6033 L
.87774 .6033 L
.87787 .6033 L
.878 .6033 L
.87814 .6033 L
.87827 .6033 L
.8784 .6033 L
.87853 .6033 L
.87867 .6033 L
.8788 .6033 L
.87893 .6033 L
.87907 .6033 L
.8792 .6033 L
.87933 .6033 L
.87946 .6033 L
.8796 .6033 L
.87973 .6033 L
.87986 .6033 L
.88 .6033 L
.88013 .6033 L
.88026 .6033 L
.88039 .6033 L
.88053 .6033 L
.88066 .6033 L
.88079 .6033 L
.88093 .6033 L
.88106 .6033 L
.88119 .6033 L
.88132 .6033 L
.88146 .6033 L
.88159 .6033 L
.88172 .6033 L
.88186 .6033 L
.88199 .6033 L
.88212 .6033 L
.88225 .6033 L
.88239 .6033 L
.88252 .6033 L
Mistroke
.88265 .6033 L
.88279 .6033 L
.88292 .6033 L
.88305 .6033 L
.88318 .6033 L
.88332 .6033 L
.88345 .6033 L
.88358 .6033 L
.88372 .6033 L
.88385 .6033 L
.88398 .6033 L
.88411 .6033 L
.88425 .6033 L
.88438 .6033 L
.88451 .6033 L
.88465 .6033 L
.88478 .6033 L
.88491 .6033 L
.88504 .6033 L
.88518 .6033 L
.88531 .6033 L
.88544 .6033 L
.88558 .6033 L
.88571 .6033 L
.88584 .6033 L
.88597 .6033 L
.88611 .6033 L
.88624 .6033 L
.88637 .6033 L
.88651 .6033 L
.88664 .6033 L
.88677 .6033 L
.8869 .6033 L
.88704 .6033 L
.88717 .6033 L
.8873 .60331 L
.88744 .60331 L
.88757 .60331 L
.8877 .60331 L
.88783 .60331 L
.88797 .60331 L
.8881 .60331 L
.88823 .60331 L
.88837 .60331 L
.8885 .60331 L
.88863 .60331 L
.88876 .60331 L
.8889 .60331 L
.88903 .60331 L
.88916 .60331 L
Mistroke
.8893 .60331 L
.88943 .60331 L
.88956 .60331 L
.88969 .60331 L
.88983 .60331 L
.88996 .60331 L
.89009 .60331 L
.89023 .60331 L
.89036 .60331 L
.89049 .60331 L
.89063 .60331 L
.89076 .60331 L
.89089 .60331 L
.89102 .60331 L
.89116 .60331 L
.89129 .60331 L
.89142 .60331 L
.89156 .60331 L
.89169 .60331 L
.89182 .60331 L
.89195 .60331 L
.89209 .60331 L
.89222 .60331 L
.89235 .60331 L
.89249 .60331 L
.89262 .60331 L
.89275 .60331 L
.89288 .60331 L
.89302 .60331 L
.89315 .60331 L
.89328 .60331 L
.89342 .60331 L
.89355 .60331 L
.89368 .60331 L
.89381 .60331 L
.89395 .60331 L
.89408 .60331 L
.89421 .60331 L
.89435 .60331 L
.89448 .60331 L
.89461 .60331 L
.89474 .60331 L
.89488 .60331 L
.89501 .60331 L
.89514 .60331 L
.89528 .60331 L
.89541 .60331 L
.89554 .60331 L
.89567 .60331 L
.89581 .60331 L
Mistroke
.89594 .60331 L
.89607 .60331 L
.89621 .60331 L
.89634 .60331 L
.89647 .60331 L
.8966 .60331 L
.89674 .60331 L
.89687 .60331 L
.897 .60331 L
.89714 .60331 L
.89727 .60331 L
.8974 .60331 L
.89753 .60331 L
.89767 .60331 L
.8978 .60331 L
.89793 .60331 L
.89807 .60331 L
.8982 .60331 L
.89833 .60331 L
.89846 .60331 L
.8986 .60331 L
.89873 .60331 L
.89886 .60331 L
.899 .60331 L
.89913 .60331 L
.89926 .60331 L
.89939 .60331 L
.89953 .60331 L
.89966 .60331 L
.89979 .60331 L
.89993 .60331 L
.90006 .60331 L
.90019 .60331 L
.90032 .60331 L
.90046 .60331 L
.90059 .60331 L
.90072 .60331 L
.90086 .60331 L
.90099 .60331 L
.90112 .60331 L
.90125 .60331 L
.90139 .60331 L
.90152 .60331 L
.90165 .60331 L
.90179 .60331 L
.90192 .60331 L
.90205 .60331 L
.90218 .60331 L
.90232 .60331 L
.90245 .60331 L
Mistroke
.90258 .60331 L
.90272 .60331 L
.90285 .60331 L
.90298 .60331 L
.90311 .60331 L
.90325 .60331 L
.90338 .60331 L
.90351 .60331 L
.90365 .60331 L
.90378 .60331 L
.90391 .60331 L
.90404 .60331 L
.90418 .60331 L
.90431 .60331 L
.90444 .60331 L
.90458 .60331 L
.90471 .60331 L
.90484 .60331 L
.90497 .60331 L
.90511 .60331 L
.90524 .60331 L
.90537 .60331 L
.90551 .60331 L
.90564 .60331 L
.90577 .60331 L
.9059 .60331 L
.90604 .60331 L
.90617 .60331 L
.9063 .60331 L
.90644 .60331 L
.90657 .60331 L
.9067 .60331 L
.90683 .60331 L
.90697 .60331 L
.9071 .60331 L
.90723 .60331 L
.90737 .60331 L
.9075 .60331 L
.90763 .60331 L
.90776 .60331 L
.9079 .60331 L
.90803 .60331 L
.90816 .60331 L
.9083 .60331 L
.90843 .60331 L
.90856 .60331 L
.90869 .60331 L
.90883 .60331 L
.90896 .60331 L
.90909 .60331 L
Mistroke
.90923 .60331 L
.90936 .60331 L
.90949 .60331 L
.90962 .60331 L
.90976 .60331 L
.90989 .60331 L
.91002 .60331 L
.91016 .60331 L
.91029 .60331 L
.91042 .60331 L
.91055 .60331 L
.91069 .60331 L
.91082 .60331 L
.91095 .60331 L
.91109 .60331 L
.91122 .60331 L
.91135 .60331 L
.91148 .60331 L
.91162 .60331 L
.91175 .60331 L
.91188 .60331 L
.91202 .60331 L
.91215 .60331 L
.91228 .60331 L
.91241 .60331 L
.91255 .60331 L
.91268 .60331 L
.91281 .60331 L
.91295 .60331 L
.91308 .60331 L
.91321 .60331 L
.91335 .60331 L
.91348 .60331 L
.91361 .60331 L
.91374 .60331 L
.91388 .60331 L
.91401 .60331 L
.91414 .60331 L
.91428 .60331 L
.91441 .60331 L
.91454 .60331 L
.91467 .60331 L
.91481 .60331 L
.91494 .60331 L
.91507 .60331 L
.91521 .60331 L
.91534 .60331 L
.91547 .60331 L
.9156 .60331 L
.91574 .60331 L
Mistroke
.91587 .60331 L
.916 .60331 L
.91614 .60331 L
.91627 .60331 L
.9164 .60331 L
.91653 .60331 L
.91667 .60331 L
.9168 .60331 L
.91693 .60331 L
.91707 .60331 L
.9172 .60331 L
.91733 .60331 L
.91746 .60331 L
.9176 .60331 L
.91773 .60332 L
.91786 .60332 L
.918 .60332 L
.91813 .60332 L
.91826 .60332 L
.91839 .60332 L
.91853 .60332 L
.91866 .60332 L
.91879 .60332 L
.91893 .60332 L
.91906 .60332 L
.91919 .60332 L
.91932 .60332 L
.91946 .60332 L
.91959 .60332 L
.91972 .60332 L
.91986 .60332 L
.91999 .60332 L
.92012 .60332 L
.92025 .60332 L
.92039 .60332 L
.92052 .60332 L
.92065 .60332 L
.92079 .60332 L
.92092 .60332 L
.92105 .60332 L
.92118 .60332 L
.92132 .60332 L
.92145 .60332 L
.92158 .60332 L
.92172 .60332 L
.92185 .60332 L
.92198 .60332 L
.92211 .60332 L
.92225 .60332 L
.92238 .60332 L
Mistroke
.92251 .60332 L
.92265 .60332 L
.92278 .60332 L
.92291 .60332 L
.92304 .60332 L
.92318 .60332 L
.92331 .60332 L
.92344 .60332 L
.92358 .60332 L
.92371 .60332 L
.92384 .60332 L
.92397 .60332 L
.92411 .60332 L
.92424 .60332 L
.92437 .60332 L
.92451 .60332 L
.92464 .60332 L
.92477 .60332 L
.9249 .60332 L
.92504 .60332 L
.92517 .60332 L
.9253 .60332 L
.92544 .60332 L
.92557 .60332 L
.9257 .60332 L
.92583 .60332 L
.92597 .60332 L
.9261 .60332 L
.92623 .60332 L
.92637 .60332 L
.9265 .60332 L
.92663 .60332 L
.92676 .60332 L
.9269 .60332 L
.92703 .60332 L
.92716 .60332 L
.9273 .60332 L
.92743 .60332 L
.92756 .60332 L
.92769 .60332 L
.92783 .60332 L
.92796 .60332 L
.92809 .60332 L
.92823 .60332 L
.92836 .60332 L
.92849 .60332 L
.92862 .60332 L
.92876 .60332 L
.92889 .60332 L
.92902 .60332 L
Mistroke
.92916 .60332 L
.92929 .60332 L
.92942 .60332 L
.92955 .60332 L
.92969 .60332 L
.92982 .60332 L
.92995 .60332 L
.93009 .60332 L
.93022 .60332 L
.93035 .60332 L
.93048 .60332 L
.93062 .60332 L
.93075 .60332 L
.93088 .60332 L
.93102 .60332 L
.93115 .60332 L
.93128 .60332 L
.93141 .60332 L
.93155 .60332 L
.93168 .60332 L
.93181 .60332 L
.93195 .60332 L
.93208 .60332 L
.93221 .60332 L
.93234 .60332 L
.93248 .60332 L
.93261 .60332 L
.93274 .60332 L
.93288 .60332 L
.93301 .60332 L
.93314 .60332 L
.93327 .60332 L
.93341 .60332 L
.93354 .60332 L
.93367 .60332 L
.93381 .60332 L
.93394 .60332 L
.93407 .60332 L
.9342 .60332 L
.93434 .60332 L
.93447 .60332 L
.9346 .60332 L
.93474 .60332 L
.93487 .60332 L
.935 .60332 L
.93513 .60332 L
.93527 .60332 L
.9354 .60332 L
.93553 .60332 L
.93567 .60332 L
Mistroke
.9358 .60332 L
.93593 .60332 L
.93607 .60332 L
.9362 .60332 L
.93633 .60332 L
.93646 .60332 L
.9366 .60332 L
.93673 .60332 L
.93686 .60332 L
.937 .60332 L
.93713 .60332 L
.93726 .60332 L
.93739 .60332 L
.93753 .60332 L
.93766 .60332 L
.93779 .60332 L
.93793 .60332 L
.93806 .60332 L
.93819 .60332 L
.93832 .60332 L
.93846 .60332 L
.93859 .60332 L
.93872 .60332 L
.93886 .60332 L
.93899 .60332 L
.93912 .60332 L
.93925 .60332 L
.93939 .60332 L
.93952 .60332 L
.93965 .60332 L
.93979 .60332 L
.93992 .60332 L
.94005 .60332 L
.94018 .60332 L
.94032 .60332 L
.94045 .60332 L
.94058 .60332 L
.94072 .60332 L
.94085 .60332 L
.94098 .60332 L
.94111 .60332 L
.94125 .60332 L
.94138 .60332 L
.94151 .60332 L
.94165 .60332 L
.94178 .60332 L
.94191 .60332 L
.94204 .60332 L
.94218 .60332 L
.94231 .60332 L
Mistroke
.94244 .60332 L
.94258 .60332 L
.94271 .60332 L
.94284 .60332 L
.94297 .60332 L
.94311 .60332 L
.94324 .60332 L
.94337 .60332 L
.94351 .60332 L
.94364 .60332 L
.94377 .60332 L
.9439 .60332 L
.94404 .60332 L
.94417 .60332 L
.9443 .60332 L
.94444 .60332 L
.94457 .60332 L
.9447 .60332 L
.94483 .60332 L
.94497 .60332 L
.9451 .60332 L
.94523 .60332 L
.94537 .60332 L
.9455 .60332 L
.94563 .60332 L
.94576 .60332 L
.9459 .60332 L
.94603 .60332 L
.94616 .60332 L
.9463 .60332 L
.94643 .60332 L
.94656 .60332 L
.94669 .60332 L
.94683 .60332 L
.94696 .60332 L
.94709 .60332 L
.94723 .60332 L
.94736 .60332 L
.94749 .60332 L
.94762 .60332 L
.94776 .60332 L
.94789 .60332 L
.94802 .60332 L
.94816 .60332 L
.94829 .60332 L
.94842 .60332 L
.94855 .60332 L
.94869 .60332 L
.94882 .60332 L
.94895 .60332 L
Mistroke
.94909 .60332 L
.94922 .60332 L
.94935 .60332 L
.94948 .60332 L
.94962 .60332 L
.94975 .60332 L
.94988 .60332 L
.95002 .60332 L
.95015 .60332 L
.95028 .60332 L
.95041 .60332 L
.95055 .60332 L
.95068 .60332 L
.95081 .60332 L
.95095 .60332 L
.95108 .60332 L
.95121 .60332 L
.95134 .60332 L
.95148 .60332 L
.95161 .60332 L
.95174 .60332 L
.95188 .60332 L
.95201 .60332 L
.95214 .60332 L
.95227 .60332 L
.95241 .60332 L
.95254 .60332 L
.95267 .60332 L
.95281 .60332 L
.95294 .60332 L
.95307 .60332 L
.9532 .60332 L
.95334 .60332 L
.95347 .60332 L
.9536 .60332 L
.95374 .60332 L
.95387 .60332 L
.954 .60332 L
.95413 .60332 L
.95427 .60332 L
.9544 .60332 L
.95453 .60332 L
.95467 .60332 L
.9548 .60332 L
.95493 .60332 L
.95506 .60332 L
.9552 .60332 L
.95533 .60332 L
.95546 .60332 L
.9556 .60332 L
Mistroke
.95573 .60332 L
.95586 .60332 L
.95599 .60332 L
.95613 .60332 L
.95626 .60332 L
.95639 .60332 L
.95653 .60332 L
.95666 .60332 L
.95679 .60332 L
.95692 .60332 L
.95706 .60332 L
.95719 .60332 L
.95732 .60332 L
.95746 .60332 L
.95759 .60332 L
.95772 .60332 L
.95786 .60332 L
.95799 .60332 L
.95812 .60332 L
.95825 .60332 L
.95839 .60332 L
.95852 .60332 L
.95865 .60332 L
.95879 .60332 L
.95892 .60332 L
.95905 .60332 L
.95918 .60332 L
.95932 .60332 L
.95945 .60332 L
.95958 .60332 L
.95972 .60332 L
.95985 .60332 L
.95998 .60332 L
.96011 .60332 L
.96025 .60332 L
.96038 .60332 L
.96051 .60332 L
.96065 .60332 L
.96078 .60332 L
.96091 .60332 L
.96104 .60332 L
.96118 .60332 L
.96131 .60332 L
.96144 .60332 L
.96158 .60332 L
.96171 .60332 L
.96184 .60332 L
.96197 .60332 L
.96211 .60332 L
.96224 .60332 L
Mistroke
.96237 .60332 L
.96251 .60332 L
.96264 .60332 L
.96277 .60332 L
.9629 .60332 L
.96304 .60332 L
.96317 .60332 L
.9633 .60332 L
.96344 .60332 L
.96357 .60332 L
.9637 .60332 L
.96383 .60332 L
.96397 .60332 L
.9641 .60332 L
.96423 .60332 L
.96437 .60332 L
.9645 .60332 L
.96463 .60332 L
.96476 .60332 L
.9649 .60332 L
.96503 .60332 L
.96516 .60332 L
.9653 .60332 L
.96543 .60332 L
.96556 .60332 L
.96569 .60332 L
.96583 .60332 L
.96596 .60332 L
.96609 .60332 L
.96623 .60332 L
.96636 .60332 L
.96649 .60332 L
.96662 .60332 L
.96676 .60332 L
.96689 .60332 L
.96702 .60332 L
.96716 .60332 L
.96729 .60332 L
.96742 .60332 L
.96755 .60332 L
.96769 .60332 L
.96782 .60332 L
.96795 .60332 L
.96809 .60332 L
.96822 .60332 L
.96835 .60332 L
.96848 .60332 L
.96862 .60332 L
.96875 .60332 L
.96888 .60332 L
Mistroke
.96902 .60332 L
.96915 .60332 L
.96928 .60332 L
.96941 .60332 L
.96955 .60332 L
.96968 .60332 L
.96981 .60332 L
.96995 .60332 L
.97008 .60332 L
.97021 .60332 L
.97034 .60332 L
.97048 .60332 L
.97061 .60332 L
.97074 .60332 L
.97088 .60332 L
.97101 .60332 L
.97114 .60332 L
.97127 .60332 L
.97141 .60332 L
.97154 .60332 L
.97167 .60332 L
.97181 .60332 L
.97194 .60332 L
.97207 .60332 L
.9722 .60332 L
.97234 .60332 L
.97247 .60332 L
.9726 .60332 L
.97274 .60332 L
.97287 .60332 L
.973 .60332 L
.97313 .60332 L
.97327 .60332 L
.9734 .60332 L
.97353 .60332 L
.97367 .60332 L
.9738 .60332 L
.97393 .60332 L
.97406 .60332 L
.9742 .60332 L
.97433 .60332 L
.97446 .60332 L
.9746 .60332 L
.97473 .60332 L
.97486 .60332 L
.97499 .60332 L
.97513 .60332 L
.97526 .60332 L
.97539 .60332 L
.97553 .60332 L
Mistroke
.97566 .60332 L
.97579 .60332 L
.97592 .60332 L
.97606 .60332 L
.97619 .60332 L
Mfstroke
[ .02 ] 0 setdash
.15541 0 m
.15548 .00056 L
.15561 .00167 L
.15575 .00278 L
.15588 .00389 L
.15601 .00499 L
.15614 .0061 L
.15628 .0072 L
.15641 .0083 L
.15654 .00939 L
.15668 .01048 L
.15681 .01157 L
.15694 .01266 L
.15707 .01375 L
.15721 .01483 L
.15734 .01591 L
.15747 .01699 L
.15761 .01807 L
.15774 .01915 L
.15787 .02023 L
.158 .0213 L
.15814 .02237 L
.15827 .02344 L
.1584 .02451 L
.15854 .02558 L
.15867 .02664 L
.1588 .02771 L
.15893 .02877 L
.15907 .02982 L
.1592 .03087 L
.15933 .03191 L
.15947 .03296 L
.1596 .034 L
.15973 .03504 L
.15986 .03607 L
.16 .0371 L
.16013 .03813 L
.16026 .03916 L
.1604 .04018 L
.16053 .04121 L
.16066 .04223 L
.16079 .04326 L
.16093 .04428 L
.16106 .0453 L
.16119 .04632 L
.16133 .04733 L
.16146 .04835 L
.16159 .04936 L
.16172 .05036 L
.16186 .05137 L
Mistroke
.16199 .05237 L
.16212 .05338 L
.16226 .05438 L
.16239 .05538 L
.16252 .05637 L
.16265 .05737 L
.16279 .05836 L
.16292 .05935 L
.16305 .06033 L
.16319 .06132 L
.16332 .0623 L
.16345 .06329 L
.16358 .06427 L
.16372 .06525 L
.16385 .06623 L
.16398 .0672 L
.16412 .06817 L
.16425 .06914 L
.16438 .07011 L
.16451 .07107 L
.16465 .07204 L
.16478 .07301 L
.16491 .07397 L
.16505 .07492 L
.16518 .07588 L
.16531 .07684 L
.16544 .07779 L
.16558 .07874 L
.16571 .07969 L
.16584 .08063 L
.16598 .08157 L
.16611 .08251 L
.16624 .08345 L
.16637 .08439 L
.16651 .08532 L
.16664 .08625 L
.16677 .08718 L
.16691 .0881 L
.16704 .08903 L
.16717 .08995 L
.1673 .09088 L
.16744 .0918 L
.16757 .09272 L
.1677 .09364 L
.16784 .09456 L
.16797 .09547 L
.1681 .09639 L
.16823 .0973 L
.16837 .09821 L
.1685 .09912 L
Mistroke
.16863 .10004 L
.16877 .10095 L
.1689 .10186 L
.16903 .10277 L
.16916 .10368 L
.1693 .10458 L
.16943 .10549 L
.16956 .10639 L
.1697 .10729 L
.16983 .10819 L
.16996 .10909 L
.17009 .10999 L
.17023 .11089 L
.17036 .11178 L
.17049 .11268 L
.17063 .11357 L
.17076 .11446 L
.17089 .11535 L
.17102 .11624 L
.17116 .11713 L
.17129 .11802 L
.17142 .1189 L
.17156 .11978 L
.17169 .12067 L
.17182 .12155 L
.17195 .12244 L
.17209 .12332 L
.17222 .1242 L
.17235 .12508 L
.17249 .12596 L
.17262 .12683 L
.17275 .12771 L
.17288 .12858 L
.17302 .12944 L
.17315 .13031 L
.17328 .13118 L
.17342 .13204 L
.17355 .1329 L
.17368 .13377 L
.17381 .13463 L
.17395 .13549 L
.17408 .13634 L
.17421 .1372 L
.17435 .13805 L
.17448 .13889 L
.17461 .13974 L
.17474 .14059 L
.17488 .14143 L
.17501 .14226 L
.17514 .1431 L
Mistroke
.17528 .14393 L
.17541 .14477 L
.17554 .1456 L
.17567 .14643 L
.17581 .14725 L
.17594 .14807 L
.17607 .14889 L
.17621 .14971 L
.17634 .15054 L
.17647 .15136 L
.17661 .15217 L
.17674 .15299 L
.17687 .15381 L
.177 .15462 L
.17714 .15544 L
.17727 .15625 L
.1774 .15706 L
.17754 .15786 L
.17767 .15866 L
.1778 .15946 L
.17793 .16026 L
.17807 .16106 L
.1782 .16186 L
.17833 .16266 L
.17847 .16345 L
.1786 .16425 L
.17873 .16504 L
.17886 .16583 L
.179 .16662 L
.17913 .16742 L
.17926 .16821 L
.1794 .169 L
.17953 .16979 L
.17966 .17058 L
.17979 .17137 L
.17993 .17216 L
.18006 .17294 L
.18019 .17373 L
.18033 .17452 L
.18046 .1753 L
.18059 .17608 L
.18072 .17686 L
.18086 .17764 L
.18099 .17842 L
.18112 .1792 L
.18126 .17997 L
.18139 .18074 L
.18152 .18152 L
.18165 .18228 L
.18179 .18304 L
Mistroke
.18192 .1838 L
.18205 .18455 L
.18219 .18531 L
.18232 .18606 L
.18245 .18681 L
.18258 .18756 L
.18272 .18831 L
.18285 .18905 L
.18298 .18979 L
.18312 .19053 L
.18325 .19127 L
.18338 .192 L
.18351 .19273 L
.18365 .19346 L
.18378 .19419 L
.18391 .19492 L
.18405 .19565 L
.18418 .19638 L
.18431 .19711 L
.18444 .19783 L
.18458 .19855 L
.18471 .19927 L
.18484 .2 L
.18498 .20072 L
.18511 .20144 L
.18524 .20216 L
.18537 .20287 L
.18551 .20359 L
.18564 .20431 L
.18577 .20502 L
.18591 .20574 L
.18604 .20645 L
.18617 .20715 L
.1863 .20785 L
.18644 .20856 L
.18657 .20926 L
.1867 .20996 L
.18684 .21066 L
.18697 .21136 L
.1871 .21206 L
.18723 .21275 L
.18737 .21345 L
.1875 .21415 L
.18763 .21484 L
.18777 .21554 L
.1879 .21623 L
.18803 .21691 L
.18816 .21759 L
.1883 .21827 L
.18843 .21895 L
Mistroke
.18856 .21963 L
.1887 .22031 L
.18883 .22099 L
.18896 .22166 L
.18909 .22234 L
.18923 .22301 L
.18936 .22368 L
.18949 .22436 L
.18963 .22503 L
.18976 .2257 L
.18989 .22636 L
.19002 .22703 L
.19016 .22769 L
.19029 .22836 L
.19042 .22902 L
.19056 .22968 L
.19069 .23034 L
.19082 .231 L
.19095 .23166 L
.19109 .23231 L
.19122 .23296 L
.19135 .23361 L
.19149 .23426 L
.19162 .23491 L
.19175 .23556 L
.19188 .2362 L
.19202 .23685 L
.19215 .23749 L
.19228 .23812 L
.19242 .23876 L
.19255 .2394 L
.19268 .24004 L
.19281 .24067 L
.19295 .2413 L
.19308 .24194 L
.19321 .24257 L
.19335 .2432 L
.19348 .24383 L
.19361 .24446 L
.19374 .24509 L
.19388 .24571 L
.19401 .24633 L
.19414 .24695 L
.19428 .24757 L
.19441 .24819 L
.19454 .2488 L
.19467 .24941 L
.19481 .25002 L
.19494 .25063 L
.19507 .25124 L
Mistroke
.19521 .25185 L
.19534 .25246 L
.19547 .25307 L
.1956 .25367 L
.19574 .25427 L
.19587 .25488 L
.196 .25548 L
.19614 .25607 L
.19627 .25667 L
.1964 .25727 L
.19653 .25786 L
.19667 .25845 L
.1968 .25904 L
.19693 .25963 L
.19707 .26022 L
.1972 .26081 L
.19733 .26139 L
.19746 .26198 L
.1976 .26256 L
.19773 .26314 L
.19786 .26372 L
.198 .26431 L
.19813 .26489 L
.19826 .26547 L
.19839 .26605 L
.19853 .26663 L
.19866 .2672 L
.19879 .26778 L
.19893 .26836 L
.19906 .26893 L
.19919 .26951 L
.19933 .27008 L
.19946 .27066 L
.19959 .27123 L
.19972 .2718 L
.19986 .27237 L
.19999 .27294 L
.20012 .2735 L
.20026 .27407 L
.20039 .27464 L
.20052 .2752 L
.20065 .27577 L
.20079 .27633 L
.20092 .27689 L
.20105 .27746 L
.20119 .27802 L
.20132 .27857 L
.20145 .27913 L
.20158 .27969 L
.20172 .28024 L
Mistroke
.20185 .28079 L
.20198 .28134 L
.20212 .28189 L
.20225 .28244 L
.20238 .28299 L
.20251 .28354 L
.20265 .28408 L
.20278 .28462 L
.20291 .28517 L
.20305 .28571 L
.20318 .28625 L
.20331 .28679 L
.20344 .28733 L
.20358 .28786 L
.20371 .2884 L
.20384 .28893 L
.20398 .28947 L
.20411 .29 L
.20424 .29053 L
.20437 .29106 L
.20451 .29158 L
.20464 .29209 L
.20477 .29261 L
.20491 .29313 L
.20504 .29364 L
.20517 .29415 L
.2053 .29466 L
.20544 .29517 L
.20557 .29568 L
.2057 .29618 L
.20584 .29669 L
.20597 .29719 L
.2061 .2977 L
.20623 .2982 L
.20637 .2987 L
.2065 .2992 L
.20663 .2997 L
.20677 .3002 L
.2069 .3007 L
.20703 .3012 L
.20716 .3017 L
.2073 .30219 L
.20743 .30269 L
.20756 .30319 L
.2077 .30368 L
.20783 .30417 L
.20796 .30467 L
.20809 .30516 L
.20823 .30565 L
.20836 .30614 L
Mistroke
.20849 .30662 L
.20863 .30711 L
.20876 .3076 L
.20889 .30808 L
.20902 .30857 L
.20916 .30905 L
.20929 .30953 L
.20942 .31002 L
.20956 .3105 L
.20969 .31098 L
.20982 .31146 L
.20995 .31194 L
.21009 .31242 L
.21022 .3129 L
.21035 .31338 L
.21049 .31385 L
.21062 .31432 L
.21075 .3148 L
.21088 .31527 L
.21102 .31573 L
.21115 .3162 L
.21128 .31666 L
.21142 .31712 L
.21155 .31759 L
.21168 .31805 L
.21181 .31851 L
.21195 .31897 L
.21208 .31943 L
.21221 .31988 L
.21235 .32034 L
.21248 .3208 L
.21261 .32126 L
.21274 .32171 L
.21288 .32217 L
.21301 .32262 L
.21314 .32308 L
.21328 .32353 L
.21341 .32399 L
.21354 .32444 L
.21367 .32489 L
.21381 .32534 L
.21394 .32579 L
.21407 .32624 L
.21421 .32668 L
.21434 .32712 L
.21447 .32757 L
.2146 .32801 L
.21474 .32845 L
.21487 .32889 L
.215 .32933 L
Mistroke
.21514 .32977 L
.21527 .33021 L
.2154 .33065 L
.21553 .33109 L
.21567 .33153 L
.2158 .33196 L
.21593 .3324 L
.21607 .33283 L
.2162 .33327 L
.21633 .3337 L
.21646 .33413 L
.2166 .33456 L
.21673 .33499 L
.21686 .33542 L
.217 .33585 L
.21713 .33628 L
.21726 .33671 L
.21739 .33714 L
.21753 .33757 L
.21766 .33799 L
.21779 .33842 L
.21793 .33885 L
.21806 .33927 L
.21819 .3397 L
.21832 .34012 L
.21846 .34054 L
.21859 .34097 L
.21872 .34139 L
.21886 .34181 L
.21899 .34223 L
.21912 .34265 L
.21925 .34307 L
.21939 .34349 L
.21952 .3439 L
.21965 .34432 L
.21979 .34473 L
.21992 .34514 L
.22005 .34556 L
.22018 .34597 L
.22032 .34638 L
.22045 .34679 L
.22058 .3472 L
.22072 .34761 L
.22085 .34802 L
.22098 .34843 L
.22112 .34883 L
.22125 .34924 L
.22138 .34964 L
.22151 .35005 L
.22165 .35045 L
Mistroke
.22178 .35085 L
.22191 .35125 L
.22205 .35165 L
.22218 .35205 L
.22231 .35244 L
.22244 .35284 L
.22258 .35324 L
.22271 .35363 L
.22284 .35403 L
.22298 .35442 L
.22311 .35481 L
.22324 .35521 L
.22337 .3556 L
.22351 .35599 L
.22364 .35638 L
.22377 .35677 L
.22391 .35716 L
.22404 .35755 L
.22417 .35794 L
.2243 .35833 L
.22444 .35871 L
.22457 .3591 L
.2247 .35948 L
.22484 .35986 L
.22497 .36025 L
.2251 .36063 L
.22523 .36101 L
.22537 .3614 L
.2255 .36178 L
.22563 .36216 L
.22577 .36254 L
.2259 .36291 L
.22603 .36329 L
.22616 .36367 L
.2263 .36405 L
.22643 .36442 L
.22656 .36479 L
.2267 .36517 L
.22683 .36554 L
.22696 .36591 L
.22709 .36628 L
.22723 .36666 L
.22736 .36703 L
.22749 .36739 L
.22763 .36776 L
.22776 .36813 L
.22789 .36849 L
.22802 .36886 L
.22816 .36922 L
.22829 .36959 L
Mistroke
.22842 .36995 L
.22856 .37031 L
.22869 .37068 L
.22882 .37104 L
.22895 .3714 L
.22909 .37176 L
.22922 .37213 L
.22935 .37249 L
.22949 .37285 L
.22962 .37321 L
.22975 .37357 L
.22988 .37392 L
.23002 .37428 L
.23015 .37463 L
.23028 .37499 L
.23042 .37534 L
.23055 .3757 L
.23068 .37605 L
.23081 .37641 L
.23095 .37676 L
.23108 .37711 L
.23121 .37746 L
.23135 .37781 L
.23148 .37816 L
.23161 .3785 L
.23174 .37885 L
.23188 .37919 L
.23201 .37954 L
.23214 .37988 L
.23228 .38022 L
.23241 .38056 L
.23254 .3809 L
.23267 .38124 L
.23281 .38157 L
.23294 .38191 L
.23307 .38225 L
.23321 .38259 L
.23334 .38292 L
.23347 .38326 L
.2336 .3836 L
.23374 .38393 L
.23387 .38427 L
.234 .3846 L
.23414 .38494 L
.23427 .38527 L
.2344 .38561 L
.23453 .38594 L
.23467 .38628 L
.2348 .38661 L
.23493 .38694 L
Mistroke
.23507 .38727 L
.2352 .3876 L
.23533 .38793 L
.23546 .38826 L
.2356 .38859 L
.23573 .38892 L
.23586 .38925 L
.236 .38958 L
.23613 .3899 L
.23626 .39023 L
.23639 .39056 L
.23653 .39088 L
.23666 .39121 L
.23679 .39154 L
.23693 .39186 L
.23706 .39218 L
.23719 .39251 L
.23732 .39283 L
.23746 .39315 L
.23759 .39347 L
.23772 .39379 L
.23786 .39411 L
.23799 .39443 L
.23812 .39475 L
.23825 .39507 L
.23839 .39539 L
.23852 .3957 L
.23865 .39602 L
.23879 .39633 L
.23892 .39665 L
.23905 .39696 L
.23918 .39728 L
.23932 .39759 L
.23945 .3979 L
.23958 .39822 L
.23972 .39853 L
.23985 .39884 L
.23998 .39915 L
.24011 .39946 L
.24025 .39977 L
.24038 .40008 L
.24051 .40039 L
.24065 .40069 L
.24078 .401 L
.24091 .40131 L
.24104 .40161 L
.24118 .40192 L
.24131 .40223 L
.24144 .40253 L
.24158 .40284 L
Mistroke
.24171 .40314 L
.24184 .40344 L
.24197 .40374 L
.24211 .40405 L
.24224 .40435 L
.24237 .40465 L
.24251 .40495 L
.24264 .40526 L
.24277 .40556 L
.2429 .40586 L
.24304 .40616 L
.24317 .40646 L
.2433 .40676 L
.24344 .40706 L
.24357 .40735 L
.2437 .40765 L
.24384 .40795 L
.24397 .40824 L
.2441 .40854 L
.24423 .40883 L
.24437 .40913 L
.2445 .40942 L
.24463 .40972 L
.24477 .41001 L
.2449 .4103 L
.24503 .41059 L
.24516 .41089 L
.2453 .41118 L
.24543 .41147 L
.24556 .41176 L
.2457 .41204 L
.24583 .41233 L
.24596 .41262 L
.24609 .41291 L
.24623 .41319 L
.24636 .41348 L
.24649 .41376 L
.24663 .41405 L
.24676 .41433 L
.24689 .41462 L
.24702 .4149 L
.24716 .41518 L
.24729 .41546 L
.24742 .41574 L
.24756 .41603 L
.24769 .41631 L
.24782 .41659 L
.24795 .41687 L
.24809 .41715 L
.24822 .41743 L
Mistroke
.24835 .41771 L
.24849 .41799 L
.24862 .41826 L
.24875 .41854 L
.24888 .41882 L
.24902 .4191 L
.24915 .41938 L
.24928 .41965 L
.24942 .41993 L
.24955 .4202 L
.24968 .42048 L
.24981 .42075 L
.24995 .42102 L
.25008 .4213 L
.25021 .42157 L
.25035 .42184 L
.25048 .42211 L
.25061 .42239 L
.25074 .42266 L
.25088 .42293 L
.25101 .4232 L
.25114 .42347 L
.25128 .42374 L
.25141 .42401 L
.25154 .42428 L
.25167 .42455 L
.25181 .42481 L
.25194 .42508 L
.25207 .42535 L
.25221 .42561 L
.25234 .42588 L
.25247 .42615 L
.2526 .42641 L
.25274 .42667 L
.25287 .42694 L
.253 .4272 L
.25314 .42746 L
.25327 .42773 L
.2534 .42799 L
.25353 .42825 L
.25367 .42851 L
.2538 .42877 L
.25393 .42903 L
.25407 .42929 L
.2542 .42955 L
.25433 .42981 L
.25446 .43007 L
.2546 .43033 L
.25473 .43059 L
.25486 .43085 L
Mistroke
.255 .4311 L
.25513 .43136 L
.25526 .43162 L
.25539 .43187 L
.25553 .43213 L
.25566 .43238 L
.25579 .43263 L
.25593 .43289 L
.25606 .43314 L
.25619 .43339 L
.25632 .43365 L
.25646 .4339 L
.25659 .43415 L
.25672 .4344 L
.25686 .43465 L
.25699 .4349 L
.25712 .43515 L
.25725 .4354 L
.25739 .43564 L
.25752 .43589 L
.25765 .43614 L
.25779 .43638 L
.25792 .43663 L
.25805 .43688 L
.25818 .43712 L
.25832 .43737 L
.25845 .43761 L
.25858 .43785 L
.25872 .43809 L
.25885 .43833 L
.25898 .43857 L
.25911 .43882 L
.25925 .43906 L
.25938 .4393 L
.25951 .43954 L
.25965 .43977 L
.25978 .44001 L
.25991 .44025 L
.26004 .44049 L
.26018 .44072 L
.26031 .44096 L
.26044 .4412 L
.26058 .44144 L
.26071 .44167 L
.26084 .44191 L
.26097 .44214 L
.26111 .44238 L
.26124 .44262 L
.26137 .44285 L
.26151 .44309 L
Mistroke
.26164 .44332 L
.26177 .44356 L
.2619 .44379 L
.26204 .44402 L
.26217 .44426 L
.2623 .44449 L
.26244 .44472 L
.26257 .44495 L
.2627 .44519 L
.26283 .44542 L
.26297 .44565 L
.2631 .44588 L
.26323 .44611 L
.26337 .44634 L
.2635 .44657 L
.26363 .44681 L
.26376 .44704 L
.2639 .44727 L
.26403 .44749 L
.26416 .44772 L
.2643 .44795 L
.26443 .44818 L
.26456 .44841 L
.26469 .44864 L
.26483 .44886 L
.26496 .44909 L
.26509 .44931 L
.26523 .44954 L
.26536 .44977 L
.26549 .44999 L
.26562 .45021 L
.26576 .45044 L
.26589 .45066 L
.26602 .45088 L
.26616 .4511 L
.26629 .45133 L
.26642 .45155 L
.26656 .45177 L
.26669 .45199 L
.26682 .45221 L
.26695 .45243 L
.26709 .45265 L
.26722 .45287 L
.26735 .45309 L
.26749 .45331 L
.26762 .45353 L
.26775 .45375 L
.26788 .45397 L
.26802 .45418 L
.26815 .4544 L
Mistroke
.26828 .45462 L
.26842 .45484 L
.26855 .45505 L
.26868 .45527 L
.26881 .45549 L
.26895 .4557 L
.26908 .45592 L
.26921 .45613 L
.26935 .45635 L
.26948 .45656 L
.26961 .45677 L
.26974 .45699 L
.26988 .4572 L
.27001 .45741 L
.27014 .45762 L
.27028 .45784 L
.27041 .45805 L
.27054 .45826 L
.27067 .45847 L
.27081 .45868 L
.27094 .4589 L
.27107 .45911 L
.27121 .45932 L
.27134 .45953 L
.27147 .45974 L
.2716 .45995 L
.27174 .46016 L
.27187 .46036 L
.272 .46057 L
.27214 .46078 L
.27227 .46099 L
.2724 .46119 L
.27253 .4614 L
.27267 .4616 L
.2728 .46181 L
.27293 .46202 L
.27307 .46222 L
.2732 .46243 L
.27333 .46263 L
.27346 .46284 L
.2736 .46304 L
.27373 .46325 L
.27386 .46345 L
.274 .46365 L
.27413 .46386 L
.27426 .46406 L
.27439 .46426 L
.27453 .46446 L
.27466 .46466 L
.27479 .46487 L
Mistroke
.27493 .46507 L
.27506 .46527 L
.27519 .46547 L
.27532 .46566 L
.27546 .46586 L
.27559 .46606 L
.27572 .46626 L
.27586 .46646 L
.27599 .46666 L
.27612 .46686 L
.27625 .46705 L
.27639 .46725 L
.27652 .46745 L
.27665 .46765 L
.27679 .46784 L
.27692 .46804 L
.27705 .46824 L
.27718 .46843 L
.27732 .46863 L
.27745 .46882 L
.27758 .46902 L
.27772 .46921 L
.27785 .46941 L
.27798 .4696 L
.27811 .4698 L
.27825 .46999 L
.27838 .47019 L
.27851 .47038 L
.27865 .47057 L
.27878 .47076 L
.27891 .47096 L
.27904 .47115 L
.27918 .47134 L
.27931 .47153 L
.27944 .47172 L
.27958 .47191 L
.27971 .4721 L
.27984 .47229 L
.27997 .47248 L
.28011 .47267 L
.28024 .47286 L
.28037 .47305 L
.28051 .47324 L
.28064 .47342 L
.28077 .47361 L
.2809 .4738 L
.28104 .47399 L
.28117 .47417 L
.2813 .47436 L
.28144 .47454 L
Mistroke
.28157 .47473 L
.2817 .47491 L
.28183 .4751 L
.28197 .47528 L
.2821 .47546 L
.28223 .47565 L
.28237 .47583 L
.2825 .47601 L
.28263 .47619 L
.28276 .47637 L
.2829 .47655 L
.28303 .47673 L
.28316 .47691 L
.2833 .47709 L
.28343 .47727 L
.28356 .47745 L
.28369 .47763 L
.28383 .47781 L
.28396 .47799 L
.28409 .47816 L
.28423 .47834 L
.28436 .47852 L
.28449 .47869 L
.28462 .47887 L
.28476 .47904 L
.28489 .47922 L
.28502 .47939 L
.28516 .47957 L
.28529 .47974 L
.28542 .47991 L
.28555 .48009 L
.28569 .48026 L
.28582 .48043 L
.28595 .48061 L
.28609 .48078 L
.28622 .48095 L
.28635 .48112 L
.28648 .4813 L
.28662 .48147 L
.28675 .48164 L
.28688 .48181 L
.28702 .48198 L
.28715 .48215 L
.28728 .48233 L
.28741 .4825 L
.28755 .48267 L
.28768 .48284 L
.28781 .48301 L
.28795 .48318 L
.28808 .48335 L
Mistroke
.28821 .48352 L
.28835 .48369 L
.28848 .48386 L
.28861 .48403 L
.28874 .4842 L
.28888 .48436 L
.28901 .48453 L
.28914 .4847 L
.28928 .48487 L
.28941 .48504 L
.28954 .4852 L
.28967 .48537 L
.28981 .48554 L
.28994 .4857 L
.29007 .48587 L
.29021 .48604 L
.29034 .4862 L
.29047 .48637 L
.2906 .48653 L
.29074 .4867 L
.29087 .48686 L
.291 .48703 L
.29114 .48719 L
.29127 .48736 L
.2914 .48752 L
.29153 .48768 L
.29167 .48785 L
.2918 .48801 L
.29193 .48817 L
.29207 .48833 L
.2922 .4885 L
.29233 .48866 L
.29246 .48882 L
.2926 .48898 L
.29273 .48914 L
.29286 .4893 L
.293 .48946 L
.29313 .48962 L
.29326 .48978 L
.29339 .48994 L
.29353 .4901 L
.29366 .49026 L
.29379 .49042 L
.29393 .49058 L
.29406 .49074 L
.29419 .4909 L
.29432 .49105 L
.29446 .49121 L
.29459 .49137 L
.29472 .49153 L
Mistroke
.29486 .49168 L
.29499 .49184 L
.29512 .492 L
.29525 .49215 L
.29539 .49231 L
.29552 .49246 L
.29565 .49261 L
.29579 .49277 L
.29592 .49292 L
.29605 .49307 L
.29618 .49323 L
.29632 .49338 L
.29645 .49353 L
.29658 .49368 L
.29672 .49384 L
.29685 .49399 L
.29698 .49414 L
.29711 .49429 L
.29725 .49444 L
.29738 .49459 L
.29751 .49475 L
.29765 .4949 L
.29778 .49505 L
.29791 .4952 L
.29804 .49534 L
.29818 .49549 L
.29831 .49564 L
.29844 .49579 L
.29858 .49594 L
.29871 .49609 L
.29884 .49623 L
.29897 .49638 L
.29911 .49653 L
.29924 .49668 L
.29937 .49682 L
.29951 .49697 L
.29964 .49712 L
.29977 .49726 L
.2999 .49741 L
.30004 .49756 L
.30017 .4977 L
.3003 .49785 L
.30044 .498 L
.30057 .49814 L
.3007 .49829 L
.30083 .49844 L
.30097 .49858 L
.3011 .49873 L
.30123 .49887 L
.30137 .49902 L
Mistroke
.3015 .49916 L
.30163 .4993 L
.30176 .49945 L
.3019 .49959 L
.30203 .49973 L
.30216 .49988 L
.3023 .50002 L
.30243 .50016 L
.30256 .5003 L
.30269 .50045 L
.30283 .50059 L
.30296 .50073 L
.30309 .50087 L
.30323 .50101 L
.30336 .50115 L
.30349 .50129 L
.30362 .50143 L
.30376 .50157 L
.30389 .50171 L
.30402 .50185 L
.30416 .50199 L
.30429 .50213 L
.30442 .50227 L
.30455 .50241 L
.30469 .50255 L
.30482 .50269 L
.30495 .50283 L
.30509 .50297 L
.30522 .5031 L
.30535 .50324 L
.30548 .50338 L
.30562 .50352 L
.30575 .50366 L
.30588 .50379 L
.30602 .50393 L
.30615 .50407 L
.30628 .50421 L
.30641 .50434 L
.30655 .50448 L
.30668 .50462 L
.30681 .50475 L
.30695 .50489 L
.30708 .50503 L
.30721 .50516 L
.30734 .5053 L
.30748 .50543 L
.30761 .50557 L
.30774 .5057 L
.30788 .50584 L
.30801 .50598 L
Mistroke
.30814 .50611 L
.30827 .50625 L
.30841 .50638 L
.30854 .50651 L
.30867 .50665 L
.30881 .50678 L
.30894 .50691 L
.30907 .50705 L
.3092 .50718 L
.30934 .50731 L
.30947 .50745 L
.3096 .50758 L
.30974 .50771 L
.30987 .50784 L
.31 .50797 L
.31013 .50811 L
.31027 .50824 L
.3104 .50837 L
.31053 .5085 L
.31067 .50863 L
.3108 .50876 L
.31093 .50889 L
.31107 .50903 L
.3112 .50916 L
.31133 .50929 L
.31146 .50942 L
.3116 .50955 L
.31173 .50968 L
.31186 .50981 L
.312 .50994 L
.31213 .51007 L
.31226 .5102 L
.31239 .51033 L
.31253 .51046 L
.31266 .51059 L
.31279 .51072 L
.31293 .51085 L
.31306 .51098 L
.31319 .5111 L
.31332 .51123 L
.31346 .51136 L
.31359 .51149 L
.31372 .51161 L
.31386 .51174 L
.31399 .51187 L
.31412 .512 L
.31425 .51212 L
.31439 .51225 L
.31452 .51237 L
.31465 .5125 L
Mistroke
.31479 .51263 L
.31492 .51275 L
.31505 .51288 L
.31518 .513 L
.31532 .51313 L
.31545 .51325 L
.31558 .51337 L
.31572 .5135 L
.31585 .51362 L
.31598 .51375 L
.31611 .51387 L
.31625 .51399 L
.31638 .51411 L
.31651 .51423 L
.31665 .51436 L
.31678 .51448 L
.31691 .5146 L
.31704 .51472 L
.31718 .51484 L
.31731 .51496 L
.31744 .51508 L
.31758 .5152 L
.31771 .51532 L
.31784 .51544 L
.31797 .51556 L
.31811 .51568 L
.31824 .5158 L
.31837 .51592 L
.31851 .51604 L
.31864 .51615 L
.31877 .51627 L
.3189 .51639 L
.31904 .51651 L
.31917 .51663 L
.3193 .51675 L
.31944 .51686 L
.31957 .51698 L
.3197 .5171 L
.31983 .51722 L
.31997 .51733 L
.3201 .51745 L
.32023 .51757 L
.32037 .51768 L
.3205 .5178 L
.32063 .51792 L
.32076 .51803 L
.3209 .51815 L
.32103 .51826 L
.32116 .51838 L
.3213 .51849 L
Mistroke
.32143 .51861 L
.32156 .51872 L
.32169 .51884 L
.32183 .51895 L
.32196 .51907 L
.32209 .51918 L
.32223 .5193 L
.32236 .51941 L
.32249 .51953 L
.32262 .51964 L
.32276 .51975 L
.32289 .51987 L
.32302 .51998 L
.32316 .52009 L
.32329 .52021 L
.32342 .52032 L
.32355 .52043 L
.32369 .52055 L
.32382 .52066 L
.32395 .52077 L
.32409 .52088 L
.32422 .521 L
.32435 .52111 L
.32448 .52122 L
.32462 .52133 L
.32475 .52144 L
.32488 .52156 L
.32502 .52167 L
.32515 .52178 L
.32528 .52189 L
.32541 .522 L
.32555 .52212 L
.32568 .52223 L
.32581 .52234 L
.32595 .52245 L
.32608 .52256 L
.32621 .52267 L
.32634 .52278 L
.32648 .52289 L
.32661 .523 L
.32674 .52311 L
.32688 .52322 L
.32701 .52333 L
.32714 .52344 L
.32727 .52355 L
.32741 .52366 L
.32754 .52377 L
.32767 .52387 L
.32781 .52398 L
.32794 .52409 L
Mistroke
.32807 .5242 L
.3282 .52431 L
.32834 .52441 L
.32847 .52452 L
.3286 .52463 L
.32874 .52473 L
.32887 .52484 L
.329 .52494 L
.32913 .52505 L
.32927 .52515 L
.3294 .52526 L
.32953 .52536 L
.32967 .52547 L
.3298 .52557 L
.32993 .52568 L
.33006 .52578 L
.3302 .52589 L
.33033 .52599 L
.33046 .5261 L
.3306 .5262 L
.33073 .5263 L
.33086 .52641 L
.33099 .52651 L
.33113 .52661 L
.33126 .52672 L
.33139 .52682 L
.33153 .52692 L
.33166 .52703 L
.33179 .52713 L
.33192 .52723 L
.33206 .52733 L
.33219 .52743 L
.33232 .52754 L
.33246 .52764 L
.33259 .52774 L
.33272 .52784 L
.33286 .52794 L
.33299 .52804 L
.33312 .52814 L
.33325 .52824 L
.33339 .52834 L
.33352 .52845 L
.33365 .52855 L
.33379 .52865 L
.33392 .52875 L
.33405 .52885 L
.33418 .52895 L
.33432 .52905 L
.33445 .52915 L
.33458 .52925 L
Mistroke
.33472 .52935 L
.33485 .52945 L
.33498 .52955 L
.33511 .52965 L
.33525 .52975 L
.33538 .52985 L
.33551 .52995 L
.33565 .53005 L
.33578 .53015 L
.33591 .53025 L
.33604 .53035 L
.33618 .53044 L
.33631 .53054 L
.33644 .53064 L
.33658 .53074 L
.33671 .53084 L
.33684 .53094 L
.33697 .53103 L
.33711 .53113 L
.33724 .53123 L
.33737 .53133 L
.33751 .53142 L
.33764 .53152 L
.33777 .53162 L
.3379 .53171 L
.33804 .53181 L
.33817 .53191 L
.3383 .532 L
.33844 .5321 L
.33857 .53219 L
.3387 .53229 L
.33883 .53238 L
.33897 .53248 L
.3391 .53258 L
.33923 .53267 L
.33937 .53277 L
.3395 .53286 L
.33963 .53296 L
.33976 .53305 L
.3399 .53315 L
.34003 .53324 L
.34016 .53334 L
.3403 .53343 L
.34043 .53352 L
.34056 .53362 L
.34069 .53371 L
.34083 .53381 L
.34096 .5339 L
.34109 .53399 L
.34123 .53409 L
Mistroke
.34136 .53418 L
.34149 .53427 L
.34162 .53437 L
.34176 .53446 L
.34189 .53455 L
.34202 .53465 L
.34216 .53474 L
.34229 .53483 L
.34242 .53492 L
.34255 .53502 L
.34269 .53511 L
.34282 .5352 L
.34295 .53529 L
.34309 .53538 L
.34322 .53548 L
.34335 .53557 L
.34348 .53566 L
.34362 .53575 L
.34375 .53584 L
.34388 .53593 L
.34402 .53602 L
.34415 .53611 L
.34428 .5362 L
.34441 .53629 L
.34455 .53638 L
.34468 .53647 L
.34481 .53656 L
.34495 .53665 L
.34508 .53674 L
.34521 .53683 L
.34534 .53692 L
.34548 .53701 L
.34561 .5371 L
.34574 .53719 L
.34588 .53728 L
.34601 .53737 L
.34614 .53745 L
.34627 .53754 L
.34641 .53763 L
.34654 .53772 L
.34667 .53781 L
.34681 .5379 L
.34694 .53798 L
.34707 .53807 L
.3472 .53816 L
.34734 .53825 L
.34747 .53834 L
.3476 .53842 L
.34774 .53851 L
.34787 .5386 L
Mistroke
.348 .53869 L
.34813 .53877 L
.34827 .53886 L
.3484 .53895 L
.34853 .53903 L
.34867 .53912 L
.3488 .53921 L
.34893 .5393 L
.34906 .53938 L
.3492 .53947 L
.34933 .53955 L
.34946 .53964 L
.3496 .53973 L
.34973 .53981 L
.34986 .5399 L
.34999 .53998 L
.35013 .54007 L
.35026 .54016 L
.35039 .54024 L
.35053 .54033 L
.35066 .54041 L
.35079 .5405 L
.35092 .54058 L
.35106 .54067 L
.35119 .54075 L
.35132 .54084 L
.35146 .54092 L
.35159 .54101 L
.35172 .54109 L
.35185 .54117 L
.35199 .54126 L
.35212 .54134 L
.35225 .54143 L
.35239 .54151 L
.35252 .54159 L
.35265 .54168 L
.35278 .54176 L
.35292 .54184 L
.35305 .54193 L
.35318 .54201 L
.35332 .54209 L
.35345 .54217 L
.35358 .54226 L
.35371 .54234 L
.35385 .54242 L
.35398 .5425 L
.35411 .54259 L
.35425 .54267 L
.35438 .54275 L
.35451 .54283 L
Mistroke
.35464 .54291 L
.35478 .543 L
.35491 .54308 L
.35504 .54316 L
.35518 .54324 L
.35531 .54332 L
.35544 .5434 L
.35558 .54348 L
.35571 .54356 L
.35584 .54365 L
.35597 .54373 L
.35611 .54381 L
.35624 .54389 L
.35637 .54397 L
.35651 .54405 L
.35664 .54413 L
.35677 .54421 L
.3569 .54429 L
.35704 .54437 L
.35717 .54445 L
.3573 .54453 L
.35744 .54461 L
.35757 .54468 L
.3577 .54476 L
.35783 .54484 L
.35797 .54492 L
.3581 .545 L
.35823 .54508 L
.35837 .54516 L
.3585 .54524 L
.35863 .54531 L
.35876 .54539 L
.3589 .54547 L
.35903 .54555 L
.35916 .54563 L
.3593 .54571 L
.35943 .54578 L
.35956 .54586 L
.35969 .54594 L
.35983 .54602 L
.35996 .54609 L
.36009 .54617 L
.36023 .54625 L
.36036 .54633 L
.36049 .5464 L
.36062 .54648 L
.36076 .54656 L
.36089 .54663 L
.36102 .54671 L
.36116 .54678 L
Mistroke
.36129 .54686 L
.36142 .54694 L
.36155 .54701 L
.36169 .54709 L
.36182 .54716 L
.36195 .54724 L
.36209 .54731 L
.36222 .54739 L
.36235 .54746 L
.36248 .54754 L
.36262 .54761 L
.36275 .54769 L
.36288 .54776 L
.36302 .54784 L
.36315 .54791 L
.36328 .54798 L
.36341 .54806 L
.36355 .54813 L
.36368 .54821 L
.36381 .54828 L
.36395 .54835 L
.36408 .54843 L
.36421 .5485 L
.36434 .54857 L
.36448 .54865 L
.36461 .54872 L
.36474 .54879 L
.36488 .54887 L
.36501 .54894 L
.36514 .54901 L
.36527 .54908 L
.36541 .54916 L
.36554 .54923 L
.36567 .5493 L
.36581 .54937 L
.36594 .54945 L
.36607 .54952 L
.3662 .54959 L
.36634 .54966 L
.36647 .54973 L
.3666 .5498 L
.36674 .54987 L
.36687 .54995 L
.367 .55002 L
.36713 .55009 L
.36727 .55016 L
.3674 .55023 L
.36753 .5503 L
.36767 .55037 L
.3678 .55044 L
Mistroke
.36793 .55051 L
.36806 .55058 L
.3682 .55065 L
.36833 .55072 L
.36846 .55079 L
.3686 .55086 L
.36873 .55093 L
.36886 .551 L
.36899 .55107 L
.36913 .55114 L
.36926 .5512 L
.36939 .55127 L
.36953 .55134 L
.36966 .55141 L
.36979 .55148 L
.36992 .55155 L
.37006 .55162 L
.37019 .55169 L
.37032 .55175 L
.37046 .55182 L
.37059 .55189 L
.37072 .55196 L
.37085 .55203 L
.37099 .55209 L
.37112 .55216 L
.37125 .55223 L
.37139 .5523 L
.37152 .55236 L
.37165 .55243 L
.37178 .5525 L
.37192 .55257 L
.37205 .55263 L
.37218 .5527 L
.37232 .55277 L
.37245 .55283 L
.37258 .5529 L
.37271 .55297 L
.37285 .55303 L
.37298 .5531 L
.37311 .55317 L
.37325 .55323 L
.37338 .5533 L
.37351 .55337 L
.37364 .55343 L
.37378 .5535 L
.37391 .55356 L
.37404 .55363 L
.37418 .55369 L
.37431 .55376 L
.37444 .55382 L
Mistroke
.37457 .55389 L
.37471 .55395 L
.37484 .55402 L
.37497 .55408 L
.37511 .55415 L
.37524 .55421 L
.37537 .55428 L
.3755 .55434 L
.37564 .55441 L
.37577 .55447 L
.3759 .55454 L
.37604 .5546 L
.37617 .55466 L
.3763 .55473 L
.37643 .55479 L
.37657 .55486 L
.3767 .55492 L
.37683 .55498 L
.37697 .55505 L
.3771 .55511 L
.37723 .55517 L
.37737 .55524 L
.3775 .5553 L
.37763 .55536 L
.37776 .55543 L
.3779 .55549 L
.37803 .55555 L
.37816 .55562 L
.3783 .55568 L
.37843 .55574 L
.37856 .5558 L
.37869 .55587 L
.37883 .55593 L
.37896 .55599 L
.37909 .55606 L
.37923 .55612 L
.37936 .55618 L
.37949 .55624 L
.37962 .5563 L
.37976 .55637 L
.37989 .55643 L
.38002 .55649 L
.38016 .55655 L
.38029 .55661 L
.38042 .55668 L
.38055 .55674 L
.38069 .5568 L
.38082 .55686 L
.38095 .55692 L
.38109 .55698 L
Mistroke
.38122 .55705 L
.38135 .55711 L
.38148 .55717 L
.38162 .55723 L
.38175 .55729 L
.38188 .55735 L
.38202 .55741 L
.38215 .55747 L
.38228 .55754 L
.38241 .5576 L
.38255 .55766 L
.38268 .55772 L
.38281 .55778 L
.38295 .55784 L
.38308 .5579 L
.38321 .55796 L
.38334 .55802 L
.38348 .55808 L
.38361 .55814 L
.38374 .5582 L
.38388 .55825 L
.38401 .55831 L
.38414 .55837 L
.38427 .55843 L
.38441 .55849 L
.38454 .55855 L
.38467 .55861 L
.38481 .55867 L
.38494 .55873 L
.38507 .55879 L
.3852 .55885 L
.38534 .5589 L
.38547 .55896 L
.3856 .55902 L
.38574 .55908 L
.38587 .55914 L
.386 .5592 L
.38613 .55925 L
.38627 .55931 L
.3864 .55937 L
.38653 .55943 L
.38667 .55948 L
.3868 .55954 L
.38693 .5596 L
.38706 .55966 L
.3872 .55972 L
.38733 .55977 L
.38746 .55983 L
.3876 .55989 L
.38773 .55994 L
Mistroke
.38786 .56 L
.38799 .56006 L
.38813 .56012 L
.38826 .56017 L
.38839 .56023 L
.38853 .56029 L
.38866 .56034 L
.38879 .5604 L
.38892 .56046 L
.38906 .56051 L
.38919 .56057 L
.38932 .56063 L
.38946 .56068 L
.38959 .56074 L
.38972 .5608 L
.38985 .56085 L
.38999 .56091 L
.39012 .56096 L
.39025 .56102 L
.39039 .56108 L
.39052 .56113 L
.39065 .56119 L
.39078 .56124 L
.39092 .5613 L
.39105 .56135 L
.39118 .56141 L
.39132 .56146 L
.39145 .56152 L
.39158 .56158 L
.39171 .56163 L
.39185 .56169 L
.39198 .56174 L
.39211 .5618 L
.39225 .56185 L
.39238 .56191 L
.39251 .56196 L
.39264 .56201 L
.39278 .56207 L
.39291 .56212 L
.39304 .56218 L
.39318 .56223 L
.39331 .56229 L
.39344 .56234 L
.39357 .5624 L
.39371 .56245 L
.39384 .5625 L
.39397 .56256 L
.39411 .56261 L
.39424 .56267 L
.39437 .56272 L
Mistroke
.3945 .56277 L
.39464 .56283 L
.39477 .56288 L
.3949 .56294 L
.39504 .56299 L
.39517 .56304 L
.3953 .5631 L
.39543 .56315 L
.39557 .5632 L
.3957 .56325 L
.39583 .56331 L
.39597 .56336 L
.3961 .56341 L
.39623 .56347 L
.39636 .56352 L
.3965 .56357 L
.39663 .56362 L
.39676 .56368 L
.3969 .56373 L
.39703 .56378 L
.39716 .56383 L
.39729 .56389 L
.39743 .56394 L
.39756 .56399 L
.39769 .56404 L
.39783 .56409 L
.39796 .56415 L
.39809 .5642 L
.39822 .56425 L
.39836 .5643 L
.39849 .56435 L
.39862 .56441 L
.39876 .56446 L
.39889 .56451 L
.39902 .56456 L
.39915 .56461 L
.39929 .56466 L
.39942 .56471 L
.39955 .56477 L
.39969 .56482 L
.39982 .56487 L
.39995 .56492 L
.40009 .56497 L
.40022 .56502 L
.40035 .56507 L
.40048 .56512 L
.40062 .56517 L
.40075 .56522 L
.40088 .56527 L
.40102 .56532 L
Mistroke
.40115 .56537 L
.40128 .56542 L
.40141 .56547 L
.40155 .56553 L
.40168 .56558 L
.40181 .56563 L
.40195 .56568 L
.40208 .56573 L
.40221 .56577 L
.40234 .56582 L
.40248 .56587 L
.40261 .56592 L
.40274 .56597 L
.40288 .56602 L
.40301 .56607 L
.40314 .56612 L
.40327 .56617 L
.40341 .56622 L
.40354 .56627 L
.40367 .56632 L
.40381 .56637 L
.40394 .56642 L
.40407 .56646 L
.4042 .56651 L
.40434 .56656 L
.40447 .56661 L
.4046 .56666 L
.40474 .56671 L
.40487 .56676 L
.405 .56681 L
.40513 .56685 L
.40527 .5669 L
.4054 .56695 L
.40553 .567 L
.40567 .56705 L
.4058 .56709 L
.40593 .56714 L
.40606 .56719 L
.4062 .56724 L
.40633 .56729 L
.40646 .56733 L
.4066 .56738 L
.40673 .56743 L
.40686 .56748 L
.40699 .56752 L
.40713 .56757 L
.40726 .56762 L
.40739 .56766 L
.40753 .56771 L
.40766 .56776 L
Mistroke
.40779 .5678 L
.40792 .56785 L
.40806 .5679 L
.40819 .56794 L
.40832 .56799 L
.40846 .56804 L
.40859 .56808 L
.40872 .56813 L
.40885 .56818 L
.40899 .56822 L
.40912 .56827 L
.40925 .56831 L
.40939 .56836 L
.40952 .56841 L
.40965 .56845 L
.40978 .5685 L
.40992 .56854 L
.41005 .56859 L
.41018 .56863 L
.41032 .56868 L
.41045 .56872 L
.41058 .56877 L
.41071 .56882 L
.41085 .56886 L
.41098 .5689 L
.41111 .56895 L
.41125 .56899 L
.41138 .56904 L
.41151 .56908 L
.41164 .56913 L
.41178 .56917 L
.41191 .56922 L
.41204 .56926 L
.41218 .5693 L
.41231 .56935 L
.41244 .56939 L
.41257 .56944 L
.41271 .56948 L
.41284 .56952 L
.41297 .56957 L
.41311 .56961 L
.41324 .56966 L
.41337 .5697 L
.4135 .56974 L
.41364 .56979 L
.41377 .56983 L
.4139 .56987 L
.41404 .56992 L
.41417 .56996 L
.4143 .57 L
Mistroke
.41443 .57005 L
.41457 .57009 L
.4147 .57013 L
.41483 .57017 L
.41497 .57022 L
.4151 .57026 L
.41523 .5703 L
.41536 .57034 L
.4155 .57039 L
.41563 .57043 L
.41576 .57047 L
.4159 .57051 L
.41603 .57056 L
.41616 .5706 L
.41629 .57064 L
.41643 .57068 L
.41656 .57073 L
.41669 .57077 L
.41683 .57081 L
.41696 .57085 L
.41709 .57089 L
.41722 .57094 L
.41736 .57098 L
.41749 .57102 L
.41762 .57106 L
.41776 .5711 L
.41789 .57115 L
.41802 .57119 L
.41815 .57123 L
.41829 .57127 L
.41842 .57131 L
.41855 .57135 L
.41869 .5714 L
.41882 .57144 L
.41895 .57148 L
.41908 .57152 L
.41922 .57156 L
.41935 .5716 L
.41948 .57164 L
.41962 .57168 L
.41975 .57173 L
.41988 .57177 L
.42001 .57181 L
.42015 .57185 L
.42028 .57189 L
.42041 .57193 L
.42055 .57197 L
.42068 .57201 L
.42081 .57205 L
.42094 .57209 L
Mistroke
.42108 .57213 L
.42121 .57217 L
.42134 .57221 L
.42148 .57225 L
.42161 .57229 L
.42174 .57233 L
.42188 .57237 L
.42201 .57241 L
.42214 .57245 L
.42227 .57249 L
.42241 .57253 L
.42254 .57257 L
.42267 .57261 L
.42281 .57265 L
.42294 .57269 L
.42307 .57272 L
.4232 .57276 L
.42334 .5728 L
.42347 .57284 L
.4236 .57288 L
.42374 .57292 L
.42387 .57296 L
.424 .573 L
.42413 .57303 L
.42427 .57307 L
.4244 .57311 L
.42453 .57315 L
.42467 .57319 L
.4248 .57323 L
.42493 .57326 L
.42506 .5733 L
.4252 .57334 L
.42533 .57338 L
.42546 .57342 L
.4256 .57346 L
.42573 .57349 L
.42586 .57353 L
.42599 .57357 L
.42613 .57361 L
.42626 .57364 L
.42639 .57368 L
.42653 .57372 L
.42666 .57376 L
.42679 .57379 L
.42692 .57383 L
.42706 .57387 L
.42719 .57391 L
.42732 .57394 L
.42746 .57398 L
.42759 .57402 L
Mistroke
.42772 .57405 L
.42785 .57409 L
.42799 .57413 L
.42812 .57417 L
.42825 .5742 L
.42839 .57424 L
.42852 .57428 L
.42865 .57431 L
.42878 .57435 L
.42892 .57439 L
.42905 .57442 L
.42918 .57446 L
.42932 .5745 L
.42945 .57453 L
.42958 .57457 L
.42971 .57461 L
.42985 .57464 L
.42998 .57468 L
.43011 .57472 L
.43025 .57475 L
.43038 .57479 L
.43051 .57483 L
.43064 .57486 L
.43078 .5749 L
.43091 .57493 L
.43104 .57497 L
.43118 .57501 L
.43131 .57504 L
.43144 .57508 L
.43157 .57511 L
.43171 .57515 L
.43184 .57519 L
.43197 .57522 L
.43211 .57526 L
.43224 .57529 L
.43237 .57533 L
.4325 .57536 L
.43264 .5754 L
.43277 .57543 L
.4329 .57547 L
.43304 .5755 L
.43317 .57554 L
.4333 .57557 L
.43343 .57561 L
.43357 .57564 L
.4337 .57568 L
.43383 .57571 L
.43397 .57575 L
.4341 .57578 L
.43423 .57582 L
Mistroke
.43436 .57585 L
.4345 .57589 L
.43463 .57592 L
.43476 .57596 L
.4349 .57599 L
.43503 .57603 L
.43516 .57606 L
.43529 .5761 L
.43543 .57613 L
.43556 .57616 L
.43569 .5762 L
.43583 .57623 L
.43596 .57627 L
.43609 .5763 L
.43622 .57634 L
.43636 .57637 L
.43649 .5764 L
.43662 .57644 L
.43676 .57647 L
.43689 .57651 L
.43702 .57654 L
.43715 .57657 L
.43729 .57661 L
.43742 .57664 L
.43755 .57668 L
.43769 .57671 L
.43782 .57674 L
.43795 .57678 L
.43808 .57681 L
.43822 .57684 L
.43835 .57688 L
.43848 .57691 L
.43862 .57695 L
.43875 .57698 L
.43888 .57701 L
.43901 .57705 L
.43915 .57708 L
.43928 .57711 L
.43941 .57715 L
.43955 .57718 L
.43968 .57721 L
.43981 .57725 L
.43994 .57728 L
.44008 .57731 L
.44021 .57734 L
.44034 .57738 L
.44048 .57741 L
.44061 .57744 L
.44074 .57748 L
.44087 .57751 L
Mistroke
.44101 .57754 L
.44114 .57757 L
.44127 .57761 L
.44141 .57764 L
.44154 .57767 L
.44167 .5777 L
.4418 .57774 L
.44194 .57777 L
.44207 .5778 L
.4422 .57783 L
.44234 .57786 L
.44247 .5779 L
.4426 .57793 L
.44273 .57796 L
.44287 .57799 L
.443 .57803 L
.44313 .57806 L
.44327 .57809 L
.4434 .57812 L
.44353 .57815 L
.44366 .57819 L
.4438 .57822 L
.44393 .57825 L
.44406 .57828 L
.4442 .57831 L
.44433 .57834 L
.44446 .57838 L
.4446 .57841 L
.44473 .57844 L
.44486 .57847 L
.44499 .5785 L
.44513 .57853 L
.44526 .57856 L
.44539 .5786 L
.44553 .57863 L
.44566 .57866 L
.44579 .57869 L
.44592 .57872 L
.44606 .57875 L
.44619 .57878 L
.44632 .57881 L
.44646 .57884 L
.44659 .57888 L
.44672 .57891 L
.44685 .57894 L
.44699 .57897 L
.44712 .579 L
.44725 .57903 L
.44739 .57906 L
.44752 .57909 L
Mistroke
.44765 .57912 L
.44778 .57915 L
.44792 .57918 L
.44805 .57921 L
.44818 .57924 L
.44832 .57927 L
.44845 .5793 L
.44858 .57933 L
.44871 .57936 L
.44885 .57939 L
.44898 .57942 L
.44911 .57945 L
.44925 .57949 L
.44938 .57952 L
.44951 .57955 L
.44964 .57958 L
.44978 .57961 L
.44991 .57964 L
.45004 .57967 L
.45018 .5797 L
.45031 .57973 L
.45044 .57976 L
.45057 .57979 L
.45071 .57982 L
.45084 .57985 L
.45097 .57987 L
.45111 .5799 L
.45124 .57993 L
.45137 .57996 L
.4515 .57999 L
.45164 .58002 L
.45177 .58005 L
.4519 .58008 L
.45204 .58011 L
.45217 .58014 L
.4523 .58017 L
.45243 .5802 L
.45257 .58023 L
.4527 .58026 L
.45283 .58029 L
.45297 .58032 L
.4531 .58035 L
.45323 .58037 L
.45336 .5804 L
.4535 .58043 L
.45363 .58046 L
.45376 .58049 L
.4539 .58052 L
.45403 .58055 L
.45416 .58058 L
Mistroke
.45429 .58061 L
.45443 .58064 L
.45456 .58066 L
.45469 .58069 L
.45483 .58072 L
.45496 .58075 L
.45509 .58078 L
.45522 .58081 L
.45536 .58084 L
.45549 .58086 L
.45562 .58089 L
.45576 .58092 L
.45589 .58095 L
.45602 .58098 L
.45615 .58101 L
.45629 .58103 L
.45642 .58106 L
.45655 .58109 L
.45669 .58112 L
.45682 .58115 L
.45695 .58118 L
.45708 .5812 L
.45722 .58123 L
.45735 .58126 L
.45748 .58129 L
.45762 .58132 L
.45775 .58134 L
.45788 .58137 L
.45801 .5814 L
.45815 .58143 L
.45828 .58145 L
.45841 .58148 L
.45855 .58151 L
.45868 .58154 L
.45881 .58157 L
.45894 .58159 L
.45908 .58162 L
.45921 .58165 L
.45934 .58168 L
.45948 .5817 L
.45961 .58173 L
.45974 .58176 L
.45987 .58178 L
.46001 .58181 L
.46014 .58184 L
.46027 .58187 L
.46041 .58189 L
.46054 .58192 L
.46067 .58195 L
.4608 .58197 L
Mistroke
.46094 .582 L
.46107 .58203 L
.4612 .58205 L
.46134 .58208 L
.46147 .58211 L
.4616 .58213 L
.46173 .58216 L
.46187 .58219 L
.462 .58221 L
.46213 .58224 L
.46227 .58227 L
.4624 .58229 L
.46253 .58232 L
.46266 .58234 L
.4628 .58237 L
.46293 .5824 L
.46306 .58242 L
.4632 .58245 L
.46333 .58247 L
.46346 .5825 L
.46359 .58253 L
.46373 .58255 L
.46386 .58258 L
.46399 .5826 L
.46413 .58263 L
.46426 .58266 L
.46439 .58268 L
.46452 .58271 L
.46466 .58273 L
.46479 .58276 L
.46492 .58279 L
.46506 .58281 L
.46519 .58284 L
.46532 .58286 L
.46545 .58289 L
.46559 .58291 L
.46572 .58294 L
.46585 .58296 L
.46599 .58299 L
.46612 .58301 L
.46625 .58304 L
.46638 .58307 L
.46652 .58309 L
.46665 .58312 L
.46678 .58314 L
.46692 .58317 L
.46705 .58319 L
.46718 .58322 L
.46732 .58324 L
.46745 .58327 L
Mistroke
.46758 .58329 L
.46771 .58332 L
.46785 .58334 L
.46798 .58337 L
.46811 .58339 L
.46825 .58342 L
.46838 .58344 L
.46851 .58347 L
.46864 .58349 L
.46878 .58352 L
.46891 .58354 L
.46904 .58356 L
.46918 .58359 L
.46931 .58361 L
.46944 .58364 L
.46957 .58366 L
.46971 .58369 L
.46984 .58371 L
.46997 .58374 L
.47011 .58376 L
.47024 .58379 L
.47037 .58381 L
.4705 .58383 L
.47064 .58386 L
.47077 .58388 L
.4709 .58391 L
.47104 .58393 L
.47117 .58396 L
.4713 .58398 L
.47143 .584 L
.47157 .58403 L
.4717 .58405 L
.47183 .58407 L
.47197 .5841 L
.4721 .58412 L
.47223 .58415 L
.47236 .58417 L
.4725 .58419 L
.47263 .58422 L
.47276 .58424 L
.4729 .58427 L
.47303 .58429 L
.47316 .58431 L
.47329 .58434 L
.47343 .58436 L
.47356 .58438 L
.47369 .58441 L
.47383 .58443 L
.47396 .58446 L
.47409 .58448 L
Mistroke
.47422 .5845 L
.47436 .58453 L
.47449 .58455 L
.47462 .58457 L
.47476 .5846 L
.47489 .58462 L
.47502 .58464 L
.47515 .58467 L
.47529 .58469 L
.47542 .58471 L
.47555 .58474 L
.47569 .58476 L
.47582 .58478 L
.47595 .58481 L
.47608 .58483 L
.47622 .58485 L
.47635 .58488 L
.47648 .5849 L
.47662 .58492 L
.47675 .58495 L
.47688 .58497 L
.47701 .58499 L
.47715 .58502 L
.47728 .58504 L
.47741 .58506 L
.47755 .58508 L
.47768 .58511 L
.47781 .58513 L
.47794 .58515 L
.47808 .58518 L
.47821 .5852 L
.47834 .58522 L
.47848 .58525 L
.47861 .58527 L
.47874 .58529 L
.47887 .58531 L
.47901 .58534 L
.47914 .58536 L
.47927 .58538 L
.47941 .5854 L
.47954 .58543 L
.47967 .58545 L
.4798 .58547 L
.47994 .58549 L
.48007 .58552 L
.4802 .58554 L
.48034 .58556 L
.48047 .58558 L
.4806 .58561 L
.48073 .58563 L
Mistroke
.48087 .58565 L
.481 .58567 L
.48113 .58569 L
.48127 .58572 L
.4814 .58574 L
.48153 .58576 L
.48166 .58578 L
.4818 .5858 L
.48193 .58583 L
.48206 .58585 L
.4822 .58587 L
.48233 .58589 L
.48246 .58591 L
.48259 .58594 L
.48273 .58596 L
.48286 .58598 L
.48299 .586 L
.48313 .58602 L
.48326 .58604 L
.48339 .58607 L
.48352 .58609 L
.48366 .58611 L
.48379 .58613 L
.48392 .58615 L
.48406 .58617 L
.48419 .58619 L
.48432 .58622 L
.48445 .58624 L
.48459 .58626 L
.48472 .58628 L
.48485 .5863 L
.48499 .58632 L
.48512 .58634 L
.48525 .58636 L
.48538 .58638 L
.48552 .58641 L
.48565 .58643 L
.48578 .58645 L
.48592 .58647 L
.48605 .58649 L
.48618 .58651 L
.48631 .58653 L
.48645 .58655 L
.48658 .58657 L
.48671 .58659 L
.48685 .58661 L
.48698 .58664 L
.48711 .58666 L
.48724 .58668 L
.48738 .5867 L
Mistroke
.48751 .58672 L
.48764 .58674 L
.48778 .58676 L
.48791 .58678 L
.48804 .5868 L
.48817 .58682 L
.48831 .58684 L
.48844 .58686 L
.48857 .58688 L
.48871 .5869 L
.48884 .58692 L
.48897 .58694 L
.48911 .58696 L
.48924 .58698 L
.48937 .587 L
.4895 .58702 L
.48964 .58704 L
.48977 .58706 L
.4899 .58708 L
.49004 .5871 L
.49017 .58712 L
.4903 .58714 L
.49043 .58716 L
.49057 .58718 L
.4907 .5872 L
.49083 .58722 L
.49097 .58724 L
.4911 .58726 L
.49123 .58728 L
.49136 .5873 L
.4915 .58732 L
.49163 .58734 L
.49176 .58736 L
.4919 .58738 L
.49203 .5874 L
.49216 .58742 L
.49229 .58744 L
.49243 .58746 L
.49256 .58748 L
.49269 .5875 L
.49283 .58752 L
.49296 .58753 L
.49309 .58755 L
.49322 .58757 L
.49336 .58759 L
.49349 .58761 L
.49362 .58763 L
.49376 .58765 L
.49389 .58767 L
.49402 .58769 L
Mistroke
.49415 .58771 L
.49429 .58773 L
.49442 .58775 L
.49455 .58777 L
.49469 .58779 L
.49482 .58781 L
.49495 .58782 L
.49508 .58784 L
.49522 .58786 L
.49535 .58788 L
.49548 .5879 L
.49562 .58792 L
.49575 .58794 L
.49588 .58796 L
.49601 .58798 L
.49615 .588 L
.49628 .58802 L
.49641 .58803 L
.49655 .58805 L
.49668 .58807 L
.49681 .58809 L
.49694 .58811 L
.49708 .58813 L
.49721 .58815 L
.49734 .58817 L
.49748 .58819 L
.49761 .5882 L
.49774 .58822 L
.49787 .58824 L
.49801 .58826 L
.49814 .58828 L
.49827 .5883 L
.49841 .58832 L
.49854 .58834 L
.49867 .58835 L
.4988 .58837 L
.49894 .58839 L
.49907 .58841 L
.4992 .58843 L
.49934 .58845 L
.49947 .58847 L
.4996 .58848 L
.49973 .5885 L
.49987 .58852 L
.5 .58854 L
.50013 .58856 L
.50027 .58858 L
.5004 .58859 L
.50053 .58861 L
.50066 .58863 L
Mistroke
.5008 .58865 L
.50093 .58867 L
.50106 .58869 L
.5012 .5887 L
.50133 .58872 L
.50146 .58874 L
.50159 .58876 L
.50173 .58878 L
.50186 .5888 L
.50199 .58881 L
.50213 .58883 L
.50226 .58885 L
.50239 .58887 L
.50252 .58889 L
.50266 .5889 L
.50279 .58892 L
.50292 .58894 L
.50306 .58896 L
.50319 .58898 L
.50332 .58899 L
.50345 .58901 L
.50359 .58903 L
.50372 .58905 L
.50385 .58907 L
.50399 .58908 L
.50412 .5891 L
.50425 .58912 L
.50438 .58914 L
.50452 .58915 L
.50465 .58917 L
.50478 .58919 L
.50492 .58921 L
.50505 .58922 L
.50518 .58924 L
.50531 .58926 L
.50545 .58928 L
.50558 .5893 L
.50571 .58931 L
.50585 .58933 L
.50598 .58935 L
.50611 .58937 L
.50624 .58938 L
.50638 .5894 L
.50651 .58942 L
.50664 .58944 L
.50678 .58945 L
.50691 .58947 L
.50704 .58949 L
.50717 .5895 L
.50731 .58952 L
Mistroke
.50744 .58954 L
.50757 .58956 L
.50771 .58957 L
.50784 .58959 L
.50797 .58961 L
.5081 .58963 L
.50824 .58964 L
.50837 .58966 L
.5085 .58968 L
.50864 .5897 L
.50877 .58971 L
.5089 .58973 L
.50903 .58975 L
.50917 .58976 L
.5093 .58978 L
.50943 .5898 L
.50957 .58981 L
.5097 .58983 L
.50983 .58985 L
.50996 .58987 L
.5101 .58988 L
.51023 .5899 L
.51036 .58992 L
.5105 .58993 L
.51063 .58995 L
.51076 .58997 L
.51089 .58998 L
.51103 .59 L
.51116 .59002 L
.51129 .59003 L
.51143 .59005 L
.51156 .59007 L
.51169 .59008 L
.51183 .5901 L
.51196 .59012 L
.51209 .59013 L
.51222 .59015 L
.51236 .59017 L
.51249 .59018 L
.51262 .5902 L
.51276 .59022 L
.51289 .59023 L
.51302 .59025 L
.51315 .59027 L
.51329 .59028 L
.51342 .5903 L
.51355 .59032 L
.51369 .59033 L
.51382 .59035 L
.51395 .59037 L
Mistroke
.51408 .59038 L
.51422 .5904 L
.51435 .59042 L
.51448 .59043 L
.51462 .59045 L
.51475 .59046 L
.51488 .59048 L
.51501 .5905 L
.51515 .59051 L
.51528 .59053 L
.51541 .59055 L
.51555 .59056 L
.51568 .59058 L
.51581 .59059 L
.51594 .59061 L
.51608 .59063 L
.51621 .59064 L
.51634 .59066 L
.51648 .59067 L
.51661 .59069 L
.51674 .59071 L
.51687 .59072 L
.51701 .59074 L
.51714 .59075 L
.51727 .59077 L
.51741 .59078 L
.51754 .5908 L
.51767 .59082 L
.5178 .59083 L
.51794 .59085 L
.51807 .59086 L
.5182 .59088 L
.51834 .5909 L
.51847 .59091 L
.5186 .59093 L
.51873 .59094 L
.51887 .59096 L
.519 .59097 L
.51913 .59099 L
.51927 .59101 L
.5194 .59102 L
.51953 .59104 L
.51966 .59105 L
.5198 .59107 L
.51993 .59108 L
.52006 .5911 L
.5202 .59111 L
.52033 .59113 L
.52046 .59115 L
.52059 .59116 L
Mistroke
.52073 .59118 L
.52086 .59119 L
.52099 .59121 L
.52113 .59122 L
.52126 .59124 L
.52139 .59125 L
.52152 .59127 L
.52166 .59128 L
.52179 .5913 L
.52192 .59131 L
.52206 .59133 L
.52219 .59134 L
.52232 .59136 L
.52245 .59137 L
.52259 .59139 L
.52272 .5914 L
.52285 .59142 L
.52299 .59144 L
.52312 .59145 L
.52325 .59147 L
.52338 .59148 L
.52352 .5915 L
.52365 .59151 L
.52378 .59153 L
.52392 .59154 L
.52405 .59156 L
.52418 .59157 L
.52431 .59159 L
.52445 .5916 L
.52458 .59162 L
.52471 .59163 L
.52485 .59164 L
.52498 .59166 L
.52511 .59167 L
.52524 .59169 L
.52538 .5917 L
.52551 .59172 L
.52564 .59173 L
.52578 .59175 L
.52591 .59176 L
.52604 .59178 L
.52617 .59179 L
.52631 .59181 L
.52644 .59182 L
.52657 .59184 L
.52671 .59185 L
.52684 .59187 L
.52697 .59188 L
.5271 .59189 L
.52724 .59191 L
Mistroke
.52737 .59192 L
.5275 .59194 L
.52764 .59195 L
.52777 .59197 L
.5279 .59198 L
.52803 .59199 L
.52817 .59201 L
.5283 .59202 L
.52843 .59204 L
.52857 .59205 L
.5287 .59207 L
.52883 .59208 L
.52896 .59209 L
.5291 .59211 L
.52923 .59212 L
.52936 .59214 L
.5295 .59215 L
.52963 .59216 L
.52976 .59218 L
.52989 .59219 L
.53003 .59221 L
.53016 .59222 L
.53029 .59223 L
.53043 .59225 L
.53056 .59226 L
.53069 .59228 L
.53082 .59229 L
.53096 .5923 L
.53109 .59232 L
.53122 .59233 L
.53136 .59235 L
.53149 .59236 L
.53162 .59237 L
.53175 .59239 L
.53189 .5924 L
.53202 .59241 L
.53215 .59243 L
.53229 .59244 L
.53242 .59245 L
.53255 .59247 L
.53268 .59248 L
.53282 .5925 L
.53295 .59251 L
.53308 .59252 L
.53322 .59254 L
.53335 .59255 L
.53348 .59256 L
.53362 .59258 L
.53375 .59259 L
.53388 .5926 L
Mistroke
.53401 .59262 L
.53415 .59263 L
.53428 .59264 L
.53441 .59266 L
.53455 .59267 L
.53468 .59268 L
.53481 .5927 L
.53494 .59271 L
.53508 .59273 L
.53521 .59274 L
.53534 .59275 L
.53548 .59277 L
.53561 .59278 L
.53574 .59279 L
.53587 .59281 L
.53601 .59282 L
.53614 .59283 L
.53627 .59285 L
.53641 .59286 L
.53654 .59287 L
.53667 .59288 L
.5368 .5929 L
.53694 .59291 L
.53707 .59292 L
.5372 .59294 L
.53734 .59295 L
.53747 .59296 L
.5376 .59298 L
.53773 .59299 L
.53787 .593 L
.538 .59302 L
.53813 .59303 L
.53827 .59304 L
.5384 .59306 L
.53853 .59307 L
.53866 .59308 L
.5388 .59309 L
.53893 .59311 L
.53906 .59312 L
.5392 .59313 L
.53933 .59315 L
.53946 .59316 L
.53959 .59317 L
.53973 .59318 L
.53986 .5932 L
.53999 .59321 L
.54013 .59322 L
.54026 .59324 L
.54039 .59325 L
.54052 .59326 L
Mistroke
.54066 .59327 L
.54079 .59329 L
.54092 .5933 L
.54106 .59331 L
.54119 .59333 L
.54132 .59334 L
.54145 .59335 L
.54159 .59336 L
.54172 .59338 L
.54185 .59339 L
.54199 .5934 L
.54212 .59341 L
.54225 .59343 L
.54238 .59344 L
.54252 .59345 L
.54265 .59346 L
.54278 .59348 L
.54292 .59349 L
.54305 .5935 L
.54318 .59351 L
.54331 .59353 L
.54345 .59354 L
.54358 .59355 L
.54371 .59356 L
.54385 .59358 L
.54398 .59359 L
.54411 .5936 L
.54424 .59361 L
.54438 .59363 L
.54451 .59364 L
.54464 .59365 L
.54478 .59366 L
.54491 .59368 L
.54504 .59369 L
.54517 .5937 L
.54531 .59371 L
.54544 .59372 L
.54557 .59374 L
.54571 .59375 L
.54584 .59376 L
.54597 .59377 L
.5461 .59379 L
.54624 .5938 L
.54637 .59381 L
.5465 .59382 L
.54664 .59383 L
.54677 .59385 L
.5469 .59386 L
.54703 .59387 L
.54717 .59388 L
Mistroke
.5473 .59389 L
.54743 .59391 L
.54757 .59392 L
.5477 .59393 L
.54783 .59394 L
.54796 .59395 L
.5481 .59397 L
.54823 .59398 L
.54836 .59399 L
.5485 .594 L
.54863 .59401 L
.54876 .59403 L
.54889 .59404 L
.54903 .59405 L
.54916 .59406 L
.54929 .59407 L
.54943 .59409 L
.54956 .5941 L
.54969 .59411 L
.54982 .59412 L
.54996 .59413 L
.55009 .59414 L
.55022 .59416 L
.55036 .59417 L
.55049 .59418 L
.55062 .59419 L
.55075 .5942 L
.55089 .59422 L
.55102 .59423 L
.55115 .59424 L
.55129 .59425 L
.55142 .59426 L
.55155 .59428 L
.55168 .59429 L
.55182 .5943 L
.55195 .59431 L
.55208 .59432 L
.55222 .59433 L
.55235 .59435 L
.55248 .59436 L
.55261 .59437 L
.55275 .59438 L
.55288 .59439 L
.55301 .5944 L
.55315 .59441 L
.55328 .59443 L
.55341 .59444 L
.55354 .59445 L
.55368 .59446 L
.55381 .59447 L
Mistroke
.55394 .59448 L
.55408 .5945 L
.55421 .59451 L
.55434 .59452 L
.55447 .59453 L
.55461 .59454 L
.55474 .59455 L
.55487 .59456 L
.55501 .59458 L
.55514 .59459 L
.55527 .5946 L
.5554 .59461 L
.55554 .59462 L
.55567 .59463 L
.5558 .59464 L
.55594 .59465 L
.55607 .59467 L
.5562 .59468 L
.55634 .59469 L
.55647 .5947 L
.5566 .59471 L
.55673 .59472 L
.55687 .59473 L
.557 .59474 L
.55713 .59475 L
.55727 .59477 L
.5574 .59478 L
.55753 .59479 L
.55766 .5948 L
.5578 .59481 L
.55793 .59482 L
.55806 .59483 L
.5582 .59484 L
.55833 .59485 L
.55846 .59487 L
.55859 .59488 L
.55873 .59489 L
.55886 .5949 L
.55899 .59491 L
.55913 .59492 L
.55926 .59493 L
.55939 .59494 L
.55952 .59495 L
.55966 .59496 L
.55979 .59497 L
.55992 .59499 L
.56006 .595 L
.56019 .59501 L
.56032 .59502 L
.56045 .59503 L
Mistroke
.56059 .59504 L
.56072 .59505 L
.56085 .59506 L
.56099 .59507 L
.56112 .59508 L
.56125 .59509 L
.56138 .5951 L
.56152 .59511 L
.56165 .59512 L
.56178 .59514 L
.56192 .59515 L
.56205 .59516 L
.56218 .59517 L
.56231 .59518 L
.56245 .59519 L
.56258 .5952 L
.56271 .59521 L
.56285 .59522 L
.56298 .59523 L
.56311 .59524 L
.56324 .59525 L
.56338 .59526 L
.56351 .59527 L
.56364 .59528 L
.56378 .59529 L
.56391 .5953 L
.56404 .59531 L
.56417 .59532 L
.56431 .59533 L
.56444 .59534 L
.56457 .59535 L
.56471 .59536 L
.56484 .59537 L
.56497 .59538 L
.5651 .5954 L
.56524 .59541 L
.56537 .59542 L
.5655 .59543 L
.56564 .59544 L
.56577 .59545 L
.5659 .59546 L
.56603 .59547 L
.56617 .59548 L
.5663 .59549 L
.56643 .5955 L
.56657 .59551 L
.5667 .59552 L
.56683 .59553 L
.56696 .59554 L
.5671 .59555 L
Mistroke
.56723 .59556 L
.56736 .59557 L
.5675 .59558 L
.56763 .59559 L
.56776 .5956 L
.56789 .59561 L
.56803 .59562 L
.56816 .59563 L
.56829 .59564 L
.56843 .59565 L
.56856 .59566 L
.56869 .59567 L
.56882 .59568 L
.56896 .59569 L
.56909 .5957 L
.56922 .59571 L
.56936 .59572 L
.56949 .59573 L
.56962 .59574 L
.56975 .59575 L
.56989 .59576 L
.57002 .59577 L
.57015 .59578 L
.57029 .59579 L
.57042 .5958 L
.57055 .59581 L
.57068 .59582 L
.57082 .59583 L
.57095 .59584 L
.57108 .59585 L
.57122 .59586 L
.57135 .59587 L
.57148 .59588 L
.57161 .59589 L
.57175 .5959 L
.57188 .5959 L
.57201 .59591 L
.57215 .59592 L
.57228 .59593 L
.57241 .59594 L
.57254 .59595 L
.57268 .59596 L
.57281 .59597 L
.57294 .59598 L
.57308 .59599 L
.57321 .596 L
.57334 .59601 L
.57347 .59602 L
.57361 .59603 L
.57374 .59604 L
Mistroke
.57387 .59605 L
.57401 .59606 L
.57414 .59607 L
.57427 .59608 L
.5744 .59609 L
.57454 .5961 L
.57467 .59611 L
.5748 .59612 L
.57494 .59613 L
.57507 .59614 L
.5752 .59615 L
.57533 .59615 L
.57547 .59616 L
.5756 .59617 L
.57573 .59618 L
.57587 .59619 L
.576 .5962 L
.57613 .59621 L
.57626 .59622 L
.5764 .59623 L
.57653 .59624 L
.57666 .59625 L
.5768 .59626 L
.57693 .59627 L
.57706 .59628 L
.57719 .59629 L
.57733 .5963 L
.57746 .5963 L
.57759 .59631 L
.57773 .59632 L
.57786 .59633 L
.57799 .59634 L
.57813 .59635 L
.57826 .59636 L
.57839 .59637 L
.57852 .59638 L
.57866 .59639 L
.57879 .5964 L
.57892 .59641 L
.57906 .59641 L
.57919 .59642 L
.57932 .59643 L
.57945 .59644 L
.57959 .59645 L
.57972 .59646 L
.57985 .59647 L
.57999 .59648 L
.58012 .59649 L
.58025 .5965 L
.58038 .5965 L
Mistroke
.58052 .59651 L
.58065 .59652 L
.58078 .59653 L
.58092 .59654 L
.58105 .59655 L
.58118 .59656 L
.58131 .59657 L
.58145 .59658 L
.58158 .59658 L
.58171 .59659 L
.58185 .5966 L
.58198 .59661 L
.58211 .59662 L
.58224 .59663 L
.58238 .59664 L
.58251 .59665 L
.58264 .59665 L
.58278 .59666 L
.58291 .59667 L
.58304 .59668 L
.58317 .59669 L
.58331 .5967 L
.58344 .59671 L
.58357 .59672 L
.58371 .59672 L
.58384 .59673 L
.58397 .59674 L
.5841 .59675 L
.58424 .59676 L
.58437 .59677 L
.5845 .59678 L
.58464 .59678 L
.58477 .59679 L
.5849 .5968 L
.58503 .59681 L
.58517 .59682 L
.5853 .59683 L
.58543 .59684 L
.58557 .59684 L
.5857 .59685 L
.58583 .59686 L
.58596 .59687 L
.5861 .59688 L
.58623 .59689 L
.58636 .5969 L
.5865 .5969 L
.58663 .59691 L
.58676 .59692 L
.58689 .59693 L
.58703 .59694 L
Mistroke
.58716 .59695 L
.58729 .59695 L
.58743 .59696 L
.58756 .59697 L
.58769 .59698 L
.58782 .59699 L
.58796 .597 L
.58809 .597 L
.58822 .59701 L
.58836 .59702 L
.58849 .59703 L
.58862 .59704 L
.58875 .59705 L
.58889 .59705 L
.58902 .59706 L
.58915 .59707 L
.58929 .59708 L
.58942 .59709 L
.58955 .5971 L
.58968 .5971 L
.58982 .59711 L
.58995 .59712 L
.59008 .59713 L
.59022 .59714 L
.59035 .59714 L
.59048 .59715 L
.59061 .59716 L
.59075 .59717 L
.59088 .59718 L
.59101 .59718 L
.59115 .59719 L
.59128 .5972 L
.59141 .59721 L
.59154 .59722 L
.59168 .59722 L
.59181 .59723 L
.59194 .59724 L
.59208 .59725 L
.59221 .59726 L
.59234 .59726 L
.59247 .59727 L
.59261 .59728 L
.59274 .59729 L
.59287 .5973 L
.59301 .5973 L
.59314 .59731 L
.59327 .59732 L
.5934 .59733 L
.59354 .59734 L
.59367 .59734 L
Mistroke
.5938 .59735 L
.59394 .59736 L
.59407 .59737 L
.5942 .59738 L
.59433 .59738 L
.59447 .59739 L
.5946 .5974 L
.59473 .59741 L
.59487 .59742 L
.595 .59742 L
.59513 .59743 L
.59526 .59744 L
.5954 .59745 L
.59553 .59746 L
.59566 .59746 L
.5958 .59747 L
.59593 .59748 L
.59606 .59749 L
.59619 .59749 L
.59633 .5975 L
.59646 .59751 L
.59659 .59752 L
.59673 .59753 L
.59686 .59753 L
.59699 .59754 L
.59712 .59755 L
.59726 .59756 L
.59739 .59756 L
.59752 .59757 L
.59766 .59758 L
.59779 .59759 L
.59792 .59759 L
.59805 .5976 L
.59819 .59761 L
.59832 .59762 L
.59845 .59763 L
.59859 .59763 L
.59872 .59764 L
.59885 .59765 L
.59898 .59766 L
.59912 .59766 L
.59925 .59767 L
.59938 .59768 L
.59952 .59769 L
.59965 .59769 L
.59978 .5977 L
.59991 .59771 L
.60005 .59772 L
.60018 .59772 L
.60031 .59773 L
Mistroke
.60045 .59774 L
.60058 .59775 L
.60071 .59775 L
.60085 .59776 L
.60098 .59777 L
.60111 .59778 L
.60124 .59778 L
.60138 .59779 L
.60151 .5978 L
.60164 .59781 L
.60178 .59781 L
.60191 .59782 L
.60204 .59783 L
.60217 .59783 L
.60231 .59784 L
.60244 .59785 L
.60257 .59786 L
.60271 .59786 L
.60284 .59787 L
.60297 .59788 L
.6031 .59789 L
.60324 .59789 L
.60337 .5979 L
.6035 .59791 L
.60364 .59792 L
.60377 .59792 L
.6039 .59793 L
.60403 .59794 L
.60417 .59794 L
.6043 .59795 L
.60443 .59796 L
.60457 .59797 L
.6047 .59797 L
.60483 .59798 L
.60496 .59799 L
.6051 .598 L
.60523 .598 L
.60536 .59801 L
.6055 .59802 L
.60563 .59802 L
.60576 .59803 L
.60589 .59804 L
.60603 .59805 L
.60616 .59805 L
.60629 .59806 L
.60643 .59807 L
.60656 .59807 L
.60669 .59808 L
.60682 .59809 L
.60696 .59809 L
Mistroke
.60709 .5981 L
.60722 .59811 L
.60736 .59812 L
.60749 .59812 L
.60762 .59813 L
.60775 .59814 L
.60789 .59814 L
.60802 .59815 L
.60815 .59816 L
.60829 .59817 L
.60842 .59817 L
.60855 .59818 L
.60868 .59819 L
.60882 .59819 L
.60895 .5982 L
.60908 .59821 L
.60922 .59821 L
.60935 .59822 L
.60948 .59823 L
.60961 .59823 L
.60975 .59824 L
.60988 .59825 L
.61001 .59826 L
.61015 .59826 L
.61028 .59827 L
.61041 .59828 L
.61054 .59828 L
.61068 .59829 L
.61081 .5983 L
.61094 .5983 L
.61108 .59831 L
.61121 .59832 L
.61134 .59832 L
.61147 .59833 L
.61161 .59834 L
.61174 .59834 L
.61187 .59835 L
.61201 .59836 L
.61214 .59836 L
.61227 .59837 L
.6124 .59838 L
.61254 .59838 L
.61267 .59839 L
.6128 .5984 L
.61294 .5984 L
.61307 .59841 L
.6132 .59842 L
.61333 .59842 L
.61347 .59843 L
.6136 .59844 L
Mistroke
.61373 .59844 L
.61387 .59845 L
.614 .59846 L
.61413 .59846 L
.61426 .59847 L
.6144 .59848 L
.61453 .59848 L
.61466 .59849 L
.6148 .5985 L
.61493 .5985 L
.61506 .59851 L
.61519 .59852 L
.61533 .59852 L
.61546 .59853 L
.61559 .59854 L
.61573 .59854 L
.61586 .59855 L
.61599 .59856 L
.61612 .59856 L
.61626 .59857 L
.61639 .59858 L
.61652 .59858 L
.61666 .59859 L
.61679 .5986 L
.61692 .5986 L
.61705 .59861 L
.61719 .59861 L
.61732 .59862 L
.61745 .59863 L
.61759 .59863 L
.61772 .59864 L
.61785 .59865 L
.61798 .59865 L
.61812 .59866 L
.61825 .59867 L
.61838 .59867 L
.61852 .59868 L
.61865 .59868 L
.61878 .59869 L
.61891 .5987 L
.61905 .5987 L
.61918 .59871 L
.61931 .59872 L
.61945 .59872 L
.61958 .59873 L
.61971 .59873 L
.61984 .59874 L
.61998 .59875 L
.62011 .59875 L
.62024 .59876 L
Mistroke
.62038 .59877 L
.62051 .59877 L
.62064 .59878 L
.62077 .59878 L
.62091 .59879 L
.62104 .5988 L
.62117 .5988 L
.62131 .59881 L
.62144 .59882 L
.62157 .59882 L
.6217 .59883 L
.62184 .59883 L
.62197 .59884 L
.6221 .59885 L
.62224 .59885 L
.62237 .59886 L
.6225 .59886 L
.62263 .59887 L
.62277 .59888 L
.6229 .59888 L
.62303 .59889 L
.62317 .5989 L
.6233 .5989 L
.62343 .59891 L
.62357 .59891 L
.6237 .59892 L
.62383 .59893 L
.62396 .59893 L
.6241 .59894 L
.62423 .59894 L
.62436 .59895 L
.6245 .59896 L
.62463 .59896 L
.62476 .59897 L
.62489 .59897 L
.62503 .59898 L
.62516 .59899 L
.62529 .59899 L
.62543 .599 L
.62556 .599 L
.62569 .59901 L
.62582 .59902 L
.62596 .59902 L
.62609 .59903 L
.62622 .59903 L
.62636 .59904 L
.62649 .59905 L
.62662 .59905 L
.62675 .59906 L
.62689 .59906 L
Mistroke
.62702 .59907 L
.62715 .59908 L
.62729 .59908 L
.62742 .59909 L
.62755 .59909 L
.62768 .5991 L
.62782 .59911 L
.62795 .59911 L
.62808 .59912 L
.62822 .59912 L
.62835 .59913 L
.62848 .59914 L
.62861 .59914 L
.62875 .59915 L
.62888 .59915 L
.62901 .59916 L
.62915 .59916 L
.62928 .59917 L
.62941 .59918 L
.62954 .59918 L
.62968 .59919 L
.62981 .59919 L
.62994 .5992 L
.63008 .5992 L
.63021 .59921 L
.63034 .59922 L
.63047 .59922 L
.63061 .59923 L
.63074 .59923 L
.63087 .59924 L
.63101 .59925 L
.63114 .59925 L
.63127 .59926 L
.6314 .59926 L
.63154 .59927 L
.63167 .59927 L
.6318 .59928 L
.63194 .59928 L
.63207 .59929 L
.6322 .5993 L
.63233 .5993 L
.63247 .59931 L
.6326 .59931 L
.63273 .59932 L
.63287 .59932 L
.633 .59933 L
.63313 .59933 L
.63326 .59934 L
.6334 .59935 L
.63353 .59935 L
Mistroke
.63366 .59936 L
.6338 .59936 L
.63393 .59937 L
.63406 .59937 L
.63419 .59938 L
.63433 .59938 L
.63446 .59939 L
.63459 .5994 L
.63473 .5994 L
.63486 .59941 L
.63499 .59941 L
.63512 .59942 L
.63526 .59942 L
.63539 .59943 L
.63552 .59943 L
.63566 .59944 L
.63579 .59944 L
.63592 .59945 L
.63605 .59946 L
.63619 .59946 L
.63632 .59947 L
.63645 .59947 L
.63659 .59948 L
.63672 .59948 L
.63685 .59949 L
.63698 .59949 L
.63712 .5995 L
.63725 .5995 L
.63738 .59951 L
.63752 .59951 L
.63765 .59952 L
.63778 .59953 L
.63791 .59953 L
.63805 .59954 L
.63818 .59954 L
.63831 .59955 L
.63845 .59955 L
.63858 .59956 L
.63871 .59956 L
.63884 .59957 L
.63898 .59957 L
.63911 .59958 L
.63924 .59958 L
.63938 .59959 L
.63951 .5996 L
.63964 .5996 L
.63977 .59961 L
.63991 .59961 L
.64004 .59962 L
.64017 .59962 L
Mistroke
.64031 .59963 L
.64044 .59963 L
.64057 .59964 L
.6407 .59964 L
.64084 .59965 L
.64097 .59965 L
.6411 .59966 L
.64124 .59966 L
.64137 .59967 L
.6415 .59967 L
.64163 .59968 L
.64177 .59968 L
.6419 .59969 L
.64203 .59969 L
.64217 .5997 L
.6423 .5997 L
.64243 .59971 L
.64256 .59972 L
.6427 .59972 L
.64283 .59973 L
.64296 .59973 L
.6431 .59974 L
.64323 .59974 L
.64336 .59975 L
.64349 .59975 L
.64363 .59976 L
.64376 .59976 L
.64389 .59977 L
.64403 .59977 L
.64416 .59978 L
.64429 .59978 L
.64442 .59979 L
.64456 .59979 L
.64469 .5998 L
.64482 .5998 L
.64496 .59981 L
.64509 .59981 L
.64522 .59982 L
.64536 .59982 L
.64549 .59983 L
.64562 .59983 L
.64575 .59984 L
.64589 .59984 L
.64602 .59985 L
.64615 .59985 L
.64629 .59986 L
.64642 .59986 L
.64655 .59987 L
.64668 .59987 L
.64682 .59988 L
Mistroke
.64695 .59988 L
.64708 .59989 L
.64722 .59989 L
.64735 .5999 L
.64748 .5999 L
.64761 .59991 L
.64775 .59991 L
.64788 .59992 L
.64801 .59992 L
.64815 .59993 L
.64828 .59993 L
.64841 .59994 L
.64854 .59994 L
.64868 .59995 L
.64881 .59995 L
.64894 .59996 L
.64908 .59996 L
.64921 .59997 L
.64934 .59997 L
.64947 .59998 L
.64961 .59998 L
.64974 .59998 L
.64987 .59999 L
.65001 .59999 L
.65014 .6 L
.65027 .6 L
.6504 .60001 L
.65054 .60001 L
.65067 .60002 L
.6508 .60002 L
.65094 .60003 L
.65107 .60003 L
.6512 .60004 L
.65133 .60004 L
.65147 .60005 L
.6516 .60005 L
.65173 .60006 L
.65187 .60006 L
.652 .60007 L
.65213 .60007 L
.65226 .60008 L
.6524 .60008 L
.65253 .60009 L
.65266 .60009 L
.6528 .60009 L
.65293 .6001 L
.65306 .6001 L
.65319 .60011 L
.65333 .60011 L
.65346 .60012 L
Mistroke
.65359 .60012 L
.65373 .60013 L
.65386 .60013 L
.65399 .60014 L
.65412 .60014 L
.65426 .60015 L
.65439 .60015 L
.65452 .60015 L
.65466 .60016 L
.65479 .60016 L
.65492 .60017 L
.65505 .60017 L
.65519 .60018 L
.65532 .60018 L
.65545 .60019 L
.65559 .60019 L
.65572 .6002 L
.65585 .6002 L
.65598 .60021 L
.65612 .60021 L
.65625 .60021 L
.65638 .60022 L
.65652 .60022 L
.65665 .60023 L
.65678 .60023 L
.65691 .60024 L
.65705 .60024 L
.65718 .60025 L
.65731 .60025 L
.65745 .60026 L
.65758 .60026 L
.65771 .60026 L
.65784 .60027 L
.65798 .60027 L
.65811 .60028 L
.65824 .60028 L
.65838 .60029 L
.65851 .60029 L
.65864 .6003 L
.65877 .6003 L
.65891 .6003 L
.65904 .60031 L
.65917 .60031 L
.65931 .60032 L
.65944 .60032 L
.65957 .60033 L
.6597 .60033 L
.65984 .60034 L
.65997 .60034 L
.6601 .60034 L
Mistroke
.66024 .60035 L
.66037 .60035 L
.6605 .60036 L
.66063 .60036 L
.66077 .60037 L
.6609 .60037 L
.66103 .60037 L
.66117 .60038 L
.6613 .60038 L
.66143 .60039 L
.66156 .60039 L
.6617 .6004 L
.66183 .6004 L
.66196 .60041 L
.6621 .60041 L
.66223 .60041 L
.66236 .60042 L
.66249 .60042 L
.66263 .60043 L
.66276 .60043 L
.66289 .60044 L
.66303 .60044 L
.66316 .60044 L
.66329 .60045 L
.66342 .60045 L
.66356 .60046 L
.66369 .60046 L
.66382 .60047 L
.66396 .60047 L
.66409 .60047 L
.66422 .60048 L
.66435 .60048 L
.66449 .60049 L
.66462 .60049 L
.66475 .6005 L
.66489 .6005 L
.66502 .6005 L
.66515 .60051 L
.66528 .60051 L
.66542 .60052 L
.66555 .60052 L
.66568 .60053 L
.66582 .60053 L
.66595 .60053 L
.66608 .60054 L
.66621 .60054 L
.66635 .60055 L
.66648 .60055 L
.66661 .60055 L
.66675 .60056 L
Mistroke
.66688 .60056 L
.66701 .60057 L
.66714 .60057 L
.66728 .60058 L
.66741 .60058 L
.66754 .60058 L
.66768 .60059 L
.66781 .60059 L
.66794 .6006 L
.66808 .6006 L
.66821 .6006 L
.66834 .60061 L
.66847 .60061 L
.66861 .60062 L
.66874 .60062 L
.66887 .60063 L
.66901 .60063 L
.66914 .60063 L
.66927 .60064 L
.6694 .60064 L
.66954 .60065 L
.66967 .60065 L
.6698 .60065 L
.66994 .60066 L
.67007 .60066 L
.6702 .60067 L
.67033 .60067 L
.67047 .60067 L
.6706 .60068 L
.67073 .60068 L
.67087 .60069 L
.671 .60069 L
.67113 .60069 L
.67126 .6007 L
.6714 .6007 L
.67153 .60071 L
.67166 .60071 L
.6718 .60071 L
.67193 .60072 L
.67206 .60072 L
.67219 .60073 L
.67233 .60073 L
.67246 .60073 L
.67259 .60074 L
.67273 .60074 L
.67286 .60075 L
.67299 .60075 L
.67312 .60075 L
.67326 .60076 L
.67339 .60076 L
Mistroke
.67352 .60077 L
.67366 .60077 L
.67379 .60077 L
.67392 .60078 L
.67405 .60078 L
.67419 .60079 L
.67432 .60079 L
.67445 .60079 L
.67459 .6008 L
.67472 .6008 L
.67485 .6008 L
.67498 .60081 L
.67512 .60081 L
.67525 .60082 L
.67538 .60082 L
.67552 .60082 L
.67565 .60083 L
.67578 .60083 L
.67591 .60084 L
.67605 .60084 L
.67618 .60084 L
.67631 .60085 L
.67645 .60085 L
.67658 .60085 L
.67671 .60086 L
.67684 .60086 L
.67698 .60087 L
.67711 .60087 L
.67724 .60087 L
.67738 .60088 L
.67751 .60088 L
.67764 .60088 L
.67777 .60089 L
.67791 .60089 L
.67804 .6009 L
.67817 .6009 L
.67831 .6009 L
.67844 .60091 L
.67857 .60091 L
.6787 .60091 L
.67884 .60092 L
.67897 .60092 L
.6791 .60093 L
.67924 .60093 L
.67937 .60093 L
.6795 .60094 L
.67963 .60094 L
.67977 .60094 L
.6799 .60095 L
.68003 .60095 L
Mistroke
.68017 .60095 L
.6803 .60096 L
.68043 .60096 L
.68056 .60097 L
.6807 .60097 L
.68083 .60097 L
.68096 .60098 L
.6811 .60098 L
.68123 .60098 L
.68136 .60099 L
.68149 .60099 L
.68163 .60099 L
.68176 .601 L
.68189 .601 L
.68203 .60101 L
.68216 .60101 L
.68229 .60101 L
.68242 .60102 L
.68256 .60102 L
.68269 .60102 L
.68282 .60103 L
.68296 .60103 L
.68309 .60103 L
.68322 .60104 L
.68335 .60104 L
.68349 .60105 L
.68362 .60105 L
.68375 .60105 L
.68389 .60106 L
.68402 .60106 L
.68415 .60106 L
.68428 .60107 L
.68442 .60107 L
.68455 .60107 L
.68468 .60108 L
.68482 .60108 L
.68495 .60108 L
.68508 .60109 L
.68521 .60109 L
.68535 .60109 L
.68548 .6011 L
.68561 .6011 L
.68575 .60111 L
.68588 .60111 L
.68601 .60111 L
.68614 .60112 L
.68628 .60112 L
.68641 .60112 L
.68654 .60113 L
.68668 .60113 L
Mistroke
.68681 .60113 L
.68694 .60114 L
.68707 .60114 L
.68721 .60114 L
.68734 .60115 L
.68747 .60115 L
.68761 .60115 L
.68774 .60116 L
.68787 .60116 L
.688 .60116 L
.68814 .60117 L
.68827 .60117 L
.6884 .60117 L
.68854 .60118 L
.68867 .60118 L
.6888 .60118 L
.68893 .60119 L
.68907 .60119 L
.6892 .60119 L
.68933 .6012 L
.68947 .6012 L
.6896 .60121 L
.68973 .60121 L
.68987 .60121 L
.69 .60122 L
.69013 .60122 L
.69026 .60122 L
.6904 .60123 L
.69053 .60123 L
.69066 .60123 L
.6908 .60124 L
.69093 .60124 L
.69106 .60124 L
.69119 .60125 L
.69133 .60125 L
.69146 .60125 L
.69159 .60126 L
.69173 .60126 L
.69186 .60126 L
.69199 .60127 L
.69212 .60127 L
.69226 .60127 L
.69239 .60128 L
.69252 .60128 L
.69266 .60128 L
.69279 .60129 L
.69292 .60129 L
.69305 .60129 L
.69319 .6013 L
.69332 .6013 L
Mistroke
.69345 .6013 L
.69359 .60131 L
.69372 .60131 L
.69385 .60131 L
.69398 .60132 L
.69412 .60132 L
.69425 .60132 L
.69438 .60132 L
.69452 .60133 L
.69465 .60133 L
.69478 .60133 L
.69491 .60134 L
.69505 .60134 L
.69518 .60134 L
.69531 .60135 L
.69545 .60135 L
.69558 .60135 L
.69571 .60136 L
.69584 .60136 L
.69598 .60136 L
.69611 .60137 L
.69624 .60137 L
.69638 .60137 L
.69651 .60138 L
.69664 .60138 L
.69677 .60138 L
.69691 .60139 L
.69704 .60139 L
.69717 .60139 L
.69731 .6014 L
.69744 .6014 L
.69757 .6014 L
.6977 .6014 L
.69784 .60141 L
.69797 .60141 L
.6981 .60141 L
.69824 .60142 L
.69837 .60142 L
.6985 .60142 L
.69863 .60143 L
.69877 .60143 L
.6989 .60143 L
.69903 .60144 L
.69917 .60144 L
.6993 .60144 L
.69943 .60145 L
.69956 .60145 L
.6997 .60145 L
.69983 .60145 L
.69996 .60146 L
Mistroke
.7001 .60146 L
.70023 .60146 L
.70036 .60147 L
.70049 .60147 L
.70063 .60147 L
.70076 .60148 L
.70089 .60148 L
.70103 .60148 L
.70116 .60148 L
.70129 .60149 L
.70142 .60149 L
.70156 .60149 L
.70169 .6015 L
.70182 .6015 L
.70196 .6015 L
.70209 .60151 L
.70222 .60151 L
.70235 .60151 L
.70249 .60151 L
.70262 .60152 L
.70275 .60152 L
.70289 .60152 L
.70302 .60153 L
.70315 .60153 L
.70328 .60153 L
.70342 .60154 L
.70355 .60154 L
.70368 .60154 L
.70382 .60154 L
.70395 .60155 L
.70408 .60155 L
.70421 .60155 L
.70435 .60156 L
.70448 .60156 L
.70461 .60156 L
.70475 .60156 L
.70488 .60157 L
.70501 .60157 L
.70514 .60157 L
.70528 .60158 L
.70541 .60158 L
.70554 .60158 L
.70568 .60158 L
.70581 .60159 L
.70594 .60159 L
.70607 .60159 L
.70621 .6016 L
.70634 .6016 L
.70647 .6016 L
.70661 .6016 L
Mistroke
.70674 .60161 L
.70687 .60161 L
.707 .60161 L
.70714 .60162 L
.70727 .60162 L
.7074 .60162 L
.70754 .60162 L
.70767 .60163 L
.7078 .60163 L
.70793 .60163 L
.70807 .60164 L
.7082 .60164 L
.70833 .60164 L
.70847 .60164 L
.7086 .60165 L
.70873 .60165 L
.70886 .60165 L
.709 .60166 L
.70913 .60166 L
.70926 .60166 L
.7094 .60166 L
.70953 .60167 L
.70966 .60167 L
.70979 .60167 L
.70993 .60168 L
.71006 .60168 L
.71019 .60168 L
.71033 .60168 L
.71046 .60169 L
.71059 .60169 L
.71072 .60169 L
.71086 .60169 L
.71099 .6017 L
.71112 .6017 L
.71126 .6017 L
.71139 .60171 L
.71152 .60171 L
.71165 .60171 L
.71179 .60171 L
.71192 .60172 L
.71205 .60172 L
.71219 .60172 L
.71232 .60172 L
.71245 .60173 L
.71259 .60173 L
.71272 .60173 L
.71285 .60174 L
.71298 .60174 L
.71312 .60174 L
.71325 .60174 L
Mistroke
.71338 .60175 L
.71352 .60175 L
.71365 .60175 L
.71378 .60175 L
.71391 .60176 L
.71405 .60176 L
.71418 .60176 L
.71431 .60177 L
.71445 .60177 L
.71458 .60177 L
.71471 .60177 L
.71484 .60178 L
.71498 .60178 L
.71511 .60178 L
.71524 .60178 L
.71538 .60179 L
.71551 .60179 L
.71564 .60179 L
.71577 .60179 L
.71591 .6018 L
.71604 .6018 L
.71617 .6018 L
.71631 .6018 L
.71644 .60181 L
.71657 .60181 L
.7167 .60181 L
.71684 .60181 L
.71697 .60182 L
.7171 .60182 L
.71724 .60182 L
.71737 .60183 L
.7175 .60183 L
.71763 .60183 L
.71777 .60183 L
.7179 .60184 L
.71803 .60184 L
.71817 .60184 L
.7183 .60184 L
.71843 .60185 L
.71856 .60185 L
.7187 .60185 L
.71883 .60185 L
.71896 .60186 L
.7191 .60186 L
.71923 .60186 L
.71936 .60186 L
.71949 .60187 L
.71963 .60187 L
.71976 .60187 L
.71989 .60187 L
Mistroke
.72003 .60188 L
.72016 .60188 L
.72029 .60188 L
.72042 .60188 L
.72056 .60189 L
.72069 .60189 L
.72082 .60189 L
.72096 .60189 L
.72109 .6019 L
.72122 .6019 L
.72135 .6019 L
.72149 .6019 L
.72162 .60191 L
.72175 .60191 L
.72189 .60191 L
.72202 .60191 L
.72215 .60192 L
.72228 .60192 L
.72242 .60192 L
.72255 .60192 L
.72268 .60193 L
.72282 .60193 L
.72295 .60193 L
.72308 .60193 L
.72321 .60193 L
.72335 .60194 L
.72348 .60194 L
.72361 .60194 L
.72375 .60194 L
.72388 .60195 L
.72401 .60195 L
.72414 .60195 L
.72428 .60195 L
.72441 .60196 L
.72454 .60196 L
.72468 .60196 L
.72481 .60196 L
.72494 .60197 L
.72507 .60197 L
.72521 .60197 L
.72534 .60197 L
.72547 .60198 L
.72561 .60198 L
.72574 .60198 L
.72587 .60198 L
.726 .60199 L
.72614 .60199 L
.72627 .60199 L
.7264 .60199 L
.72654 .60199 L
Mistroke
.72667 .602 L
.7268 .602 L
.72693 .602 L
.72707 .602 L
.7272 .60201 L
.72733 .60201 L
.72747 .60201 L
.7276 .60201 L
.72773 .60202 L
.72786 .60202 L
.728 .60202 L
.72813 .60202 L
.72826 .60202 L
.7284 .60203 L
.72853 .60203 L
.72866 .60203 L
.72879 .60203 L
.72893 .60204 L
.72906 .60204 L
.72919 .60204 L
.72933 .60204 L
.72946 .60205 L
.72959 .60205 L
.72972 .60205 L
.72986 .60205 L
.72999 .60205 L
.73012 .60206 L
.73026 .60206 L
.73039 .60206 L
.73052 .60206 L
.73065 .60207 L
.73079 .60207 L
.73092 .60207 L
.73105 .60207 L
.73119 .60208 L
.73132 .60208 L
.73145 .60208 L
.73158 .60208 L
.73172 .60208 L
.73185 .60209 L
.73198 .60209 L
.73212 .60209 L
.73225 .60209 L
.73238 .6021 L
.73251 .6021 L
.73265 .6021 L
.73278 .6021 L
.73291 .6021 L
.73305 .60211 L
.73318 .60211 L
Mistroke
.73331 .60211 L
.73344 .60211 L
.73358 .60212 L
.73371 .60212 L
.73384 .60212 L
.73398 .60212 L
.73411 .60212 L
.73424 .60213 L
.73438 .60213 L
.73451 .60213 L
.73464 .60213 L
.73477 .60214 L
.73491 .60214 L
.73504 .60214 L
.73517 .60214 L
.73531 .60214 L
.73544 .60215 L
.73557 .60215 L
.7357 .60215 L
.73584 .60215 L
.73597 .60216 L
.7361 .60216 L
.73624 .60216 L
.73637 .60216 L
.7365 .60216 L
.73663 .60217 L
.73677 .60217 L
.7369 .60217 L
.73703 .60217 L
.73717 .60217 L
.7373 .60218 L
.73743 .60218 L
.73756 .60218 L
.7377 .60218 L
.73783 .60218 L
.73796 .60219 L
.7381 .60219 L
.73823 .60219 L
.73836 .60219 L
.73849 .6022 L
.73863 .6022 L
.73876 .6022 L
.73889 .6022 L
.73903 .6022 L
.73916 .60221 L
.73929 .60221 L
.73942 .60221 L
.73956 .60221 L
.73969 .60221 L
.73982 .60222 L
Mistroke
.73996 .60222 L
.74009 .60222 L
.74022 .60222 L
.74035 .60222 L
.74049 .60223 L
.74062 .60223 L
.74075 .60223 L
.74089 .60223 L
.74102 .60223 L
.74115 .60224 L
.74128 .60224 L
.74142 .60224 L
.74155 .60224 L
.74168 .60224 L
.74182 .60225 L
.74195 .60225 L
.74208 .60225 L
.74221 .60225 L
.74235 .60225 L
.74248 .60226 L
.74261 .60226 L
.74275 .60226 L
.74288 .60226 L
.74301 .60226 L
.74314 .60227 L
.74328 .60227 L
.74341 .60227 L
.74354 .60227 L
.74368 .60227 L
.74381 .60228 L
.74394 .60228 L
.74407 .60228 L
.74421 .60228 L
.74434 .60228 L
.74447 .60229 L
.74461 .60229 L
.74474 .60229 L
.74487 .60229 L
.745 .60229 L
.74514 .6023 L
.74527 .6023 L
.7454 .6023 L
.74554 .6023 L
.74567 .6023 L
.7458 .60231 L
.74593 .60231 L
.74607 .60231 L
.7462 .60231 L
.74633 .60231 L
.74647 .60231 L
Mistroke
.7466 .60232 L
.74673 .60232 L
.74686 .60232 L
.747 .60232 L
.74713 .60232 L
.74726 .60233 L
.7474 .60233 L
.74753 .60233 L
.74766 .60233 L
.74779 .60233 L
.74793 .60234 L
.74806 .60234 L
.74819 .60234 L
.74833 .60234 L
.74846 .60234 L
.74859 .60234 L
.74872 .60235 L
.74886 .60235 L
.74899 .60235 L
.74912 .60235 L
.74926 .60235 L
.74939 .60236 L
.74952 .60236 L
.74965 .60236 L
.74979 .60236 L
.74992 .60236 L
.75005 .60237 L
.75019 .60237 L
.75032 .60237 L
.75045 .60237 L
.75058 .60237 L
.75072 .60237 L
.75085 .60238 L
.75098 .60238 L
.75112 .60238 L
.75125 .60238 L
.75138 .60238 L
.75151 .60239 L
.75165 .60239 L
.75178 .60239 L
.75191 .60239 L
.75205 .60239 L
.75218 .60239 L
.75231 .6024 L
.75244 .6024 L
.75258 .6024 L
.75271 .6024 L
.75284 .6024 L
.75298 .60241 L
.75311 .60241 L
Mistroke
.75324 .60241 L
.75337 .60241 L
.75351 .60241 L
.75364 .60241 L
.75377 .60242 L
.75391 .60242 L
.75404 .60242 L
.75417 .60242 L
.7543 .60242 L
.75444 .60242 L
.75457 .60243 L
.7547 .60243 L
.75484 .60243 L
.75497 .60243 L
.7551 .60243 L
.75523 .60244 L
.75537 .60244 L
.7555 .60244 L
.75563 .60244 L
.75577 .60244 L
.7559 .60244 L
.75603 .60245 L
.75616 .60245 L
.7563 .60245 L
.75643 .60245 L
.75656 .60245 L
.7567 .60245 L
.75683 .60246 L
.75696 .60246 L
.7571 .60246 L
.75723 .60246 L
.75736 .60246 L
.75749 .60246 L
.75763 .60247 L
.75776 .60247 L
.75789 .60247 L
.75803 .60247 L
.75816 .60247 L
.75829 .60247 L
.75842 .60248 L
.75856 .60248 L
.75869 .60248 L
.75882 .60248 L
.75896 .60248 L
.75909 .60248 L
.75922 .60249 L
.75935 .60249 L
.75949 .60249 L
.75962 .60249 L
.75975 .60249 L
Mistroke
.75989 .60249 L
.76002 .6025 L
.76015 .6025 L
.76028 .6025 L
.76042 .6025 L
.76055 .6025 L
.76068 .6025 L
.76082 .6025 L
.76095 .60251 L
.76108 .60251 L
.76121 .60251 L
.76135 .60251 L
.76148 .60251 L
.76161 .60251 L
.76175 .60252 L
.76188 .60252 L
.76201 .60252 L
.76214 .60252 L
.76228 .60252 L
.76241 .60252 L
.76254 .60253 L
.76268 .60253 L
.76281 .60253 L
.76294 .60253 L
.76307 .60253 L
.76321 .60253 L
.76334 .60254 L
.76347 .60254 L
.76361 .60254 L
.76374 .60254 L
.76387 .60254 L
.764 .60254 L
.76414 .60254 L
.76427 .60255 L
.7644 .60255 L
.76454 .60255 L
.76467 .60255 L
.7648 .60255 L
.76493 .60255 L
.76507 .60256 L
.7652 .60256 L
.76533 .60256 L
.76547 .60256 L
.7656 .60256 L
.76573 .60256 L
.76586 .60256 L
.766 .60257 L
.76613 .60257 L
.76626 .60257 L
.7664 .60257 L
Mistroke
.76653 .60257 L
.76666 .60257 L
.76679 .60258 L
.76693 .60258 L
.76706 .60258 L
.76719 .60258 L
.76733 .60258 L
.76746 .60258 L
.76759 .60258 L
.76772 .60259 L
.76786 .60259 L
.76799 .60259 L
.76812 .60259 L
.76826 .60259 L
.76839 .60259 L
.76852 .60259 L
.76865 .6026 L
.76879 .6026 L
.76892 .6026 L
.76905 .6026 L
.76919 .6026 L
.76932 .6026 L
.76945 .60261 L
.76958 .60261 L
.76972 .60261 L
.76985 .60261 L
.76998 .60261 L
.77012 .60261 L
.77025 .60261 L
.77038 .60262 L
.77051 .60262 L
.77065 .60262 L
.77078 .60262 L
.77091 .60262 L
.77105 .60262 L
.77118 .60262 L
.77131 .60263 L
.77144 .60263 L
.77158 .60263 L
.77171 .60263 L
.77184 .60263 L
.77198 .60263 L
.77211 .60263 L
.77224 .60264 L
.77237 .60264 L
.77251 .60264 L
.77264 .60264 L
.77277 .60264 L
.77291 .60264 L
.77304 .60264 L
Mistroke
.77317 .60265 L
.7733 .60265 L
.77344 .60265 L
.77357 .60265 L
.7737 .60265 L
.77384 .60265 L
.77397 .60265 L
.7741 .60266 L
.77423 .60266 L
.77437 .60266 L
.7745 .60266 L
.77463 .60266 L
.77477 .60266 L
.7749 .60266 L
.77503 .60266 L
.77516 .60267 L
.7753 .60267 L
.77543 .60267 L
.77556 .60267 L
.7757 .60267 L
.77583 .60267 L
.77596 .60267 L
.77609 .60268 L
.77623 .60268 L
.77636 .60268 L
.77649 .60268 L
.77663 .60268 L
.77676 .60268 L
.77689 .60268 L
.77702 .60269 L
.77716 .60269 L
.77729 .60269 L
.77742 .60269 L
.77756 .60269 L
.77769 .60269 L
.77782 .60269 L
.77795 .60269 L
.77809 .6027 L
.77822 .6027 L
.77835 .6027 L
.77849 .6027 L
.77862 .6027 L
.77875 .6027 L
.77888 .6027 L
.77902 .60271 L
.77915 .60271 L
.77928 .60271 L
.77942 .60271 L
.77955 .60271 L
.77968 .60271 L
Mistroke
.77982 .60271 L
.77995 .60271 L
.78008 .60272 L
.78021 .60272 L
.78035 .60272 L
.78048 .60272 L
.78061 .60272 L
.78075 .60272 L
.78088 .60272 L
.78101 .60272 L
.78114 .60273 L
.78128 .60273 L
.78141 .60273 L
.78154 .60273 L
.78168 .60273 L
.78181 .60273 L
.78194 .60273 L
.78207 .60273 L
.78221 .60274 L
.78234 .60274 L
.78247 .60274 L
.78261 .60274 L
.78274 .60274 L
.78287 .60274 L
.783 .60274 L
.78314 .60274 L
.78327 .60275 L
.7834 .60275 L
.78354 .60275 L
.78367 .60275 L
.7838 .60275 L
.78393 .60275 L
.78407 .60275 L
.7842 .60275 L
.78433 .60276 L
.78447 .60276 L
.7846 .60276 L
.78473 .60276 L
.78486 .60276 L
.785 .60276 L
.78513 .60276 L
.78526 .60276 L
.7854 .60277 L
.78553 .60277 L
.78566 .60277 L
.78579 .60277 L
.78593 .60277 L
.78606 .60277 L
.78619 .60277 L
.78633 .60277 L
Mistroke
.78646 .60278 L
.78659 .60278 L
.78672 .60278 L
.78686 .60278 L
.78699 .60278 L
.78712 .60278 L
.78726 .60278 L
.78739 .60278 L
.78752 .60279 L
.78765 .60279 L
.78779 .60279 L
.78792 .60279 L
.78805 .60279 L
.78819 .60279 L
.78832 .60279 L
.78845 .60279 L
.78858 .60279 L
.78872 .6028 L
.78885 .6028 L
.78898 .6028 L
.78912 .6028 L
.78925 .6028 L
.78938 .6028 L
.78951 .6028 L
.78965 .6028 L
.78978 .6028 L
.78991 .60281 L
.79005 .60281 L
.79018 .60281 L
.79031 .60281 L
.79044 .60281 L
.79058 .60281 L
.79071 .60281 L
.79084 .60281 L
.79098 .60282 L
.79111 .60282 L
.79124 .60282 L
.79137 .60282 L
.79151 .60282 L
.79164 .60282 L
.79177 .60282 L
.79191 .60282 L
.79204 .60282 L
.79217 .60283 L
.7923 .60283 L
.79244 .60283 L
.79257 .60283 L
.7927 .60283 L
.79284 .60283 L
.79297 .60283 L
Mistroke
.7931 .60283 L
.79323 .60283 L
.79337 .60284 L
.7935 .60284 L
.79363 .60284 L
.79377 .60284 L
.7939 .60284 L
.79403 .60284 L
.79416 .60284 L
.7943 .60284 L
.79443 .60284 L
.79456 .60285 L
.7947 .60285 L
.79483 .60285 L
.79496 .60285 L
.79509 .60285 L
.79523 .60285 L
.79536 .60285 L
.79549 .60285 L
.79563 .60285 L
.79576 .60286 L
.79589 .60286 L
.79602 .60286 L
.79616 .60286 L
.79629 .60286 L
.79642 .60286 L
.79656 .60286 L
.79669 .60286 L
.79682 .60286 L
.79695 .60287 L
.79709 .60287 L
.79722 .60287 L
.79735 .60287 L
.79749 .60287 L
.79762 .60287 L
.79775 .60287 L
.79788 .60287 L
.79802 .60287 L
.79815 .60287 L
.79828 .60288 L
.79842 .60288 L
.79855 .60288 L
.79868 .60288 L
.79881 .60288 L
.79895 .60288 L
.79908 .60288 L
.79921 .60288 L
.79935 .60288 L
.79948 .60288 L
.79961 .60289 L
Mistroke
.79974 .60289 L
.79988 .60289 L
.80001 .60289 L
.80014 .60289 L
.80028 .60289 L
.80041 .60289 L
.80054 .60289 L
.80067 .60289 L
.80081 .6029 L
.80094 .6029 L
.80107 .6029 L
.80121 .6029 L
.80134 .6029 L
.80147 .6029 L
.80161 .6029 L
.80174 .6029 L
.80187 .6029 L
.802 .6029 L
.80214 .60291 L
.80227 .60291 L
.8024 .60291 L
.80254 .60291 L
.80267 .60291 L
.8028 .60291 L
.80293 .60291 L
.80307 .60291 L
.8032 .60291 L
.80333 .60291 L
.80347 .60292 L
.8036 .60292 L
.80373 .60292 L
.80386 .60292 L
.804 .60292 L
.80413 .60292 L
.80426 .60292 L
.8044 .60292 L
.80453 .60292 L
.80466 .60292 L
.80479 .60292 L
.80493 .60293 L
.80506 .60293 L
.80519 .60293 L
.80533 .60293 L
.80546 .60293 L
.80559 .60293 L
.80572 .60293 L
.80586 .60293 L
.80599 .60293 L
.80612 .60293 L
.80626 .60294 L
Mistroke
.80639 .60294 L
.80652 .60294 L
.80665 .60294 L
.80679 .60294 L
.80692 .60294 L
.80705 .60294 L
.80719 .60294 L
.80732 .60294 L
.80745 .60294 L
.80758 .60294 L
.80772 .60295 L
.80785 .60295 L
.80798 .60295 L
.80812 .60295 L
.80825 .60295 L
.80838 .60295 L
.80851 .60295 L
.80865 .60295 L
.80878 .60295 L
.80891 .60295 L
.80905 .60295 L
.80918 .60296 L
.80931 .60296 L
.80944 .60296 L
.80958 .60296 L
.80971 .60296 L
.80984 .60296 L
.80998 .60296 L
.81011 .60296 L
.81024 .60296 L
.81037 .60296 L
.81051 .60296 L
.81064 .60297 L
.81077 .60297 L
.81091 .60297 L
.81104 .60297 L
.81117 .60297 L
.8113 .60297 L
.81144 .60297 L
.81157 .60297 L
.8117 .60297 L
.81184 .60297 L
.81197 .60297 L
.8121 .60298 L
.81223 .60298 L
.81237 .60298 L
.8125 .60298 L
.81263 .60298 L
.81277 .60298 L
.8129 .60298 L
Mistroke
.81303 .60298 L
.81316 .60298 L
.8133 .60298 L
.81343 .60298 L
.81356 .60298 L
.8137 .60299 L
.81383 .60299 L
.81396 .60299 L
.81409 .60299 L
.81423 .60299 L
.81436 .60299 L
.81449 .60299 L
.81463 .60299 L
.81476 .60299 L
.81489 .60299 L
.81502 .60299 L
.81516 .60299 L
.81529 .603 L
.81542 .603 L
.81556 .603 L
.81569 .603 L
.81582 .603 L
.81595 .603 L
.81609 .603 L
.81622 .603 L
.81635 .603 L
.81649 .603 L
.81662 .603 L
.81675 .603 L
.81688 .60301 L
.81702 .60301 L
.81715 .60301 L
.81728 .60301 L
.81742 .60301 L
.81755 .60301 L
.81768 .60301 L
.81781 .60301 L
.81795 .60301 L
.81808 .60301 L
.81821 .60301 L
.81835 .60301 L
.81848 .60302 L
.81861 .60302 L
.81874 .60302 L
.81888 .60302 L
.81901 .60302 L
.81914 .60302 L
.81928 .60302 L
.81941 .60302 L
.81954 .60302 L
Mistroke
.81967 .60302 L
.81981 .60302 L
.81994 .60302 L
.82007 .60302 L
.82021 .60303 L
.82034 .60303 L
.82047 .60303 L
.8206 .60303 L
.82074 .60303 L
.82087 .60303 L
.821 .60303 L
.82114 .60303 L
.82127 .60303 L
.8214 .60303 L
.82153 .60303 L
.82167 .60303 L
.8218 .60303 L
.82193 .60304 L
.82207 .60304 L
.8222 .60304 L
.82233 .60304 L
.82246 .60304 L
.8226 .60304 L
.82273 .60304 L
.82286 .60304 L
.823 .60304 L
.82313 .60304 L
.82326 .60304 L
.82339 .60304 L
.82353 .60304 L
.82366 .60305 L
.82379 .60305 L
.82393 .60305 L
.82406 .60305 L
.82419 .60305 L
.82433 .60305 L
.82446 .60305 L
.82459 .60305 L
.82472 .60305 L
.82486 .60305 L
.82499 .60305 L
.82512 .60305 L
.82526 .60305 L
.82539 .60305 L
.82552 .60306 L
.82565 .60306 L
.82579 .60306 L
.82592 .60306 L
.82605 .60306 L
.82619 .60306 L
Mistroke
.82632 .60306 L
.82645 .60306 L
.82658 .60306 L
.82672 .60306 L
.82685 .60306 L
.82698 .60306 L
.82712 .60306 L
.82725 .60306 L
.82738 .60307 L
.82751 .60307 L
.82765 .60307 L
.82778 .60307 L
.82791 .60307 L
.82805 .60307 L
.82818 .60307 L
.82831 .60307 L
.82844 .60307 L
.82858 .60307 L
.82871 .60307 L
.82884 .60307 L
.82898 .60307 L
.82911 .60307 L
.82924 .60307 L
.82937 .60308 L
.82951 .60308 L
.82964 .60308 L
.82977 .60308 L
.82991 .60308 L
.83004 .60308 L
.83017 .60308 L
.8303 .60308 L
.83044 .60308 L
.83057 .60308 L
.8307 .60308 L
.83084 .60308 L
.83097 .60308 L
.8311 .60308 L
.83123 .60309 L
.83137 .60309 L
.8315 .60309 L
.83163 .60309 L
.83177 .60309 L
.8319 .60309 L
.83203 .60309 L
.83216 .60309 L
.8323 .60309 L
.83243 .60309 L
.83256 .60309 L
.8327 .60309 L
.83283 .60309 L
Mistroke
.83296 .60309 L
.83309 .60309 L
.83323 .6031 L
.83336 .6031 L
.83349 .6031 L
.83363 .6031 L
.83376 .6031 L
.83389 .6031 L
.83402 .6031 L
.83416 .6031 L
.83429 .6031 L
.83442 .6031 L
.83456 .6031 L
.83469 .6031 L
.83482 .6031 L
.83495 .6031 L
.83509 .6031 L
.83522 .6031 L
.83535 .60311 L
.83549 .60311 L
.83562 .60311 L
.83575 .60311 L
.83588 .60311 L
.83602 .60311 L
.83615 .60311 L
.83628 .60311 L
.83642 .60311 L
.83655 .60311 L
.83668 .60311 L
.83681 .60311 L
.83695 .60311 L
.83708 .60311 L
.83721 .60311 L
.83735 .60311 L
.83748 .60312 L
.83761 .60312 L
.83774 .60312 L
.83788 .60312 L
.83801 .60312 L
.83814 .60312 L
.83828 .60312 L
.83841 .60312 L
.83854 .60312 L
.83867 .60312 L
.83881 .60312 L
.83894 .60312 L
.83907 .60312 L
.83921 .60312 L
.83934 .60312 L
.83947 .60312 L
Mistroke
.8396 .60312 L
.83974 .60313 L
.83987 .60313 L
.84 .60313 L
.84014 .60313 L
.84027 .60313 L
.8404 .60313 L
.84053 .60313 L
.84067 .60313 L
.8408 .60313 L
.84093 .60313 L
.84107 .60313 L
.8412 .60313 L
.84133 .60313 L
.84146 .60313 L
.8416 .60313 L
.84173 .60313 L
.84186 .60313 L
.842 .60314 L
.84213 .60314 L
.84226 .60314 L
.84239 .60314 L
.84253 .60314 L
.84266 .60314 L
.84279 .60314 L
.84293 .60314 L
.84306 .60314 L
.84319 .60314 L
.84332 .60314 L
.84346 .60314 L
.84359 .60314 L
.84372 .60314 L
.84386 .60314 L
.84399 .60314 L
.84412 .60314 L
.84425 .60314 L
.84439 .60315 L
.84452 .60315 L
.84465 .60315 L
.84479 .60315 L
.84492 .60315 L
.84505 .60315 L
.84518 .60315 L
.84532 .60315 L
.84545 .60315 L
.84558 .60315 L
.84572 .60315 L
.84585 .60315 L
.84598 .60315 L
.84612 .60315 L
Mistroke
.84625 .60315 L
.84638 .60315 L
.84651 .60315 L
.84665 .60315 L
.84678 .60315 L
.84691 .60316 L
.84705 .60316 L
.84718 .60316 L
.84731 .60316 L
.84744 .60316 L
.84758 .60316 L
.84771 .60316 L
.84784 .60316 L
.84798 .60316 L
.84811 .60316 L
.84824 .60316 L
.84837 .60316 L
.84851 .60316 L
.84864 .60316 L
.84877 .60316 L
.84891 .60316 L
.84904 .60316 L
.84917 .60316 L
.8493 .60316 L
.84944 .60317 L
.84957 .60317 L
.8497 .60317 L
.84984 .60317 L
.84997 .60317 L
.8501 .60317 L
.85023 .60317 L
.85037 .60317 L
.8505 .60317 L
.85063 .60317 L
.85077 .60317 L
.8509 .60317 L
.85103 .60317 L
.85116 .60317 L
.8513 .60317 L
.85143 .60317 L
.85156 .60317 L
.8517 .60317 L
.85183 .60317 L
.85196 .60317 L
.85209 .60318 L
.85223 .60318 L
.85236 .60318 L
.85249 .60318 L
.85263 .60318 L
.85276 .60318 L
Mistroke
.85289 .60318 L
.85302 .60318 L
.85316 .60318 L
.85329 .60318 L
.85342 .60318 L
.85356 .60318 L
.85369 .60318 L
.85382 .60318 L
.85395 .60318 L
.85409 .60318 L
.85422 .60318 L
.85435 .60318 L
.85449 .60318 L
.85462 .60318 L
.85475 .60318 L
.85488 .60319 L
.85502 .60319 L
.85515 .60319 L
.85528 .60319 L
.85542 .60319 L
.85555 .60319 L
.85568 .60319 L
.85581 .60319 L
.85595 .60319 L
.85608 .60319 L
.85621 .60319 L
.85635 .60319 L
.85648 .60319 L
.85661 .60319 L
.85674 .60319 L
.85688 .60319 L
.85701 .60319 L
.85714 .60319 L
.85728 .60319 L
.85741 .60319 L
.85754 .60319 L
.85767 .60319 L
.85781 .6032 L
.85794 .6032 L
.85807 .6032 L
.85821 .6032 L
.85834 .6032 L
.85847 .6032 L
.8586 .6032 L
.85874 .6032 L
.85887 .6032 L
.859 .6032 L
.85914 .6032 L
.85927 .6032 L
.8594 .6032 L
Mistroke
.85953 .6032 L
.85967 .6032 L
.8598 .6032 L
.85993 .6032 L
.86007 .6032 L
.8602 .6032 L
.86033 .6032 L
.86046 .6032 L
.8606 .6032 L
.86073 .6032 L
.86086 .6032 L
.861 .60321 L
.86113 .60321 L
.86126 .60321 L
.86139 .60321 L
.86153 .60321 L
.86166 .60321 L
.86179 .60321 L
.86193 .60321 L
.86206 .60321 L
.86219 .60321 L
.86232 .60321 L
.86246 .60321 L
.86259 .60321 L
.86272 .60321 L
.86286 .60321 L
.86299 .60321 L
.86312 .60321 L
.86325 .60321 L
.86339 .60321 L
.86352 .60321 L
.86365 .60321 L
.86379 .60321 L
.86392 .60321 L
.86405 .60321 L
.86418 .60321 L
.86432 .60322 L
.86445 .60322 L
.86458 .60322 L
.86472 .60322 L
.86485 .60322 L
.86498 .60322 L
.86511 .60322 L
.86525 .60322 L
.86538 .60322 L
.86551 .60322 L
.86565 .60322 L
.86578 .60322 L
.86591 .60322 L
.86604 .60322 L
Mistroke
.86618 .60322 L
.86631 .60322 L
.86644 .60322 L
.86658 .60322 L
.86671 .60322 L
.86684 .60322 L
.86697 .60322 L
.86711 .60322 L
.86724 .60322 L
.86737 .60322 L
.86751 .60322 L
.86764 .60322 L
.86777 .60322 L
.8679 .60323 L
.86804 .60323 L
.86817 .60323 L
.8683 .60323 L
.86844 .60323 L
.86857 .60323 L
.8687 .60323 L
.86884 .60323 L
.86897 .60323 L
.8691 .60323 L
.86923 .60323 L
.86937 .60323 L
.8695 .60323 L
.86963 .60323 L
.86977 .60323 L
.8699 .60323 L
.87003 .60323 L
.87016 .60323 L
.8703 .60323 L
.87043 .60323 L
.87056 .60323 L
.8707 .60323 L
.87083 .60323 L
.87096 .60323 L
.87109 .60323 L
.87123 .60323 L
.87136 .60323 L
.87149 .60323 L
.87163 .60323 L
.87176 .60323 L
.87189 .60324 L
.87202 .60324 L
.87216 .60324 L
.87229 .60324 L
.87242 .60324 L
.87256 .60324 L
.87269 .60324 L
Mistroke
.87282 .60324 L
.87295 .60324 L
.87309 .60324 L
.87322 .60324 L
.87335 .60324 L
.87349 .60324 L
.87362 .60324 L
.87375 .60324 L
.87388 .60324 L
.87402 .60324 L
.87415 .60324 L
.87428 .60324 L
.87442 .60324 L
.87455 .60324 L
.87468 .60324 L
.87481 .60324 L
.87495 .60324 L
.87508 .60324 L
.87521 .60324 L
.87535 .60324 L
.87548 .60324 L
.87561 .60324 L
.87574 .60324 L
.87588 .60324 L
.87601 .60324 L
.87614 .60325 L
.87628 .60325 L
.87641 .60325 L
.87654 .60325 L
.87667 .60325 L
.87681 .60325 L
.87694 .60325 L
.87707 .60325 L
.87721 .60325 L
.87734 .60325 L
.87747 .60325 L
.8776 .60325 L
.87774 .60325 L
.87787 .60325 L
.878 .60325 L
.87814 .60325 L
.87827 .60325 L
.8784 .60325 L
.87853 .60325 L
.87867 .60325 L
.8788 .60325 L
.87893 .60325 L
.87907 .60325 L
.8792 .60325 L
.87933 .60325 L
Mistroke
.87946 .60325 L
.8796 .60325 L
.87973 .60325 L
.87986 .60325 L
.88 .60325 L
.88013 .60325 L
.88026 .60325 L
.88039 .60325 L
.88053 .60325 L
.88066 .60326 L
.88079 .60326 L
.88093 .60326 L
.88106 .60326 L
.88119 .60326 L
.88132 .60326 L
.88146 .60326 L
.88159 .60326 L
.88172 .60326 L
.88186 .60326 L
.88199 .60326 L
.88212 .60326 L
.88225 .60326 L
.88239 .60326 L
.88252 .60326 L
.88265 .60326 L
.88279 .60326 L
.88292 .60326 L
.88305 .60326 L
.88318 .60326 L
.88332 .60326 L
.88345 .60326 L
.88358 .60326 L
.88372 .60326 L
.88385 .60326 L
.88398 .60326 L
.88411 .60326 L
.88425 .60326 L
.88438 .60326 L
.88451 .60326 L
.88465 .60326 L
.88478 .60326 L
.88491 .60326 L
.88504 .60326 L
.88518 .60326 L
.88531 .60326 L
.88544 .60326 L
.88558 .60326 L
.88571 .60326 L
.88584 .60327 L
.88597 .60327 L
Mistroke
.88611 .60327 L
.88624 .60327 L
.88637 .60327 L
.88651 .60327 L
.88664 .60327 L
.88677 .60327 L
.8869 .60327 L
.88704 .60327 L
.88717 .60327 L
.8873 .60327 L
.88744 .60327 L
.88757 .60327 L
.8877 .60327 L
.88783 .60327 L
.88797 .60327 L
.8881 .60327 L
.88823 .60327 L
.88837 .60327 L
.8885 .60327 L
.88863 .60327 L
.88876 .60327 L
.8889 .60327 L
.88903 .60327 L
.88916 .60327 L
.8893 .60327 L
.88943 .60327 L
.88956 .60327 L
.88969 .60327 L
.88983 .60327 L
.88996 .60327 L
.89009 .60327 L
.89023 .60327 L
.89036 .60327 L
.89049 .60327 L
.89063 .60327 L
.89076 .60327 L
.89089 .60327 L
.89102 .60327 L
.89116 .60327 L
.89129 .60327 L
.89142 .60327 L
.89156 .60328 L
.89169 .60328 L
.89182 .60328 L
.89195 .60328 L
.89209 .60328 L
.89222 .60328 L
.89235 .60328 L
.89249 .60328 L
.89262 .60328 L
Mistroke
.89275 .60328 L
.89288 .60328 L
.89302 .60328 L
.89315 .60328 L
.89328 .60328 L
.89342 .60328 L
.89355 .60328 L
.89368 .60328 L
.89381 .60328 L
.89395 .60328 L
.89408 .60328 L
.89421 .60328 L
.89435 .60328 L
.89448 .60328 L
.89461 .60328 L
.89474 .60328 L
.89488 .60328 L
.89501 .60328 L
.89514 .60328 L
.89528 .60328 L
.89541 .60328 L
.89554 .60328 L
.89567 .60328 L
.89581 .60328 L
.89594 .60328 L
.89607 .60328 L
.89621 .60328 L
.89634 .60328 L
.89647 .60328 L
.8966 .60328 L
.89674 .60328 L
.89687 .60328 L
.897 .60328 L
.89714 .60328 L
.89727 .60328 L
.8974 .60328 L
.89753 .60328 L
.89767 .60328 L
.8978 .60328 L
.89793 .60328 L
.89807 .60328 L
.8982 .60329 L
.89833 .60329 L
.89846 .60329 L
.8986 .60329 L
.89873 .60329 L
.89886 .60329 L
.899 .60329 L
.89913 .60329 L
.89926 .60329 L
Mistroke
.89939 .60329 L
.89953 .60329 L
.89966 .60329 L
.89979 .60329 L
.89993 .60329 L
.90006 .60329 L
.90019 .60329 L
.90032 .60329 L
.90046 .60329 L
.90059 .60329 L
.90072 .60329 L
.90086 .60329 L
.90099 .60329 L
.90112 .60329 L
.90125 .60329 L
.90139 .60329 L
.90152 .60329 L
.90165 .60329 L
.90179 .60329 L
.90192 .60329 L
.90205 .60329 L
.90218 .60329 L
.90232 .60329 L
.90245 .60329 L
.90258 .60329 L
.90272 .60329 L
.90285 .60329 L
.90298 .60329 L
.90311 .60329 L
.90325 .60329 L
.90338 .60329 L
.90351 .60329 L
.90365 .60329 L
.90378 .60329 L
.90391 .60329 L
.90404 .60329 L
.90418 .60329 L
.90431 .60329 L
.90444 .60329 L
.90458 .60329 L
.90471 .60329 L
.90484 .60329 L
.90497 .60329 L
.90511 .60329 L
.90524 .60329 L
.90537 .60329 L
.90551 .60329 L
.90564 .60329 L
.90577 .60329 L
.9059 .60329 L
Mistroke
.90604 .60329 L
.90617 .60329 L
.9063 .6033 L
.90644 .6033 L
.90657 .6033 L
.9067 .6033 L
.90683 .6033 L
.90697 .6033 L
.9071 .6033 L
.90723 .6033 L
.90737 .6033 L
.9075 .6033 L
.90763 .6033 L
.90776 .6033 L
.9079 .6033 L
.90803 .6033 L
.90816 .6033 L
.9083 .6033 L
.90843 .6033 L
.90856 .6033 L
.90869 .6033 L
.90883 .6033 L
.90896 .6033 L
.90909 .6033 L
.90923 .6033 L
.90936 .6033 L
.90949 .6033 L
.90962 .6033 L
.90976 .6033 L
.90989 .6033 L
.91002 .6033 L
.91016 .6033 L
.91029 .6033 L
.91042 .6033 L
.91055 .6033 L
.91069 .6033 L
.91082 .6033 L
.91095 .6033 L
.91109 .6033 L
.91122 .6033 L
.91135 .6033 L
.91148 .6033 L
.91162 .6033 L
.91175 .6033 L
.91188 .6033 L
.91202 .6033 L
.91215 .6033 L
.91228 .6033 L
.91241 .6033 L
.91255 .6033 L
Mistroke
.91268 .6033 L
.91281 .6033 L
.91295 .6033 L
.91308 .6033 L
.91321 .6033 L
.91335 .6033 L
.91348 .6033 L
.91361 .6033 L
.91374 .6033 L
.91388 .6033 L
.91401 .6033 L
.91414 .6033 L
.91428 .6033 L
.91441 .6033 L
.91454 .6033 L
.91467 .6033 L
.91481 .6033 L
.91494 .6033 L
.91507 .6033 L
.91521 .6033 L
.91534 .6033 L
.91547 .6033 L
.9156 .6033 L
.91574 .6033 L
.91587 .6033 L
.916 .6033 L
.91614 .6033 L
.91627 .6033 L
.9164 .6033 L
.91653 .6033 L
.91667 .6033 L
.9168 .6033 L
.91693 .6033 L
.91707 .60331 L
.9172 .60331 L
.91733 .60331 L
.91746 .60331 L
.9176 .60331 L
.91773 .60331 L
.91786 .60331 L
.918 .60331 L
.91813 .60331 L
.91826 .60331 L
.91839 .60331 L
.91853 .60331 L
.91866 .60331 L
.91879 .60331 L
.91893 .60331 L
.91906 .60331 L
.91919 .60331 L
Mistroke
.91932 .60331 L
.91946 .60331 L
.91959 .60331 L
.91972 .60331 L
.91986 .60331 L
.91999 .60331 L
.92012 .60331 L
.92025 .60331 L
.92039 .60331 L
.92052 .60331 L
.92065 .60331 L
.92079 .60331 L
.92092 .60331 L
.92105 .60331 L
.92118 .60331 L
.92132 .60331 L
.92145 .60331 L
.92158 .60331 L
.92172 .60331 L
.92185 .60331 L
.92198 .60331 L
.92211 .60331 L
.92225 .60331 L
.92238 .60331 L
.92251 .60331 L
.92265 .60331 L
.92278 .60331 L
.92291 .60331 L
.92304 .60331 L
.92318 .60331 L
.92331 .60331 L
.92344 .60331 L
.92358 .60331 L
.92371 .60331 L
.92384 .60331 L
.92397 .60331 L
.92411 .60331 L
.92424 .60331 L
.92437 .60331 L
.92451 .60331 L
.92464 .60331 L
.92477 .60331 L
.9249 .60331 L
.92504 .60331 L
.92517 .60331 L
.9253 .60331 L
.92544 .60331 L
.92557 .60331 L
.9257 .60331 L
.92583 .60331 L
Mistroke
.92597 .60331 L
.9261 .60331 L
.92623 .60331 L
.92637 .60331 L
.9265 .60331 L
.92663 .60331 L
.92676 .60331 L
.9269 .60331 L
.92703 .60331 L
.92716 .60331 L
.9273 .60331 L
.92743 .60331 L
.92756 .60331 L
.92769 .60331 L
.92783 .60331 L
.92796 .60331 L
.92809 .60331 L
.92823 .60331 L
.92836 .60331 L
.92849 .60331 L
.92862 .60331 L
.92876 .60331 L
.92889 .60331 L
.92902 .60331 L
.92916 .60331 L
.92929 .60331 L
.92942 .60331 L
.92955 .60331 L
.92969 .60331 L
.92982 .60331 L
.92995 .60331 L
.93009 .60331 L
.93022 .60331 L
.93035 .60331 L
.93048 .60331 L
.93062 .60331 L
.93075 .60331 L
.93088 .60331 L
.93102 .60331 L
.93115 .60331 L
.93128 .60331 L
.93141 .60331 L
.93155 .60331 L
.93168 .60331 L
.93181 .60331 L
.93195 .60331 L
.93208 .60331 L
.93221 .60331 L
.93234 .60331 L
.93248 .60331 L
Mistroke
.93261 .60331 L
.93274 .60331 L
.93288 .60331 L
.93301 .60331 L
.93314 .60331 L
.93327 .60331 L
.93341 .60331 L
.93354 .60331 L
.93367 .60331 L
.93381 .60331 L
.93394 .60331 L
.93407 .60331 L
.9342 .60331 L
.93434 .60331 L
.93447 .60331 L
.9346 .60331 L
.93474 .60331 L
.93487 .60331 L
.935 .60331 L
.93513 .60331 L
.93527 .60332 L
.9354 .60332 L
.93553 .60332 L
.93567 .60332 L
.9358 .60332 L
.93593 .60332 L
.93607 .60332 L
.9362 .60332 L
.93633 .60332 L
.93646 .60332 L
.9366 .60332 L
.93673 .60332 L
.93686 .60332 L
.937 .60332 L
.93713 .60332 L
.93726 .60332 L
.93739 .60332 L
.93753 .60332 L
.93766 .60332 L
.93779 .60332 L
.93793 .60332 L
.93806 .60332 L
.93819 .60332 L
.93832 .60332 L
.93846 .60332 L
.93859 .60332 L
.93872 .60332 L
.93886 .60332 L
.93899 .60332 L
.93912 .60332 L
Mistroke
.93925 .60332 L
.93939 .60332 L
.93952 .60332 L
.93965 .60332 L
.93979 .60332 L
.93992 .60332 L
.94005 .60332 L
.94018 .60332 L
.94032 .60332 L
.94045 .60332 L
.94058 .60332 L
.94072 .60332 L
.94085 .60332 L
.94098 .60332 L
.94111 .60332 L
.94125 .60332 L
.94138 .60332 L
.94151 .60332 L
.94165 .60332 L
.94178 .60332 L
.94191 .60332 L
.94204 .60332 L
.94218 .60332 L
.94231 .60332 L
.94244 .60332 L
.94258 .60332 L
.94271 .60332 L
.94284 .60332 L
.94297 .60332 L
.94311 .60332 L
.94324 .60332 L
.94337 .60332 L
.94351 .60332 L
.94364 .60332 L
.94377 .60332 L
.9439 .60332 L
.94404 .60332 L
.94417 .60332 L
.9443 .60332 L
.94444 .60332 L
.94457 .60332 L
.9447 .60332 L
.94483 .60332 L
.94497 .60332 L
.9451 .60332 L
.94523 .60332 L
.94537 .60332 L
.9455 .60332 L
.94563 .60332 L
.94576 .60332 L
Mistroke
.9459 .60332 L
.94603 .60332 L
.94616 .60332 L
.9463 .60332 L
.94643 .60332 L
.94656 .60332 L
.94669 .60332 L
.94683 .60332 L
.94696 .60332 L
.94709 .60332 L
.94723 .60332 L
.94736 .60332 L
.94749 .60332 L
.94762 .60332 L
.94776 .60332 L
.94789 .60332 L
.94802 .60332 L
.94816 .60332 L
.94829 .60332 L
.94842 .60332 L
.94855 .60332 L
.94869 .60332 L
.94882 .60332 L
.94895 .60332 L
.94909 .60332 L
.94922 .60332 L
.94935 .60332 L
.94948 .60332 L
.94962 .60332 L
.94975 .60332 L
.94988 .60332 L
.95002 .60332 L
.95015 .60332 L
.95028 .60332 L
.95041 .60332 L
.95055 .60332 L
.95068 .60332 L
.95081 .60332 L
.95095 .60332 L
.95108 .60332 L
.95121 .60332 L
.95134 .60332 L
.95148 .60332 L
.95161 .60332 L
.95174 .60332 L
.95188 .60332 L
.95201 .60332 L
.95214 .60332 L
.95227 .60332 L
.95241 .60332 L
Mistroke
.95254 .60332 L
.95267 .60332 L
.95281 .60332 L
.95294 .60332 L
.95307 .60332 L
.9532 .60332 L
.95334 .60332 L
.95347 .60332 L
.9536 .60332 L
.95374 .60332 L
.95387 .60332 L
.954 .60332 L
.95413 .60332 L
.95427 .60332 L
.9544 .60332 L
.95453 .60332 L
.95467 .60332 L
.9548 .60332 L
.95493 .60332 L
.95506 .60332 L
.9552 .60332 L
.95533 .60332 L
.95546 .60332 L
.9556 .60332 L
.95573 .60332 L
.95586 .60332 L
.95599 .60332 L
.95613 .60332 L
.95626 .60332 L
.95639 .60332 L
.95653 .60332 L
.95666 .60332 L
.95679 .60332 L
.95692 .60332 L
.95706 .60332 L
.95719 .60332 L
.95732 .60332 L
.95746 .60332 L
.95759 .60332 L
.95772 .60332 L
.95786 .60332 L
.95799 .60332 L
.95812 .60332 L
.95825 .60332 L
.95839 .60332 L
.95852 .60332 L
.95865 .60332 L
.95879 .60332 L
.95892 .60332 L
.95905 .60332 L
Mistroke
.95918 .60332 L
.95932 .60332 L
.95945 .60332 L
.95958 .60332 L
.95972 .60332 L
.95985 .60332 L
.95998 .60332 L
.96011 .60332 L
.96025 .60332 L
.96038 .60332 L
.96051 .60332 L
.96065 .60332 L
.96078 .60332 L
.96091 .60332 L
.96104 .60332 L
.96118 .60332 L
.96131 .60332 L
.96144 .60332 L
.96158 .60332 L
.96171 .60332 L
.96184 .60332 L
.96197 .60332 L
.96211 .60332 L
.96224 .60332 L
.96237 .60332 L
.96251 .60332 L
.96264 .60332 L
.96277 .60332 L
.9629 .60332 L
.96304 .60332 L
.96317 .60332 L
.9633 .60332 L
.96344 .60332 L
.96357 .60332 L
.9637 .60332 L
.96383 .60332 L
.96397 .60332 L
.9641 .60332 L
.96423 .60332 L
.96437 .60332 L
.9645 .60332 L
.96463 .60332 L
.96476 .60332 L
.9649 .60332 L
.96503 .60332 L
.96516 .60332 L
.9653 .60332 L
.96543 .60332 L
.96556 .60332 L
.96569 .60332 L
Mistroke
.96583 .60332 L
.96596 .60332 L
.96609 .60332 L
.96623 .60332 L
.96636 .60332 L
.96649 .60332 L
.96662 .60332 L
.96676 .60332 L
.96689 .60332 L
.96702 .60332 L
.96716 .60332 L
.96729 .60332 L
.96742 .60332 L
.96755 .60332 L
.96769 .60332 L
.96782 .60332 L
.96795 .60332 L
.96809 .60332 L
.96822 .60332 L
.96835 .60332 L
.96848 .60332 L
.96862 .60332 L
.96875 .60332 L
.96888 .60332 L
.96902 .60332 L
.96915 .60332 L
.96928 .60332 L
.96941 .60332 L
.96955 .60332 L
.96968 .60332 L
.96981 .60332 L
.96995 .60332 L
.97008 .60332 L
.97021 .60332 L
.97034 .60332 L
.97048 .60332 L
.97061 .60332 L
.97074 .60332 L
.97088 .60332 L
.97101 .60332 L
.97114 .60332 L
.97127 .60332 L
.97141 .60332 L
.97154 .60332 L
.97167 .60332 L
.97181 .60332 L
.97194 .60332 L
.97207 .60332 L
.9722 .60332 L
.97234 .60332 L
Mistroke
.97247 .60332 L
.9726 .60332 L
.97274 .60332 L
.97287 .60332 L
.973 .60332 L
.97313 .60332 L
.97327 .60332 L
.9734 .60332 L
.97353 .60332 L
.97367 .60332 L
.9738 .60332 L
.97393 .60332 L
.97406 .60332 L
.9742 .60332 L
.97433 .60332 L
.97446 .60332 L
.9746 .60332 L
.97473 .60332 L
.97486 .60332 L
.97499 .60332 L
.97513 .60332 L
.97526 .60332 L
.97539 .60332 L
.97553 .60332 L
.97566 .60332 L
.97579 .60332 L
.97592 .60332 L
.97606 .60332 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "We see that the decomposition of the original signal using the best basis \
selected from the entropy criterion is able to concentrate the energy better. \
This means that for a given compression ratio, best basis decomposition will \
give less error or distortion. So we will use the wavelet packet coefficients \
to do the compression. (For compression with wavelet packets, see Coifman et \
al. (1992).) In many applications, the maximum error or distortion allowed is \
known and from this we can determine how much we want to compress the data. \
Suppose we want the reconstructed sound signal with less than ",
  Cell[BoxData[
      \(TraditionalForm\`20  %\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " error or distortion, we should keep at least ",
  Cell[BoxData[
      \(TraditionalForm\`96  %\)], "InlineFormula",
    CellTags->"S2.1.3"],
  " of the total energy. "
}], "Text",
  CellTags->{"S2.1.3", "3.52"}],

Cell["\<\
We choose to retain enough of the coefficients such that we keep \
about 96% of the total energy. The compression ratio is about 9.\
\>", 
  "MathCaption",
  CellTags->{"S2.1.3", "3.53"}],

Cell[CellGroupData[{

Cell["Length[Select[ewp, #<=0.96&]]", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(780\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["This gives the reconstructed data.", "MathCaption",
  CellTags->{"S2.1.3", "3.54"}],

Cell["\<\
InverseWaveletPacketTransform[
Compress[wpdata, %+1], s6];\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.1.3"],

Cell["\<\
The reconstructed signal is played here and it resembles the \
original sound rather well.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.55"}],

Cell[CellGroupData[{

Cell["ListPlay[%, SampleRate -> 8012, PlayRange -> All]", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8012 7168 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00Oo`00;@0000000`00
Oomoo`3oOolYOol100000003001oogoo09Ioo`04001oogoo0003Ool00`00Oomoo`28Ool100000003
001oogoo02Aoo`80009oo`03001oogoo06Moo`04001oo`00Ool200000goo00000003Ool00`00Oomo
o`27Ool100000003001oogoo029oo`04001oogooOol2000017oo00000000IGoo00<007ooOol00P00
0Woo00D007oo001oo`00009oo`8008Moo`40000000<007ooOol087oo00<007ooOol02P0000Aoo`00
Ool005aoo`03001oo`0000Aoo`80009oo`06001oo`00001oo`000Woo00<007ooOol0QGoo0@000000
0`00Oomoo`0LOol800001Goo00000000Ool01@0000Aoo`00000005Mooa<0009oo`H008Aoo`400000
00<007ooOol077oo6@00;7oo00<007oo00000`0000=oo`0000000`006Woo400000=oo`0000002`00
9Woo00<007ooOol0;Woo1P009Woo0@0000000`00Oomoo`0EOol00`00Oomoo`0600000goo0000000E
00000goo0000000UOol200000goo0000000=000017oo001oo`003Goo00D007ooOol007oo01P00003
Ool0000000L001eoo`800003Ool0000000D00003Ool007oo02Ioo`04001oo`00OolD000HOol10000
0003001oo`0009@00003Ool000000900005oo`40000000<007oo0000C@0000=oo`00Ool00gooS000
00Aoo`000000009ooc/00005Ool00000001oo`020001Ool100000003001oogoo019oo`800005Ool0
0000001oo`0:00000goo0000000@00000goo001oo`0VOolA000EOolK00000goo00000004000NOol2
0004Ool200000goo001oo`0[OolC00000goo0000000GOol100000003001oogoo01Yoo``00003Ool0
000000H00006Ool00000001oo`00<Woo0P000Woo00<007ooOol06Goo7@00F7oo200000Ioo`00Ool0
07oo000NOol100000003001oogoo01ioo`800003Ool0000000800003Ool0000000T005Uoo`@00003
Ool0000000D00003Ool0000000800004Ool00000Ool200000goo00000024Ool100000003001oo`00
02=oo`<00003Ool000000080009oo`03001oogoo05ioo`05001oogoo001oo`0200001goo000007oo
001oo`00009oo`03001oo`0008Moo`40000000<007ooOol087oo0P0000=oo`0000000P0017oo00<0
07ooOol0Igoo0P000Woo0`000Woo00<007ooOol0Qgoo0@0000000`00Oomoo`2GOol200000goo001o
o`2<Ool100000003001oogoo09Eoo`03001oogoo008008ioo`40000000<007ooOol0ogoo:Goo0@00
003o000]00000003001oogoo0?moobUoo`40000000<007ooOol0UWoo00<007ooOol0Sgoo0@000000
0`00Oomoo`3oOolYOol100000003001oogoo0?moobUoo`40000000<007ooOol0ogoo:Goo0@000000
0`00Oomoo`3oOolYOol100000003001oogoo0?moobUoo`40000000<007ooOol0ogoo:Goo0@000000
0`00Oomoo`3oOolYOol100000003001oogoo0?moobUoo`40000000<007ooOol0ogoo:Goo0@000000
0`00Oomoo`3oOolYOol100000003001oogoo0?moobUoo`40000000<007ooOol0:goo00<007ooOol0
nWoo0@0000000`00Oomoo`3oOolYOol100000003001oogoo09Qoo`03001oogoo08eoo`40000000<0
07ooOol087oo00<007ooOol0ogoo1Woo0@0000000`00Oomoo`3oOolYOol100000003001oogoo01mo
o`03001oogoo079oo`03001oogoo00=oo`03001oogoo08]oo`40000000<007ooOol0;7oo00<007oo
Ool0nGoo0@0000000`00Oomoo`0OOol00`00Oomoo`1cOol00`00Oomoo`2@Ool100000003001oogoo
025oo`04001oogoo003oOol4Ool100000003001oogoo01eoo`03001oogoo0?moo`Uoo`40000000<0
07ooOol09Goo00<007ooOol0MGoo00<007ooOol0R7oo0@0000000`00Oomoo`0XOol2001_Ool00`00
Oomoo`2<Ool100000003001oogoo0?moobUoo`40000000<007ooOol09goo00<007ooOol0oWoo0@00
00000`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo0000LGoo00<007oo
Ool0QWoo0@0000000`00Oomoo`0POol01000Oomoo`00Mgoo00<007ooOol0RWoo0@0000000`00Oomo
o`0VOol00`00Oomoo`1^Ool200000goo001oo`2<Ool100000003001oogoo0?moobUoo`40000000<0
07ooOol0ogoo:Goo0@0000000`00Oomoo`2SOol00`00Oomoo`22Ool100000003001oogoo01eoo`03
001oogoo0?moo`Uoo`40000000<007ooOol08Goo00<007ooOol00P00KWoo0P00TWoo0@0000000`00
Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`1ROol2000;Ool00`00Oomoo`02001JOol00`00Oomo
o`0YOol100000003001oogoo02moo`03001oogoo06eoo`03001oogoo08Ioo`40000000<007ooOol0
9goo00<007ooOol0Hgoo00<007ooOol04Woo00<007ooOol0Pgoo0@0000000`00Oomoo`0JOol00`00
Oomoo`1fOol00`00Oomoo`03Ool00`00Oomoo`2<Ool100000003001oogoo08aoo`03001oogoo00Yo
o`03001oogoo009oo`03001oogoo009oo`03001oogoo089oo`40000000<007ooOol05goo00<007oo
Ool05Goo00<007ooOol0GGoo00<007ooOol00goo00<007ooOol027oo00<007ooOol0FWoo00<007oo
Ool0:7oo0@0000000`00Oomoo`27Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`25Ool100000003001oogoo019oo`8000=oo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo00Eoo`8006Uoo`06001oo`00001oo`000goo00<007ooOol0QGoo0@0000000`00Oomoo`0B
Ool00`00Ool00003Ool00`00Oomoo`08Ool01P00Oomoo`00Ool0049oo`03001oogoo02Eoo`03001o
ogoo00eoo`03001oogoo05]oo`03001oogoo02Aoo`40000000<007ooOol05Woo00@007ooOol0009o
o`8000=oo`03001oogoo071oo`03001oogoo00Yoo`03001oogoo08Aoo`40000000<007ooOol047oo
00@007ooOol0009oo`<000Moo`8000]oo`04001oogoo001JOol00`00Ool00004Ool01@00Ool007oo
0000TGoo0@0000000`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool2
001HOol00`00Oomoo`0kOol00`00Oomoo`1OOol100000003001oogoo00moo`8001Uoo`03001oogoo
04]oo`03001oogoo01Aoo`03001oogoo008000ioo`03001oogoo05Yoo`8002Moo`40000000<007oo
Ool03Woo0P0000=oo`0000000P0017oo00<007oo00001Woo00<007oo00000Woo100000=oo`00Ool0
0Woo00<007ooOol0EWoo00D007ooOomoo`0000Moo`04001oogoo0002Ool01000Oomoo`009Woo0`00
=7oo1@009goo0@0000000`00Oomoo`0HOol01@00Oomoogoo00001Goo00<007oo00000Woo00<007oo
Ool017oo0P001Goo00<007ooOol0?Woo0P00C7oo0P0000=oo`00Ool0Ggoo0@0000000`00Oomoo`0>
Ool00`00Oomoo`02Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<0
07ooOol00Woo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol017oo00<007ooOol03Woo00<0
07oo00008goo00<007ooOol00goo00<007ooOol0FWoo0@0000000`00Oomoo`0@Ool01000Oomoogoo
100000=oo`00Ool027oo00@007ooOol000=oo`03001oo`0005Yoo`03001oogoo00Ioo`8000Aoo`03
001oo`00009oo`03001oogoo00Aoo`03001oo`0001moo`04001oo`000003Ool00`00Oomoo`1JOol1
00000003001oogoo00moo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo02moo`04001oogoo
000BOol00`00Oomoo`0=Ool00`00Oomoo`04Ool01000Oomoo`001Woo0P002Goo00<007ooOol07goo
00<007ooOol0<goo00<007ooOol0:Goo0@0000000`00Oomoo`0?Ool01000Oomoo`002Goo00<007oo
Ool01goo00D007ooOomoo`0000Eoo`04001oogoo000`Ool00`00Oomoo`0BOol00`00Ool0000AOol0
1@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol09Woo00<007ooOol0
FWoo0@0000000`00Oomoo`0<Ool00`00Oomoo`02Ool30002Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00
Oomoo`06Ool20002Ool00`00Oomoo`08Ool00`00Ool00004Ool20003Ool01000Ool0000017oo00H0
07ooOol007oo0003Ool00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`0]Ool01000Oomoogoo
0P009Goo0@0000000`00Oomoo`0<Ool00`00Ool00009Ool20006Ool00`00Oomoo`05Ool200000goo
001oo`02Ool01000Oomoo`00EWoo00<007ooOol017oo00<007ooOol017oo00<007oo00001Goo00<0
07oo00008Woo00@007oo000000=oo`03001oogoo05Yoo`40000000<007ooOol037oo00<007ooOol0
1Goo00<007oo000017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00001goo00<007oo0000
AGoo00<007oo000027oo00<007ooOol01Goo00<007ooOol017oo00@007ooOol000Ioo`05001oogoo
Ool0000ROol200000goo001oo`0aOol00`00Oomoo`05Ool00`00Oomoo`0SOol100000003001oogoo
00ioo`03001oo`0000Ioo`05001oogooOol00004Ool00`00Oomoo`16Ool01P00Oomoo`00Ool000Io
o`04001oogoo000?Ool00`00Ool0000@Ool20007Ool00`00Oomoo`0QOol00`00Oomoo`1MOol10000
0003001oogoo00moo`03001oogoo0080009oo`03001oogoo00Moo`04001oogoo0004Ool30002Ool2
00000goo001oo`0bOol00`00Oomoo`08Ool00`00Oomoo`05Ool20002Ool2000:Ool00`00Oomoo`02
0004Ool01000Oomoo`002Goo00@007oo001oo`8002Eoo`03001oo`00008002aoo`03001oogoo02ao
o`40000000<007ooOol02goo0`004Goo00<007ooOol00Woo00D007ooOomoo`00009oo`800003Ool0
07oo039oo`03001oogoo009oo`<00003Ool007oo009oo`03001oogoo009oo`05001oo`00Ool00002
Ool2000017oo000000000Woo0P000Woo00@007ooOomoo`80009oo`04001oogoo0002Ool20003Ool0
1000Ool000001Goo00<007ooOol07Goo00<007ooOol00Woo00@007ooOomoo`8002ioo`<002Uoo`40
000000<007ooOol02goo00<007ooOol00P001Woo00D007ooOomoo`0000=oo`80009oo`05001oogoo
Ool00004Ool20007Ool00`00Oomoo`0^Ool00`00Oomoo`0FOol20008Ool00`00Oomoo`04Ool01000
Oomoo`0017oo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo025oo`03001oogoo02mo
o`03001oo`0000Moo`03001oogoo009oo`03001oogoo01aoo`40000000<007ooOol02goo00<007oo
Ool02Goo0P001goo00@007ooOol000=oo`06001oogoo001oo`000Woo00<007ooOol00Woo0P00>7oo
0P0000Aoo`00001oo`8000Aoo`03001oo`00009oo`800003Ool00000009oo`03001oogoo00<000Ao
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Qoo`80009oo`03001o
ogoo009oo`03001oo`00009oo`03001oogoo02]oo`03001oogoo00Qoo`03001oogoo01aoo`400000
00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo009oo`04001oogoo
0005Ool00`00Oomoo`03000kOol01P00Oomoo`00Ool000=oo`800004Ool00000Ool20005Ool20006
Ool01000Oomoogoo0P0000=oo`00Ool00Woo00<007ooOol00goo00<007ooOol01goo00<007oo0000
0Woo00<007ooOol077oo10000Woo00<007ooOol01Goo00<007ooOol09Woo0P002Goo00<007ooOol0
8Goo0@0000000`00Oomoo`0:Ool20004Ool2000<Ool00`00Oomoo`04Ool01000Oomoo`0027oo00<0
07ooOol0?Woo00<007ooOol017oo00<007ooOol00goo0P0000=oo`00Ool00Woo00<007ooOol027oo
00<007ooOol01Goo00<007ooOol09Woo00<007ooOol01Goo00<007ooOol0>goo00<007ooOol07Goo
0@0000000`00Oomoo`0:Ool01@00Ool007oo00000goo00H007oo000007oo0005Ool30005Ool20004
Ool00`00Ool0000aOol01000Oomoo`0017oo00D007ooOomoo`0000=oo`03001oo`0000800005Ool0
0000Ool00003Ool00`00Ool0000:Ool01000Ool000000Woo00<007ooOol017oo00<007ooOol00Woo
00D007oo001oo`00029oo`8000=oo`800003Ool007oo00Aoo`03001oogoo02=oo`03001oogoo00Io
o`<00005Ool007ooOol0000QOol100000003001oogoo00]oo`04001oogoo000DOol00`00Ool00004
Ool01000Oomoo`001Goo00<007oo0000?goo00<007oo000047oo00<007ooOol00Woo00<007ooOol0
1goo00<007oo00000goo00<007ooOol01Woo00<007ooOol06Goo0P000goo00<007ooOol0@goo00<0
07ooOol067oo0@0000000`00Oomoo`08Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Ool00005
Ool01000Oomoogoo0`0000=oo`0000001goo00<007ooOol00Woo00<007ooOol09goo0P001Goo00<0
07ooOol01Woo00<007ooOol00Woo0P0000=oo`00Ool00goo00<007ooOol027oo00D007ooOol007oo
008000=oo`03001oogoo00Aoo`03001oogoo00Moo`<00004Ool007oo000KOol00`00Ool00007Ool0
1@00Oomoogoo00009goo00@007ooOol000=oo`05001oogooOol0000:Ool00`00Oomoo`0FOol10000
0003001oogoo00Ioo`<00003Ool007oo00=oo`04001oogoo0002Ool00`00Ool00007Ool30008Ool0
0`00Ool00009Ool01000Oomoo`00:Woo0P0000=oo`00Ool00Woo00@007ooOol000=oo`03001oogoo
00<000=oo`800003Ool00000009oo`05001oo`00Ool00007Ool00`00Oomoo`04Ool01000Oomoo`00
0Woo00@007ooOol000Moo`80021oo`04001oo`000005Ool01@00Ool007oo000097oo00<007ooOol0
2Woo0P0000=oo`00Ool00Woo00<007ooOol05goo0@0000000`00Oomoo`06Ool300000goo00000007
Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`0YOol01@00Ool007oo
000027oo0P001Goo00D007oo001oo`0000=oo`03001oogoo00800003Ool007oo00aoo`03001oo`00
00Moo`80009oo`800003Ool007oo01eoo`03001oogoo00=oo`8000Aoo`06001oogoo001oo`00;Goo
00<007ooOol08Woo0@0000000`00Oomoo`06Ool200000goo001oo`02000017oo001oo`002Woo0`00
17oo00<007oo00000Woo00<007ooOol00P001Goo00<007oo00000Woo00@007ooOol002Aoo`03001o
o`0000Ioo`04001oogoo0003Ool200000goo001oo`02Ool01000Oomoo`001Goo00D007oo001oo`00
00Eoo`<0009oo`05001oo`00Ool00003Ool01@00Oomoogoo00002Goo0`006goo00<007ooOol03Goo
00<007oo00000P008Goo00D007oo000007oo00<000=oo`04001oo`00Ool20002Ool00`00Oomoo`0K
Ool100000003001oogoo00Aoo`03001oo`00008000Uoo`05001oo`00Ool00002Ool00`00Ool00005
Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P000Woo00@007ooOol002Ioo`03001oo`000080
00Aoo`05001oo`00Ool00008Ool01@00Oomoogoo00000Woo0P0000=oo`00000037oo00D007ooOol0
07oo00<00005Ool007ooOol00002Ool00`00Oomoo`04Ool01000Oomoo`007Goo0P0000Eoo`00Oomo
o`00009oo`<00004Ool007ooOol2000QOol00`00Oomoo`03Ool00`00Ool000020002Ool00`00Ool0
0003Ool00`00Oomoo`02Ool00`00Oomoo`0FOol100000003001oogoo00Aoo`03001oo`0000=oo`05
001oogooOol0000AOol00`00Oomoo`0AOol00`00Oomoo`0VOol20007Ool00`00Ool00004Ool01@00
Oomoogoo00000Woo00@007ooOol000]oo`04001oogooOol2000017oo001oo`006Goo00<007ooOol0
6Goo0P002Woo00<007ooOol09Goo0P0000=oo`00000017oo00D007ooOomoo`0000Eoo`03001oogoo
01aoo`40000000<007ooOol017oo00@007oo001oo`800004Ool007oo0003Ool01P00Ool007oo001o
o`80009oo`80009oo`04001oogooOol2000017oo001oo`000Woo00D007ooOomoo`0000Aoo`D002Ao
o`06001oogooOol007oo0P0000=oo`0000000P0000Aoo`00000000Aoo`03001oo`0000=oo`03001o
ogoo008000=oo`800003Ool007oo00<00003Ool007oo00Eoo`07001oogooOol007oo00000Woo00<0
07ooOol00P001Goo00<007ooOol00Woo00<007ooOol05Woo00<007ooOol00goo00<007ooOol00Woo
1P000Woo0P008goo0P0000Aoo`00Ool0009oo`H000Ioo`8001Uoo`40000000<007ooOol017oo00<0
07ooOol00P001Woo0P000goo0P0000=oo`00Ool017oo00<007oo00000Woo00<007ooOol01Woo0P00
1Goo0`000goo00<007ooOol09Goo1@000Woo0P0000=oo`00Ool01goo0P000goo00@007ooOomoo`80
009oo`800007Ool00000Ool007oo00002Goo1P000Woo00L007ooOomoo`00Ool00002Ool00`00Ool0
0003000LOol200000goo001oo`05Ool01@00Oomoogoo0000:7oo00@007oo000000aoo`03001oogoo
009oo`03001oogoo01Aoo`40000000<007ooOol01Goo00<007ooOol00goo0P003Woo0P000goo00<0
07ooOol02Woo00D007ooOomoo`0000Eoo`03001oo`0002=oo`8000Moo`03001oo`00011oo`05001o
ogooOol00002Ool01000Ool0000047oo0P002Woo00<007ooOol00Woo00<007ooOol067oo0P0017oo
00<007ooOol02goo00<007ooOol08Goo00@007ooOol000Uoo`03001oo`0000Aoo`800003Ool007oo
01Moo`40000000<007ooOol00goo0P001Goo00<007ooOol01Woo00<007oo00002goo00<007oo0000
0Woo00@007oo0000009oo`800003Ool007oo008000Aoo`03001oogoo02Aoo`@000Aoo`<0009oo`03
001oogoo00=oo`04001oogooOol20003Ool20002Ool01000Oomoogoo0`000Woo00<007ooOol00goo
0P0027oo00<007oo00001Goo0`0017oo0`0067oo00<007oo000017oo00H007ooOol007oo0002Ool0
0`00Oomoo`02Ool00`00Oomoo`0QOol200001goo001oogoo001oo`0000Eoo`03001oo`00009oo`04
001oo`00Ool2000FOol100000003001oogoo00=oo`04001oogoo0003Ool01000Oomoogoo0P002Goo
00D007oo001oo`0000]oo`<003Eoo`03001oogoo00Qoo`03001oogoo009oo`8000moo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00005Ool00`00Oomoo`0LOol00`00
Oomoo`0:Ool3000VOol00`00Oomoo`02Ool00`00Ool00005Ool20004Ool20004Ool2000FOol10000
0003001oogoo00=oo`80009oo`<00005Ool007ooOol00002Ool01000Oomoo`001Goo00@007oo0000
00Ioo`8000=oo`04001oogoo0003Ool20002Ool200001Woo00000000Ool0029oo`800003Ool007oo
00800003Ool007oo00L0009oo`800003Ool007oo00=oo`07001oo`00Ool007oo000017oo0P000goo
00<007oo000017oo00D007ooOomoo`0000=oo`04001oogoo0002Ool20004Ool01000Ool0000067oo
00<007ooOol017oo0P000goo0`0000Aoo`00Oomoo`@0029oo`800004Ool007oo0002Ool00`00Oomo
o`02Ool02P00Oomoo`00Ool007oo001oo`0067oo0@0000000`00Oomoo`03Ool01@00Ool007oo0000
0Woo00@007oo0000009oo`06001oogoo001oo`0017oo00@007ooOomoo`8000=oo`03001oogoo00Yo
o`05001oogoo001oo`020002Ool00`00Ool0000QOol200001goo000007oo001oo`0000=oo`800003
Ool007oo019oo`05001oogooOol00008Ool01000Oomoogoo0`0027oo00@007ooOol000=oo`05001o
ogoo001oo`0300000goo001oo`0COol400000goo001oo`02Ool01@00Oomoogoo00000Woo00@007oo
001oo`8002Qoo`05001oogooOol00003Ool00`00Oomoo`0300000goo001oo`0HOol100000003001o
ogoo00Aoo`03001oogoo00]oo`04001oogoo0007Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Ioo`03001oogoo009oo`03001oogoo02=oo`800003Ool0000000Aoo`8000Aoo`03001oogoo009o
o`03001oo`0001Aoo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=o
o`80009oo`800003Ool007oo01=oo`80009oo`03001oogoo00Eoo`8000Ioo`03001oo`00008001ao
o`03001oogoo009oo`03001oogoo00Ioo`03001oo`00009oo`03001oogoo00Uoo`03001oogoo015o
o`40000000<007ooOol00Woo0P0000=oo`00000027oo00<007ooOol01Goo00<007ooOol00P000Woo
0`0017oo00D007ooOomoo`0000Qoo`03001oo`0000D00003Ool0000001moo`8000=oo`05001oogoo
Ool00003Ool01000Ool000002Woo0P000goo00@007ooOol0009oo`800004Ool007oo0002Ool01000
Ool007oo0P0000=oo`0000001Woo0P000Woo00<007oo00000P000Woo00<007oo00000P0000Eoo`00
001oo`0000=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00005
Ool01@00Oomoo`00Ool00`007Goo00<007ooOol00Woo00@007ooOomoo`80009oo`@00005Ool00000
Ool00002Ool200000goo001oo`02000COol100000003001oogoo009oo`03001oogoo009oo`03001o
o`00008000Eoo`03001oo`00009oo`<00003Ool0000000Aoo`03001oogoo00]oo`05001oogooOol0
0003Ool01000Ool007oo10007Woo0P0000Ioo`00000007oo0002Ool00`00Ool0000200001goo001o
ogoo001oo`0000=oo`03001oogoo008000Moo`04001oogoo0008Ool00`00Oomoo`07Ool01000Oomo
o`000Woo0P0000=oo`00Ool00Woo00@007ooOomoo`800003Ool000000080009oo`05001oogooOol0
0007Ool01000Oomoo`002Woo00@007ooOomoo`D00003Ool007oo00<001Yoo`<00006Ool00000001o
o`000Woo00@007ooOomoo`800003Ool0000000800003Ool0000000D001Ioo`40000000<007ooOol0
0Woo00<007ooOol00goo0P0047oo00D007oo001oo`0001Aoo`04001oogoo0002Ool30002Ool01`00
Oomoogoo001oo`0001Aoo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`001Woo00<0
07ooOol05Woo00@007ooOol0009oo`8001Aoo`03001oogoo00=oo`03001oogoo00Uoo`03001oo`00
00Aoo`<000Uoo`03001oogoo009oo`06001oogooOol007oo1P0067oo00<007oo00000P0017oo00<0
07ooOol01goo0P0000Aoo`00Oomoo`800009Ool00000Ool007oo001oo`00019oo`40000000<007oo
Ool00Woo100000=oo`00Ool00goo0P000Woo0P0000=oo`0000001Goo00<007oo00000Woo00<007oo
Ool01Goo00<007ooOol00P001goo00<007ooOol00P0000=oo`00000010000Woo100000Eoo`00001o
o`0000moo`03001oogoo00800004Ool007ooOol400000goo001oo`02000017oo000000000goo00D0
07ooOomoo`0000Aoo`80009oo`8000Eoo`06001oo`00001oo`0017oo00<007ooOol00goo00D007oo
Oomoo`00009oo`8000Qoo`03001oogoo00L00004Ool00000Ool400000goo000000070002Ool01@00
Oomoogoo00000Woo00<007oo00000Woo0`000Woo0P0000=oo`00Ool00P0000=oo`00Ool037oo00<0
07oo00000Woo0P0000=oo`0000000Woo00L007ooOol007oo001oo`04000027oo000007oo001oo`00
Ool300000goo00000005000BOol100000006001oogoo001oo`002Woo00<007ooOol01goo00<007oo
Ool01Woo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`<000Aoo`03001oo`0000800003Ool007oo
009oo`04001oo`000002Ool3000EOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol047oo00<007ooOol00Woo00<007ooOol00Woo0P0017oo0P0000Aoo`00Ool000Aoo`04
001oogoo0002Ool200000goo0000000600000goo00000002000017oo000007oo0P000Woo0`002goo
0P0017oo0P000goo0`0000Eoo`00001oo`0000Uoo`06001oogooOol007oo0P0000Eoo`00001oo`00
00Aoo`03001oo`0000aoo`04001oogooOol20003Ool500000goo001oo`0:Ool00`00Oomoo`02Ool1
00000003001oo`0000@00003Ool0000000Moo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Ool000020004Ool01000Oomoogoo100000Ioo`00000007oo0003OolB0008Ool;0007Ool00`00Oomo
o`0500000goo001oo`0:Ool2000017oo001oo`0027oo0`0000Eoo`00Oomoo`00011oo`04001oogoo
Ool2000017oo001oogoo0`0000=oo`0000003P0000Eoo`00000007oo00800006Ool007ooOol007oo
0`0000Qoo`00Oomoo`00Ool007oo100000=oo`0000000P0000=oo`0000000P0000=oo`00Ool00P00
0Woo3@0000=oo`00Ool01Goo0P000Woo00<007ooOol00`0000Eoo`00Ool007oo00@00003Ool00000
00H00004Ool007ooOol2000017oo000000000Woo0@0000000`00Ool000050002Ool300000goo001o
o`02Ool01@00Oomoogoo00001Goo00D007ooOomoo`00009oo`03001oogoo00Eoo`04001oogooOol2
000017oo000007oo0P000Woo00@007oo001oob@000Eoo`D0009oo`800005Ool00000Ool00003Ool2
0008Ool00`00Oomoo`04Ool200000goo001oo`030003Ool20003Ool00`00Oomoo`03Ool200001Woo
001oo`00Ool0009oo`05001oogoo001oo`0E00000goo001oo`07Ool20003Ool20004Ool300000goo
0000000M00000goo00000004Ool01000Oomoo`000goo00<007oo00000P0000=oo`0000000P000Woo
5P000Goo0@0000000`00Ool000030002Ool00`00Ool00008Ool20003Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool01000Oomoo`000Woo00D007ooOol007oo00@00003Ool007oo01L0
00Eoo`03001oogoo00Aoo`04001oogoo0005Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Qo
o`04001oogoo000>Ool20008Ool00`00Oomoo`03Ool400000goo001oo`07000017oo000007oo1`00
3Goo0`0000=oo`0000000Woo00<007ooOol07P0000=oo`0000001Goo00D007ooOomoo`00009oo`03
001oogoo00Qoo`05001oo`00001oo`0B0001Ool100000003001oo`0000@00003Ool007oo00=oo`04
001oo`00000>Ool00`00Oomoo`05Ool20002Ool20006Ool01P00Oomoogoo001oo`80009oo`03001o
o`0002400003Ool0000000800005Ool00000Ool00002Ool01000Oomoo`000Woo00<007oo00000Woo
00D007ooOomoo`0000]oo`03001oogoo009oo`05001oo`00001oo`020002Ool01000Oomoogoo0P00
0goo00@007oo000000Eoo`H00003Ool0000001D000Aoo`<000Ioo`D0009oob800003Ool0000000=o
o`03001oo`0000@00004Ool00000Ool20003OolH0001Ool100000003001oo`0000<00003Ool007oo
00@00003Ool007oo009oo`03001oogoo008000=oo`03001oogoo008000Eoo`8000Aoo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo5P0000=oo`0000000Woo3@000Woo1`0000=oo`00Ool00Woo
0`0000=oo`00Ool00Woo00<007oo000017oo0P0000=oo`0000000P0000Eoo`00001oo`0000Qoo`03
001oogoo00Eoo`03001oogoo00Moo`800003Ool0000000<00003Ool0000001D0009oo`05001oogoo
001oo`0600001goo00000000Ool007oo00H00003Ool0000000@00003Ool0000001@00003Ool00000
00800003Ool007oo00T00004Ool00000OolE000017oo000007oo0@0000001000Oomoo`000Woo00D0
07ooOomoo`0000aoo`03001oogoo00=oo`04001oo`00Ool20004Ool00`00Oomoo`09Ool01000Ool0
00000Woo00<007oo00000Woo100000=oo`00000020002Goo00D007ooOol007oo00800003Ool007oo
008000Ioo`05001oo`00Ool00009Ool01P00Oomoo`00Ool000Aoo`03001oo`0000=oo`800003Ool0
07oo00Yoo`03001oogoo00]oo`03001oogoo008000Eoo`03001oogoo009oo`<00004Ool007oo0002
Ool01000Ool000000goo00<007ooOol027oo00<007ooOol00`000Woo0P000goo0P0017oo0P0000=o
o`0000000goo00<007ooOol00goo00D007ooOol007oo00H0009oo`8000aoo`03001oogoo00H00004
Ool007ooOol80004Ool00`00Oomoo`06Ool100000003001oogoo00@00003Ool0000000Aoo`03001o
o`0000Moo`04001oogooOol20003Ool00`00Oomoo`0?Ool01P00Ool007oo001oo`@00003Ool00000
0080009oo`03001oo`0000H000]oo`04001oogooOol300002Woo001oogoo001oo`00Ool007oo1000
0goo1`0017oo00<007oo00001Goo0P000goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00`001Woo100000=oo`0000001`000goo10000goo00D007oo000007oo00<0009o
o`80009oo`03001oo`0000X000Eoo`03001oogoo00=oo`03001oogoo00Aoo`L00003Ool007oo00L0
0003Ool007oo00@0000=Ool007oo001oo`00Ool007oo001oo`00Ool01P0000=oo`00Ool03Goo0@00
00001000Oomoogoo0P0000Aoo`00Oomoo`H000=oo`03001oogoo00Moo`800005Ool007ooOol00002
Ool01000Ool000000Woo10000goo0P0000Ioo`00Ool007oo0002Ool300000goo001oo`02Ool20004
Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool01@00Ool007oo00000Woo00D007oo000007oo00800003
Ool00000008000Eoo`03001oogoo009oo`800005Ool007ooOol00005Ool00`00Oomoo`03Ool20000
1goo000007oo001oo`0000Aoo`04001oogooOol20007Ool6000017oo001oogoo0P000Woo00@007oo
Oomoo`800003Ool00000009oo`80009oo`03001oogoo009oo`03001oogoo009oo`04001oo`00Ool2
0002Ool4000COol01000Oomoogoo1P000goo0P0000=oo`00Ool00P0000Ioo`00000007oo0002Ool0
0`00Oomoo`0600000goo00000002000AOol10000000;001oogooOol007oo001oo`00Ool00005Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo00Moo`03001oogoo009oo`8000Aoo`04001oogoo0008
Ool01000Oomoogoo0P00:goo00@007ooOol0009oo`80009oo`03001oogoo00Ioo`03001oogoo00Uo
o`8000Aoo`03001oogoo00]oo`03001oogoo00Aoo`04001oogooOol200000goo001oo`020003Ool0
0`00Oomoo`08Ool20002Ool20007Ool00`00Oomoo`05Ool01000Oomoogoo0P006Goo00H007ooOomo
o`00Ool20006Ool00`00Oomoo`06Ool20003Ool01000Oomoo`000Woo0`004goo0@0000001000Oomo
ogoo0P000goo00@007ooOol000Aoo`800003Ool007oo00@000=oo`80009oo`03001oogoo00=oo`80
00Qoo`05001oo`00Ool00002Ool400001Goo000007oo00007goo00@007ooOol0009oo`04001oo`00
Ool20002Ool40004Ool20003Ool20002Ool200000goo0000000300001Woo001oo`00Ool000Aoo`07
001oogooOol007oo000017oo00<007ooOol01Goo00D007ooOomoo`0000=oo`03001oo`00009oo`03
001oogoo008000Ioo`03001oogoo0080009oo`03001oogoo009oo`03001oogoo00H0009oo`80009o
o`06001oo`00001oo`005Woo00@007ooOomoo`@000=oo`D00004Ool00000Ool2000017oo000007oo
0P0000=oo`0000001P004goo0@0000000`00Oomoo`03Ool30005Ool2000LOol02`00Oomoogoo001o
o`00Ool007oo00000goo00<007ooOol00goo00<007ooOol07goo00@007ooOol000=oo`03001oogoo
00=oo`04001oogooOol30002Ool20002Ool20002Ool20002Ool00`00Oomoo`04Ool00`00Oomoo`07
Ool50003Ool00`00Ool0000=Ool01P00Oomoo`00Ool0009oo`03001oogoo00Moo`80009oo`03001o
o`0000=oo`03001oogoo00Eoo`03001oo`0000=oo`04001oogoo000HOol00`00Oomoo`04Ool01000
Oomoo`001Goo00<007ooOol017oo00@007oo0000009oo`04001oogoo000GOol100000003001oogoo
00=oo`<00004Ool000000005Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo00002Woo
10000Woo0`000Woo0P0087oo00<007ooOol00P000Woo00<007ooOol00goo0P0000=oo`00Ool01@00
00Ioo`00001oo`00Ool300000goo001oo`02Ool40003Ool00`00Ool00004Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo00800007Ool007oo001oo`00Ool010004goo00<007ooOol00P000Woo00/0
07ooOol007oo001oo`00Ool007oo00@00003Ool007oo008001aoo`800004Ool000000002Ool00`00
Oomoo`03Ool01000Oomoogoo0P0000=oo`0000000P0000=oo`0000000P005Woo0@0000000`00Oomo
o`03Ool200000goo001oo`02Ool40002Ool01000Ool000000goo0P0000=oo`00Ool00Woo00<007oo
Ool00Woo00<007oo000017oo00<007ooOol00P002goo0P008goo0P0000Aoo`00Ool000Eoo`03001o
o`00009oo`800003Ool0000000=oo`03001oogoo00Aoo`800003Ool007oo00L0009oo`03001oogoo
015oo`03001oogoo009oo`03001oogoo008000Aoo`03001oogoo00moo`03001oo`00009oo`04001o
ogooOol200002Woo001oogoo001oo`00Ool007oo0P007goo0`001Goo00<007oo00000P0000=oo`00
00000Woo0`000Woo100000=oo`00Ool057oo0@0000000`00Oomoo`04Ool20007Ool00`00Oomoo`0A
Ool00`00Ool00009Ool00`00Oomoo`03000/Ool01000Oomoo`001goo00D007ooOol007oo00D00004
Ool007oo0006Ool20002Ool40002Ool00`00Ool000020002Ool00`00Oomoo`0BOol00`00Oomoo`02
0005Ool00`00Oomoo`0@Ool00`00Ool00003Ool02P00Ool00000Ool007oo001oo`000goo00<007oo
Ool087oo00D007ooOol007oo0080009oo`800004Ool007oo0002Ool01000Ool000001Goo00<007oo
Ool057oo0@0000000`00Oomoo`05Ool500000goo001oo`02Ool00`00Ool0000:Ool20002Ool01000
Oomoo`0017oo00D007ooOomoo`0000Aoo`8000Aoo`@002=oo`03001oogoo00=oo`03001oo`000080
0003Ool007oo00800004Ool00000Ool300000goo001oo`0600000goo001oo`0200001Woo00000000
Ool0009oo`03001oogoo00=oo`04001oo`000006Ool30002Ool00`00Oomoo`02Ool200000goo0000
000GOol300000goo001oo`03Ool01000Ool007oo0`000goo0P007goo00<007ooOol017oo1P0000Io
o`00Oomoo`00Ool30002Ool3000HOol100000003001oogoo00Eoo`04001oogoo0003Ool3000:Ool2
00000goo00000004Ool00`00Oomoo`08Ool30006Ool200000goo0000000QOol200001Woo00000000
Ool000Aoo`800003Ool0000000D00003Ool007oo00Aoo`800004Ool00000Ool4000017oo001oogoo
100000Ioo`00001oo`00Ool20003Ool01000Oomoo`000Woo0P000goo00D007ooOomoo`0001]oo`03
001oogoo009oo`03001oogoo00@00003Ool007oo009oo`03001oogoo029oo`03001oo`0000800004
Ool007ooOol200000goo001oo`05Ool00`00Ool00003000HOol100000003001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Moo`04001oogooOol4000=Ool00`00Oomoo`03Ool0
1000Ool007oo0P008Goo00<007ooOol00P002goo0P0000=oo`00Ool017oo00<007oo00001Woo00<0
07ooOol0100000=oo`00000077oo00D007oo001oo`0001eoo`03001oogoo009oo`04001oogooOol2
0003Ool00`00Oomoo`0QOol01000Oomoogoo10000Woo00@007ooOol0029oo`40000000<007ooOol0
1Goo1@0000Aoo`00000000=oo`05001oogooOol0000;Ool01000Oomoo`000Woo00<007ooOol00Woo
00@007ooOomoo`80009oo`03001oogoo008002=oo`03001oo`0000D00003Ool007oo00Ioo`0;001o
ogooOol007oo001oo`00Ool00005Ool200001Woo001oogoo001oo`8000Ioo`80009oo`03001oogoo
008000=oo`05001oogooOol00003Ool20003Ool2000IOol00`00Oomoo`04Ool20003Ool30002Ool0
1000Oomoo`008Goo0P000Woo0P000Woo00<007oo0000100000=oo`0000000goo0P0000=oo`00Ool0
5goo0@0000000`00Oomoo`05Ool20006Ool00`00Ool00003Ool00`00Oomoo`06Ool20004Ool00`00
Oomoo`04Ool00`00Ool00007Ool20002Ool01000Oomoo`008goo00D007oo001oo`0000Aoo`04001o
ogooOol2000?Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`040002Ool00`00Oomoo`09
Ool01P00Oomoogoo001oo`8001Yoo`8000=oo`<000Uoo`03001oogoo029oo`03001oogoo00Ioo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo01Ioo`40000000<007ooOol01Woo00<007oo0000
0P0000=oo`00Ool01Woo00<007oo00001Goo0`000Woo00<007ooOol00Woo00<007ooOol017oo0P00
0Woo00D007ooOomoo`0000=oo`03001oogoo021oo`03001oo`00009oo`80009oo`<00003Ool00000
00D000Aoo`800003Ool007oo008000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo009oo`06001oogoo001oo`0017oo00<007oo00000Woo00H007oo000007oo000JOol0
0`00Oomoo`02Ool200000goo001oo`02Ool01000Oomoo`000Woo00<007ooOol08Goo00H007oo001o
o`00Ool20005Ool00`00Ool00002Ool00`00Oomoo`0JOol100000003001oogoo00Ioo`05001oo`00
001oo`03000017oo000000001Goo00<007oo00000Woo0P0000=oo`00Ool02Woo00<007ooOol00goo
10000goo0P008Woo00<007ooOol01Goo00<007ooOol00Woo0P0017oo00@007ooOomoo`800005Ool0
0000001oo`020002Ool600000goo001oo`05Ool00`00Ool00003Ool01000Oomoo`0017oo00<007oo
00000Woo00<007ooOol07goo0P0000Aoo`00000000Aoo`80009oo`05001oogoo001oo`02000TOol0
0`00Oomoo`09Ool00`00Oomoo`0OOol100000003001oogoo00Qoo`800003Ool00000008000=oo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`8000Aoo`800004Ool007oo000/Ool2000=
Ool00`00Ool00007Ool01000Oomoo`000goo00<007ooOol00Woo0`0000=oo`00Ool01Woo0P001Woo
00<007ooOol00goo00<007ooOol07Goo00<007ooOol017oo00D007ooOomoo`0002]oo`04001oo`00
0002Ool01P00Oomoo`00Ool000=oo`8001moo`40000000<007ooOol02Goo0P0000=oo`00Ool02Goo
00@007oo000000Eoo`03001oogoo009oo`08001oogooOol007oo001oo`8000Ioo`03001oogoo02Io
o`04001oogoo0002Ool01000Ool000000Woo00<007ooOol01goo00H007oo000007oo0003Ool00`00
Oomoo`030005Ool01P00Ool00000Ool000Eoo`04001oo`000006Ool00`00Oomoo`02Ool01000Oomo
o`0077oo0P0000Eoo`00Oomoo`0000=oo`03001oogoo00Ioo`03001oogoo02Moo`07001oogooOol0
07oo00008Woo0@0000000`00Oomoo`0:Ool01000Ool000001Goo00<007ooOol00Woo00<007ooOol0
0goo0P000goo00@007ooOol000aoo`03001oo`0000=oo`03001oogoo02Aoo`04001oo`000003Ool0
0`00Ool00002Ool20005Ool00`00Oomoo`0200001Goo00000000Ool00P000Woo00@007ooOomoo`80
00=oo`04001oogoo0002Ool01000Oomoogoo0P0037oo00<007ooOol07Goo0P000Woo00@007oo0000
00=oo`03001oogoo009oo`800003Ool007oo025oo`04001oo`000002Ool00`00Oomoo`020009Ool0
0`00Oomoo`0IOol100000003001oogoo00aoo`06001oogoo001oo`005Goo0P000Woo00<007ooOol0
1Woo00<007ooOol0:7oo00<007ooOol00Woo00@007ooOomoo`8000Moo`03001oogoo009oo`8000=o
o`03001oo`0000]oo`05001oogooOol00004Ool00`00Oomoo`0<Ool01@00Oomoogoo000077oo0P00
0goo00<007ooOol00goo00<007oo0000:7oo00@007oo000000]oo`03001oogoo01ioo`40000000<0
07ooOol03Goo0P0000=oo`00Ool00goo00H007ooOol007oo0002Ool01@00Oomoogoo00001Goo00P0
07ooOol007oo001oo`0027oo00<007ooOol09Goo00@007ooOomoo`@0009oo`05001oogooOol00005
Ool200001Goo001oo`00Ool00P0000=oo`00Ool00Woo00<007ooOol01Goo0P0000Moo`00Oomoo`00
Ool00008Ool01@00Ool007oo00000Woo0P007goo00<007oo00000goo00P007ooOol007oo001oo`00
0Woo00<007oo0000:7oo0P0000Moo`00Oomoo`00Ool00006Ool00`00Oomoo`0IOol100000003001o
ogoo015oo`03001oogoo00Ioo`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`0cOol00`00
Oomoo`0=Ool01@00Oomoogoo00004Woo00<007oo000027oo00<007ooOol017oo00<007ooOol017oo
0P0000=oo`00Ool06Woo0`000Woo00<007ooOol0GWoo0@0000000`00Oomoo`0=Ool00`00Oomoo`02
Ool00`00Oomoo`02000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo00000002Ool00`00
Oomoo`0[Ool02@00Oomoogoo001oo`00Ool00006Ool01@00Oomoo`00Ool01@000Woo00@007ooOol0
00Aoo`<000Ioo`05001oogooOol00005Ool01000Oomoo`0017oo00<007ooOol00Woo0P007goo0`00
0goo0P0000=oo`00Ool00Woo00<007ooOol097oo00<007ooOol00goo00D007ooOomoo`0002=oo`40
000000<007ooOol03Woo00@007ooOomoo`D0009oo`03001oo`0000eoo`03001oogoo009oo`03001o
ogoo00=oo`04001oogoo000ZOol200000goo001oo`03Ool20007Ool20003Ool00`00Oomoo`0;Ool0
1000Oomoo`001Woo00<007oo000017oo0P001Goo00<007ooOol08Woo00@007ooOol000Ioo`03001o
ogoo02eoo`03001oogoo00Eoo`03001oogoo021oo`40000000<007ooOol03Woo00<007ooOol017oo
00<007ooOol017oo00<007ooOol00goo00<007ooOol0@7oo00<007ooOol037oo00<007ooOol03goo
00@007ooOol000Moo`03001oogoo009oo`04001oo`00Ool2000WOol20007Ool00`00Oomoo`0eOol0
0`00Oomoo`0QOol100000003001oogoo00ioo`04001oo`000002Ool00`00Oomoo`08Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Ool000020002Ool00`00Oomoo`0/Ool00`00Oomoo`0@Ool00`00
Oomoo`0COol01@00Oomoogoo00000Woo00<007ooOol01goo0`0017oo0P0087oo1@0017oo00<007oo
Ool0<7oo00<007ooOol09Goo0@0000000`00Oomoo`0>Ool00`00Oomoo`07Ool30002Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool01P00Oomoogoo001oo`<003Ioo`03001oogoo01Yoo`03001oogoo00Ao
o`03001oogoo008000eoo`03001oo`00029oo`04001oo`000004Ool00`00Oomoo`0/Ool01000Oomo
o`0027oo00<007ooOol07Woo0@0000000`00Oomoo`0@Ool01@00Ool007oo00001Woo00<007ooOol0
0goo00<007ooOol00Woo0P001Goo00D007oo001oo`0003Uoo`03001oogoo01moo`03001oo`0000]o
o`03001oogoo00Aoo`80021oo`<0065oo`40000000<007ooOol047oo0P000Woo00<007oo00000Woo
00D007ooOomoo`0000=oo`07001oogooOol007oo0000HGoo0`002Woo00<007ooOol02Woo00<007oo
Ool07goo00<007ooOol0<goo00H007oo000007oo000WOol100000003001oogoo011oo`04001oo`00
Ool30008Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo05Qoo`03001oo`00009oo`04001oo`00
0003Ool200000goo00000003Ool01@00Oomoogoo00001Goo00<007ooOol0F7oo00<007ooOol09Goo
0@0000000`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool00`00Oomoo`1HOol00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0QOol00`00Ool0
000hOol00`00Oomoo`0UOol100000003001oogoo01Uoo`<001=oo`03001oogoo03Aoo`03001oogoo
01moo`04001oo`000003Ool01000Oomoo`004Goo00<007ooOol0PGoo0@0000000`00Oomoo`0AOol2
0004Ool30005Ool20008Ool01000Oomoo`00Ggoo00<007ooOol00Woo00<007oo00002goo00<007oo
Ool08goo00<007ooOol0H7oo0@0000000`00Oomoo`0AOol20002Ool2000<Ool01P00Oomoo`00Ool0
06Yoo`06001oogoo001oo`0017oo00<007ooOol0;7oo00<007ooOol0;Woo00<007ooOol0:7oo0@00
00000`00Oomoo`0BOol01P00Ool007oo001oo`8000Qoo`03001oo`0000]oo`03001oogoo05Ioo`04
001oogooOol20007Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`03001oogoo05Aoo`80009o
o`03001oogoo02Ioo`40000000<007ooOol0QWoo00<007ooOol017oo00<007ooOol01Woo00D007oo
Oomoo`0008eoo`40000000<007ooOol04Woo00<007oo00000`0000=oo`00Ool00goo00<007ooOol0
1goo00H007ooOol007oo001MOol00`00Oomoo`0;Ool01000Ool000001Goo0P00Q7oo0@0000000`00
Oomoo`0KOol00`00Oomoo`020003Ool300000goo0000001ROol20005Ool00`00Oomoo`02Ool20004
Ool00`00Oomoo`28Ool100000003001oogoo01Qoo`03001oogoo009oo`05001oogooOol0000BOol0
0`00Oomoo`1@Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0001WOol00`00Oomoo`0VOol1
00000003001oogoo01Aoo`80009oo`09001oogooOol007oo001oo`0000Aoo`05001oogooOol00003
Ool2001OOol00`00Oomoo`04Ool01000Oomoogoo0P001Woo00@007ooOol005Moo`03001oogoo02Uo
o`40000000<007ooOol07Goo00<007ooOol00goo00D007ooOomoo`0006eoo`04001oogoo002?Ool1
00000003001oogoo01Aoo`03001oo`0000Ioo`<0009oo`07001oogooOol007oo000017oo00<007oo
Ool017oo00<007ooOol0Egoo00<007oo00001Goo0`0027oo00@007ooOol008=oo`40000000<007oo
Ool05Goo00<007ooOol00Woo0P003goo0P00IWoo0P001goo00@007oo0000009oo`03001oogoo08=o
o`40000000<007ooOol05Goo0P002Woo00<007ooOol02Woo0P00Igoo00<007ooOol017oo0P00R7oo
0@0000000`00Oomoo`0HOol00`00Oomoo`06Ool30002Ool01000Oomoo`001Goo00<007ooOol0Hgoo
00<007oo00000goo00@007ooOol0009oo`03001oogoo08Aoo`40000000<007ooOol08Woo0P000goo
00<007ooOol0Igoo00<007ooOol01goo00<007ooOol00Woo00@007ooOol008Aoo`40000000<007oo
Ool07goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0Hgoo00<007ooOol0Rgoo0@000000
0`00Oomoo`0FOol00`00Ool00008Ool01@00Oomoogoo00000Woo00<007ooOol0Igoo00<007ooOol0
37oo0P00QGoo0@0000000`00Oomoo`0TOol00`00Ool00007Ool00`00Oomoo`1_Ool00`00Oomoo`25
Ool100000003001oogoo0?moobUoo`40000000<007ooOol08Goo00@007ooOomoo`80009oo`04001o
ogoo001WOol01@00Oomoogoo00002Woo00<007ooOol0PWoo0@0000000`00Oomoo`3oOolYOol10000
0003001oogoo02Yoo`03001oogoo06Qoo`03001oogoo091oo`40000000<007ooOol0WGoo00<007oo
Ool0R7oo0@0000000`00Oomoo`2JOol00`00Oomoo`2;Ool100000003001oogoo02Yoo`03001oogoo
0?]oo`40000000<007ooOol08Woo00<007ooOol017oo00<007ooOol0o7oo0@0000000`00Oomoo`3o
OolYOol100000003001oogoo02Ioo`03001oogoo06eoo`03001oogoo08moo`40000000<007ooOol0
ogoo:Goo0@0000000`00Oomoo`0[Ool00`00Oomoo`3jOol100000003001oogoo02Aoo`800?moo`=o
o`40000000<007ooOol0:Woo00<007ooOol0ngoo0@0000000`00Oomoo`3oOolYOol100000003001o
ogoo02Qoo`800?ioo`40000000<007ooOol0ogoo:Goo0@0000000`00Oomoo`2LOol00`00Oomoo`29
Ool100000003001oogoo02Moo`03001oogoo0?ioo`40000000<007ooOol0ogoo:Goo0@00003o000]
00000001\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-0.0419901, -0.0250053, 
  0.00362535, 0.00586594}},
  ImageSoundCache->{{{0, 299}, {179, 0}} -> GraphicsData["MacintoshSound", "\<\
00400@050000X001P540000001@00000000L01m<000000000000000lShj>Si2@
Shj=SHj>SY2@Shf=S8b<SHf<RXR8R8Z<SXn?Shn@TY>CTi:AT8n>SXf<S8^:RHV9
RX^:RXZ:Rhf?TIBGV9NGUI>AT8j;RHJ3PX:3Q8F7R8V;SHnATiBEV9VIVI^MWI^G
TXb7PWilNg]jNgeoPXJ:SY>GVYbNWYjOWijNWYbJUI2<Qh1jMG9bLW=fNGf1QhjC
Ui^PY:JWYJ>RXZ>RWiZCSHZ6OgQcKVe]Kg1bMG^1RI6DV9fQYZZ[ZJNWZJRUXI^F
TH^4OGI`KVi^KVa]LWMnQhfBUibRZ:ZZZZ^/ZjVUX9^FTHb5OGMdLFi]JVY/KgAl
Ph^AV:2UZ:^/[:f^[JZUX9^FTH^5OgYcKV]XIFAVKG=kQ8jFWZBY[Jj][Zn^[:ZV
X9ZET8^4O7E`JF=PGf5VKWR3S9BNYJV[[[2a[jf][:RRWIZFSXIoN6mWH5]HFF1Z
M7j8TinWZZbb]KJe]K>_ZZJRWIN>QWecJF5IDDeAG6M`NhVHXjbb]kVi^kbk]k6[
Yj6HTH^2MVaUGEA<BTiFHFekRi^W/K_0`L72`[jj/ZZTWYJ=QWmgKfILDTa9B4eH
IWF6UjFa^l?7b<O6a/2dZZJQV8f7PgabJ5iFCDE4CEMNK82AWZbh`LK7b/g9_[F_
YijGT8b7OWE^I5M>B4A8DEi^NX>H[kRj`<WBeLc2_[NXViRBQgafLFQKDU5>ATEB
IgEgOYVb^;W2cMKHdLS1]ZFHU8f0NWM/HEeKDd]7BEMUJg:3V:Vg`/O=f=kEbKnf
ZijAR8B1MfMLF5MBB454Df9/M8BG[/K<a]7Of]39_;>`WXZ9Q7EZHUUDCdU5AU1R
LW^;XZjga<K3b/g0_l>m]j^DLUUBCTLi?F63Qgj5WJf/TWfC];:DU/CG_:>TXiR@
PW9LCFB2PVmbT9EhFUakQ7EbV<C5]kk>e]6iX9:5RZ>XO4M?N7Q4;5EdM6n7ZZN?
Qj2cYj:X`=?@e;B;OGJE_:]XD81kAb<eL6YUPZB`SGj5TiVYcm;Ae<o?TVIXKZW=
WV5WRF0P7F6BMh6Z^ZA/J7ieQl?M`/KEcZmSGX:Fa]:KFVahB1X]S9b8Y:fPPeUL
Lg>UhmRb_]W0P4M/RJCOd95GNG8f8TVXWiNiYi1[CF5_MkWKe;BdfJ=QD7N:[>g9
KdnEMBd[H/:MWlNPOe=6JfUjc]_C]ZoIRD]MO8nmm/iPA:Id8SI__I:LbYU[CdiU
I8SPi<nj[L:2D6ImSl3fgfLgV74U=fW2WYGBZFQBAF5[K]Wae<RG/9IEJ7F0_^3T
UBijQRTkHZFnUlnoKeY?IFEJ/OoKdiN@/TeZNVJQc_[<F4f>ABMAM<Na]]F:I5UN
Gdf<g^kJ]hnFNeejI86hho^^CUYm;2IIYm6Ja/=`EV9]CUjcmmfm[82MJE>ENhNc
k>N8C7]e5CQe^[6AejaWM7IQFG3=lj^^YhNEH7Z:Gj36e/:EMg947V5RUZJci9N<
SFaBCWfj_[C=WiZSJH]hD9fedMBYNVQN;4A9RZjNf;^bV4mGEejR/jfm]KNYRH=P
BhBkh=:nRV9i@CY;HiZLf=ZGRgA[FDn@XjC3aK^FTYEDEY>V][c:VdemOTQDGIJ/
VKbORhiVL79iYIbK[:RJRYF8N:2n]In[_7aKP71KFGNOPXB8LHYjNI^4Ri:I^Y>4
XJ2ZXJ^mTWnASHR@Yj^AQHZ9L5MFFVUgRjn/VYJ6Lf5ROHj[d=gE]HimMG>1U:FW
YkNaTgMZLV=?JGmoRIJHPGAmO7f:UY^IVjB//:fYZ:>CQH^BSXfCViV<QWi`K7Ao
PH23PGj1QhImN7Z1TjNc^;>TUYVSXIRLYIZ@UXijMGalMWb8PGJ1S8=eKW9mR9NV
Zj6@S9:CVJR_ZZBSX9>6OGaoQHV=TI2:QH5hKG1mRIFLVhj4QhN5T9^NX:BWXiRA
TI2<R8^@RX>8T8]oO8:7Q8F:RHJ<THb5RiBIWIjKUI:CTY2EUi27QXN2Q8f=R8V;
QXB9RhR:Shf:T9VGTi>@RXV<TYRJUiBDSX>3RX^7Ri6@S8n?R8F:RhN8Si:ATY2<
Rhf?T8j=TYFDT8^9RX^=T92?SHb=SHb<Rhb>T92>SH^;S8f=RhZ>T9:BSXZ:S8nA
TI2=S92ASHb=S8^>T92>SHb;RhV7RHb=Si>BSX^;S8f>T92BUIFBT8j:RHb?T8n@
Shb8QHF7QhN;T9:@SHb9QhZ?TiFFUYFBShf;RXb?TYBBSh^9R8J5QhZ<Si:ASXZ7
QhZ?Ti>CU9>@Shb9R8^@Ti>BShb;RXV:RHV=TY>ASHZ9RH^>SXnBTi>BSXZ6Qhb@
TY>ASXf<RhZ9RH^>TYBASX^9RX^<SHjAU9B@S8V7RH^?TY:AT8j>S8V8RXfBUI>A
SX^8R8Z<SHnBTY2?RhN6R8^?TI:BTY2<RHV<SI2CU9>@SH^:Rh^;SI2@Shj<RHR9
RXb?TI6AShf<S8b;SHnATI2?SXb;Rhb>Si2@T8j<Rh^=SHf>Shj=SXj=Rh^<S8j?
T92>SHb=SXj=SY2?SXf=S8f>SHf>SHf>SXj=SHf=SXn>SHj?SXj>SHb=SHb>T8n=
SHf>Shj=SXj=S8f>SXf<Rhb<S8f>Shn>SHf>Shn@T8n>SXj=SXj=S8b<S8f=S8^;
S8b=SXj>SXn?Shn>SXj>SXj=SHf<SHf=SHj>SHf>SXb=SXf=SHf=SXn>Si2>S8f>
SXj>SHf=SHf>Shf;SHj>SHb<S8^;RXb>SXnATY6@T92@Shj=S8^:Rhf>S8b=SXn>
SHb<S8Z:S8f=Si2@TI6?SHj>Rh^;RXb>SHfATi6?TI6?SHf<SHj;RXb=RXZ=T8j;
Rhb=S8^<SXn<Ri2ETXn@TI6?SHf?Shb:S8f:RHb?T8n<Rhj@SXf>SXb<S8f=S8Z:
SHn>SHj=SHj>SY2BTI2BTi6>SHf>SXj<S8f9QHN:RXZ=Si2@Shj?TI2>T9>?Rhb>
SXj<RXb=S8b@T8b:Rhf>SXb>T8j<SY:CTY>DTHj:RHb>RhZ@THf=SXn@RX62QX:0
PXB3QhZ;TI^RXZFZZ:BRVI6BSh9oQ7ieLgEhOX:1P8J;RHZCV9VRZ:JW[JVPX:2F
QGajN7QcJVmlOWj@XJ6BQHJ>SX>0Sj:SVYna/jJJW:BNPg9lQ7Y[IgN8OfmnUYB4
NX2EW8n4SjB_YYRNYj:LW:fjYH5dNWeaF5MjSWefTJRRSG]kQ8AnPYJXYIZO[:nW
WZFh]YAgLWMbGeAWQXj7TJb_S75eOXB4O8BR/[BbYY^AQHNK/kRIMGN7O5iFKX^@
Qi>a/XidMgeeKGfM[Zj]ZZ6FS8J:TJFiZ8IoRX1UE662TXjH/kN>JVaiNG=hS:6]
]KJYThB5TIZbaJQlM820KUMOQYVCUZR]SfeXM7I`NI:W/;2`[Z2CT8b=XkFQOGF3
R7=GGhFHUI>R/IU^IG9jN7N:Xjnb/JVKT8Z9TZZmZhAeQY=lG5mnUi>2SZRFLFE_
OWafQ9nh^:fZXIjFQhVK]KF;O9FIRF15IhR9NH2WZ8]iKH:=M7B;X[jhYj>MY9R1
RZ2_W7j4Uij7G5MbO7]ePZ>XVY2;S8IlLgFCXiVFVJBbYHnCZ:nPTiJOX8ITG6Y`
IF=]OIJSV92DTh^8RH^AU9>LZJVRWjBZZ9jCUJ2LQG1SGfEWGUi_Pi2GU9BKWifJ
VYfPXZ2OW9J>S9NOWYnPWinGP6iWI6=XKg=iOG]lQ8fATiZU/KF/Xj:RWibJVinQ
WijKThMmM6aVI69RIfieNgf0QXjBUin[];Rc[jn/YZ6OWj6RWYVCR7M[JVMTHf1P
JgIdLgMmRiRLX:Vc]kNi^[F^ZjVXYIZ@SXb4NW1YIfALF5aRJ6eaNXbKWjBY[K6e
/Zj^[k2`[jZQVYJBSHMiKFYWH5M?CeeYK7>1T9fVYZVa][Jf];6^[Zn[Y9nLV9RD
Q7E^If1LE4aAGFM_MX:BX:^c]KJh]K2]ZJ>PXZ6LVYbLV8j4OGQaIUYEEeMJHfii
RY^X/;>c]KFbZj>PXZ2LVi^JViZDSHImMF]PEUIKGVA]NHVEVj6[/K6a/k>`[:NS
Xj2IUYNESHN1Mg9^I5eOHf=WKGB1TIRLYK2e]K>b/JfUXJ:QVY:@T96:O7IhLVMQ
Gf1WK6mjRiJMY:JV[:nZYZJVZJROVYfMVI:9QXIlKFIRGf5SIW5lPY2OX9jPXZZe
[ZJZ[J^ZXiBDV966OWEaM6iRH6I_MgQgPi6KXZ2JX[2c[JBNXZfZV92FVi>3MGAk
N6aSIW1hNWUkPY2OXYbIXJb]Y9bQZZ^TW9RLWY:2N7EcKVEOHVihNGN2TYVOZJZU
Xj>RXjBPWJ2KT9:OWi:3NWenKE]HH6ifMGb?WZZe/:6OXJ2PWYVMYIf=RhnAU9>2
KVYeMVeRF6J6TXR<Y;Fg/:JW_<^iXIfTXY1U@U=cLei@H9JeUWAiTIjHPX2/d<6T
Vi^SWg1;HH^^a:b5QYfQRFULMYN=IEAcVYMeKiW2bKN//KncOEUWP9fiXV=>JXZ6
JV:<aL>:IH:]Vf=LS[^oZJ:_]9mcGVn</ln^JTQMQhEOEhc4`8QPO9n;HVRPclb/
Yk>[SV]KLig1cimJ?UR<Rf1WXlJdPFN:WW]FJJ>n/:Ja_:InLW:4[/_:SdPlJIIj
CVnjdYMUQJZGI522ZjZUYl;:VFa/NIK1e;I_@EB5PTaDS[k4PFRLZ8YOHJ>bWj>b
`ZMlJg:;Ym3DT5UCMIIM>7bg_8QHQk2?HUfQaZ:FYlJlR6mVNj6kg;9EDX:POSUF
YKV<Eg:ZVF5DU<jeVZ?5cYR2Mf1n/MjhC4RB[7lmGZj/MTb0`YYGAXk6Vi_8e/>Q
UG5JN:KSZCMUYjaa7Fk1XGI9V]IdAeJH/7b_fM3AYY]hCWJ_ih/fVZfE@B2[[FmP
KM>d@UYdR8Ige?7:^Jj]LVRJb<]8H<6SKP1C_gYQHZSHJRigSXR4Tm[I`M2hPfV=
eLiIA;O7NaL_^He=Ei3?OE>0NfelS/oC]NCETFJ2d/Xn@lcBV2HmYG1IIXRVLFVR
M5AiZ=fb^N[BUUn2gIHLQ/^iMRnLVT9DMj^4@iJ/HEa/^mc2fLc9XH^iJ2f<_[F8
F8QmCE9LVY=PNg]eLGnj]<cme[B?X:94EYNZ/XbSYE]NGfQdEhB6JH61Vi^^jLk7
^jjQ93RKRib>/]Q]IGI^P3mSQ4ilU/W9QmOJ/[RY_F4[KWZ?PIKGTgjCNVPjFGeA
GHo1aZ_Hh;JXYia1>HZ;PWRQg9egQ9:C@T=iIFB8/MWE`moBYI=IDEhhJhfH/j>m
[89jEeY7>g^<Vk_Fg/gGek1^EV]NC5:</i6V_Zf@JgEO=3i^];joi=c<^jUn?TIT
Kg9fR96GTY:KQH:9OGf1TZBdb]CBa:N0G59DHG23WiR;RWI_JVj>V:6^WYRAT:>X
]/:aXHj0N6UbOW=]NH5mNWMjSjNd]JJAPWj8W:RTX:NUSgYfKF9[O8f@QiNWW8nE
WiF8RH5jOH2AW9NKY:2ESGiePHj;SYnXWYBCT8AgNX>0OXR=SI2DUYVITH=oPhR>
SiFPViFKWYB6QYBBQH:5QGn1RhZ8SI>ESX^DVYNDUiZFT8V2Q8J0PhN7RXb:RHR9
T9JDU9VIUYVGTI2ATHn;Qh=oOhB;SHR8RHV8RHZ=Si6FVYZJVYNDTi>?R8:1PhJ8
S92;R8b<QXB7Rhf?UYnNV9FFTi6?RhN6R8Z;RH^>RHB8RhR7RHV=U9ZJU8nATY6A
TXn:RHf>RHJ8RhnBTY2<QXJ8SI:BTI:CShb;RXN8SY:?S8^:RHV:SHnATY6?SY2B
U9JIUi2;S8Z4PXN:Rhb=S8R6R8^=T9>CShb?THj<T9JJVIB>RXN7QhR;SHj?SX^:
RHZ=Si2BTi6=S8^=Shn?T8f:RHZ;S8f=T9>AShn<R8V;SHj>RXZ>Si:DTHjBTXn<
R8B7RhnCUI>CThn=RhN5Qh^=SHb:Rhj=Si6@Si2@Si6@SXj?T96?RXV9QhR:Rhb?
T8nATHj>SHb>T8n?TI:BTY6@T8n;RHV8QXF6R8Z:Rh^;Rhb<SY2ATi>CUYVFTi>A
T8n=RhZ:RH^;RHZ:QhN9R8J7RHb@TY:EUYBDThn?Shb<SXf=Shf;SXj<RhV7RXf=
Si:ATYBAS8b9QXR9RXnCTiJIThj<QX62PH67SI6GVYNHVIB@Shb9S8b;SHf;Rh^5
Q8F4Qhf?TINKVYVET8j<QhF5QHR;S8b>Si2@Shj?Shf=SHj@TI2@T8j>ShnATI6B
TY2=RXJ5QhJ7RHR9RHR7R8R:SY>FVYfLW9bIUiB@S8^8Ph1lN7QiN7^0QXjFVj2V
ZZZ/ZZFRWiNARWieKfMSI6IYLgj7TifQYjj_/KBb[ZnZXIZ>PGYcJFESH6=XJg=o
RIBPZ;2g^KRg];6]YinFRWibIEUCCdmJI6j0T9bZ];>i_[Zm_;>^ZYfCQg5TFdm>
D51JJgJ6VJ6[^[k0a/>k_;NZXYZ9OgISEeA>Be=IHWR:U:B`]Kk3_KZk][BaYib@
PWEWFE9>Ce]YLGf>U9n^Z:Nc/k2j]JJ`[9VHSgeiMVANHEaPJ6eiRIFOYjVYZ::H
Ui26THj;WIfGZ:nLYjF5TX]]LVaNIViWLWmoT9VIXYnPXYVMU96OU9VTVj:bXiRY
T8BHK5i^DE9REEUjPXZZ[;G7_KV^XZ6:QhQmTInHX:ZNWZ:0M7EMH6=GH6]eP8fK
YZng^k6c]YRBTGUmR7EbRXJ6WiF=XZ>CVYIoQHIaLgedNi6<TZJQWjJKS8b3M7Ig
LW^9RI:QY:Re/JVbZifLSGajM6EUIf9^NW^4TIFKY:6OY:2JV9B>Shn=TINLWYjN
W9RDSX=oOgAbLV]/LW1bPHN=W::U[k:ZZ:FKUY:9Q8N5PhR8R8j@T9>DU9JETXn8
PgefL6i/KgMnQiBMYk2e]KJcZjBKShEmMG1bM7R0RI2IWj2QX9ZCRh5jM6m/KW9j
Q8fGXJR]/:fZYYfDS8EoOWajO7j0QHZ<TIFGVifMViRDT8^6PX1nOWn0PhN:SY:D
UYRIVY^JV9RFTi2>RXR5PX20P863QHR<Si:DUIFDTY2=Rh^:RX^=Si6CUIRIV9JD
THj;R8F4PhB6QhV;SHn?T8n?Shj>SXj?Shn>SHf<S8f=SY2ATiBDU9>AShb9QXJ6
QXN8RH^<SHj?T96@T92@TI6@T8n>SXj=SHj>SXn?SXj=RhZ9QhN7R8R:Rhf?TI:B
TY:BTI6@T92?Shn@TI6?SXf;RXR7QhR9RXb?TI:BTI2?SXf<RhZ:RX^=SHf>SXf>
SXj?T8n?T92ATI2@Shj=SHb;Rh^:RX^;Rh^:RHZ:Rhf>Si2ATY>CTY2>S8Z9RH^=
SXn@TI:BTI2>SH^:RHV:S8f>T92@T8n=SHb<RhZ:RXb=Si2AT92@Shn>SXj=SHf=
SXj>SHj>SXj=SHj?Shj>SHb<RhZ;Rh^<S8f=SXn@T8n=S8b<SHf=SXj>SXj@TY6?
SHf=SHf=SHj=S8j?Shn>Rh^;RXZ;Rh^<SHjATi6@T8n@THn>SXf;S8f=SXj;Rhb<
SHj>SHf<S8j@TI6@Shn@T92?SH^:R8V:Rh^:RHV:S8f>Shj>SXj@TI6@Shj>Si6A
T8n>SXn?Shj=S8^;S8f<S8^;S8j>SXj=S8b<SHn@SXf<S8j@T96@SXb<SHn@Shf=
SHf?T96BTHf;Rhb=S8V9RHZ:Rhb=Shj=Si2?SXn>Si2>S8j?SXj>SXn?RXN8RHZ=
S8f?T8j?TI>EUI6?Shn?T8n>SXf:RHZ:S8b:R8R7QhZ>T92?SXf?Shn@TY>BT92A
U9BASXf<RhZ8R8^<RXR9RhnAShf>SXf<RXZ=Si2@Shn?SHZ9RX^>Shn?TYBHVYNB
SHV6QhR9RHZ8QhV;Si:@SHZ:S92CU9FETi6?SXf<RHJ5QhV;SY2BUIFASXb8QhR9
S8n=S8j@T9:?Rhb=S8f@TI>ETHf@T8b:QX>5R8F6SI:GViVEV9N@SH^9SI2=Rhj;
Ph23QhZ:Q8F=T8b:SY>FTXV9V:6LU8n@UYNASYRNUXV4PhF2LfQcQ8b@SXZ:Rh^;
UIjMVYNGWZJSWibHTi6?SHf9Ng1`LG5cLgR7TYBCTY2<Ri:LYjbTWZNa[jJBPhJ>
SH^AT8=dIEeZNG=`O8>4R8Z<Vj>CRI:KZ;Fa[:nZVYBEUZ>[WhmiHE]TLgeiKfae
P8B8SY>HU8N5TjJ`/JRIUI21N8JR_LVo/:bTQ5@iCW^LV6mOO9>@O6]gX:EjHGFO
bM6cY::@LEMOQkO7`;RYWiF7TjVHLTi1Kj6MO6=PNhegHW2A[;2HS:Bm`;>QUiV;
H4idYL[@ZHMoNGV7XJjCJ4a=Lhj2MX>IY9IbIhNY/jVJXK_3]J>ETHMZC4ibWL31
WhV1MG9jS:FWREQ5IhnSXI>CWif:OHNO/:bIT9JNWYB>TiR=KeQKM9^`YIV?QXN7
QY6TXH1XKXBS[8moTinAOgAnXk:EP96U[J>2LhZHPfmZM8jNUY2CSX5kQije^JJD
Pg9UHGRM]k>HPX25PGAeSZjhWh1kSJFTTHN7Rh=aKhFLX9:2QI>@O7F1UZVWVj6Z
TW9WKiVlYXAoQi6AN6f@/JbGNVn6Uhj9TIZLRfaVQ9n/YX^1R8F1PX2>Z:VMUhV5
U9R@V:6LTGeQHhZQWYJ3OI2BNW>1T:6QS8JEVY:>U9jSV7iaOXjJWinKT7i`KG^>
VJ2RWi:3OH>BVHn5QXb;PG^3VJRORWn6SXn:RYbc/9AnN8BBR7IjTJ:SUH>5T8Mi
OXbKYIN3Qi6<QXN9TYR7N8BFX:JSWIjHOFUeR9ZRTh:2Q7moRiJLV8=dPI:NXj2I
U8aiKGF5UZ>WYIfAO7:3V:6QTH:3QhF9Uj2KSgQZNXfATY6@THn3NhZJW9R>Qi6M
VI>EUYFBQ7IkR96IW9J?S89jQ96IWiJ7PX>5RXj<Rhn>RX^<T9RMV96=RHN8R8bD
UiB<QXZAUiR@R8J7QXJ8SHj<QH67SY2@T9:EUiBBUYVGTX^6R8V2P8J>TiF>Qh^@
T8n?SY2@RHF<TiJESHN9RhV9SI2CThb8RhnATXn=S8b;SI2BTi6>S8^9RH^<SH^9
RXb>Shj?TiJASH^:SY>ASXn@SHb;RXfBShZ8R8R:S8f@THf:RX^>TY6@TY6>Si6A
TY:<RH^=S8f;RXf>RhZ;S8f>RhZ>Shf=SXjBU96>Shj?T8j=SXj;RXZ;SXj=SHf;
Rhb>TI:@SHf=SHf>Shn>S8Z;SY6@SHb<S8f<Rhf@T8j<Rhf@T8n>SHj>S8^<SHj>
SHf=SHf<SY2AT8j=S8f>Si2@SH^;S8f?SXj>SH^:Rhf?Shf<S8f>Shn?Si2?SXj?
Shn>SXf>SXb;Rhb=SHf;Rh^<S8j?Shn=SHf>T9:AShn>SHj?Si2?S8Z:Rhb<S8b<
S8b=SXj?T8j>Shn?Shj>Si2?SXj=S8b<SHb;Rh^:Rhf>SXn?SHj@Si2ATHn>SXj?
T92>SH^;Rhf>SHV8RXZ<SXf<SHf>Si2@T96@T92@Shn>Shn>SHb=SHf=RhZ;S8b<
RhZ;S8f>SXf>SXnATI2>SHf>T92?Shj=SHj?Shn>S8Z:RX^<SHf;S8b<SY2@Shj=
S8b<SHf>Shj>SP\>"]},
  ImageCacheContents->"Sound",
  CellTags->"S2.1.3"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[16]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell[TextData[{
  "The relative error or distortion is indeed less than ",
  Cell[BoxData[
      \(TraditionalForm\`20  %\)], "InlineFormula",
    CellTags->"S2.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.3", "3.56"}],

Cell[CellGroupData[{

Cell["Sqrt[(mdata-%%).(mdata-%%)/(mdata.mdata)]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(0.199871578567326402`\)], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["\<\
Of course, we know the error all along from the energy \
distribution.\
\>", "MathCaption",
  CellTags->{"S2.1.3", "3.57"}],

Cell[CellGroupData[{

Cell["Sqrt[1-ewp[[781]]]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.1.3"],

Cell[BoxData[
    \(0.199871578567359602`\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S2.1.3"]
}, Open  ]],

Cell["2.1.4 Local Cosine Packet Analysis of a Sound Signal", "Subsection",
  CellTags->{"S2.1.4", "4.1"}],

Cell[TextData[{
  "To illustrate the use of local sine and cosine packet transforms, we study \
another sound signal (see Wesfreid and Wickerhauser (1993)). The signal is a \
recorded sound of a cricket in the file ",
  StyleBox["cricket.dat", "MR"],
  ". The sound was recorded at a sampling rate of 22050 Hz. "
}], "Text",
  CellTags->{"S2.1.4", "4.2"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.1.4", "4.3"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.1.4"],

Cell[TextData[{
  "This loads the package ",
  StyleBox["Miscellaneous`Audio`", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.4", "4.4"}],

Cell["Needs[\"Miscellaneous`Audio`\"]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.1.4"],

Cell["This reads in the data.", "MathCaption",
  CellTags->{"S2.1.4", "4.5"}],

Cell["\<\
cdata = Get[ToFileName[{\"Wavelets\", \"Data\"}, \"cricket.dat\"]];\
\
\>", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.1.4"],

Cell["There are 4096 data points.", "MathCaption",
  CellTags->{"S2.1.4", "4.6"}],

Cell[CellGroupData[{

Cell["Length[cdata]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.1.4"],

Cell[BoxData[
    \(4096\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S2.1.4"]
}, Open  ]],

Cell["The sample mean is subtracted.", "MathCaption",
  CellTags->{"S2.1.4", "4.7"}],

Cell["cdata = cdata-(Plus @@ cdata)/4096.;", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.1.4"],

Cell["This plays the cricket sound.", "MathCaption",
  CellTags->{"S2.1.4", "4.8"}],

Cell[CellGroupData[{

Cell["ListPlay[cdata, SampleRate -> 22050, PlayRange -> All]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
22050 4096 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
8181818080818180818181808181818081818080818180818080808081808081818081818180
7E8187837C7B7E848983767583908973708894817278858D8672768B887F7F787E8C84797C80
84877F787F8585807B7B8487807B7D8287837B7D8384827E7C8086837F7D8184847F7C808483
7E8182818182818181808384817F82838282818182828182828382828081838381808282837F
818382827F828281818182838080848180847F7F85837D7E85857E7C8187847A7B89887B7883
8A84797A868A807A7E828484807F7F818282818180828281807E8084837E7E8384817E7F8284
817F828282828280808182818181828281818181828281818182818181818180818182818181
8181818181818181818181818181808081818180808181808081818181808080818181818180
818181818181818181818181818181818180808182808082828081828180808182817F828580
7B8189837A7C86877E7A8387807C82847F7D83857F7C8186817B8086837D7E83837E7E828280
7F81817F7F82827F7E808281808081817F7F8181807E7C7F87897B718191847078908A707591
8F75728289817F868475778F91746D8A977C698097876F768D8B77788987787A89887879898C
7B74828D82777D89867A7B85877E7B82857F7C8186827E82857E787D8C907C697A968F787580
8685848277758D987965829D8B6A6B8DA2845F759890777885867A7E8F8872758F9177708995
806E7D928976798A8A7C798488827F82827D7E878D81737C8E8C7A75868F8074828D8277818D
83747D8D887777898D7B74858E82757B8A8D7D75818A827B7D8488807A8187817D8184827D80
86847E7E8383808084847F7C8387827C7D8489827A7E8686807E8183817F808284827F7F8283
828080818180818281808081818182817F808282807F80828180808181818180818181818180
8181818181818281818181818181818181818181818181818181818181818080818181818180
8080818181808081818080808181818080808181808080808080808080808081808080818080
8081818080808081818181818181818081818080818180808181818181818081808181818081
8181818181818181818181818081818180818181808181818181818181818181818181818181
8181818181808181818181818181808181818181818181818181818181818181818181818181
8181828181818182818181828281818282818282828282828282818282828182828282828282
8282828281818282818182828181818181818282818181828181818281818182818181818181
8181818181818181818181818181818181818181808181818181818181818181818281808182
8281818181818181818181818281818182818181818181828181818282818182818182818081
8282818081818180818080818282807F8183817F8082828080818181818080808182817F8082
82807F82858179808C80708399826378A0996C5C81A6986B5C7BA4A2735472A3A7775A769992
7C777C8886767D8E8A7B6E789E9A615899B4804B66B0B25E4192C7883C60B5B7653B80C89C40
4FADC272396DC2B14E3B9BD087335BBEC15C2F87D69B314BBCCE65257CDDA62C3EBCDA6C1D6E
DDB8352CADE5821C56D5CE4A1D90E99C2042CADB5A1780E9AD2931BCE6711463E2C63B1FA1ED
8E1949D4D9501686EDA72036C3E56C1678E9A62244CCD75C1B80E7A6223BC7E1641470E7C135
22A6EF8E1748D5DE581279EDB82B27B2EE7E1259DED4471890EFA21E3ECDE05E147BEBB4282E
BAE8731467E3C63B1FA0EE911847D2DB541482ECAE262FBBE9731161E3CA3C1A9AEF9B1B3DCB
E464106CE8C2331EA3F093183FCEE35C0E73EBBF2F21ABEE86144CD7DD55117CEDB32827B1ED
82134FD8D9511380EAB62F24A9ED8C1946CCDE671864DDC8421F8DE2AD372E9FDF932946B8D3
7B2F57B7C5723A63B2BC754268A8AD80585F91AB9564507BB1A7664C7EA99A725C7DA68E636B
909E806374979573698397897272889081737A88897E787F88847C7B8287827B7D85857E7B81
87827C7D85857E7A8287827A7C85887F787F89877A747F908B756F8395887172898F8474748A
8E7C7A7E828884797D8587827C7B8488817C7E8486827D7E8385827E7E818483807E80838481
7E7E8285827E7E8184837E7E828482817F80828280808181828180818181818180818282817F
8083837F7F8284827F8183827F8185857F7E8185847F7D818685807D808686817E8286847F7F
8486827E8286847E7E8588827C8087877F7C8388857C7D8689827B7F89887D79838A857A7B86
8B82797E89887C79838B85797A868B81777E8A887B77828D867878858C82777B888A7E787F89
857B7A8388817A7E87857C7B8387817A7E87867D7C8287827C7F85867F7C8287827B7E87877E
798188857B7A858981787E88887C78828A84797B868980787F89867B79848981787D88877C77
828A83787B88897D778089857979858A7F777E89877C77818A84787A868A80777E8A87797885
8A80777D89877A78838A82797B868980797D86877F7A7F87857C7B84867F7B8087847B7C8587
7C78858D7C7281898B896863A0B16B4878B0AA6B4B78A298836F657E9B91756A799291786F7D
8B8B7F747A898B7F777B888B7D737D8B8B8179747494AC743C7FD4982C51CAC84C27A2E2731A
7CE69B2150D8CC3E1FA7F07C0C60E9CA311EB3F1740C6AEFBC2629C1EC610B7EF4A7163DD8DB
4219ACF272096EF2BE2624C2F3620070F9C5231CBCF56F0C85FA960C3FD6DF5A2291C56F5BA1
A5685188C296334BC5D251198EF3A01240DDDE4619A8F27E0C52E5DC400D9CFC8C0A50E7D536
14AAFA820558EED33116B3F8730368F5C5221FC3F768006DF9C32019BCFB74005AF2D32F10AA
FE87044DEADA350EA5FE8B064AE7DC3A0EA4FC89064FEAD63310A9FC810357EFD22E12ACFC83
0451EBD7360DA0FD930A40DEE347078AFAAB152DCDED5B0578F6B71D25C3F168066EF2C0251F
B9F2720765EEC5281CB5F57B085AEACB2F18AEF7820851E7D43411A4F98F0A47E3E045098EFB
A5132FCEEE5B0373F5C32619B2F984074CE5E0470887F9AD1929C4F36F055CEAD73C0D93F9A6
162EC8F0700A5AE4D542128AF0B0252AAEE5882256CCBD433AA8CC763075CDA03C4AB2C66A32
79CDA24148A8C677386BC2AE534393C28B4660ACB06A4E81AF915E67969E78668098886E778F
8D777388907F727E8E887877858C847A7B8289867C777F8D8B7A7180948D746D869A886A6F90
9B7E667593987E6A78908D80797A85897E7F877B778E8D79777B8B957D6780998F726B879B89
6A7191987D6B7F968D73738A94817380908876798C8F7C73859385727A919079718597877176
8F957D6F80958C74748A9382747D908C7877889181747E908C76758A9380717C908D78738792
81727D8E8A7A76858F85777C898B7F7A8388827C8188847C7D8687827D7E8486827E7F838582
7F81828282828280818384817F818483817F808284817E8084837F7E8285817C7F86847B7983
8A82777B888A7C757F8B877877848B82777C87877C778189847B7A8388817B7D84867F7C7F85
847E7C8185827E7E8385817E7F83837F7D7F84847E7D8286817C7E85857C7B8286817A7D8585
7E7B8186817B7C84857D7A8186817A7C84867C78808883797B85877E777F89857A7882898277
7B87887C77818983777A87897D76808A84777985897F777E8A877876858C80757C8A88797584
8C81767B87897D777E88857A79828881787C86867D7A8187827B7C84857C7B87887779857E82
977F5975A7A06B5584AA8A5E6F97987364879C806C819080717F94886D759392746C8797846C
7691907A738693856B6F9BA466589FA866629BA3705389C0813B84CB8A3A6CBCA4585CA5B261
439AC4743A83D2982D4CC7D2581F8DE595214FD2CD4B2196E58B1D5ADAC33C2AABE2731A74E3
A52546CDCF4B25A2E47C1B68DFC03E25A4E47B176DE4B12B39C3D757249AE07F1F6CE1BA332A
B4E671167AEBAB2337CAE359138DF3971649DCD5421DA9F27D0F62EBC22B29BFEC650E7DF3AD
1D36D0E34F1092F7991141D9DD44109CF78C0A4EE5D43714AAF77B065FEFC82A1AB6F36D066E
F5B81C28C8EF5B0683FAA20E37D8E64B0A96FC910947E6DC3B0DA0FB870653ECD22F15B3FB7A
055CF2C8261AB6FA760361F2CE2D18B5F978055FF2CC2C19B4F9760462F2CA291AB7F7760561
F1CB2B1AB5F97D075BEECC2C15AFFA810555EBD63610A7FD8F0843E1E246078DFCA40F31D4F0
5A0276F8BC1E1FC0F7700261F3CF2E0FA4FF920842E3E5460389FEAE1327CCF6680066F5CD2A
13AEFF8A0443E2E74A0282FDBB1C1DBFFA760055EDDD3E068FFFA91226C8FB75024FE7E24505
87FAB71D1EB8FA8A0B3DD6EB5D0669EDD03C128BEDB32E2CA4DB93404D8EB1976F6871818F9A
8968617CAA9F675E7895A085676C8193997F63759796766981998C6E6E8A9A866C6E8D9E8265
7499987468829B896E759090787287917F7281938470789190756E8798826A779593736A879A
826876979470698A9D7F6078A19668618AA4875C6BA2A36E5A80A18F6C6D8D96766887A08564
6F919D846475958B797D83817A80938B6B6C92A1805E729FA0715D7EA69A695C88AC8F5F6496
AA7F5875A6996867929B7A6C8795806F80968971758F957D6C7B949579687D9D966D658CA586
616F9B9D756081A28E686B929E816673969B7E6770939F84666A88A494666186A29167658E9F
87666A8E9D856D7084918A776F7D928F7B717A888F847573838F8A7A717D8F8E7A6F7E918F7A
6E7E918E79707F918D787080908D7B737F8C887B78838A83797D86857F7C8286827C7D848680
7C808484807E8083838080818382808183817F8083837F7E8284817E7F84857F7C8185837D7D
8486817C7F85857E7C8286827C7F8585807C8085847D7C8386817C7E84857F7A8087857B7882
8A847879868B7F757D8B897A75838D837579898B7C73808E857577898E7D727E8F887576888E
7E737E8E887676878E7F747F8D887877868D80767E8B877A78858B81777D89877C7A8288827B
7E85857E7C8286817C7F8384807E80828180808181808181807F8182817E7F83847F7C808482
7D7E83857F7C8084827D7E83847E7C8186817B7D85857D7A8187827A7C85877E798087837A7B
84867E7A8087837B7C85877E7A8186827C7E84857E7D8285817D7F85847E7C8286827D7F8585
7E7C8186827C7E84847E7C8286827C7F84837E7D8285807B7F86837A7B84887E767F8A857878
858B7F747C8A887874838C82747A8A8B7B73818D8474788A8C7C737F8D877877868B7F767F8A
867A79858981797F88867C7B8488817B7F87867D7B8487817C8087847D7C8488817B7F87867E
7A8289847A7C86897F798089857B7B8589817A7F88877C7B8489827A7D87887F7A828B857B7C
878A7F78808B887B79868C82787E8A897C79848C83797E8A897D79858C83787C89897D78828B
857A7B87897F798088847C7C8487807B8086837C7D84857F7C8086837D7E84847F7D8284817E
7F83837F7E8183807E8083827F7E8284817E7F83837F7E8284817E7F83847F7D8184837D7D83
85807C7F86857D7C8287817B7E86867F7B8187837C7D85877F7B8187837B7D85867F7B818683
7C7E84867F7C8187837C7C85867F7B8187837C7E84857F7C8186827C7E84
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S2.1.4"]
}, Open  ]],

Cell[TextData[{
  "We do cosine packet transform on the data with an initial block size or \
window size of 1024. The taper function used is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\@\(\(t\^4\) \((35 - 84  t + 70  t\^2 - 20  t\^3)\)\)\)], 
    "InlineFormula",
    CellTags->"S2.1.4"],
  ", the so\[Hyphen]called ",
  StyleBox["Polynomial[3]", "MR"],
  " function, with taper width 16."
}], "MathCaption",
  CellTags->{"S2.1.4", "4.9"}],

Cell["\<\
cp = CosPacketTransform[cdata, 1024,
Taper -> {Polynomial[3], 16}];\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.1.4"],

Cell["\<\
The best basis corresponds to subdividing the initial block of size \
1024 into various smaller blocks.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.10"}],

Cell[CellGroupData[{

Cell["Short[Length /@ cp]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.1.4"],

Cell[BoxData[
    TagBox[
      \({32, 32, 32, 32, 32, 32, 32, \[LeftSkeleton]50\[RightSkeleton], 128, 
        64, 64, 32, 32, 64, 512}\),
      Short]], "Output",
  CellLabel->"Out[8]//Short= ",
  CellTags->"S2.1.4"]
}, Open  ]],

Cell["This shows the position of various blocks.", "MathCaption",
  CellTags->{"S2.1.4", "4.11"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[cp, PlotRange -> All]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0.0147151 0.0735755 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .08829 m
.97619 .08829 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .23544 m
.97619 .23544 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .38259 m
.97619 .38259 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .52974 m
.97619 .52974 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.03125 .01472 m
.03125 .08829 L
s
.03869 .01472 m
.03869 .16187 L
s
.04613 .01472 m
.04613 .08829 L
s
.05357 .01472 m
.05357 .23544 L
s
.06101 .01472 m
.06101 .08829 L
s
.06845 .01472 m
.06845 .16187 L
s
.07589 .01472 m
.07589 .08829 L
s
.08333 .01472 m
.08333 .30902 L
s
.09077 .01472 m
.09077 .08829 L
s
.09821 .01472 m
.09821 .16187 L
s
.10565 .01472 m
.10565 .08829 L
s
.1131 .01472 m
.1131 .23544 L
s
.12054 .01472 m
.12054 .08829 L
s
.12798 .01472 m
.12798 .16187 L
s
.13542 .01472 m
.13542 .08829 L
s
.14286 .01472 m
.14286 .38259 L
s
.1503 .01472 m
.1503 .08829 L
s
.15774 .01472 m
.15774 .16187 L
s
.16518 .01472 m
.16518 .08829 L
s
.17262 .01472 m
.17262 .23544 L
s
.18006 .01472 m
.18006 .08829 L
s
.1875 .01472 m
.1875 .16187 L
s
.19494 .01472 m
.19494 .08829 L
s
.20238 .01472 m
.20238 .30902 L
s
.20982 .01472 m
.20982 .08829 L
s
.21726 .01472 m
.21726 .16187 L
s
.2247 .01472 m
.2247 .08829 L
s
.23214 .01472 m
.23214 .23544 L
s
.23958 .01472 m
.23958 .08829 L
s
.24702 .01472 m
.24702 .16187 L
s
.25446 .01472 m
.25446 .08829 L
s
.2619 .01472 m
.2619 .45617 L
s
.26935 .01472 m
.26935 .08829 L
s
.27679 .01472 m
.27679 .16187 L
s
.28423 .01472 m
.28423 .08829 L
s
.29167 .01472 m
.29167 .23544 L
s
.29911 .01472 m
.29911 .08829 L
s
.30655 .01472 m
.30655 .16187 L
s
.31399 .01472 m
.31399 .08829 L
s
.32143 .01472 m
.32143 .30902 L
s
.32887 .01472 m
.32887 .08829 L
s
.33631 .01472 m
.33631 .16187 L
s
.34375 .01472 m
.34375 .08829 L
s
.35119 .01472 m
.35119 .23544 L
s
.35863 .01472 m
.35863 .08829 L
s
.36607 .01472 m
.36607 .16187 L
s
.37351 .01472 m
.37351 .08829 L
s
.38095 .01472 m
.38095 .38259 L
s
.38839 .01472 m
.38839 .08829 L
s
.39583 .01472 m
.39583 .16187 L
s
.40327 .01472 m
.40327 .08829 L
s
.41071 .01472 m
.41071 .23544 L
s
.41815 .01472 m
.41815 .08829 L
s
.4256 .01472 m
.4256 .16187 L
s
.43304 .01472 m
.43304 .08829 L
s
.44048 .01472 m
.44048 .30902 L
s
.44792 .01472 m
.44792 .08829 L
s
.45536 .01472 m
.45536 .16187 L
s
.4628 .01472 m
.4628 .08829 L
s
.47024 .01472 m
.47024 .23544 L
s
.47768 .01472 m
.47768 .08829 L
s
.48512 .01472 m
.48512 .16187 L
s
.49256 .01472 m
.49256 .08829 L
s
.5 .01472 m
.5 .52974 L
s
.50744 .01472 m
.50744 .08829 L
s
.51488 .01472 m
.51488 .16187 L
s
.52232 .01472 m
.52232 .08829 L
s
.52976 .01472 m
.52976 .23544 L
s
.5372 .01472 m
.5372 .08829 L
s
.54464 .01472 m
.54464 .16187 L
s
.55208 .01472 m
.55208 .08829 L
s
.55952 .01472 m
.55952 .30902 L
s
.56696 .01472 m
.56696 .08829 L
s
.5744 .01472 m
.5744 .16187 L
s
.58185 .01472 m
.58185 .08829 L
s
.58929 .01472 m
.58929 .23544 L
s
.59673 .01472 m
.59673 .08829 L
s
.60417 .01472 m
.60417 .16187 L
s
.61161 .01472 m
.61161 .08829 L
s
.61905 .01472 m
.61905 .38259 L
s
.62649 .01472 m
.62649 .08829 L
s
.63393 .01472 m
.63393 .16187 L
s
.64137 .01472 m
.64137 .08829 L
s
.64881 .01472 m
.64881 .23544 L
s
.65625 .01472 m
.65625 .08829 L
s
.66369 .01472 m
.66369 .16187 L
s
.67113 .01472 m
.67113 .08829 L
s
.67857 .01472 m
.67857 .30902 L
s
.68601 .01472 m
.68601 .08829 L
s
.69345 .01472 m
.69345 .16187 L
s
.70089 .01472 m
.70089 .08829 L
s
.70833 .01472 m
.70833 .23544 L
s
.71577 .01472 m
.71577 .08829 L
s
.72321 .01472 m
.72321 .16187 L
s
.73065 .01472 m
.73065 .08829 L
s
.7381 .01472 m
.7381 .45617 L
s
.74554 .01472 m
.74554 .08829 L
s
.75298 .01472 m
.75298 .16187 L
s
.76042 .01472 m
.76042 .08829 L
s
.76786 .01472 m
.76786 .23544 L
s
.7753 .01472 m
.7753 .08829 L
s
.78274 .01472 m
.78274 .16187 L
s
.79018 .01472 m
.79018 .08829 L
s
.79762 .01472 m
.79762 .30902 L
s
.80506 .01472 m
.80506 .08829 L
s
.8125 .01472 m
.8125 .16187 L
s
.81994 .01472 m
.81994 .08829 L
s
.82738 .01472 m
.82738 .23544 L
s
.83482 .01472 m
.83482 .08829 L
s
.84226 .01472 m
.84226 .16187 L
s
.8497 .01472 m
.8497 .08829 L
s
.85714 .01472 m
.85714 .38259 L
s
.86458 .01472 m
.86458 .08829 L
s
.87202 .01472 m
.87202 .16187 L
s
.87946 .01472 m
.87946 .08829 L
s
.8869 .01472 m
.8869 .23544 L
s
.89435 .01472 m
.89435 .08829 L
s
.90179 .01472 m
.90179 .16187 L
s
.90923 .01472 m
.90923 .08829 L
s
.91667 .01472 m
.91667 .30902 L
s
.92411 .01472 m
.92411 .08829 L
s
.93155 .01472 m
.93155 .16187 L
s
.93899 .01472 m
.93899 .08829 L
s
.94643 .01472 m
.94643 .23544 L
s
.95387 .01472 m
.95387 .08829 L
s
.96131 .01472 m
.96131 .16187 L
s
.96875 .01472 m
.96875 .08829 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03125 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.03869 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.04613 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.05357 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.06101 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.06845 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.07589 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.08333 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09077 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.09821 .08829 translate
.01489 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1131 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.12054 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.12798 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.13542 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.17262 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.1875 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.19494 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.20238 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.21726 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.23214 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.24702 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.25446 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.00745 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.26935 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.27679 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.28423 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.29167 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.32143 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.35119 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.35863 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.36607 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .23544 translate
.05953 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.44048 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.45536 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.4628 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47024 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.51488 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.52976 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.55952 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.56696 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5744 .08829 translate
.01489 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.58929 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.60417 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61161 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.62649 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.63393 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.64881 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.65625 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.66369 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.67857 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.70833 .16187 translate
.02977 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.75298 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.76786 .16187 translate
.02976 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.79762 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.8125 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.82738 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.83482 .01472 translate
.00744 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.84226 .08829 translate
.01488 .07358 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .30902 translate
.11905 .07357 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],

Cell[TextData[{
  "We can think of the cosine packet or sine packet transforms as being \
\"dual\" to wavelet packet transforms in that the roles of time and frequency \
are interchanged in the two transforms. For example, though in both cases ",
  StyleBox["ShowBasisPosition", "MR"],
  " shows how the original space is split into subspaces, it shows how the ",
  StyleBox["time", "TI"],
  " domain is split for cosine transforms and how ",
  StyleBox["frequency", "TI"],
  " space is divided for wavelet transforms. Therefore, in the above diagram \
each block corresponds to a definite time range; within each block or sublist \
the coefficients are arranged in increasing frequency. In contrast, for \
wavelet packet transforms, each block or sublist corresponds to a frequency \
range and within each sublist the coefficients are arranged in increasing \
time. \nAgain the function ",
  StyleBox["PhaseSpacePlot", "MR"],
  " can be used to plot the cosine or sine packet coefficients in phase \
space. However, now the frequency is plotted along the horizontal axis. If we \
choose to follow the usual convention of plotting time along the horizontal \
axis, we must use the option ",
  StyleBox["ExchangeAxes", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  ". "
}], "Text",
  CellTags->{"S2.1.4", "4.12"}],

Cell["\<\
This shows how the coefficients are distributed in phase \
space.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.13"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[cp, AspectRatio -> 1,
Frame -> True, FrameTicks -> None,
FrameLabel -> {\"frequency\", \"time\"}]\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00186012 0.0238095 0.119048 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -27 -9 ]
[.5 -0.0125 27 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -9 -12 ]
[-0.01875 .5 0 12 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(frequency)] .5 -0.0125 0 1 Mshowa
0 0 m
0 1 L
s
[(time)] -0.01875 .5 1 0 90 Mrotshowa
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .03125 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFEFEF8FEF9FAFCFFFEFFFFFFFEFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .03869 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFEFCF4FDFDFFFFFFFFFEFCFDFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .04613 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .05357 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .06101 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFEFDFAFBFEFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .06845 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFEFDFFFEFFFEFFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .07589 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .08333 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .09077 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .09821 translate
.95238 .01489 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFEFCFBFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .1131 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFEFDFEFEFCFCFEFDFBFDFEFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .12054 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFDFEFFFEF7FEFBE9FDFEFFFEFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .12798 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFEFEFFFEFEF7FBFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .13542 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFBFFFCECF9F5FCFAFFFDFEFDFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .14286 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFEFFFFFFFFFDFEFCFFFFFEFE
FAFCFFFAFDFEFFFCF8FFFBE9F3FDFEFFFEFEFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .17262 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .1875 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .19494 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .20238 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .21726 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .23214 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .24702 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .25446 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .2619 translate
.95238 .00745 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .26935 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFEFBF6F4F5FFF6FBFEFDFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .27679 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFEFFF8E6F3DFEEF7F9FEFFFDFEFEFEFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .28423 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFEFEFDF5EEADFFF8FEFFFAFEFFFEFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .29167 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFFFEFFFEFEFEFFFFFFFFFFFFFDFFFEFFFFFE
FDF8ECEFE8F6BEE712FFDEF7EBF7EDFBFDFFFEFEFEFFFEFF
FFFFFFFEFEFEFFFDFFFFFFFFFEFFFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .32143 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFCFEF8FA
F4EFEBE6E9CFA127AAD1E7E7F8F3F9F7FCFCFEFEFFFFFFFF
FEFFFFFFFFFFFEFFFDFFFFFFFFFFFFFFFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .35119 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFEFCFDFCB9DEE8F6FDFDFFFEFCFEFFFE
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .35863 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFEFEFEFDF0E6FDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .36607 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFC
FBFBF2FBF8FFFFFDFEFFFFFFFFFFFFFFFFFEFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .38095 translate
.95238 .05953 scale
256 string
256 1 8 [256 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FDFEFFFEFEFDFCFEFEFAFBFEFDF3F3FEF7FBFCFEFDFFFEFE
FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .44048 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FEFFFFEFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .45536 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFDFBF4F3FBE5F4FDF6F9FDFFFAFCFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .4628 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFDFEF4F9E0FEFFFDF3FAFBFEFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .47024 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFEFEFDFEFEFFFBFBFFFAF9FEFCFAFEF9F2FDFFF4
FCF7F8DDDBF8FCD6D5AF22C7E7F2FEF1FFE9F7FDF4FCFFFB
FEFDFDFFFDFDFFF9FDFEFAFDFEFEFEFEFFFEFDFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .5 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFD
F4FEF7B926C9DDF9F7FFFBFFFFFFFFFFFFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .51488 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFA
FCE6FF50F9B3FBEDFCFFFFFFFFFFFFFFFFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .52976 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFFFEFFFDFFFFFFFEFFFFFEFEFCFFFEF9FFFF
F2FBF9D6F4EADC00C8F7E5E6F4FDFCFBFEFEFBFFFFFEFFFF
FEFFFFFFFEFEFFFFFFFFFFFEFEFEFFFEFFFEFFFEFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .55952 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFAFCE8EEFDFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .56696 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFDFDEAFDF4FCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .5744 translate
.95238 .01489 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFC
FAF6F9F7E1FFFDFFFEFFFFFFFFFFFDFDFDFEFFFFFEFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .58929 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FDFEFBF0F7F3FFFEFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .60417 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFDFDFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .61161 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFEFBF8FEFDFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .61905 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFDF6FEFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .62649 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .63393 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFEF8F1FFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .64881 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFFFFFFFFFCFCF6FEFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .65625 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFFFFFFFFFFFFFFFEFDFAFBEFF0FFF8F4FEFAFEFEFDFEFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .66369 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFDFFFEFFFEFBFD
FAFDF7EFECBBEEFDECFAFCFBFFFEFAFEFBFAFFFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .67857 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFEFFFEFCFEFEFFFCFFFFFFFDFFFEFCFEFFF9
F9FEF8EBFAE6F9BEE30CFEBBF8EFFDFCFEFAFFFEFAFEFDFD
FFFFFFFEFFFFFEFFFFFFFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .70833 translate
.95238 .02977 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFDFFFFFFFFFFFFFFFFFEFFFEFEFBFB
F4FDEBF8D8F6B8C801AEA8E8DFF7F8FCFDFFFDFEFEFFFEFF
FFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .7381 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFEFEFEFFFEFFF3
FED9FB1CEAE8F6FDFDFDFFFFFEFFFFFEFFFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .75298 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFEF9FAFCFDE3
E7BE83F4B4F1F7FAFFFDFEFEFFFEFFFFFFFFFFFFFFFFFEFF
FEFFFFFFFFFEFEFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .76786 translate
.95238 .02976 scale
128 string
128 1 8 [128 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFFFDFFFDFCFEF9FFF7FAFDF4FF
F7F9ECF6E5FEFFEDDCEAE5FAFAFAFFFCFDFFFDFFFEFEFFFF
FFFFFFFFFFFEFEFDFFFEFDFFFDFFFEFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .79762 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
F6EDFCE2D8FDFFF8F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .8125 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFBFEF4
F2D9F0FBFEF9F8FAFFFFFFFFFFFEFFFFFFFFFFFFFFFEFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .82738 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFDF2F0FEFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .83482 translate
.95238 .00744 scale
32 string
32 1 8 [32 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFEFFFFFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .84226 translate
.95238 .01488 scale
64 string
64 1 8 [64 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDF9FDFAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% Start of gray image
p
.02381 .85714 translate
.95238 .11905 scale
512 string
512 1 8 [512 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFEFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFFFFFEFFFDFFFFFFFCFFFEFFFEFC
FDFDF9FDF4FAFDF5EBF3FEECF6F8FCFCFFFFFAFEFEFFFDFE
FEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],

Cell[TextData[{
  "Now the axes are exchanged using the option ",
  StyleBox["ExchangeAxes", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.1.4", "4.14"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[cp, ExchangeAxes -> True,
AspectRatio -> 1, Frame -> True, FrameTicks -> None,
FrameLabel -> {\"time\", \"frequency\"}]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.00186012 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -9 -27 ]
[-0.01875 .5 0 27 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 1 Mshowa
0 0 m
0 1 L
s
[(frequency)] -0.01875 .5 1 0 90 Mrotshowa
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.03125 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
F8
FE
F9
FA
FC
FF
FE
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.03869 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FC
F4
FD
FD
FF
FF
FF
FF
FE
FC
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.04613 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FE
FE
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.05357 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.06101 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FD
FA
FB
FE
FE
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.06845 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FD
FF
FE
FF
FE
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.07589 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.08333 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.09077 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.09821 .02381 translate
.01489 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FE
FF
FE
FC
FB
FD
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.1131 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FE
FD
FE
FE
FC
FC
FE
FD
FB
FD
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.12054 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FD
FE
FF
FE
F7
FE
FB
E9
FD
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.12798 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FE
FE
F7
FB
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.13542 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FB
FF
FC
EC
F9
F5
FC
FA
FF
FD
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.14286 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FE
FF
FF
FF
FF
FD
FE
FC
FF
FF
FE
FE
FA
FC
FF
FA
FD
FE
FF
FC
F8
FF
FB
E9
F3
FD
FE
FF
FE
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.17262 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.1875 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.19494 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.20238 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.21726 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.23214 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.24702 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.25446 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.2619 .02381 translate
.00745 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.26935 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FB
F6
F4
F5
FF
F6
FB
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.27679 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
F8
E6
F3
DF
EE
F7
F9
FE
FF
FD
FE
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.28423 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FD
F5
EE
AD
FF
F8
FE
FF
FA
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.29167 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FE
FF
FE
FE
FE
FF
FF
FF
FF
FF
FF
FD
FF
FE
FF
FF
FE
FD
F8
EC
EF
E8
F6
BE
E7
12
FF
DE
F7
EB
F7
ED
FB
FD
FF
FE
FE
FE
FF
FE
FF
FF
FF
FF
FE
FE
FE
FF
FD
FF
FF
FF
FF
FE
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.32143 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FE
FF
FC
FE
F8
FA
F4
EF
EB
E6
E9
CF
A1
27
AA
D1
E7
E7
F8
F3
F9
F7
FC
FC
FE
FE
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FE
FF
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.35119 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FE
FC
FD
FC
B9
DE
E8
F6
FD
FD
FF
FE
FC
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.35863 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FE
FD
F0
E6
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.36607 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FC
FB
FB
F2
FB
F8
FF
FF
FD
FE
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.38095 .02381 translate
.05953 .95238 scale
1 string
1 256 8 [1 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FD
FE
FF
FE
FE
FD
FC
FE
FE
FA
FB
FE
FD
F3
F3
FE
F7
FB
FC
FE
FD
FF
FE
FE
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.44048 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
EF
FB
FF
FF
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.45536 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FD
FB
F4
F3
FB
E5
F4
FD
F6
F9
FD
FF
FA
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.4628 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FD
FE
F4
F9
E0
FE
FF
FD
F3
FA
FB
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.47024 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FD
FE
FE
FF
FB
FB
FF
FA
F9
FE
FC
FA
FE
F9
F2
FD
FF
F4
FC
F7
F8
DD
DB
F8
FC
D6
D5
AF
22
C7
E7
F2
FE
F1
FF
E9
F7
FD
F4
FC
FF
FB
FE
FD
FD
FF
FD
FD
FF
F9
FD
FE
FA
FD
FE
FE
FE
FE
FF
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.5 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FE
FF
FF
FD
F4
FE
F7
B9
26
C9
DD
F9
F7
FF
FB
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.51488 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FE
FF
FA
FC
E6
FF
50
F9
B3
FB
ED
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.52976 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FE
FF
FD
FF
FF
FF
FE
FF
FF
FE
FE
FC
FF
FE
F9
FF
FF
F2
FB
F9
D6
F4
EA
DC
00
C8
F7
E5
E6
F4
FD
FC
FB
FE
FE
FB
FF
FF
FE
FF
FF
FE
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FE
FE
FE
FF
FE
FF
FE
FF
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.55952 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FA
FC
E8
EE
FD
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.56696 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FD
EA
FD
F4
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.5744 .02381 translate
.01489 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FC
FC
FA
F6
F9
F7
E1
FF
FD
FF
FE
FF
FF
FF
FF
FF
FD
FD
FD
FE
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.58929 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FD
FE
FB
F0
F7
F3
FF
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.60417 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FD
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.61161 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FB
F8
FE
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.61905 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
F6
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.62649 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FA
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.63393 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
F8
F1
FF
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.64881 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FC
FC
F6
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.65625 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FF
FF
FF
FF
FF
FF
FF
FE
FD
FA
FB
EF
F0
FF
F8
F4
FE
FA
FE
FE
FD
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.66369 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FD
FF
FE
FF
FE
FB
FD
FA
FD
F7
EF
EC
BB
EE
FD
EC
FA
FC
FB
FF
FE
FA
FE
FB
FA
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.67857 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FE
FF
FE
FC
FE
FE
FF
FC
FF
FF
FF
FD
FF
FE
FC
FE
FF
F9
F9
FE
F8
EB
FA
E6
F9
BE
E3
0C
FE
BB
F8
EF
FD
FC
FE
FA
FF
FE
FA
FE
FD
FD
FF
FF
FF
FE
FF
FF
FE
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.70833 .02381 translate
.02977 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FD
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FE
FB
FB
F4
FD
EB
F8
D8
F6
B8
C8
01
AE
A8
E8
DF
F7
F8
FC
FD
FF
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.7381 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FE
FE
FE
FF
FE
FF
F3
FE
D9
FB
1C
EA
E8
F6
FD
FD
FD
FF
FF
FE
FF
FF
FE
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.75298 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FF
FE
FE
F9
FA
FC
FD
E3
E7
BE
83
F4
B4
F1
F7
FA
FF
FD
FE
FE
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FE
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.76786 .02381 translate
.02976 .95238 scale
1 string
1 128 8 [1 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FD
FF
FD
FC
FE
F9
FF
F7
FA
FD
F4
FF
F7
F9
EC
F6
E5
FE
FF
ED
DC
EA
E5
FA
FA
FA
FF
FC
FD
FF
FD
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FE
FE
FD
FF
FE
FD
FF
FD
FF
FE
FF
FE
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.79762 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FD
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
F6
ED
FC
E2
D8
FD
FF
F8
F9
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.8125 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FD
FB
FE
F4
F2
D9
F0
FB
FE
F9
F8
FA
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.82738 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
F2
F0
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.83482 .02381 translate
.00744 .95238 scale
1 string
1 32 8 [1 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FC
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.84226 .02381 translate
.01488 .95238 scale
1 string
1 64 8 [1 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FD
FD
F9
FD
FA
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% Start of gray image
p
.85714 .02381 translate
.11905 .95238 scale
1 string
1 512 8 [1 0 0 512 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FF
FE
FF
FE
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FE
FF
FD
FF
FF
FF
FC
FF
FE
FF
FE
FC
FD
FD
F9
FD
F4
FA
FD
F5
EB
F3
FE
EC
F6
F8
FC
FC
FF
FF
FA
FE
FE
FF
FD
FE
FE
FF
FF
FF
FF
FF
FE
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
FF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],

Cell["\<\
For comparison, we will decompose the sound signal using different \
bases and see their energy concentration. \
\>", "Text",
  CellTags->{"S2.1.4", "4.15"}],

Cell["\<\
For example, this is the cosine transform with block size or window \
size 256.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.16"}],

Cell["\<\
ctrans = CosTransform[cdata, 256,
Taper -> {Polynomial[3], 16}];\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.1.4"],

Cell["This gives the windowed Fourier transform.", "MathCaption",
  CellTags->{"S2.1.4", "4.17"}],

Cell["wf = CosTransform[cdata, 256, Taper -> False];", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.1.4"],

Cell["\<\
The cumulative energies from different transforms are \
computed.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.18"}],

Cell["\<\
(norm = cdata.cdata;
e = CumulativeEnergy[#, 800]/norm& /@
{cp, ctrans, wf};)\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.1.4"],

Cell["\<\
We see that the cosine packet transform (solid line) does best in \
terms of representing the signal efficiently; the cosine transform (dashed \
line) with fixed window size and the same taper as in the cosine packet \
transform also does quite well, whereas the windowed Fourier transform (light \
solid line) is obviously inferior.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.19"}],

Cell[CellGroupData[{

Cell["\<\
Show[MapThread[ListPlot[#, PlotStyle -> #2,
PlotJoined -> True, DisplayFunction -> Identity
]&, {e, {{}, Dashing[{0.02}], GrayLevel[0.5]}}],
DisplayFunction -> $DisplayFunction]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00119048 -9.34101 9.94819 [
[.2619 .59469 -9 -9 ]
[.2619 .59469 9 0 ]
[.5 .59469 -9 -9 ]
[.5 .59469 9 0 ]
[.7381 .59469 -9 -9 ]
[.7381 .59469 9 0 ]
[.97619 .59469 -9 -9 ]
[.97619 .59469 9 0 ]
[.01131 .0103 -24 -4.5 ]
[.01131 .0103 0 4.5 ]
[.01131 .10978 -24 -4.5 ]
[.01131 .10978 0 4.5 ]
[.01131 .20926 -24 -4.5 ]
[.01131 .20926 0 4.5 ]
[.01131 .30874 -24 -4.5 ]
[.01131 .30874 0 4.5 ]
[.01131 .40822 -24 -4.5 ]
[.01131 .40822 0 4.5 ]
[.01131 .50771 -24 -4.5 ]
[.01131 .50771 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60719 m
.2619 .61344 L
s
[(200)] .2619 .59469 0 1 Mshowa
.5 .60719 m
.5 .61344 L
s
[(400)] .5 .59469 0 1 Mshowa
.7381 .60719 m
.7381 .61344 L
s
[(600)] .7381 .59469 0 1 Mshowa
.97619 .60719 m
.97619 .61344 L
s
[(800)] .97619 .59469 0 1 Mshowa
.125 Mabswid
.08333 .60719 m
.08333 .61094 L
s
.14286 .60719 m
.14286 .61094 L
s
.20238 .60719 m
.20238 .61094 L
s
.32143 .60719 m
.32143 .61094 L
s
.38095 .60719 m
.38095 .61094 L
s
.44048 .60719 m
.44048 .61094 L
s
.55952 .60719 m
.55952 .61094 L
s
.61905 .60719 m
.61905 .61094 L
s
.67857 .60719 m
.67857 .61094 L
s
.79762 .60719 m
.79762 .61094 L
s
.85714 .60719 m
.85714 .61094 L
s
.91667 .60719 m
.91667 .61094 L
s
.25 Mabswid
0 .60719 m
1 .60719 L
s
.02381 .0103 m
.03006 .0103 L
s
[(0.94)] .01131 .0103 1 0 Mshowa
.02381 .10978 m
.03006 .10978 L
s
[(0.95)] .01131 .10978 1 0 Mshowa
.02381 .20926 m
.03006 .20926 L
s
[(0.96)] .01131 .20926 1 0 Mshowa
.02381 .30874 m
.03006 .30874 L
s
[(0.97)] .01131 .30874 1 0 Mshowa
.02381 .40822 m
.03006 .40822 L
s
[(0.98)] .01131 .40822 1 0 Mshowa
.02381 .50771 m
.03006 .50771 L
s
[(0.99)] .01131 .50771 1 0 Mshowa
.125 Mabswid
.02381 .03019 m
.02756 .03019 L
s
.02381 .05009 m
.02756 .05009 L
s
.02381 .06998 m
.02756 .06998 L
s
.02381 .08988 m
.02756 .08988 L
s
.02381 .12967 m
.02756 .12967 L
s
.02381 .14957 m
.02756 .14957 L
s
.02381 .16947 m
.02756 .16947 L
s
.02381 .18936 m
.02756 .18936 L
s
.02381 .22916 m
.02756 .22916 L
s
.02381 .24905 m
.02756 .24905 L
s
.02381 .26895 m
.02756 .26895 L
s
.02381 .28884 m
.02756 .28884 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .34853 m
.02756 .34853 L
s
.02381 .36843 m
.02756 .36843 L
s
.02381 .38833 m
.02756 .38833 L
s
.02381 .42812 m
.02756 .42812 L
s
.02381 .44802 m
.02756 .44802 L
s
.02381 .46791 m
.02756 .46791 L
s
.02381 .48781 m
.02756 .48781 L
s
.02381 .5276 m
.02756 .5276 L
s
.02381 .5475 m
.02756 .5475 L
s
.02381 .56739 m
.02756 .56739 L
s
.02381 .58729 m
.02756 .58729 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.08746 0 m
.0881 .00585 L
.08929 .01642 L
.09048 .02679 L
.09167 .03696 L
.09286 .04692 L
.09405 .05688 L
.09524 .06679 L
.09643 .07661 L
.09762 .08633 L
.09881 .09596 L
.1 .1053 L
.10119 .1146 L
.10238 .12375 L
.10357 .1326 L
.10476 .14132 L
.10595 .14973 L
.10714 .15807 L
.10833 .1662 L
.10952 .17424 L
.11071 .1822 L
.1119 .18984 L
.1131 .19725 L
.11429 .20463 L
.11548 .21193 L
.11667 .21903 L
.11786 .22598 L
.11905 .23265 L
.12024 .23927 L
.12143 .24568 L
.12262 .25195 L
.12381 .2581 L
.125 .26418 L
.12619 .27022 L
.12738 .27614 L
.12857 .28202 L
.12976 .28789 L
.13095 .29369 L
.13214 .29944 L
.13333 .30495 L
.13452 .31026 L
.13571 .31552 L
.1369 .32075 L
.1381 .3257 L
.13929 .33033 L
.14048 .33482 L
.14167 .33928 L
.14286 .34373 L
.14405 .34795 L
.14524 .3521 L
Mistroke
.14643 .35621 L
.14762 .36029 L
.14881 .36414 L
.15 .36798 L
.15119 .37178 L
.15238 .37532 L
.15357 .37884 L
.15476 .38232 L
.15595 .38576 L
.15714 .38901 L
.15833 .39215 L
.15952 .39514 L
.16071 .39803 L
.1619 .40091 L
.1631 .40378 L
.16429 .40663 L
.16548 .40935 L
.16667 .41197 L
.16786 .41447 L
.16905 .41695 L
.17024 .41936 L
.17143 .42175 L
.17262 .42412 L
.17381 .42647 L
.175 .4288 L
.17619 .43109 L
.17738 .43331 L
.17857 .43551 L
.17976 .43767 L
.18095 .43976 L
.18214 .44184 L
.18333 .44391 L
.18452 .44594 L
.18571 .44796 L
.1869 .44992 L
.1881 .45186 L
.18929 .45377 L
.19048 .45567 L
.19167 .45757 L
.19286 .45945 L
.19405 .46132 L
.19524 .46319 L
.19643 .46504 L
.19762 .46688 L
.19881 .46871 L
.2 .47055 L
.20119 .47218 L
.20238 .47374 L
.20357 .47528 L
.20476 .47678 L
Mistroke
.20595 .4782 L
.20714 .4796 L
.20833 .48099 L
.20952 .48233 L
.21071 .48366 L
.2119 .48499 L
.2131 .4863 L
.21429 .48759 L
.21548 .48887 L
.21667 .49014 L
.21786 .4914 L
.21905 .49264 L
.22024 .49386 L
.22143 .49506 L
.22262 .49625 L
.22381 .4974 L
.225 .49852 L
.22619 .49962 L
.22738 .5007 L
.22857 .50177 L
.22976 .50281 L
.23095 .50385 L
.23214 .50488 L
.23333 .5059 L
.23452 .50691 L
.23571 .50792 L
.2369 .50893 L
.2381 .50991 L
.23929 .51088 L
.24048 .51186 L
.24167 .51283 L
.24286 .5138 L
.24405 .51474 L
.24524 .51567 L
.24643 .51659 L
.24762 .51751 L
.24881 .51843 L
.25 .51933 L
.25119 .52023 L
.25238 .52112 L
.25357 .522 L
.25476 .52288 L
.25595 .52374 L
.25714 .5246 L
.25833 .52544 L
.25952 .52627 L
.26071 .5271 L
.2619 .5279 L
.2631 .52869 L
.26429 .52948 L
Mistroke
.26548 .53024 L
.26667 .531 L
.26786 .53172 L
.26905 .53245 L
.27024 .53316 L
.27143 .53387 L
.27262 .53457 L
.27381 .53526 L
.275 .53594 L
.27619 .53663 L
.27738 .53731 L
.27857 .53799 L
.27976 .53865 L
.28095 .53931 L
.28214 .53998 L
.28333 .54063 L
.28452 .54127 L
.28571 .54191 L
.2869 .54254 L
.2881 .54317 L
.28929 .54378 L
.29048 .54439 L
.29167 .545 L
.29286 .54559 L
.29405 .54616 L
.29524 .54672 L
.29643 .54725 L
.29762 .54777 L
.29881 .54826 L
.3 .54876 L
.30119 .54925 L
.30238 .54974 L
.30357 .55023 L
.30476 .55072 L
.30595 .55121 L
.30714 .55169 L
.30833 .55217 L
.30952 .55264 L
.31071 .55312 L
.3119 .55358 L
.3131 .55405 L
.31429 .55451 L
.31548 .55496 L
.31667 .55542 L
.31786 .55587 L
.31905 .55631 L
.32024 .55676 L
.32143 .5572 L
.32262 .55763 L
.32381 .55806 L
Mistroke
.325 .55849 L
.32619 .55891 L
.32738 .55934 L
.32857 .55975 L
.32976 .56015 L
.33095 .56056 L
.33214 .56096 L
.33333 .56136 L
.33452 .56175 L
.33571 .56214 L
.3369 .56252 L
.3381 .56291 L
.33929 .56328 L
.34048 .56364 L
.34167 .56399 L
.34286 .56434 L
.34405 .56468 L
.34524 .56501 L
.34643 .56535 L
.34762 .56567 L
.34881 .566 L
.35 .56633 L
.35119 .56665 L
.35238 .56696 L
.35357 .56728 L
.35476 .5676 L
.35595 .56791 L
.35714 .56821 L
.35833 .56852 L
.35952 .56881 L
.36071 .5691 L
.3619 .56939 L
.3631 .56968 L
.36429 .56996 L
.36548 .57024 L
.36667 .57052 L
.36786 .5708 L
.36905 .57107 L
.37024 .57134 L
.37143 .57161 L
.37262 .57187 L
.37381 .57214 L
.375 .5724 L
.37619 .57265 L
.37738 .57291 L
.37857 .57317 L
.37976 .57342 L
.38095 .57367 L
.38214 .57392 L
.38333 .57416 L
Mistroke
.38452 .5744 L
.38571 .57464 L
.3869 .57487 L
.3881 .57511 L
.38929 .57534 L
.39048 .57556 L
.39167 .57578 L
.39286 .57599 L
.39405 .57621 L
.39524 .57643 L
.39643 .57664 L
.39762 .57684 L
.39881 .57704 L
.4 .57724 L
.40119 .57744 L
.40238 .57763 L
.40357 .57782 L
.40476 .57801 L
.40595 .5782 L
.40714 .57839 L
.40833 .57858 L
.40952 .57876 L
.41071 .57894 L
.4119 .57911 L
.4131 .57928 L
.41429 .57946 L
.41548 .57963 L
.41667 .5798 L
.41786 .57996 L
.41905 .58012 L
.42024 .58028 L
.42143 .58044 L
.42262 .5806 L
.42381 .58075 L
.425 .58091 L
.42619 .58106 L
.42738 .58121 L
.42857 .58136 L
.42976 .58151 L
.43095 .58165 L
.43214 .5818 L
.43333 .58194 L
.43452 .58208 L
.43571 .58222 L
.4369 .58236 L
.4381 .5825 L
.43929 .58264 L
.44048 .58278 L
.44167 .58292 L
.44286 .58306 L
Mistroke
.44405 .58319 L
.44524 .58333 L
.44643 .58346 L
.44762 .5836 L
.44881 .58373 L
.45 .58386 L
.45119 .584 L
.45238 .58413 L
.45357 .58426 L
.45476 .58439 L
.45595 .58452 L
.45714 .58465 L
.45833 .58478 L
.45952 .58491 L
.46071 .58503 L
.4619 .58516 L
.4631 .58528 L
.46429 .58541 L
.46548 .58553 L
.46667 .58565 L
.46786 .58577 L
.46905 .58589 L
.47024 .58601 L
.47143 .58612 L
.47262 .58624 L
.47381 .58635 L
.475 .58647 L
.47619 .58658 L
.47738 .58669 L
.47857 .5868 L
.47976 .58691 L
.48095 .58702 L
.48214 .58713 L
.48333 .58724 L
.48452 .58735 L
.48571 .58745 L
.4869 .58756 L
.4881 .58766 L
.48929 .58777 L
.49048 .58787 L
.49167 .58797 L
.49286 .58807 L
.49405 .58817 L
.49524 .58827 L
.49643 .58837 L
.49762 .58847 L
.49881 .58857 L
.5 .58866 L
.50119 .58876 L
.50238 .58885 L
Mistroke
.50357 .58895 L
.50476 .58904 L
.50595 .58913 L
.50714 .58923 L
.50833 .58932 L
.50952 .58941 L
.51071 .5895 L
.5119 .58959 L
.5131 .58968 L
.51429 .58976 L
.51548 .58985 L
.51667 .58994 L
.51786 .59002 L
.51905 .59011 L
.52024 .59019 L
.52143 .59027 L
.52262 .59035 L
.52381 .59043 L
.525 .59051 L
.52619 .59059 L
.52738 .59067 L
.52857 .59075 L
.52976 .59083 L
.53095 .59091 L
.53214 .59099 L
.53333 .59106 L
.53452 .59114 L
.53571 .59121 L
.5369 .59129 L
.5381 .59137 L
.53929 .59144 L
.54048 .59152 L
.54167 .59159 L
.54286 .59166 L
.54405 .59174 L
.54524 .59181 L
.54643 .59188 L
.54762 .59195 L
.54881 .59202 L
.55 .5921 L
.55119 .59217 L
.55238 .59223 L
.55357 .5923 L
.55476 .59237 L
.55595 .59244 L
.55714 .59251 L
.55833 .59257 L
.55952 .59264 L
.56071 .5927 L
.5619 .59277 L
Mistroke
.5631 .59283 L
.56429 .5929 L
.56548 .59296 L
.56667 .59303 L
.56786 .59309 L
.56905 .59315 L
.57024 .59322 L
.57143 .59328 L
.57262 .59334 L
.57381 .5934 L
.575 .59346 L
.57619 .59353 L
.57738 .59359 L
.57857 .59365 L
.57976 .59371 L
.58095 .59377 L
.58214 .59383 L
.58333 .59389 L
.58452 .59395 L
.58571 .59401 L
.5869 .59407 L
.5881 .59413 L
.58929 .59418 L
.59048 .59424 L
.59167 .5943 L
.59286 .59436 L
.59405 .59441 L
.59524 .59447 L
.59643 .59453 L
.59762 .59458 L
.59881 .59464 L
.6 .59469 L
.60119 .59475 L
.60238 .5948 L
.60357 .59485 L
.60476 .59491 L
.60595 .59496 L
.60714 .59501 L
.60833 .59506 L
.60952 .59511 L
.61071 .59517 L
.6119 .59522 L
.6131 .59527 L
.61429 .59532 L
.61548 .59537 L
.61667 .59542 L
.61786 .59547 L
.61905 .59552 L
.62024 .59557 L
.62143 .59561 L
Mistroke
.62262 .59566 L
.62381 .59571 L
.625 .59576 L
.62619 .59581 L
.62738 .59586 L
.62857 .59591 L
.62976 .59595 L
.63095 .596 L
.63214 .59605 L
.63333 .5961 L
.63452 .59614 L
.63571 .59619 L
.6369 .59623 L
.6381 .59628 L
.63929 .59632 L
.64048 .59637 L
.64167 .59641 L
.64286 .59645 L
.64405 .5965 L
.64524 .59654 L
.64643 .59658 L
.64762 .59663 L
.64881 .59667 L
.65 .59671 L
.65119 .59675 L
.65238 .5968 L
.65357 .59684 L
.65476 .59688 L
.65595 .59692 L
.65714 .59696 L
.65833 .597 L
.65952 .59704 L
.66071 .59708 L
.6619 .59712 L
.6631 .59716 L
.66429 .5972 L
.66548 .59724 L
.66667 .59727 L
.66786 .59731 L
.66905 .59735 L
.67024 .59739 L
.67143 .59742 L
.67262 .59746 L
.67381 .5975 L
.675 .59753 L
.67619 .59757 L
.67738 .59761 L
.67857 .59764 L
.67976 .59768 L
.68095 .59771 L
Mistroke
.68214 .59775 L
.68333 .59778 L
.68452 .59782 L
.68571 .59785 L
.6869 .59789 L
.6881 .59792 L
.68929 .59796 L
.69048 .59799 L
.69167 .59803 L
.69286 .59806 L
.69405 .59809 L
.69524 .59813 L
.69643 .59816 L
.69762 .5982 L
.69881 .59823 L
.7 .59826 L
.70119 .59829 L
.70238 .59833 L
.70357 .59836 L
.70476 .59839 L
.70595 .59842 L
.70714 .59846 L
.70833 .59849 L
.70952 .59852 L
.71071 .59855 L
.7119 .59858 L
.7131 .59862 L
.71429 .59865 L
.71548 .59868 L
.71667 .59871 L
.71786 .59874 L
.71905 .59877 L
.72024 .5988 L
.72143 .59883 L
.72262 .59887 L
.72381 .5989 L
.725 .59893 L
.72619 .59896 L
.72738 .59899 L
.72857 .59902 L
.72976 .59905 L
.73095 .59908 L
.73214 .59911 L
.73333 .59913 L
.73452 .59916 L
.73571 .59919 L
.7369 .59922 L
.7381 .59925 L
.73929 .59928 L
.74048 .59931 L
Mistroke
.74167 .59934 L
.74286 .59937 L
.74405 .5994 L
.74524 .59942 L
.74643 .59945 L
.74762 .59948 L
.74881 .59951 L
.75 .59954 L
.75119 .59956 L
.75238 .59959 L
.75357 .59962 L
.75476 .59965 L
.75595 .59967 L
.75714 .5997 L
.75833 .59973 L
.75952 .59975 L
.76071 .59978 L
.7619 .59981 L
.7631 .59984 L
.76429 .59986 L
.76548 .59989 L
.76667 .59992 L
.76786 .59994 L
.76905 .59997 L
.77024 .59999 L
.77143 .60002 L
.77262 .60005 L
.77381 .60007 L
.775 .6001 L
.77619 .60013 L
.77738 .60015 L
.77857 .60018 L
.77976 .6002 L
.78095 .60023 L
.78214 .60025 L
.78333 .60028 L
.78452 .6003 L
.78571 .60033 L
.7869 .60035 L
.7881 .60038 L
.78929 .6004 L
.79048 .60043 L
.79167 .60045 L
.79286 .60048 L
.79405 .6005 L
.79524 .60053 L
.79643 .60055 L
.79762 .60057 L
.79881 .6006 L
.8 .60062 L
Mistroke
.80119 .60065 L
.80238 .60067 L
.80357 .60069 L
.80476 .60072 L
.80595 .60074 L
.80714 .60076 L
.80833 .60079 L
.80952 .60081 L
.81071 .60083 L
.8119 .60086 L
.8131 .60088 L
.81429 .6009 L
.81548 .60093 L
.81667 .60095 L
.81786 .60097 L
.81905 .60099 L
.82024 .60102 L
.82143 .60104 L
.82262 .60106 L
.82381 .60108 L
.825 .6011 L
.82619 .60113 L
.82738 .60115 L
.82857 .60117 L
.82976 .60119 L
.83095 .60121 L
.83214 .60124 L
.83333 .60126 L
.83452 .60128 L
.83571 .6013 L
.8369 .60132 L
.8381 .60134 L
.83929 .60136 L
.84048 .60139 L
.84167 .60141 L
.84286 .60143 L
.84405 .60145 L
.84524 .60147 L
.84643 .60149 L
.84762 .60151 L
.84881 .60153 L
.85 .60155 L
.85119 .60157 L
.85238 .60159 L
.85357 .60161 L
.85476 .60163 L
.85595 .60165 L
.85714 .60167 L
.85833 .60169 L
.85952 .60171 L
Mistroke
.86071 .60173 L
.8619 .60175 L
.8631 .60177 L
.86429 .60179 L
.86548 .60181 L
.86667 .60183 L
.86786 .60185 L
.86905 .60186 L
.87024 .60188 L
.87143 .6019 L
.87262 .60192 L
.87381 .60194 L
.875 .60196 L
.87619 .60198 L
.87738 .602 L
.87857 .60202 L
.87976 .60203 L
.88095 .60205 L
.88214 .60207 L
.88333 .60209 L
.88452 .60211 L
.88571 .60213 L
.8869 .60214 L
.8881 .60216 L
.88929 .60218 L
.89048 .6022 L
.89167 .60222 L
.89286 .60223 L
.89405 .60225 L
.89524 .60227 L
.89643 .60229 L
.89762 .6023 L
.89881 .60232 L
.9 .60234 L
.90119 .60236 L
.90238 .60237 L
.90357 .60239 L
.90476 .60241 L
.90595 .60242 L
.90714 .60244 L
.90833 .60246 L
.90952 .60247 L
.91071 .60249 L
.9119 .60251 L
.9131 .60253 L
.91429 .60254 L
.91548 .60256 L
.91667 .60257 L
.91786 .60259 L
.91905 .60261 L
Mistroke
.92024 .60262 L
.92143 .60264 L
.92262 .60266 L
.92381 .60267 L
.925 .60269 L
.92619 .6027 L
.92738 .60272 L
.92857 .60273 L
.92976 .60275 L
.93095 .60277 L
.93214 .60278 L
.93333 .6028 L
.93452 .60281 L
.93571 .60283 L
.9369 .60284 L
.9381 .60286 L
.93929 .60287 L
.94048 .60289 L
.94167 .6029 L
.94286 .60292 L
.94405 .60293 L
.94524 .60295 L
.94643 .60296 L
.94762 .60298 L
.94881 .60299 L
.95 .60301 L
.95119 .60302 L
.95238 .60303 L
.95357 .60305 L
.95476 .60306 L
.95595 .60308 L
.95714 .60309 L
.95833 .60311 L
.95952 .60312 L
.96071 .60314 L
.9619 .60315 L
.9631 .60316 L
.96429 .60318 L
.96548 .60319 L
.96667 .60321 L
.96786 .60322 L
.96905 .60324 L
.97024 .60325 L
.97143 .60326 L
.97262 .60328 L
.97381 .60329 L
.975 .60331 L
.97619 .60332 L
Mfstroke
[ .02 ] 0 setdash
.10507 0 m
.10595 .00758 L
.10714 .01755 L
.10833 .02748 L
.10952 .03734 L
.11071 .04661 L
.1119 .05582 L
.1131 .06503 L
.11429 .07399 L
.11548 .08291 L
.11667 .09111 L
.11786 .09919 L
.11905 .10706 L
.12024 .11486 L
.12143 .12241 L
.12262 .12992 L
.12381 .13737 L
.125 .14464 L
.12619 .15141 L
.12738 .15815 L
.12857 .16488 L
.12976 .17111 L
.13095 .17732 L
.13214 .18329 L
.13333 .18926 L
.13452 .19519 L
.13571 .20098 L
.1369 .20673 L
.1381 .21246 L
.13929 .21816 L
.14048 .22383 L
.14167 .22946 L
.14286 .23495 L
.14405 .24032 L
.14524 .24559 L
.14643 .25084 L
.14762 .25592 L
.14881 .26089 L
.15 .26581 L
.15119 .27067 L
.15238 .27553 L
.15357 .28039 L
.15476 .28517 L
.15595 .28995 L
.15714 .29463 L
.15833 .29918 L
.15952 .30369 L
.16071 .30817 L
.1619 .31218 L
.1631 .31606 L
Mistroke
.16429 .31975 L
.16548 .32342 L
.16667 .32706 L
.16786 .3307 L
.16905 .3343 L
.17024 .33779 L
.17143 .34124 L
.17262 .34462 L
.17381 .34796 L
.175 .35129 L
.17619 .35458 L
.17738 .35779 L
.17857 .36098 L
.17976 .36414 L
.18095 .36723 L
.18214 .37024 L
.18333 .37311 L
.18452 .37593 L
.18571 .37871 L
.1869 .38134 L
.1881 .38382 L
.18929 .38629 L
.19048 .38873 L
.19167 .39113 L
.19286 .39351 L
.19405 .39589 L
.19524 .39824 L
.19643 .40056 L
.19762 .40285 L
.19881 .40509 L
.2 .40732 L
.20119 .40953 L
.20238 .41172 L
.20357 .41377 L
.20476 .4158 L
.20595 .41783 L
.20714 .41985 L
.20833 .42185 L
.20952 .42383 L
.21071 .4258 L
.2119 .42776 L
.2131 .42966 L
.21429 .43154 L
.21548 .4334 L
.21667 .43527 L
.21786 .43711 L
.21905 .43891 L
.22024 .4407 L
.22143 .44244 L
.22262 .44416 L
Mistroke
.22381 .44586 L
.225 .44754 L
.22619 .44919 L
.22738 .45077 L
.22857 .45235 L
.22976 .45388 L
.23095 .4554 L
.23214 .45688 L
.23333 .45834 L
.23452 .45975 L
.23571 .46111 L
.2369 .46246 L
.2381 .4638 L
.23929 .46514 L
.24048 .46647 L
.24167 .46779 L
.24286 .4691 L
.24405 .4704 L
.24524 .47169 L
.24643 .47297 L
.24762 .47421 L
.24881 .47544 L
.25 .47667 L
.25119 .4779 L
.25238 .47911 L
.25357 .48032 L
.25476 .48152 L
.25595 .4827 L
.25714 .48384 L
.25833 .48497 L
.25952 .48609 L
.26071 .4872 L
.2619 .48831 L
.2631 .4894 L
.26429 .49046 L
.26548 .49153 L
.26667 .49258 L
.26786 .49361 L
.26905 .49464 L
.27024 .49566 L
.27143 .49666 L
.27262 .49765 L
.27381 .49865 L
.275 .49961 L
.27619 .50056 L
.27738 .50151 L
.27857 .50245 L
.27976 .50337 L
.28095 .50427 L
.28214 .50517 L
Mistroke
.28333 .50606 L
.28452 .50694 L
.28571 .50781 L
.2869 .50869 L
.2881 .50956 L
.28929 .51042 L
.29048 .51129 L
.29167 .51214 L
.29286 .51299 L
.29405 .51382 L
.29524 .51463 L
.29643 .51544 L
.29762 .51624 L
.29881 .51703 L
.3 .51779 L
.30119 .51855 L
.30238 .5193 L
.30357 .52004 L
.30476 .52078 L
.30595 .52152 L
.30714 .52226 L
.30833 .52299 L
.30952 .52372 L
.31071 .52443 L
.3119 .52513 L
.3131 .52581 L
.31429 .5265 L
.31548 .52717 L
.31667 .52785 L
.31786 .52848 L
.31905 .52912 L
.32024 .52974 L
.32143 .53037 L
.32262 .53099 L
.32381 .53161 L
.325 .53221 L
.32619 .5328 L
.32738 .5334 L
.32857 .53399 L
.32976 .53457 L
.33095 .53515 L
.33214 .53573 L
.33333 .53629 L
.33452 .53685 L
.33571 .53741 L
.3369 .53796 L
.3381 .53851 L
.33929 .53903 L
.34048 .53956 L
.34167 .54007 L
Mistroke
.34286 .54057 L
.34405 .54106 L
.34524 .54155 L
.34643 .54204 L
.34762 .54252 L
.34881 .54299 L
.35 .54346 L
.35119 .54392 L
.35238 .54439 L
.35357 .54485 L
.35476 .54529 L
.35595 .54572 L
.35714 .54616 L
.35833 .54659 L
.35952 .54701 L
.36071 .54743 L
.3619 .54784 L
.3631 .54826 L
.36429 .54866 L
.36548 .54907 L
.36667 .54948 L
.36786 .54988 L
.36905 .55029 L
.37024 .55069 L
.37143 .55109 L
.37262 .55149 L
.37381 .55188 L
.375 .55226 L
.37619 .55264 L
.37738 .55302 L
.37857 .5534 L
.37976 .55377 L
.38095 .55414 L
.38214 .55451 L
.38333 .55488 L
.38452 .55524 L
.38571 .5556 L
.3869 .55595 L
.3881 .5563 L
.38929 .55664 L
.39048 .55697 L
.39167 .55731 L
.39286 .55763 L
.39405 .55796 L
.39524 .55828 L
.39643 .5586 L
.39762 .55892 L
.39881 .55923 L
.4 .55954 L
.40119 .55985 L
Mistroke
.40238 .56016 L
.40357 .56046 L
.40476 .56077 L
.40595 .56107 L
.40714 .56136 L
.40833 .56166 L
.40952 .56195 L
.41071 .56225 L
.4119 .56254 L
.4131 .56282 L
.41429 .56309 L
.41548 .56337 L
.41667 .56363 L
.41786 .5639 L
.41905 .56416 L
.42024 .56443 L
.42143 .56469 L
.42262 .56495 L
.42381 .5652 L
.425 .56545 L
.42619 .5657 L
.42738 .56594 L
.42857 .56618 L
.42976 .56641 L
.43095 .56664 L
.43214 .56687 L
.43333 .5671 L
.43452 .56733 L
.43571 .56755 L
.4369 .56778 L
.4381 .56801 L
.43929 .56823 L
.44048 .56846 L
.44167 .56868 L
.44286 .56891 L
.44405 .56913 L
.44524 .56935 L
.44643 .56957 L
.44762 .56979 L
.44881 .57 L
.45 .57022 L
.45119 .57044 L
.45238 .57065 L
.45357 .57087 L
.45476 .57108 L
.45595 .57128 L
.45714 .57147 L
.45833 .57167 L
.45952 .57186 L
.46071 .57205 L
Mistroke
.4619 .57224 L
.4631 .57243 L
.46429 .57262 L
.46548 .5728 L
.46667 .57299 L
.46786 .57318 L
.46905 .57336 L
.47024 .57355 L
.47143 .57373 L
.47262 .57391 L
.47381 .57409 L
.475 .57427 L
.47619 .57445 L
.47738 .57463 L
.47857 .5748 L
.47976 .57497 L
.48095 .57515 L
.48214 .57532 L
.48333 .57549 L
.48452 .57566 L
.48571 .57582 L
.4869 .57599 L
.4881 .57616 L
.48929 .57632 L
.49048 .57649 L
.49167 .57665 L
.49286 .57681 L
.49405 .57698 L
.49524 .57714 L
.49643 .5773 L
.49762 .57746 L
.49881 .57762 L
.5 .57778 L
.50119 .57794 L
.50238 .57809 L
.50357 .57825 L
.50476 .5784 L
.50595 .57855 L
.50714 .57871 L
.50833 .57886 L
.50952 .57901 L
.51071 .57916 L
.5119 .57931 L
.5131 .57945 L
.51429 .5796 L
.51548 .57975 L
.51667 .57989 L
.51786 .58004 L
.51905 .58018 L
.52024 .58033 L
Mistroke
.52143 .58047 L
.52262 .5806 L
.52381 .58074 L
.525 .58088 L
.52619 .58101 L
.52738 .58115 L
.52857 .58128 L
.52976 .58141 L
.53095 .58154 L
.53214 .58167 L
.53333 .58179 L
.53452 .58192 L
.53571 .58204 L
.5369 .58217 L
.5381 .58229 L
.53929 .58242 L
.54048 .58254 L
.54167 .58266 L
.54286 .58278 L
.54405 .5829 L
.54524 .58302 L
.54643 .58314 L
.54762 .58325 L
.54881 .58337 L
.55 .58348 L
.55119 .58359 L
.55238 .58371 L
.55357 .58382 L
.55476 .58393 L
.55595 .58404 L
.55714 .58415 L
.55833 .58426 L
.55952 .58437 L
.56071 .58447 L
.5619 .58458 L
.5631 .58468 L
.56429 .58478 L
.56548 .58488 L
.56667 .58498 L
.56786 .58509 L
.56905 .58519 L
.57024 .58529 L
.57143 .58538 L
.57262 .58548 L
.57381 .58558 L
.575 .58568 L
.57619 .58577 L
.57738 .58587 L
.57857 .58597 L
.57976 .58606 L
Mistroke
.58095 .58616 L
.58214 .58625 L
.58333 .58634 L
.58452 .58643 L
.58571 .58652 L
.5869 .58662 L
.5881 .58671 L
.58929 .5868 L
.59048 .58689 L
.59167 .58698 L
.59286 .58707 L
.59405 .58716 L
.59524 .58725 L
.59643 .58734 L
.59762 .58743 L
.59881 .58752 L
.6 .58761 L
.60119 .5877 L
.60238 .58778 L
.60357 .58787 L
.60476 .58796 L
.60595 .58805 L
.60714 .58813 L
.60833 .58822 L
.60952 .58831 L
.61071 .58839 L
.6119 .58848 L
.6131 .58856 L
.61429 .58864 L
.61548 .58873 L
.61667 .58881 L
.61786 .58889 L
.61905 .58897 L
.62024 .58905 L
.62143 .58913 L
.62262 .58921 L
.62381 .58929 L
.625 .58937 L
.62619 .58944 L
.62738 .58952 L
.62857 .5896 L
.62976 .58968 L
.63095 .58975 L
.63214 .58983 L
.63333 .58991 L
.63452 .58999 L
.63571 .59006 L
.6369 .59014 L
.6381 .59021 L
.63929 .59029 L
Mistroke
.64048 .59037 L
.64167 .59044 L
.64286 .59051 L
.64405 .59059 L
.64524 .59066 L
.64643 .59073 L
.64762 .59081 L
.64881 .59088 L
.65 .59095 L
.65119 .59102 L
.65238 .5911 L
.65357 .59117 L
.65476 .59124 L
.65595 .59131 L
.65714 .59138 L
.65833 .59145 L
.65952 .59152 L
.66071 .59159 L
.6619 .59165 L
.6631 .59172 L
.66429 .59179 L
.66548 .59185 L
.66667 .59192 L
.66786 .59199 L
.66905 .59205 L
.67024 .59211 L
.67143 .59218 L
.67262 .59224 L
.67381 .5923 L
.675 .59237 L
.67619 .59243 L
.67738 .59249 L
.67857 .59255 L
.67976 .59261 L
.68095 .59268 L
.68214 .59274 L
.68333 .5928 L
.68452 .59286 L
.68571 .59292 L
.6869 .59298 L
.6881 .59304 L
.68929 .5931 L
.69048 .59316 L
.69167 .59322 L
.69286 .59328 L
.69405 .59334 L
.69524 .59339 L
.69643 .59345 L
.69762 .59351 L
.69881 .59357 L
Mistroke
.7 .59363 L
.70119 .59369 L
.70238 .59374 L
.70357 .5938 L
.70476 .59386 L
.70595 .59391 L
.70714 .59397 L
.70833 .59402 L
.70952 .59408 L
.71071 .59413 L
.7119 .59419 L
.7131 .59424 L
.71429 .5943 L
.71548 .59435 L
.71667 .5944 L
.71786 .59445 L
.71905 .5945 L
.72024 .59455 L
.72143 .5946 L
.72262 .59465 L
.72381 .5947 L
.725 .59475 L
.72619 .5948 L
.72738 .59485 L
.72857 .59489 L
.72976 .59494 L
.73095 .59499 L
.73214 .59504 L
.73333 .59508 L
.73452 .59513 L
.73571 .59518 L
.7369 .59522 L
.7381 .59527 L
.73929 .59531 L
.74048 .59536 L
.74167 .59541 L
.74286 .59545 L
.74405 .5955 L
.74524 .59554 L
.74643 .59558 L
.74762 .59563 L
.74881 .59567 L
.75 .59571 L
.75119 .59575 L
.75238 .59579 L
.75357 .59583 L
.75476 .59587 L
.75595 .59591 L
.75714 .59595 L
.75833 .59599 L
Mistroke
.75952 .59603 L
.76071 .59607 L
.7619 .59611 L
.7631 .59615 L
.76429 .59619 L
.76548 .59623 L
.76667 .59627 L
.76786 .59631 L
.76905 .59635 L
.77024 .59639 L
.77143 .59643 L
.77262 .59646 L
.77381 .5965 L
.775 .59654 L
.77619 .59658 L
.77738 .59662 L
.77857 .59665 L
.77976 .59669 L
.78095 .59673 L
.78214 .59676 L
.78333 .5968 L
.78452 .59684 L
.78571 .59687 L
.7869 .59691 L
.7881 .59695 L
.78929 .59698 L
.79048 .59702 L
.79167 .59705 L
.79286 .59709 L
.79405 .59712 L
.79524 .59716 L
.79643 .59719 L
.79762 .59722 L
.79881 .59726 L
.8 .59729 L
.80119 .59732 L
.80238 .59736 L
.80357 .59739 L
.80476 .59742 L
.80595 .59746 L
.80714 .59749 L
.80833 .59752 L
.80952 .59755 L
.81071 .59759 L
.8119 .59762 L
.8131 .59765 L
.81429 .59768 L
.81548 .59771 L
.81667 .59775 L
.81786 .59778 L
Mistroke
.81905 .59781 L
.82024 .59784 L
.82143 .59787 L
.82262 .5979 L
.82381 .59794 L
.825 .59797 L
.82619 .598 L
.82738 .59803 L
.82857 .59806 L
.82976 .59809 L
.83095 .59812 L
.83214 .59815 L
.83333 .59818 L
.83452 .59821 L
.83571 .59824 L
.8369 .59827 L
.8381 .5983 L
.83929 .59833 L
.84048 .59836 L
.84167 .59839 L
.84286 .59842 L
.84405 .59845 L
.84524 .59848 L
.84643 .59851 L
.84762 .59854 L
.84881 .59857 L
.85 .5986 L
.85119 .59863 L
.85238 .59866 L
.85357 .59869 L
.85476 .59871 L
.85595 .59874 L
.85714 .59877 L
.85833 .5988 L
.85952 .59883 L
.86071 .59886 L
.8619 .59888 L
.8631 .59891 L
.86429 .59894 L
.86548 .59897 L
.86667 .59899 L
.86786 .59902 L
.86905 .59905 L
.87024 .59907 L
.87143 .5991 L
.87262 .59913 L
.87381 .59915 L
.875 .59918 L
.87619 .59921 L
.87738 .59923 L
Mistroke
.87857 .59926 L
.87976 .59929 L
.88095 .59931 L
.88214 .59934 L
.88333 .59936 L
.88452 .59939 L
.88571 .59941 L
.8869 .59944 L
.8881 .59946 L
.88929 .59949 L
.89048 .59952 L
.89167 .59954 L
.89286 .59957 L
.89405 .59959 L
.89524 .59961 L
.89643 .59964 L
.89762 .59966 L
.89881 .59969 L
.9 .59971 L
.90119 .59974 L
.90238 .59976 L
.90357 .59979 L
.90476 .59981 L
.90595 .59983 L
.90714 .59986 L
.90833 .59988 L
.90952 .5999 L
.91071 .59993 L
.9119 .59995 L
.9131 .59997 L
.91429 .6 L
.91548 .60002 L
.91667 .60004 L
.91786 .60007 L
.91905 .60009 L
.92024 .60011 L
.92143 .60014 L
.92262 .60016 L
.92381 .60018 L
.925 .6002 L
.92619 .60023 L
.92738 .60025 L
.92857 .60027 L
.92976 .60029 L
.93095 .60031 L
.93214 .60034 L
.93333 .60036 L
.93452 .60038 L
.93571 .6004 L
.9369 .60042 L
Mistroke
.9381 .60044 L
.93929 .60047 L
.94048 .60049 L
.94167 .60051 L
.94286 .60053 L
.94405 .60055 L
.94524 .60057 L
.94643 .60059 L
.94762 .60062 L
.94881 .60064 L
.95 .60066 L
.95119 .60068 L
.95238 .6007 L
.95357 .60072 L
.95476 .60074 L
.95595 .60076 L
.95714 .60078 L
.95833 .6008 L
.95952 .60082 L
.96071 .60084 L
.9619 .60086 L
.9631 .60088 L
.96429 .6009 L
.96548 .60092 L
.96667 .60094 L
.96786 .60096 L
.96905 .60097 L
.97024 .60099 L
.97143 .60101 L
.97262 .60103 L
.97381 .60105 L
.975 .60107 L
.97619 .60109 L
Mfstroke
.5 g
[ ] 0 setdash
.12407 0 m
.125 .00604 L
.12619 .01363 L
.12738 .02113 L
.12857 .02857 L
.12976 .03599 L
.13095 .04339 L
.13214 .05072 L
.13333 .05795 L
.13452 .06504 L
.13571 .07209 L
.1369 .0791 L
.1381 .08541 L
.13929 .0917 L
.14048 .09796 L
.14167 .1042 L
.14286 .11041 L
.14405 .11657 L
.14524 .12271 L
.14643 .12855 L
.14762 .13421 L
.14881 .13969 L
.15 .145 L
.15119 .15014 L
.15238 .15511 L
.15357 .15965 L
.15476 .16411 L
.15595 .16847 L
.15714 .1728 L
.15833 .17712 L
.15952 .18142 L
.16071 .18571 L
.1619 .18985 L
.1631 .19391 L
.16429 .19786 L
.16548 .20178 L
.16667 .20568 L
.16786 .20953 L
.16905 .21336 L
.17024 .21713 L
.17143 .22082 L
.17262 .22441 L
.17381 .22791 L
.175 .23135 L
.17619 .23471 L
.17738 .23791 L
.17857 .2411 L
.17976 .24425 L
.18095 .24737 L
.18214 .25042 L
Mistroke
.18333 .25343 L
.18452 .25641 L
.18571 .25938 L
.1869 .26234 L
.1881 .26518 L
.18929 .268 L
.19048 .27079 L
.19167 .27346 L
.19286 .2761 L
.19405 .27866 L
.19524 .28122 L
.19643 .28376 L
.19762 .28628 L
.19881 .2888 L
.2 .2913 L
.20119 .29367 L
.20238 .29599 L
.20357 .29829 L
.20476 .30058 L
.20595 .30284 L
.20714 .30507 L
.20833 .30728 L
.20952 .30948 L
.21071 .31168 L
.2119 .31387 L
.2131 .31606 L
.21429 .31823 L
.21548 .32038 L
.21667 .32252 L
.21786 .32465 L
.21905 .32675 L
.22024 .32882 L
.22143 .33084 L
.22262 .33285 L
.22381 .33485 L
.225 .33684 L
.22619 .33883 L
.22738 .3408 L
.22857 .34272 L
.22976 .34462 L
.23095 .34652 L
.23214 .34841 L
.23333 .35028 L
.23452 .35212 L
.23571 .3539 L
.2369 .35563 L
.2381 .35736 L
.23929 .35907 L
.24048 .36074 L
.24167 .36235 L
Mistroke
.24286 .36394 L
.24405 .36554 L
.24524 .36712 L
.24643 .36867 L
.24762 .37021 L
.24881 .37173 L
.25 .37324 L
.25119 .37474 L
.25238 .37622 L
.25357 .3777 L
.25476 .37917 L
.25595 .38063 L
.25714 .38207 L
.25833 .3835 L
.25952 .3849 L
.26071 .3863 L
.2619 .38766 L
.2631 .38899 L
.26429 .39031 L
.26548 .39162 L
.26667 .39292 L
.26786 .3942 L
.26905 .39548 L
.27024 .39674 L
.27143 .398 L
.27262 .39926 L
.27381 .40051 L
.275 .40173 L
.27619 .40293 L
.27738 .40413 L
.27857 .40527 L
.27976 .40641 L
.28095 .40754 L
.28214 .40866 L
.28333 .40976 L
.28452 .41087 L
.28571 .41194 L
.2869 .413 L
.2881 .41404 L
.28929 .41507 L
.29048 .41611 L
.29167 .41714 L
.29286 .41816 L
.29405 .41917 L
.29524 .42018 L
.29643 .42119 L
.29762 .42219 L
.29881 .42318 L
.3 .42417 L
.30119 .42515 L
Mistroke
.30238 .42612 L
.30357 .4271 L
.30476 .42806 L
.30595 .42902 L
.30714 .42998 L
.30833 .43093 L
.30952 .43188 L
.31071 .43282 L
.3119 .43375 L
.3131 .43468 L
.31429 .4356 L
.31548 .43651 L
.31667 .43738 L
.31786 .43824 L
.31905 .43909 L
.32024 .43994 L
.32143 .44078 L
.32262 .44161 L
.32381 .44243 L
.325 .44325 L
.32619 .44406 L
.32738 .44485 L
.32857 .44563 L
.32976 .44641 L
.33095 .44718 L
.33214 .44794 L
.33333 .44869 L
.33452 .44943 L
.33571 .45015 L
.3369 .45088 L
.3381 .45159 L
.33929 .4523 L
.34048 .45301 L
.34167 .45371 L
.34286 .45442 L
.34405 .45512 L
.34524 .45582 L
.34643 .45653 L
.34762 .45722 L
.34881 .45792 L
.35 .45862 L
.35119 .4593 L
.35238 .45998 L
.35357 .46065 L
.35476 .46132 L
.35595 .46199 L
.35714 .46264 L
.35833 .4633 L
.35952 .46396 L
.36071 .46461 L
Mistroke
.3619 .46526 L
.3631 .46591 L
.36429 .46655 L
.36548 .46719 L
.36667 .46782 L
.36786 .46844 L
.36905 .46905 L
.37024 .46966 L
.37143 .47027 L
.37262 .47088 L
.37381 .47149 L
.375 .4721 L
.37619 .4727 L
.37738 .4733 L
.37857 .4739 L
.37976 .47449 L
.38095 .47507 L
.38214 .47565 L
.38333 .47621 L
.38452 .47677 L
.38571 .47731 L
.3869 .47784 L
.3881 .47837 L
.38929 .4789 L
.39048 .47943 L
.39167 .47995 L
.39286 .48046 L
.39405 .48096 L
.39524 .48147 L
.39643 .48196 L
.39762 .48246 L
.39881 .48295 L
.4 .48343 L
.40119 .48391 L
.40238 .48439 L
.40357 .48486 L
.40476 .48533 L
.40595 .4858 L
.40714 .48626 L
.40833 .48672 L
.40952 .48718 L
.41071 .48764 L
.4119 .48809 L
.4131 .48854 L
.41429 .489 L
.41548 .48944 L
.41667 .48987 L
.41786 .49028 L
.41905 .49069 L
.42024 .4911 L
Mistroke
.42143 .49151 L
.42262 .49191 L
.42381 .49231 L
.425 .49271 L
.42619 .4931 L
.42738 .49349 L
.42857 .49388 L
.42976 .49427 L
.43095 .49466 L
.43214 .49504 L
.43333 .49542 L
.43452 .4958 L
.43571 .49618 L
.4369 .49654 L
.4381 .4969 L
.43929 .49727 L
.44048 .49763 L
.44167 .49799 L
.44286 .49834 L
.44405 .4987 L
.44524 .49905 L
.44643 .49939 L
.44762 .49974 L
.44881 .50008 L
.45 .50043 L
.45119 .50077 L
.45238 .50111 L
.45357 .50144 L
.45476 .50178 L
.45595 .50211 L
.45714 .50244 L
.45833 .50277 L
.45952 .5031 L
.46071 .50343 L
.4619 .50375 L
.4631 .50408 L
.46429 .5044 L
.46548 .50472 L
.46667 .50503 L
.46786 .50534 L
.46905 .50565 L
.47024 .50595 L
.47143 .50626 L
.47262 .50656 L
.47381 .50686 L
.475 .50715 L
.47619 .50745 L
.47738 .50774 L
.47857 .50803 L
.47976 .50832 L
Mistroke
.48095 .50861 L
.48214 .5089 L
.48333 .50918 L
.48452 .50947 L
.48571 .50974 L
.4869 .51002 L
.4881 .51029 L
.48929 .51056 L
.49048 .51084 L
.49167 .51111 L
.49286 .51138 L
.49405 .51165 L
.49524 .51191 L
.49643 .51218 L
.49762 .51244 L
.49881 .5127 L
.5 .51296 L
.50119 .51322 L
.50238 .51348 L
.50357 .51374 L
.50476 .514 L
.50595 .51425 L
.50714 .51451 L
.50833 .51477 L
.50952 .51502 L
.51071 .51528 L
.5119 .51553 L
.5131 .51579 L
.51429 .51604 L
.51548 .5163 L
.51667 .51655 L
.51786 .51681 L
.51905 .51706 L
.52024 .51731 L
.52143 .51757 L
.52262 .51782 L
.52381 .51807 L
.525 .51832 L
.52619 .51857 L
.52738 .51882 L
.52857 .51907 L
.52976 .51932 L
.53095 .51956 L
.53214 .5198 L
.53333 .52005 L
.53452 .52029 L
.53571 .52053 L
.5369 .52077 L
.5381 .52101 L
.53929 .52124 L
Mistroke
.54048 .52148 L
.54167 .52172 L
.54286 .52195 L
.54405 .52219 L
.54524 .52242 L
.54643 .52265 L
.54762 .52288 L
.54881 .52312 L
.55 .52334 L
.55119 .52357 L
.55238 .52379 L
.55357 .52402 L
.55476 .52424 L
.55595 .52446 L
.55714 .52469 L
.55833 .52491 L
.55952 .52513 L
.56071 .52535 L
.5619 .52556 L
.5631 .52578 L
.56429 .526 L
.56548 .52621 L
.56667 .52643 L
.56786 .52664 L
.56905 .52685 L
.57024 .52706 L
.57143 .52728 L
.57262 .52749 L
.57381 .5277 L
.575 .5279 L
.57619 .52811 L
.57738 .52832 L
.57857 .52853 L
.57976 .52873 L
.58095 .52894 L
.58214 .52914 L
.58333 .52935 L
.58452 .52955 L
.58571 .52976 L
.5869 .52996 L
.5881 .53017 L
.58929 .53037 L
.59048 .53056 L
.59167 .53076 L
.59286 .53096 L
.59405 .53116 L
.59524 .53135 L
.59643 .53155 L
.59762 .53175 L
.59881 .53194 L
Mistroke
.6 .53213 L
.60119 .53233 L
.60238 .53252 L
.60357 .53272 L
.60476 .53291 L
.60595 .5331 L
.60714 .53329 L
.60833 .53348 L
.60952 .53367 L
.61071 .53385 L
.6119 .53404 L
.6131 .53423 L
.61429 .53442 L
.61548 .53461 L
.61667 .5348 L
.61786 .53498 L
.61905 .53517 L
.62024 .53535 L
.62143 .53553 L
.62262 .53572 L
.62381 .5359 L
.625 .53609 L
.62619 .53627 L
.62738 .53645 L
.62857 .53663 L
.62976 .53681 L
.63095 .53699 L
.63214 .53717 L
.63333 .53735 L
.63452 .53753 L
.63571 .53771 L
.6369 .53788 L
.6381 .53806 L
.63929 .53823 L
.64048 .53841 L
.64167 .53858 L
.64286 .53875 L
.64405 .53893 L
.64524 .5391 L
.64643 .53927 L
.64762 .53944 L
.64881 .53961 L
.65 .53978 L
.65119 .53995 L
.65238 .54012 L
.65357 .54028 L
.65476 .54045 L
.65595 .54061 L
.65714 .54078 L
.65833 .54094 L
Mistroke
.65952 .5411 L
.66071 .54127 L
.6619 .54143 L
.6631 .54159 L
.66429 .54175 L
.66548 .54191 L
.66667 .54207 L
.66786 .54223 L
.66905 .54239 L
.67024 .54254 L
.67143 .5427 L
.67262 .54286 L
.67381 .54301 L
.675 .54317 L
.67619 .54332 L
.67738 .54348 L
.67857 .54363 L
.67976 .54379 L
.68095 .54394 L
.68214 .54409 L
.68333 .54425 L
.68452 .5444 L
.68571 .54455 L
.6869 .5447 L
.6881 .54485 L
.68929 .545 L
.69048 .54515 L
.69167 .5453 L
.69286 .54544 L
.69405 .54559 L
.69524 .54573 L
.69643 .54588 L
.69762 .54602 L
.69881 .54617 L
.7 .54631 L
.70119 .54645 L
.70238 .5466 L
.70357 .54674 L
.70476 .54688 L
.70595 .54702 L
.70714 .54716 L
.70833 .5473 L
.70952 .54744 L
.71071 .54758 L
.7119 .54772 L
.7131 .54786 L
.71429 .54799 L
.71548 .54813 L
.71667 .54827 L
.71786 .54841 L
Mistroke
.71905 .54854 L
.72024 .54868 L
.72143 .54881 L
.72262 .54895 L
.72381 .54908 L
.725 .54921 L
.72619 .54934 L
.72738 .54947 L
.72857 .5496 L
.72976 .54973 L
.73095 .54986 L
.73214 .54999 L
.73333 .55012 L
.73452 .55025 L
.73571 .55037 L
.7369 .5505 L
.7381 .55063 L
.73929 .55075 L
.74048 .55088 L
.74167 .551 L
.74286 .55112 L
.74405 .55125 L
.74524 .55137 L
.74643 .5515 L
.74762 .55162 L
.74881 .55174 L
.75 .55186 L
.75119 .55198 L
.75238 .55211 L
.75357 .55223 L
.75476 .55235 L
.75595 .55247 L
.75714 .55259 L
.75833 .55271 L
.75952 .55283 L
.76071 .55294 L
.7619 .55306 L
.7631 .55318 L
.76429 .5533 L
.76548 .55341 L
.76667 .55353 L
.76786 .55364 L
.76905 .55375 L
.77024 .55387 L
.77143 .55398 L
.77262 .55409 L
.77381 .55421 L
.775 .55432 L
.77619 .55443 L
.77738 .55454 L
Mistroke
.77857 .55465 L
.77976 .55476 L
.78095 .55487 L
.78214 .55498 L
.78333 .55509 L
.78452 .5552 L
.78571 .55531 L
.7869 .55542 L
.7881 .55552 L
.78929 .55563 L
.79048 .55574 L
.79167 .55585 L
.79286 .55595 L
.79405 .55606 L
.79524 .55616 L
.79643 .55627 L
.79762 .55638 L
.79881 .55648 L
.8 .55659 L
.80119 .55669 L
.80238 .5568 L
.80357 .5569 L
.80476 .557 L
.80595 .55711 L
.80714 .55721 L
.80833 .55731 L
.80952 .55741 L
.81071 .55752 L
.8119 .55762 L
.8131 .55772 L
.81429 .55782 L
.81548 .55792 L
.81667 .55802 L
.81786 .55812 L
.81905 .55822 L
.82024 .55832 L
.82143 .55842 L
.82262 .55852 L
.82381 .55862 L
.825 .55872 L
.82619 .55882 L
.82738 .55891 L
.82857 .55901 L
.82976 .55911 L
.83095 .55921 L
.83214 .5593 L
.83333 .5594 L
.83452 .5595 L
.83571 .55959 L
.8369 .55969 L
Mistroke
.8381 .55979 L
.83929 .55988 L
.84048 .55998 L
.84167 .56007 L
.84286 .56017 L
.84405 .56026 L
.84524 .56036 L
.84643 .56045 L
.84762 .56055 L
.84881 .56064 L
.85 .56073 L
.85119 .56083 L
.85238 .56092 L
.85357 .56102 L
.85476 .56111 L
.85595 .5612 L
.85714 .5613 L
.85833 .56139 L
.85952 .56148 L
.86071 .56157 L
.8619 .56167 L
.8631 .56176 L
.86429 .56185 L
.86548 .56194 L
.86667 .56203 L
.86786 .56212 L
.86905 .56222 L
.87024 .56231 L
.87143 .5624 L
.87262 .56249 L
.87381 .56258 L
.875 .56267 L
.87619 .56276 L
.87738 .56285 L
.87857 .56293 L
.87976 .56302 L
.88095 .56311 L
.88214 .5632 L
.88333 .56329 L
.88452 .56337 L
.88571 .56346 L
.8869 .56355 L
.8881 .56363 L
.88929 .56372 L
.89048 .5638 L
.89167 .56389 L
.89286 .56397 L
.89405 .56406 L
.89524 .56414 L
.89643 .56423 L
Mistroke
.89762 .56431 L
.89881 .5644 L
.9 .56448 L
.90119 .56456 L
.90238 .56465 L
.90357 .56473 L
.90476 .56482 L
.90595 .5649 L
.90714 .56498 L
.90833 .56507 L
.90952 .56515 L
.91071 .56523 L
.9119 .56532 L
.9131 .5654 L
.91429 .56548 L
.91548 .56556 L
.91667 .56565 L
.91786 .56573 L
.91905 .56581 L
.92024 .56589 L
.92143 .56597 L
.92262 .56605 L
.92381 .56613 L
.925 .56621 L
.92619 .56629 L
.92738 .56637 L
.92857 .56645 L
.92976 .56653 L
.93095 .56661 L
.93214 .56669 L
.93333 .56677 L
.93452 .56685 L
.93571 .56693 L
.9369 .56701 L
.9381 .56709 L
.93929 .56717 L
.94048 .56724 L
.94167 .56732 L
.94286 .5674 L
.94405 .56748 L
.94524 .56756 L
.94643 .56763 L
.94762 .56771 L
.94881 .56779 L
.95 .56786 L
.95119 .56794 L
.95238 .56802 L
.95357 .56809 L
.95476 .56817 L
.95595 .56825 L
Mistroke
.95714 .56832 L
.95833 .5684 L
.95952 .56847 L
.96071 .56855 L
.9619 .56863 L
.9631 .5687 L
.96429 .56878 L
.96548 .56885 L
.96667 .56893 L
.96786 .569 L
.96905 .56908 L
.97024 .56915 L
.97143 .56923 L
.97262 .5693 L
.97381 .56938 L
.975 .56945 L
.97619 .56952 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],

Cell["\<\
Since the cosine packet transform does best, we choose this as the \
preferred method to analyze the sound of the cricket. \
\>", "Text",
  CellTags->{"S2.1.4", "4.20"}],

Cell["\<\
99.5% of the total energy is contained in the first 251 \
coefficients. By keeping 99.5% of energy, we will make a relative error of \
about 7%.\
\>", "MathCaption",
  CellTags->{"S2.1.4", "4.21"}],

Cell[CellGroupData[{

Cell["Length[Select[Take[e[[1]], 300], # <= 0.995&]]", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.1.4"],

Cell[BoxData[
    \(250\)], "Output",
  CellLabel->"Out[16]= ",
  CellTags->"S2.1.4"]
}, Open  ]],

Cell["The inverse transform is applied to the compressed data.", "MathCaption",
  CellTags->{"S2.1.4", "4.22"}],

Cell["\<\
InverseCosPacketTransform[Compress[cp, 251],
Taper -> {Polynomial[3], 16}];\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.1.4"],

Cell["The sound is reproduced.", "MathCaption",
  CellTags->{"S2.1.4", "4.23"}],

Cell[CellGroupData[{

Cell["ListPlay[%, SampleRate -> 22050, PlayRange -> All]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
22050 4096 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
81827F7E7F81817F7F8080807F7F80808080807F7F808080807F7E7F8182807D7C8083827E7D
7D8083847F797A848A827576858E827275878D81747986897F797C8384807C7C8085837C797F
87857B777E87867C777D87877E777C85877F797C8385807B7D8183807E7E8080807F80808080
80808080808080808080808080808080808080808080808080808080808080808080807F7F7F
81817F7E8082817D7D8183807C7D83837E7B7F84837D7B8084817C7C8284807B7D83837E7C7F
83827E7D8082807E7E8081807F7F808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080807F7F81807D808581767C8C8873728A
91796E828F7F73818A7C75868E786D8596806879958A6F748B89787A8782777E8B82737A8B87
777885877C79818680797D85837C7D81807D808481797A848B8172768A907C6D7B8E897A777E
8183878071758E9578637C9D906A688A99806B798D8877798684787B89857577898A7773858E
7D707E8E85747788897A7783887D7882877D77818A80747C8A86777786897C7682897E778089
80757D8B867576888C7B717F8D8474798888797784887D77818980757C8A867876848A7F767D
87857B7A82847F7C80827F7D8083807C7E83837D7B8084817D7D8082807F7F7F8080807F7E7F
81807F7F8080807F808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
808080808080808080808080808080807F80807F7F81817E7D81837F7E80807D7F8582797A84
867D7A82837A7B8989766E849683677496956F6181A1936A5B7AA4A2705170A4A3745C769491
7A727E8883787A898C78687D9E93625A91B2824867B1AD5E438CC18B415DB2B5603D87C69642
4EA8C475356BC2B0503C96CC87355BBDBD593188D4983248B9CE62257EDBA3303FB7D76A1F6F
DAB53A2DA5E2821D56D3CB491E90E9981F42C9D959177EE7AA2933B8E26F1765DEC13C229CEA
8F1B47CED8541583EBA52238C3DE5E167DE7A4263EC3D75A1B82E5A1273DBFDC65186FE1BA36
24A2EC8D1744D1DE550F7DEFB02629B3EA7C1556D7CD491D8DE89C223FC4DC5F1576E8B32B2A
B3E9751262E2C13722A2EA89194BCFD655177EE8AD292EB5E774135FE0C83C1C99EE951A3FC9
E061126DE5C0371F9DED931A40CADF5E1172E9BA2F23A9EE85144BD5D952137DEAB22C29ACEA
82174FD3D553167DE9B12D28AAEB881945C9DE661665D9C64B2285DEA93733A1DC8E2C46B3D3
7B2C57B9C6723762B1B8764764A0AF84585E8AA79567567CA99F69527BA99B685A81A28F6967
8A99806877949072688398896E6E8793837176888A7D777F86817A7E85837A79838880777B86
887E777D87867B77808A847777848B80747A888A7B747E8B867875838B82767986897E767D87
867C788086837C7B8083827E7C7E8183807C7C8184807B7C8284807C7E82827F7D7F82817E7D
8082807E7E8081807E7F8081807F7F8081807F7F8081807F7E8081807E7E8082807E7E81827F
7D7F82817E7D8082807D7E81827F7D7F82817E7E81827F7D7F82817E7E81827F7D7F82817E7D
81827F7C7F83827D7C8184807B7D84847D7A8086827A7B83867F787D86857B78818882787A85
887E777D88867A77818982777A85887E767D88857A77828982787A85877D777E87847A798287
80787C85857D798086827A7B83867F797E85837C7A8185807A7D84847D7A8085827B7C83857F
7A7E85837C7A8186817A7C84857E797E85847C7A8186817A7B83867F797D85847C7981878179
7C85857B79828780787C87857A78828880777C87867B77808983787984887F777C87867B7781
8983787985887E777D87867A77818982787A85887D767F89827A7B84877B74848D7F757A8489
7F74828B7A7480868E8764639BAF784A69A9AD6E4F7A9D928071697F9A917365799794756A7E
8D887E7979828A80737D8C8677797E818989786A7699A46D4180CC973450C0C64F269FE77313
78E79C244FCDC44226A8EB770E60E6C5341FABED750E6AEDB6212AC4EB5F0D7BECA31F44D3D1
3C1DACEF720C68EFBE1F20C5F664036BEFC1291FBBF25F0582F8A1173BCCD8542A94C1725291
A86C4D88C28E3352C6CA501F8BEA9D1A3FD6D73F19A5F17E0B56E8D3370F9CF890104BDED13A
16A5F8820654EBCE2E17B1F6720669F2BB2023C0F3680269F6C32219B7FB76025BEFCD2E15AA
F9830850E7D8370B9EFF8E0648E5D73812A3F8830855EACE2E15ACFA7E0556EACE3317A6F584
0A4EE4D63B0F9BFA920D42DADF4A0B88F7A61630CBEC5D0574F6B71D23C0F36A0667F0BF2622
B9F16D0969EDBD2A24B3EF770D5DE6C93219A9F67E0757EBCE3215A4F78A0C49DDDC460C8AF8
A5162FC8ED63076CF0C0291CAFF781084DE3DB430A8BF9A8182BC2F06E095DE6CF3C1392F5A2
192EC0F0730954E2D9470E82F0AF282DAFE17A2363CBB44A3F9FC7753775C6A0414AAEC76A2F
78CEA54143A6C977366BBEAC554491BF894860A5AC70527CA691646790997767829882687796
8E6F6C8793806F7A8B87787784887F797C8286837A757F8E8A746C8297896B6B8A9983686F8D
97816B738A918072778588817C7D7F7E8186837876838F84717289937E6A789290736A839786
6B718E937A6A7D938970728A907B6F7F908571768C8D776F8392836E768E8F786D8091877173
888F7E717B8C887875838B80757C8A877775858D7E717C8E887473878F7D6F7C8F887373878F
7E707C8D887674858D7F737B89877A76818882797B8385807B7D82837F7C7E82827F7D7F8180
7F7F80808080807F7F8081807E7E81827F7C7E83837E7B7F84827C7B8185817A7C83857F7A7E
84847C7A8185807A7D85847C7A818681797C85857C78808782797A84877F787D86857D797F86
847C7A8086837C7A8086827B7B8286807A7D84837D7B8184807B7E83837D7C8184807C7D8383
7E7C8084817C7C82847F7B7E84837C7B82857F7A7E86837B7A83877F787D87857A7883897F76
7C88867976838A80757B89887975828B827579878A7D757D89877A76818983787984887F777D
87857B79818780787D86847B7B82847F7B7E83857E787F8781787E8982757A8788807B777889
967F5F6E9EA26E5581A88A5F709791716D86947E6B80937E6E7F908770718F93736B87928170
738C967764829B86677096976963989F655E99A66A4F8EBB7B3A79C7913F66B6A15158ABAE57
4AA3BE6A387FCD9B3349C1CC54248FE08F2553CBC64D2694E18C2155D2C44129A6E1721B74E1
A32746CACC4A249CE4811C5EDABF3A29AAE374196DDFAD2E3EBFD0542695DE822163D8B63531
B3E16A1573E8AD2435C5DF571489EE96184BD8CF3F1CA3EF7E0F5EE7C02B26BAE9640E7BEFA6
1C39CDE051108BF3991444D9D942119BF88B0A4FE5D13417A9F57C0A5EE9C32C22B4EF710B69
EEB8222AC4EB5A0781FAA40F38DAE5450894FD940A46E1D73B13A1F6840B56E7CA301AAEF679
065DEEC92A18B2F978045CEFC92A19B2F6760660EEC6291CB3F575065FEEC62B1BB1F577085E
EBC52D1DB1F3760860EDC82B17AEFB81044DE8D9390E9DFA8E0D49DED9430E91F99F1033D2EF
590074FBBB1B1FBEF871035BEDD03211A2FC8E0842E0E4470586FDAC1628C5F26A0564EEC82F
15A5FC8E063DDFE94D037FF9B11C26BCF3750956E4D53F0D8FFCA71225C5FA75024FE2DD4A0B
81F3B12123B5F7820741D9EC5D0463EACF411487E9AD332F9CD595434E93AE8D6B6B79818C95
85666286A5956A5C789A9B7F6669849B937463779494796A7A928D736B849887686B8E9D8062
71959775667F97876D748F8E746E86927E6D7D91856E76908F716B88997F657797916E688A9B
7E647798916D688A9A7E64799A9069648DA4825A6B9CA1745A7A9E906B6C8D947669849A8565
6E92997C68778D8C7E797F7D7A838E846D6E8D9C80606F999F745878A599675A87A88B5D6697
A2765B7BA18F666A9198766884967F6B7D94876D728E937A6A7A929076687C98926E6386A187
5F6B999E735D7EA08F68678A9B84686F8D988169708C97846B6B869D8D686187A58E62608BA4
8A63668A9C886D6B82948B756E7D8E8C7B727B88898078798188877B747C8B8B7B707B8D8C79
6F7D8F8C776D7E918B756E8090887572828D8577778288817B7D82827F7F81807E7E81827F7D
7F81817F7F8080808080807F7F8080807F7F81817F7D7F82827F7D7F83827E7C8083817D7C81
83817C7D8183807C7E82837F7C7E83827E7C7F83827D7C8083817D7D8183807C7D8183807C7E
83837D7A818781787C87867A76828A80747B8A887874838D81737A8A8A7973818C837478888A
7B747F8B847677868A7D757E8A85787885897E767E8884797983877F787E86837B7B83857E7A
7F84827C7D82837E7C8083807C7F83817D7E82827E7C81837F7C7F83827C7D82847E7B808481
7B7D83847E7B8085817B7D83847D7B8085817B7D83837D7B8084807B7E83837D7C8183807C7E
83827D7D81837F7C7F83817D7D81827F7C7F83817D7E82827E7C8083817C7D82837E7C808481
7C7D83847E7B7F85827B7C83857E797E86837B7A83867F787D86847A79828880777C87867A77
828981767B87877B76818A82767A87887B75818A83767987897C75808A83767886897C757F8A
84777886897D757E8985787884897E767D88857978838980777C87867B77818881787B86877D
777F8883797984887F777D87857A78828880777B86877B77808982777A86887D767F89847878
84897E767D89857977838980767C88867A77828981777B87867B77818881787B85867C788087
827A7C84857D7A8085827B7C83847E7B7F84817C7D82837F7D7F82817D7E81827F7E8082807E
7F81817F7E8081807E7F81817E7E8082807D7F82817E7D8083807C7E82827E7C8084817C7D83
847E7B7F85827B7C83857E7A7E85837B7A82867F797D86847B79828780797C85857C79808681
7A7C84857E7A7F85827B7B8285807B7E83837E7C8083817D7D8182807D7E
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.1.4"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"S2.1.4"]
}, Open  ]],

Cell[TextData[{
  "This is the relative error due to compression by a compression ratio of \
about 16.3 (",
  Cell[BoxData[
      \(TraditionalForm\`\( \[TildeTilde] 4096/251\)\)], "InlineFormula",
    CellTags->"S2.1.4"],
  ")."
}], "MathCaption",
  CellTags->{"S2.1.4", "4.24"}],

Cell[CellGroupData[{

Cell["Sqrt[1-e[[1]][[251]]]", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S2.1.4"],

Cell[BoxData[
    \(0.0705779758018575087`\)], "Output",
  CellLabel->"Out[19]= ",
  CellTags->"S2.1.4"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 207}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 90, 1, 52, "Section",
      CellTags->"Contents"],
    Cell[1802, 52, 578, 18, 78, "Contents",
      CellTags->"Contents"]},
  "S2.1.0"->{
    Cell[2383, 72, 97, 1, 52, "Section",
      CellTags->{"S2.1.0", "0.1"}]},
  "0.1"->{
    Cell[2383, 72, 97, 1, 52, "Section",
      CellTags->{"S2.1.0", "0.1"}]},
  "S2.1.1"->{
    Cell[2483, 75, 93, 1, 36, "Subsection",
      CellTags->{"S2.1.1", "1.1"}],
    Cell[2579, 78, 255, 5, 36, "Text",
      CellTags->{"S2.1.1", "1.2"}],
    Cell[2837, 85, 294, 6, 28, "DisplayFormula",
      CellTags->{"S2.1.1", "1.3"}],
    Cell[3134, 93, 2431, 58, 193, "Text",
      CellTags->{"S2.1.1", "1.4"}],
    Cell[5568, 153, 68, 1, 34, "Subsubsection",
      CellTags->{"S2.1.1", "1.5"}],
    Cell[5639, 156, 724, 22, 42, "Text",
      CellTags->{"S2.1.1", "1.6"}],
    Cell[6366, 180, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.7"}],
    Cell[6446, 183, 93, 2, 28, "Input",
      CellTags->"S2.1.1"],
    Cell[6542, 187, 187, 7, 29, "MathCaption",
      CellTags->{"S2.1.1", "1.8"}],
    Cell[6732, 196, 141, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[6876, 203, 336, 8, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.9"}],
    Cell[7237, 215, 268, 8, 96, "Input",
      CellTags->"S2.1.1"],
    Cell[7508, 225, 37233, 1485, 186, 23471, 1311, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.1"],
    Cell[44756, 1713, 245, 5, 36, "Text",
      CellTags->{"S2.1.1", "1.10"}],
    Cell[45004, 1720, 116, 2, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.11"}],
    Cell[45123, 1724, 93, 2, 28, "Input",
      CellTags->"S2.1.1"],
    Cell[45219, 1728, 197, 5, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.12"}],
    Cell[45419, 1735, 104, 2, 28, "Input",
      CellTags->"S2.1.1"],
    Cell[45526, 1739, 469, 15, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.13"}],
    Cell[46020, 1758, 80, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[46103, 1762, 120, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[46238, 1768, 1358, 41, 70, "Text",
      CellTags->{"S2.1.1", "1.14"}],
    Cell[47599, 1811, 239, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.15"}],
    Cell[47863, 1820, 169, 6, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[48035, 1828, 37464, 3347, 70, 37391, 3344, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[85514, 5178, 106, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.16"}],
    Cell[85645, 5183, 191, 6, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[85839, 5191, 4559, 362, 70, 4486, 359, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[90413, 5556, 2626, 62, 70, "Text",
      CellTags->{"S2.1.1", "1.17"}],
    Cell[93042, 5620, 291, 7, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.18"}],
    Cell[93358, 5631, 183, 6, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[93544, 5639, 4778, 248, 70, 4705, 245, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[98337, 5890, 156, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.19"}],
    Cell[98518, 5899, 193, 6, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[98714, 5907, 2088, 150, 70, 2015, 147, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[100817, 6060, 348, 10, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.20"}],
    Cell[101190, 6074, 226, 7, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[101419, 6083, 4777, 248, 70, 4704, 245, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[106211, 6334, 312, 6, 70, "Text",
      CellTags->{"S2.1.1", "1.21"}],
    Cell[106526, 6342, 173, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.22"}],
    Cell[106702, 6349, 101, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[106806, 6353, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.23"}],
    Cell[106932, 6358, 142, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[107077, 6365, 3968, 268, 70, 3895, 265, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[111060, 6636, 232, 7, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.24"}],
    Cell[111317, 6647, 73, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[111393, 6651, 104, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[111512, 6657, 1959, 56, 70, "Text",
      CellTags->{"S2.1.1", "1.25"}],
    Cell[113474, 6715, 158, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.26"}],
    Cell[113635, 6722, 137, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[113775, 6729, 162, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.27"}],
    Cell[113962, 6737, 168, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[114133, 6744, 4221, 287, 70, 4148, 284, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[118369, 7034, 145, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.28"}],
    Cell[118539, 7042, 105, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[118647, 7046, 84, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[118746, 7052, 116, 2, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.29"}],
    Cell[118887, 7058, 72, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[118962, 7062, 103, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[119080, 7068, 1817, 63, 70, "Text",
      CellTags->{"S2.1.1", "1.30"}],
    Cell[120900, 7133, 144, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.31"}],
    Cell[121047, 7139, 86, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[121136, 7143, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.32"}],
    Cell[121240, 7146, 110, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[121353, 7150, 129, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.33"}],
    Cell[121507, 7158, 180, 6, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[121690, 7166, 22884, 1276, 70, 22811, 1273, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[144589, 8445, 247, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.34"}],
    Cell[144861, 8454, 89, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[144953, 8458, 104, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[145072, 8464, 131, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.35"}],
    Cell[145228, 8472, 116, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[145347, 8476, 105, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[145467, 8482, 132, 4, 70, "Text",
      CellTags->{"S2.1.1", "1.36"}],
    Cell[145602, 8488, 141, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.37"}],
    Cell[145746, 8494, 140, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[145889, 8501, 244, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.38"}],
    Cell[146158, 8510, 222, 7, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[146383, 8519, 5263, 358, 70, 5190, 355, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[151661, 8880, 392, 7, 70, "Text",
      CellTags->{"S2.1.1", "1.39"}],
    Cell[152056, 8889, 137, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.40"}],
    Cell[152196, 8895, 117, 2, 28, "Input",
      CellTags->"S2.1.1"],
    Cell[152316, 8899, 363, 9, 56, "MathCaption",
      CellTags->{"S2.1.1", "1.41"}],
    Cell[152704, 8912, 159, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[152866, 8919, 34029, 1426, 186, 22917, 1285, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.1"],
    Cell[186910, 10348, 95, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.42"}],
    Cell[187030, 10353, 146, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[187179, 10360, 128, 3, 20, "Output",
      CellTags->"S2.1.1"],
    Cell[187322, 10366, 70, 1, 34, "Subsubsection",
      CellTags->{"S2.1.1", "1.43"}],
    Cell[187395, 10369, 690, 17, 65, "Text",
      CellTags->{"S2.1.1", "1.44"}],
    Cell[188088, 10388, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.45"}],
    Cell[188169, 10391, 93, 2, 28, "Input",
      CellTags->"S2.1.1"],
    Cell[188265, 10395, 93, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.46"}],
    Cell[188361, 10398, 141, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[188505, 10405, 268, 7, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.47"}],
    Cell[188798, 10416, 163, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[188964, 10423, 22349, 1234, 186, 22276, 1231, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[211328, 11660, 407, 12, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.48"}],
    Cell[211738, 11674, 145, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[211886, 11681, 164, 4, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.49"}],
    Cell[212075, 11689, 137, 5, 45, "Input",
      CellTags->"S2.1.1"],
    Cell[212215, 11696, 36698, 3239, 186, 36625, 3236, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[248928, 14938, 135, 4, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.50"}],
    Cell[249088, 14946, 210, 6, 62, "Input",
      CellTags->"S2.1.1"],
    Cell[249301, 14954, 1870, 122, 70, 1797, 119, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[251186, 15079, 160, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.51"}],
    Cell[251349, 15086, 136, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[251488, 15093, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.52"}],
    Cell[251653, 15101, 167, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[251823, 15108, 3276, 221, 70, 3203, 218, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[255114, 15332, 117, 2, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.53"}],
    Cell[255256, 15338, 71, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[255330, 15342, 102, 3, 70, "Output",
      CellTags->"S2.1.1"],
    Cell[255447, 15348, 347, 9, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.54"}],
    Cell[255797, 15359, 139, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[255939, 15366, 134, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.55"}],
    Cell[256098, 15374, 159, 5, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[256260, 15381, 22364, 1237, 70, 22291, 1234, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[278639, 16621, 224, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.56"}],
    Cell[278888, 16630, 289, 9, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[279180, 16641, 35849, 2304, 70, 35776, 2301, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[315044, 18948, 106, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.57"}],
    Cell[315153, 18951, 87, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[315243, 18955, 131, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.58"}],
    Cell[315377, 18961, 107, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[315487, 18965, 143, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.59"}],
    Cell[315655, 18973, 283, 9, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[315941, 18984, 35841, 2304, 70, 35768, 2301, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[351797, 21291, 1881, 49, 70, "Text",
      CellTags->{"S2.1.1", "1.60"}],
    Cell[353681, 21342, 191, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.61"}],
    Cell[353897, 21351, 250, 7, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[354150, 21360, 19455, 1292, 70, 19382, 1289, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[373620, 22655, 137, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.62"}],
    Cell[373760, 22661, 106, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[373869, 22665, 177, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.63"}],
    Cell[374071, 22673, 223, 7, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[374297, 22682, 22152, 1436, 70, 22079, 1433, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[396464, 24121, 536, 11, 70, "Text",
      CellTags->{"S2.1.1", "1.64"}],
    Cell[397003, 24134, 141, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.65"}],
    Cell[397147, 24140, 119, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[397269, 24144, 238, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.66"}],
    Cell[397532, 24153, 267, 8, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[397802, 24163, 35729, 2298, 70, 35656, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.1"],
    Cell[433546, 26464, 134, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.67"}],
    Cell[433683, 26470, 107, 2, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[433793, 26474, 257, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.68"}],
    Cell[434075, 26483, 267, 8, 70, "Input",
      CellTags->"S2.1.1"],
    Cell[434345, 26493, 55852, 2548, 186, 35684, 2295, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.1"]},
  "1.1"->{
    Cell[2483, 75, 93, 1, 36, "Subsection",
      CellTags->{"S2.1.1", "1.1"}]},
  "1.2"->{
    Cell[2579, 78, 255, 5, 36, "Text",
      CellTags->{"S2.1.1", "1.2"}]},
  "1.3"->{
    Cell[2837, 85, 294, 6, 28, "DisplayFormula",
      CellTags->{"S2.1.1", "1.3"}]},
  "1.4"->{
    Cell[3134, 93, 2431, 58, 193, "Text",
      CellTags->{"S2.1.1", "1.4"}]},
  "1.5"->{
    Cell[5568, 153, 68, 1, 34, "Subsubsection",
      CellTags->{"S2.1.1", "1.5"}]},
  "1.6"->{
    Cell[5639, 156, 724, 22, 42, "Text",
      CellTags->{"S2.1.1", "1.6"}]},
  "1.7"->{
    Cell[6366, 180, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.7"}]},
  "1.8"->{
    Cell[6542, 187, 187, 7, 29, "MathCaption",
      CellTags->{"S2.1.1", "1.8"}]},
  "1.9"->{
    Cell[6876, 203, 336, 8, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.9"}]},
  "1.10"->{
    Cell[44756, 1713, 245, 5, 36, "Text",
      CellTags->{"S2.1.1", "1.10"}]},
  "1.11"->{
    Cell[45004, 1720, 116, 2, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.11"}]},
  "1.12"->{
    Cell[45219, 1728, 197, 5, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.12"}]},
  "1.13"->{
    Cell[45526, 1739, 469, 15, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.13"}]},
  "1.14"->{
    Cell[46238, 1768, 1358, 41, 70, "Text",
      CellTags->{"S2.1.1", "1.14"}]},
  "1.15"->{
    Cell[47599, 1811, 239, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.15"}]},
  "1.16"->{
    Cell[85514, 5178, 106, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.16"}]},
  "1.17"->{
    Cell[90413, 5556, 2626, 62, 70, "Text",
      CellTags->{"S2.1.1", "1.17"}]},
  "1.18"->{
    Cell[93042, 5620, 291, 7, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.18"}]},
  "1.19"->{
    Cell[98337, 5890, 156, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.19"}]},
  "1.20"->{
    Cell[100817, 6060, 348, 10, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.20"}]},
  "1.21"->{
    Cell[106211, 6334, 312, 6, 70, "Text",
      CellTags->{"S2.1.1", "1.21"}]},
  "1.22"->{
    Cell[106526, 6342, 173, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.22"}]},
  "1.23"->{
    Cell[106806, 6353, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.23"}]},
  "1.24"->{
    Cell[111060, 6636, 232, 7, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.24"}]},
  "1.25"->{
    Cell[111512, 6657, 1959, 56, 70, "Text",
      CellTags->{"S2.1.1", "1.25"}]},
  "1.26"->{
    Cell[113474, 6715, 158, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.26"}]},
  "1.27"->{
    Cell[113775, 6729, 162, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.27"}]},
  "1.28"->{
    Cell[118369, 7034, 145, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.28"}]},
  "1.29"->{
    Cell[118746, 7052, 116, 2, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.29"}]},
  "1.30"->{
    Cell[119080, 7068, 1817, 63, 70, "Text",
      CellTags->{"S2.1.1", "1.30"}]},
  "1.31"->{
    Cell[120900, 7133, 144, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.31"}]},
  "1.32"->{
    Cell[121136, 7143, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.32"}]},
  "1.33"->{
    Cell[121353, 7150, 129, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.33"}]},
  "1.34"->{
    Cell[144589, 8445, 247, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.34"}]},
  "1.35"->{
    Cell[145072, 8464, 131, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.35"}]},
  "1.36"->{
    Cell[145467, 8482, 132, 4, 70, "Text",
      CellTags->{"S2.1.1", "1.36"}]},
  "1.37"->{
    Cell[145602, 8488, 141, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.37"}]},
  "1.38"->{
    Cell[145889, 8501, 244, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.38"}]},
  "1.39"->{
    Cell[151661, 8880, 392, 7, 70, "Text",
      CellTags->{"S2.1.1", "1.39"}]},
  "1.40"->{
    Cell[152056, 8889, 137, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.40"}]},
  "1.41"->{
    Cell[152316, 8899, 363, 9, 56, "MathCaption",
      CellTags->{"S2.1.1", "1.41"}]},
  "1.42"->{
    Cell[186910, 10348, 95, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.42"}]},
  "1.43"->{
    Cell[187322, 10366, 70, 1, 34, "Subsubsection",
      CellTags->{"S2.1.1", "1.43"}]},
  "1.44"->{
    Cell[187395, 10369, 690, 17, 65, "Text",
      CellTags->{"S2.1.1", "1.44"}]},
  "1.45"->{
    Cell[188088, 10388, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.45"}]},
  "1.46"->{
    Cell[188265, 10395, 93, 1, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.46"}]},
  "1.47"->{
    Cell[188505, 10405, 268, 7, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.47"}]},
  "1.48"->{
    Cell[211328, 11660, 407, 12, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.48"}]},
  "1.49"->{
    Cell[211886, 11681, 164, 4, 42, "MathCaption",
      CellTags->{"S2.1.1", "1.49"}]},
  "1.50"->{
    Cell[248928, 14938, 135, 4, 28, "MathCaption",
      CellTags->{"S2.1.1", "1.50"}]},
  "1.51"->{
    Cell[251186, 15079, 160, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.51"}]},
  "1.52"->{
    Cell[251488, 15093, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.52"}]},
  "1.53"->{
    Cell[255114, 15332, 117, 2, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.53"}]},
  "1.54"->{
    Cell[255447, 15348, 347, 9, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.54"}]},
  "1.55"->{
    Cell[255939, 15366, 134, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.55"}]},
  "1.56"->{
    Cell[278639, 16621, 224, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.56"}]},
  "1.57"->{
    Cell[315044, 18948, 106, 1, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.57"}]},
  "1.58"->{
    Cell[315243, 18955, 131, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.58"}]},
  "1.59"->{
    Cell[315487, 18965, 143, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.59"}]},
  "1.60"->{
    Cell[351797, 21291, 1881, 49, 70, "Text",
      CellTags->{"S2.1.1", "1.60"}]},
  "1.61"->{
    Cell[353681, 21342, 191, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.61"}]},
  "1.62"->{
    Cell[373620, 22655, 137, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.62"}]},
  "1.63"->{
    Cell[373869, 22665, 177, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.63"}]},
  "1.64"->{
    Cell[396464, 24121, 536, 11, 70, "Text",
      CellTags->{"S2.1.1", "1.64"}]},
  "1.65"->{
    Cell[397003, 24134, 141, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.65"}]},
  "1.66"->{
    Cell[397269, 24144, 238, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.66"}]},
  "1.67"->{
    Cell[433546, 26464, 134, 4, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.67"}]},
  "1.68"->{
    Cell[433793, 26474, 257, 5, 70, "MathCaption",
      CellTags->{"S2.1.1", "1.68"}]},
  "S2.1.2"->{
    Cell[490212, 29044, 68, 1, 36, "Subsection",
      CellTags->{"S2.1.2", "2.1"}],
    Cell[490283, 29047, 884, 23, 65, "Text",
      CellTags->{"S2.1.2", "2.2"}],
    Cell[491170, 29072, 1281, 35, 49, "DisplayFormula",
      CellTags->{"S2.1.2", "2.3"}],
    Cell[492454, 29109, 1568, 31, 207, "Text",
      CellTags->{"S2.1.2", "2.4"}],
    Cell[494025, 29142, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.5"}],
    Cell[494105, 29145, 93, 2, 28, "Input",
      CellTags->"S2.1.2"],
    Cell[494201, 29149, 92, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.6"}],
    Cell[494296, 29152, 133, 3, 45, "Input",
      CellTags->"S2.1.2"],
    Cell[494432, 29157, 74, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.7"}],
    Cell[494531, 29162, 138, 5, 45, "Input",
      CellTags->"S2.1.2"],
    Cell[494672, 29169, 91714, 4676, 186, 68212, 4382, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.2"],
    Cell[586401, 33848, 128, 4, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.8"}],
    Cell[586532, 33854, 136, 5, 45, "Input",
      CellTags->"S2.1.2"],
    Cell[586671, 33861, 200, 5, 42, "MathCaption",
      CellTags->{"S2.1.2", "2.9"}],
    Cell[586874, 33868, 111, 2, 28, "Input",
      CellTags->"S2.1.2"],
    Cell[586988, 33872, 131, 4, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.10"}],
    Cell[587122, 33878, 125, 5, 45, "Input",
      CellTags->"S2.1.2"],
    Cell[587250, 33885, 91, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.11"}],
    Cell[587366, 33890, 135, 5, 45, "Input",
      CellTags->"S2.1.2"],
    Cell[587504, 33897, 68315, 4382, 186, 68242, 4379, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.2"],
    Cell[655834, 38282, 292, 8, 70, "Text",
      CellTags->{"S2.1.2", "2.12"}],
    Cell[656129, 38292, 1071, 30, 70, "DisplayFormula",
      CellTags->{"S2.1.2", "2.13"}],
    Cell[657203, 38324, 103, 1, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.14"}],
    Cell[657309, 38327, 111, 2, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[657423, 38331, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.15"}],
    Cell[657657, 38340, 186, 6, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[657846, 38348, 68256, 4382, 70, 68183, 4379, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.2"],
    Cell[726117, 42733, 227, 7, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.16"}],
    Cell[726347, 42742, 110, 2, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[726460, 42746, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.17"}],
    Cell[726586, 42751, 187, 6, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[726776, 42759, 68156, 4376, 70, 68083, 4373, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.2"],
    Cell[794947, 47138, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.18"}],
    Cell[795090, 47144, 187, 6, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[795280, 47152, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.19"}],
    Cell[795514, 47161, 187, 6, 70, "Input",
      CellTags->"S2.1.2"],
    Cell[795704, 47169, 68129, 4373, 70, 68056, 4370, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.2"]},
  "2.1"->{
    Cell[490212, 29044, 68, 1, 36, "Subsection",
      CellTags->{"S2.1.2", "2.1"}]},
  "2.2"->{
    Cell[490283, 29047, 884, 23, 65, "Text",
      CellTags->{"S2.1.2", "2.2"}]},
  "2.3"->{
    Cell[491170, 29072, 1281, 35, 49, "DisplayFormula",
      CellTags->{"S2.1.2", "2.3"}]},
  "2.4"->{
    Cell[492454, 29109, 1568, 31, 207, "Text",
      CellTags->{"S2.1.2", "2.4"}]},
  "2.5"->{
    Cell[494025, 29142, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.5"}]},
  "2.6"->{
    Cell[494201, 29149, 92, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.6"}]},
  "2.7"->{
    Cell[494432, 29157, 74, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.7"}]},
  "2.8"->{
    Cell[586401, 33848, 128, 4, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.8"}]},
  "2.9"->{
    Cell[586671, 33861, 200, 5, 42, "MathCaption",
      CellTags->{"S2.1.2", "2.9"}]},
  "2.10"->{
    Cell[586988, 33872, 131, 4, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.10"}]},
  "2.11"->{
    Cell[587250, 33885, 91, 1, 28, "MathCaption",
      CellTags->{"S2.1.2", "2.11"}]},
  "2.12"->{
    Cell[655834, 38282, 292, 8, 70, "Text",
      CellTags->{"S2.1.2", "2.12"}]},
  "2.13"->{
    Cell[656129, 38292, 1071, 30, 70, "DisplayFormula",
      CellTags->{"S2.1.2", "2.13"}]},
  "2.14"->{
    Cell[657203, 38324, 103, 1, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.14"}]},
  "2.15"->{
    Cell[657423, 38331, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.15"}]},
  "2.16"->{
    Cell[726117, 42733, 227, 7, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.16"}]},
  "2.17"->{
    Cell[726460, 42746, 101, 1, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.17"}]},
  "2.18"->{
    Cell[794947, 47138, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.18"}]},
  "2.19"->{
    Cell[795280, 47152, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.2", "2.19"}]},
  "S2.1.3"->{
    Cell[863848, 51545, 101, 1, 70, "Subsection",
      CellTags->{"S2.1.3", "3.1"}],
    Cell[863952, 51548, 200, 5, 70, "Text",
      CellTags->{"S2.1.3", "3.2"}],
    Cell[864155, 51555, 68, 1, 70, "Subsubsection",
      CellTags->{"S2.1.3", "3.3"}],
    Cell[864226, 51558, 787, 22, 70, "Text",
      CellTags->{"S2.1.3", "3.4"}],
    Cell[865016, 51582, 77, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.5"}],
    Cell[865096, 51585, 93, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[865192, 51589, 87, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.6"}],
    Cell[865304, 51594, 161, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[865468, 51601, 12371, 805, 70, 12298, 802, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[877854, 52409, 230, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.7"}],
    Cell[878087, 52418, 111, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[878201, 52422, 2821, 69, 70, "Text",
      CellTags->{"S2.1.3", "3.8"}],
    Cell[881025, 52493, 177, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.9"}],
    Cell[881205, 52499, 143, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[881351, 52506, 151, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.10"}],
    Cell[881527, 52514, 82, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[881612, 52518, 129, 3, 70, "Output",
      CellTags->"S2.1.3"],
    Cell[881756, 52524, 1286, 38, 70, "Text",
      CellTags->{"S2.1.3", "3.11"}],
    Cell[883045, 52564, 311, 6, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.12"}],
    Cell[883381, 52574, 163, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[883547, 52581, 46302, 4082, 70, 46229, 4079, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[929864, 56666, 385, 11, 70, "Text",
      CellTags->{"S2.1.3", "3.13"}],
    Cell[930252, 56679, 258, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.14"}],
    Cell[930513, 56686, 87, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[930603, 56690, 344, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.15"}],
    Cell[930972, 56701, 93, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[931068, 56705, 2542, 202, 70, 2469, 199, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[933625, 56910, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.16"}],
    Cell[933837, 56917, 158, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[933998, 56924, 217, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.17"}],
    Cell[934240, 56933, 91, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[934334, 56937, 2309, 184, 70, 2236, 181, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[936658, 57124, 285, 6, 70, "Text",
      CellTags->{"S2.1.3", "3.18"}],
    Cell[936946, 57132, 88, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.19"}],
    Cell[937037, 57135, 100, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[937140, 57139, 236, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.20"}],
    Cell[937401, 57148, 90, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[937494, 57152, 3059, 250, 70, 2986, 247, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[940568, 57405, 621, 18, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.21"}],
    Cell[941214, 57427, 163, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[941380, 57434, 12376, 1076, 70, 12303, 1073, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[953771, 58513, 1175, 28, 70, "Text",
      CellTags->{"S2.1.3", "3.22"}],
    Cell[954949, 58543, 172, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.23"}],
    Cell[955124, 58550, 91, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[955218, 58554, 142, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.24"}],
    Cell[955385, 58562, 156, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[955544, 58569, 12340, 1076, 70, 12267, 1073, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[967899, 59648, 710, 16, 70, "Text",
      CellTags->{"S2.1.3", "3.25"}],
    Cell[968612, 59666, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.26"}],
    Cell[968777, 59674, 157, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[968937, 59681, 5184, 407, 70, 5111, 404, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[974136, 60091, 261, 6, 70, "Text",
      CellTags->{"S2.1.3", "3.27"}],
    Cell[974400, 60099, 127, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.28"}],
    Cell[974530, 60105, 142, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[974675, 60112, 97, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.29"}],
    Cell[974797, 60117, 114, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[974914, 60121, 7229, 599, 70, 7156, 596, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[982158, 60723, 145, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.30"}],
    Cell[982328, 60731, 176, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[982507, 60738, 8883, 714, 70, 8810, 711, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[991405, 61455, 222, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.31"}],
    Cell[991630, 61462, 218, 7, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[991851, 61471, 196, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.32"}],
    Cell[992072, 61480, 215, 7, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[992290, 61489, 21914, 809, 186, 10802, 668, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.3"],
    Cell[1014219, 62301, 156, 4, 22, "Text",
      CellTags->{"S2.1.3", "3.33"}],
    Cell[1014378, 62307, 500, 10, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.34"}],
    Cell[1014903, 62321, 87, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1014993, 62325, 103, 3, 20, "Output",
      CellTags->"S2.1.3"],
    Cell[1015111, 62331, 258, 5, 56, "MathCaption",
      CellTags->{"S2.1.3", "3.35"}],
    Cell[1015394, 62340, 87, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1015484, 62344, 103, 3, 20, "Output",
      CellTags->"S2.1.3"],
    Cell[1015602, 62350, 72, 1, 34, "Subsubsection",
      CellTags->{"S2.1.3", "3.36"}],
    Cell[1015677, 62353, 425, 9, 52, "Text",
      CellTags->{"S2.1.3", "3.37"}],
    Cell[1016105, 62364, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.38"}],
    Cell[1016186, 62367, 93, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1016282, 62371, 143, 5, 29, "MathCaption",
      CellTags->{"S2.1.3", "3.39"}],
    Cell[1016428, 62378, 95, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1016526, 62382, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.40"}],
    Cell[1016607, 62385, 124, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1016734, 62389, 298, 11, 30, "MathCaption",
      CellTags->{"S2.1.3", "3.41"}],
    Cell[1017057, 62404, 77, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1017137, 62408, 85, 3, 20, "Output",
      CellTags->"S2.1.3"],
    Cell[1017237, 62414, 214, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.42"}],
    Cell[1017476, 62425, 117, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1017596, 62429, 15278, 233, 70, 15205, 230, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[1032877, 62664, 174, 5, 70, "Output",
      CellTags->"S2.1.3"],
    Cell[1033066, 62672, 139, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.43"}],
    Cell[1033208, 62678, 140, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1033351, 62685, 166, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.44"}],
    Cell[1033542, 62693, 130, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1033675, 62700, 245042, 21845, 70, 244969, 21842, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[1278732, 84548, 133, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.45"}],
    Cell[1278890, 84556, 173, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1279066, 84563, 17378, 515, 70, 17305, 512, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[1296459, 85081, 162, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.46"}],
    Cell[1296624, 85087, 107, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1296734, 85091, 102, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.47"}],
    Cell[1296861, 85096, 108, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1296972, 85100, 67130, 5791, 70, 67057, 5788, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[1364117, 90894, 168, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.48"}],
    Cell[1364310, 90902, 79, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1364392, 90906, 85, 3, 70, "Output",
      CellTags->"S2.1.3"],
    Cell[1364492, 90912, 357, 9, 70, "Text",
      CellTags->{"S2.1.3", "3.49"}],
    Cell[1364852, 90923, 118, 2, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.50"}],
    Cell[1364973, 90927, 110, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1365086, 90931, 234, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.51"}],
    Cell[1365345, 90940, 313, 9, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1365661, 90951, 209136, 13402, 70, 209063, 13399, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.3"],
    Cell[1574812, 104356, 944, 18, 70, "Text",
      CellTags->{"S2.1.3", "3.52"}],
    Cell[1575759, 104376, 197, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.53"}],
    Cell[1575981, 104385, 94, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1576078, 104389, 85, 3, 70, "Output",
      CellTags->"S2.1.3"],
    Cell[1576178, 104395, 89, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.54"}],
    Cell[1576270, 104398, 131, 5, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1576404, 104405, 153, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.55"}],
    Cell[1576582, 104413, 114, 2, 70, "Input",
      CellTags->"S2.1.3"],
    Cell[1576699, 104417, 58743, 803, 186, 15205, 230, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.1.3"],
    Cell[1635445, 105222, 175, 5, 20, "Output",
      CellTags->"S2.1.3"],
    Cell[1635635, 105230, 224, 7, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.56"}],
    Cell[1635884, 105241, 106, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1635993, 105245, 103, 3, 20, "Output",
      CellTags->"S2.1.3"],
    Cell[1636111, 105251, 133, 4, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.57"}],
    Cell[1636269, 105259, 83, 2, 28, "Input",
      CellTags->"S2.1.3"],
    Cell[1636355, 105263, 103, 3, 20, "Output",
      CellTags->"S2.1.3"]},
  "3.1"->{
    Cell[863848, 51545, 101, 1, 70, "Subsection",
      CellTags->{"S2.1.3", "3.1"}]},
  "3.2"->{
    Cell[863952, 51548, 200, 5, 70, "Text",
      CellTags->{"S2.1.3", "3.2"}]},
  "3.3"->{
    Cell[864155, 51555, 68, 1, 70, "Subsubsection",
      CellTags->{"S2.1.3", "3.3"}]},
  "3.4"->{
    Cell[864226, 51558, 787, 22, 70, "Text",
      CellTags->{"S2.1.3", "3.4"}]},
  "3.5"->{
    Cell[865016, 51582, 77, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.5"}]},
  "3.6"->{
    Cell[865192, 51589, 87, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.6"}]},
  "3.7"->{
    Cell[877854, 52409, 230, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.7"}]},
  "3.8"->{
    Cell[878201, 52422, 2821, 69, 70, "Text",
      CellTags->{"S2.1.3", "3.8"}]},
  "3.9"->{
    Cell[881025, 52493, 177, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.9"}]},
  "3.10"->{
    Cell[881351, 52506, 151, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.10"}]},
  "3.11"->{
    Cell[881756, 52524, 1286, 38, 70, "Text",
      CellTags->{"S2.1.3", "3.11"}]},
  "3.12"->{
    Cell[883045, 52564, 311, 6, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.12"}]},
  "3.13"->{
    Cell[929864, 56666, 385, 11, 70, "Text",
      CellTags->{"S2.1.3", "3.13"}]},
  "3.14"->{
    Cell[930252, 56679, 258, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.14"}]},
  "3.15"->{
    Cell[930603, 56690, 344, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.15"}]},
  "3.16"->{
    Cell[933625, 56910, 209, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.16"}]},
  "3.17"->{
    Cell[933998, 56924, 217, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.17"}]},
  "3.18"->{
    Cell[936658, 57124, 285, 6, 70, "Text",
      CellTags->{"S2.1.3", "3.18"}]},
  "3.19"->{
    Cell[936946, 57132, 88, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.19"}]},
  "3.20"->{
    Cell[937140, 57139, 236, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.20"}]},
  "3.21"->{
    Cell[940568, 57405, 621, 18, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.21"}]},
  "3.22"->{
    Cell[953771, 58513, 1175, 28, 70, "Text",
      CellTags->{"S2.1.3", "3.22"}]},
  "3.23"->{
    Cell[954949, 58543, 172, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.23"}]},
  "3.24"->{
    Cell[955218, 58554, 142, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.24"}]},
  "3.25"->{
    Cell[967899, 59648, 710, 16, 70, "Text",
      CellTags->{"S2.1.3", "3.25"}]},
  "3.26"->{
    Cell[968612, 59666, 140, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.26"}]},
  "3.27"->{
    Cell[974136, 60091, 261, 6, 70, "Text",
      CellTags->{"S2.1.3", "3.27"}]},
  "3.28"->{
    Cell[974400, 60099, 127, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.28"}]},
  "3.29"->{
    Cell[974675, 60112, 97, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.29"}]},
  "3.30"->{
    Cell[982158, 60723, 145, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.30"}]},
  "3.31"->{
    Cell[991405, 61455, 222, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.31"}]},
  "3.32"->{
    Cell[991851, 61471, 196, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.32"}]},
  "3.33"->{
    Cell[1014219, 62301, 156, 4, 22, "Text",
      CellTags->{"S2.1.3", "3.33"}]},
  "3.34"->{
    Cell[1014378, 62307, 500, 10, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.34"}]},
  "3.35"->{
    Cell[1015111, 62331, 258, 5, 56, "MathCaption",
      CellTags->{"S2.1.3", "3.35"}]},
  "3.36"->{
    Cell[1015602, 62350, 72, 1, 34, "Subsubsection",
      CellTags->{"S2.1.3", "3.36"}]},
  "3.37"->{
    Cell[1015677, 62353, 425, 9, 52, "Text",
      CellTags->{"S2.1.3", "3.37"}]},
  "3.38"->{
    Cell[1016105, 62364, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.38"}]},
  "3.39"->{
    Cell[1016282, 62371, 143, 5, 29, "MathCaption",
      CellTags->{"S2.1.3", "3.39"}]},
  "3.40"->{
    Cell[1016526, 62382, 78, 1, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.40"}]},
  "3.41"->{
    Cell[1016734, 62389, 298, 11, 30, "MathCaption",
      CellTags->{"S2.1.3", "3.41"}]},
  "3.42"->{
    Cell[1017237, 62414, 214, 7, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.42"}]},
  "3.43"->{
    Cell[1033066, 62672, 139, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.43"}]},
  "3.44"->{
    Cell[1033351, 62685, 166, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.44"}]},
  "3.45"->{
    Cell[1278732, 84548, 133, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.45"}]},
  "3.46"->{
    Cell[1296459, 85081, 162, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.46"}]},
  "3.47"->{
    Cell[1296734, 85091, 102, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.47"}]},
  "3.48"->{
    Cell[1364117, 90894, 168, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.48"}]},
  "3.49"->{
    Cell[1364492, 90912, 357, 9, 70, "Text",
      CellTags->{"S2.1.3", "3.49"}]},
  "3.50"->{
    Cell[1364852, 90923, 118, 2, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.50"}]},
  "3.51"->{
    Cell[1365086, 90931, 234, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.51"}]},
  "3.52"->{
    Cell[1574812, 104356, 944, 18, 70, "Text",
      CellTags->{"S2.1.3", "3.52"}]},
  "3.53"->{
    Cell[1575759, 104376, 197, 5, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.53"}]},
  "3.54"->{
    Cell[1576178, 104395, 89, 1, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.54"}]},
  "3.55"->{
    Cell[1576404, 104405, 153, 4, 70, "MathCaption",
      CellTags->{"S2.1.3", "3.55"}]},
  "3.56"->{
    Cell[1635635, 105230, 224, 7, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.56"}]},
  "3.57"->{
    Cell[1636111, 105251, 133, 4, 28, "MathCaption",
      CellTags->{"S2.1.3", "3.57"}]},
  "S2.1.4"->{
    Cell[1636473, 105269, 105, 1, 36, "Subsection",
      CellTags->{"S2.1.4", "4.1"}],
    Cell[1636581, 105272, 355, 7, 52, "Text",
      CellTags->{"S2.1.4", "4.2"}],
    Cell[1636939, 105281, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.3"}],
    Cell[1637019, 105284, 93, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1637115, 105288, 142, 5, 29, "MathCaption",
      CellTags->{"S2.1.4", "4.4"}],
    Cell[1637260, 105295, 95, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1637358, 105299, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.5"}],
    Cell[1637438, 105302, 141, 5, 45, "Input",
      CellTags->"S2.1.4"],
    Cell[1637582, 105309, 81, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.6"}],
    Cell[1637688, 105314, 77, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1637768, 105318, 85, 3, 20, "Output",
      CellTags->"S2.1.4"],
    Cell[1637868, 105324, 84, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.7"}],
    Cell[1637955, 105327, 100, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1638058, 105331, 83, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.8"}],
    Cell[1638166, 105336, 118, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1638287, 105340, 9054, 152, 186, 8981, 149, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1647344, 105494, 174, 5, 20, "Output",
      CellTags->"S2.1.4"],
    Cell[1647533, 105502, 447, 12, 61, "MathCaption",
      CellTags->{"S2.1.4", "4.9"}],
    Cell[1647983, 105516, 139, 5, 45, "Input",
      CellTags->"S2.1.4"],
    Cell[1648125, 105523, 166, 4, 42, "MathCaption",
      CellTags->{"S2.1.4", "4.10"}],
    Cell[1648316, 105531, 83, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1648402, 105535, 218, 6, 32, "Output",
      CellTags->"S2.1.4"],
    Cell[1648635, 105544, 97, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.11"}],
    Cell[1648757, 105549, 103, 2, 28, "Input",
      CellTags->"S2.1.4"],
    Cell[1648863, 105553, 16755, 1414, 70, 16682, 1411, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1665633, 106970, 1339, 27, 70, "Text",
      CellTags->{"S2.1.4", "4.12"}],
    Cell[1666975, 106999, 128, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.13"}],
    Cell[1667128, 107007, 185, 6, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1667316, 107015, 20778, 1165, 70, 20705, 1162, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1688109, 108183, 220, 9, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.14"}],
    Cell[1688354, 108196, 207, 6, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1688564, 108204, 24593, 5054, 70, 24520, 5051, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1713172, 113261, 167, 4, 70, "Text",
      CellTags->{"S2.1.4", "4.15"}],
    Cell[1713342, 113267, 142, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.16"}],
    Cell[1713487, 113273, 137, 5, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1713627, 113280, 97, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.17"}],
    Cell[1713727, 113283, 111, 2, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1713841, 113287, 128, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.18"}],
    Cell[1713972, 113293, 150, 6, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1714125, 113301, 396, 7, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.19"}],
    Cell[1714546, 113312, 250, 7, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1714799, 113321, 37942, 2465, 70, 37869, 2462, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1752756, 115789, 179, 4, 70, "Text",
      CellTags->{"S2.1.4", "4.20"}],
    Cell[1752938, 115795, 207, 5, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.21"}],
    Cell[1753170, 115804, 111, 2, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1753284, 115808, 85, 3, 70, "Output",
      CellTags->"S2.1.4"],
    Cell[1753384, 115814, 111, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.22"}],
    Cell[1753498, 115817, 148, 5, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1753649, 115824, 79, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.23"}],
    Cell[1753753, 115829, 115, 2, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1753871, 115833, 9054, 152, 70, 8981, 149, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.1.4"],
    Cell[1762928, 115987, 175, 5, 70, "Output",
      CellTags->"S2.1.4"],
    Cell[1763118, 115995, 280, 8, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.24"}],
    Cell[1763423, 116007, 86, 2, 70, "Input",
      CellTags->"S2.1.4"],
    Cell[1763512, 116011, 104, 3, 70, "Output",
      CellTags->"S2.1.4"]},
  "4.1"->{
    Cell[1636473, 105269, 105, 1, 36, "Subsection",
      CellTags->{"S2.1.4", "4.1"}]},
  "4.2"->{
    Cell[1636581, 105272, 355, 7, 52, "Text",
      CellTags->{"S2.1.4", "4.2"}]},
  "4.3"->{
    Cell[1636939, 105281, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.3"}]},
  "4.4"->{
    Cell[1637115, 105288, 142, 5, 29, "MathCaption",
      CellTags->{"S2.1.4", "4.4"}]},
  "4.5"->{
    Cell[1637358, 105299, 77, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.5"}]},
  "4.6"->{
    Cell[1637582, 105309, 81, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.6"}]},
  "4.7"->{
    Cell[1637868, 105324, 84, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.7"}]},
  "4.8"->{
    Cell[1638058, 105331, 83, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.8"}]},
  "4.9"->{
    Cell[1647533, 105502, 447, 12, 61, "MathCaption",
      CellTags->{"S2.1.4", "4.9"}]},
  "4.10"->{
    Cell[1648125, 105523, 166, 4, 42, "MathCaption",
      CellTags->{"S2.1.4", "4.10"}]},
  "4.11"->{
    Cell[1648635, 105544, 97, 1, 28, "MathCaption",
      CellTags->{"S2.1.4", "4.11"}]},
  "4.12"->{
    Cell[1665633, 106970, 1339, 27, 70, "Text",
      CellTags->{"S2.1.4", "4.12"}]},
  "4.13"->{
    Cell[1666975, 106999, 128, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.13"}]},
  "4.14"->{
    Cell[1688109, 108183, 220, 9, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.14"}]},
  "4.15"->{
    Cell[1713172, 113261, 167, 4, 70, "Text",
      CellTags->{"S2.1.4", "4.15"}]},
  "4.16"->{
    Cell[1713342, 113267, 142, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.16"}]},
  "4.17"->{
    Cell[1713627, 113280, 97, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.17"}]},
  "4.18"->{
    Cell[1713841, 113287, 128, 4, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.18"}]},
  "4.19"->{
    Cell[1714125, 113301, 396, 7, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.19"}]},
  "4.20"->{
    Cell[1752756, 115789, 179, 4, 70, "Text",
      CellTags->{"S2.1.4", "4.20"}]},
  "4.21"->{
    Cell[1752938, 115795, 207, 5, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.21"}]},
  "4.22"->{
    Cell[1753384, 115814, 111, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.22"}]},
  "4.23"->{
    Cell[1753649, 115824, 79, 1, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.23"}]},
  "4.24"->{
    Cell[1763118, 115995, 280, 8, 70, "MathCaption",
      CellTags->{"S2.1.4", "4.24"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 1764476, 116039},
  {"S2.1.0", 1764634, 116044},
  {"0.1", 1764723, 116047},
  {"S2.1.1", 1764815, 116050},
  {"1.1", 1778100, 116388},
  {"1.2", 1778192, 116391},
  {"1.3", 1778279, 116394},
  {"1.4", 1778376, 116397},
  {"1.5", 1778466, 116400},
  {"1.6", 1778562, 116403},
  {"1.7", 1778651, 116406},
  {"1.8", 1778745, 116409},
  {"1.9", 1778840, 116412},
  {"1.10", 1778936, 116415},
  {"1.11", 1779028, 116418},
  {"1.12", 1779127, 116421},
  {"1.13", 1779226, 116424},
  {"1.14", 1779326, 116427},
  {"1.15", 1779420, 116430},
  {"1.16", 1779519, 116433},
  {"1.17", 1779618, 116436},
  {"1.18", 1779712, 116439},
  {"1.19", 1779811, 116442},
  {"1.20", 1779910, 116445},
  {"1.21", 1780011, 116448},
  {"1.22", 1780104, 116451},
  {"1.23", 1780204, 116454},
  {"1.24", 1780304, 116457},
  {"1.25", 1780404, 116460},
  {"1.26", 1780499, 116463},
  {"1.27", 1780599, 116466},
  {"1.28", 1780699, 116469},
  {"1.29", 1780799, 116472},
  {"1.30", 1780899, 116475},
  {"1.31", 1780994, 116478},
  {"1.32", 1781094, 116481},
  {"1.33", 1781194, 116484},
  {"1.34", 1781294, 116487},
  {"1.35", 1781394, 116490},
  {"1.36", 1781494, 116493},
  {"1.37", 1781587, 116496},
  {"1.38", 1781687, 116499},
  {"1.39", 1781787, 116502},
  {"1.40", 1781880, 116505},
  {"1.41", 1781980, 116508},
  {"1.42", 1782080, 116511},
  {"1.43", 1782180, 116514},
  {"1.44", 1782282, 116517},
  {"1.45", 1782377, 116520},
  {"1.46", 1782477, 116523},
  {"1.47", 1782577, 116526},
  {"1.48", 1782678, 116529},
  {"1.49", 1782780, 116532},
  {"1.50", 1782881, 116535},
  {"1.51", 1782982, 116538},
  {"1.52", 1783083, 116541},
  {"1.53", 1783184, 116544},
  {"1.54", 1783285, 116547},
  {"1.55", 1783386, 116550},
  {"1.56", 1783487, 116553},
  {"1.57", 1783588, 116556},
  {"1.58", 1783689, 116559},
  {"1.59", 1783790, 116562},
  {"1.60", 1783891, 116565},
  {"1.61", 1783987, 116568},
  {"1.62", 1784088, 116571},
  {"1.63", 1784189, 116574},
  {"1.64", 1784290, 116577},
  {"1.65", 1784385, 116580},
  {"1.66", 1784486, 116583},
  {"1.67", 1784587, 116586},
  {"1.68", 1784688, 116589},
  {"S2.1.2", 1784791, 116592},
  {"2.1", 1788150, 116676},
  {"2.2", 1788247, 116679},
  {"2.3", 1788340, 116682},
  {"2.4", 1788444, 116685},
  {"2.5", 1788539, 116688},
  {"2.6", 1788637, 116691},
  {"2.7", 1788735, 116694},
  {"2.8", 1788833, 116697},
  {"2.9", 1788932, 116700},
  {"2.10", 1789032, 116703},
  {"2.11", 1789133, 116706},
  {"2.12", 1789233, 116709},
  {"2.13", 1789327, 116712},
  {"2.14", 1789433, 116715},
  {"2.15", 1789534, 116718},
  {"2.16", 1789635, 116721},
  {"2.17", 1789736, 116724},
  {"2.18", 1789837, 116727},
  {"2.19", 1789938, 116730},
  {"S2.1.3", 1790041, 116733},
  {"3.1", 1801318, 117016},
  {"3.2", 1801416, 117019},
  {"3.3", 1801508, 117022},
  {"3.4", 1801608, 117025},
  {"3.5", 1801701, 117028},
  {"3.6", 1801799, 117031},
  {"3.7", 1801897, 117034},
  {"3.8", 1801996, 117037},
  {"3.9", 1802090, 117040},
  {"3.10", 1802190, 117043},
  {"3.11", 1802291, 117046},
  {"3.12", 1802387, 117049},
  {"3.13", 1802488, 117052},
  {"3.14", 1802583, 117055},
  {"3.15", 1802684, 117058},
  {"3.16", 1802785, 117061},
  {"3.17", 1802886, 117064},
  {"3.18", 1802987, 117067},
  {"3.19", 1803081, 117070},
  {"3.20", 1803181, 117073},
  {"3.21", 1803282, 117076},
  {"3.22", 1803384, 117079},
  {"3.23", 1803480, 117082},
  {"3.24", 1803581, 117085},
  {"3.25", 1803682, 117088},
  {"3.26", 1803777, 117091},
  {"3.27", 1803878, 117094},
  {"3.28", 1803972, 117097},
  {"3.29", 1804073, 117100},
  {"3.30", 1804173, 117103},
  {"3.31", 1804274, 117106},
  {"3.32", 1804375, 117109},
  {"3.33", 1804476, 117112},
  {"3.34", 1804571, 117115},
  {"3.35", 1804674, 117118},
  {"3.36", 1804776, 117121},
  {"3.37", 1804879, 117124},
  {"3.38", 1804974, 117127},
  {"3.39", 1805075, 117130},
  {"3.40", 1805177, 117133},
  {"3.41", 1805278, 117136},
  {"3.42", 1805381, 117139},
  {"3.43", 1805483, 117142},
  {"3.44", 1805585, 117145},
  {"3.45", 1805687, 117148},
  {"3.46", 1805789, 117151},
  {"3.47", 1805891, 117154},
  {"3.48", 1805993, 117157},
  {"3.49", 1806095, 117160},
  {"3.50", 1806190, 117163},
  {"3.51", 1806292, 117166},
  {"3.52", 1806394, 117169},
  {"3.53", 1806491, 117172},
  {"3.54", 1806594, 117175},
  {"3.55", 1806696, 117178},
  {"3.56", 1806799, 117181},
  {"3.57", 1806902, 117184},
  {"S2.1.4", 1807007, 117187},
  {"4.1", 1811938, 117310},
  {"4.2", 1812038, 117313},
  {"4.3", 1812132, 117316},
  {"4.4", 1812232, 117319},
  {"4.5", 1812333, 117322},
  {"4.6", 1812433, 117325},
  {"4.7", 1812533, 117328},
  {"4.8", 1812633, 117331},
  {"4.9", 1812733, 117334},
  {"4.10", 1812836, 117337},
  {"4.11", 1812939, 117340},
  {"4.12", 1813041, 117343},
  {"4.13", 1813139, 117346},
  {"4.14", 1813242, 117349},
  {"4.15", 1813345, 117352},
  {"4.16", 1813441, 117355},
  {"4.17", 1813544, 117358},
  {"4.18", 1813646, 117361},
  {"4.19", 1813749, 117364},
  {"4.20", 1813852, 117367},
  {"4.21", 1813948, 117370},
  {"4.22", 1814051, 117373},
  {"4.23", 1814154, 117376},
  {"4.24", 1814256, 117379}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 90, 1, 52, "Section",
  CellTags->"Contents"],
Cell[1802, 52, 578, 18, 78, "Contents",
  CellTags->"Contents"],
Cell[2383, 72, 97, 1, 52, "Section",
  CellTags->{"S2.1.0", "0.1"}],
Cell[2483, 75, 93, 1, 36, "Subsection",
  CellTags->{"S2.1.1", "1.1"}],
Cell[2579, 78, 255, 5, 36, "Text",
  CellTags->{"S2.1.1", "1.2"}],
Cell[2837, 85, 294, 6, 28, "DisplayFormula",
  CellTags->{"S2.1.1", "1.3"}],
Cell[3134, 93, 2431, 58, 193, "Text",
  CellTags->{"S2.1.1", "1.4"}],
Cell[5568, 153, 68, 1, 34, "Subsubsection",
  CellTags->{"S2.1.1", "1.5"}],
Cell[5639, 156, 724, 22, 42, "Text",
  CellTags->{"S2.1.1", "1.6"}],
Cell[6366, 180, 77, 1, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.7"}],
Cell[6446, 183, 93, 2, 28, "Input",
  CellTags->"S2.1.1"],
Cell[6542, 187, 187, 7, 29, "MathCaption",
  CellTags->{"S2.1.1", "1.8"}],
Cell[6732, 196, 141, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[6876, 203, 336, 8, 42, "MathCaption",
  CellTags->{"S2.1.1", "1.9"}],

Cell[CellGroupData[{
Cell[7237, 215, 268, 8, 96, "Input",
  CellTags->"S2.1.1"],
Cell[7508, 225, 37233, 1485, 186, 23471, 1311, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[44756, 1713, 245, 5, 36, "Text",
  CellTags->{"S2.1.1", "1.10"}],
Cell[45004, 1720, 116, 2, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.11"}],
Cell[45123, 1724, 93, 2, 28, "Input",
  CellTags->"S2.1.1"],
Cell[45219, 1728, 197, 5, 42, "MathCaption",
  CellTags->{"S2.1.1", "1.12"}],
Cell[45419, 1735, 104, 2, 28, "Input",
  CellTags->"S2.1.1"],
Cell[45526, 1739, 469, 15, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.13"}],

Cell[CellGroupData[{
Cell[46020, 1758, 80, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[46103, 1762, 120, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[46238, 1768, 1358, 41, 70, "Text",
  CellTags->{"S2.1.1", "1.14"}],
Cell[47599, 1811, 239, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.15"}],

Cell[CellGroupData[{
Cell[47863, 1820, 169, 6, 70, "Input",
  CellTags->"S2.1.1"],
Cell[48035, 1828, 37464, 3347, 70, 37391, 3344, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[85514, 5178, 106, 1, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.16"}],

Cell[CellGroupData[{
Cell[85645, 5183, 191, 6, 70, "Input",
  CellTags->"S2.1.1"],
Cell[85839, 5191, 4559, 362, 70, 4486, 359, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[90413, 5556, 2626, 62, 70, "Text",
  CellTags->{"S2.1.1", "1.17"}],
Cell[93042, 5620, 291, 7, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.18"}],

Cell[CellGroupData[{
Cell[93358, 5631, 183, 6, 70, "Input",
  CellTags->"S2.1.1"],
Cell[93544, 5639, 4778, 248, 70, 4705, 245, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[98337, 5890, 156, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.19"}],

Cell[CellGroupData[{
Cell[98518, 5899, 193, 6, 70, "Input",
  CellTags->"S2.1.1"],
Cell[98714, 5907, 2088, 150, 70, 2015, 147, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[100817, 6060, 348, 10, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.20"}],

Cell[CellGroupData[{
Cell[101190, 6074, 226, 7, 70, "Input",
  CellTags->"S2.1.1"],
Cell[101419, 6083, 4777, 248, 70, 4704, 245, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[106211, 6334, 312, 6, 70, "Text",
  CellTags->{"S2.1.1", "1.21"}],
Cell[106526, 6342, 173, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.22"}],
Cell[106702, 6349, 101, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[106806, 6353, 101, 1, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.23"}],

Cell[CellGroupData[{
Cell[106932, 6358, 142, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[107077, 6365, 3968, 268, 70, 3895, 265, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[111060, 6636, 232, 7, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.24"}],

Cell[CellGroupData[{
Cell[111317, 6647, 73, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[111393, 6651, 104, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[111512, 6657, 1959, 56, 70, "Text",
  CellTags->{"S2.1.1", "1.25"}],
Cell[113474, 6715, 158, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.26"}],
Cell[113635, 6722, 137, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[113775, 6729, 162, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.27"}],

Cell[CellGroupData[{
Cell[113962, 6737, 168, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[114133, 6744, 4221, 287, 70, 4148, 284, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[118369, 7034, 145, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.28"}],

Cell[CellGroupData[{
Cell[118539, 7042, 105, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[118647, 7046, 84, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[118746, 7052, 116, 2, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.29"}],

Cell[CellGroupData[{
Cell[118887, 7058, 72, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[118962, 7062, 103, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[119080, 7068, 1817, 63, 70, "Text",
  CellTags->{"S2.1.1", "1.30"}],
Cell[120900, 7133, 144, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.31"}],
Cell[121047, 7139, 86, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[121136, 7143, 101, 1, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.32"}],
Cell[121240, 7146, 110, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[121353, 7150, 129, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.33"}],

Cell[CellGroupData[{
Cell[121507, 7158, 180, 6, 70, "Input",
  CellTags->"S2.1.1"],
Cell[121690, 7166, 22884, 1276, 70, 22811, 1273, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[144589, 8445, 247, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.34"}],

Cell[CellGroupData[{
Cell[144861, 8454, 89, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[144953, 8458, 104, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[145072, 8464, 131, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.35"}],

Cell[CellGroupData[{
Cell[145228, 8472, 116, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[145347, 8476, 105, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[145467, 8482, 132, 4, 70, "Text",
  CellTags->{"S2.1.1", "1.36"}],
Cell[145602, 8488, 141, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.37"}],
Cell[145746, 8494, 140, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[145889, 8501, 244, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.38"}],

Cell[CellGroupData[{
Cell[146158, 8510, 222, 7, 70, "Input",
  CellTags->"S2.1.1"],
Cell[146383, 8519, 5263, 358, 70, 5190, 355, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[151661, 8880, 392, 7, 70, "Text",
  CellTags->{"S2.1.1", "1.39"}],
Cell[152056, 8889, 137, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.40"}],
Cell[152196, 8895, 117, 2, 28, "Input",
  CellTags->"S2.1.1"],
Cell[152316, 8899, 363, 9, 56, "MathCaption",
  CellTags->{"S2.1.1", "1.41"}],

Cell[CellGroupData[{
Cell[152704, 8912, 159, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[152866, 8919, 34029, 1426, 186, 22917, 1285, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[186910, 10348, 95, 1, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.42"}],

Cell[CellGroupData[{
Cell[187030, 10353, 146, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[187179, 10360, 128, 3, 20, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[187322, 10366, 70, 1, 34, "Subsubsection",
  CellTags->{"S2.1.1", "1.43"}],
Cell[187395, 10369, 690, 17, 65, "Text",
  CellTags->{"S2.1.1", "1.44"}],
Cell[188088, 10388, 78, 1, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.45"}],
Cell[188169, 10391, 93, 2, 28, "Input",
  CellTags->"S2.1.1"],
Cell[188265, 10395, 93, 1, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.46"}],
Cell[188361, 10398, 141, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[188505, 10405, 268, 7, 42, "MathCaption",
  CellTags->{"S2.1.1", "1.47"}],

Cell[CellGroupData[{
Cell[188798, 10416, 163, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[188964, 10423, 22349, 1234, 186, 22276, 1231, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[211328, 11660, 407, 12, 42, "MathCaption",
  CellTags->{"S2.1.1", "1.48"}],
Cell[211738, 11674, 145, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[211886, 11681, 164, 4, 42, "MathCaption",
  CellTags->{"S2.1.1", "1.49"}],

Cell[CellGroupData[{
Cell[212075, 11689, 137, 5, 45, "Input",
  CellTags->"S2.1.1"],
Cell[212215, 11696, 36698, 3239, 186, 36625, 3236, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[248928, 14938, 135, 4, 28, "MathCaption",
  CellTags->{"S2.1.1", "1.50"}],

Cell[CellGroupData[{
Cell[249088, 14946, 210, 6, 62, "Input",
  CellTags->"S2.1.1"],
Cell[249301, 14954, 1870, 122, 70, 1797, 119, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[251186, 15079, 160, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.51"}],
Cell[251349, 15086, 136, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[251488, 15093, 140, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.52"}],

Cell[CellGroupData[{
Cell[251653, 15101, 167, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[251823, 15108, 3276, 221, 70, 3203, 218, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[255114, 15332, 117, 2, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.53"}],

Cell[CellGroupData[{
Cell[255256, 15338, 71, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[255330, 15342, 102, 3, 70, "Output",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[255447, 15348, 347, 9, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.54"}],
Cell[255797, 15359, 139, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[255939, 15366, 134, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.55"}],

Cell[CellGroupData[{
Cell[256098, 15374, 159, 5, 70, "Input",
  CellTags->"S2.1.1"],
Cell[256260, 15381, 22364, 1237, 70, 22291, 1234, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[278639, 16621, 224, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.56"}],

Cell[CellGroupData[{
Cell[278888, 16630, 289, 9, 70, "Input",
  CellTags->"S2.1.1"],
Cell[279180, 16641, 35849, 2304, 70, 35776, 2301, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[315044, 18948, 106, 1, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.57"}],
Cell[315153, 18951, 87, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[315243, 18955, 131, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.58"}],
Cell[315377, 18961, 107, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[315487, 18965, 143, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.59"}],

Cell[CellGroupData[{
Cell[315655, 18973, 283, 9, 70, "Input",
  CellTags->"S2.1.1"],
Cell[315941, 18984, 35841, 2304, 70, 35768, 2301, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[351797, 21291, 1881, 49, 70, "Text",
  CellTags->{"S2.1.1", "1.60"}],
Cell[353681, 21342, 191, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.61"}],

Cell[CellGroupData[{
Cell[353897, 21351, 250, 7, 70, "Input",
  CellTags->"S2.1.1"],
Cell[354150, 21360, 19455, 1292, 70, 19382, 1289, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[373620, 22655, 137, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.62"}],
Cell[373760, 22661, 106, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[373869, 22665, 177, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.63"}],

Cell[CellGroupData[{
Cell[374071, 22673, 223, 7, 70, "Input",
  CellTags->"S2.1.1"],
Cell[374297, 22682, 22152, 1436, 70, 22079, 1433, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[396464, 24121, 536, 11, 70, "Text",
  CellTags->{"S2.1.1", "1.64"}],
Cell[397003, 24134, 141, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.65"}],
Cell[397147, 24140, 119, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[397269, 24144, 238, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.66"}],

Cell[CellGroupData[{
Cell[397532, 24153, 267, 8, 70, "Input",
  CellTags->"S2.1.1"],
Cell[397802, 24163, 35729, 2298, 70, 35656, 2295, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[433546, 26464, 134, 4, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.67"}],
Cell[433683, 26470, 107, 2, 70, "Input",
  CellTags->"S2.1.1"],
Cell[433793, 26474, 257, 5, 70, "MathCaption",
  CellTags->{"S2.1.1", "1.68"}],

Cell[CellGroupData[{
Cell[434075, 26483, 267, 8, 70, "Input",
  CellTags->"S2.1.1"],
Cell[434345, 26493, 55852, 2548, 186, 35684, 2295, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.1"]
}, Open  ]],
Cell[490212, 29044, 68, 1, 36, "Subsection",
  CellTags->{"S2.1.2", "2.1"}],
Cell[490283, 29047, 884, 23, 65, "Text",
  CellTags->{"S2.1.2", "2.2"}],
Cell[491170, 29072, 1281, 35, 49, "DisplayFormula",
  CellTags->{"S2.1.2", "2.3"}],
Cell[492454, 29109, 1568, 31, 207, "Text",
  CellTags->{"S2.1.2", "2.4"}],
Cell[494025, 29142, 77, 1, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.5"}],
Cell[494105, 29145, 93, 2, 28, "Input",
  CellTags->"S2.1.2"],
Cell[494201, 29149, 92, 1, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.6"}],
Cell[494296, 29152, 133, 3, 45, "Input",
  CellTags->"S2.1.2"],
Cell[494432, 29157, 74, 1, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.7"}],

Cell[CellGroupData[{
Cell[494531, 29162, 138, 5, 45, "Input",
  CellTags->"S2.1.2"],
Cell[494672, 29169, 91714, 4676, 186, 68212, 4382, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.2"]
}, Open  ]],
Cell[586401, 33848, 128, 4, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.8"}],
Cell[586532, 33854, 136, 5, 45, "Input",
  CellTags->"S2.1.2"],
Cell[586671, 33861, 200, 5, 42, "MathCaption",
  CellTags->{"S2.1.2", "2.9"}],
Cell[586874, 33868, 111, 2, 28, "Input",
  CellTags->"S2.1.2"],
Cell[586988, 33872, 131, 4, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.10"}],
Cell[587122, 33878, 125, 5, 45, "Input",
  CellTags->"S2.1.2"],
Cell[587250, 33885, 91, 1, 28, "MathCaption",
  CellTags->{"S2.1.2", "2.11"}],

Cell[CellGroupData[{
Cell[587366, 33890, 135, 5, 45, "Input",
  CellTags->"S2.1.2"],
Cell[587504, 33897, 68315, 4382, 186, 68242, 4379, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],
Cell[655834, 38282, 292, 8, 70, "Text",
  CellTags->{"S2.1.2", "2.12"}],
Cell[656129, 38292, 1071, 30, 70, "DisplayFormula",
  CellTags->{"S2.1.2", "2.13"}],
Cell[657203, 38324, 103, 1, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.14"}],
Cell[657309, 38327, 111, 2, 70, "Input",
  CellTags->"S2.1.2"],
Cell[657423, 38331, 209, 5, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.15"}],

Cell[CellGroupData[{
Cell[657657, 38340, 186, 6, 70, "Input",
  CellTags->"S2.1.2"],
Cell[657846, 38348, 68256, 4382, 70, 68183, 4379, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],
Cell[726117, 42733, 227, 7, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.16"}],
Cell[726347, 42742, 110, 2, 70, "Input",
  CellTags->"S2.1.2"],
Cell[726460, 42746, 101, 1, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.17"}],

Cell[CellGroupData[{
Cell[726586, 42751, 187, 6, 70, "Input",
  CellTags->"S2.1.2"],
Cell[726776, 42759, 68156, 4376, 70, 68083, 4373, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],
Cell[794947, 47138, 140, 4, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.18"}],
Cell[795090, 47144, 187, 6, 70, "Input",
  CellTags->"S2.1.2"],
Cell[795280, 47152, 209, 5, 70, "MathCaption",
  CellTags->{"S2.1.2", "2.19"}],

Cell[CellGroupData[{
Cell[795514, 47161, 187, 6, 70, "Input",
  CellTags->"S2.1.2"],
Cell[795704, 47169, 68129, 4373, 70, 68056, 4370, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.2"]
}, Open  ]],
Cell[863848, 51545, 101, 1, 70, "Subsection",
  CellTags->{"S2.1.3", "3.1"}],
Cell[863952, 51548, 200, 5, 70, "Text",
  CellTags->{"S2.1.3", "3.2"}],
Cell[864155, 51555, 68, 1, 70, "Subsubsection",
  CellTags->{"S2.1.3", "3.3"}],
Cell[864226, 51558, 787, 22, 70, "Text",
  CellTags->{"S2.1.3", "3.4"}],
Cell[865016, 51582, 77, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.5"}],
Cell[865096, 51585, 93, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[865192, 51589, 87, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.6"}],

Cell[CellGroupData[{
Cell[865304, 51594, 161, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[865468, 51601, 12371, 805, 70, 12298, 802, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[877854, 52409, 230, 7, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.7"}],
Cell[878087, 52418, 111, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[878201, 52422, 2821, 69, 70, "Text",
  CellTags->{"S2.1.3", "3.8"}],
Cell[881025, 52493, 177, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.9"}],
Cell[881205, 52499, 143, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[881351, 52506, 151, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.10"}],

Cell[CellGroupData[{
Cell[881527, 52514, 82, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[881612, 52518, 129, 3, 70, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[881756, 52524, 1286, 38, 70, "Text",
  CellTags->{"S2.1.3", "3.11"}],
Cell[883045, 52564, 311, 6, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.12"}],

Cell[CellGroupData[{
Cell[883381, 52574, 163, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[883547, 52581, 46302, 4082, 70, 46229, 4079, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[929864, 56666, 385, 11, 70, "Text",
  CellTags->{"S2.1.3", "3.13"}],
Cell[930252, 56679, 258, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.14"}],
Cell[930513, 56686, 87, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[930603, 56690, 344, 7, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.15"}],

Cell[CellGroupData[{
Cell[930972, 56701, 93, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[931068, 56705, 2542, 202, 70, 2469, 199, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[933625, 56910, 209, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.16"}],
Cell[933837, 56917, 158, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[933998, 56924, 217, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.17"}],

Cell[CellGroupData[{
Cell[934240, 56933, 91, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[934334, 56937, 2309, 184, 70, 2236, 181, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[936658, 57124, 285, 6, 70, "Text",
  CellTags->{"S2.1.3", "3.18"}],
Cell[936946, 57132, 88, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.19"}],
Cell[937037, 57135, 100, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[937140, 57139, 236, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.20"}],

Cell[CellGroupData[{
Cell[937401, 57148, 90, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[937494, 57152, 3059, 250, 70, 2986, 247, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[940568, 57405, 621, 18, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.21"}],

Cell[CellGroupData[{
Cell[941214, 57427, 163, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[941380, 57434, 12376, 1076, 70, 12303, 1073, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[953771, 58513, 1175, 28, 70, "Text",
  CellTags->{"S2.1.3", "3.22"}],
Cell[954949, 58543, 172, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.23"}],
Cell[955124, 58550, 91, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[955218, 58554, 142, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.24"}],

Cell[CellGroupData[{
Cell[955385, 58562, 156, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[955544, 58569, 12340, 1076, 70, 12267, 1073, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[967899, 59648, 710, 16, 70, "Text",
  CellTags->{"S2.1.3", "3.25"}],
Cell[968612, 59666, 140, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.26"}],

Cell[CellGroupData[{
Cell[968777, 59674, 157, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[968937, 59681, 5184, 407, 70, 5111, 404, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[974136, 60091, 261, 6, 70, "Text",
  CellTags->{"S2.1.3", "3.27"}],
Cell[974400, 60099, 127, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.28"}],
Cell[974530, 60105, 142, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[974675, 60112, 97, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.29"}],

Cell[CellGroupData[{
Cell[974797, 60117, 114, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[974914, 60121, 7229, 599, 70, 7156, 596, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[982158, 60723, 145, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.30"}],

Cell[CellGroupData[{
Cell[982328, 60731, 176, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[982507, 60738, 8883, 714, 70, 8810, 711, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[991405, 61455, 222, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.31"}],
Cell[991630, 61462, 218, 7, 70, "Input",
  CellTags->"S2.1.3"],
Cell[991851, 61471, 196, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.32"}],

Cell[CellGroupData[{
Cell[992072, 61480, 215, 7, 70, "Input",
  CellTags->"S2.1.3"],
Cell[992290, 61489, 21914, 809, 186, 10802, 668, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1014219, 62301, 156, 4, 22, "Text",
  CellTags->{"S2.1.3", "3.33"}],
Cell[1014378, 62307, 500, 10, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.34"}],

Cell[CellGroupData[{
Cell[1014903, 62321, 87, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1014993, 62325, 103, 3, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1015111, 62331, 258, 5, 56, "MathCaption",
  CellTags->{"S2.1.3", "3.35"}],

Cell[CellGroupData[{
Cell[1015394, 62340, 87, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1015484, 62344, 103, 3, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1015602, 62350, 72, 1, 34, "Subsubsection",
  CellTags->{"S2.1.3", "3.36"}],
Cell[1015677, 62353, 425, 9, 52, "Text",
  CellTags->{"S2.1.3", "3.37"}],
Cell[1016105, 62364, 78, 1, 28, "MathCaption",
  CellTags->{"S2.1.3", "3.38"}],
Cell[1016186, 62367, 93, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1016282, 62371, 143, 5, 29, "MathCaption",
  CellTags->{"S2.1.3", "3.39"}],
Cell[1016428, 62378, 95, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1016526, 62382, 78, 1, 28, "MathCaption",
  CellTags->{"S2.1.3", "3.40"}],
Cell[1016607, 62385, 124, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1016734, 62389, 298, 11, 30, "MathCaption",
  CellTags->{"S2.1.3", "3.41"}],

Cell[CellGroupData[{
Cell[1017057, 62404, 77, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1017137, 62408, 85, 3, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1017237, 62414, 214, 7, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.42"}],

Cell[CellGroupData[{
Cell[1017476, 62425, 117, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1017596, 62429, 15278, 233, 70, 15205, 230, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"],
Cell[1032877, 62664, 174, 5, 70, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1033066, 62672, 139, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.43"}],
Cell[1033208, 62678, 140, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1033351, 62685, 166, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.44"}],

Cell[CellGroupData[{
Cell[1033542, 62693, 130, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1033675, 62700, 245042, 21845, 70, 244969, 21842, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1278732, 84548, 133, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.45"}],

Cell[CellGroupData[{
Cell[1278890, 84556, 173, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1279066, 84563, 17378, 515, 70, 17305, 512, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1296459, 85081, 162, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.46"}],
Cell[1296624, 85087, 107, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1296734, 85091, 102, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.47"}],

Cell[CellGroupData[{
Cell[1296861, 85096, 108, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1296972, 85100, 67130, 5791, 70, 67057, 5788, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1364117, 90894, 168, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.48"}],

Cell[CellGroupData[{
Cell[1364310, 90902, 79, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1364392, 90906, 85, 3, 70, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1364492, 90912, 357, 9, 70, "Text",
  CellTags->{"S2.1.3", "3.49"}],
Cell[1364852, 90923, 118, 2, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.50"}],
Cell[1364973, 90927, 110, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1365086, 90931, 234, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.51"}],

Cell[CellGroupData[{
Cell[1365345, 90940, 313, 9, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1365661, 90951, 209136, 13402, 70, 209063, 13399, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1574812, 104356, 944, 18, 70, "Text",
  CellTags->{"S2.1.3", "3.52"}],
Cell[1575759, 104376, 197, 5, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.53"}],

Cell[CellGroupData[{
Cell[1575981, 104385, 94, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1576078, 104389, 85, 3, 70, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1576178, 104395, 89, 1, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.54"}],
Cell[1576270, 104398, 131, 5, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1576404, 104405, 153, 4, 70, "MathCaption",
  CellTags->{"S2.1.3", "3.55"}],

Cell[CellGroupData[{
Cell[1576582, 104413, 114, 2, 70, "Input",
  CellTags->"S2.1.3"],
Cell[1576699, 104417, 58743, 803, 186, 15205, 230, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.1.3"],
Cell[1635445, 105222, 175, 5, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1635635, 105230, 224, 7, 28, "MathCaption",
  CellTags->{"S2.1.3", "3.56"}],

Cell[CellGroupData[{
Cell[1635884, 105241, 106, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1635993, 105245, 103, 3, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1636111, 105251, 133, 4, 28, "MathCaption",
  CellTags->{"S2.1.3", "3.57"}],

Cell[CellGroupData[{
Cell[1636269, 105259, 83, 2, 28, "Input",
  CellTags->"S2.1.3"],
Cell[1636355, 105263, 103, 3, 20, "Output",
  CellTags->"S2.1.3"]
}, Open  ]],
Cell[1636473, 105269, 105, 1, 36, "Subsection",
  CellTags->{"S2.1.4", "4.1"}],
Cell[1636581, 105272, 355, 7, 52, "Text",
  CellTags->{"S2.1.4", "4.2"}],
Cell[1636939, 105281, 77, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.3"}],
Cell[1637019, 105284, 93, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1637115, 105288, 142, 5, 29, "MathCaption",
  CellTags->{"S2.1.4", "4.4"}],
Cell[1637260, 105295, 95, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1637358, 105299, 77, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.5"}],
Cell[1637438, 105302, 141, 5, 45, "Input",
  CellTags->"S2.1.4"],
Cell[1637582, 105309, 81, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.6"}],

Cell[CellGroupData[{
Cell[1637688, 105314, 77, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1637768, 105318, 85, 3, 20, "Output",
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1637868, 105324, 84, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.7"}],
Cell[1637955, 105327, 100, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1638058, 105331, 83, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.8"}],

Cell[CellGroupData[{
Cell[1638166, 105336, 118, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1638287, 105340, 9054, 152, 186, 8981, 149, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"],
Cell[1647344, 105494, 174, 5, 20, "Output",
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1647533, 105502, 447, 12, 61, "MathCaption",
  CellTags->{"S2.1.4", "4.9"}],
Cell[1647983, 105516, 139, 5, 45, "Input",
  CellTags->"S2.1.4"],
Cell[1648125, 105523, 166, 4, 42, "MathCaption",
  CellTags->{"S2.1.4", "4.10"}],

Cell[CellGroupData[{
Cell[1648316, 105531, 83, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1648402, 105535, 218, 6, 32, "Output",
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1648635, 105544, 97, 1, 28, "MathCaption",
  CellTags->{"S2.1.4", "4.11"}],

Cell[CellGroupData[{
Cell[1648757, 105549, 103, 2, 28, "Input",
  CellTags->"S2.1.4"],
Cell[1648863, 105553, 16755, 1414, 70, 16682, 1411, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1665633, 106970, 1339, 27, 70, "Text",
  CellTags->{"S2.1.4", "4.12"}],
Cell[1666975, 106999, 128, 4, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.13"}],

Cell[CellGroupData[{
Cell[1667128, 107007, 185, 6, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1667316, 107015, 20778, 1165, 70, 20705, 1162, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1688109, 108183, 220, 9, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.14"}],

Cell[CellGroupData[{
Cell[1688354, 108196, 207, 6, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1688564, 108204, 24593, 5054, 70, 24520, 5051, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1713172, 113261, 167, 4, 70, "Text",
  CellTags->{"S2.1.4", "4.15"}],
Cell[1713342, 113267, 142, 4, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.16"}],
Cell[1713487, 113273, 137, 5, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1713627, 113280, 97, 1, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.17"}],
Cell[1713727, 113283, 111, 2, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1713841, 113287, 128, 4, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.18"}],
Cell[1713972, 113293, 150, 6, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1714125, 113301, 396, 7, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.19"}],

Cell[CellGroupData[{
Cell[1714546, 113312, 250, 7, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1714799, 113321, 37942, 2465, 70, 37869, 2462, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1752756, 115789, 179, 4, 70, "Text",
  CellTags->{"S2.1.4", "4.20"}],
Cell[1752938, 115795, 207, 5, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.21"}],

Cell[CellGroupData[{
Cell[1753170, 115804, 111, 2, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1753284, 115808, 85, 3, 70, "Output",
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1753384, 115814, 111, 1, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.22"}],
Cell[1753498, 115817, 148, 5, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1753649, 115824, 79, 1, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.23"}],

Cell[CellGroupData[{
Cell[1753753, 115829, 115, 2, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1753871, 115833, 9054, 152, 70, 8981, 149, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.1.4"],
Cell[1762928, 115987, 175, 5, 70, "Output",
  CellTags->"S2.1.4"]
}, Open  ]],
Cell[1763118, 115995, 280, 8, 70, "MathCaption",
  CellTags->{"S2.1.4", "4.24"}],

Cell[CellGroupData[{
Cell[1763423, 116007, 86, 2, 70, "Input",
  CellTags->"S2.1.4"],
Cell[1763512, 116011, 104, 3, 70, "Output",
  CellTags->"S2.1.4"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

