(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1633318,      49888]*)
(*NotebookOutlinePosition[   1650245,      50366]*)
(*  CellTagsIndexPosition[   1648809,      50311]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["2.2 Analysis of Two\[Hyphen]Dimensional Images", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["Introduction",
    ButtonData:>{"Wavelets 2.2.99"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["2.2.1 Analysis of an Image Using Wavelet Basis",
    ButtonData:>{"Wavelets 2.2.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["2.2.2 Analysis of an Image Using Local Trigonometric Basis",
    ButtonData:>{"Wavelets 2.2.2"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["2.2 Analysis of Two\[Hyphen]Dimensional Images", "Section",
  CellTags->{"S2.2.0", "0.1"}],

Cell[TextData[{
  "In this section we analyze a couple of two\[Hyphen]dimensional data sets \
using the functions in ",
  StyleBox["Wavelets.m", "MR"],
  ". For two\[Hyphen]dimensional data, the functions doing wavelet packet \
transforms and trigonometric packet transforms can impose large memory \
requirements. The use of these functions should be attempted only if you have \
sufficient memory on your computer. "
}], "Text",
  CellTags->{"S2.2.0", "0.2"}],

Cell["2.2.1 Analysis of an Image Using Wavelet Basis", "Subsection",
  CellTags->{"S2.2.1", "1.1"}],

Cell[TextData[{
  "The following example demonstrates the use of wavelet decomposition to \
compress two\[Hyphen]dimensional images. The file ",
  StyleBox["swphoto.eps", "MR"],
  " contains a scanned picture. "
}], "Text",
  CellTags->{"S2.2.1", "1.2"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.2.1", "1.3"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
This reads in the file and converts it to a matrix of 8\[Hyphen]bit \
numbers.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.4"}],

Cell["\<\
data = Reverse[Partition[ToExpression /@
(StringJoin[Join[{\"16^^\"}, #]]& /@
Partition[Characters[StringJoin @@ Drop[Drop[
ReadList[ToFileName[{\"Wavelets\", \"Data\"}, \"swphoto.eps\"], String],
22], -3]], 2]), 250]];\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.2.1"],

Cell["We check the dimensions of the data.", "MathCaption",
  CellTags->{"S2.2.1", "1.5"}],

Cell[CellGroupData[{

Cell["Dimensions[data]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \({277, 250}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "We drop the extra rows at the top and pad 3 extra columns both on the left \
and on the right so that the data set has dimension ",
  Cell[BoxData[
      \(TraditionalForm\`{256, 256}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  "."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.6"}],

Cell[CellGroupData[{

Cell["\<\
(data = Transpose[Join[Table[#[[1]], {3}], #,
Table[#[[-1]], {3}]]&[Transpose[Drop[data, 21]]]];
Dimensions[data])\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \({256, 256}\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
We plot the content of the file: portrait of a scientist as a young \
child.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.7"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[data, Mesh -> False]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -6 -9 ]
[.20703 -0.0125 6 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -12 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(50)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(100)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(150)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(200)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(250)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(50)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(100)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(150)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(200)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(250)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2E2E2E2E231E191913131E1E28314344432E2C28191E1E19
282C231E191013101319282E382E2C231913131310101010
10101010101010101010101010131313191919191E19191E
1913131313131310131313232E2E2E2E2E2C282E23232319
131913131313131313131313131313131313131313131010
101310101010101010101010101010101010101010101010
101010101010101010101010101010101010101010101010
100710101010101010101010101010101010101010101010
1010101010101010101010101E1910101010101010101010
101010101010101013131313101010101010101010131013
13131313131310131313131913131313
3C3C3C3C2823231E13131E1E28353C44432E2C282323191E
282323281E1313131319282E2E282E1E1E13131013101010
10071007101010101010101013131313191E191E1E191913
1913131313131313131313232C2C312C2E282323231E1E19
131313131313131313131313131313131313101310131313
101310131310101010101010101010101010101010101010
101010101010101010101010101010101010101010101010
101010101010101010101010101010101010101010101310
101010101010101010101013231310101010101010101013
131010101010101013101013101010131013101013131013
13131313191313131313191919191919
444444442E2C231E1E1E191E282C384347382E282323231E
282323232319131313191E2C352C281E1E19131313101007
101010070710100710101013101313131E1E19191E191E1E
1913191313131313131919282E2E2E282E2823231E191913
131313131313131313131313131310101313131313101310
101010101010101010101010101010101010101010101007
101010101010101010101010101013101010101007101010
070710101010101010071010101010071010101010101010
101010100710101010101319191010101010101010101010
101310101010101010101010101310131013101013131313
10101010131313131313131919191919
6C6C6C6C3C35281E1E1E192323233144473F31282C232323
2323282C231E191313191E28312328231E13131010101010
10101010071007101010101013131313191E192323191919
191319131313131313131E282E2E2E282C231E1E19131313
131313191313131313131313131313131313131013101310
101310131010101010101010101010101010101010101010
1010101010101019232C352823191E191313101010100707
071007101007101010071010101010071010101010101010
101010100710101010101313131010101007101010101010
131310101010101010101310101010101013131010131313
13131313131313131313191919191919
7E7E7E7E66442E2828281E2C2C232E3F4744352E2E282328
23232C2C282319131E1E1E232C2828191913131313101010
101010101010101010101013131313131E1E191E1E19191E
1E13191313131313191E232C2E2C2C282C28191913131313
131313191313131313131313131313131313131013131313
101010101010101310101010101010131010101010101010
101010101019234D6C53663C443543382C2C131010101010
071010071010100710101010101010101010101010101010
101310101010101010131313131010101010101010101010
191010101013101013101010101310131010101010131313
13131313131313191313191919191919
7E7E7E7E7C6E3C312E23232323232C3143473F2E31282C2C
231E2C2823281E19232323232323231E1313131310101010
1010101010101010101010101013131919191E232319191E
13131313131313131E1E232E2E2E2E23231E131313131319
131913191313131313131313131313131313131313131313
101010101010101310101010101010101010101010101010
10101310194D6C6079565E4D564F4A604447281010101010
070710101010101010101010101010101010101010101010
101E13101010101013131010101010101010101010101010
101010101013101010101010101010101010131310101313
10131313131310131319191923232323
7B7B7B7B7E7E5B3C352E28232323282E3C4A4335432E2E2E
23232C232C281E2823192328232323191913131310101010
101010101010101010101013131313191E1E19231E191E1E
191919131313131323232C2E2E282C232323191919131919
131913131913191313191313131313131313131313131013
101310101310101313101010131010101010101010101010
10101328477487586C563F443C4A35564743311910101007
100710101010071010101010101010101010071010101010
101013131010131313131313101010101010101010101010
101010101313101013101010101310131013101313131013
13131913131313131313192843434343
7C7C7C7C7E7C766043312C2E2823282838444A3C3F312E2E
231E2E282C2E2323231E23231E2323191913131310101010
101010071010101010101010131313191E1E1E232319191E
191313131313131923232E2E2E2C231E191E191919131319
131319131913131913191313191313131313131013131013
131010101310101310131010101010131010101013101010
13233F636E70795253523844384A35564F3F442819101010
101007101010101010071010101010101010101010101010
101010131319191919131313131010101010101010101010
101010101010101010101010101010131010101013131013
1313131313131319131923444D4D4D4D
7B7B7B7B808379745B433C31232828232E3C4D473C2E2E3F
28232C282C2C282C231E2323191E19131313101310131010
10101010101010101010101013131319191E1E1E1E19191E
13191913131913232E2C2E282E2823231E19191E19191919
191919131913131913131313131313131313131310131010
101010101010101010131010101010101010101010101319
3162667E7C637B524F53314D2E432E383F313C2819101010
071010071010101010071010101010101007101010101010
10101323191E191313131313101010131010101010101010
101010101010101010101313101010131010101013131313
131013131313131319233C4D4F4F4F4F
7C7C7C7C80817C7971634F38312E28232E3844444331313C
31312C232C2E282E2823231E191E1E191313131310101010
101007071010101010101010131313191E231E231E1E1E1E
13131913131313232C2C31282E231E1919191919131E1919
13131E131913131913131313131313131313131313131010
10101010101010101010101010101013131010101323385E
6283666E704F603F3C432C3F28382C2E382C433123131010
100707100707100707071007071010101010101010101313
1313191E1919191313101313101013101007101010101010
101010101310101010131013101010131310131313131313
101313131319191931444F4D4F4F4F4F
797979797B7E7E79716C684F3F382C282E2E4444473F3835
38383128282C2C2E28232823191919131313131310101010
1010101010101010101010101313131919231E23231E1919
19131913191E192C2C2C2E2328231E19191E191E191E1E19
191919131919131313131919131313131313131310131010
1010131010131013131013101010131310131E2835686276
587963636E4A5B4331442E3F282E282C3128382828191007
100710101007101010101010101010101010131313131919
131319191913131313191010101313101010101010101010
101010101313131010191013131313131313191919131313
131313131919192E534F4F4D4F4F4F4F
7E7E7E7E7C857E7C786E63635B44352E2E313F4444433C38
2E353C31312E312E28232323191913131313131310131010
1010101010101010131013131313131919232323231E1E1E
1E131913191E1E282E2C3123231E1E1E1E1E191E1E191919
191913131313131313131319131313131310131010131313
13101313131310131310131013131319232C5E6C6E8A7485
62765B56633C4D4F31432C351E28282C2C23312328191007
100710101007071010101010101313191919191913191919
191919191913191313131313101319101010101010101010
101010101010101313191313191313191319191313131319
13191919191E3152564D4D474D4D4D4D
7B7B7B7B7E83818379746666636344353C31383F44474344
31353F3C3F31312E282823231E1913131919131310131010
101010101010101010101013131319191E232323281E191E
191319131923232C2C2828232823231E231E1E1923191913
131913131313131913131313131313131310131313131313
131013101313131313131313131E2844797891766E7C5E71
4F6247435838473F2E3F2C3123282C3C432E3C28281E1307
0710101010101010101010131919231E1E1E1E1E191E1319
191913191913131313131313131313101010101010101010
10101010101313131313131919191E191913131313131919
19191919283C4D5858534A4A47474747
7E7E7E7E7C8180807C766A636663604F443135353C433F43
31313C3F4338353528282C231E1E13131913131310101010
1010101010101010101013131313191919282323231E1923
19191E19192823282C232323231E231E23191E191E1E1319
131313131319131913131313131313131313131313131313
131313131313191E1E28232C43797B7E8A7C8C6360714F63
444F383F4731434738472C352328383C44312C1E1E191007
10101010101010131313131919131913191313191E191319
131319191319131313131310131313131010101010101013
1010101010101313131313131E1E13131010131013191319
191919354A4F4F53564F444443434343
7C7C7C7C8185837E7C766C686863636A5B383F3838433F44
352E3131433F3C352C3128231E1919131913131313131010
10101010101010101010101313131319192823232823191E
19191E191E232323232323231E23231E231E231E191E1913
131313131319191919191319131319131313131313131313
13131E1E23386E856085839180A194938A7487626063434F
31472C31382C47353C3F2C38282E3C2E38282C1E231E1310
101013101013131319131919191919191913191919131919
131919191919131313131313131313101010101010101010
10101013131313131319191E191310101313131313131313
19284353564F4F52534A444343434343
7E7E7E7E8081857E7B746866686668666A6047433F433C4A
3F38312E3144473831352E28231E19131313131313131310
1010101010101313101010131313131919232323231E1E23
1E1E231E2323232323231E231E2823231E231E1E19191313
13131319191E1E191919131913131313131313131313191E
233535444A5B899DA1AA9EAC93A08980706074525B523F52
28352C28282838283F3C313F2C382E282C1E281E1E1E1310
131313131E19191919191919131913191313131919131913
131913191913191319131313131313101010101010101010
10131310131313131319191310131313131313131913131E
3F56585253534D534F4D47433F3F3F3F
7B7B7B7B808180797671686668686862636A5B4743443F47
4A443F2C2E3C47443835312C2C2319131913131313131313
10101010131010101010101313131319191E232323231E1E
1919191E2328232323282323232323231E231E1E19131313
1313131E23231E1E13191913131313131313131319192C35
3C44565B5E5B636A80998F9D859181706A5B6A4753533853
31311E1E1E1E28283F3135313F381923231323231E191313
131319131913131319191E19191919131313131919191919
191919191919191919131313131313101010101010101010
131013131913131319131313131313131013131319192C47
565B5853524D4D4F4F4A444344444444
7B7B7B7B7E8079797470626262666663606668604A473F47
47444A312E2E3C4D433C312E2E2C1E191913131313131310
10101310101010131010131313131319191923232823191E
1E1E231E232323232323232328232823231E1E191E131313
13131E23232319191E232C31281E1310101319192C314352
525B5B62605E58606368637074877E706C5E6E444F4A2E44
2E38191919191E1E352E3535311E1E23281E232319191319
131313131919131913131919131913131313191319191319
131319191913191313191319131313101010101010101010
10131013131313191313101010101313101313131E385858
56565652534F4F524D4F443F44444444
787878787C807B74706E63605E666663605E585E5E564747
474752443C35314444473C31312C231E1913131313131310
13101010131013131010131313131319191E232328282323
1E191E1E2323232328282823282328232319231913191313
131323282C2E35385E4F4D562E191313131923313F4A5256
5B6062666363565862626258585B6060715E714F5347313F
2C31191E13131E192C2C2E3819132C282819191913131313
131013131313131313101319131313131313131313131319
131919131919131919131913131313101010101010101010
10131313131313131010131013131313131313192C565656
53535352534F4D524D4D474447474747
787878787C7C7B74706A6263626A636360605B605E625B4A
4D444A4A4D38353C3C4A4435383128232313131310131310
13131010101010101013101013131319191E232328231E1E
1E1E2328232C282C2328232823232C1E231E191913131313
232C3156444A784F5E602E3C2C1313191E2E3C47535E6063
66666A6668635B605E5E5853534F4D3F3F384A444A47313F
2828191E1313131328232C381319231E2319191913131313
101010131313131313101313101313101913131313191319
191319191919191919191919131910101010101010101013
101313131310101010101013131913191319191E4F565853
5353524F4D524A4F4F4D444347474747
71717171787C7B766E6A62606068686662635E5E58565B5E
564A474F4A4D3C3F3C4347433F3831312C19131913131310
10131310131010101010131313131313191E231E23231E23
1E191E232E282C2323232C28232323231923191919192847
4356585B68525E5344562C2319191E2C384F585E66686A6A
6A6C706C6A665E5E5858524F4D443F38352E2C23282E232E
23231319191319131919282E13191E1E1E13131910131313
131313131313131313131313131313191313131313131913
191319191319191919191919191313101310101010101010
131313131013131313131313312C1E1919192C475E565653
5253524F4F4D4D52524D474744444444
76767676797B787970686263666C6A666368626060565E56
60604F524A5247473C3C443C433C35312E1E1E1313131313
10101310131013101310131313131313191E232328231E1E
191E23282C28282323282823282328231E1E1E1E384D4A5E
604F83527066434431311E1919233C475B66686C6E707171
706C6A6A6862585B534D4A443C3838312C28231E19191919
191E131913131310131319231019191E1910131310131313
101910131313131313131313101313131913131313191919
191913191919191919191919191310101310101010101010
1010101010101010131313194D8A563F384456605E565658
564F4F534F4F4F52534F4D4747474747
7B7B7B7B7B7B76706E626066636E706E6C6E666663606058
5E5E66624F524F534D3F4443443F35353128231E13131313
13131013131010101013131013131319191E231E23231E23
1E23232C282C282C23282E23281E23232323444F4F636A4D
6C5B6E43434A2C382E1E1923354A62667476767176716A66
6058524A473C3C38383131352E2E2C2C2323191919191313
10101010131319101313191E101313131313131010131313
131313101310131313131313131313131313131919191319
13191319191913191919191E191010101310101013131010
10101010131013131313131E3852605B58565E5E5B565B58
5656535653524A56524F524A47474747
7B7B7B7B7C787470666266636A71716C70716C686663625E
5B5E5E6366624F52534F4A444447353C3128231E13131913
1313101010101313101313101313131E191E281E2823191E
232328282E2828232E2828232323282C354F5268624D6352
4A5644442E352328232835435E6A717878787663534F3F35
2E28231E1E1919191919191919191E191E1E1E1919191310
101010101010191013131313131010131310101013101313
101310101313131313131910101913191313131319191313
19131919191913131319191E131010101010101013101310
1013101013131313131E2C52636862605B5660605B5B565E
5E5B565852534F5353524D4747474747
7C7C7C7C807E79716E686868717074747171706A6A666C62
5E585E5B5E636356564F534D474F433835312E28191E1913
1313131313101313131313131313131E191E2C1E23231E1E
232328312C2C232E2C2E2323232C3C6C566E6053663F475E
35432E31232C232831445B6A767C7976685643312C282828
23231E191919131313101319131313191919191919131313
131310101010101010101013131313101010101010101310
101310131313131313131313131913131313131313131313
191919131913191319191919191010101010101010101010
101313131313191923525B63626362605E5E5B605E565658
5B5B5E58524D5353534F4D474A4A4A4A
81818181817E7970706C6C6A717174746E6E6C70706C6862
62605E60605E5E62635858534D4F47433C2E2E2C23231E19
1919131310101313101313131313131E19192E1E2323191E
28232C2C28282C232E28232C356E70876C4768524F472C38
2E2C2828191E3143536C7881837E685E52443C352E2E2E2E
2E2823191919131313131319131913131013131313131919
191313101010100710101013131313101010101010101010
101010131313131013131310101313131313131313131913
131313191919131319191919131010101010101010101010
1313131313191E355363606366625B5B5B606063625B5B5B
585E5B5B4F4F4D53534F4A4444444444
858585857C807B74747070707671706E6A706C716E6E6A6A
66625E605E565B5B5E6C635B4F5B524A47313131232C2319
1E1E1313131010131013131313131319191928232323131E
2C2C2C2C282C282E2C283153709A8C626A43474F384D2E2E
282319192838566378818685837B7871685B58524A47433C
383128231919191913191313131919131313131010101313
101010101010101010101010101010101013101013101010
131313131013131313131313131313131310131313131313
191919131319131319191919101010101010101010101313
1919131323354A5E60605E6060625B585B60626062605B5E
5B5B56534D4D4D4F5252474347474747
818181817C7E7C797170716C717070706C66667071716E66
62605E63605858585858626C605E62524F3F3C312828281E
1E23191919131010131313131313131E191E2E23231E1923
282C2E2C282C2E313138538389687C444D4A31352E443123
1919192E4A607480868C90918F8A8A868079766A635E5844
43383128281E191919191919191919191919131310101013
101010101010101010101010101010101010101010101310
101313101313131013131313101313131313131313131313
19101919131919191E231919101010101010131010191313
19191E2E4F5E62605E5B5B5B5E605E5E5E5B626362605B5B
5E58564F4D474A52524F4A4447474747
7B7B7B7B7E807E747071706C6E716E70686E7170706C6666
60605E6062605858565658565B6263535E47473F31312C23
23281919191313131313131313191323191E281E2C231E23
23312E28282E2E314770716270605B56444A31432E382E19
19192C526E7C899391969B9D9E9A97968C8C868379746656
5243382E281E191919191919191919191919131313131010
101313101313101010101010101010101010101013101010
131313131313131013131313101313131013131313131313
19131919191E1E1E232C1E13101010101310131313191919
2338525B5E6066625B5658565B5E5B5E5B5B626060606060
5B5856524D444A525253474747474747
797979797E817C78747163706C6A6E6E6A6A6E74706C6862
5E5B5E6262605B56585B5B5653525B6262524F4A38383523
28231923191313131313131313131323191E282328231E23
2C2E312E2C3138435B6A7853626A43382C352C352E1E1919
191E4D74899396969EA1A9A7AAA2A3A099969690867E7062
5B4A43352E231E1E1E191919191919191919191919191010
101013101010101310101010101010101010101010101010
101010131013131313131310101013131913131313131313
19191E23232C282C2E2C1E10101010101013131313192344
5B6360605E6060625B56565653585B5B586060635E60605E
606058564F4F4D52524D4A4444444444
7B7B7B7B7C807C7B7170686C6E6A6C6C686E70716C6A6662
5853586363605E605E5E605B534F5353666A5E604744432E
2E2E282C2313131313131313131919282323281E1E232323
2E2E31313C4F564F6C637B564A432C2E2843313128131919
1E38718A97999AA3AAAEAEAEB0AEACAAA2A0A09990897968
60524A3831282323231E1E19191919191919191919191010
101010101310101010101010101010101010131010101010
131010131013101313131313131313131313131319191E1E
28282C2C2E282E353C2C131010101313131319191E355668
666366605E60635E585B5856565E5B605B62606260625E5E
5E605E564F4F4F4D534D444447474747
7E7E7E7E80838080717470706E6C706C6A66717471686660
58585E63686363626260605E56525353586C6A6C5852523F
3C3C312E281E1E1913131313191E19232323282323282C2C
53524A7068818C6A8C7476382C2E234A3C443C2819131919
385B89939B9EA2AEB3B6B6B4B0B3B4B0ACA5A39B97908071
68564D3F38312C2C28231E19191919191919191919191313
101313101010101313131010101010131310101010131010
1310101010101013131913131313131319131319191E2323
28282323232831352E231010131313131319233F5258626A
6866666262625B5E5E5E5E58585E5B606262605E5E5E5B5E
5E5E5E58525253524F4D4A444A4A4A4A
7E7E7E7E8080837B7878717071706E6E686870706E686260
5B565E62636363625E606A66625353535B6066687468604D
474A31313528282319131313131319282C28312823282E43
A0B8A1BF9DA1AC786C4A352C23434360583128191919192E
5B7B939AA0A9AEB6B6B9B8B6B7B7BBB6B3A9A3A19D978678
6E5B52473C3131312E2C231E191919191919191919191913
131310131313101913131013101010101013101010101010
1010101013131313101313131313131919131E192323231E
231E19191E1E3135282313131313131E3144525B5B60626C
68666863636262605B5E6056585856605E5B5B5B5B5B5860
625E605E585352524A474A4A4A4A4A4A
7C7C7C7C7E81807C7979707071746C68636A7071716A665B
5E5E5E6666666362606366636058535B606663666A707966
585644443C31312E28231E131919192C31313131282C316A
B8CAACBE90838A533C312C444460684D583519191919234A
798A9BA5A9B0B3B9BEC4BCBBB8B8BEBBB4ADAAA7A19A8C81
79665B4F47383531312C231E1E191919191E191919191913
131313101313101013131010101010101013101010101010
1010101013101313131313131913131313191E191E191919
19191319192835312E19131319233858605E5B5858606668
6A6866686A686C605B5B605E5B605E63605E5E5E585E5E58
6062605E585652524F4F4D474A4A4A4A
818181817C8180817C7C71707174716868686C7670666660
6262606666666663666C6E68625E5E5B5E666A6366666C76
7174624F4D383F312E312E1E191919232E3135312E2C4487
CAD5BBB1915E5E382C2C2E63716074563C281919191E386E
8A949EA5AEB1B6BFBFC1BCBCBCBCC2BEB8B4B3B3ACA59A86
816A5E534A3F3835312E28231E191E19191E1E1919191919
131313131313101010131310101013131010101010101010
101010131313131313131313131319131319191919191313
131313191928312828191928435360666662585B605E6062
686366666C666A62605B5E5E605E605B5B5E5E5E5B60585E
5E60605E5858525353534F4D4A4A4A4A
83838383808186807C7C76767474746C666870746E6C6362
626362686C666366686C6E6868636060606C6C666663666E
706E6E6C6853474338313123191E1919282C3C3F3F445BA7
CEC8BE91783C2C2E43474A608578535638281919193F6C8A
969AA3ADB1B3B9C1C4C5BFBCBBBFC6C5C2BEBFB8B0AA9E8C
8771635852433C38352E2C281E1E1E1E1E1E1E1E19191919
191313131310101310131310101010101310131010101010
101010101313101013101313131319131919191313131313
1913191923352C2C1E2C4D58565E636366636063665E605B
5B6368686A6A6660605B5E626060625E585B5B5B5E605E60
5B5E5E585358565653534F4D4D4D4D4D
818181817E8689858080797871767071706E74746E6E666A
6663636E6C666A66666C6C6C68636362636A66666363626C
6E6E6C6A6C70635B4D383F3128231E1928283C4D4D6056A9
D7ADAE684A312E31635663716A7B58312319191938748993
999DA9B1B1B4B7C2C5C2BEBCBEBBC6C6C5C4C4BEB4AEA194
8C7B705B56473F3C35312E2C282323231E1E1E1E23191919
191913131913131313131313131013101010131310101010
101010101010131313131313131913191319191919191919
19191E282C312E434D5B62605860606063626062605E5E62
60626363666866625E5B5B5E6062605E5858565658585B5B
5B585E5E5656525253534F4D4A4A4A4A
7E7E7E7E808187858381787878767470766E717671706A6A
6663686C6E666663666A6A7068636363686E6C666062666C
6E6E686666666C6E6E5E5B4A35352E28312E31312E2E47A9
DC907C4731383C31444D44797E5E47281E2C2838768C9497
9BA1ACACB0AEB1B7BCBBB7B7B7B7C4C5C8C8C6C4B9B3A599
8C837B634F4A433C3835312C2828282328231E23231E1919
191919191319191319191319131013131313101310101010
101010101010101010131313131319191919191319191919
191E283531314760606360625E62626060626262635E6063
626060606260605B5B565B5860605E5B5253565656565658
56585E5B56564F535656534A47474747
7E7E7E7E81838A86868179797876787070716E717876706A
666363706E66636A6A6E6C6C6A636866686A66686260666E
706E6A636266636663606666605E53433C282323232847AC
D1814D5E4343585235444A446060311919315B7E91949697
9EA1A7A9ACA5A5ADB1B6B0B0B0B3BEC1C6CACECBC5B7AC9A
9489836E5B5247433531312E2E282C232828232823232319
191919191919191919191919191310101313131010131010
101010101010101313131313131319191919191913191919
2328353C433F5E6663666262605E605E605E6260605B5E62
66626062635E5E58585658585E60605B5656525353565656
53565656564F4F4F5352534A4A4A4A4A
7B7B7B7B7E8185868580797479787976717071747B74716E
6E6863706E66626A6870706C6A6668666A6863636063636C
6E6E6A6662626363635E5E605E63718C38281E19192C7CBC
A77E5E586347536A473F4D4F47352828386A8A918C93939A
9BA1A9ACA9A29EA5A7AEADAAA9A9B3BBC4C8CECFC8BFAC9E
9B918671665347433C31312E2E2E2C2C2C28282328232319
191919191919191919191919191319131313191913101310
10101010131010101313131313131919191E19191919191E
2835383C4D5366626A66636258605E605E5B605B5E60605E
62636260605E5B58565858585E5B605B5356525653565656
53535358534F4D4D4F4F4F4A4A4A4A4A
797979797E80878380807978797976766E6E717978787470
6366636C6E6866636668716E68686663666866625B63636A
6A6A6666606062606058565E60606EA9472319191E3C8CC8
9A8C7C4F706C4F585B47353C47351944708F898A8F8C9090
9AA0A7A9A39E9A9EA2A5A3A3A19EA5B0B8C2C9D1CDC5B4A7
A19187716C584D473F3535312E312E2E2E2E2C2C2C282823
191919191919191919191919131913131313191313131310
10101010101010101010131919191E19191919191919191E
232831525E666A63686A6360585B5860605B5B5B5860605E
66626262605E565653585856585E5B5E5853535652525656
5652525352524F4A524D4D4A4A4A4A4A
787878787B7E818083837E7979767678706C74787978746C
636362686E6C6663636870706C686A626062635E5B5E6066
6A6A686A62606363625B5B5B5E5E74C4683F2C4F7094B9A1
A7817B707C83634A5858473F382831808A8787898C8C8A8F
949BA5A7A29E999D9EA1A2A19D9B9B9DA5B0B8C8C6C2B6A9
A2978671685E4F4A3F383131312E2E2E2E2E2C2C2C282828
19191919191919191E191919191319131013131310131313
101007101010101010131313191919191913191313131919
282E4F6A70686A666A68606058585B5B5B5B5B5B5B5E6060
63626263605B585258525656585E5E585656535356565858
5653534D524F4F4A4F4F4D4A47474747
78787878767C8081807E7978787B7878707074747979796E
63606268686C63666868716E6C6A6A626362625B5B606366
6A6A6868686362626063605E626874C1A99494A1BBAA9E9E
A9AC809B707976524F5352473C2E709A968A8C898583838A
979DA5A7A5A1A0A1A19E9EA09999939391949BA9B1B4ADA2
9E9083716A5E4D473C31312E2E2E2E2E312E2C2C2C2C2328
231919191919191E1E231E19191919191313131310131013
10101010101013101010131319131E191919191913191923
2C356E746C6C6E6A6C685E5B585656566060585858585E66
68636062635E5B58565B565658585E5B525652535B565656
53524F4F52534F4A4D4A4D4A47474747
7B7B7B7B797B817E817E7C7B7B797878717071747876766E
6362636A706A666368687171686C6A63636363625E636863
6A6C6C686866666666636363666C76B4E4E2CDCAB0B6BEAE
A3A5A39386686679624F3F3535689DA09A93908A7C797B86
939BA7AEADAAAAACA2A19B999B99918F89817C7C868A8F8A
86796E665E524A44352E2E2C2E2C2C2C2E2E2E2C2C2C2828
231E1919191E23282C232319191919191913131013131313
13101010101010131310101313191E1E1E231E1E191E1E28
3C58786E666E6C6E63665B58565656586262605E5E606266
6A63606060585658585E5B5856585B58565356565B5B585B
564F4D52524D524D4D4D4D4A47474747
7B7B7B7B7B7B7E7C807C7B7C7B7C797971706E787674746E
636363666A6C66626A6C6E70706A6363686660626266666E
70716E68666C6A686363686C6E6C7697ECE7DBCED7C9BCAD
8789A2908587785B5252443F669DA9A3A0978F877B74747C
8993A3B0B1B0B3B3ADA59E9A97968C8C85797062605B6260
5E564D4744433C35312C2823232323282C282E282C232828
2823191E1E23282C312E2823191919191919131313131313
13101310101010131313101319191E1E1919191E1E232C38
6278706C706C6E6C6C665B5B5B5853586062606262606068
635E5B58585B58585E585858565656585856565858565E5B
58524F4D524A4F4D4A4D474743434343
7E7E7E7E7E8081807C7C7B7E7B7C7974717070747674706E
686668686C70686368706E6E716C6A6E686C666666686A70
717170706C68686866686A686C717486F6F5E7E2CBC1B1AD
93798CBF858C86624F443C7EA2B3B0A79E9B8C8A81706C78
818CA3AEB4B7B7B6B3A9A29E99968F8A81746C60524A4343
43433C3535312E2C231E1E1919191E1E2323282323232323
23232323232E353C3F312E23191919191919131913131313
13131310131010101910101013191E191919191923314362
71766C6C70706C6C6663585B5856585B6062636360606663
6A625858585E5B5E605B5E5B58565B5B565356585B585858
58534D4A4D4A4D4A444A4A4747474747
80808080808183817C7C797B797E79797974797679747870
6E68686A706866636C6C716E6C6C6A6A6866636A6C666C70
766E6E6C686C6C6E6C686A66686E7476E9F6ECDFDEC5BFA2
9D939AB8B08062565E636AA7B6B6B1A7A59D948F83706A6C
76839EADB7B8BBBBB8B1A3A19A938C8781786E604D433835
3538312E2E2E2C281E1E1919191919191919282323282828
232323232C3C434D4743312C1E1919191919191913191913
191310131310101019131010191923231919191E2C3F627B
7470706E6C6C6C6A6863605B5B5B5E626362636363636068
6A605E565B60605E5E585B58585E6058535658565E5B5656
58534F4F4A4D4A4744474A473F3F3F3F
80808080838186817E7B7B7C7B7B78767874787978747474
706C6E6E6E706C66686A6E6E6C68666666666A6663666A6E
74706E6C6C6870746E6C6A6366636A71CDF5F4E5D5CEC1C1
99BBB9C69D93805B4D6CA0B7B8B6B3ACA5A1978F83746E63
68768FA5B6B9C1BEBBB9ADAA9E9A94918A83806C5B4F3F38
3838312C2C2C23231E1919191919191919191E1E1E1E231E
23232323354753565247382E231E19191919191919131919
13131319131310101313131013192323191313233C4F7976
6C6C6A6A6668666366635E5B605B60626868636262636263
62625E605B62626262625E5B585E605E565353565E585656
564F524F4A4D47444D4A474747474747
8383838386858586807C7E7978787874747176797B787674
7470707171706E6C6A686A6E6C6A6863666866666266666A
6C6E6C706C6E6E70706C6C5E6263686E97E9FAF4E5CDD1CD
D1CABB9BBC8971687194B3B9B8B7B3B0A7A2999389786C62
6066809AAEB7C4C6C4BCB7B0AAA5A09E9B968F806860534F
4D4A3F31312E2C28231E1E1919191919191919191E1E231E
281E23283F56635E56523F2E28231E191919191919191913
13131919131310101013191313132323131919233852786C
6A6A6E68626663626663605E606266636360636262606263
635E625B5B5E62626862625B5B5B625E53535858605B5653
52524F4D4A4A4D474F47474D47474747
818181818685878580807B7B767474707074747878787B76
746A7071746C6A6C6C636A686A686A62636866665E626666
6A70686A686A6C746E6C68626266666A7EC8FBF7ECDEE0EA
D1B1A294BCB3805E99B4B8BBB9B6B0ACA7A2969487786E60
5B5E7190ACB4C2C8C5BEBBB6B1AAACAAA5A59D89796C6660
584F473C38312E2C231E1E191919191919191919191E1E1E
23231E2C4D686C6A5E56433528231E191919191919131313
191313131313191310131313131923231919192E56706E6C
666668636366626366636262626266636363666660605E60
5E5B5B5B586062636262625E606062605653565B60605853
564F4F4F4D474D474F4F4D4A4A4A4A4A
8181818180818686817E79797671716E70717479797C7978
716E6C6E746C6A6C68636C6A6E66666362686A6666666668
6A6C6E6E6E6A707474686863686A70687194F6F8F3E2E4E2
DCD1A99086A79B85B3BCBEBEB8B3ADA9A29B949089807462
5B586686A0AEBFC6C2C1BCB8B3AEB0ADA9A39B8574706C66
5B5347433F35312C281E1E1919191919191919191919191E
1E232C3C6070706A63584A3C2C231E191919191919191913
1919131313101313131313131319232319232858786E6863
6263626262686263626260606262666866666062605E605E
625E5E5B5B5B60626360605B5E5E605852535358605E5353
4F4F4F524D4A4D4A4F4F4F4A47474747
7B7B7B7B7C7E8186807878767474716E6E6E71787B7B7C76
6C63666A6C6A6A6668626A686C6666636068636A68686663
6A6C6E6E686E6E7174706C6A666E686E6370D4FDFDF4F3F4
E5AAA385867187A7C1BEC1BCB7B1ACA59D9B979389857B62
58535E7493A2B4C1C2BEB6B4ADA7A9A09E9B9181837C6C63
584F47434335352C28231E1919191919191919191919191E
1E23384D6C766E6C666252432C28231E1919191919191919
13131313191919131313101319192323234466766C6A6660
62636A6662636668636260605E62636262606062625B5858
585B5E58565B5B605B585B58585B605B56524F535E585852
4F4F4D524F4D474D4D4D4F4F4A4A4A4A
767676767B7C83857C78767671746E706E6C71767B797974
6E686668706E6868686366686E666866626668686A6C6668
686C68686C6E6C7070746C686A6C6C6A686C9EF8FDF7F3EA
DECDA585818691BBC2C1BCB8B3B1AAA19D9A978F8A817966
585652607E91ACB9BCB8B4B3ACA09D9DA0A1A1A09B90705B
534F47433F3F38352C231E19191919191919191919191919
1E283C566C76746E6A635847312C281E1E19191919191919
19191919191919191913131919192C3547717C716A666660
6363666263626366686260605E606262606060605E5B6058
585B5B58606060605B585E56585B5858535253535E585658
565353534F4F4A4F4F4F524D4D4D4D4D
7676767678787C7E7B74716E6E6E747168686E7479797876
6A6662636C706A686362686A6E686E66666A6E706E6C6A6A
6A6E6A6A686C6E6A7174716C6A706C6C686674DEF8FAFAF7
E6C4A79B789AB8C2C1C1B7B3B0AEA9A09E9A999089817970
60564A4A63799BA7AEA9A7ACB9AAA3A2AEB0B6BBA28A6A5B
534D4744443F3C382E23231E191919191319131913191919
192343586A747471716E5E4D35312C231E19191919191919
191319191313131919191913191E44767C7870706C636260
636666626663666866635E5B5E605E606368635E605E605B
5B585E5B5B5E5E585B58564F53535E5856524F5258585858
5B53534F525252524F4F4F524F4F4F4F
7474747474747C7C7974706E6C6C716E6E6871747B7B7976
6E66626A76706C6666636C686C70706E66666C6C6E706C6A
6A6E686368666C6A7471717170706C6E6866669EEAFEF7F3
DFCDC6809BB1C2C2BEBEB8B1B1AAA5A09B96939087817B6C
625B473C4456767C7C7B80899EA3ACAAAAA0A5AE8F796358
534A4744444343383128231E191919191913131919131319
192843526A7074716E6A604F383128231E1E1E1919191919
19191319131319191919131919235379786E666C6A666262
6263626362606266666A5E6058585E626666666260605E5E
5B5858535B5B5B585653524A52525B5B56524D5256585653
535656564F524F4F4D4A4F5252525252
7171717171747B797976716A6C707074716C6E76767B7670
6E68686E7174746C6A6C706C6C6E706E686E6A716E706E6C
6C6A636663636A6C71706E6C6A6C6E706C636378BFF8FAF5
E0D1A9A2A3BCC5BFBEBCB9B6B4A9A5A09B99949187837C71
6C624F433F3F4447474D4F5E6C7C8A8A8581858576685E52
4A44433F3838312E2C23231E1E1919191913131913131313
1E283C4D62667070716C624F3C352C23231E191919191919
19191313131913131919191919285E70716C686C6C686362
636262626260626368666060585856606668666262606058
5E5B585856565658564F534F4F52585B58524F4F5B585653
5658565B4F4D4F4D4D4D4F4D4D4D4D4D
76767676767679797B76746E6E7074767174717476787474
6C6C6E747679746E68686E746E7074706C6C706C70706E6E
70716A6363636A66706E6C6E6A6E70716C6A636C90EFFEFA
F1DFD1B6ADC6C6C1C1BCBBB6B4B1ACA7A09A938F89857E7B
7170625B585B5E5B5E534D47434A52525356585B564F4A43
3F312E28282828231E1E1919191919131919131319191919
232E3C4A60666A6E706A624F3F35312823231E1919191919
1919191919191913191919191E2E636E6E6E6E6C6A6C6366
686662625E5E6062666866635B565360666868636260605E
5E56585656535B565653535353565B58585852535E58585B
5B5B5856524F4F4A4A4D4D4F4A4A4A4A
7676767674787B7C79797871747878767674797878787674
6C6C7071717476706A6C6C6E706E6E6E6266686A6C6E6C6A
706E6C686362666A6C706E6C6A6A6E717063686371BEFEFD
F6E6DFC9C6C8C6BFC1BFBFBBB8B3ADA5A09B969089868080
7C7C7674767E81878A8670624D433C3C383C3F43433F3831
3128231E1E1E1E191919191919191913191919191919232C
3138434A60666A6E6C68624D4338312C231E1E1E19191919
19191919191919131919191E233F706E70706E6C6E6A6663
666A66625B586263686668605B565662666A6668635E5E56
5E5858524F5356585658585253565B5B565352565B5B5858
565B53524F52474F4A4D4F4A47474747
7878787878787B7E7878767176767B747679747B7B747674
716C6C747678766A68636C6A7070706A6663686A66666E68
6C6C6C68666266686A6E6C6A6A6C6E6E6E6A66626687E9FF
FEFAF5DACBC8C8C4BFC2C1BBB7B3AEA9A19796908A868686
858681878C9099A2AAAC9A8A6E5B4A433F3F43443F3C3131
312C231E1E1E1E19191913191919191E1E231E2323282E31
3843474F6063666E6A68604A433F31282C231E1E1E191919
19191919131919191919191E234A706E70706E6C6E6C6666
686666665B585E62686662625E5B5860666A6862625E585B
5B5B56534F5853585658585656565B5B5656535358565858
56535652524D4D4F4A4D47434A4A4A4A
7676767678787E7E7678787674717979787B797976747171
746C6C707871746E6A66666E7070706863666C66686C6E6C
68746C6C685E6268666C6E6866686C6C6C6E6662636CA3E4
FFFEFADCCDCBC9C5C2BFBFBCB9B8B1A7A59B96938A898786
89898A919D9EA7B0B6BEB7AEA0896C5E524F4D4F4A44433F
3C3128231E1E1E1E1E191919191E1E282C2C2C2E3138383C
4A47535B62606A6C6C685B52433F352E2C2C231E19191919
19191919191919191919191E2C566A6A6A706C6E6E6A6868
686863665E5B5E62686366605E585E6068686362605B5658
58585856565E5E56585B5B56565656585352565358535853
58534F4D4F4A4D4D47474A4A4A4A4A4A
7878787879787E7C7B787874746E767B7B797B7978747671
71686A6E7476766C6C666A6C7171716A6C666A6663666C6C
70706E6E6A626060686C6C6A636866686C6A636363687696
EAFEFAD8CBCDCAC8C6C5C1BFC1BCB7ADAA9E9996908A8A89
8A8A9397A0A3B3B7BEC4C4C5BEB19E8A7868605858534F4D
4F47382E231E1E1E231E23231E28282E2E31383C3C3F4344
53586063686A6A6C6863564F433F352E3128231E1E191919
1919191919191919191919233C68706E6C6E6C6A6A686366
686A6863635E62626663625E60585662636666625E5E585B
5E58585B5B5E60605B605E5E5B5856565256565356565352
56524F4F524F4D47474A4D474A4A4A4A
767676767478787B76747470706C7176767B787479767170
70686C707178766A686C6E707170716C6A636366666A7171
71746E6E6A62666668666A6A626263686E6A686660636674
96ECF5D1CECDCAC9CAC9C4C1C5BEB8B0AAA19B939493908F
8C90919AA7ADB8C1C6CACDCDCECABFB7A78F80746C68666A
666253443C2C232828282C2C2C2E3131353C3F4344444D52
6066686E6C6E6E6C6660584F433C38312E28231E1E1E1919
19191919191919191919191E3F6A706C706C6A6868686360
636A6662605B60686262605B565858586262605B5B5B5B5B
605E585B5B636062625E5E58585858565353535353525653
53534F4D4F4F4A4D444F4A4A4A4A4A4A
7676767676717C7E7B74716C6A6C7474767B767479787671
706A6A6C7178716C6A6C6E747174716C6A636266666C716E
7470706C6E626063686666626362666A6C6C686362606666
719ED3D1D4D1CDCBCBCBC8C8C6C1BCB3AEA79E9D9A979391
90949AA0AAB4BBC5C9CED1D3D3D1CDCAC4B7AD9D89837C79
797B7E706247312E2E312E2E31353135383F44444D4D5658
666E7678717671686662585244433C35312C28231E1E1919
19191919191919191919191931636A6C6C6A6A6368666863
68636860625E60626063625E585356585E5B5E58565B5E5B
605B5E585B5E62605B60605E58585E565252524F53535252
53534F4F4A4D4A4A4A4D4A4A4A4A4A4A
7979797976787E7B7878716C706A70717679787878787876
6E68686E7179716E686E7171747071706A626366686E6C70
70746E6C68636060626363626062666A6C6E666263636263
6E9DC4CFD1D1D1CDD3D3D1CBCBC4C1B8B1ACA29E9B9B9993
919396A2ADB3C1C8C9CFD1D5D5D4D1CFCBCBC6BEA3948178
7681918F896644352E2E2E313131383F4347474D53565B63
717980817B76716C68605B4F47443F352E2C28231E1E1919
1919191919191919191919192358706E6C686A666A666863
6660636260626060605E5E5E5653535856565658565B5E5E
605E5B585B5E5E5B5E6060605B625B56535353565252524F
53534F4D4447474A474A474A4A4A4A4A
7878787878787C7B7E766E6C6A6870717674717478787476
706C6C7476766E6E6A6A7070706C6E636A63666663686A6A
6C686A6A66625B5B626666636066636E6C6E686663636663
70AACAD1D3D1D5D4D8D5D1CDCAC8C2BEB9B0A9A2A09A9B91
949496A1ACB4C4C9CBCED1D7D5D3D4D1CBCACEC8B3997E6C
6E7E979E97794D352E2E2E3135383C3F43474A53565E6268
79808583817B766E666058524A443C35312E23231E1E1E19
1919191919191919191919191E4D6A6E6A686A6363636366
66636362606260605B585E605B56565858535656565E5E5E
625E5E6058585856585E60606063625B56565356534F4D4F
52524F4A474A4A47443F433F44444444
797979797B7B807E7B786E6E6A66687171706C7076747678
746C6C7070706C66666C6A6A706C6A636660636362686866
6C6A6866605E62606266686663666A6E6E70686363666668
7EB9CAD1D4D5D8DADCD8D4CECDC8C5C1BBB1AAA7A5A79E97
9494999DA9B0BBC9CBCDCFD1D1D1D7D3CBCACBCDB89D7B68
687C96A19D7C52382E2E3131353843474A4D4F56585E666E
818387868379747168635B524A443F35352E2C281E231E19
1919191919191919191919191935626C6E6A636868686668
63686663626260625E5B60606058585B585658585860605E
605E5B5B565658565B5E6062606262605852535256564F4F
4F4F4D4A4444474A3F3F3F3F43434343
7B7B7B7B797B7C7C7B746C686866686C706A6E7070717474
716C6E6C6E6C6862626268636A6866636262606362666668
686666625E58605E686A686368666870716E6E6A6363666E
89C6CBD4D7D7DBDCDCD8D7D1CFC8C6BFBBB6ADA7A3A3A09B
94999694A2AAB7C4CACED1D1CDCDD4D3D1CBCDCDBCA38066
667C949D97714A352E2E312E383C43444F5353565B626A71
83878786837B706E68625B4F47443C3535312C28231E1E19
19191919191919191919191919235B6C6C6A686C6A666A66
66636363635E5B625E5B626260585B5B5B5E585858605E5E
62605B58525252585B585E6063605B58534F4D4F52534D4D
534F4D4D44444A4A3C3C3C3C43434343
797979797B79797C7B786E6866666A6A706C6C6C6E717471
716A706C6E6C6A6063636C6E6C6666636060626363686666
6666635B5E5E6360686C6C6663686C6A716E6C666668686A
97CAD1D5DBDBDEDFD8DADAD5D1CEC8BCBBB6AAA7A5A2A09A
969490999EA3B3BEC5CDCECFCECDD4D7D5D3D4CEBCAC866E
6A7E90968A6844352C2E2E353C3F434F5253565B5B66717B
89878987857C747068625E4F4A443F38312E2C28231E1E19
191919191919191919191919191E4D6A6C6C6C6C6C6C6862
6668686262626360625E62636260605E5B605E58585E5E5B
605B58585353535B5B62626262605E565352524D56534F4F
4F524A4A4D44443F3F3F3C3C3C3C3C3C
71717171747879787B766C686666636C6E716C706C707474
71706C6C6E6E6A6262686E6E6E6E6A62626360636866686A
6E686660605B6262666868626066686E6A6C6E686A686C71
ADCFD3DBE0E2E2DFDCDCDFDCD1CBC8BCB8B4ACA5A1A2A19E
97919091949BAAB8C2C8CBCED1CFD4D8D5D8D7D5C4B08F76
70808C867B5B3C312E2E2E383C3F4447535356585B6A747E
8A8A8985817976706A635B5347443F38312E28231E1E1E19
19191919191919191919191919193C606E6E706C6C6A6262
636366636662626266626666666260605E60625E605B5E60
605B565B5353565E606263605E5E605853524F4F58535352
53534F4F4F4D4D433C433F3F38383838
707070707176787B76746E6A6C6A70747176706E6E717476
71706E6C706E6C6663666C7471706E6862606866666E6E6A
6A66625E666268686C665B6060626A6C6E6A6A6A68666A79
B8D3DBDFE2E6E5E2E0DCE2DBD3C2C9C4BEB6ADAAA5A1A29E
96908A919094A3B0B9C8CDD1D4D3D5D7D8DCDCD8CBB99983
7B83857C6E4F382C2C2C2E2E383F43444F4F4D535B6A797E
878985857E7B74706A6660584D443F38312C2E2C231E1E19
19191919191919191919191919192C526A6C6E6C6C6C6358
6060686366666366606266636860606060626060605E585B
605E5B58585B5E5E6262625E5E60625B584F4A4F56564F4D
53565353524F4D474447433C3C3C3C3C
717171716E7179797C78716E717071787676716E70717476
707070707171706866686C717171716E63666A70686C7068
68686860626263666663605B6060666C6E706A6A6A6A717E
C1DADFE4E4E5E5E5E2E2E0DBD5CBC9C4C1B9B3AEA7A2A29B
968F878C9094A0AEB6C2CBD1D3D4D5DADBDEE0DCD1C5A58C
8586836C60432E2C282E2E31383F3F4447474A525868797C
878785817B76716E6C665E524A443F38352E2C28231E1E19
19191919191919191919191919191E3F63686A6C6A665E58
626066636366636362626260636262626360625E5E60585B
5E60625E56585E60605E5E5E5B605B5856534A4D53564F52
52535353524F4D474344473F3C3C3C3C
707070707174787B7C7976717174797C7B79707174747476
787671747474786C666A6E707171706E686A6E706A6C6C6C
68666363606263626362636062606668706E6E666A6E708A
CEDEE2E4E5E6EAE4E5E4E0DED7D1CDC5BFB9B4B0A9A2A29B
918F86898A919BA9B1C2CBCED7D7DADBDADEDFDBD5C8B19B
8F8679604F3C282323232C2E2E38353F4344474D58667179
818681817E7874706C63605847444438352E2C2823231E1E
1919191919191919191919191919192C5E6A6A6A6A625B58
6060666266636362626062606363626060606060605E5B5B
6063625B565B5B5B635B5B58565B5B5E5B524F5256534F4F
5253565658524A4443443F433F3F3F3F
7171717174767B7B7E7B79787976797B7B78717471747878
78766E70767B74706C66707174716E68686A6E6E6E6C6E68
686C6362626263626862605E606062666E6A6E6A6A6C7093
D5DFE2E9EAEAEAE6E9E4DFDCD8D4CFC9BFBBB7B1ACA7A2A0
94918685898A93A0ADB9C6CDCFD4D8DAD7DBDBDBD1C8B99D
8978624A3C2E231E192328282E2E3535383F434A53637078
7E83817C7970706E68665E584A44443835312E28231E1E1E
1919191919191919191919191919191E52666A6668625858
5E63636362636663605E6362636663666062605E605E5E5E
6060605B5856565B60605B5E585B5B5858524D5656584F53
52535656534F4D4A43474A433C3C3C3C
7474747474797C80807E797E7874797876716E7171747679
71746C6C7079747068666E70716E6C6C6C686E706C6E6E6A
6A6868626060626263626260636262666E6C6C6A666676A0
D8E4E4EAEAEAEAE7E9E6E2DFDFD7D3C9C4BBB7B4ACAEA3A0
979185858786909BA3B4C1C6CBCECFCBC8C9CACEC9C1AD93
7B523F2E28231E1919191923282C2E2E31383C4A53626E79
7E817B8076746E6E63635E584A47443C38312C2C231E1E1E
191919191919191919191919191919194368636C6363625E
6262666366626262605E5B60626366625B605E605B5E5E60
63625E5E585B5B5860565B5658585B585652525358565252
52535353534F4A4A4A4A4A4444444444
7474747474797C7C7E7C78787470717470706E7070717674
71706C666C6C706860626A6A686A6A6A6863686C706C6A68
6C6C6662625B5E62636668626263606266686A68686678A5
DAE4E5E6EAEAEAEAEAE9E4E2E0DBD8CDC8BEBBB6B3AAA7A2
97968681808589969EAEB8BFC2BCB3ADA5A5A9B1ADA79174
562E281919191919191919191E1E1E232C2E35444F606C74
79787B797871706866625B584F4A4338353128281E1E1E19
191919191919191919191919191919192E56534D4A4F6260
63636A66626262625B626062626366626263605E585E5B60
625B58604F56565B5B56565656565652534F535656565252
5252524F524D4A47444D4A4444444444
7070707074767B7E7E797B71707170716E70686E71747674
6C6C686666686668605E6268686668666663666A6E6C6E6E
6C6C6363625E5B5E636663686266636663666A63626C80B3
E0E5E7E7E7E9EAEAECEAE7E6E4DFDBCDC8BEB8B4B3ADA7A7
9B9787838080858A94A1B0B1AC9A8985868C91948F836C4A
3C23191919191919191919191919191E1E2C31434F5E6870
78787676746E6E6860605E564F4D433C352E2C231E1E1E19
191919191919191919191919191919191E2C2319191E314F
5B62636660606060625E6366666A68626666625E6063625B
53585B585356565E58535656535656525352525353565352
4F4F4F524F4D47444A4F4D4A47474747
71717171707479797E797876706C6E6A7068666C70707671
706C62606263605E585860666863686662636868686A6E6C
6E6E636662625E60636A6C6A6A6A6A6A66686C66686C89BE
E5E6E9E9EAEAEAEAEDECE9E9E4DFDACECAC1BBB7B4ACA9A5
9E9B8985808083858A9AA2A38C70626668798589796C523F
312319191913191919191E19191919191E28354352626871
78767676746A6C6862605E584D4A433C353128281E1E1E19
19191919191919191919191919191919191919131319191E
3853686A63606262626062636C6A66636868636260635B58
585B58565653565858534F4F4F564F53535252565352524F
4D4F4F4F4D4A474A4A4D4D4D4A4A4A4A
7171717174717476797876706A6A706E6E6A66666870706E
6C6C66626666625B565B60636A68666262626868666A6C6A
6A66666862636666666E6E6E686A6C6C686C6C63686E90C6
E5E7E6EAE9E9EAEAECEDEAE9E4E0D8CDC9C6BCBBB7B1ADAA
A5A18F87858083858996A3A1835E4343567987857968523F
31231919191319191E191E1E191919191E2335434F626870
76787174716E6C6662625B534F4A4338382E28231E1E1E19
191919191919191919191919191919191919101313131919
19285668625E60686068686C6868636362626060635E5E56
5856565656565856524F4F4A4D525252524F4F5253534F4F
4D4F4A524A444343474A4A4A44444444
6C6C6C6C74716E79767671706C6A6A68716A62636A6E706E
686E66636363625658586066636A66626062686366666866
6866666263636663666E706E6E717470716C6E68666A94CB
E5E6E7E9E9E9EAECECEEEEEAE6E0DAD1CBCAC4BEBBB6B3AE
ACA5998986838385899DB1B49A7960627B949A8C7B6A5643
382C1E191919191E191E1E1919191919192835444F5E686C
71787176716E6E6A63625B584A4A443C352E2C281E1E1E19
191919191919191919191919191919191919191013191319
19192C6062685E606266686C6C66666368666060605B585B
5653565653565656564F4D4D4D4F53524D4F525352524D52
4F4D4A4D4D4A44434347474443434343
7171717174706C7471716E6A686670706E6A6262666A6E70
70706E6E6E68665B5B5B626A686A666662626666666C6863
6362606060606260666A6C6C70717171706C6C6A6C6A9AD1
E5E9E7EAEAEAEAECEDEEEDEAE9E0DBD3CFCDC4C1C1B9B9B3
AEAA9D948F87838689A2BFC8B8A59799A2A9A28F7C6E6053
4331231E1919191E2323231E191919191E2838474F5B636C
6E717174706E686866625E5B4D4A443F382E28231E1E1919
191919191919191919191919191919191919191319191919
1919193F5B6263625E666C6E6C66686263625E605E5E5856
565252534F525653534F4D4D4D5252524D52524F4D4F4A4F
4D4D4A4A4444433F444347443C3C3C3C
747474747170686E6C6E6C6C66706E706E686266636E7174
74747476717168605B60666C716C6A666666686A6A6A6363
666362625B60606068666A6C6C6C74716E6E6C68686EA3D4
E5EAEAECEAEAEAEAEAEDECEAE6E2DAD5D1CFC9C6C1BFBCBB
B4B0A79E9790898A8CADCEDAD5C8BBB9B7B6AC967E74635B
4D3C2C1E1E1E1919191E1E1919191919232C3C4A52606363
686E70706C6E686863625E58524A4438352E28231E1E1E19
191919191919191919191919191919191919191913191919
1919191E3F626360606A6E706C686360605E58585B585858
585652534F524F5653525252524F564F4D4D4D4F534F4D4F
4D4F4F4D474444443F4443433F3F3F3F
6E6E6E6E6E6A6C6E71706E6E686C7074716A6268686E7178
767676787678706862636C6E766C6E6A636868666C686863
636668635B585B60606666686A6E6E706E6A6A6A686CB0DB
E7EAEAEAEDE9EAEAEAECE9E7E6E4DCD5D1D1C9C5C1C1BFC1
BEB7ADA5A29A8F8C93ADD5E2E4DFD1CDC6BCB39B7E71685E
583F312C231E1919191E1E19191919192C2E3C4A56586663
6C6E70706E6A686663605B584D4A3F3C353128231E233819
191919191919191919191919191919191919191913191319
191919191E476263666A66686A66665E5E5856585B5B585B
565652524F4F4F56535356535652585253524F52524D4D4F
4F4D4D4A4A4A474747443C3F38383838
6C6C6C6C6C6A6C6C70706E71706E7471716C63636A717679
7674786A7071786C68666E74746E706868666870686A6C66
686E6A6C60605B6060666266686A6C6A6A6E6C626C6EB8E2
E7EAEAEAEAEAEAE9E6EAE7E7E7E2DCD7D5D1CAC8C1C4C2C5
C4BCB6B0A7A79A9399B0D4E2E7E5DCD8D1C6B79B7B68605B
584A352E282319191E1919191919191E2C313F4A4F536266
68686C686663666060605B564D4A443C3531281E1E1E5219
191919191919191919191919131919191919191919191319
19191919191E4F60636866686362605B5B585B585856585B
5853534F4D4D53565656565358565853535252524F4F4F4D
534D4F524D4A4D4A473F3F3C43434343
6E6E6E6E6E716C717171717470707671716E666A6E747474
797471707171717070707176767470686A6A686E6A686A6A
6C706E7063625E60636266666368706E6C706E686A79CBE2
EAE7E9E9EAEAEAE7E9E7E6E6E4DFDAD5D3CFCEC9C6C8C6C8
C5C4C1BBB4B3A59EA1ADD1E2E4E2E4DFDCCDBF9A76635656
534438312C231919191919191919191E2E313F4A4F566062
686A6A6A66666362605E58584A474438352E2C281E23441E
191919191919191919191919191919191919191919131313
191919191919234363686268626260585E5B5B5858585858
585653564F524F5B56565658535656565656524F4F524D4D
4D4F4F4D4F4D4F4D47433F4343434343
666666666A6C6E70787479746C707476767166666E707171
747174666A707071747178797676716E6C6A66666C686668
6E70706A6A6260606266606666686E6E6C6E706A6E8CD8E5
EAECEAEAE9E9EAE9E7E9E4E4E4DFD7D3CFCFCDCAC9C8C8C8
CAC9C6C6C4BEB7A9A7AECDDBE0E0E4E6E6D1B99371604F4D
4D4A3C312823191919191919191919282E353F4A4D53585E
63636666626363625E6058524A443F3835312C23231E2319
1E1919191919191919191919191919191919191919101913
131313191319191E5B6A63606060605E60585E5858535658
585856565252565656565358534F53585656524D4F4F4D4D
4D4A4A4D4D4D4D4A4343443F3F3F3F3F
666666666866686E787178706E6C70717470666A6A6C7171
71716A6C686E7071747479787B7070686663666A68666666
6C6C706C6862606266636366686A6C6E7170716A6EA7E2EA
ECEAECECEAE9EAEAE9E9E4E4E5DFD8D1D1D1CECDCBCACACB
CDCBCDCEC9C9C4B7B1B6CDDBE2DFE6E9ECD5B8856862564D
4A4A3C2E2C231E1919191919191E23283135434A47525358
60626060666062625B5B53534D4A3F38352E2C281E1E1E1E
1E191E191919191919191919191919191919191919131313
13191913131919192E6063625E5B585B585E585B58565652
585B5653535356585B5858564F5252534F5353524A4D4D4D
4D4F4A4D4A4A4743433F444743434343
636363636A68636C6E71716E666C707070706663636A6C71
6C6A6668636A716E70717878786E66626062636868686363
66686E6A62606266686A6A6863686A6A6E6E747076BBE5E7
EAECEAECEAE7EAEAEAEAE6E4E2DFDBD5D1CDC9CACBCBCACF
D1CFD3D3D4D3CEC4BFBCC9D5E2E0E5E7EAD5B48366606256
52473C352E231E1E19191919192323282E353F44474F5358
5E5E6262665E5E605E5B5B4F4F4D3F3835312C2E23231E1E
1E1919191919191919191919191919191913191913131313
13131919191319191944635E585B585B585B5B58585B5356
585853535253585E5B5858524F524F524F4F4D4F4D4D5252
4D4A4D474A474743433C3C4747474747
66666666666663686C6C686C666A717170706363666E6E70
6C6A6663666C6E6A6E707674746E6C665E5E606666666863
66686868635E63666C6E6E6E686868686E6E707178C5E6EA
EAEAECEAE9EAE7E9E9E7E2DFDCDAD7D1CFCECACDCBCDCBCF
D1D1D1DBDCDBDCD7D1C8CAD1DCDFE2E2DECAB389766C6E63
5B4A3C312E231E19191919191E23232831353843444A5353
58585B5B5B5B5B5B5653524F4D4A443C38312E312823231E
231919191919191919191919191919191913191919191010
131919131313191319235E5858565658585858585856585B
565B565656585856585856564D4F4A4F4F4D4F4F4D4D4F4D
4F4A4A4A4747443F3C3F3C4344444444
68686868666362626A666363666E6E716C6A626266706A6E
6A6A636366686E6E6A6C6E7071706A625B5B5E6366636368
68686A6A636266686E6C6E6E68636666686E747691D7E7EA
EAEAEAEAEAEAEAEAEAE9E5E2E0DCDBD7D1CFCBCBCDD3CFD1
D3D1D5DFE2E2E5E2DFD7D3D7DBDCE0DBD1C5B3948078766E
624D3F312E232319191919191E23282C3131383F444A5256
535858585E585B5B585856524F47443F3C3531312C282323
231E19191919191919191919191919191919191919191313
131319191313191319194D585E5B58565656565656565356
5E56535653535B53565353524A4D4A4A4A4A4D474D4F4F52
4F4A4A4A434347383F383F4344444444
63636363636260626666606262666E71686C6263636E6E6A
6A68636A686E666C6A6C686E6C6A6C625E585E6666666666
666C6C6A626662637074746C6C6868666C6A7085BBDFE9E7
EAEAEAEAEAEAEAEAE9E5E4E2E2DFDCD5D1CECBCECBCFCFD1
D5D7DBE2E5E7EAE9E5E2DEDEDEE2DFD8CDC4B89A87867E6E
604D3C35312323191919191E232323282E2E353C3F474F4F
4D4F5653585B585B585856524F4A4443383131312C2C231E
1E1919191919191E19191919191919191319191919131913
101013131013131313192E535B5B585B56565856585B585B
58535352525256565656534F4D4D4D4D4A4A4A474A4D4D4F
4F4F4A443F4344433C383C3F44444444
6C6C6C6C665E6362666260626366686A6A68666666706E6C
666A66666A716C6E6E6A6A6A6C6863605E605E6363666366
686A6A68606266686E746E6E6E6C686A6E6C71AAD8E2EAEA
ECECEDEAEDEAEAE6E6E7E5E2E2DEDAD3D1CECFCBCDCDCECF
D4D5DEE0E5E9EAEDEEEDEAE7EAE9E2D5CAC1B6A1918C8374
634D3F352E2C28232319191E232828282C2E35383C444447
474F4F53535658585B5B5653524D4743433835312E2C2323
1E1E19191919191919191919191919191919191919191913
131310131010131313191E436062605B5856585658565658
585B53535353565853534F524D4D4D4D4A4A47474D524F53
534F474A4444434438383C4344444444
6A6A6A6A6360666666636360626266686A66686868706E66
686C6C666C70706C6866666868666863626266626A686662
6C6E6A6C6666636C7070706E6C70706E6C6E80CEE2E5EAEA
ECECECECECEAE9E9E5E5E2DFDFDBDAD3CFCECDCDD1CACDCF
D1D4DBDEE2E4EAEEF1F1EEF1EFEDE7DBCAC1B6A59D978A7B
6A4F4338312C28231E1E1E1E232323282C2C2E35353F433F
444A4F524F56585856585B58524F4A47433F35382E2E2C1E
231919191919191919191919191919191319191919191913
1310101010101013131319235E62625E5B56535653585656
5656524D524F525353525252524F4A4F4D4744474A4D5253
4F474A44444D4A443C38433F3F3F3F3F
63636363626262636A68636060626A6C706C6663666E6A68
636A686E6A6E6E6C6A6666686366686666636363686A6868
666E6E6A6666686A6C6C6C6E6E707071787496DEE2E2E9E9
EAEAEDEAEDEAEAE9EAE4E2DFDCDCD8D1CECBCACBCFCBCBCF
D1D3D8DBE2E4E9EDF1F3F1F4F4EFE9DBCBBCB1A7A7A0937C
6C4F433831282828232323232323232823282E2E35383C43
44474A4F5656585B58585858524D4D47433C3531312E2C23
231919191919191919191919191919191919191919191919
1013101010101310101319194462605B5B5B565353565852
5656524D4D525353534F5252524D524F4A4747444D4D4D4F
4D47443F4447444A443F3F3F38383838
60606060636663666A6862606062666C6C686A66686A6A62
686868686C70706C6A66666E6A66666663636A6C706E686A
6A6E6E6C686A6C6E6C6C68686E7071717479B7DEDCE0E9EA
EAEAECEEECECEAEAE5E5E2DFDFDBD7CDCECAC6C8CBCAC9CB
D1D4D8DBDFE2E5EAEFF4F3F5F4F1EAE2CFC1B9B1ACA59683
6E524338352E2C28232323282323232323232E2E35353C3F
434A52525658585656535652524A4743433C35312E282823
231E19191919191919191919191919191919191919191913
101010101010101013131319285B605B5B565353535B5858
56564D4F4F525656524F4F4F4D4F4F4F4D4747444D4D4D4A
4D4A4A44474A4D4A3F3F47443F3F3F3F
60606060606060636366635E586063686A6E6C686A636362
66686C6C6E746E6A6E6C6A6C6E666C6866666E6E706E706E
6C6E706E70686A686C6868666A6E6E74787CCDDCDEE4ECEA
EDEAECEFECECEDEAEAE9E4E2E0DCDACDCDCACAC9CBCACACB
CECFD4DBDFDEE5E9ECEEEFF1F5F1EAE5DACBC6BEB1AA9485
76524338312E2C23282328231E1E1E1E28232C2E2E353C3F
474F4D5253585656534D4F4D474747443F3C3835312E2C23
1E1E19191919191919191919191919191919191913191919
101013101010101010131319193156605858585B58585658
5853564F4F535252535252524D4F524D4A4A4447524D4A4A
4F474A474D4F4F4A4A4444433F3F3F3F
5E5E5E5E5B5B606366625E5B5E5E63636C6A66686C6E6863
666A70706C6E6A66666866636A686C686A686C6C6C6E6E6A
68706E6C6C686A6A68686868706E70767B89D4DCDCE4EAED
EDEAEDEFEEEDEDEDEAEAE5E0E0E0D8D1CFCBCDCECBCAC8CA
C9CBD1D5D7D8DFE5E9EFECEFEEECEAE9E2DAD1C8B7AC9B85
714F433535312E28282823231E1E1E1E2828232C31353C3C
4D5352564F5353524F4A474744433C3C3F383531312E2C23
1E1E19191919191919191919191919191919191919191913
131010101313131010131019191E385860585E5B58585B56
565352524F4F52565352525352534F4F474A4A4D534D4D4D
4A4A4A4A4A4D4A4D4A43473F44444444
5E5E5E5E5E58606362625E5B585E62666868666363666A6A
686E6E6E6E706E6363666666666368636666686E686C716C
686E6A6C6C6863686A6866686C6E7176799BDAD5D1E2E7EC
EDECEEEFEEECEDECECEAE9E2E2DFDED8D4CFCFCECAC9C8C9
C8C6CAD1D4D3DADFE2EAEAEDEAEAECEAE9E2DBCABCB19B89
765E4A4338312C2E2828231E1E1919191E23282C2E384343
444F524F4D4D4D524A4747433C3C3C383131312E2E2C2C1E
1E1919191919191919191919191919191919191919191919
13131310101010101013131319191E52625B625E5B5B5B56
56534D524F525253535256535653524D4D4A4D4D524D4A4A
474A4D4D4D4D4A474A47444344444444
5B5B5B5B5B58606366666058585B62626863606060686866
686C70716E6C6C636260606266666668666A6C6C6C6A6C6E
6A6A6866666263666C6A6A686C6E6E7B7EB6DABFCBE0E9E9
ECEDEDEEEDEAEEECECEAE9E5E2E0DCDAD7D3CECDCBC9C8C2
C2BFC5C8CBCED5DCDEE4E6E9E7E9EDECEAE4E2D1C5B8A28A
7B6656443C352C2E2828231E191919191E1E232C2E383F44
4753524F4D4A4D474443433F383C3531312E2E2C2828281E
1E1919191919191919191919191919191919191319191919
131010101010101010131013191919315B5E5E5B5B5E5656
5856524D4F4F535856565356565256524F4F4F4F4F4F4747
444D4F4F4F524D444347444447474747
5858585856565E626366605B56585E606262605B5E636868
707070686A6A6C62605E5E6060686668666C666C6C6C6A68
66666363626263666A6E6C6A686A70788FCECEB7C9E0EAEA
ECEEEEEEECEDEDECEEEAE6E6E2E0DEDBDACEC9C8C8BFC2BF
BEBFBEC1C6C9CED7D7DFE2E6E7E6E9EAEAE7E5DBCBB9AA91
85685B443C312E2C28231E19191919191E1E2C2E313C474A
4A4A4D4D4A4A4D4A4747443F3C35312E2E282C2828232319
1E1919191919191919191919191919191919191919191919
1310131013131013101310101319131943585B5658565656
52564F4D5252525656535656585353524F4D4D4A524D4744
474A4D4A4D4A4A433843444343434343
5B5B5B5B56585B626666605E5E5858606263605B5B636668
68666C6A6A6A68625E605B6063666C666668636C6C686A66
626063666263636C6C6E6C686A686C71A7D3B9AACBE2E9EA
EEEEEDEDEDEEEEEEEDECEAE9E4E4E2DCDACFC9C8C2BFC1BC
B8BBB8BBBEC1C8CACFD8DEE2E4E5E5E9E9E9E7DED1C5B199
8A705E443C352C28281E1E19191919191E23282E31434444
47474D4F4A4A47474343433C3831312E2E28282828231E19
191919191919191919191919191919191919191919191913
101010101013101010131313131319192347585858535653
53525252534F525356585E56585B52524F4D4A4D4F4F4A44
44474A4A4D4D4A434343444A47474747
5B5B5B5B5B5660636A6663625E5B5B6060625B5B5B606866
6A66686C68686A6862625E62666C6C6A686A6A6C66686366
666666636666636870716E6A6A6A6C76BFCEAEB0D1E5E7EA
EDEEEFF1EEEFEEF1EEEFEDE9E9E7E4E0DED3CEC9C4BCBEB8
B3B4B0AEB1B6B9C1C6D3DBE2E4E2DFE2E7EAEAE5D8CFB9A3
91765B4A3F352C2C282319191919191919232831353F4447
4D4D4D4D4A44433F3F3C383531312E2C2823282819231919
191919191919191919191919191919191919191919191919
191310101013131010101319191313131923565856564F52
5653524F534D535656585658565652534F4A4A474F4D4A47
474A47474A4747473F43474A47474747
5E5E5E5E58585E636668666362605E6263665B5B60606068
68666868686C6C6866606263626A66666363636666666363
62666C6A6E6C6C6C747170686C687480C9C5A1B8D7E5EAED
F1F1F1F1EEF1F1EFF1F1EFEAEAE9E6DCD5CDC9C5C1B7B7B3
B0B0A5A9A9A9AEB6B8C1D1DBE2E0DFE2E4E7EAE7DFD5C5AC
997962473C312C2823191919191919191923282E313C4447
4D4F4A4D4A433F3C3C3C3C35352E31282C23232319191919
191919191919191919191919191919191919191919191913
131010101010101310101013131310131919435653524D4D
4F524D4F5353565856585B585653524D4F4A4A474D4D4A4A
47444744474A44474343474747474747
5858585858585E66636A6666636060626368626060626268
63686868686C6A686A626263686668686A63636363636663
686A6E707170706C6C6E6E6A6A6C7194D1B994BEDCEAECED
EFF5F4F3F3F3EEEFF4F3EEEDEAE6DECDC9BCB4B0A3A09E9E
9EA09EA1A0A1A2A5ACB4C5D3DFE0DEDEE0E5EAEAE4DFCAB4
9E78624A43312C2823191919191919191E232C2E313F4A4A
4F4A443F3F31353538383831312E2E2C28231E1E19191919
191919191919191919191919191919191919191919191910
1310131310131313131010191913101313192852524F4D47
4F524F52565256585856585653524D4D4A4A44474A4A4D4D
4A444744474A4A473F43474443434343
585858585B5B626663606663666262636A6A666260626366
68666366686E6C6A68636268686866666062626260626063
636E6E7470706C6A6C6A68686A6A78B3CAAD93C4DFE7EDEE
F3F4F6F5F5F4F3F1EFEFECE6E4E2D8CAC6B9AEAA9E948F8C
8C8C93999D9D9DA1A3AEBEC9D8E0DBDADBE2E9ECE7E2D1BB
A37B624D43352C281E1919191919191E1E23283131384344
38352C2828231E282E3135312E2E2E282C23191E19191919
1919191919191919191E1919191919191919191919191913
10101013101310131313101313191313131319434F4D4A4A
4D52535856565B5656585653534F4D4D474A44434A474A47
4A474343444747443C3F434343434343
5E5E5E5E5E606062625E6262606260636C7068666362666C
6A6868686A6A6868666668686A6C68626360626262626263
666C747871746A6A63686A68686E93B9CAA993CDE2EAEDED
EFF4F1F3F4F3F1EDECECE9E2DFDFD8CFC6B3A39B8F85837E
80858A9196999DA2A9B3BEC8D1DAD8D3D8E0E7EDEAE9D8C1
AC816A5344352C28191919191919191E1E23282323282C2C
1E19191313131919232C2E2E2E2E2C282323191E19191919
191919131919191919191919191919191919191919131313
131310131010131313131319131313101013192E474D4D4F
524F535656535656525252524D4F4F4D4A4A4747474F4D4A
473F433F444A47433F43433F3C3C3C3C
5E5E5E5E60605E5B5B606062606362666A6E686363666666
6A6C6868686A6E706E666A6E6E6A6A686263606262606262
666A707470716C686A68686A6E76ACACCBA999D3E4ECEEEF
EEF3F1EFECEDECEAEAE9E5DFDCDBD3C5BBA28F7E6E5B5653
586278818989939BA1ACB9C2C9D1D4D1D3E0E5EAECEADBC8
B689705B4D3C2C281E191919191919191919191919191919
13191010131010131923282E2C2C28231E1E191919191919
131919191919191919191E1E191919191919191919191910
13131010101010131313131919131013131313234353524F
524F5253525252534D52524D4D524D4A4A4D474D4A4D4F4D
4747443F474A4444433C3F3C3F3F3F3F
5E5E5E5E5E605858565B5E62606062636868686A66626368
686E6666636E686E6A6A6E7071706E686662606263666663
66637071746E6E6E68666A687197A7A1D3AD96D3E2EDEEEE
EDEEECE7E7E5E4E2E5E4DFD4D4CDC1A99E87604A3C2C2C2C
2C2E627679797B7B7E91AAB8C1C8D3CED1DCE2EAEEECE4D1
C1937962533F2E2819191919191919191919101310131313
101313131313131013192C2C28231E191919191919131913
131919191919191919191919191E19191919191919191919
1313131010131310131313131E131313131013192E5B5252
5356565252524F524F4F4D4F4D4D4A4D4A4D4D4D4A4A4A47
47474A47444A474A433F434443434343
606060606260585858585860605E5E6268666A666068636A
686A686A6A6C6E7068686A706E71716C6366606366636266
666C717174746E6E6E686A6E94A79694D4B09AD7E4EAEEEC
EAEAE7DFD5D1CDD1CBCBCDC6C4B9A090805831281E191919
1919436A716C635B5B6C96A7B7B9C8C8CDDAE4ECEDEFE7D5
C69B8168564331281E1919191319191E1913101013101010
10131010101010101019282E2C231E191913131313131310
131313191919191919191919191919191919191919191313
13101010101010101010101313101013131013191E585653
58565253524F4F524F4F4A4A4D4F4D4D4A4A4A4A4A4A4447
444A4D4A474A4D4A4343433F44444444
5E5E5E5E605E5853565B5B5E62605B606362666360636266
686A68666A6C706C6A6866686E716E6668625E6063636266
6A7074767678716E706E6C79A9A0868AD4AAA1D7E6EEEEEE
EAE7E2D3C9BBB1A99E9B9B9DA09685816A311E1919191919
19192E5E6C68584F4A4F7994A5A3B7BCC9D4DEE9ECEAE7D8
C69E836A5844312C19191913191919191913131310101010
131313131010101013192C28231E19191313131313131310
131913191919191919191919191919191919191919191910
101010131010101013101313131310131013131919525656
565B5656564F5353524D4A4A4A4F4D4D4D4A4A4A4A4D4A47
474A4D4A4A4A4A444743473F43434343
5B5B5B5B5E5E53585B5B5E6260625E60626662665E636263
636366686C6C706668636363686C6E6663605B606262636A
687176787B7970716C6C6C91A7967881C691A3D8E4EAECEA
EAE2DFCEBFAE9E856E635B5E606363715223191919191919
1919285262604F433F3F5B78878FA0AEC4D1D8E0E6E6E2CF
C2A1856A5844312C1E191919131919191913101010101013
1928231310101010101923231E1910101010131313191313
191313191919191919191919191919191919191919191310
101010101010101010101013131010131310101319475253
5653565658535353524F4A4D4D4F4D4D4D44474744474447
4A444D474747473F443C3F3F38383838
5B5B5B5B5E5E5858585E5E606062606266666362605E6260
636363686A6A6663606062636268666362625E5E605E6066
6A6A78787B78716E6A6E74A79B836C70A271A7D5DFE7EAEA
E7E0DCC9BBAD9B7E5B44352E2E2E38472E19191913131913
1919234A5B524435353C5668717E96A5BBC8D1D8DFDED5CA
BEA0856E6047352823191919191919191919131010101013
192E23131010101010191313131313101313131319191919
191919191919191919191919191919191919191919191310
1010101010101310101010101313101013131313193C4F4F
5358585E58534F524F4D4A4A4D4F4F4D4D4A4A47474A4444
474A4D47434744433835353C38383838
585858585B5E56585E5E6062606260606A68686663636360
68626668686366635E5B5E5E5E6362605E605B5B62605E63
6666707476766E6A6A6E85AE8C7866666C60A5D1DBEAECE9
E5DFDACBC1AEA0815E44312C281E192C1E191919191E1E13
19131E3C433C312E3144565E687190A0B4C5CACED1D1C8BF
B69B856E5E47312823191919191319191919191919131310
101913131010101013101313101313131313191919191919
191913131319191919191919191919131913131319191010
101010131010131010101010101010101013101313314F53
56565658525252524F4A4D4D4D4F4F4F4D4D474747474A4A
444A4A4A4A474344383F383838383838
53535353565B5653585E5860606060606C6C666663636868
66666362686A6663625B585E606062605E5E606360605B5E
62606A6E71706C6C68709BA07B6A605844589DCED7E4EAE7
E7DFDACDC4B6A98F6E583C2C281E191919131E1E28282319
10131923282828314353585B6370899BB0BEBFC9C5C5C1B4
AC94816A6047382E2819191919191919191E23231E191913
101010101310131310131319131319191919191919191919
191919191919191919191319191919191919191319131313
101010101013131010101010101010101310101313314F56
535858564F4D4F4F534D4F4F4D4D5256524D4A444A444344
4A4A4A4444443F443C38383838383838
53535353535356585656535B5B5E5B6268716E686863666C
6868666363666862625E586060606062605E606063666062
5E60666C6C6E6C666683A9907062533C385691C1D1E2E9E9
E5DFDED1C9BFB3A1877B5E3F2E2319191919191919191919
1919191923283543535B626063708999AAB4BBBBBCBCB6AC
A18C7B6C5E4D3C3128231E19191919191E23282C2C28281E
191919191919191919191919191919191919191919191919
191919191919191319191319191919191919191019131310
101010101010101010131010101010101310131013315256
525656534D4D4D4D4D4D4D4A4D4D4F53534D474747434444
4747474444443C3F3838383838383838
4D4D4D4D4F53535653535B5B585B605B636E6C6863626368
666366626062666060606262626663626362606663635E5E
605E6366666A6663689AA77E6358382E314D80A9BED8E7EA
E6E0DFD8D1C9C2B3A1917B635B473528231E1E1919191919
191E282C353F4A56586266636E78909AA3ADB1B1B3B1A9A2
9B87786C5E4D3F352C282319191919191E232C313135312E
2E282828282C282C282828231E1E2323231E1E1E19191E19
191919191919131319131919191919191919191313191010
1010101010101010101313101013131310131919193F5253
565653524F4D4F4D4D4D4D444D4A4F524F4D4A44473F4444
434D4A4344443F3F3C38353C38383838
4D4D4D4D4F5253535252585B5E5B5B5B666866635E606260
636060636363666363626263666366666062636663626360
6262626A6866636266A9966E523F1E2C2C38668194BBE0E6
E2E0DBDBD4CBCBC4B7AA9B87867866564F4A433F38353C38
3F3F444D535858605E6066666E7C9199A1A3A5A9AAA5A59D
937E71665E474338312C231E191919191E23283131383C38
3F35353135353535383531312E2C2C28281E1E231E191E19
191919191919191319191913191919191913131013101310
10101010101010131010101010101313131919191E475853
534F524D4F4F4D4D4A4D4D47474A4D4F4D4D4744443F4743
474747444444383F3C38383C38383838
4A4A4A4A4F5356524F53565B5B5B606063666360585E6062
6360606363666868666363666662666362666A6A66686662
636363666A6668627BA18058352319282C314F5E6CA0D1E0
E0E2DEDCDAD3D4CBC5B9AEA5A09687807E79706C6863635B
60606262636260626060626870788F949A9A9D9EA0A19D93
897E74685B4F443C312E28231E1E19191E1E232E31383C3F
3F3C3C3C3F3C3F3F3C3F3838312E2C2C2823191E19191919
191919191919191319191919131919191919191313131310
1010101010101013101010131013101313191319234F5252
4F524F4F4D474A4A474A474D43474D4F4D4A4A43434A4343
444A4A4A433F433F43383C3838383838
4A4A4A4A5253534F4D5253585B5B5B606666605E58606260
60605E63626268666863636666666663636366666A686868
6A666E7070686362918F6E432819191E2C2E3F435289BBD5
E2DCDADEDADAD5CDCAC6BFB7ADA7A1969490898580807C76
716E6E6E686862666262666C787B8987909394979A9A998C
877C6E635852473F382E2C282319191E191E232C2C2E3131
383F3F3F433F43433F3F3C31312E2C2C281E1E1919191919
191913191919191919191919131919191919131313131010
101010101010101313101013101010131319131E354D4F4D
4D4F4D4A4D4747474D4A4A4A44474A4A4D4A3F3F3F3C4343
43444444433F43433F3F43383C3C3C3C
4D4D4D4D5356535252535358585B56586260626360606063
6062626363626A686A686362636663636666666C666A6866
6A6A707170686C6AA07C582E1E1E1E19232C2C313F74A0C6
E0E0DBDAD7D7D5D1CECAC5BCB6B1AAA29E9B938F8A868383
7876716E686A666662636A6C71788183878A8C939A99968F
857970685E534A433F382E2C282323231E1E1E2828282E2C
2E2E2E353838383F3F3F3F38312E2E282323191919191913
191919191919191919191919191919191913131313131013
131010101010101010101313101010131313131928474A44
4A4A4A474F47474D4A4A473F3F43444A4444433F3F444343
474447473F3C3C444743443C3C3C3C3C
4D4D4D4D56565352535356585B5B5B586263666363606360
6060626263636E666A6360605E636366666366636A686868
686C7074706E6E6CAA744323191E1E191E23232C35668FAD
D5DFDAD1D1D7D4D1CEC9C4C4C1BBB3ACA5A19B9389868580
79746E6A6863666260666A6C7174808183898C8F91939087
80787066635E4A4A4338382E2C2828231E1E1E191E282328
282828282C2E2E31313531312E2C2828231E191E19191919
191913191919191919131919191919191913131310131010
1310101310101310101010101010131013101013192E3F4A
4D4A474A4447474D4D4A4A4744444347473F3F3F43444443
44434447433F3C433F3F3F3F3C3C3C3C
4A4A4A4A53534F52535358585856585B6266666663626360
5B5E60626266666E6860626260666268636666666663686A
6A6C71746E706C70AE78351E191E1E191E1E1E2C314F859B
CBDCD8CFD1D1CECACAC8C4C5C4BBB0AAA39B948A817B7876
6C6663625E5B5B5B5E6263686E717C808587908A91918F86
8376706866605652473838312E2E2C28281E231E1E191E1E
1E1E23281E23282823282E2C2C28231E1E19191919191919
191313191919191919191919191319131913191313131013
101010101010131013101313131010131313131313192844
4D4A474F444A474A52474A474443443F3F433F3F3C433F43
44444747433F3F433F3F3C3C3F3F3F3F
4D4D4D4D53564F5356535856535653525B63686360606058
58585E605E60636666636260626266636262626263636A6A
6E6E6E70706C6868A280381919191E19191E1E2C2E4D7B91
C1DAD8D1CAC8C6C5C5C4C1BEB8B6AD9E998C837E716A6660
5E5B5E5858565658586363686C76818687908C91918F8C89
8578746866625B564A433F3C35312E2E2E2C23232323231E
1919191919191E19191E1E1E1E1E19191919191919191919
191919191919191919191919191919191913131010101013
131010101310131310101313101010131310101013101923
43443C4A4A47474D4D4A4447444443443F3F3C3F3F3F433F
434A4A3C4444383C3C3C3F3F3F3F3F3F
4D4D4D4D52534F524F56535353535352565B5E5B605E5E5E
5B565860605B62626360626060636A625E5E605E63606363
63686C716A666A6E807B4319191E1919191E232C2E4F7193
B7D3D3CDC6C8C8C6C4BEB7B0ADA99E93858174716C63625E
56585858585E5E5E62686A71747C86868F9494969796908A
8580766A6C68635B4F474343433F3C31312E2E2C2C2C2823
1E1E1E1E1E1E19191E191E1E1919191E1E19191919191919
191919191919191919191919191919191913101310101010
101010101010101010101013101010101010131010131013
1E383C3F4744474A4A47474A4747433C3F3C3C3C3F44433F
44444A473F3F3C3C3C3C3F4443434343
4A4A4A4A52524D4A4D4F524F52524F4A565358585B5E605E
5B565B585E5B5B5E625E5B5B606260635E5E5B5B62606060
60626A71686263686E6A431E191E1919191E1E2C2C4A6A8F
B3C9CFCECBC5C6C6C2B9B1B0A7A0978C857C78706A626363
5E5E62626663686C6C6E747B80868C9094999A919494918A
867E746E716C6662564D4A4444433F3F383C3835312E2E2E
28282323231E1E19191E1923191E1E1E19191E1919191919
1919191919191E1919191919191919191919131010101010
101010131010101010131010101013101313101010101010
131E2C3543444A474D4A444A4747433F3F3F3C3C3F434744
4744474A4443383F3F433F4447474747
4A4A4A4A4F4D4A474D4F524F5252524A4D4D53535862635B
5E5B5B5B5E5E605E5B5B5E5E5E6060605E5B5B5860636362
63666C6C636062686A533C1E1E1E1E191E1E23282C446C89
A7C4CFD7D4D1CFCFCAC6BCBEB9B0A5968A807E7E71717071
6E6C767B767479787B798083898F979A9D9D9D9B9996948F
877E717974706A635B534F524F4A524D4A4A4A3F3F3C3835
2C2C2C28282328232828231E1E1E1E1E1E1E191E1E191919
191919191919191919191919191919191313131013131010
131013131010131013131013101313131010101010101010
1013192838444A4D4A4A47444A4A44443F3F3F3F3F43443F
44444A3F3F3C3C3C433F44433F3F3F3F
4D4D4D4D4F4A4A474A4A52564F4D4A4D474A4F525B5B5E62
605E5B5B5B5B605E605E5B5B5E5E605E5B585B5B605E5E62
636A71746E6660625E52431E23232319191E232C2E3F687E
9DBFCEDADEDCDFDBD8DAD1CFCBC4B7A59B9191908C898A87
8786898C89868686878A8F9497999DA0A1A0A19E9B969790
8A85797B796E6E6C625B5B53565656565856534D4D4A3F3C
38312E2C2C282828232823282323231E1E191E1E1E1E1E19
191919191919191919191919191919191313101313131013
101010101010101010101013101013101010101010131310
101010192843474A4A4A47444A4A47434343433C44474443
4344443F3F3C3F3C3F473F443C3C3C3C
4A4A4A4A4A4A4744474A4F524F4D4A4F4D4D5252535B5E5E
5B5E5B5B585E5E62625B5B5B5B5B5B62605E60605E606062
626863686A6E6E686052432C2828231E1E1E232E2E3F626E
94B9CAD8E0E0E2E4E4E5E0DAD3CABFB6B4A7A5A1A5A3A2A2
9D9D9D9D9496919090979799999EA2A2A2A29E9B9A96968F
8C86807C7974716C68605B585B56605E5B585B56564D473F
3C3C35312E2E2C2C282828282328231E231E1E191E1E1919
1E1919191919191919191919131913131310131310101010
101010101010101010101310101010101310101010101010
101010131938444A47474A474A444A4444443F3843474343
3F3C383C3C3C3C3F43443F3C3F3F3F3F
4A4A4A4A4A4A444A44474A4D4D4D4D4D4D4F535352585E5E
5E5E585E5B5E5E6362625856565E5E5B585E5E5B625E5E5E
626663686C6668766A534A312C2E231E1E1E282E2E3C5866
89B6C8D3DEDFE2E5EAEAE2D8D1C9C4C2C2B9B6B4B3B3B3B1
B0ACAAA5A19A9A9A949B9D9EA1A1A7A7A1A1A09D96939391
8C897E7C7E7971706860605E5B5E5E5E5E60605858524A44
3F3C3835312E312C2E2E282828232323231E1E1E19191919
191919191919191919191913191313101310131313101010
101010101010101010101010101010101010101013131010
10101010102C3F47474D4D47474A4A474D443F3F47434447
3F3C3C383C383C3F44383C433F3F3F3F
434343434D4A4A4A4A4A4D4F4D4F4D4D4D5252535356585B
5B5856585B5860606360585E58565B5658585E585E5E6060
6062636C6A6C666A705E4F3C313C2C231E232C35313C5362
81ADC2D3DEDFE2E7E7E7DED5D1CBCACBCAC4C1BFBBBBBFBB
B8B9B4ACA5A09E9D9E9EA3A3A1A2A3A5A7A2A29D99949394
91867C78787676706A6663625E585E606060605858534F4A
433F3835312E2E2E2C2E282C2823282323231E1E19191919
191919191919191919191919131013101010101010101010
101010131010101010101010101310101010101010101310
10101010101E384A4A474A4A474D4D4A4747434347474444
433F3C3F3F3F3F443F38383C3C3C3C3C
474747474A4D4A4D4D4D524A4D4F4A4D4F5353535352565B
5B585B5B5E5B60605E5E5B5658535853585B5B5E62635E5B
5860686C706E6C68686253473F472E2C28282E35313C4A58
7EACBED3DFE0E2E4E5E4E0DED8D5D1D3CFCBCAC8C6C4C2C1
BEB7B4AEA5A3A2A0A0A2A3A5A3A3A3A7A5A3A29E9D969493
938A7E7E7C7674706A686663635B6060605E5B585B52524D
443F3C38312E2E2E282E282C2823282323191E1E19191919
191919191919191919191919131313131310131010101313
101310101010101010101010131010101010131010101310
1310101010192C474A4744444747444A4A44444343474444
443C3C433C4344443F3C3C3C3C3C3C3C
474747474A4D4A4D4A4A4F524D4D4F4F4F53535353525858
5B585B585E5B6060625E585656585B56585E5B6063606060
5E6362687471706A6C665E564F4D352E2C2C3C3835384753
79A7BBD1DCDFE0DFE2E4E2DEDEDBDADAD5D1CACBCAC4C4C2
BCBBB4B1ACA7A7A2A2A3A5A7A5A5A5AAA3A2A3A29D9B9693
918C807C7B7470706E686662626360605E5E565658564D4F
443F3835312E2C2E2C2E2C28282323231E1E1E1919191919
191919191919191919191913131010101010101010131010
101010101010101010101010101013101310101013101013
131013101019233F4A47474443444343474747444A4A4A4A
443F3F433C3F47433F3F3C3F3C3C3C3C
4A4A4A4A474A4A4A4A4A4D4D4A4D4D4D4D4D4F535356565E
5B5B5B5B5E565E5B5E5E5858535B605B5E5E5E6666666363
6266666C747171706E6C68635B523C353538443C2E2E4353
80A7BBD1DCDEE0DFE0E2E2DFDFDCDAD8D4D1CBC9C8C6C5C4
BCB8B7B4AEACAAA3A5A5A5A9A7A7A7A7A5A2A3A1A0999493
918C85817E76746E706A66636260605E5E5B565852524A44
443F3835312E2E2E2E2C2828232323231E1E191E1E191919
191919191919191319191910131313101010101013101010
101010101010101010101010101310131310101310101013
1310101010191E3544474A443C3F444443474343444A4A4A
434343433F4344433C3C3C4344444444
44444444434444444A4A4D4D4A4A4A474A534F5353535658
5E5B5E5E5B585E5E5E625E5B585E60626260626066686363
626A6666706C6A6E706E6C6A635B4A3F434A523C2E2C4358
81A2B6D4DADFDFDCDFE2DFDFDFDBDAD7D1D1CFCBC9C8C5C6
C1BFB8B4B1AEACA9A9A7A5A7A3A7A9A7A3A2A19EA09D9996
938C87817E797474706C68666360605E5B585656564F4A47
433F383831312C2E2C2C28232323191E1E1E1E1919191919
191919191919191913191913131310101010101010101010
101010101010101010101010131310131310101310131310
101010101013192E3C4747433C433F4347443F3C4747474D
444A4A433F3F3F433F383C4343434343
4444444444434A444A474D4D4D4A4D4A4A525252534F535E
5E5B605E5653565B5E60585B5B5E62626662606063686263
63686A6E6E706E6C706E746E70665B5353524F382C2C445E
80A2B6CFDADEDFDFDEDFDEDEDFDCDAD8CFCECBC9CAC5C6C6
C5C1BBB8B3B0B0A7A5A7A5A5A5A3A7A3A5A2A09D9B9D9D99
948C89817C797876706C6C6A666260605B58585656524D4A
443F383131312E2C2C2C2828231E231E231E191919191919
191919191919191919191319191313131310101010131010
101010131013101010101010101310101310101013131310
13101010131319233147433C3F3F444444433C38434A4747
4A474A433C3F433C3C3C3C383C3C3C3C
434343433F434744474A4F4D4A4A4A4A4A4F525352534F53
535B565B535353525356585658606268686362635E626663
63666A71716E706E716E706E7470666658524A312C314F63
86A3B7D1D8DFDCDFDEDEDFDBDCD8D1D3CDCDCACBC9C5C6C6
C6C2BBB9B4B3AEA7A5A3A7A5A7A19EA1A1A2A09B9B9B9996
9489868181797671716C6C66685E5E5E605B585656534D4A
443F3535312E2E2E2C2C2828281E1E23231E1E1919191919
191919191919191319191913131313101310131310101010
101010101010101013101310101310101010131010101010
10101313131319232E3F443F3F434347433F3C3843474A47
443F443C3C3C3C3C38383C383C3C3C3C
43434343433F43444A4A524F4A4D4A474A4F4D5253534F4D
56585656534F4D4F5356524F536060636866626262636363
6666626C7070686E74686C767471706E564D442C2C3F5B74
8CA9B8CFD4DCDEDEDADEDED8DAD7D4D4D1CDCBC9CAC5C9C6
C4C1BBB8B6B1B1A9A7A5A3A5A1A19E9DA09D9B999A999793
908C86807E797474786E6C6A6A60605E60585B5853524D4D
43433F3831312E2E2C2E282828231E1E1E191E1919191919
191919191919131319131913131010101010101010101010
101310101010101013131010101010101010101010101010
101310131013191E2C383C3C3C3F3F3F3C3F38383F434447
3C3F3C38383838383C383C383C3C3C3C
474747473F433F474A4A4D4F4A4A4A474A4A4F4F4F4F4A4A
5356565352524D4A4F4F4D4F585E606266625E5E60686662
605E5E63686E636668665B717474716E4F473F2E2E476A7E
94AEBED1DADCDCDEDCDADBDCDED8D7D3D1D1CBCBCAC8C8C6
C4BFB9B7B4B3ADADA9A3A2A5A29EA09D9D9B9B9996979490
8F8C83807C797170716E706E6A665E605E5B585656524D4A
44433F38352E2E2E2E2E2C2C232823232319191919191919
191919191919191319131313131010131310101310101313
101010101013101013101010101010131310131013101313
101010131313191E2C38383C433F3C3F3C3C3C3C43474447
3F3F3C3835383835383C383C38383838
44444444433F434344474A4A474444433F4A4F4A4A4D4A4D
5252525252524F4D4F4F4D4F535863626662625E5E625E56
585E5E5E666366636260566C686E6C62443F3C2E2E4F7686
9EB6C2D1D8DADCDCDCDCDEDCDADAD7D1D1CFCECACBC8C5C4
C5C4BBB8B6B3AEADA5A1A1A19E9E9D9B979797999696908C
8986837C7E7874717470706E6866625B5B5E585656534F4A
473F3F3C38312E2E2E2E2E2C28232323231E1E1919191919
191919191919191919131313131313101010101310131010
101010101010131010101010131310131310101010131010
131013101013191E283138383F3F3C3C3C3C3C43444A473F
3C353835383531383538383C3C3C3C3C
434343433F3F433F444343443C3F443F3F4A4A4D4A4A4A4D
4D4D4D4F4F4D4D4A4D4D4D4F4F566062626362605E605E58
5353585E6262626C604F476068706A523838433535588093
A9BBC6D4D8DADBDADCDBDBDBDBD8D8D4D1D1CECBCBC8C5C5
BFBEBBB8B6B3B0ACA9A19E9E9D9D9A979396969796948C89
8985817E7B79767071706E6C6868685E5E585B565656524D
4A43433F353531312E2E2E2E28282823232319191919191E
191919191919191913131313101010101010101010101010
101010101010101010101010101010101010101010101010
1310101010131E1E282C38383C3C3C383C3F3F434A47443F
3838353535312E2E3535383C3C3C3C3C
3F3F3F3F3C3F433F3F3F3F4743383F3F4347474A4A474A4D
4D4F4A4D4D4A4D4D4D4D4F5253605B63666263625E5B6058
56535B5B6263636666433C585E665B473138443F476A899E
AEC4CBD4DBDBDBDBDBDADBDCDEDBD7D3D3CFCFCECBC6C6C5
C4C2BEB9B8B4B1ACA7A29EA09B9D97999994949491908F8A
8686837C7C797474746E6E686A6A6660605B585B5653524F
4A44433F3F3C352E31312E2E2E2C2823231E1E1919191919
191919191919191919191913191313101310101013131310
101010101013101010131313101013131313101010101010
1010101013131E1E2C2C383F3F3F3F3C3F3F434447433F3C
3838383838353531383838383C3C3C3C
3C3C3C3C3C3F433C3C3C3C433C3C383F4347474A4A4A4A4F
4D4D474A4A4A4A4F4D4F4F525258625E60636260605E5E5B
565858566062635E5B3C3C4D56584F3C3138474F587993A7
B7C8CED8DCDBDBDCDADBDADCDEDBD8D7D3CED1CECBC8C6C5
C5C5BCBCB7B6B1AAA7A5A3A39E9A97969793919191938F87
8587817B79797674706E6C6C66666663605B56565658524F
4D4343433F38383C2E2E312E2C2C2828231E1E1919191919
191919191319191919131313131013101013101010131010
101010101313101010101010101010101310101013101310
1010101310131E1E232C313F4743434344434343473F3F38
383838383C3C35353535383C3C3C3C3C
3C3C3C3C433F3C383C3C383C3C3C38383C474A4D4F4D4A52
4D4F47474A474A4A4D4F534F5656586262606262625E5E58
585858565E625E5E443538444D4F44382C384F636A839BA7
BBCBCEDADBDCDCDCDFDBD8DBDCDBDBD7CFD1CFCFCBCAC8C6
C6C4BEBBB8B6B3B0A9A7A2A3A09B97969396969190918F8A
86867E7B79767674706E6C6A686366605B5B56585653524F
4A47433F3C3835352E2E2E2E2E282823281E1E1919191919
191919191919191919131313101013101013131010101010
101010101010131010101310101013131010101313101010
101310101013191E1E2C313C444D4A4A4444474443443C38
3838383F3C3838353F3C383F3C3C3C3C
3F3F3F3F3F3C38383C383F433F3F3C3F43444A474F525253
4D4F52474A4A4D4A4D4F524D4F56535B5B5E5E6060606058
5656535862686262382E353C4D4A3F383838526A7B90A0AA
BFCBD1DADEDEDCDADADADAD8DEDAD5D4D1D1CECECBCBCBC8
C8C4BCBBB6B6B4AEA9A9A1A29E9D9B9794969493918F8C8C
8781807B7976706E706C6A66686363635E5B585656585652
4A4A433F3F38383531312E2E2E2C2C282823231E19191919
191919191919191919191313131313101310131010131010
101013101013131013101010101010101310101013101010
1310131313191E1E28282E3F4D4D4D4A4A4A4744433F3C43
3838383F38383535433F3C3C38383838
3C3C3C3C3F3C3F3C383C3C473F3F3C3F3C474A4A4A4F4D4D
4D4D4D4D4A4D4A4A4D4F4D4D525253565256585B5B585858
565656586063665E2E2C2E384A4D3F35474453708094A7B1
BFCBCFD7DBDBDFDCDCDCDBD8DBDBDAD7D5D5D1CED1C9CAC8
C9C4BFBCB9B8B4B3B0A3A09D9E9E9D9A9694909491908A89
87817E7C747870716E6A6C686A6362625B5E585E5B5B5352
4D47433F3C3C38312E2E2E2E2E2E2C2C2828281E1E191919
191919191919191919191913131310101313131010131310
131010101013101013101010101310131310101313101013
1010101313191E1E231E2C3C4F4A4A4A47444A4A47433F3C
38383838383C38383F433C3F3F3F3F3F
3F3F3F3F3C3C383C3C433F47434343433F3F474A4A4A4A4F
4D4D4D4F4D474A4A4A4D4D4A4D4D53535352565B585B5856
535656565B6262562C2328314A4D43384D5660718399A9B3
BCCDCEDADFDCE0DFDFDFDBDCDEDCDEDBDAD7D7D4D1CECECA
C8C5C1BCBCB8B4B3B0A9A3A29E9D9B9996969394918F8A8C
89818079797670716C6C6C6C666362605E5B5B5658535352
4A443F3F3C313831312E2E2E2C2E2C2828281E1923191919
191919191919191919191919101313101013131010131310
101010131310101013101010101310131310101010131010
10131310131919192323233C4D4A4A4A4747474443443C3C
3538383C353C38383C3C3C3C3F3F3F3F
3F3F3F3F3F43383F3C3F474A44433F433C3C434747444A4A
4A4D4D4D4A47444A4A4D4A4D4A4F5252524D525352535356
525253585E5E60522C1E1E2C444D3F38526C71717E96A3B0
BCCBCFDADEDBDEDFE0E0DCDCDFE0DFDBDAD3D5D4D1CECECD
C9CAC4BEBBB9B9B0AEAAA3A19E9D9D9999979A97938F8C8C
87838079787871746E6A66686866625E5B5E5E5858565356
4A47433F383535312E2E2C2C282C2E28282823231E1E1919
191919191919191913131310131313131313101313131010
131010131313101013101010101013131010131013131010
1313101313191919231E233F474744433C4444434343433C
3838353C38383838383C383838383838
38383838383C3C38383F44434443473F383C3F3F43474747
4A4A4A4A4D47474A4D4D4D4D4F4F5253524D4F4D524D5653
5653565B5E605B3F23191928444F473C4F767B797E90A1AA
B8C8CED5DADEDFDEDFDFDFDEE0E2DFDCDAD3D5D3D1CFD1CD
C9C8C4C1B8B9B7B0B1AAA3A3A09E9E9D9A9A99979390918C
8983807B7978746E6E6C6A686A636360585B5B5858585656
4D4743433C38352E312E2E2828282C2823232319191E1919
191919191319191919131313101010131310131010101313
101010101313101310101013101013101313101010131310
10101310131E1E1E2323233C43433C383C3F433F3F3F3C3C
3838383C383C383C3C383C3831313131
38383838383C38383C3C3F444A3F433C433C3F3F47474A4A
4A4D4A4A474747474A4A4D4D4F525353534D4D4D4F525353
565258605E584F2E1E13191E44534D475371797B818A9BA5
B9C8D1D7D8DADFDFDFE0DFE0E2E2E0DCDBDAD7D1D1CFCDCA
CBCAC6BFB9B7B8B6B1ADA3A2A29EA0A19B9B9B9494979089
8685807978767474716C6868686668625B585E5B58535352
4D4A443F3835312E2E2C2828282828282823231E1E1E1919
191919191919191913131313101313101313131310131010
131010101010101010131013101010131310101013131313
10101310131919281E1E233C3C3F3C383C3C4444443F3F3C
3838383F383C3838383C383135353535
3838383838383538383C3F4444433F3C433C3C3F44444343
47444447433F4747444D4D4A4D525356534D4F4F4D4F5853
56535B605B533C2C1E19191E314D4A4F5370747B838997A5
B8C9CBCFDADADEDFE0DFE2E2E0E2E2DEDEDADAD8D4D1D1CE
CDCBCAC2BCB9B9B4AEADA7A2A1A09D9DA09D9A9797908C8A
86857E7C7C7876746E6C6A6868686663635B5E5E58535653
4A4A44433F35312E2E2C23282823232328231E1E1E191919
191919191919191913131010101310101013131013101010
131010101010101010101010101010131310131010131310
10101010131919231E1E2C3F3C3C3C3C3C3C3F443C3F383F
3838383C383838353C3C353835353535
3838383838383C38383838433F3F3F383C3C3C433F434343
474444474A43444A4D4A4D4A4F525353534F524D53565E56
5853565B564A2C231E1319192C3F475256687179868C94A9
B9C4CBCFD4DBDEDEE0E2E2E2DFDFDFDFDFDFDEDAD8D5D4D3
CFCDCAC6C1BCB9B6B4AEACA7A3A3A09D9DA09B999A96908A
89838079787976716E6C6A6A6A666663625E5E5E5B565653
4A474A3F3C38312E2C28232823231E2323281E1E1E191919
191919191919191913131010101010101013131010101310
131010101010101010101310101310101313131313101313
1010131313191E23231E2E383C3F3C3C384343433C3C3C3C
3C38383C383535353C38353135353535
3838383835383838383538383C3F3C3F3C383C433F3C3C47
4447444A4A43474D4D524F4D4D535653534D4A4F53565B5E
585356565844281E19191319232E3F4F60606C71819394A0
B8C6CBD1D1D7DBDEE5E6E0E0E2DCE2DCDEDCDCDAD8D8D8D3
D1D1C9CAC1BEB8B7B1B0ACAAA3A2A1A09D9D9A999793908A
8985817978747170706A6E686A6A66626260625B5B5B5B52
4F4747433F35352E282828281E1E1923231E1E2319191919
191919191919131313131010101313131313101013131313
131313131013101310101310101310101313131313131313
1313131313191E23231E35383C3F3C3F3F3F3F3C38383C38
3C3838353535352E3538353131313131
31313131383838353535353C3C3F3F433C383C3C433C4743
4A4A474447474A4A4D4D4F5352525656524F536062626360
5B58535658382319191313191E232E44625E606A7690969B
AEBFCACFCFD1DADEE2E2E2E0E0DFDFDBDCDBDEDBD5D7D8D7
D1CDC9C5C2BEB8B6B3ADACAEA3A3A3A09D9B9A9A97969090
8A86817674767071716C6A686C6C68636362605B585B5653
4A4A47434335352E2C28232323191E19191E1E1E19191919
191919191913131313101310101313101313131010101013
131310101010101010131010101010101310131313131310
1013131313191E1E23232E383C4444433F43433C3C383F38
38353535353535313131353535353535
31313131353835383838383F3F3F3F3F3C383C3C3C43434A
4A4A4A44444744474A4A4F4F4D5352565353525856585E5E
5E5E5652522C19191E1313191E19233153535663708C9397
A5B6C2CACACDD5DADEDEE0E2DFDEDEDCDEDCDEDED8D8D8D5
D1CFC9C9C5BCB8B4B1B1ADAAA7A3A1A09D9E9B9A9999918F
89867E7E79787171706A6A6A6C6C6C6A60625E605B585656
524D4744433835312C2C2C281E1E1E1E1E231E1E1E191919
191919191919131313101313131313131313131010101313
131010131310131013101010101010131310101013131313
1010131313191E1E192C313C3F433F3F434443433F383C38
383838353835352E3131353538383838
313131313535383838383F433C3F3F3C38383C3F3C434444
4A4A47444343433F474D4D4A4A4F4D53524F534F53535653
53585E5B471E1919191313191919191E353C4F5E637E8A91
9BAEB4C6C8CDCED5DBDEE0DEDCDCDBDCDCDEDEDFDCDADAD7
D4CDCAC8C4BBB7B4B1AEADA9A9A3A0A19E9A9A9B9996938F
898581807C767171706E6C666A6A6A686663625E585E5B56
524F4A4A3F3C352E2E2C28231E191E1E1E1E191919191919
191919131313131913101013101313101013101013101313
131310101010101010101010101010131013131313101313
131313131919191E192C2E383C3F4443474444433C3C3F3C
3C3838353535312E3138353835353535
353535353535383838383F433F3F3F3F3838383C38383C44
4A4A474343443F44444A4A4F4F4D4D52525352524F525353
56525B5B3C191E1E191313131919191923283C585E708689
97A1ADC2C5CACBD1D4DBDCDCDEDCDCDCE2DFE0DFDEDCDCD7
D4D1C9C6C1BEB7B3B0B0ACA9A7A59E9D9D9D9B9B9994938C
8985817E807676716E706A686A6A6A66666662625B565B56
564A4A44433C352E2E2C2828191E23191E19191919191919
191919191319131013101013131313131010101013131310
131010101310101010101013101010101010101013131310
10101313191E1E1E1E2E2E3C383F3F4443433F43433F443F
3C3C3C383535312E312E383835353535
313131313535383138383F3C3F3C383538383C383838383C
444A473F3F3F4343474A4A4D4F4F52535352525253525253
5252565338191E19191919191919131919192C47585E767E
859BA1B8C4C8C9CECED4DADBDEDCDCDEDEDFDEE0DEE0DED8
D4D1CDC8C5BFB9B4B3B1B3AEA9A2A39E9E9E9E9B9791938C
8C857E807B76716E6E6E6863686868636A63635B5B565853
564F4D4A433C38352E2E28281E19191E1E19191919191919
191913131313101010101010131013131010101010101010
101010101013101013101010101010101010101013131010
10131319191E1E1E282C2E383C3F3F433F3C3F3F44474344
443C3C38383535313838353C38383838
31313131313538353838383C3C3C3838383538383C3C3C38
434343443F4344444A4D4A4A4F4F4A4F53534F4A4F4F5253
4F56524F2C19231E1E1919191919191919191E3544475E6A
718F9AADBEC1C5CACECED3DADBDEDEE0DEE2E2E2E0E0DED8
D5D1CAC6C1C2BCB7B3B4B1B1ACA5A5A29E9BA09B9393908F
8A857E7C7C7674716E6C6A666A66666866636362605B5352
524A4744433C35352E2E2C281E1E1E191E19191919191919
191919131313131010101013131013191313101010101013
101310101010101010101013101013101010101313131013
13101919191E1E23312E2E3C3C3C3C3C3C383C3F3F3F433F
383F3C383831352E3835353138383838
2E2E2E2E313138353538383C3C3C3C3535383C3C3F3C383F
3F433C3C3C3F3F44474A4447474A4D4A524F4D4F4F4F4F56
5253535228192323231E191E1919191919191923313C4352
638094AAB8BCC2C8CBCED1D7DBDBDCDFE0E2E2E2E2E2DED8
D8D3C9C6C1BEBBB7B6B6ADB0ADA9A2A3A0A09D9A97969490
8F8681807C79707171716C6A6666686863666360625E5656
524D4D44433538312E312C28231E19191919191919191919
191919131313131310131013101019101313131313101010
101010101010101310101010101013131313101010131010
1310191919191E2C382E2E3C4344433C383C3C3F3C3F383C
3C3C3C38353531313531353831313131
2E2E2E2E3535353835353838383C3C3838383C3C3F3C383F
3F3C3F3C3C3F43444A4D474A474A4D4D4F4D4F4D4D474D52
52524F4F2319232C281E1E191E1E1E1E1919191E2831313C
567187A3B1C4BFC5C8CDD4DAD8DBDBDEDFDFDFE0DFDEDCD8
D4CFC8C6C2BFB8B8B4B3AEADAAA9A3A3A19E9E9993979791
8C87837E7C76707170706E6A6A66626668636362625E5858
534F44433F383831352E2828231E19191919191913191919
191313131010131313101313131319131313131313131013
131313131010101013131010131013101310101313131310
13131319191E232E382E353C3F3C3C3C3C3F383C383C3838
383C3838383135312E31353838383838
2E2E2E2E383538353C353C3F3F3F3C3C35353C433F3C383C
3C3C3F3F38383C44444A474444444A4D4F4A4A4A4A4A4D52
4D524D4F2319232C28231E1E232828231E1E1919232C3131
44667C9DACC1BFC2BFC8CED3D5D7DADADCDCDEDEDCD8D7D3
CFCBC9C4BFBCBBB7B6B3AEB1ACA7A7A1A2A09A9A9994938C
8A85807C7C74716E6E716A6C66636362666262625B5E5653
534A4A433F3835312E2E28231E1919191919191913191919
131913131010101013101310131013101010101010101013
131010101010101010101010101010101310101010191010
13131919191E2831382C31383C3C383F38433C3838383838
38383835312E2E2E312E313538383838
31313131313538383C3838433C3F3C3C38383C3F3F3F3C3C
3C3F3F3F433F3F44434447474A444D4F4F4D4D47474A4A4D
4D4F4F562319232C282C23282E2E2C2C23231E1E1E2C2E31
43607094A3BBC5C4C2C8CACDCECFD5D7D4DAD8DBDBDAD8D4
D1CEC6C2BBBBB7B8B8B1B0ADA9A7A7A2A1A09E9D9A94948F
8A837B797976707070706C6A6363636260625E625B5B5B56
4F4A443F3831312E2828231E191919191913191910191313
131913131310131013101013101013101010131013101010
101010101010101013101010101010131310101313131313
131319191E282E38382E38353C3C3C3F433F3C3F38383835
313835312E2E2E2E2E2C2E3138383838
313131313135383838383C3F43433C383C383C3F3F3C3C3C
3C433F433F3C433F47444A474A4A4A4D4D4D4F4A44474A4D
4F4D525623191E2C282E2E2E31352E2E28231E1E23232C2E
4453688A9BB1B9C1C6C6C9CACACECFD1D1D7D4D5D5D3D4CE
CDCBC2C1BBB8B7B7B3B1AEA9A7A9A5A3A3A1A0A09A97938F
8F837B797B767070706E6A6A6360665E62605E585B5B5653
4F4D443F312E2E2C231E1E19191919191913191310131319
191913131313131013131013101310101013101313101310
101010131010101010101313101013101010131013131313
131319191E232E3838353F3C3C3C3C3C3C433F3838383838
31313135312E2E2E2C2C2E3538383838
313131313135383838383F3F3F3F433F38383F3F433F383C
3C434347443F3C434A47474A474D4D4D4D4D4A4747444A4D
4F4F4F56231919282E3C3C313538312E2828231E191E2C31
4758638196A7B1BCC5C5C6C9C9C9CACFD1D1D4D4D4D3CFCD
C9C9C2BFBBB8B7B6B3B4B0AAACAAA3A3A1A0A09B9A99968F
89837E78787171706E6C6C6C62666260625B5B5656565253
4D47433F352C231E1E191E19191919131013131313131319
191313131010101013101013101013131310101313101010
101010101010101013101010101310131010131313131313
19131919232C35433C4752433838383838383C3C38353838
35313535352E2E312C2C2E3135353535
2E2E2E2E3135313535383C3C43433C3C3C383F3F43383C3C
3C3F3F3C433F3C3F444A474A4A4A524D4D4D4747444A4A4A
4F52535E2C1919232C3C4F47474A3F382E2C231E191E282E
475E6678879DA1B3C1C6C9C9CAC8CACDD1CECFD4D4D1CECA
C9C6C4BFBCB9B7B4B3AEACACA9A7A3A19DA19E9A9A99948F
87807C7971746E6E6E6C6A6A6366605B5E5B58565652534F
47473F3C2E231E1E19191919191919191310131010131013
131010101010101010101010101310101010101310101310
101010101010101010101010131010101310101013131313
1319191928353C433C4344433C3838353538383C38383531
31313838313531352E2E2E3131313131
313131313131353835383C3C4443443F383C353C3F383C3C
3F43473F43443F3F4344444A4A4A4D4D4F524A47474A474A
4D536C6231191E232C354347433F3C3C43382C281E19232E
475B666E79919BAAB9C5C5C8C8C9C5CACBCDCFD1D1CECDC9
C4C5C1BEBBB8B8B4B0ADACAAA5A5A29E9EA09D9B9793948A
89837B7679746E706C6C6A6863625E5B58565653524F4D47
43433C352E231E1E19191919131919191310101310131313
131310101010101013131313101010101310101313131310
101310101010101010101010131313101E19131010131013
19191E232C383C3C383F3F3C383538313138383838353838
31353138353538353531313131313131
31313131353535383C383C3C3F4444433C3C3C3F43383C3F
3F434447473F3C3F3F4447474A4A4D4F4D4F4A4A4743434D
566C584F311919282835313C3831232C4D4F352C281E1E2C
476066666E8396A5B4BCC2C8C8C4C4C6CDCACFCECECDCDC8
C6C4C4C1B8B7B6B1B0ADAAA9A5A39E9E9D9A99969491908A
87807B787974716E6C6C6A6362585852524F4A4D4D4D4444
3F3F312E2C231E1919191319131319131910101313131313
131310131310101010101313101010131313131013101310
131010101313101310131010131313131013131313131919
19191E232C383C38383F3F3C38383538353C38383C3C3C38
353835383835383831312E2E31313131
3535353535353F383838383C3F4443433F38383C443F443F
433F43444444433C434344444A4A4A4D4D4F4F4A47474756
52534A4D3F1919282C35313831281E193C533F352C1E191E
4362666060798AA2ADB4B9C2C4C1BFBFC4C8CBCACBC8C8C8
C6C4BBB9B7B1B0A9ACA7A3A1A29A9190908C8C89878A8986
867B797878746E6C6A6A60605B4D4A443F3F3F3F3F3F433F
38352E2C2C1E191919131913131313131313131310131310
131013101010131013101013101013131010101313101013
101013101010101010101310131313131013131013131319
191923232E383835383C3C3C3C3835383838383838383835
35313131353535353835313135353535
3131313131383838383C3C3C3C44433F3C35383C433F4443
3F4343444344443F44444343474447474A4F4D4D4A474743
4A4A4A4D4D1919232E38382E2E281919283C3C38352C1E19
2E5E6358566C7E9BACB1B6B4B7B6B4B6B7BEC4C5C4C1C4C1
C4C1B7B3B1AAA3A09A9997948F877C766E74747174787B78
78767070706C6A6362605B5652443F31353535353831352E
312E2C23231E1E1319191313191919131310131313131313
131310131310131313131013101310131313131010101010
131010131010131010131313101313131310131013131919
191E232C353C43313C3F3C38383C3838383C313538383838
31312E31383838383835313138383838
2E2E2E2E3538383C38383F383F4444433C3C3C3F3C3C3F3C
3F3F433F3F4447433F3F3F3C3F3F43474D4D4D4F524A4347
4A4A4D4D521E191E2E38382C282C1E1919232C2E3831281E
23525B525358708FA0A9ADB0AAA9A09BA1A7B1B4B7B4B6B6
B6B7AAA3A39D968F86807E7970685B4F4744444A4F535B5B
60606063625E5B58534F4F474438312E2C282C2C2E2E282C
282823231E1E1E1913131313131919131313131313101013
101013131313131013101010101313101313131310101013
101010101010101013101313101313131313131313191919
191E2C313C3C3C38383838383838383838383535383C3535
31313535383835383838383531313131
2E2E2E2E3535383C3835383F4343433F3F3C383C3C3F3F3C
3C3F3C3F3C3F3F3F3F3C3F3F3F3F43434D4F4D534D534A4A
4A5252524F23191928383828232C1E1319191E23282C2C28
1E3C584D4F5360798F9BA3A7A39D9189898C93949DA0A1A2
A3A1969191877C716E625B58474335312C2C2C2E312E3131
353C3C3F43433F3F383835312C2C2C231E231E232823231E
1E1E1E191919191919131313131313131313131013101013
101313131310101010101313101013101313101310101310
101010101010131310101013131313131013131013191919
192331383C3C383538383538383835353135353535353538
31312E31353135383538353138383838
2E2E2E2E2E353838383C3C3C383F3C3C3C38383C3C3C383F
3C383C3C383C3F3C383F3F3F434343444A4A4D524A4D524D
524F4A52533819191E3531231E231E19191919191E2C2E2C
1E2E433F43474D637B879796968C7E716A686C6E767B7C81
817E7C7974685E524D3F3C353128232323231E19191E1E1E
1E282328282C2828282828231E1919191E191919191E1E19
1E1919191919191913131310131313131313101310131010
101313131310101013101313101013101010101313101013
13101010131013131013131313131313131319191319191E
2328383F3F3C38383538383838383535353535353C353838
2E313138383538353535313131313131
2E2E2E2E2E3138313535383C3C3F3F383835353535383C35
3C38383C3838383C3F3C3C3F433F43474A4A4D4D4A4D524D
535656585856231E232E3123231E23191919191919232C31
23232E2E313C3F4F637480817C7868534D433F434A4D5256
5E5B58534F4D43352E2C2828231E191E1E1E191919191919
1919191919191E1E1E1E1E19191919191E19191919191919
191919191919191913191313191313101310101310101310
131310131313131010101313131313131313101313101313
131010101313101313131313131313131313191919191E23
2C313C474338353835353838383538383538353835383C38
35313135353535353135353538383838
2C2C2C2C2E2E3131313131383838383535312E3135383838
353838383C38383838383C3F3F44433F4A474D4A4A4F4F56
585E5B5352532C1E233138281923231E1919191E19192328
28191E28282E353C44525E5E5B584D35312E2C2C2E312E35
3C3C3C3F35312E28231E1E1E1919191E1919191919191919
191913191319191919191919191913131319131319131913
191919191919191013131313131313131013101313101310
101310101310101313101010101013101310101010101010
101310101013131013101013131010101313191919192328
2E3844473C35313131383138383835383835313535383C38
312E313135352E312E31353138383838
2C2C2C2C2C2C2E2C2E2E2E3535383535312E2E3135353838
35383C3838383C35383C383C3C3F3F3C47474A474A535B62
666260524F53311E1E35382C1E23232319231E231E191919
1E1E19191E232C2E3538383838352C23232823232828282C
2C2C2C2C2828281E1E191919191919191E19191919131313
191913131313191919131913131313101313131313131319
191319191913131313131313131313131010101310101010
101010131010131313131010131313101013131310131010
1013101013101013101310131913131319131919191E2328
2C3C434A3C31312E31313138353838383538313131383535
312E312E313531313135313538383838
2E2E2E2E2C2E2E2E2E31312E313535353535353535383835
3135383F3C3C3C383138383C383C383C43474A535B565358
58535353534D3F23192C3F2C1E232C2C1E232C281E191319
19191919191E23282C2C28281E231E191E19191E1E231E1E
2323231E1E1E1E1E1E1E1919191919191E19191313131319
131313131313131313131319131313131313131313131313
131313191913131313131013131313101010101010101010
101010131010101310101013101010101013101010101310
1010131010131010131013101313131319191913191E1E28
31433F3C3838383131313138383538353531353535383138
312E312E2E2E2E313131313135353535
2C2C2C2C2E31312E2E2E2E31313835383531353838353535
3535383C383C3C383838383C3C3F3F3F435258524A4A4F58
56524F62604A472E19283F382C23312C2828352C23191913
1919191919191E28231E1919191E191919191E191E1E231E
191E1E19191919191E191919191913191919191913101319
131913131310131310131313101013131013131013131010
131313131313131313131013131313101010101310101013
131313131310131010101010101310131013101010101310
1310131010131013131313131313131319191919191E232E
3C443F3C3F38353535383838383831353538353535353835
2E2E312E2E2E31313131313131313131
2E2E2E2E2E2E2E312E3131313138383C3531353838353838
3538383838383538353835383C3F3F4452534A474A474A52
56534D5B565B4F3F2C233843382E3538282831312C1E1919
13191E2328231E1E1E1919191919191919191919191E1E19
191919191919191919191919191919191919191313131313
131313131010101013131310131313131313131313131313
131313131313101313101013131313131010131310131313
101010131010131310101013131313101313131010131013
101010101313101313131319131313131919191919232E38
3F43383C3C35383535383135353131353538383131314738
313135312E2E3131312E2E3138383838
2E2E2E2E2E2E2E2C2C2E2E2E313C35383835353535383838
3535383C38353835313835383C3F434F5347474744474A4A
52524F4F4F63564D3C28353F47443C38352E35352C231919
19191E2C2E28231E1E19191919191913191919191919191E
1E1E19131313191919191913191913131313131313131013
101313101013131313131313101313131313131313131013
101313101013131010131010131310101010131013101010
131010101013101310101010101013101010101013131313
131010101010101013101013131313131313191E1E2C3843
47443F3F3C3535383838313131353535313C353535313535
352E2E31312E31352E2E2E2E35353535
2C2C2C2C312E2C2C312E2E2E313535353835313531353838
383C383F3C3538353138383C3F47524D474744444744444A
44534F4A4D56584A4A312E3F3C3F43443F3F38352C231E1E
1E23282C2E2C281E19191919131313191319191319131319
191E19101313101313191313131313131313131313101313
131313101310131013131013101310101310101010131010
131010131010131013131010131310101313131013101310
101310101010101310101013101010131010101010101010
10131013101310131913101013131319191919192835383F
3F3F383C3838383838383535313838353838353535383838
352E312E31312E312E2E2E2E2E2E2E2E
282828282C282C2C2C2C2C2E2C3535353531313138383F38
35383C3C3C3835383838383F3F4A433F43443C3F3F3C3F47
434A564D5656584F5247353C382E384744473F382E281E1E
231E232C2C2E2C23191E1919131913131319191313131319
191919131013101313101913131310131013131313101010
131313131313131013131313101310101013131013131313
101310101010131313101010131313131010131313131313
101010101313131013101010101313101310101313101013
131010131313131313131313131913191919192C31383C43
3C3C3838383838383838383C383835383835353131383C38
383531312E2E2E2E2E312E2E31313131
282828282C28282E2E2E2C2C313135352E35313138383C38
383838383838383838383F44473F3F3C3C3C3F3F3F3C3C3F
3F43535B535658584453533F43312C3C4343383C382E2323
231E23282C28231E1E191913131313131913191313131313
131913131310101010131013101313101010101013131010
101313131310101310131313101313101010101313101010
101313101010101010131010101013101010131310101310
101010131013101010101313131313101010101010101310
131010131013131313101319191919191E1E233138353C43
3C383C38353838353C383C3C3C3835383531383835383C38
35352E312E2C2E2E2C2C2C2C31313131
282828282828282C2E2C2E2E2E31353131353535383C3C38
353838383C383835383C444A43433C3C3C3C3C3C3C383F3F
3F434A53526258564F4F62563C2C2C314744352E352E282C
232328282323231E1E191919131313101319191913131313
131319131310101010101010101010101313101013131013
101313101310101013131313131013101010101013101310
101313101313101013101013101010131013101313131310
101310101010101010101013101313101310131010131313
101310131013191313131319191919191E282E3F443C3C43
3F3F43383835353C3C3C3C3F383835313835353538383838
35312E2E2E2E2E2E2E2C282C2C2C2C2C
282828282C282C2C2C2C2E2E312E31313531383838383538
3C38383C383538383C3C4D443F43433C3F3F38383F3C3843
3F43434A5E6666634A4F5363472E282E433F312C352E2E2C
2C282328231E191919191913191313131313131913131313
131313131310131010131310101010101013131013191313
101313101313101313131013101013131013131313101010
101313101013101010101010131313101313101313131310
101010131013101010101010101313131313101310131310
1313131919191319131313191919191E2C2E3844433F3C3C
3F4444443F3C3F3C433F3F3F383838313131313131383838
38312E31312E2E2E2E2C2E2E2E2E2E2E
282828282C2828282C2C2C2E2E2E31353531383538353838
38353838383C3C3838383F3C3C3C3F3C3C3C38383C3F3C43
3F4744445E797B79564752635E3F2E3147352C2328352E2E
2E282323231E191919191913131310131010131310131313
131310131010101010101010131310101010131013131013
101313101310131010131010101010131313101013101310
101010101013101010101010101013131013131010131310
101313131010101010101010101013101313131010131013
131313191313131313191919191919232E3843473C3C3C43
433F3F38383838353C3C3C35312E2E2E2C312E3131313535
31312E2E2E2E2E2E2C2C2C2E2E2E2E2E
2828282828282828282C2C312E2E31313535353538383838
3C38383C3F3C3C38383C3C3C383C3F3C3F3F3C38383C3844
44474444586E868378534F627666444353442E23282E312E
2E2828232319191913131313101313101010101310101310
131310101313101010131013101013101010101313131010
131310101010101010131010131010131910131313131310
101013101010131010131010101010131010101010131310
101310101310131010101010101313101310101010101013
131019191313131313191919191E2331383F4D3F383F3F4A
47433C3C38383838383835353131312E2E2E2C2E2E353131
2E2E2E2E2C2E2E2C2C2E2C2C2C2C2C2C
2828282823282828282C282C282E2E3531312E3135383835
3538383F38383835383838383838383F433F3F443F3F3C43
474A444A4F586E7C796E6060787B66606252352323282E31
312C2323231E191919101313131310101313131310101013
101010101310101010101010131013101010131010101010
131313101013101010131010101010101310101010131313
131010131010101010131010101310131313101010101010
131313101010101013101010101310101010101010101313
1313101313131313191919191E313538434F4D3838384447
4743433C3C383838383538353131313131313131312E3131
2E31312E2E2C2E2E2E2E2C2E2E2E2E2E
2323232323232C282828282C2C2C2E2E31312E3131383535
3538383C3C383C313838383C3C383C433F474447433C3F43
474A4D474A52566C7E787460707671686C6C4F2C2328282C
2E2E2C231E1E191313131313131310101013131313101010
131010101010101010131013101010101010131310101010
101010101013101310131310101310131310101010101310
101010101010101010101010101010101310101010131010
101010101010101013101010101010101010101313101313
1313131313131319191E1E232E433F3F4752443C43434744
473F3F3C3835353838353831353831313135312E2E2E2E31
35312E2E2E2E2C2E2E2E2E2E2E2E2E2E
282828282328282C2C2C282C282E2E312E31353135383538
38353C383C3C3C3838383C3C3C433C3C434744443F3F3C3F
47474F5B5653565B7B7E7C71666A706A66716344312C2C2C
31312C231E1E191919131310131310131319191919131310
131010101310101010101010101010101010101010101013
131313131310101010131313101010101313101310101010
101313131013101010101010101313131313131013131310
101010101013101310101013131013131310101313131313
191919131319191E1E2C2C2E383C3844524D3F3F444D4747
4A433F3C3838383538383535313535383535352E2E313531
2E31312E2E2C2C2E2E2E2E2C2E2E2E2E
282828282C2C282C2C2E2C2C2E2E312E3531353138353138
383535383C3F3C383C3C3C3C3F473F44444344443F3F3C3F
3F474A5260605658637C868078767674606063584A382C2C
313128231E19191E19191313131013191319191919131310
101010131010101010101310131010131010101310101310
131310191310101310131310101313101313101013101013
131313101310101313101010131013131313131013131313
131310101013131010131013131313131313131313191319
19191913191E191E2C2C31383C3C444F52443F4F4F4F4D44
4444443F443C383538383835352E3538313C3835312E352E
2E2E3131312E2C2E2C2E2E282E2E2E2E
28282828282C2E2C2C2E2E312E2E2E2E3531353538383C31
3531353C3C3C38353C383C3F3F3C3F3F4443443C3C3C3C3C
4344474A5363625B62637686837E797C6E625E564F4D3C31
383528191919191E19191913131310191919191919191913
101013131310101310101010101010101013101010131313
131313131310131310131010101313131013101313101310
101010131313101010101013131010101010131310131010
131013101313131010101010131313101313101913131919
19191919191E1E232E3131353C444D4F4D444D56534A4A47
4743433F3C383C38353531312E31353C383831312E31312E
312E31312E2C2E2E2C2E2C2C2C2C2C2C
28282828282C282E2E2E2E2E312E2C2E3131313135313138
35313538383C3531353838383C383C3C3C3F3C3835353838
3C3F4743474F535E6362687B8C8F86867E71534D4A444F4D
433828191919191919191919131310131319191919191310
101013101010101010101013101010131310131013131313
131310131310101310131310131313131013131013131013
131010101310131310131010131010131313101010131013
131310101013131013101013101313191319131313131919
19191919191E232C2E2E2C31434F524A4F52565656564D47
4A4443433C38383838313131353138383835353535313131
31312E2E2C2C2C2C2C2C2C2C2C2C2C2C
282828282828282C2C2E2C2E2E31312E312E313135353131
353135383831313131353838353C353838383C3531313135
35383C3C4343434A535E627085949993867B4A473F3C3F4D
5343311E1919191E1E191919191313101313191919191313
101013131010101013131313101013131010101010101013
131313101010101013131013131310131010101310131313
131310131013131010131310101010131010101010131310
131310131013131010101013131313131919131913191919
19191319191E2C2C2C2E2E354F565B4F535353524F584D47
44434343433835383531312E35313138353131312E313131
2E312E2E2C2C2C2C28282C2C2C2C2C2C
2323232328282828282C2C2C2E2E2E31312C3131352E3131
313138383831353131353135353535353838353831313535
383838383C3C3C3F474D4A5E71808A9091784F353138383C
474D472819191E1E1919131E191913131013191313131313
131013101010101010131310131010101013131010101310
101010131010101010101010101310131013101313131013
131010101010101010101013131010131010101010101010
131310131013131010101013101010131913191313191919
1319191E2323282C28283F47535E584F565352564F524743
443C3C3F3F3835312E2E2E3531383535312E312E2E2E3131
31312E2C282E2E2C2828282C2C2C2C2C
282828282328282828282C282C2E31312E2C31312E35312E
2E3131353835353131313135353538353538353531353135
3535383C383C3C3F434A44475866818C948662352C2E3835
383F47382319191E191919191E1E19131013131013131313
101310131010101010131010101010101010131010101310
131313101010131010131010101313131310131010131013
131010101013101013131310101010101013101010101313
1313131013101310101013101013131919191319191E191E
19191E2323282828232E58565858585658565653524A4443
3F383C3C3838383531353131383835352E2E2E2C2E313135
312E2E2C2E312E2E2C28282C2C2C2C2C
23232323282828282828282E2E2E2E312E2C2E2E31353131
2E2E31353138312E31313835353535353838353835313138
383C38433C3C3F433F4743434A526380A19B7C523F2C3538
3C353C3C31231E231E191919191919131313131313131313
131313131010101010131013131010131313131310131310
101313101010131313131313101013101010131313131313
131310101313131313131310131313101010101310101013
13131313131313131313101013131313191919191E281919
19191E28282828282E435E685E58585B5858534F5344433F
3F3838353C38353535313131353535312E2E2C2C2E313131
312E2E2E31312E2C2C2C2C2C2C2C2C2C
2323232323282328232823282C2E2E2E2C2C2E2E31313131
2E2E2E35383538353135313C353538353838383835353138
3C3C3F3F3F3F3F3C3F44433F4A4D4F688C9D996E58443838
433C3F353531281E231E1919191919191313131313131313
131310131013101013131010131310131013131313131313
131013101010101013131013131010131313131013101013
131313131313131013131310131310131313131313101310
1313131313131313131313131313191919191923231E1919
1E1E232828282C2C3C5858636362635B5653584F4F3C3C38
3C3838383C353831352E31312E3135312E2E2C2E2C313131
312E2E2E35352E2C2C2C2C2C2C2C2C2C
1E1E1E1E2323232328282828282E2E2E2E2E2E2E2E313138
2E3535383838383538383135383538383838383C3C383838
38383C383C3C3F3F4344433F47444F566C80A09479625653
4D4A473831312E231E281E19191919191310131313101010
131310131910101010101010101013131319131310101013
131010131013101310101010101310101013131010101310
131310131310131313101013131010101013131310101313
1313131310101313131313131919191919191E231E191E1E
232323282E2C2E38565E636668626262625B5B4D473C3C3C
3C38383838383831312E2E2E2E313131312E2E2E2E313135
312E2E3131352E2C2C2E2C2C2C2C2C2C
2323232328232328232328282E2C2C2E2E2E2E2E31313131
31313135383C3C3C3835353835383835383835383C383C3C
3C3C3F383C3C3C3C3F3C473C434A4A566060839D9E8A7466
5B534F3F312C2E2E2C2328231E1919191913131313101010
131313131913101313101013101013101313101313131310
101313101313101313131013131310101313131310131313
131313131313131313101013101013131010101310131013
101013131313131313131319131919191E2328231E1E2823
23232C313131445662666C706A6A6E706C5B4D47473C3838
3C35383838383835312E312C2E2E2E2E2E2E312E2E2E2E31
2E312E3135312E2C2C2C2C2C2C2C2C2C
23232323232323282828282C2E2E2C2E2E2E2E3531313131
3131353538383C383835353835383535383C3C3C38353838
383F3F3F3C433C3F3F3C473F44524A525E5E6085919E9A81
6A63685343312E2C2E2E282C281E19191913191313131313
101013131913101013101013131010131013131313131313
131310101310101313101013131313131310131313101313
131310131313131313131313131310131313131313131013
131313131313131319131319191E191E232E2E231E232C23
23282E3F3F4A586A66686E6E6E6A685E4D433C3C3C3F4443
4338353538433835312E2E2E2E312E31313131312E2E3131
312E313135312E312E2E2C2E2C2C2C2C
23232323282328232828282E2C2C2E2E2C312E2E31313131
313131383838383838353838353131353838383C3835383C
3C3F3F3F3F433C3C3F3F4347474F4D4A585B5B68788CA39B
857171715B3F352E2C2E2C28232C28191913131313101013
131313101313101010131310101310101313131013131313
131010131013101013131010101313131013101010131010
101010131313131013131013131310131313131310131010
1313131319131313191913191E1E231E2C312823282C2828
282E434F4D536A6E716870637060534443383C3C38383C3C
3C3F3C3C3C3C3835312E2E31312E31313531312E2E2E312E
312E31313131312E2E2E2E2C2E2E2E2E
2323232328282823232C2C28282C2C2C2E312E2E2E313131
35313531353835383535353838353838383F3C3C38383838
3F43443F433F3C3C43434344444A534D4F5253686678909A
8F817C786E68533C312E23282C2C2C281E19131310131310
131313131310131310131010101010101010101313131313
101010101010101010101010131013131313131313101010
101310101313131313101310101313131013131310131313
1913131313191913191319232323282C2E281E232E2E2C2E
313C52535B666E717162626E625247433C383C383C3C3838
38383C473C3F383535313531353535353135353131312E31
312E2E2E313131312E2E2E2E2E2E2E2E
282828282323282828282C28282C2E2E2E2C2E2E2E313135
31312E3131383838353831383831313538383C3838383838
3C3F3F433C3C3F3F3F44434A444A4F4D47475863686E797B
8C76748379767466473F2E23232C2C2E2C1E191919191313
101310131019131310131313101013101010131313131313
101310131310131310101010131010131313101310131310
131310131313101013101310131313131013131010131913
13131319131913131919192828282E2E2C231E2838313543
4A5258626A717174635E60605B4A3F433C3C3C3C38383C35
383535353F3C38383131313131313135313535312E312E31
2E2E312E2E2E2E312E2E2E2C2E2E2E2E
232323232328282823282828282C2E2C2C2E2C2E2E313531
31313135353535383535383535353535383F3C3C383C3C38
3C433F3F443F38433C44444743474A524D474D626A766A6A
718163717E7E80786E5E3C352E282C2C2C28281E19131313
131313131010101013131310131310131013101013131313
101313131310131313101010131310101313131313131313
101310101313131313131313131013131913131313131313
13131319191919131919232E2E2E38352823283C3F3F4D56
5E66627B7E7B6E6E6E63524A4A47433F433F3C3C38383535
3835353535353835312E312E2E2C2E35313531312E312E35
2E2E2C312C2E2C352E2E2E2C2C2C2C2C
282828282828282823282C2828282C28282E282C2E2E3131
3131313531353138353835353531353138383C383C353C38
383F3C43433F3F3F474343444747474D4F4A4D586E796863
627981526C7178706E76704F383538352E282323231E1913
131013101310101310101013101313101013101010101010
101313131310131010101310101013131313131310131313
131313131313131013131310131013131313101313131319
131313131913191919282E3C3838443C28313C4F53587076
7C837E807B78746E624F434344443F3F3C3C383C3C353538
353535353535312E312E2C2C312E312E312E2C2C2E2E2E31
2C2C2E2C2C2E2C312E2C2C2C2C2C2C2C
2828282823282823282828282828282C282C2E282C313131
2C2E3131353531353831383135353531383C3F3C3C383838
384443443F4343434343434344444D4456524D5E686C6E62
60627E684F5B5E74747078766E4D3C3C3C352E2C2823281E
191913131313101313131913131313131310101013101310
101313131310101013131313131310131310101313131313
131313191313131919191913131313131319131313131313
131319131913191E2331353F3F3F3F43355871795B5E7B7C
83878781797B7B6A4F443C3C473F3F3C3F3C383C38313531
3535353C3535313131312E2E2E2E31312E312C2E2E2E2C2E
2C2C2E2C2C2C2E2C2C2C2C282C2C2C2C
23232323232823282828282823232828282C2C2C2E2C2E2E
2E2E2E2E3135312E3538383535353835383C3F3F3F3C3C3C
3C433F474343434743434443444A44474F564F585E5E6C66
63606083584F525E6370716E76745E44383535352E2C2C2C
28281E191919131313131313131013131310131010131013
131313131313131313131013131313131310101013131313
131313191919191E1E191919191919191919131313131919
1913131919191E2C3138353C38353F4A527B8C806C768385
868F8985837860584D3F383C433F433C3C383835353C3138
3835313538353531352E3131353531312E2E2C2C312E2C2E
2C2C2C2C2C2E2E2C2C2C2C2828282828
2323232328282323232828282828282828282C2C2C2E2C2C
2C2C2E2E3135313131353835383538383C43434443433F3C
3F444744444744434747444743444A474A525B535E586A66
62606378854A3F474F52566A74716A635B3C38353831312E
312E2C28231E191319191913191319191919191319131310
131313131313131919131913131313131313131313131313
19131919191E1E1E1E1E1E1E1E231E1E1E19131913191919
1319191919192C35353538352E2E4F56748F948683878680
878786807C6853474A3F383F443F3F3C3C38353831353538
38353535353131312E31353535383135353131312E2E2E31
2E2E2E2E2E2E2C2C2C2E2C2828282828
232323232323232828232828232328282328282C2C2C2C2C
2C282E2C2C2C2E2E3131353835313838383F4447433F3F3F
3F4344474747474A474A444743434A47474A5E565B566660
636A627090875E3C4443434D58766C6A6C605B533C353535
312C2C2C2823191919191913191313131919191319191313
101310101310131313131313131010101313131313131313
19131919191E191919191919232323232823191919191319
191919191E2831312E31312E28355663819D9A878C8C8686
86867C6C5E4D44433F473C3C443F3C3C3C38383138383538
383835313131312E3131353835383135352E2E2E312E2E31
2E2E2E2C2C2E2E2E2C2C28282C2C2C2C
1E1E1E1E231E23282328282323282828282328282C2C2C2C
282E2C2E2C3131313131383C353838383F47444447433F3C
3F4444474A4A4D4D4A4A47474443444A444752625E525E60
60636262809B94563C3C433C3F526366635863685E524438
2C2C2C28231E191919191919131313131313131319191913
131313131310131313191919191313101313191313131310
1919131919191919191E19191E1E1E2328231E231E1E1E1E
1E1919192C31312C3538312E355678839E9E99918C898186
837B6A5B524F473F3C3C4A43433C38383835383835383538
3838353131313135353538353535353131313131312E3131
31312E312E2E2C2E2C2C28282C2C2C2C
232323231E23232323282828282C2C28282828282C2C2C2C
2E2C2C312E35313135383C3C3C3F3C3C3F4347474344443F
4447474A4A4752524F4A4D44474343474F4D535362565360
565B5E5E6A819996563547443F44475E5E5B4D526262665B
44352C28231E191919191919191313131313131319191919
191919131919191919191919191919131319131919191913
131313131919191E232319191E191E1E1E23232828282323
1E191E2338382E3538383C434A688A9AA09A9A978C818181
766A5E534A4D474A474444443F383C3C3838383C38353838
3538353535312E3535383C35383835383531352E2E353135
352E312E2E2C2E2E2E2C282C2E2E2E2E
232323231E23232328282C2C28282828282C28282C2C2E2E
2E2E2E3535383835353C3C383F433F434447474443433F43
43474A444A474A4F4D4F4A4A47433F43474F565253604F5B
58635E5B5B6A7E998F683C43384443534F4A444743475660
6A6647352323231919191919131313191913191919191919
191913191919131919191E1E1E1E1E191913131919191919
19131313191919232C28231E1E1E23192328282E2E2C2828
1E1E1E2C3C3C38434A52565E5B68939E949A97998A85807E
76706052473F3F3F44474443433C3C353835383838383838
313535353535313535383F38383835353531312E31313531
31312E2E2E2E2E312C2C282828282828
23232323231E1E2323232328282C2C2C2C2C2C2C2C2E2E2E
31353135353838353838383C3C43433F3F433F433C3F3C3C
3F44474747444A4F4D4D4747433F434A4A4A52584F5E5B56
5E5E6658565B62859B996A312C3F434D4A3F3C444A38313C
525B60523C383828231E1E19131913131913191919191919
1919191919191919191E1E1E23231E231E19191919191919
191919191919191E282C2828231E2323282C31352E282323
2328283138353C4A58716E6A6866869186908F908581766A
625B4D56524343443C433C443C3835383838383838353838
38383838353835353C383C38353535353131312E2E2E3531
2E35312E2E2E2E2E2E2E2C2C2E2E2E2E
232323232323232323232823232C2C282C2C2C2C282C312E
313131353535383538353838383C383F383C3C3F3C433C3C
3F434A4D47444A4A4F4A4744443F434343474D525E66585B
625860585356566A899A9B663C2C384F4F35433F4A47382C
2C3543474D4A473F3F38312C23191913191313131919191E
1E1E1E1E1E191913131919191E23282C281E191919191919
1913131919192323231E282E28232323282C2C2C28232823
2C2E31353531384A567B71666A7483818585858A857E6E66
56524F4F434F473F3C384344383835353535383538313535
35383838383535383838383135313531312E2E2E2E2E2E2E
312C2C2C2C2C2E2E2C2C2C2C2C2C2C2C
1E1E1E1E23232323232323282828282C2C2C282C282C2C2E
313131313535353535353538383C383838383C3F3C3C3F43
44444A4D4A474A4A4D4D4F4A47474443474A4A4D52625B58
60635E66534F525E6E7E9D91813F2C3F4F523C474A434435
2323282C31384D3F3C434D433C2C231E19191919191E1E23
2C23232C231E1E191919191923232323231E19191919191E
1919191E1E1E2328281E23352C231E1E282823231E191E2C
35434A47352E314D5E6A71767B7C85857C8083877E746660
4F5252473F3C4F4A3C3C4447383535313138383C35353535
383838383835353838383535353531352E2E2E2E2E2E312E
2E2E2C2C2C2E2C2E2E2E2E2C2C2C2C2C
1E1E1E1E1E1E2323232323232C2C282C2E2C2C2C282C2C2E
3131312E3138353135353838383838383838383C3F434347
4A4A4D4F4D4A4A4A4D4D4A4D4A4A4A4443444A4D4F565E60
666A6362625256526066809991793C2C355B563C3C3C3844
352C19191E2328383F4347474A473F3C2C23282328232831
352E2C2E2C231E1E1E191919191E1E1E191E1E191919191E
191E1E1E28282828281E28312C231E1E2828231E1E232843
384A56604A3F384D5B637483878185818383837B6A666056
5B5B473C3C4343524744473F383835353531383835383538
3C38383C3C383835353838353831352E2E2E2E2E2E2C312E
2C2C2C2E2E2C2E2E2C2E2E2C2C2C2C2C
1E1E1E1E23232323232323232828282C2C2C2828282C2C2E
2E313131313835353531383F3C3C3C3838383C3C3F474A4A
4F5352524F4D4A4A4F52524F4A4A4A4A4A4A4A4D52535E56
66746E716C6656585E606A83938A70382835585838383547
473F281919191E282E313131383C4444433F3C3C3C352E28
2828282E2E2C2323232323231E1E1919191E1E1E1E19191E
19231E1E23282831231E2835231E1E2828282828282C313F
3C434D6053534F5360768986838C8C8C8C8780706262625B
585E433838474F4F5B433C3C383538353131353838383835
35383C3838383835353835383531352E2E31312E2E312E2E
2C2E2E2C2E2E312E2C2E2E2C2C2C2C2C
1E1E1E1E1E232323232328232328282828282E2C2C31312E
313131313835383838383C3F3F3F433F3F3F3F3C3F43444A
4A4D534D4D534A4A4D4A4A4D4D474747444A4A4D4D4F585B
53606E7171786E585B62626C81938F74532E384F5B3C313C
4F4D31281E191E1E23232323282C2C2E3543474A44473531
2E312E2E3128231E28282C2E2E28231E1919191919191919
1E23231E1E23282C281E2C2C232328383128282843564A35
31383F585E6A707B868F918F9193948C837E79686E716353
4F4D4F3F383C3C3C4D433F3F3C3535383838383535353138
383C433C383535353135353535352E31312E2E2E2E31312E
2E2C2E2C2E2E2E2E2E2E2C2C2C2C2C2C
1E1E1E1E23232323232323282828282C2E2E2E2E2E353531
31383538383C38383C3C383F3F3C3F434343433F3F444A4A
4D4D52524D4F534D4D4A4D4D4A474A4A47444A4A4A4F4F5B
5353566E78717B7666666A6A747B968986603C31525E442E
434A3F382C1E19191E1E1E1E231E2323282C2C3135383831
2E383535382C2C2C2C2823282C2828231E1E191E1E191E19
1E231E1919191E2C352E2C282828313531282C2E4471764D
4F5B6071808C93AEAEA9A39794979396877B747970665E5E
4A47474D443F3F3F4444433F3F383C313538383538383835
38383C38383131353535383538353135312E312E2E312E2E
2E2C2E2C2E2C2E2E2E2E2C2E2C2C2C2C
1E1E1E1E1E23232323282328282C232C2E2E31312E313535
35383C383C433F3C43443F43434344443F4343443F444A4D
4D4D4F4F4F4D4F53524D4A4A4D4D4D4D474747474A4D4D52
564F52626A6E6C7B81767974746E89838687705B38585638
313844443F3123191919191E1E1E1E282C231E232C2E3131
2E2E2E31352C2E2E31312C28231E1E1E1E1E1E1E1E19191E
1E231919191E23353C352C2C2C2E3F3F474D4F473F526363
667B7B909EA0A7C2C8BCBC9694938C8583767068635E5360
564A3F444D474343444F433C3C3838313535383538353835
38383C383135313835353838353531312E2E312E2E2E2E2E
2E2C2E2E2E2C2E2E2E2E2C2E2E2E2E2E
232323231E2328232828282828282C2E312E2E2E31353138
38383C383C433C3F44433F44444447474447474A43444A4A
4D4D4D4D4F4D4D4D53524A4A4A4D4D4F4A4A4D4A4A524D4D
525E5B5862716E6E7E858585816C838A878A8F8666474447
2E3531434D3F2E2C1E19191919191E2328282328282C2831
31312E282C282323232C2C2323191E1919191E231E19191E
1E1E1919191E28312C2E282C384356667478624F43475370
768796ACADACB4C5C2C4C49B8A7B706A6A786E60534A5256
52473F3C3F474A43444A3F3F3C3838353538383131353535
383838383531353535383535383835312E2E2E2C2E2E2E2E
2C2C2C2E2C2E2E2E2E2E2E2E2C2C2C2C
232323232323282328282828282C2E2E2E312E2E31313138
353C3C383C3F3C43433F3F4343434A444A4A4A4A4A474A47
4A4A4F4D4F4D4F4D4F5352524A4D4D4D4D4F4D4D4D535252
5253565E5863716C6E7B7E8F877B7C868F918F8C94766044
473535354A473F38352319191919191919191E28281E2328
2C383F3128281E231E282828231E1E191919191E1E191E23
231E1E1E191E232823282C35535B5E606663565B63716A7B
8A94A2AEAAACB6B4B1AEA07C746C686A786E605B524A4A4D
4A433C3C3F444D4D474A3C3C3C3C38383535383531313835
3838383C38353531353538353838353131312E2E2E2E2E2E
2E312E2E2E2E312E2C2E2E2E2C2C2C2C
23232323232328282C2C2C2E2C2E2E3131382E3531353535
35383F3F3F4744433F3F3F3C4444474A47474A4A4A474A4A
4A4D52524F4D4D4F4F4F4D5252524F4D4A4D4D4F4F565352
525252535B60606E7676788C8F7E6A85939397908F9A9078
58532C3538444A4338382E231E1919191919191E1E1E1E1E
1E2E3835313123232323282828231919191E191E1E1E282C
28281E1E19191E2323282E2E5252474D5362626C747B7E8A
94A3AEBBADA7A9A3A1937E635B5E7171665E524447524A4A
44433C3F3F3F4A474A443C3C383838353538353131353535
353538383531313131353838383C35312E2E2E2E2E2E2E2E
2E31312E2E2E2E2E2C2C2E2C2C2C2C2C
282828282828282C2E2C2C2E2C2C35353535353835353838
38383F434344443C3F3F3C4343474A4447474A4A4D474D4A
4D4D5352524D52524F4F524F4A4A534F4F534F5252535353
52534D4D535653586C747C838C947C7C8C99999787949794
8F7B60443838433C3C38312E28231E19191919191919191E
192828352E2E2E23282823232328281E1E1E1E1E1E232E31
35312823231E1E2328282C2E4752606C6A6E7978899D969D
ADB1B8BBAAA19D938778635358666A7052524F434743444F
524D3C3F434444434A443C383838383C3535383535383835
353838383531313131313535353535352E2E2E2C2C2E2E2C
2E312E2E2E2C2C2C2C2C2C2E2C2C2C2C
2323232328282C2E2E2E3131313135353C35383C353C3838
3C38434343474743443C3C3C444A474A4A4A4A4D4D4D4D4F
4D53525353524F4D52524D4D4D4D4A4D4F535656585B5653
535353535356535860626E798086917B768F96878A91909B
9797878158473C443C3C38312C2C2C281919191919191E19
19191E2828282E28282C23231E1E23231E1E231E1E283538
4447383535312E2E35353F4D607183878993A0A59D9D9AA9
B7AEADADA2938C7C6A5E58606060585652474D523F3C434D
5E5E3F433C3F3F3F443F3C3C3C3835383838383135383831
383838353835353131313135313835352E2C2E2E2C2C282C
2E2E312E2E2E2C2E2C2C2C2C2E2E2E2E
28282828282E2C2E31313531353135383C3C3F433F3F3C38
3F3F4343444D4A4447433F44474A474A4A4D4D524D4D4D4A
4A4F52524D4F4D4D5253534F4A4A4A4D4D4D534D56535653
534F524F535353535B5B5E66717C8986817B8F938194998F
94918994837C634F4F44474D43353831281E191919131919
191919192323232C23282828231E232323232323282C3C3F
3C52534444473847474D52636E7C8F9797A1A29A9790969E
A39D968F8A83746362666A665E4F4F4A4D534F5347443F47
4A433C3F383F3F3F473C3C3C3C433C3C3C38383838383835
383535353831352E31313131353531312E31312E2C2E2E2E
2E2E2E2E312E2C2E2C2E2C2E2E2E2E2E
2C2C2C2C2C2E2E2E353535353135353C3C3C3C4A3C3C4344
3F3C3F44474A4A474443444A4A4D4D4F47524D4D4F4A4F4D
4A4A4F4F524D4D4A4D52524F4D4D4D4D4F524F4D4F4F5653
5253534F4D534F56535B5B6366748A7B81859393998F9483
899686858F86867E766A5B4F4F4F4A4738312E281E1E1E19
19191E191E1E1E282323232328282E2C31382E282E353F3F
354A5852353F353C4A4F6270818A9694969791878C868AA0
9A877E74767971686362604F4A4D4A47444D53534D4D3F43
44433F3C3F3F4347443C383C433F3F3F3C38383C38383838
38353535353535313531353135313135352E312E2E2E2E2E
2E2E2E2E2E2C312E31312E2E2E2E2E2E
2C2C2C2C2E2E353135353535353835383F3F3C43473F4347
3F4744474A4A4A4A4A4A47474D4A4D4D4D4D4F4D4F4F4D4D
4D4A4D4F524F4D4A4F4F4F4F4F524F4F5353524F52565653
534F4F525353535353535E626662898070747C8A99938F85
7C7E97858F8A8A838691817B66564F4D534A4443382E281E
19191E23232323233123232328283135354447313C4A4743
3547534F312C2C354753626A7E8394949694908C807E8985
80807871767466666C624F43434A4A474F534F4D443F4447
4743433F3F4347473C383C4344443F3F3F3C3F3C3C3C3835
353538353538383535353531313531312E3131312E312E31
312E2E312E2E2E313131312E31313131
3131313131353538383C3838383C3F433F3F43434344444A
4443474A4A4F4A4A4A4A473C444A4A4A4D4D4D4F5252534A
4A4A4D4F4D4D4D4D525252524D4F52535356535253585656
535352535353525353565B5B6266799679706871838C949B
857B8789898C8F918983908C85795E565B535256534A3C2E
2C28282828282C282E2C231E1E1E282C353C5353534F4444
313F43382C2E3147474D63747B7B877B7C81807871788068
6A63626C665E5B585656534D4D525E58564A4A444A474747
4A4A4A4A4D4F4D473F3F4344474743443F3F3F3F3F3F3835
353835353838383835353531353535312E313135312E3135
31312E2E313131353535312E2E2E2E2E
38383838383C3C3C3C3F3C3F3F433F3C3F443F4A444A4A4D
4F4A4D4F5253534D4F524D4D444F524F534D4F53524F524D
52524F524F524A4F5256524F524D4F535653565353535356
585353565856535653565E5B60686E949668636C707B8A93
968985898C9190898C939090898F81786A635B4D47444743
433C312C2C2C2E2E283C311E232328283135525E5B52353C
3531312E2E3C444D4D5371817E7C938585836C6A76717066
5B565E62636660585856535B60585B5E524A474A4D535E53
56585653524D4A474343434A4A4D4A44443F43473F3C3C38
3C3C35383C3C3C3838383835353838353531353535313535
353135353538383838383C3531313131
383838383F3F3F3C3F3F43474744444344434A4D4D4A4A4D
4D4D525356565B565352524D5252524D5252535353535353
524F525353534F56565252535352524F53535356535B5353
5658565656565653565656585B606E839674686263707C80
938996899090858C8C8C8C8C968C858385807874604D3F3F
3C3C3C353535383C443F4A2C282C2E35383C4F6A6A4A3835
2E2C2E31384D4F535268868985878C868174666C70686262
5E586363636660605B585252524D4D4A5253534F4D4F5352
5353524A4D4A4A474A4747474D4A4A4A473F444443444343
3C3C3C383F3F3C433F3F3F3C383838353535353838383C3C
38383C383F3F4447474A433F3F3F3F3F
4444444444434744474A4A4A474A47474A4D4A4D4F4A4F4F
4D525656535E5B53535352524F525353534F535653535653
5252535353535356564F5353524F525353535253535B5656
56565353535856565356535B585E6A7E8994786E585E6376
89898C909089858383918C8783918C86868183878C83705E
4F47473F434344444F58534F312E4347444A526C765B432E
35383C4A4A52535E667B898A857B7C897E6A766A6868686A
6363635E53524D524A52534F4A4D4A4A4A4D525653534F4D
4F4F524D4D4A4A4A4A4F4A4D4F4A4A4A4A4D4A4A4A4A474A
44443F4444474A4A4A4A4A47474A4343433F3F434747474A
474A4A4D4A4D56535B56565656565656
444444444747474A4D4D4D4F4F4D4A5252535353534F524D
535356585E565B5656565352525356525353535656565352
52535353535353535853565356534F535652535653565653
565653525353535653535356565E5E80818791896C5B5B6A
6A8376878F9191978586908F8C999691969191838A878F90
8C70685656585353606A6C635E44434D474A5366706C5B53
4D535E60636C6E787C818A7E85807B6A78817471746E7466
6258524D4A4D4D4D4A4D524D4F4F4D4F4F52525B58565353
5856535252534D4D53535253535352535653535352535352
524D4D4D525356565E56585B535B535656565853585E5E60
5E5B5B6366636E71797B797B7C7C7C7C
4A4A4A4A4A4A4A4A4A4D4D4F4D524F535353535356565353
5653585853565B5653524D4F525356535653525653535352
4D524F5252535353585B5653534D53535656565652535353
5858585353535353535653585B5856718086969E90716362
666A7C6E7985869BA09485868F94919691999D978C878189
87837E767476717874787B81746C60584F566C787B74787B
79797B7C8C8C908C918C8585878578747C78767970635E52
5353524F5252535253535652525658565B5E5E6260625E5B
62605B605E5E5E5E5E5E5E62626668636666636262626663
6362606362686A7471747471717074747476787B7E81837E
8181878F94999B9D9EA2A1A1A5A5A5A5
53535353524F4F4D4D4F5253525353565358565656565656
5353535B5356565353524D4D4D5253565356535B56535253
524F4D5352535353565656565653535E565B5B5356585858
56585856565B565853585B5B5E5B5B60718696979E8C8579
6E667479706E7974818C9A9990898C908C8C868F96969096
968C898A8985808A8A817C8790867868707686868F7B767C
89908C878F918F949091909085868687817676706358585B
585E5E5E62605B5E5E6063636066666A6E6E707971747476
797B7B7876787B7C7B7B7B7E81817E868787898587858986
8987898A899094969B9B9B9B9D9BA09DA0A1A3A2ACACAAAC
ADADAEB8B9BBBBBBBCBCB9B9B9B9B9B9
58585858565353524F534F565353565656585B5B58585858
5656585B5656565853535352525356535653585B5E565658
53535353565353535B5B5B5653585E605B585E585B5B5E58
5E5E5E58585E5E5B5E5E5E60625B585E6A76869E9BA1937E
817C7C70807E747C7B858687979394938F91949186838C93
94999A949B9D9D9D9EA1A29DA09B93898C8F8F8789786871
879A8F86858C91918C8C8685858C8F86807B76716E767474
6E70707478767978787B7C7C817E8587878A8C908C8C9096
96979D9A9E999D9EA2A2A5A5A9A9ACACADB0B3B1B0B1B6B6
B6B7B6B9B8BBC1C4C5C8C9CDC6C4C1BFBFBFBFC1C1BCBCBC
BBBFC2C4C4C2C2C1C4C4C1BEBEBEBEBE
6060606060605B585856565B5E5E5E5E5E5E5B5E60605E5E
58585B5B5E5E5E5E605E53565356585E5B5E605E6060625E
5E5E58565B585853585E5B585B5B5E5E5B5E605E535E5E5E
6060605E5E5E60626362626366605E5E626E81869D9EA590
7C7C909989818681837E858587919797979D9B908C898791
909AA3A5A39E9EA2A3A1A3ACA5A9ADA29690867E7C706879
93918F949194949A94938C8C919091918C8987898F8F8A8F
8A8F8F9396999B9999999A9DA1A2A9AEB0B1B1B0B3B4B6BB
BFBCC1C2C1C4C2C5C6C9CACDCECED1D3CFD1D3D1D1D3D1D3
D1CED1D1D1D3D8D8DCE0E2E2DEDAD1C6C5C8C4C2C1BEBCBE
BCBFC2C4C4C4C2C1C2C2BFBBB8B8B8B8
6E6E6E6E6E6A63636363626C6E686A636863626268686868
636A66636368666666635B5E5E5B60606060626263636363
6663636262605E5E60626262626262606062636063636263
6363636663636666636663636A63626663707679919AA0A3
9781808A979494979094979D979197999EA3A3A297918C90
978F949BA0A09D99978F91A09BC4C4A394978C8780807881
9DA1A0A3A5A3A9A9A9A9A7A9A7A7A1A3A3A5A7A7ACADAEAD
B4B7B6BCB9BBBEC1BFBFC6C6CACED1D3D5D7D5D5D4D8DADA
DCDCDCDCDEDEDCDFDBDEDCDEDFE2E2DFE0DFDEDEDEDBDBDE
DCDAD5D8D7DCDFE4E7EAEAEAE4E2D5C5BFBFB9B8B4B3AEAD
AEADB0B0B0B1B1B4B6B4AEAAA9A9A9A9
808080807E80797678747479797978767471707071717979
78747876747878716E706C6A686E7070706E6A7070717674
7878767171716C666A6A6C6A6C6E68666866666A68636C6C
6C6E6C6E63666C6E707171707470666868747980859B93A1
ADA98C8187908F9494A09BA3AEAEADAEA7A2A0A5A7A1A2A0
9D9BA0A7A9A19E96999799ACA3D3CDA394999D9A8C818C99
B7B8BBBCB9BBBBBFC2C5C8C2C5C6C2C2C5C8CACAD1D1D1D5
D7D7D8DEDEDCDEDFE0DEDFE2E0E2E4E4E4E2E6E2E6E6E5E5
E5E6E2E4E6E7E6E5E4E4E0E0E0E4E2E2E0DFDEDEDCDEDAD7
CED4D3D1D1D8E0E6EAEEEEEAE5DCC9AEACA7A19E9B969494
919393999A9DA1A5A9A9A7A3A3A3A3A3
969696969694908A8F8A878C8F8F8C8A8A8983838989878A
8A8A8A898787898381807C7B7C7C83818180808387858380
8385818183807C7C80797B7B7B7C797B7B78767678767679
7B7878767171767678787B7B7E7B797879808787908C949D
AAB6B7A19B9AA39B9E9DA1A2A7ADB8B9B9B8B6B1B8B9BEBE
BEBEBEC2C2BCBBB3ADB0B4BFBCD5D1B09BA0A39D9AA1A9B6
CAD4D3D3D3D5DADCDEDFDFDEDFE0DFDFE0E2E2E4E5E6E7EA
EAEAEAEAEAEAE6ECEAEAEAEAE9E9EEE9E6E4E6E7E7E9E5E2
E4E5E2E0E2E2DFE2DFDED5CFDCDADED8D8D5D4D1CFCDC9CA
CACBC6C6C9CFDCE6EAEAE9E4DAD1B3938A8C8C87857E7E81
8080838790949EA1A7A9A7A7A7A7A7A7
B8B8B8B8B7B3ADAEAAA7A7A9A9A9A9A9A7A9A3A2A3A5A3A3
A3A0A3A1A1A0A19D9796999A969A9B9BA09B9A9D9B9B9A97
9D9A9A9A9D9B9993949491919094908F90908F8F908C9090
8F8A8C878787868A908C90919197969197979EA1A3A7A7A2
B3B8CDCBC9C5C6C2BCB8BBBCC2C2CDCED1D1CFCFCFCFD3D5
D7DBDBD4CED1CBCBCDCED1DAD4D4D3C2B4ADACAAB1C2CED5
E0E2E2E4E2E5E9E9E9EAECE7EAEAE9E6E6E5E7E6EAEAE6EF
EAEAEAE9E6E7E7E9E9E9E9E6E6E4E6E2E2E2E2E2E2E0DFDA
DBD8D4D4D5D5D1CFCDCBCDCACBCBCAC8C9C4C2BFBCB9B6B7
BBB9BBBBBCC9D8E6EAE6E4DED1CAAA8A837E81807C767878
787B7E858C919BA1AAA9A7AAAAAAAAAA
DBDBDBDBD7D4D3D1CFCECECACBCECECECECFCFCBCBC9C6CA
CBC8C8C6C4C4C4C2BCBFBFBBBBBBB9BEBFBFBEBEC1BEBCB9
BFBEBEBEC1BEBEBCB8B8B9B8B6B7B7B3B7B7B0ADB0B3B0B1
B1AEADAAACAAACAEB3B8B7BBBBBEBEBFC2C6C2C4CBCFCBCB
C2C2D4DFE2E0E2E4E4E4E2E2E5E4E2E2E6E9E5E5E9EAEAEC
ECE9E4DEDBDBDADFE0E2E0E4E2E6E2DAD1CFCED1D3DAE0E0
E2E2E5E5E2E5E5EAE6E5E7E6E6E6E5E4E5E2E2E2E4E2E2E5
E5E2E2E0DEDEDFE0DFDCDEDCDCD8D5D7D5D5D1D4D1D1CFCA
C4C8C6C8C8C6C4C2C4BFC2C4C1C2C2BFBFBCBCBCBBB9B6B6
B1B6B7B6BCC8D4E5E9E6E2DBCFC6AC897C7C7C7979787676
717679838C9199A2ADAEACAEAEAEAEAE
E7E7E7E7E5E4E2DFDFE0E0DFDFE2E2E4E2E7E9E7E7E4E2E2
E6E5E4E4E5E2E2E4E2DEDED8D7D5D8DBDCDFE0E2E2E5E2E2
E0E2E2E4E9E7E5E4E2E2E0DFDEDFDFE0DEDFDBD8DADADBD8
DADBD8DADAD8DBDBDFE2E2E4E5E7E2E5E7E9E6E5E9E7E9E9
E5E2DCE9F1EFEEF3F3EDEEF3F4F3F3EDECEDEAEFF3F3EEE7
E6E7E2DEE0E4E2E4E4E7E5E5E4E2DBDEDCDCDCDEDCDEDFDE
DEE0E2DFDEDEDFE0DEDBDAD7D8D7D5D4D1D1D1D3D3D4D4D3
D1D1D1CECDCDD1CED1D1D1D1D1CECECECFD1CFCDCDCDC9C8
C4C2C1C2C2C4BFC2C2C1C6C4C2BFC2C1C2BFBEBBBEB8B7B6
B6B6B4B8BFC2CFE4E9E5E2D8CFC5AC877C7C797976747476
7476788087919BA3AEB3B0B4B4B4B4B4
E6E6E6E6E4E2E4E0E2E2E2E2E4E7E5E9EAF1EFEEF1EEEDEC
F1F3F3F5F5F4F4F3F1EAE9E5E2E2E4E6E5E9EAECECEFEDEF
EFF1F4F6F6F7F8F8F5F4F1EEEEEEEDF1EEEDEEEAECECEDEC
EFF4EFEFEEEFF3F1F4F7F5F3FAFBF7EDF7F5F5F6F6F5F6F6
F5F5F1E4EDEFF5F7F8F4F1EEEEEFEFEAECE9E7E9E9E9E4E2
E0E4E5E2E2E5E6E5E5E2E2DFDEDED7D4D7D5D4D1D1D1D1CE
D1CED1CECBCBCBC8C9C2C6C4C5C1C5C1C4C4C2C6C9C9C6C9
CAC6C6C8C9C6C8C9CACAC9CACACACDCBCDCECDCAC9C8C8C5
C4C6BFC4C2C2C1C2C1C2C9C5C2C2C5C2C1C1BFBBBCB9B8B1
B7B8B8B9BCC5D1E4E7E4E2DACEC4AC877974767878767474
7474787E86909AA5B1B3B4B8B9B9B9B9
D8D8D8D8D5D7D5D8D7D8D8DEDFE2DFE2E6ECEAEAEAECEAED
F3EFF1F4F4F3F3EFEEECE9E4E0DFE0DFE0E2E2E5E6E9ECEA
EAF4F7F8FAF8FAFAF6F5EFEEEDECEAEAEAECEAEAEAEFECF4
F3F5F5F6F6F5F5F5F6F8F8FAFBFBF8F6F5F5F3F4F4F1F3F4
F6F4F6F3EDE9EAEAECF1EAEAEAEAE7E4E2DFDFDEDEDCDCDE
DFE4E2E0E0DBDEDBD8D7D1D1CFCBCACFD1CAC9C9C9CBC6C4
C5C4C4BEC1BFBEBEBFC1C1BEBEC1C2BFC1C4C1C4C4C8C6C5
C8C4C8C8C4C5C9C8C4C8CDCBC8C9C8C9CDCACACBC9C8C5C2
C4C2C4C4C5C5C5C6C8C5C5C5C8C4C4C1C1C1BFBEC1B8B8B6
B6B9B9BBBFC8D3E2EAE5E0DACDC6AD877E78717678747171
7470767C838C9DA7B3B8B7BBBCBCBCBC
BFBFBFBFC2C5C9CACACBCDCBCED1D1D5D5DEE0DFDFE2E2E4
E6E5EAEAECEAEAE5E6E4DCD8D4D1CFD1CBCFD1CFD4D7D8DB
DCE6EAEAF1EFF1EDEEE9E7E0DEE0DBDEDEDBDCDBDCDEE4E4
E7EAEAEEEFEFEFEAEEF1F3F3F4EDF3ECECEAE6E9E7E7E7E7
EAEDEEEEEDEAE5E4E0E4E0E2E2DFDCD5D8DADADEDFDCDCDB
DBDCDBD5D7D5D5D7D3D1D1CFCFCBC9CBC5C5C6C8C5C6C8C2
C4BFC2C2BFBEC1BFBFBEBEBEBFBFBEC1C1BFC2C2C1C5C5C4
C4C5C6C9C5C8CAC8C6CBC9CBC9CACDCACACAC8C9C9C6C6C6
C8C4C2C6C8C6C6C9CACAC6C6C6C5C6C2C1C2BFBFBEBBB4B8
BBBBB9BEBEC8D1E2E7E4E0DACDC6AD897B76717678707171
6C70747B81879AA5B1B7B6BBBCBCBCBC
BBBBBBBBBCBFC1C2C6C8C6CACBCACECED1D4D7D8DBDBDCE2
E2E2E5E5E4E4E2DCDBDBD4D3CBC6C4BFB9BEBCBEC1C4C6C8
CBD8E0E4E7E5E2E2E0DCD3CDC8CBCBCBC8C8C5C2C6CDD1D4
D8DEDEE5E5E7E2E2E2E5E5E9E7E7E7E7E5E0DFE0E2E0DFDF
E4E6EAECECE9E9E5E2E0D8D7D5D4D8D8DADEDEDEE0E2E2E2
DEDFDFDBD7DAD7D7D3D1CFCBCAC8C5C6C2C1C8C5C1BFC2C5
C2C1C4C2C1C1BFC4C1BFBEBEBFBFBEC1BEBEC2C1C2C1C1C4
C2C6C6C4C6C8C8C9C8C8C6CBC9C8CBCACDC8C9C9C9C8C8C5
C6C4C8C9C9C6C8C9CBC9CAC9C8C5C6C5BFC2BEC1BEBBBBB9
BBBBB9BCBFC6D1E0E7E5E2DACEC5AE8979767171716C706C
70706E797E8796A2B0B3B6B8BBBBBBBB
BCBCBCBCBFC1C1C2C5C5C9C9CACBD1CFD1D1D4D7DBDCE0E2
E2E2E4E5E6E2DFDEDAD5D1D3CAC5BEBEBCB8B8BCBCC1BFC5
C9D5DCDEE2E0E2E0DBD7CFC5C1C2C2C2C2C1BEBEBFC5C4CA
D1D7DAE0E4E6E4E6E2E2E4E7E4E4E7E5E6E4E0E0E0E0DEE0
E4E5E7EAE9EAEAE5E4E0DEE0DED8DCDEDED8DEE2E2E4E2E2
DFE2E2DFDFDEDBD7D4D1D1CDCBCACAC5BFC2C4C2C1C2C2C2
C2C2C2C5BFC1C1C2C1C1BFBFC4C5C1C1BEBEBEBFC1BFC2C2
C5C6C6C6C6C6CAC6C9C6C9C6C9CDCDCDC8CBCBC9C8C6C8C5
C5C5C6CACAC6C9CACBCAC4C9CBC8CAC2BEBFBFBBBFBCBBBF
BEBCBBBEBEC5CFDFEAE4DFDACFC8B18976747671706E6A6E
6E6C6C787C8796A1ACB4B8BCC2C2C2C2
BCBCBCBCC2C1C2C1C4C9C8C9CBCECDD1CFD1D3D4DEE0E0E2
E5E4E4E6E5E2E2DCDAD5D3D3CAC6C2BEB8B8B8BBBEBEC2C5
C9D4DCDEE0E2DCDFDCD4CBC4BFBFC2BCBEBEBCBCBBC1C2C6
CDD4D8E0E5E9E9E7E5E5E7E7E7E7E9EAEAE7E6E4E0DFE0E2
E2E7E9EAE9EAEAE6E5E4E2E4E2DFDEDFDEDFE0E0E0E4E5E5
E4E5E2DFE2DEDCDAD5D5D3D3CECDCBCAC5C6C4BFBFC4C1C1
C8C4C2C4C1C1C2C6C6C4C1C2C4C4C1BFBFBFBFBFC1C2C1C5
C9C6C5C8C8C9CAC8CAC9C2C9C8CDCECECDCDCDC9C4C6C5C4
C5C5C6CAC8C8C9C9CACECECECECAC9C6C1BFBCC1BEBEBBBF
BEB9BBBBBEC6CFDFE9E4E0D8CFC8B08F767074746E706E6E
6A6C6A787B8594A2ADB3B8BCC2C2C2C2
BEBEBEBEBEBFC1BFC5C6CACBCBD1D1D1D1D1D7DADCE0E2E4
E2E2E5E6E6E2E0DBD8D5CFD1C9C4C2BBB9BCBCBEC1C1C4CA
CBD7DEDFE2E2DEDCD8D3CABFBEBFBEBCBBB9BCBBB8C1C4C6
CDD4DBE4EAEEEDECEAEAE9E9EAEAEAEDECEAE9E6E5E5E4E5
E7E5E7EAEAE9E7E5E2E4E2E0E2DFDEDCDEDCDEE0E4E4E4E9
E7E6E7E5E5E2E0DFD8D7D3D3D1D1CBCBCAC6C5C6C8C6C6C2
C5C6C6C5C5C6C4C5C1C1C1BFC2C2BEC2BEBEBFC2C2C2C5C4
C6C5C9CBC6C9C9C8CAC8C9CACBCBCECBCDCBCDC6C6C4C4C4
C8C4C6CAC9C8CACACECFCECFCFCBC8C5C5C1BFC2BFBCBBBE
BFBEB8BCBEC4CADCE6E5DFD5CEC4B08F79716C716E6C6A6E
6A6A6E767B81909EAEB6BBBFC2C2C2C2
B9B9B9B9BEBEC1C2C4C8CDCECED1D4D5D4D7D7DCDBE0E2E5
E4E4E4E5E5E2DEDBDAD5D1CECBC6C2BFBCBFC2BFC6C6CACD
CBD5DEDFE2E2E0DCD8D3C9BCBEBBBCB9B9BBB9BBB7BEC5C8
CBD4DBE6ECF1EFF3EDEEEEEDEFEFF1EDF3EEEAEAE9E7E9E5
E6EAE9ECECE7E6E4E2E2DFDCDCDBD8D5D8DBDEE0E2E2EAED
EAEAEAE7E5E2E4E0E0D8D7D5D3D1CECDCBCACAC9C9CBC8C8
C9C8C6C6C5C6C6C6C1C2BFBFC1BEC1BEBEBBBEC1C6C4C5C4
C8C9CDCDCBCACBC5C9C9CACACACBC6CACACBC6C2C4C4C2C6
C6C6CACBC9C8CDCACECFCFD1CECACAC8C5C4C1BFC1BFBBBE
BCBCB9BEBFC2C5DAE5E0DED7CDC4B08F7870706C6E6C6A6A
6A6866747980909DAEB4B9C1C2C2C2C2
B7B7B7B7BBBEC1C5C8C8CAD1D1D3D3D7D8DBDAE0E2E4E4E5
E6E7E5E2E5DFDFDBD8D4D1CEC8C5C2C4BFC1C4C4C6C9CACA
CDD4DEDFE4E2E0DBD7CFC6BCBBBEBCBBB9B9BBB8B8BCC5C9
CED8DCE5EEF1F4F3F4F4F4F1F4F4F5F5F4F3F3EEEEECEAED
EFF1EEEDE9E6E5E2E2DEDBDBD7D5D5D7D7DCDEDFE4E7EAED
EAECECEAE9E5E2E2E2DEDAD8D4D1D1CFCECDCBC9C8CACAC8
C5C9C8C8C5C8C4C6C6C5C2BEBEBEB9BFBEBEBCC1C4C4C8C8
BECACBCDC9CAC9CACACACAC9CBCECAC8C9C8C4C5BFC5C2C4
C4C5C4C8CAC9C9CDCECECFD3CDCAC8C5C5C5C5C2C2BFBBBB
BBBCBCBBBEC2C6D8E5E2DCD8CBC2B093766E6A6E6E63686A
68666A7178808F9BADB4B8BFC6C6C6C6
B8B8B8B8BEBFC4C6C6C8CDD1D3D5D5D7DEDFE0E4E5E7E7EA
EAE9E6E5E6E4E2DED5D7D1CDC9C9C6C4C2C6C4C4C6C9C9C9
CBD3DBE0E0DFDED8D7CFC6B8B8B9B9B9B8B6B8B9B4BCC9CD
D1DADFE9EFF5F5F6F7F7F6F6F6F7F7F7F6F4F3F5F5F3F3EF
F3F4EDF1EDE7E4E2E0DEDCDAD5D1D4D4D8DCDFE2E5EAEAED
EDEDECECECE6E6E4E4E2DCD7D7D3D3D1CFCECDC9CACACBCA
CACBC8CAC9CAC8C5C8C6C2BEBEBBBBB9BEBCBEC1C1C4C6C6
C5C9CDCDCDCACBCBCAC9C9CACDCDC9CACDC5C5C5C4C4C6C4
C2C2C8C8C9CAC9CDCDCFD1D1D1CECBCAC6C4C6C5C5C1BCBE
BEBFBFBEB9BFC8D7E4E0DED5CAC2B18F766C6C6A6A686A66
63636874787C8C99AEB6BCC2CACACACA
B9B9B9B9BEBFBEC1CACDCFD3D3D7D8DBE0E2E5E7ECECEDED
EAEAEAE6E9E5E2DCDBD5CFCEC9C9C9C8C5C8C9C8C9CBCBC9
CDD4DBDFDEDEDBD8D8CFC6BBB7B9B8B9B8B8B9B6B6BCC8CE
D8DCDFE7EEF5F5F6F7F8F8F8FAF8FAFAFAF6F6F6F6F5F3F5
F4F3F4EFECE9E6E5E0DCD8D7D4D3D5D4D7DAE0E2E5E9E9EC
EEEEEFEFF1E7E9E6E4E2E0DADAD4D4D1CFCFCDCACACAC9CB
C9CACACBCBC9C9C9CAC8C2BEC1BCB9BCBBBFBFC1BEC4C9C9
CACBCBCDCDCBCBCBC9C8CACACDCAC9C9C6C4C5BCC2C5C5B7
C2C2C8C5C5C8CDCBD1CFCFCED1CFCDCACAC5C6C5C2C1BBC2
C4BFC1BCBCBEC5D4E0E2DCD5CBC2B393786E706C66686868
68626671747C899AB1B8BFC1CDCDCDCD
B9B9B9B9B9BFC1C1C9CECFD4D7D8DCDFE5E7EAECF3F4F5F5
EFEEEAEAEAE4E2DBDAD7D1CEC9CACAC8CACBCAC6C9C6CECE
CED3DEDEDFDFDBD8D3CEC6B9B8B9B6B8B8B9B7B6B7BCC8CE
DCE0DFECF1F5F5F7FAFAFAFAFAFAFAFAFAF8F8F7F8F7F7F7
F4F4F5F4EEEAE9E7E4DED8D7D4D3D3D5D8D8DFE4E6E6EAEC
EAEDEFF3F3EDEAEAE5E4E2DEDCD7D5D3CFD1CDCDCFCFCBCB
CAC9C8C9C9CBC9C8C9C6C5C1C1BCBCBCC1BFBFBFC5C4C9CB
CBCBCDCBCBCDCEC9C4C9C9CACBC9C6C5C8C6C4C4BFBFC2BB
C4C2C6C8C8C8CECBCECFCFD1CFCBCDCACDC9C8C5C2C1C1C4
C4C1BCBFBBBFC1D1E0DFDED7CBC2B1947B6A6A6866626363
6263606C767B899BB1B8C5CECECECECE
B8B8B8B8B9BEBEC4C9CDD1D5D7DCDFE2E7EAEFF4F7FAFAFA
F6F5EFEAEAEAE4E0DAD7D1CDCACAC9CBCAC9C9C9CBCDCFCA
C8D1DCDBDBDCDAD8D4CBC5B9B7B7B7B7B4B4B3B6B3BCC8CD
D7E2E4ECEFF6F7FAFAFAFBFAFDFAFAFAFAFDFAFAFAFAFAFA
F6F5F4F4F3EAEAE9E6E0DBD7D5D1D4D5D8D8DFE2E6E7EAEA
EDEEF1F1F1EFEAEAE9E7E4E2DBDBD8D5D3D1D1CFCFCDCDCD
CBCACACBCECAC8CAC9C9C6C1BFBCBFC1C1C4C4C1C8C5C8C9
CDCECFCFCBCBCECBCDCBCACBCBCAC9C6C6C8C5C6C5C1C1BC
C2C4C2C9CBCDCFCFCFD1CFCFCED1CECDCECBC9C4C1C6C4BF
BFBFBEBBB9BEBFCFDEDCD8D3CAC1B3967B6A6A6666666062
62636268747B859DB1BBC5CACFCFCFCF
B8B8B8B8B9BEBFBEC8CDCFD7D7DCE2E6EAECF4F8FAFAFBFA
F7F7F3EAE9E9E4DEDAD7CECDCBCDCACECFCFCDCECFCED1D1
CDD4DCDCDAD8D8D4D1CFC6B7B6B4B1B0B4B3B3B3B3B9C5CD
D5E0E5EDF3F7FAFAFAFAFBFDFBFBFAFAFBFBFDFAFAFAFAFA
FAF7F1F4F1EEEAEAE6E2DFDBD5D5D4D5D8D7DCE2E2E7EAEA
ECEDF1F3F1EFECEDECE9E5E2DEDBDBD7D4D5D1CFCFD1CFCE
CFCECDCDCECECACACAC9C8C2C4C1C2C1BFC5C4C6C8C8C9C9
CECECECFCECED1CECECDCBCBCAC9C6C5C5C5BFC5C5BFC2BE
C2C4C4CAC8CECECECFD1D1CFD1D1D1CFCFCDCDC8C4C6C5C5
C2BFBEBBBBB9BECDDCDCDAD1C9BFB1977B6A666663636263
6360626C7679899DB3BCC6CED1D1D1D1
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "We use the least asymmetric filter of order 4. Here we have changed the \
starting index from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " so that the boundary effect is symmetric."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.8"}],

Cell[CellGroupData[{

Cell["\<\
(s4 = LeastAsymmetricFilter[4];
 s4 = MapAt[-3&, s4, {2}])\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \({{\(-0.0757657147895023364`\), \(-0.029635527646002826`\), 
        0.497618667632774869`, 0.803738751805132345`, 0.297857795605306385`, 
        \(-0.0992195435766336153`\), \(-0.0126039672620313814`\), 
        0.03222310060405146`}, \(-3\)}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "The data are transformed using ",
  StyleBox["WaveletTransform", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.9"}],

Cell["\<\
wtdata = WaveletTransform[data, s4, 3,
BoundaryCondition -> Fixed];\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
The output of the two\[Hyphen]dimensional wavelet transform is \
organized according to the resolution levels. Note that at each resolution \
level there are three detail matrices.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.10"}],

Cell[CellGroupData[{

Cell["Dimensions /@ wtdata", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \({{32, 32}, {3, 32, 32}, {3, 64, 64}, {3, 128, 128}}\)], "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "We can plot the coefficients of one\[Hyphen]dimensional wavelet transform \
in phase space using ",
  StyleBox["PhaseSpacePlot", "MR"],
  " or plot the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_\(j  k\)}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " against ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " for each level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " and stack the plots for different levels together using ",
  StyleBox["PlotCoefficients", "MR"],
  ". For two\[Hyphen]dimensional wavelet coefficients, we arrange the \
matrices from different levels into a big matrix of the size of the original \
data and plot its density plot using ",
  StyleBox["PlotCoefficients2D", "MR"],
  ". Note that we cannot use ",
  StyleBox["PhaseSpacePlot", "MR"],
  " for two\[Hyphen]dimensional coefficients. \nThe two\[Hyphen]dimensional \
\"equivalent\" of ",
  StyleBox["ShowBasisPosition", "MR"],
  " is ",
  StyleBox["ShowBasisPosition2D", "MR"],
  ", which shows how an approximation space ",
  Cell[BoxData[
      \(TraditionalForm\`V\_j\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " is split into detail spaces and an approximation space of a \
lower\[Hyphen]resolution level."
}], "Text",
  CellTags->{"S2.2.1", "1.11"}],

Cell[TextData[{
  "This shows how different matrices are joined together, or how the original \
approximation space is split into various subspaces. Note that the matrices \
are arranged from left to right and from bottom to top, so the first element \
of ",
  StyleBox["wtdata", "MR"],
  " is at the lower\[Hyphen]left corner of the diagram and the last element \
at the upper\[Hyphen]right corner."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.12"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition2D[wtdata, AspectRatio -> Automatic]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.14286 .02381 m
.14286 .2619 L
s
.2619 .02381 m
.2619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.02381 .14286 m
.2619 .14286 L
s
.02381 .2619 m
.5 .2619 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .02381 m
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "This function uses ",
  StyleBox["ListDensityPlot", "MR"],
  " to plot the wavelet coefficients. Note that the residual trend is \
normalized differently from details to make the plot more discernible."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.13"}],

Cell[CellGroupData[{

Cell["PlotCoefficients2D[wtdata]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20982 -0.0125 -6 -9 ]
[.20982 -0.0125 6 0 ]
[.39583 -0.0125 -9 -9 ]
[.39583 -0.0125 9 0 ]
[.58185 -0.0125 -9 -9 ]
[.58185 -0.0125 9 0 ]
[.76786 -0.0125 -9 -9 ]
[.76786 -0.0125 9 0 ]
[.95387 -0.0125 -9 -9 ]
[.95387 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .20982 -12 -4.5 ]
[-0.0125 .20982 0 4.5 ]
[-0.0125 .39583 -18 -4.5 ]
[-0.0125 .39583 0 4.5 ]
[-0.0125 .58185 -18 -4.5 ]
[-0.0125 .58185 0 4.5 ]
[-0.0125 .76786 -18 -4.5 ]
[-0.0125 .76786 0 4.5 ]
[-0.0125 .95387 -18 -4.5 ]
[-0.0125 .95387 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20982 0 m
.20982 .00625 L
s
[(50)] .20982 -0.0125 0 1 Mshowa
.39583 0 m
.39583 .00625 L
s
[(100)] .39583 -0.0125 0 1 Mshowa
.58185 0 m
.58185 .00625 L
s
[(150)] .58185 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(200)] .76786 -0.0125 0 1 Mshowa
.95387 0 m
.95387 .00625 L
s
[(250)] .95387 -0.0125 0 1 Mshowa
.125 Mabswid
.06101 0 m
.06101 .00375 L
s
.09821 0 m
.09821 .00375 L
s
.13542 0 m
.13542 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.24702 0 m
.24702 .00375 L
s
.28423 0 m
.28423 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35863 0 m
.35863 .00375 L
s
.43304 0 m
.43304 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.50744 0 m
.50744 .00375 L
s
.54464 0 m
.54464 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.69345 0 m
.69345 .00375 L
s
.73065 0 m
.73065 .00375 L
s
.80506 0 m
.80506 .00375 L
s
.84226 0 m
.84226 .00375 L
s
.87946 0 m
.87946 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.99107 0 m
.99107 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .20982 m
.00625 .20982 L
s
[(50)] -0.0125 .20982 1 0 Mshowa
0 .39583 m
.00625 .39583 L
s
[(100)] -0.0125 .39583 1 0 Mshowa
0 .58185 m
.00625 .58185 L
s
[(150)] -0.0125 .58185 1 0 Mshowa
0 .76786 m
.00625 .76786 L
s
[(200)] -0.0125 .76786 1 0 Mshowa
0 .95387 m
.00625 .95387 L
s
[(250)] -0.0125 .95387 1 0 Mshowa
.125 Mabswid
0 .06101 m
.00375 .06101 L
s
0 .09821 m
.00375 .09821 L
s
0 .13542 m
.00375 .13542 L
s
0 .17262 m
.00375 .17262 L
s
0 .24702 m
.00375 .24702 L
s
0 .28423 m
.00375 .28423 L
s
0 .32143 m
.00375 .32143 L
s
0 .35863 m
.00375 .35863 L
s
0 .43304 m
.00375 .43304 L
s
0 .47024 m
.00375 .47024 L
s
0 .50744 m
.00375 .50744 L
s
0 .54464 m
.00375 .54464 L
s
0 .61905 m
.00375 .61905 L
s
0 .65625 m
.00375 .65625 L
s
0 .69345 m
.00375 .69345 L
s
0 .73065 m
.00375 .73065 L
s
0 .80506 m
.00375 .80506 L
s
0 .84226 m
.00375 .84226 L
s
0 .87946 m
.00375 .87946 L
s
0 .91667 m
.00375 .91667 L
s
0 .99107 m
.00375 .99107 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.20982 .99375 m
.20982 1 L
s
.39583 .99375 m
.39583 1 L
s
.58185 .99375 m
.58185 1 L
s
.76786 .99375 m
.76786 1 L
s
.95387 .99375 m
.95387 1 L
s
.125 Mabswid
.06101 .99625 m
.06101 1 L
s
.09821 .99625 m
.09821 1 L
s
.13542 .99625 m
.13542 1 L
s
.17262 .99625 m
.17262 1 L
s
.24702 .99625 m
.24702 1 L
s
.28423 .99625 m
.28423 1 L
s
.32143 .99625 m
.32143 1 L
s
.35863 .99625 m
.35863 1 L
s
.43304 .99625 m
.43304 1 L
s
.47024 .99625 m
.47024 1 L
s
.50744 .99625 m
.50744 1 L
s
.54464 .99625 m
.54464 1 L
s
.61905 .99625 m
.61905 1 L
s
.65625 .99625 m
.65625 1 L
s
.69345 .99625 m
.69345 1 L
s
.73065 .99625 m
.73065 1 L
s
.80506 .99625 m
.80506 1 L
s
.84226 .99625 m
.84226 1 L
s
.87946 .99625 m
.87946 1 L
s
.91667 .99625 m
.91667 1 L
s
.99107 .99625 m
.99107 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .20982 m
1 .20982 L
s
.99375 .39583 m
1 .39583 L
s
.99375 .58185 m
1 .58185 L
s
.99375 .76786 m
1 .76786 L
s
.99375 .95387 m
1 .95387 L
s
.125 Mabswid
.99625 .06101 m
1 .06101 L
s
.99625 .09821 m
1 .09821 L
s
.99625 .13542 m
1 .13542 L
s
.99625 .17262 m
1 .17262 L
s
.99625 .24702 m
1 .24702 L
s
.99625 .28423 m
1 .28423 L
s
.99625 .32143 m
1 .32143 L
s
.99625 .35863 m
1 .35863 L
s
.99625 .43304 m
1 .43304 L
s
.99625 .47024 m
1 .47024 L
s
.99625 .50744 m
1 .50744 L
s
.99625 .54464 m
1 .54464 L
s
.99625 .61905 m
1 .61905 L
s
.99625 .65625 m
1 .65625 L
s
.99625 .69345 m
1 .69345 L
s
.99625 .73065 m
1 .73065 L
s
.99625 .80506 m
1 .80506 L
s
.99625 .84226 m
1 .84226 L
s
.99625 .87946 m
1 .87946 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .99107 m
1 .99107 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000FF00FB96138EA37A30FF21FF5F8100
0000FFFF00FF275FA0FF994E828400FFFFFF229D8D949098
B17B5076B8F29B7A677F8B72859D883F9B97758597888771
8B7D84817900FFFFFF7B86678F98A87A889F764A907C8880
9D8765619D847E00312D574FAE7F5F6BA2A241AA81795C85
7745DB7E889B816C7DC15C6C638C6F7D8F6665BFAE937F7D
7BA8A36E7AB38A6E778F7C80807F826C759794616C755B82
7F80807F7F80816F64847D641C304C59547A548439528B81
7362856E638483687E8451827B9B52857E7E7F7B598D7D81
738D7B85747F758F6B684A75834F6759
000000000000000000000000000000000000000000000000
0000000000000000FF00FF009CB9637F25B1006200FF00FF
FFFF00FFFF58FF0000CA559A1F00FF004600FF9736348D80
3E5C70837D4F737D6D636B85B06077AB6E886D71826A666F
6C650000FFFF000000B58F4D4D4D507F57E9889272739F69
6E7D6969753B94FF2508E87BC1A6D99A7185777E92728C5F
B2917C934597A7736E6D90C06C8C8679A272369AA874817D
AEA77F749E8C70A07C77727D7E7D82747B82889380677687
867F7E86897F80766E814CC8FFFFE6FFFFAE4EEB9DA47EA7
6EA17B919C837F838984AB7B8489A87B9BAD7A7E94758586
90658A968B5C8A817569818C946D5850
000000000000000000000000000000000000000000000000
0000000000000000FFFFFF56FF502744B20000FF9400FF00
00FFFFFF7BAAD1E771000800FFFF00FFDDFF00BEFF442FFF
31819A898B9A8096A07E94826F96EA6F393489557D784B00
0000FFFF0000FFCBFF4371C0A4F0FFCF5463948C8F878161
73C2AC1654FF8900788A02967E99A079A26AE4717E90AB72
7043C68CA481867F82837A788286A96EAF715693C6BE7A7C
72AF7364BDE1A98366668B9E89947F81807B7C7188898F7E
907D8F83867F807D5C20FF00000000000034A25A98817445
7080807B835881805A37788E7D9F937C7B7B827C9E7F907D
977E8696946D927F94A179A0774BFFFF
000000000000000000000000000000000000000000000000
0000000000000000040952007800FF8000FFFF00FFFFFFFF
FFCA374C8E6797E6FF00FFFF0077FFFF7771722100FFF700
CCA3528C8F8484806363735EC0BD6B641C7200802215FFFF
00000095FFA700B500EA78AC5B6B909FBF87AA7C7F7F8393
9200C641FF0073FF8479C731A5B2278B59877480D26D6689
A2777B40547586897E97AE7C80848183676C459B69C98088
CE86679ECF7188B4AC8C7789696E50827F8B837E62866F79
7B788B7370753427FFFF00E4FFBDA95D0012378930A8686D
87917981754682787DB8C258308666848A7F80807E7E8C83
848F89807F847A8F74897D6346BB223D
00000000000000000000000000FFFF000000000000000000
00000000000000000000DCC800570000FF00FFFF000000FF
4DFFBF009A886A84FFFF00002E880700375BD4D6DC00EAC0
19A4E57373856478784C4BDA644F002FFFFF0000FFFF20FF
FFFF000016D975BA58888DA0BC9EAE94AA86AC968E7B8C76
4FFFDAFF00E0A84B626456960095AF7E6F9C9DA056986D84
5D9B943E6678848875E0A57A81807F81546C8F409E84AEC8
946A5DA19E96BD7DCA738C8869AF987D8082657F808D878A
97917575006AFFFF0039FFFFC7C0AA71912557825BC3BE9F
FF9FE965667690A0775B7867A28D7983A0AC798080827994
8391878D73A1AA739070863AD803AAA3
000000000000000000FF0000FFFFFFFF0000000000000000
0000000000000000FFFF40FFE38CFFFF0000FF0018FFFFFF
000000FF4EC5A600FF00FFC2FFFF25BB649B96B181E51B22
FFDA1DA8826F92859A897F747900FF000000FFFF00000000
000061FFFF5089D4A086518E78848926726F5C6F7B5A7200
FFFF0000FFA1564F4E4A69889B9D31C88B58879DD975B063
87958F92A692767882757C836B67789D9E6A945C4A807D9A
9141C0A1708677994C9A9A91897E697F848D9F6F6E6B4E21
0500069FFFD9000014548978167FC19CFFFF9E975F9478DA
64779FC8707CA36269598C5186798B517F7A8180817E8DA1
606A83C0814AA1938A1DAFCE3DC97E5B
0000000000000000FFFF21FF00FFFF000000000000000000
00000000000000007801FF7AFFFFFF00FF360000FF000000
00280000FF6F85D300FF4FFF006DFF0F00133C03A85824E7
0000FF4D1A87818497AE0000FF0000FFFFFF0000FFFFFFCA
638CC6A00B9E916C69778B8782838D7B54CBFFA34914DEFF
0000FF8181689EB967609DA8798CB320D9B3A2928132518C
87635C7A8589968D7C857F80866A86608C75B37D6A60786A
5AA27B958ABB7F96718F6181A69A919B7A78786A4C85BDFF
FFFFFF000094FFA95CA469981F648D76019EDBBE71858489
89807ED3C1E55294AB85A26F7C8B8E7B728480776F85988C
83D96B60C2A0745131FF2B519F919A9A
000000000000000000FFFFFF000000000000000000000000
00000000000000007F2F008E247F3C53FF0000FF0000FFFF
FFCEFFFF359400009C3800C915E02436E1BBAEFF7377C792
79FF00DFFF78B030C878FFFF0000FF00FF008C5000000043
A8645023B38BA47C7B817F98759191E705000000FFFF0000
FFF07739639660BD635F826766948D91007C50867CC09854
A25B9C71AE7E7E79887D905C70837F857E7A9B71332E7399
82A8855C8383828982709063214945987F6D74BBA4761300
000000CDFFCB7A8ADE487D74A63DA945957F9B74779C2B29
6493B4A47B909AA3ADA88F98767A807F8280817F8A69AE78
9C52CE75628249FF93009D768151A8B9
000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000057FFFFFFFFFFFF3E009AC74000530000
00000002C57EE66CFF3900F7E959FAFF7CADB686E8897F9D
685AAC8000FFFF7D00FF0000FFE100FF7C95ACA1FFBE7862
79BEA68F7E96AC857A8B85587C749893FFFFFFFF003EE95E
59495A3A6D5D6A6575757CA4659C8A84AC00A6BF788BF384
32C863636A7D7E839961958E7D74807F919E6FDA77398780
A3A76A7B6BA64D743B337CFFFFFF734A8788A53E00699BF6
FFFF6E0099C5F7CF7187829E927E54E367225A675D91615B
857E847D855C657BA68D848EB66361857D8080808291956D
5C9E82778D61B1004EAE896B718CA592
000000000000000000FFFFFFFFFFFFFF0000000000000000
0000000000000000A20086FFFFFF002CFF00569CFFFFFFFF
FFFFFFFF56CC1FFF0047531FB5EA37006E6640734E886775
66992F729BA70000AAD3FFFF9700FF001F8F533500FFFFCD
DF898F9E8A35064384A07B8767C8657E00950024FF8F65DD
9F8DB3B0C1816D8D3F3D5F91868747918297320CDB8C33C5
9B5FACA8A583A4806889948E7A929272697A65A38B1E8248
52A28F646C7462FFFFD8A20000B81BA0C7AE787693C4C890
5A8498BAFF9B0000786D82C555658286955C80819FA08383
848FA19871826579648C5672756B7D7C91807E74808577B1
A680FFA128CDA787957F8E8C93957563
000000000000000000FFFFFFFFFFFF000000000000000000
0000000000000000FF000000000000FF9BFFB67900FF0024
0027006FFF359E00FFCF93AD42008A00B3C37B9F81468C9A
9B83D3F7FEB5EBFF7600000000FF00EC95FFFF7BFF000000
000F435785B6E0869CAB8689947DADADFF00CBCC95FF6A00
90797E74A4717D6C8C8D876B416E5993B67F95B72FB2CC48
DFAC8B5F96889B6C968285676C82728C9270458DC37375B4
88A3752B33FFC9192206004EFF8CFFF67FB0D37A1A050000
00127F676D6CECDB80437BB29FD182526799817E81717276
807B8F886184AF5552897967838D8881817E968A8C909399
65430000CC0040A871AC926A7E837C6C
000000000000000000FFFFFFFFFFFF000000000000000000
0000000000000000006771BABEFFD3000D00FFFFFF00FF00
A400FF320063887E0CFA00FFDCFFBBFF8488B47D459BA6C6
8D48200000716D3B00FFFF97FF00D5D04D00A6FFFFFFFFFF
FFFFFF61634D77948267559F588A0022008A58B46F5D57A3
A6A68C986A83DAC77B789AADCA868D9290747D9B898800E1
595E9FA56FD6B97B6E90A8728A868B78738E53B9687D9793
877833E8FF28016DD5A1A49ABDDA3E32000000ADFFFFFFFF
FFF3F6A0A4496466A589935A618496A9688F67837E918877
8757A05F6791617F927B6493C26CA87E8B80776C6F897055
D6FF008F909687613093777A7E899C9A
0000000000000000FFFFFFFFFFFFFF000000000000000000
0000000000000000FF85FFD0FF65FFF0FFFFFF8C00FF00FF
0CEC0000FFC7808D7052FF004D00935A06363B80A35B3B2E
6C8892C0B189A497FF70001B0077AB71A000C17900FF0000
995D60A4AE9547C0B18B9ADCB665FF75F3BF9E3F3A7669BB
6D12753CC5906F958D92688D9085A761729A50A49674735F
33E984AE838651826D76926F887F7D737A748E64998CA580
8B9CFF00005D7EFFD8339FFF770012FFFFFFFFD059625B77
73604988B39F853B1C5E7AA0AF73636387868C89939B6C8B
9088AD8E7C73904ABBC033806C7A887F7D7E7C8A994293FF
122673A09B726A719E55648E7686ABBD
0000000000000000FFFFFFFF00FFFFFF0000000000000000
000000000000000000E3E47A000000D900FF0000FF000000
63FFFFFFBEFF4E5E4E855370FFFF2C00C2CCD2E5D68C97F0
D394615A8A83711BF633FFB224FFC2A6B2FF230000000000
003C604089004F59867C74D6409100FFAC5264C759887055
94FF8CE7A46657206A668F806C878F8679F3703F9E8379A4
AE3900668875C0848F584897847E8A8C7737B4946B806234
F49A00FFFFEBFF3E9FBE942E63A1B1601508615BAD7D3967
5E5E60774D668695889C90837980838483809A6395888882
847C837F6E7C7878787286846D9A6F7D8D737A4890FF2400
A3997F5B5F8864AA7A8F928289827F77
000000000000000000FFFF000000FFFF0000000000000000
0000000000000000FFFFB6B4BA36FFA3FF000000000000FF
B30000000042BB88A18A0000FF0091CC424A66175D544F49
9D93F0B6BE8B798500FF0000BF5B8D88000000FFFFFFFFFF
FFFFFFFF79FF956392707E836DFDCE514FC4954A717496FF
DC5D476969A571EA9EA376865AAF808576955A827155868A
AD8EC66D54F5A19A98DD9E63768193BDB47D3592010065E5
60DF8E00E2FF66E266A32959BE6A6A8C86887F8660766F83
839E7E828867546A8272977A6D817D807F8C89819C90886B
7D89A392417997C6F2D88243AC52848E745699FF00008EC9
7694B9B0A97D9486597856588D69A0AC
000000000000000000FFFFFF00007A950000000000000000
0000000000000000007DFF99FF50AFFF9670FFFFFFFF1C00
1378FFFFFF2E66008C7D81FF00FF4F66B7D6B7CB8C7DADC3
7833587A003F3CB9C626FFC2AF71C682628B6000000000FF
6000714E5F5DA09D74698B7D96087787A2844AB9869E6F56
00D5D5B6635A28096261675E8B5D8A71848A5274825A536A
479EAB66BE00BFA25328927B95662F5FC7AB7348FFFFFB7A
0000DFFF9A00BA78C94CA5B95F619E8582778D7A79906B53
89A4877B807F868A8265A490817B8A765C977472738198A0
5D61818982A3A56A45538263ACB4402AFFFF000DA6B271B8
5B64565550567980A0919F635E628165
00000000000000000000FFFFFFFFFFFF0000000000000000
0000000000000000AC5424000097000000FF560000000000
B7FF5A3597886FA089895700CB00000000025C6DB7B75E9D
DFFFB3A8E8DB7C222E7A00A65DA3260D677760FFFFE1FF00
5FD579A1BE7B8C9456267D8673D89E91439DC79C849A56BA
FF8584A0AADFC88FB8BD8C88918A7398A5637B6A947A698A
A5CE92A739B78B00DEF877642CAF756237713EAD4362D243
FFD4AF0254A851876C69597A6B5391928A99BAB661505F8E
7C9E6A8E708C77898D7C868781908093897281828284928A
748B4CA09B55869D828E77481E6FFFE50014E8716871653E
AB77724E5279A0679A707D8883879A83
00000000000000000000FFFFFFFFFFFF0000000000000000
0000000000000000FFFFFFFFFF00FFFFFF00FDFFFFFFFFFF
4A505E00D3A69196918E7F9850DDFFFFC8F6C5B75B89B9B1
C1574F66594A5ECE6D8A6063779A7B969793A6B8FFEEB25C
3840718251A86A6CA17D987B8485BFFFFF5E5D84645FC32D
31A07DCB785043635F60688DA1806760BE9B7B8FA08570AA
5C7C716B7F437CB38E3200FFD39B955FA182DF13728100FF
AEAB00E70000E86F419A818986739964635F76788AA8697D
807DA7936E699D78768B9D907F7D8B9C6C7B897D7F866F99
978991825B92E1BD728C7F48FF3C005CA87D4191EA53609D
866B757389754C437A96C84E70845F52
000000000000000000FFFFFFFFFFFFDA0000000000000000
0000000000000000472B26FFAFFFFF1700FF281BD1821279
64FAD8FF2F7181A791966A984CFF5316241F544E92737732
07786969A3AFAFB7BFAAD87A857C4C3E61751C00000000FF
BFFFA6BCB16A8F6E7484887F7F74000000FFA8CAB2F52893
8B47A959579582A19EA090A6828B698F5374859183638D86
C39371A47244A3699FAFAE34001EFFFF6D5CFFF872A8FFB9
C3B500D000FF7D449F5A7E62838B828A77A9A57F9374DE99
695D9571579972A7815C9A6973809670618D7B887F80838E
A87B7E766D94756CB596A1900099997E8578735F7E9EA89C
8F888D95B47D78A0855568795B6BADB1
000000000000000000FFFFFFFFFFFFFF0000000000000000
00000000000000008F96FFB2962FB5FFFF00FF2F02FFFFFF
CAEFD9007068B157A07F9477DE790000FFBC4894AAA9FFFF
F2C7BACA780A002227666FAA6F80B08D87C2B7FFFFEFFF3E
454D9CB6367A6CC4736C827F7F829CD5FF00DF7A5F3AAD4B
83F4778192839E79817F8D9C6895965F687E769C27747C93
4E61826F63B270846E5D6F9995758A0026005302EFB51E77
5600F674FF007B8A69745F7E8C59756C6C95A9BB8D6F68AF
89AC858079A6A9AC91827E837A79734F7C585E8B7D806683
7181B8A76E6571801F08E6779493945E92837875A4728E68
6C78717F9E75696E92867C939F8B7B7B
00000000000000000000FFFFFFFFFFFF0000000000000000
000000000000000042E45D833B16240000FF5769FF000000
000000FFD3D6A2A3739A53A700CC9FE56B92E8828B7B0E00
508F964B79B9C9AFE1D1BA6E9A7C2AAF44BE64000000002D
9A9464764F98A962592D00A77A9E663900FF00E7D7AB57DD
7A15706D45465FC183866D99703E81A07D8474A895886F67
B0866880AB8B80A8816A8C716B9CC791FFFF8D00FFFF075F
94528EFD00FB7F65B99E8995927080927A214D87919BCA70
60787896947F8C69987B7A7E7AA77A989E938F6F70C87F8F
767B778E96B3B7A0739C10AD897F725FAD774E6EB57C98A9
8FAC717A85718F5D626FA28E6F6F979B
00000000000000000000FFFFFFFF00000000000000000000
0000000000000000FFA8FFFFBFFF00FFFFFFFFFFFFFFFFFF
FFFFFF2C82886F7A78651A00A38F726AEAB3226689A0BEB6
5248BE5DC086808E103C43777770A39B8C6EFEEE00FFFF68
45766491AE3E6965A8D3E26E877C8AB3991BFF7A764DA27E
1D70737383887F336764786B78757C8F757B877B70723F8B
8C6DAD4D96687174C181778D4E8C986F0000FF53000069FF
00D4FF00AC4F9289535A656C949E6E628FE7940906141347
7F7F3D558A6E71559D82994F4EA3907C70937E7271867B88
728FA9692F1D6C76FF39E273BF90AF6A615E746153545FA2
824084699283587C84926B6E735E6665
000000000000000000000000000000000000000000000000
0000000000000000B15576506D2CFFFF0000000000000000
00002B8B6E6E79648016FF58620000BE095EFCBAD6696863
8CABBEB180B17151FF4C59729121396C653F127AD1019875
88986E5281BF8AA69F70A9797682857D809E7526AD3C6273
7D938A792B5BD5417B7C736F866E7496C5B38DB289648043
8B866955524597718D5C45B89A6F75819186D6EA6EFFBD00
D5FF00689EB46F88698B8F77836A67456D6D72C4AB96C3CB
AAADCA9B6C95BACAAC507D8C8E9FA077819176AA9B6B7D84
8384AFB0B492A7A830B6697A97AD9497A1739D6F81928B81
564A77966D967F938096A47C8C7C3D20
000000000000000000000000000000000000000000000000
00000000000000007772AD27000000000000380011519075
51878271517E53682B00008E77149E17C7804B5D6760F28F
110055005D2A68CB4E3E8E7D838CF8DD765CAA2FB49755D1
8C536A94951E4A5E1A787574828372989E805AD46DE07169
78C890AB8A7236749A999A858D8A638D6B688E91837B8A6E
A7768AAA9860A0755C7A976E588974BA13A1F34EFF00E100
FF1C879C8C7BAA619A726785AE73A5A0B69C8AB0F2D17EC5
A9A26D79808695B0A27085926F8F719B7F817F836A91727C
84958C6B64B20011AFB78B9292907BA937638978A265526D
8175837C62B594897D7665A967807754
000000000000000000000000000000000000000000000000
0000000000000000FFFFC3D79CB29DFF00FFFF3A00682E75
508C4C2645666A00FFFF00FFFFFF6F71DCC894D490AA1F70
D0DA9E7B7DF8BA7357C98B9DAAD4C0FFF24A38C4349AA627
89A69596AFFF8C5AD28E7D857E7F8488957571C2415F7380
70874C69AD2DF5BB959B696F866E86838E819F72888A6D9D
68A2AA5E878EB79B8CA8C49A997790B08461740486FF00AE
9E6F987D67688EAE8A98758772846D6D4A0700294C517E6C
7D79817E7B7B876E6CC8B14D628892727C838CD26BA48930
8092707444BDF546707E818864667089B2537491ACB98C5E
9B6F5267506F6B585189828B7B64654E
000000000000000000000000000000000000000000000000
0000000000000000002F8A2164FFFD74CDFF0082FFE21E7A
789989AAFFF700FF0000FFA5E9FFFFABB1BF5F0EAE9AD584
3EA970A76A19005BDF8354AEDA7BFFFB4EFFFFC3806560B0
91847B000000008579D8916C8589806B9373907BB86AD97E
3A71B6AF4D734B3B817F92A67B95816F8A897463B0B9B18B
9C6E8E86899D6B8E8F4F917D705C6D7FD07F691381FFD5FF
357E7284976F6D489A726DB5A9CBC062D7FFFFBC759C6DA4
9D6E808080847D7F816940AA84628E7E897B8269B1C57066
A8A17A8CFF05429C90467B648481948F8E8C5BC8AC73CDBC
AABAA96355B1A57FBDA6729D98936F88
000000000000000000000000000000000000000000000000
C5000000000000000068002A0018FFA152FF00FF0000FFFF
FF0031490090FF00FFFF008D00584569686CBF92353654A6
5E177D58D1FFA4FF52A47200000000D8FFA4000050C97A43
8064BEFFFFFBFFA4912B726689607C8033817541619A5ED1
DB806A2D868E95936C6D679C88979A52A09B9C8E9889CA66
95887090773465856A5E7671A06BA37A6799337226A0901E
7C95916264537C7C39872900000000F487000082979E98AF
9A83787EA77AAC469E7B86864254774977A37E8391768FBB
784C9D2600808D986A676B5988A66682806E8E6A7B516D81
6E6E92737F77856A2CA6854363778694
0000000000000000000000000000000000000000000000FF
00000000000000001891EA5A00008B5715FF0000FFFFFF00
0085FFFFFF00000090001000000000006E674A47BBF8FF6B
B48C71AB0000876B0BFFB8FFFFFF12610000FFFFCB382867
816D94FF000021DDEA7C4485777485659E8789796C46DA04
7E91C9AF8685D8E7B7B6B379888B8B876D9777898E87A967
5457A49E84898182A0C47E866D8EAD907CB0AEB7B9FF4F98
A2796EC2A570808E83BDFFFFFFFF53000031682752002E94
55564D776C778EAE8B9AA48E727D7A917CAF78827DAFAD9C
926C917ADEAE6E81A68E6E7F7AA68C8581887A96896188AC
868C969D76A58D96B67A7E9C6B859C83
0000000000000000000000FF670000000000000000FFFF00
00000000000000000000000000000000000000FF000000FF
FFFFFFFF00FFFF0000FFFFFFFFFFFFFF82B48ED285002BA9
A8837DA0D5EC7A00F6005A5500FFFFFFFFFF0000677DBB61
418E2000E2FFFFF1885D7B6CC668727E7B8C82677AE78185
61876F899EA1C06D878492707B5A6068795684689E6DC884
45727F9EA6A46E866D667B8B796689987D7AA753D9C04396
7E735774805F798E86512E000078ECFFFFFFCFAEC7BDBFC0
AC647B7EBC81B2863670775C908479789E8B8781807E5C89
8E7B49487676808B8E59A1687D69A085747E6486937B9F7C
6A5E917792895E7385949095834A96AF
00000000000000000000000025FFFF000000000096000000
0000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5A1DFFFFFFFF000000000000000000005A51A9A0CBEC5483
6B698F544B3AC3FF3DFF0A220000000000000000E2815CB5
92429B4F060000002BA79071656D738D75858F80B200BCE0
95C97BA776BF093B9EA09270987A888083799AAC637779AA
6C967785B7695E4A9E6F8C888286976D765E91A500C36781
96A19B9997838D82768B49796D2909ABB23E474A8D92484D
66A8A49E387D6E6A76998E95615B6A667545AA7D7F857181
8087D4DDAA7C675D76A77B96836693586FA9929FB47B7C65
B391AD8F928E88867699B9888392607C
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000000000000000005C
5C0AE7FFFFFFFFFFFFFFFFFFFFFFFFFF596028A44F49FDB7
7B5179979E8E00009807CAFFFFFFFFFFFFFFFFFFC3735D8F
8B94FFF8FFFFFFFFE1AA6C6F80866DB2968B969297F5FF00
D36DB79D8A61E85D8A898B96B48B72AB958E82A48F657869
9C6092927F9B7A6C707B99467B7571AE786E72ABEC00CD93
65847F868997A26381BE907D7995690724F5CD966DF4F7A9
825F546175608389468E8678859099A59EB3816F82808181
7F852F59628381A4B2709D7F6EA4AD7288877D845F7E6881
46A79986727E8671858378738D80898A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFAAFFFFFFFFFFFFFFE1A032FFFF64
0014611AD93D45BCA6180000F01F85730E7CEF70C9A91D66
738715524B27FF9E647B560000001B0000000000314B5124
512A00002C0D182C835A55898C7887698B988686815C76FF
70A494959AEE4B74625E795EA36B54908C457E628BAFA56D
8C76735A5B9A556E5B4F97678FA68F7A818F827C6DFF8782
854F70799C8A925E80907E8E8C8594A268002F40573D0F54
7B8AA2912E767A87746B70AC6C70955C9B637A9A7F808080
827ABA69787D3F6093A176856B809E989A947D867EA38C6B
617D74A4A57E786B8276ADAB655A4453
00FFFF0000FF3FFF008C001AFF4E6B84821CFF0EA8666D7E
9900C8B353C82966FFCC00FFA0667BA97CFF5D00D7956064
30FF00FF00D59F8C00B36182732BE300532F0953347EE783
A7EAFF82F1429376FF739F98C36300169DCBB692AB6DA2C4
BB77969F409C9D3F789681846E9C7A7D698A7A8A7E8E4C5E
5AA29021AD9344BF989C78577860689E72A07A705182877D
6C6659738B8A8684736D8B4893768265889E8B69545A8874
658185757598455B8F78669579A88A61A9AF87B0939F713F
7E7189647085898967848473636C6D6F7C6A846484808080
807F88A466A5717787497A5A697C6771887B696D93927262
705A8F48406F574F9A9088927C728C99
00FF002A00FF6CFF00FF00FF4595428DEAFF00FF97195DA3
1A918A896300FF0000FFA0FF0AB67E68B60000DD0000FFFF
00FFC800FF5E1E7786A5823DB9FF0033EBBEA29D74555C9B
742A18984A00282F006FFF8F6FA7F6D07247A9847C6B3761
65AD7A6F7DB9829E6B7D7D846444667B91797B77A5889959
C2562ACF604D92C24A4C53916D5E85507F928D82A6777E7E
877978A28A71837CBFA6965A764D7674738D8D84C4729789
96937369748665988A8E476B8A708D866372AB6978797880
8A8C6A6D5C7E7675718A62778C757A708C7158887F808080
80807B668B8770687752A05E939A955E887CB688A3848180
8C656A8D93638F8D99A87EEA818B8983
C2FFFFFF179F2FFF00FF5EB300887DFF1D00FF09006C1968
2880AC2C00FF00FF8D00FF62FF01B09D5586FF00FF00FFFF
00CD08FF0097455237421EFF00FF00C522516C90A5B0AA52
94E7B6B0FFBFA6517FFF629782867B70B69F90C5A66ED98A
915C9067799CA478546B7065838C9384868F9178839B738C
68EEF9098FFFDD5E94977E6AAA9382577B6981766B8D8686
8084587F968C925679B6554638C77B7689A08BAF6B857666
847C9D9B609C7A77787E93B09E656C7B95858C9179AA7F72
969FBB857E96856E8F8A7369865342819A5A55847F808080
80807E756E747663B6796E669070639981846499789E6D51
746A7F4E5DA462948B546D6F47757D64
00FF00A600FF34F000462600FF6B5ABD3084FF00FF6D97BE
9B009CFF0073FFFF5DEE6B22D7009FFFFF00FFFF00FF00AF
DD20C05DAF98734B95FF00FF00FF0090A988EBD598192AB1
5D4C47194754D1D6FF00876DADA3DFBA6BA181577E707290
91A287885A6377978290857986B07690868D6F8C94737E6D
4B3200AC595621AB8586808C837FB665678E61966E57886A
9F79A7785A6F8295779B8B8EB84C5E7778788F687076B07C
896C66708F848590AD7D88586E6C6580AAAD8D975A475C7C
808E96AB59886DA08D8A464C797F8D6E839978617B818080
80817D90738CA089757D6D9E7C888F94A0847A8D7A6D8E71
89B8BE835166869D8F814AA59BD04F4F
00FF0078EA006DFFFF0000FF007F00FF8D0097BE6C858E68
FFFFFF00FF9697FF718E21A8DF00FF00FFFFFF0042000053
D3228F56719856F900FFE67DFF72AA619A76493C9CD4703C
6385B0DFA66848953871CA7D7F6AA2A3708C927B77675085
9581C3884F8C6278888E6EA694946087785F7078837F736C
7BA8F49D7C829BEE6F6D7A6E5765556686A37F72898C7658
5E74517E5D57925A877786608F9E6869486B9C6D606F6E86
8B826D968B948974798A5E7A9E7B93461407132F00A4857E
91BD452981665B764C74787E98739675546D568073828080
8080808158250071B597649368C28677B88E747465614F4F
8F8888616A7A857982847C863C7C584B
FFC000A000FF00FFFF3493FF00FF00FFFF00FF1A6889C1FF
00FFFF0023FF34FF47E8AE44FF50FF00FFFF0000FFFF00FF
00870EFF00660000FF00B3573F88426C1855A1FFA78FFF69
23738C8684B87989007F4967469167433F4B505B81868FA4
8E85944D9C8EB1B7A48B867B919F817E6A72806B7E5E6B68
2EA095E057A97EC7A9AF7B797E8EAF667679776BAB6C7083
4392878D82976D6C7F9B85A58BB2958E9B97B8748786A483
7E7E6F688B9C816B6A8282928357054361A9BEC9F6AC6368
79899D9DA3979BA7928E936F9D8278698D809B7C82808080
8080827DADFFFFED00DBA3977F646F697684763AE3828D69
7C616C698686976A7C8E69968F708C91
978D00C400FF00FF005A000000FFFF00FF00FFFF544306FF
00FF55FF550FFF985787E80B8CF89DFFFF00FFFF00FFFFD9
0ECFFF00C67374FF2BFF2BFFCEB95D8D35504E03629B3B78
F1A192D5DD47C488FF0000897C90AE9A97A7D3CEAB65933C
70806391297F94B366B9808E6778C06877808E7E94819478
CBA9083A5890B6634D4A6C909F71B0477C6CA891776C4957
7F7557817B6F716C907874575D76A5AF96877E5A79837A87
8C928C99919480887987617A85D1FFFFFFDB82797B87779C
727E5B7B698C786F6C95908B8C9578967DA7947B7F808080
80808084699A5965FF36B1815D488F98C6B075747B87716E
B384977C6FAD7F83907397BA83798DA2
FFFF00450450FF00FFFF0000FF0000FFBD5200FFFF00FF00
FFFF00FFFFDF568299CC47CE671CE64700FF2500FFFF0000
FF5B00C247B2FF0B7F1DFF5659C7926DD79FB6DC7B639CE2
3EA7A37347A631EAA1FFFF5FB80F2A46695E7E7977A32F51
7545754777754901A06768A45D5E44555D6E75745B897EB0
522DDBCC931E598C85877A72728EA4796E8490A27B867982
6985938C829C8B53A5A679969393638E7E8C5597748E817B
6A846C7D7199777F91947B998C8C6500007192617091818A
163D6F81838B9FA05A8A6FA1726A81714B968B8880808080
807F85807B7C53654ACC33A29492906782585C76A499A270
929C8D796F4DBD9D889DB5928179A9BB
C2FF001300FF6677FF00D5FFFF002600FFFF00FFFF00FF9B
FF77C4FF00FF59A2BD1E6A9AFF8800B5FF00BD6B0900FFFF
005FB45CAF7C00545BFB9501FF4483656370646A7A4B7451
54689488C8FF4780FF617A9A20FFFFE9B4DFDAD9FFE4B5C3
B1C4A6E16173EFA2A698456A818B6D829C827B73CE6E7DC9
000070759FAEE05C9C9D967B5C67A68C5D7B62A06F691C69
7975706D8390938DA983BDAC937F7D786F9076667C827087
6B878D749F848A84698E678F846E4A528A8D68486E84718E
9E64838A649353766A5B436A6E938BAC797159A07F808080
7F846281817EA0958B66DF1A6CA4805479B2686A8272678F
91737B855B81718D86A88D825E8CDDFF
FFFFFF3A0057FF5BFF00DD00FF00004600FF00F3BF00FF00
0035DBFF00FF00FF0EE0FF004F277CFF5116C8690073FF00
E26177A3627DFF00FF00E5B311FF1EF0074179B37F744757
B5144AD400DC7CFF00005886CD4B00A2B66A000000000000
0000473D216D7BA59E66758D7E7780807467806E967D4FDD
D975575F4095878637373E6C9CA66975B3695A77659C45A0
678A7F969D637673706B76747B5CA56D6F6B928889A07C85
7F7F8B7F747A786A8D6593976F8383859C43807E7AAD537C
89817C87A18A7D5C62605D867D83726696636C0083858080
7F826E8182857EA9695744F9659F65968F73766A89886E8E
6371826A7C7D7D6F8C5C80695F863B4B
FF8EFF000062DA00FF0000FFFF0000FF000F0000FF7A00E4
E200D8FFE74F42C51FCB564D5726FF0000C96644FFC300FF
00C6776B485B28F1008C574DB371C7007B701146272689B6
84827130F0BEFB83F8F53B00000000000000E8FFFFFFFFFF
FFFFE5F6F7EB56B281917D6BA667A06C7381736E6E8BD35E
3F82CE67966F64C76C679C9E597F64A07B7A59796D725A80
687A775985808B83677A61888AB55479578A954E67797378
7A8D6B92824C6C799185926D845275876E878E7CB37EA270
8F7A845B695C839B8FAA906D95B86B80808DABA871578280
80808180737160877461B64FBC5A64A891897A908C667F8E
876A8D7AAE5290A87A6E80A6A04E8297
E2ECFFFF00FF5600FF7A1CFF00FFFFFFFF009500FFFF5800
FF00FFFF85FF238CC475FF7009624BFFFF6FC26600FFFF00
E4BC19F61F768C85FFFF00C4780000688EA8CDE9CE8AA627
8594FF0000FAE9F46B9CF5FFFFFFFFFFFFFF9745000B0E38
5E5894877A5D93858FA4A08D7B8E9D858F7B98894585FD97
D450819DC6C5869C747285717D7F7B88667377607A7B7282
8C5D906B657D875C98A4969A73565B736594C2A07C778595
98ACBFB8A77987A4878D7D7869AE907080986E6C73977E94
7C8265A3808E909BA394BD8FB9C8916385867B7787917E81
81808080899660927C76B37F9E9CB597717E7F4C8758527D
876662925C6B679C8A87677F8781988F
FFFFB000FF009FFB00FF1294FF0000FF00FF00E600FF5900
00FF00FF00A900ED00FF00E700FF00EB00DE00FF0000C6EA
565CFF00FFAA737734F2FF0AE07EFFD44A3A7E733AB06857
CB9C00A95DFF003900D1450053002A3F004D3A68A8807377
508968857C997580747D839776AC90827F8473DB93D40072
6DFF649DAF5F609EEFF5B0858277A7667285A78B838458BC
949599537A935C628B565F968D4F8B7982A68F799D918B77
6D976E677F8D827E676776719B86A68E7D638166A38E6CBB
BF6C69BF9290885A8189726986828E81C3AD817EB9937D71
6784827AAD7998819B9F8B898892A0AE797974449CAB9B98
6B6D8A677F7DA6ACA178CB7753959E8B
FF9AFF126CFF00FFFFFF00FF000000FF3E77FF00FF338700
FF0000FF16992F97FFB9B53CFF00FF000000FF00FFFF0024
CD00FFFF5ECD799874BE006A48ED6E7288795674974B94B0
4600B57DD371FFFFFF0046D272306E1E8F657DA6755A6476
64758B898E5A946F705C88898E82595670364848EE00C700
000063564470788F4D477D5A8D8482AFBA70528374578B59
A18D7572854E609062864E945D719653BD7F39746D7A7C82
928A8A7F7B6C6A8892829692797E71675D487590586C6D72
B08B99A44E878E73AB58AB83B26C7A7A694A6D708D857F82
8380827BAB7F818B888C809468BC617D69A6798283917AA8
866F62A764968E60866A5A26BB656F5F
00B87A156DF700000000FFFF00FF00FFFF00D900AA6A9800
A700FF00FFFF00FF527A0055BDFF00FFFF00FF61000000BD
5AFF080037BB66677A60FF005F62646ED1F7BDCCBCE89186
FFFF8D2515FF178400FF7736D87CC4D08D98767D818EACA7
77819AA17DA28F8E90AA9D9E7AA3B699C7DEFF7E00FF7ECE
BC7A87C66C99715D9DA36A585089576E869B895D6FA69F75
9A9A66AAA58651A087889F4F668F766EA050CD9E8A807B83
A5927E9577A398937669909588578A7795A5915F8E73555F
818D4D5FAC84627DA2526B8386725BAB8FA2B7C36078817F
7F8080817B8462939D8B7D8D6A85702A98AD9B5574B47957
78A9968A6B749D7C95529D75C85E5153
52CB00FFEC4BFFFFFF00CAF9DAFF00ECFF00F505FF588AFE
8700FF00FFFF009D82FFB9A8F200FF0000DFFF06FF3CD97A
8B6CC552ED78894E884AFFFFB759EFDE5250394A8C5B6F85
633E589B62000000FF0000FF339363207B6E8391615F5379
6466786D8A68697E8578797A7071587D499A00FD97004263
3BC634398275717C8E88AD8C6BA35D9980982B5AA35D8EB7
8CA6954C4B7787979D719F5F906F5986569E4B6C79887775
789386949B80708B97739F8566849191715E6F72BCDDA66B
838677612BA26AB4485172787EA361B04875717671758280
8080808081826C93929E5D57818D7DB597879E7F8F6D838E
698E71859C736C64708D9B897A8C8161
4C009FFFFD8C00FFFF00FFFF1BAD17DEFF00FF149A9A3EA1
6A8300FF00FFFF76812D5037A6F860FFFFFF50B7328E8064
91555C4E9D788481948852006444F55A374B7D758683BFCE
D3969BB78E65BAFF00FFFF00D55E61AD5CA184749E747889
5D797E717F8A5E717D8876676CA587399300FF2BFF9196BB
46139BA07E81607D7678656F5973826C6D9D7B7CBE804E88
73965E817D5981904D758C936E866E78987BAB868D858883
896A73856C4D5E53A2909C837E818B6683877571934D5B75
785686848DC48BBF80487BA3D7A9A37484769C7476848080
808080807F929F7B799A96908685497B4C83557F5F63A57C
57848D64635A8B7F8F5A53536B71544D
FF006200FF0C4E00FF00FFFF45C10AFF3800FF01FF39926A
888D1BFF00FFFF28AD00D4253CDF00FF0030C18FCCA5B897
6835F4AE417A7084868C836F64FFD7C2658A86588C4F9548
368187688183872DFF0000FF7A00ED1F865386697C7E7065
645B7E725871666E7A73AA8E729C3A004FFF000000F300E2
89EFBA8F8E60909775718D988D9261AA74587F80AC957699
A293978A95C27168B99576687B9C86A188B4AD736F8F887C
8B7E898ABDC1C5948E6A5765989E956774948E7D8D779C89
AE877981597D8C6CCA9E79766A4167804C92417F917E8080
80808080807E7E8EDE87828C7F6DB9409A659477A0775F8D
933A716F8B7C746DA48F626C58896A74
3E0000ABFF3800EFFF00FFF85EFF00F62F4EB96AFF5DEC58
75AD3EFF0000EF3E5BFA7DA09400FF00C0FF6F4567109481
70A963657B8445A5798E7D3589CE6A1B969979805F7F6199
807B72766FA39453A5FFFF0000FF2A6BEB70727B7E5E6E69
6B9582627AA2C88858677C2FFFE8FFFFFE4832C491469EE0
5C9054504D8E5B7038326A858E7F7C6C64A573A565878264
8C6C9797C9A2748BAF726A744C718C529C60758D668E9E69
907E8B383A1100081C7E8372637080857988876F6E5ABA85
A7917D7D979BAED3AE75404F8C6561807E7591947A828380
81818080808183868E988FA08395C5886D71907F88A0915F
8A687C797962768298948AA460827369
9A00FFA01AFF00FF2D00B09366E500ED9D750DFF380CDDAA
969C0CFF0094A7656FA1189973B421FFB66EFF979AE94BFF
3278B2A45C728C6A87916CFFE47A3B6A8B5C907C80599A6B
8479706A5795C58A3DA151FFFF0027FF0000325A03688F68
40924F9A631D00006DED64DC00FAFF004B00FFA03EC96A60
9D49698FAA8482B8B7BA9A6D858C5E707F878C9691B18E53
779777869B7E9394909594995CAF6ABD729A96866369786B
818E92C8D4A5A3DFFFCD76B3FFD8906883828A8E88A67271
7B7D817C728A1B122B7169AF776F88955C967C8086746D84
7169837E807F7A479791758C7B96994C67BC61959D526A57
736D7192949691C8705B8992A29E4543
FC006CB87BFF7D00FF00FF00FF7800FFC429A4B0C2C3687C
90840AFF00B5410088CC79FFFF00D2FF006700DE4800FF00
A427CBC2415E8D9C8F647300D8CBC260509666188E827C46
2D0000350D6C2A4554C4E26300FF8F8200FFFFFF0D005A68
021FFF4B75DD06FDFC007600690000BC02FF00246342917F
7A1F3D4F2F656EA877796F77826B826D718BA3668B687457
439B88977C818EAA7174908B69738269B4505F787B679C9A
B1B3813D15000049163E8524004690A8887A8EA6948E7184
58848285ADA690DAA99F90B47E9C6D4877878664877D7580
874B71937E807B77A38D899C7775719F6681467B8CAA9184
9C6E8B67858966495E9C76A283BFA88F
FB00FF00F0FF00003BFF00FF0005D576008C1999AA6A976E
895CC0007900A7B34DF0551BFF5CFFC30000FF00FF00D25C
2E63A46B86938D7C916EEEFFBC70B7A5B6A47E664EB798B4
B9F1FF975E868C2683B500FFFF00FF00FFFF000017FF0333
E2FFA85B800089197EFF0000FFFFFFFFC3970093BF7A757A
6A78AA96AE898376696B637664B189896462885E8083587D
9777825D81616691878C91897D944D6CAA88929E98787F35
000030C6DFE9FFF7FFC08FE8FF606951795D7976785E6F7A
666F9D7265A16F7E757E90808AA744716DA897928EAD7B80
7F8689897F8279B775968A889C9EB095787FA47E76A68F98
878D7A7090958AC197628A52869B8074
8362DB00FFFF00FF00E700FF00FFAA9D818D3B6A706A888B
9F00FF00D076FF2C79765772FF2EFF00FFFF00B94FC5959B
B58F5B7FAE719B8F3DFFFF00A9546978A996907373173B22
2D4E69A5547B56D498ECFF8600FF00FF2F00FFFFEFFF397A
007100595AC200FF9B000007000000000000FF28943D72D3
748B837B8D94876A9FA193A65F74757D937C766C97887155
669B8F608EA0725F797973807C9E6D74257B70877C7E8DE0
FFDB8600008017304F79AC5B43F09BB76F768E6C9E82BA8D
75769F818A946F6D5E3E827989443BAEAA7D879281B07880
80827F7F7E7F82918083848A86817D8C71B27F7C81B58D62
6967668A86B5ADA266AD80A16A60AECE
A5B9712C00A8FFC4FF00FF009C365F7496707EA66C7B79C5
2BFF00FF39B1D37964557E8100FB00FFFF5C02C99A6E6AA4
7869B162985CC94F000000A300B0AA7B565D6B7F7BC6AC57
D8BBAF9A68468257353F6DFF8B00C60000FF403CFF539800
717C7A75D8FFFFFFFF400000FFFF00FF012649C4A278877C
91507C8B5F6F8A886F706C7A51557D7F8B64639E876593AA
A1739A9288AA877275817B8C827A588AAF9396588F83697F
948D42EC8B6ECBA06B5A1475E3758C71877496A3786B7BAE
9E728F9E7BA06D8599A7627964949B849D696E7E7CB7CD7E
87638093AAD27C898A75768B7E7C907E94709595689E8B57
9C938091A37E8B328E7E34677C578875
C56D3900BB6194FFFFFF14009B6AA68B77939181AB69FF00
FF003E67DEFB52868F7E7A908C9ACF00FF54FF459E5B8D69
9473777BA66600FF00FF4232E64DBF6F98B7A2D07D659EDA
AD40859DCDACC9797CDC9FB6C2FFFF00FF0000A9C100FFCB
9E00008E00008D00008B5DFF00FFF90CFFFF7885553C5756
063314000022000057547C806FD285925759636E54687E63
61AA889C828C7C3681756C5F98749D548B64668C91799490
6831FFDD49446A740CA6FFCD4A66A5B484798760988F8068
8A75787D687B6872C8A3B9C8BCB876AAC2AD8E9A817A7A6C
8089857E797E81848381849179897F9F76ACC4849482969A
9983758B6C90747D85AD7E9BA4748C7E
79668366DC6E00FF00A798FF028B5686A3847892A96900C7
5600FF00FF9444B6994F716D744F9FFF0000FF008FAC21F3
43636BA71800FF00FF00FFAF27B544833C24301C916E7000
0000613C000E5561934C434F139000FF0000FFAC0000FFFF
FFFFBBFFFFFFFF008AB7000000008C0040824773C890A5FD
FFFFFFFFFFFFFFFF67677497778257BA8499748BAA987498
867E7F6983A6A293706A6DA1AE5626AE93AE8A7A879E9690
5455241AB0D0FFDB8F9211387973745D6D8D72795FC8929D
5D8A9982756F8A6D487B8B8656703D477D6A406E8480856C
7586807F8FDE998F7980807B7F93927E72538A5D8DA27253
736A9588968D9D856BB777B89277707F
C559628898003DAC0000FF75CE3B69942C93C9CF00FFFF00
00FF509100FFA9BA879B38BF3CB04122FF0000FFFF7800EA
191F1AF7FF85FFFF00FFB446613F7888365D7BBE46178CA1
C96E5A0DB493233700090A2109008C0058FFFF54FFEE0000
000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFB3350000
00000000000000009B9E8698AA8F7E6D3C86B56A989B8A93
918D646E92AD7B7158624ABE766A93B25968976B88A75A7A
9E51775446332415636772A77B903D7F8D69A69D9197B369
9A9289C59F6787C78900403F91B4B3948182927969B97E79
747D9C8575767C8C987F807E5C8D7F8A7276019866708CA1
755B40795AAAB7B493B78042B0757A5F
A39CF84220FF0C27F9FF00CBFF005C000092FF9BFFFF0000
FF00842D00C4A2997A9C3350547F4C5A970000FFFF00A28C
FFFF0000007F0015FA614656D671787CFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFED00000000000000000000000000000000003DA0
A9B0FFFFFFFFFFFF61625E677A816860A1827E866C7A896D
9994B3877BAA7C7DA0847B67AD9D876F9B886C77917DAE58
68A57D637D5C745A4E5960406B3F6D6987798B919F78689B
83516F6EAA9EA54452A1949E7AA58D734D73647D687C8280
93A06D646FA2988A8175747A919EA06E9DA7C23E919DB87A
83695B8354AD495D8B986D90A5827A9A
FFDD2D00FF39269A02FFB300F2948700CCFF3EDBFF00FFFF
FFB1C73300FF6D937AA76A3B6F808B8E58D44300B7FFF56A
00FF00FF1D00DE1BFFC9DC7DA5711A440000000000000000
000000000000000000000000000000000000000000000000
000000006AC2FFFFFFFFFFFFFFFFFFFFFFFFFFF5E5CAC8D9
D0B57E40052524007574757F63738A969B3B888EC46D9A8B
7E75769B7A7F8B4C1E806ABE358C908082898A8B99536BBB
923A5138587D9CD3B6759BC7BFA2B1666D999BAA748F9C95
815EA4C6357A8B7AB0CDD7A4C4BFB6AFC07A7D807D5F8282
7E7C7C6E7B8D98805D836B68796F867C66A276D20FAE5577
679B9C6E5C8282957C7B968F9D79A5A5
723B3000FF00E7A4B200FF00C40000FF0000FF00CFAE964E
195B29FF0066FFA3C3E05C30724866B1558BFFFF00E80FFF
0700FF0044FF00008B694AFF077AFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFF97CEE4
FFFFFFFFCC8C5B45669A7D6C54695F42493568847C712F66
6B4D778D9692B09994977775A59D85AC63838A8D84949DBC
5EB4899B698579ADBBAB6284C22D7C908C9C699F62B0B6C2
B4E2FFFF9984A6A085B2A797808261949885C88D8E7C8C7A
6A90C5B8B7A0A8A43F73779DDDA56651A968A57D7C828558
8281838B59599E88908B7B918C83978867788371C07C6F93
807D7E957C8B8C5550A01E815F84401F
00C0A912FF2D00BAFFFF000088E2E80000FF00F2A58A962E
99AD00FF00FFFF002F2FFE7836B753905E64D33712D9EB1D
00FF0082B45594B45466C293729F10949B8845585FA596A2
78705A00222F564C4A4595461F42415D6D918782A786408B
4B6E3E26517A93A17E4799637871989359687B8C9B6AE987
919598928E7597C95C5C6574736A739DB1AA559C44808687
77777B6FC7B284A0700815E9B674A25CB26F7B77756C513F
735A3E27AC8377897E7C63786E5B3A796E5D62736B7E8187
6F556F8A496A616A6BB27E8D947F5972A17C6C4E9C7F7F85
7F816B607097676E798F84868B8E797A977F7A556BB07E74
718C7E6A7A515B7663407A66A06D97C2
FF3D9D0049FF00FFFF00F5FF00D25F44F330A477AE26B88D
BC0029FF00FFFF00717EAA641BC05E7E4E558DA65958969F
8D54965F8499A671836879A4685E7CB87B92805521000053
6C79536A80A299859D936065796C73525A57477C7E89985A
5346635A74777260465D617C6C8A8F6F956A6F8E4D6F6A96
B58D6EAEAAA5613A4C477D9A9DB998757C6E8D6460675476
6D8BB5418C725F9C7F929672359980C0818A9D9F8867A396
65588D90585F596E618F726F9391744E9C889D93926A3F86
8F93786A926D7D8E9777726E627E869E7D8993908D7F807E
7D99758E7B6D63858285887F7E89888783855B867E6E9B7F
964B989D4E9D7A7D848FB5AF7C7D4262
0066BF00F7FF00DAA500FE6C876880B08EA4D03FFF35C013
7A7280858986738A7D817E87806D88827265BB7A8C7F7D72
7E60FFA9808581A759978C8C99A17D99A4FF4CC94874348D
6A42757CA8B191698CB2A0886B947672768B7B6D8B817778
857D867160FF2085D57E7B8254858B8D8DA56C52818F9384
757F6A89619C5D89736F857E5A629CA2847D809879666A7A
AE6E85B38088647DDD4A7791BA9A8D6E42A3928A687A6773
868F6C90A56864797198A98E77878C967D877B8A6A765F6E
8F6C72937E887574825C767BA68F7A73859A6D7F8080807F
8473665C5E6C8D676777887F7F8367918F649474808E7C90
74B77997639EB3AE8D826B6684788A7E
00FF91FF71AA5DEAE613E283467C7EE79BCF817FDB7ABE9E
7B94798E7C5C8B8B8E87834E9DBD00B496106C879A847294
1B717AAD88B1977C8B7172608967D56600F49B6765D9A563
8486927F7D808783617C64939F9C7A8D67A19B8177757670
607375FF00FF003C6ABE6A2094685874B64F7F869195787D
6192895FA58500CB3F3A675B80908F6580B07063769586AC
AEAAA76780765B71656D4E4369666CA1A0B39898665E8B7D
7E777D897FA1A282AE8F74819F80588D7E757AB394736D8A
8E8E8F8B74719DA19D87917A6C868651699D3F8580807E97
838593618481688B828280817F7C8D7E7C7E869868887168
8B5EA9709B678E6A9BA672699E795249
FF00DCFF00FFBA4589009081A26096E7709A55FF1F958461
789C868D788B8C997E5C98A9A600FFFF00FF85678764B45A
96657C7290789589658D9E9340C3E96DA30AFF22C200CBC0
97C084786786786A82AA8740AC73C6CB6F90B5718F83A880
81FF00FFC01EADCC9B375E6DCB71A5C69E638FA073816C71
B360AC44FE00FF5A7A7C6B6B779B676A7A7194812D508397
2C825C948B9B75828C779682A567687960677D96898B8872
7D8F6944749382827372837284829667718596527065A85C
78625D5F96827A6A757C91738E6D975B78A9858080808076
53AC2E796196826B817868718F8E8887749368676A967E8B
A2959584858987915948825F7F77C4B8
9936D867FF00B6553BEB5386877C7CBE27C798A85AB1AC6C
726B83897C69722D8BC70000FAA600E44DFF27BD94628980
8FA46B2590798771B4707B5CD9FF7E987D8587FF00FF0068
DF8F676C8B88877B9B6BB4A56F978CB2AE7B638C828B9AFF
00FF55789FE0BDFC51AB8CAC555D558599808C6D7F8688A5
7A564AF700A04B889FA678958663867F839062667F9589A5
6775C3867B5568B1527E4F78395E7C737C90866B6D8CB975
9570B489728C8C788E777A758381968F8B9E73858F748279
34998B7C866C8F74764B816D82986E9EC7697D7F7E827AAF
916D8F96A3908D957F708B8D747A878B97948F997F769D7C
9899B692A38FAEA3B0B08DA56D856953
C414FF337CAF6700AABA8D5B88698FBC3EB2A64BA0405792
D96051B28A7400BA39000AB0B8E36FFFABAC92955860C97A
7B949B5D7E838FA73B9471EE00F3C56B825BABA26F20FF00
65B6AB78728E888C487CB7386D6C7EC9B300CF1900C74430
784CF200CD31F8289C78659A6876A46B8961A896828B847F
FF0082FF0099848E8C916E7397755597A573A87760736A57
63797E71797F8DB09649A38BB628BEBD69A88E7C9076897D
7B5F817B947E7B93535B7C81A27285757D8F7E749E8C7F80
6B6F869D9778849191AD5F92837A82A6795E8189907D8475
528A6A5890786C7E8980836B8C865E6F678B7B79826C8D93
8D87746A73837C689A9A5D6269866F6A
DA00FF007CAB43FF15AEFF5479816EB46A78F42F442B8587
2DB416FF084494FF665C77D2BBF400FFB2789674749D9768
978667B8828C6A3DFF00FF00DED79B749D6962938C19FF9F
06549C6868728A7F5D8A93B293AB14FFC4A500FF9A656181
77A866AB98D65B868B819A798C755B81516A78566C8647FF
00FFFF363169B96F7E7C8D837B7C478C699886867F69807B
847D4A8C577C898382795E733CBD6C758F857D818F7A827B
87856F9086838081757680797D9E8F7958769B8175766E94
60957279786B758D7E805C818C7F5D7997737D8688826185
6034446F6C8D6863827C8A7A774F7B666272908F8788687F
4958888A9772868F756B8D7E5A769D83
AB12FF0082499A5CB245556173765EB200FF68B6E300C4CF
00D3FF007B937E868084797D8B2E897A8B618B7A5E52B78F
99B633FF847674BED90077FF0FFF507DBD4F866C5A6B9916
FF7E26967B928278B3007DFF00FF0004FF00FF344189A1A9
7BD09BA35E658E7F8C6E8B826D6E869593845B867C961916
D4009A8C9696728A939D548878ADB397D85C59B66FB387A4
897660894B7B6C997661B0BBB773A78EB6457A8D89858C80
48848E48847175818B727373627C6A95955F8C7075888A60
726B7B85AF8187B49288A7A49F9386BB85B0877E7F826E80
8E92A1868D698D917D8C91848F6D855D8D7B70898383A9B4
C174B94C98847C81A67466716E88545B
9300E221E138FAC5093E74765EDD549A10FF00FF7700FF00
FF004D9B87537BDE6A6787897687847884966B8157737AAB
5FFB008745C19D00D07255AC02FF8A736F823862AC9D5562
B909FF34C81BAF9E25FF0000FF00FFEC4D206B80D066AF81
728E6E548B8B8C888E787B6A7F7D786EA7004DFF5E64D24B
67D69A94AB787782AEB0933BA39585A59C5999879C8B7372
6C8D557AB0A1A7B56A756B62886E76896BB27E827794B580
947F9E85879D85A77A7E7F7A6EC2945D6BA5748898809475
818D6C7E896B256E69696C58A9847969742B8080807F857F
7F787D9A6A7E8175678F8F7E80817A7978796E7F7E9D7451
928A78A6A67443757C908D676B5E6768
B500FB037D4CFF6500FF001A9CA97AFF00FF000000C900FF
00FF582DF040A0FF559175567FA8848F7484A086759EA68E
A100FF94807B8D4939896AD100A1A66892475CC96566A278
A8A05DC0D413FF51D100B1FF00FF8700798A8DA152883973
8874D5C77988A294788E717D6B9FB65561FF00ED2D7E5BA8
767DA7758472927D44482E7160585EB36B8275948B6E9DA8
938E9C7D8684909092A3858D298FA2B85C69AB896773679A
6A868176838576876A637C639F748F8C8A5E72948B7E8575
61B87F777B55878B8971AB888B91867B6854447F8084647B
B7B97F636D8C4F9F737973837E8491729773689361887AB8
9D837A61918170487698819FA1A08072
641CC2118CAFECCE00FF00FF6D7D00FF00FF00FFFF00FF00
94FF684D697268E1359978A1A593549769868A867D593781
A40A8757C1B4AE00FF00AA5D19DF288B7B695F5D5C9A803D
5D5C736A8F7ABA00FF0000FF0FFF00BE538271A8927DFFA9
827F6A70B28B743B6A7B9868A46B8369FF003A86BA395A84
63997F909143BA7A8988847B68AD6698627468444A466B68
7883637A82966F867B86727CCFAB3D517D907E95904A8689
7A8B738D8884A5A68D8E9782538F795D8288884C9774AB93
5B89895EA3867EA3767CBE89917E7D6C6C6D657581826E84
936677697670797C7E7B8F887C6A768A789866757372877C
69B2A186896C4D688B7571749F8A9767
A22ED010FF00FFDB00C400FC2E96CB00FF45FF009DFF00D0
00FF00FF51CD00D1C369BC0CA876767B336FA5807F595B70
BE8D33B45EA59094A500DC48A3DE208B8F809A819EC174AA
7BDDA29C683AB8FF001BCE33FF0000818A8393AA0BDB598B
5690629050856DB6728F57B191757EFFA73590878078737C
7ECE59778A9F867B818276587F7E6D8CB267885887926B99
79B07995824374588689A1C06F857971AD8365866BAB8C6A
A7788A926254697D7886687E6770717A8D6657637C8C8357
8F88768E748D6C99956C987D7499726B7D637C80807F845A
708484A1966EA0838B9C878B87797E7C84777D8C8D7D7975
75968271A4365E726F78618F51986B54
695CB116FF00FF6D1EA564B0396800FF30004F00FF00AFFF
0098FA68F658C030CF974E8ED2B824A28F6F9CA4E4062CFF
00DCADFF23E1D8B1542EE25DFF46339185A1637A94737259
B6802C556A817C0000D400BC00727430DA4A767D9A33A49A
769BBFA6F4169650A478573F2F76E00700AC7C777E5D56D2
559D945687A6C979A4AB767BA9978C676594777B7E7C8C50
787742758853002D8B9A6356AC8B8B893386A2778D607076
747A847C9B82A278799DA2767C8D7E728A918C816B7EBF87
6B887D938079A482B786779077D3838FE993A27C807E92A2
867F93828F78869E79889F94887A848C9077778895767C8B
5FB798317B85955B94A08E7391897787
A520AE5CA556F77B7A982AE2519F00FF00FFFFD51552898C
FF00D0DC00FF283AA55D603BFF0094E23F7880AF5000FF00
FF858F7F6BBE76527900FF8171A24C9396669854AD997E56
8489B385A66C17FFFF4A00F1FF3E4FAC188C8DD4C6C74C4C
91757B6300E7446B97487BAE6EFF009B58A097717F528C61
6A8E619E866EAE7C9D9E92797E60908FA46450439C8B8795
9275C59892A5B5A6D2437EAC916C76A8CE4EB0AE9D9A818E
75729C8B9A8172827C8675897B86707671957E767D767799
7876988C6E82894B8F50837E7B948AA15D93987E808EC77C
558D96888C807D826F739F868A8588747B517C904F746FB3
8A96906D6964A990789B8B905B5F8F8F
912CD63AFF00FF2AF44557A836C08700FFD6FFFF00B87A00
FF00FFFF11BECF38BF5E7F08FF0000C7736F975E61BC0FDD
2F97A35C787F5C3D8A00FF40A0C94190868472A95684128E
87B675996A829B3F0000FFFF1B8C954BCAFF00BB9C00A8A8
80885C8FDD6E976F8A749951AD000084647160A490984E90
7F8C869D89C42D90969C6F8FA07087AB9557A3B48B69B987
84837A3A786E3D807EA15E949C516D98A1A233505D8B635F
9C6774908FA68B6E89655B948263928C7D718283737D86AA
8B949B8F7A93C08164386F66689872C4698182827BBE8BA4
8A869088A3828A9396847C7466898B8D808A868B8F86767D
8E9081627689575B24916D5E515D4A6E
6C658801FF00FF009D00B68B35CC2D00FF00FF00A9736B8F
6B33C02D54FFC300B6869F74FF5D00E8637A7A920000FFFF
23FF00FF00A67E4D7809FF7635906187838563BF866D9E7C
6D977388A1906879FFFF0020DD7E95745D04FF00FF7659B7
5166939E4C8D8D966A789C89DAD97C98AF6388877561D166
A3A5659B9356608D8E8AAA8683716273A06866796EA191A5
A0B8AF92888C6464716365898471729D6E87BC877F5C939F
6BA7948F786D62735E759888618963846F83598265806A80
6968A1569B797F6E914D8A9AAA657B8A948466867E4D706F
7C7CA1859B6D7490A2A08875868C93765C78A68B8A6A889F
4BA3481EA4656CAA767A92927687C0ED
793E64A15A81FF00FF008E550EFF00EE00FF00FF6937AB84
D5F700F0C8CC22FF569F43E971A21CD66EA06235FF00F0D4
00FF06FF00FF821D3D55937EB46C5178906E82969C9898B9
A68A2592657B497228FFF2936B856D948D8B53898B81F200
AA6AB284A3A0A49F806A8087155574A19D68BC80BA8D72A2
808B7FAF775DAB71939C567F8065576E958067A49770C1C6
7D76BB9D88AD79687E9891868393A5648F969378CB7D61A2
C189646D757297B7BD81796D89775E837AA17B9FA06C7C8C
9B8D7590767A9BA88D5D4A6F7D65858D79757D5A7C7E90A0
877E809D8DA3A1816894857D9A8586908E868D7B8A6AA19E
88938FA4B073A57E5A7D7EA46E7E7678
647A91D7B91CFF00904AE35C4BFF00FF1BFF00FF8A60E200
FF06B55400FF00FF4D5F76FF00BF506F636D7461C000FF80
6C694CEE7348737B4900C0C11250BA6988806F8849719663
6378A384B6818252A28AA762578470889A76ABAA199438C4
92A88A53744D935C95768179C49B488C776875746DA2B66C
445860849A911E9B7C7A88808D8F4E9F7A8DA6797280AF5F
A37B6C928C4D868086567270A9B56782529A32959DA69692
6C7B8B7D958BA788818D8386979FAF7E70666B9C4D955D78
749296848A7B767B7E66C34C61AA8C764974A38A55736C60
786F778D8B7179678575727E9A5D78768D76937E987798CE
BDEA685B7255996C94AB787988706171
8B888ADF852EDC196F33A66755CB0B9100FF00C52AA69B00
DEC800D845FF00FF9B7D71D030EE237A46726F8300FF6DD1
339694B04FB03FF4590BFF8D7C2C7078A28E7392958EA372
7ACA76BF6787409B5C8BA97CB32C806E6B8E8B28B52DF415
8D904CBF777F786C74788A826C1C448F9A7A9357755BB2CF
638B6493867C8D85A6AB7B9E979176BA775B697C90DDA39B
865C895F91A68B6969FF669C8C000017EDB4A06E804F7AA6
756D7877679667867174758E829A6F8EA09D85739B85AD8E
858D7C94928784697E7D91B08F8F648276819398B09B8A7E
9BA38576A27E9F818388828089847F9CBAB7756DA295964E
558F447F739167A0BC5391808C8E9197
7372919CBE53FF00DC168052669B8EEE00FF00FF6D749239
DFF40068C50062FF434EEA1A3ADD00745B82857612FF00FF
3C41B13B7AE800DF7134FF8B7C8800937C8C69829B8D9BA7
A9693457B664895C94548E8167956E938B8402FF00FF00F6
256F6B8D72935E7A817A837F839CFFF600D299ABAA6F5287
77959A7370958C8CA1A86EA4546A936B77437CBA81685CB5
966F8E7B7D9775D61C0DED7D90E2A8D500956F4A61967D79
8A677993758C8F739A527F738279946F6889799A9E8B8D7D
916A8364326F36966E9896547C937D7F5D96647C6C7C548B
9B767D8B6260947E71985E6B677F8572AB7B6B3D708A7C78
8876987862705A3E5F3F5969A1A1A3A2
8A9636B3FF00E100D140B5827EE7008B00FF00FF922ADE94
75EC00FF0000FF16686DFD22A78734686758747C79CC00FE
00FFB67973435085CC3CAC6392F100995765814482969E89
9DAABAA074B7A6858498608596729E659F84E500FF0CD360
74A98F836C8C8797886E8180837F14FF0000B34D8E596AAD
70968C723C7D8284807BA196875F949EB0BA674D6A767194
655A5480A879A67EDDB354837E678CA597345E97B268986A
6283A647435D828170726698814F43372800171045648A6E
75677296AE7B97AC9D6AA1896E784F638F8E746A65877B82
6470738E727F958B757D766A896985847C8F91836B897E4A
72538C64759D937C7FB981617CB65230
8FFF3279FF0EB000D62C8B5D2BB2374700FF2AFF4C936FA8
3BD000FF00FFFFAD00A2991D61B134817D0087767D6F8E00
FF00A8B9CE878F74AA0A9CC15CB236989392439A74A267EB
52968DAABE5D8E6F881F7D877D8D7D796D625FFF3889196F
61667C90877E87888AFF578D9A898B22FFFF00C2709D7175
7F9A71718673129B8389638B82CE226A64898E61918570AA
73909594716C64638C07BDA46C51666BA1B8998689514469
89887985665142323F665B634D69BAD7ECC796FFECBF9383
A2BA9D16A28A4F8DB68AA49F547E83A57C7C8784767D868F
9A75818A6C81936EA27A927285A9748395AB9C76B27F92A7
849F7E8DB67FB09765AFC4A68178461C
89E0089CFF3F6B0FAF75B6D200FF68470000DBA7AB895CB1
800090FF00FF03FF31FF3BA953A641892C00AF6D727A6FE5
00FF00DC5EB140C061A464859E2CE66D635BD637D4749084
A724A5849C857087B6D28A68828276579BB74C00B4DAB375
82BDBC4B7566618C950098797F7F868A57E9FF6F9083A76F
8197868D6F616B776C69836C8F65634A895DA2808082819C
3C8A7D8B617F7D86B77F072A7DCB598A7562984F6796B580
411F445274FFDAA57EA4BE84DA906F975B6D758197ABC7B5
8E939F63395A6F7F7C837A73566A4B8A8E8D917E6787725B
A36F566E62706F676D8C68906A658362717F688F5A954B65
686E8B6F7D53817554708A6470665862
75FF514AE000D9229C16ED9D00FF009DFF00FFA68644C372
F500FF7C0060D67B9F66902F958E886FB1FDAE758B67908D
190000E88ACC866F339E6D66850EFF6AA281599B9099635C
607C8E72885EAE70006B749A8179AE8DA26DBE84FC6B779A
2C8078A7B070857C76A69D7F7B8995936776000E7A6F7566
758A7A679B90419591928D9F9CA16481A8C388875F5FC089
658086717299FF200010AC9E57764BA586945B9FA4729B7E
ACFFBDD18235604D78946E5D9E98757375704BAF675E8458
527BAE899A898B804F7689A27D7886787A7D7D888781886D
657B6D618E586B847D89738D7C82427472896D4CA36B55CE
928D966E7382C082917F7E596D775C65
4AE3698BB7009910E338D49700F95B00FF00E47F9F24C7A4
77B1CC00FF00FF25B672994078575FAFCC45CE6A85697912
A203FF00FF537D4A9D65FF3ED300A2835F8DAA6CAA1A776C
6080786776AB6E79D57C79906D83777A8B85538C317447AB
A577903E5895606D9351967E827591988864FFFF397C8989
9D9F516766AB92759B9E765A8B9E738C837D71A67C827859
616A6349D900A6949D8817C9CE5D9FA2612FAB7D7286E490
5AB99670865A7950816A99A272857BB3947171835B667872
927EA089908A8B9F9486A56C7978808985887D95585C6C82
94859A7F7B958884726E8F7A6F82967D7C796CB6726C597D
61325A7E777B50B1A49E86778266C9E4
60D620AE756B3E259E547C3A60D1AA00006EAA967C41AF6F
A5BE5891790CFF7113DE696D006A7B7D9806B76B7E878216
A96D00FF12A1926A9C2AFF7F843689727D98ADA19073A497
7B6C6C7A768CA7E8FFBA977B7958568176966AB1985BDA6F
958988BB6DA1A15F6C76768181807D9980646B00F1968889
6573986DA4C8A284726E9083A991726E7D6E79689E999B81
918E98D238AE99726C7E83165E740071C4A6578B96C0438B
63724D637E726A6B39789C545B796A83ABA7768D9F838D5C
726D836A74686882896D9570A07B8A8B998C7CA377917C7A
81849978978F645C68919A92B498777ED27A744C213C6AA6
6DA2A077A37470E775A37171778E6149
2CFF1DFF54538004FF00BB7776FF00FF00008BA17A58DB5F
AA6E4CFF0640E0C1A453651069C426966C8B7D7E817F8F35
BF4D92FF00FF87AC667FFF49880374848D749A985A709286
6D5E66926FA04900007A995165A9808054913C736692717E
628B874D894E876B90727D75788578B2918343A50B578A80
785F7F6386827F849C9BA276A4869A7F779B6C599C645E92
589691808896AE8B5F836A9524DBF0963634BF9C708B8930
7860626BA56E9678676E877387627295795E7C93727B6F6C
7F79808E845D8257778E866A6A956A607C876166778D6C69
6F9699736978598D6B855B6F8A6E9D8982944E6C8F90726C
8475638A6A9FC367625D868873597678
806A61FF07C6A232FF3EA184318600FFFF00AEA06B1080F1
3294BA00CE00FF6CB0824400BEFF0077C377687B68858A5C
7D79D401FF00B9675871B711F500787D7E93A5966E5EB667
9F6080B25178FFFF8BA3686DC558FF22FF00FFBA74725F66
8173707F6DBA558C999EAB8081898083809E604554C99088
9669B16C967D36877D789D9680768D6A8C6E7D4BA98E6579
A0825CAC8F70A26F8775A4B06700915F6382AB6E9F56A858
6478838A9441777F90627C8C83A3858F618E889C77879095
86746A8C84A08E688280637E707A859E798A777E77799C8E
7F827F878A788B6C8887D16B8D747F72B7634F725681C6C6
8F968EA05E684F99A0959B7A77AFA8B2
BC907CE910C47E05FF00FF886236FFFFFF003B69FF00FF00
FF00FF56D100FFBB704BD5CA007400DB95689B7D7A7A9951
8579AB92FF00DAB1D0429A6B212DA472796DAAAA68956874
C2898B799365000044698EF210FF465400FF007F67759071
90707919FF41978173886B82A380797B8E856F8377615C78
649591918FA57070868A6E9278909377758B9787A893AD60
97C992909296644E91775827FF9BB8FFCCB1A273759C7E75
695586908686917274879792839C617E8A79908D8775786D
908197868995977F81A27B8588898E708362937E825E8794
7C808B9482647D81719295957D5770ABA775739D99B0B5A3
9C6FBBC5967287947479857C83826768
AA9178FF00ADBB19FF19C89EB00600FFFF00BD00FF65FF00
FF9D00FF0E73ECFFB16E3FAD00924A7F7D7F9873B77EB179
81547A841F006BCC9E70C1B33156C07B9B6B828ECB44C391
986D4F8E87D3FFFF7841A143FF59CF4AE484C785A6615389
A69198AF42978D86A099835F60719185806FA7A2E14C868F
7C7D83598483667B56517583777FAC6E73A87C739D7497A8
769A99AE69975F7D7793808B676D2E0061FF78714BBC616F
429771895F66897E90867285879778707E7F9C836D5F7B83
868A8D8CA289877155806E8D7577756F6574859A5F638B87
767F767C8A83967073AB8682749FC9665B52DD9675455166
87738A8A68645E7CA3607E80738A7876
B600A4EC00959838CD5585678EFF00FF0000FF8381C12A70
5874891BC014CFB5519B953CEC90448DCF6F8C93506F8467
7C8C7565FF00C8A1208C839215CD8D8077915E883C7F7F6B
8D7A62869C4E6656BF8A0C93BF9B5CA876AC538A489B925D
7A7E676C7639B38F847FA283778B4A6E7D738D8D00FF5982
907E698D7C56CC7968609F8D638C9F7DA265816778638D73
957E839AA37A9F927A4262D93E8FFFF05D00E16A5D648176
7F91838B82585A737286758083959386849288806670868E
8D7375A07F6C7E9198667A739A7D88647A7379769E8A7A7C
8187767B6A9383967652A1548C4F66E96A8AB07A4997CA81
7E8D8D5C60A4964C8776A18B797D7983
F9577DFC00597C6CCC448A7F00FF4F3D00FF00E897715A61
806F7834B20DE051C85BB64A806E3B93B676CA70878F999A
986772A1B4D960FF6E86A96637F5717D89818E65C65D6A46
97BC9A735872FF898636FF55C189587B9790AB7F8448CDC1
68725EA969837B589A849E788B68738570848567AD00FF17
867B69858AAA518A888592529C6A79856A675A2AC07A5D90
6171668E5C636E654E997100DFBF64D6ADA32090ED64A470
72798378438B8D3C74756279708E8F879479947384729166
809C917983877777A68A678D9F7E6C95B4777A9996746780
92908296AB8D6A77857C629187469E6AA69383CD8391A961
9993B97F5CB9B88F85757E6E7A82818E
C18F37828400D37CB513E95D00FF000500FF00FFDF00BA69
6C859760574FFF00FF445E4C988954779A86796A8560AD86
79886F73699FF800FF4CB12610F35891B276975C5F84B78B
736C844765FF67638AB252A59494379B658C91A263ABBF37
79AD4D56879C788E638C6F7A7B977578778C946C66972BFF
9F6D81A86D6EC3795C597A8F67858058918774767B9093B5
9B5F827CA47C9CB6B09F72BA73004A00525649A400EC6A8D
4C73878F8D874876897773866867866280A1859B67699B86
657461918B90926774647863835FA6768A867C62877B7A80
838162746973527A63AEC45C5BB68956698CAF4388564F89
4B7F8AB9738D90719980668F93717F7E
B27064975563B095AE4D796EC6B79C0000FF00FF20E8C05B
28B43B8858C4FE519F9F6A77778B70858492818F498D7A83
7F837F7C8B555900A074F32AF46DD980749C89758283679E
657F80994EB366AF00BD9C8D75855F7776897F56845A785F
827356A4727894A37186826D8E798491817F888791519E10
166DB48E41C5B17B483C9B848C81B3668C6599768F8B625E
6BAD7E6191838568AD98A58683A9E534EEDCF94CED2093BB
A36C594D8A9F9680909073818492A4839D8B8C8A65788477
968F8A676782A78E898A86927C769D9C7D708F647A809191
9C6F8E595A9C84884A67886ED15D988B6F5F7F8E916FAA5F
7A68676D7F83806D6D8D79726A9F7E80
776B40913BDB54DF3E44D14AD79288FF00FF00B89369A588
796B736E9799A0AB8A8DD37C9FAA57B97F8C7E7B388D8776
817F9085A08025FF00DCC9094810EA6D76C9877A92799969
9E61A06CC07AA83CB42A7C80807F7C568AA29942A0AC65AB
74737B8B4CB4614499848376857F8F7785749694977F80AB
D19E599191889C8E5B577B798FB0768498866E9896C07D6C
8F796982886FA8A457424A77AB7D4DC61A26D4F3AAA94764
6C9B727F697078607B869E72637D6A7BA2935E6576818BA0
747D5F90548475967765737D8D6B7F77537565828E7F6A76
7C6E9A75667D429E98638E6398AF913BFFBC75AB947B698A
79739C7B887F8A898D84617983807F80
3BD207882BFF09DF8645B907F97DFF00009B0080AD7E97A0
A04BBB8E7F609CCC6DD88D625EC645D394768C947F9D8677
7F8C8889857651FF0089FF008690667F92649FCCB79B6E9B
888D86A598903CFFAEC48375A0838790867653D87748707D
95B6A18B9068A47C8B7C659C848E787B8C8A708186688092
838478A56651877D62664F73AE9780907A8B8E8780A37E52
6F7A826D86C079475288A3A69B83A56FDA9F00C890CFDF55
518D9B7F5998869F776B7E726B7D8E8086A67478AA647976
737273947C70806D826D817A8595A46A94A88B7D9B907471
A26D9D8A8D8E81606F62CBA84B59783A003146E3D56C8299
736A8996A87B84A09180818F9B8B837E
83447FF11ABFAB7E7C577512FF00FF008D002CB4D2517DB7
7C47BF86974A62807931D238AF7F7F7F83776D65AD797C66
8D5E648CA588585EBD5EC651BFDB8B865F61707380B7A1A4
9F437B86469EFF79151E91897985818A7B9C8486A7917070
78836E9B9A817061AD867B716187906CA6A680817968818B
9DA797607A1CA06D83847F84739262708985827A9290558F
7B669BD090B1828174A476749A843EA26186FF0045985EFF
7B20AC53C8886EA06684A48B946284756C70927F727D7179
71739D7394999B7B9C8B768B85856395687B8595A78151AF
63839E857E3C58758263587360718CADF08DA5A16B55A296
93A790B066A7A17C8E6B89808B7D8374
96906D796D6E59C74F63AB56FF00FF00D9006C9FCC3E8F93
8068D648809598889A749B45B45A845068A76E815B87595D
9B949477B68A7621FF00934F93C95D8A77ACB4DB8389844D
71796C6260EB0021FFC397706E9B60A5838A7F8CA6998579
659EA9927688C9D4A5A697876B745A8C68837D9087868586
58809FAC6EA7A873372E8B9B527A857A798A818778ADAD5F
74A26FB996A8909B9786B8637E767070DA4292F97161532A
CDC7AF5725BA3F468C946B3B8B688575906E75837E837374
887E7E9272978F766E726BA189867D6DAF82A448977290AD
668E7B9E718A8CC95F96E04CFF7235B17B6F8A658EC06169
787D76758B6C89889C65908F8F857B70
805C9E6FE8877BE56336DB0DFF00FF0000FF00889757748A
0E7C908D67798352C832735575C595B17C9E723FA9716495
9A816C9887428307FF5B3D7BA0C34A84A0936A93963A5640
6C9756BF4081DEDC00147F7F81777E8E787E98888C689A8B
A2478EB58BAB7A458477796F8A8564919C8B908AA05F936A
7F8D94848D5994806C734C779663838A9C9E74A5686C918D
787283948AA987778DBB6299588B60958AAA6165B144AF41
D600FF55A4E565ABB58874828EB98A788D6A96A1847E8370
9D77AD6C7862988175798880BBA683798CA775705DA39371
995D8638A2FF6300001E8BCC50A19D719D9C616C6A899AAA
9DA4688190AF92778485818073857887
AB42CC2AB6C35EC83D46FB3692FF6EFFD71200EA46AD3B62
A5C05196A2708EA0BB326B319CA724DF42B0759E98626C83
988674978E61800083692B888C6A57828A71B88BA15E7E74
A661BA68F0354CDFECB41380C1557074816C757360987971
9C7DAC9B7E7F93B563958A885F9B678E6D7C7E768B9048C9
D758707E79909E6EA7A6A9884D82BA9B797975946E8A968A
845F867295A28E8770AA6C7782916E997395AA9656BBD61B
43155F05FF3E4D574A9AB7879CB49EB4BDAEAB7C65837E77
A0AB7377859E8C7D979F698464A48A927879937140BD4D9E
478055A78704B17A6379438590868F649589736A68AC6E51
5195697AB3A8728B8F92897287868F95
983E7D5D6EFF00C95FC86FCF00FF6D3AFF19C19196B18451
9D7E5DBB346ED7BE768476C295C100C992805B68975AA387
87898A73A96C85E5EF4EDC515BBF5E8D5E868DBB7D5E6477
88AA6F45848D84669A00F529915C7878647D5C6B84BBAB64
8B5C5F697364596398906B868CA7836B9373777C857B882E
509994507694B06D524B7F7B628B859599777A847B909DB7
859F9A8DB38A8D8C6E89839C7C80876C9A50B469665700FF
9ADA67080000FFFF20502D5A738C71975E4972888DA08C8A
A0BCA89E789979747E797A88A0A558444C788ECD8E6BA14A
B68FDBFFF67C79577841EEFF5A8792695F897A7485799690
AD85678860B18284918EA3697A946F69
AC45D824B7C741EF41A351F600FFA000E060CA00C07A827A
76AA8F89755CE2D321C47F765EAA53A22A796792854E7F9E
7B9C7C81B256609DFFAD3E803394DC6C8FA9A0788B85874C
77979F86004ADBF190D7005C517F8D6D74718B8379897F88
7C887E83828F60A2A2466C826789707A84778CBC877C7963
FF5A93815269768267638278A6926D47807E818C739092A0
79676C87B687835C756A724B61838D7828B44593B2B8C400
FF7732FF34AF0000FFFF7B9351684186B0B1967551437234
669EA3727E685F61C7968C7A88B695ACBE977B74817461C7
E6FF5D1E429C94AFE7FF76001E91AE7A5F6A6F90717467A0
7087856E6A668E735C838A8C79724045
7E56C100FBCC46FF657C3AFF00FF00FF00FF00A037FF8C76
5482869A4E41DF9A48929A593FFF5F22B18DA1976998A474
8480969F7084F40000BC3B479C5EE16A9D857387378F4E5B
7C8EC6225ADB0500FF00CCFB347E8D84895F6E33A578546F
7C6284A52E47A03687948B8780836A6D7E8381A79756817F
7C537C82668D4F9084887EC486C25A685F715D88695B8278
7A85653C78819BA58F9C95837D838E61465DE06C843378FB
00D1FF00E598ABFF02005DB5FFFFC6566C3D5D7B9C899763
425348AFAF698581691F63B57330897E523946A688586D53
1E003FE0AC69B5A2A1C608A762A487985B74796A4D6D7C67
6A6C7279866D9560883C727F74655B51
A91BBC00FF51743884CC3EFF2AFF00FF00FF00FF00FE3BB2
A2818F94993DC57B56B2AD6B8672AC3290817E8E787F6C96
8D726C586C17EE00808CB41EF67AAC6D848D9A5DA14C7F99
8D697FBD2D4A7FD000FF6900B06436D551607A3EB085A17A
B28A65A976856C5D867E9772A97E6D7C688B849395805B8A
778FA4559375797E9EA46B6881787DA484A37C8C8289718F
7794767E946796A3859A83788C4A749A5A7B947DD17B8976
D60000FF00F60000FFF19C009B0068FFFF97AD97988D7875
807C2B6D699F817C7A7EA1A05FA95B9181B69EF1985FFFB4
2BA47C4BB1A51455E444AF70BC82679AA04F788F957CA399
6D9C777E6C877B727B8189886F7A8383
833AC13BE92D836893B32E8CDAFF00008F00B4FF001CFF9C
5E5397DD79A8716059AA8C808F5E9B7591837D98826F8A8B
9471AA9B35CD00FF8C7EC100F95F8B6E87698A6F93AA84BB
A1AE4787AB87FF61ED00E5B7754B99639A727B7D7C646A8A
737E8B7C5C468A8A7A788C708179978DA77F7778596DFDBC
6CAF3F238D6E96777B81567C7C98768358A2AA9A906D8D77
93996392B98870333E47678D581E875A2E7D618E23105EEA
31D04769FF00FE712F6CBACEA3BA9500006571B2FFCB7138
5E78DCF591463F7D7D93765976728BBCA515E2FF001334BB
FF3ADA8A0D45FFB100B18C0000C2AC67BCAC5D4FBBA79E67
6A70876F94557B8E846D84618D777D7C
8865941DD64D804B8DCC19FFFF00851707FF927FCA6F7658
408E8DA841B65F87677B7891869BB7597687846DA5746D65
85A48AC934FA11DF899D41008A6ED56772837E4D946A7B71
9DFF028FC9D500FF56A27AA69E817E1F948291847D807A98
6C637C88729E775E7F728979837B666F8A3F7F8B7BE44074
8CCD76474E85927B7A81568084946B6E5B836F5D8C7681AD
98BEA6B64265837992708455B366989D877F7E7B85DF3700
C0C0D74400FF3C258D33A5B95B77A6E3FFCAAD686700536C
89F54D095198715E8D7CADF88E7E7080FFFF1700A08DA81B
24D57B51306F0061E76951ABC98856598F6F786584A769AC
7B7E70695A7F7A817D828885807D8893
A2BCA226C1048E8E904CAF88500065FF26FFDD2269A104E3
1BA94E7A908762A15E688A85557D9B687862906E8960957D
A269CD7EFF4798B7669E732BD67BB56D7B857677A54C9071
E56A6B9C0077FF00C657B2478A647C878D848B608ABC796E
7AA6956787786D766B80847C8479879E669F44680B3EEE43
97888A734874747D5C558C6D69698D796095697A688D6F7D
7C716C6F897C8589638A7E9F66A6A46E796F81997F1B9DA0
4A00779ADF00BFFF52A5198FD2808154092487735DFFBD95
AF72B89CA35B6395929A803F7EA5FD340000FFFF61240064
500018F3FF27FE984473C471A7808191747EA08881929D7F
6F92826B98998C7E989C888C7A7A888B
7B886B979F7BAC6904A27CCBFF00FFFF7E02A8C8777D5B8C
9A887C6F7F8869866EB5A4637070737D8D56628885697974
7A8E59FF00FF3ED2258B894AA2709580A5B069905DC0BC62
7C489626FF0052FFF3B998AD617F935F7E7E8381A371899B
837D879D6E85946C706F8A577C787C866DA415FFFFAA7F7C
4C947837857C7579A9A9A4897561559A79737E79A4737937
7D8C9D8B6B8588858B6A84A286AB1D75BCA37F688690444F
16F16FFF37C85100FFFF94002F00949B73988978C353408A
958433E08B887F609581A0917B5421FFFFD09FCCF6B691BA
788EFF7A3AC49C1FFF9498947C897F90898E9B9192959094
8B6255739B7B6F7A7A687A767F82887C
71738B8EA05ED45C96BE0DFB57FF003800FF00A37EB7569D
8F917D8B71918AA34A7F8C868091978C83788A5DA6769CAC
4FDDA27FFF4E7CB453962B655FB26E76817C71468C904A7A
986F8E9199FF004D00F300C4DB4962A3927E707862877181
73998E8E6490796E86767E7D71A68F689B1C4BFFAC40BF71
6A644E5E75619D78BDC299738783727B7AACA7808281848E
74B69F7569977F63467951777BB46C8F6C332E567F4C6672
A762720FFF89A9E41200B0FFA698F15192544D3797AB7354
538ACC807D599D841DB29AAFDFA4560018000052002E1B49
C6FF2288AF9DAFAC00008397B57A6DD28C7CA18487687450
7485975A81A077BC88708B797B897C6D
8B778277BB72B09567A00BB76A70FF5DE7FF00F2AB824F5D
59965C93636F6A8F855D9291B16A70987F91894882C89021
BC00FF00BE6FBB98DE44AE6E7D33B17A8EA36A8A71AC72A8
A67090518368F900FFD6770040B6779DA094766C7C98A98E
A292707E747F979F7B73776F8A711FC05DFFFF02677E6482
67A875926C797082545462986D648F6D83709D6672C77E75
AD6D624C847394818A8F7F8D9A6683898A98C8A27757B38A
71849B960C004EBE5CD77E0000FFF30090B0FF965957CBAD
BD8E646466BDA3D0C265742568280057B0FFD7A72CFFFF4B
963CA172D9790042CC8B6B823B9D8971829D858457918391
7B786F8E33937F7E907B92656C708F9A
A378C246B02CCC3DAF8187D8569200FF00FF00FF4F569899
B1BF8D9959836E8F938D568F9487968B6697689292763F83
86FF00E47DFFC72DB52A9C46FF61887C915B3B5F6D70858F
839283AA80B66BF600FFFF00F500CF8263586A71797E8066
6A89778C767F82635979864F8E59FFDD647662FF00B53ECA
75588A7B8C547F7C8F8E9291737AA5425770A396B29B9FA3
A0D8E5BEA7927355C997A97A727390607A77675190779E8F
7D96915FB2ACB61198D6AD8FA19100FFE9430000C1825750
57ACBAB25E29162B7D60AED576E0BBFFFF67C970CF9AAEFF
FF93D2254AB3A0FFC7AF563C8E5D94967A897274A3838783
738A6C749E7A707C648C8B84559C857C
966B56718772B83BA8E019D02EB75600FF00FF41DA00DB7E
89886C808A639F8DA9807D82A076917D677EAE74F592FF25
6939FFA8D547D81BB190388CA179917A8A9D79B05F8B7BA0
7C6585A65960A4A88F0000FF00E29146A2807086888C8795
646CA18476A4756C61A557CB5BFF00610000FF33B67971B6
955AA4857D5E767DD3DC8F9DBE9C57849673529285857162
54843D808D5E867E788B6878617E6674A2786A928E4B778B
739192A07EEF5F329832958E2CDB179B0000FFFFFF5B756D
448B7585B99792BE67D58D00BE34320E6DDB50FFB4840400
00798ED56C119D814C8AA17C5B897E576CAF8B4D8779899C
6A78B0BCA4809A739F976F5C4C729686
71543A666C31B3995CAB07A626D06A77FF0000FF00FFA67A
768E54798C78609A8595A26C93AA699C84597FCE170B00FF
7600FF558FBEAA81AA79A4747C787B795E6F795CA55A6A90
93977280966F8A78FFE3130064D11A28BF798473A2497D72
669B508376A261A3739FFF12F600FFB3870034B872984EA2
696B707D7887C1739A9C837D3F6C578747497D8E868C2F9C
5E4C78788E76557B6B657B868A8252787591716D899D8784
758B994BA550E4D28A9D0000FF6F3C3A44B2D200005ED5E5
B45356FF5BFFF095FF85FFE08FA5C5A5D327480000BADA9F
B08C61787FA66E91637B73987B668DA475786A76697D658A
839F7EA1A6AAFECABFFFFFFFCCB3B3BB
879B3F50AD61925830B714C14A736F8D0A72FF00FF00FF8A
74ED39BB9E5A8998679A62A1AA9EAF96D43DFF2600FF00FF
00FF7897919072AA4D8EA1818D7FB36CAE868C5D73835891
8B819B737E958021B24CFFFF00FF8F09C15E80A57B7D606A
779E67A17C04B6D34AFF00EC00FF265284007B8E69B96F74
B76992AF807C6E7F5858597584595C667984896E84997F8C
869DAF8572748F9E76A17E709EA54EA1736C94739EA1657E
B27683609E467C0194DBDDFFFF0056FFACFF000C6ECB75F4
B0FF897DC127001B002900464000304F1673E8FFC16C68BC
AD9BADAA858C847E877ACE8AB0DCC0F8A6C5C1E7E7D5DCC8
C3D7B3716A66280C001C0000133D4249
7091806A707BA64E9D45689E0FF249CDAA8700FF00FF90B4
001321CCB3ACAB938F39FD57D5C28CFF00FF08FF0008999B
8B1C21D4489C6CDC306A834E8075947A7E8E3A477A4B9595
907463724C5F97B87A6381515700FFFF00F584BF2E376A6D
6B8CC9882BC1000DFF00FF003600FF00B2F188AB8F792495
6C9F897D737D9E7C9798845F82A69C6F607C6580A6B56272
4874946E453A6027587D8B7DA28D867E825DC28069777F8D
505F6665A77B6D35FF0012B4D9FFFF385374CC7A7A000955
000011AC0EEEFFE38CF5A2CEB9FFD7BAA8D05F8CB1C5B08D
B5E1D4BE95B4989C7373615B4626261C24272122462C2B3F
53353B748152776450432F355E324551
A543AA9E6C558D46AF667E633BBA6168893EAC5DFF00FFFF
00FF4F72A47ACEF9976364C3246192FFFF007FFF005C5771
00B2779E5BAB0FA9748C7C46926F73827886653E9B9F7C77
8A70AB8F709830AA6567003FEA8FB0FFFF00CD261DFF0089
548A706CBA00FFA2FFFF005F24F519480022FB7C78879E65
7F6F8C7873586182716E7F5A6B5F93738B74AE69506D5E54
9B547A5C659E9B532A256360AB777392B09E927F73578C70
3935418E8D71796200FFFFBB380000009AFF6BA1FFFFFFFF
FFFFC952BC144DDE7D8DA0D5B6688D8B7F60525441451226
263B406F5C54575F687D61516D4564856F68502DCF729084
8C6E675830919492C2C4C1DDCBC4CEC9
666C6F9D85715E7DC24F498E55B581498C43F25B26FF0000
FF00DFB4D1B100FF00A170FF5C9DFF4A47661DFF00FF01D5
FF3C6980156B30CB73408F766A6C72877C5D6B9E7BA67291
98A65D7A82945CA0737563144C00C4E0BFD3F149C89FA482
3DD39072009267B300FFFE5000FF00ED6D5F9982819EA173
9AA2697F9C798A7EBCBFAED3DBE3CFE1D1E1E5CCFFF1CED2
E9DEB9B6AFC1E4D8D1E1C8C4DFE5F1DAEFB1B0BDCEDCD5EC
E0FFFFD3FFE5E6FFFF0E005FEAFFFFC68C7FB1C07E026358
492E62FFCDFFFF3425524232534A5C53827F6A78797C8A7D
71627C5E623E4D5A35808787BE809CBEA5CCFFFFBAB6C18D
88A0A4C2A5A68FA679668576778E6E71
879646BF7F829F00FF2D887547C816AA6D3688BEFA000040
1DD34550B03F9A72926F250000FFFF0008FF555AA1000BFF
878CFF7597587E7691417B936C9B927B8F6F9D586687756D
616D9A9A42A6779380B482AC94FF6FA3D592E30093A38C39
0063DBFFFF00A74EFF666711FF7CFF4D79E43B697E8BA684
89598B827A6A5C8B60614E434D324335532928393A4F4759
1726464434191100213405221E120F030B161F1B31240013
17010A2C0021403A1CCD196A61520012685C042F94C59882
8768687617000036472F333021475F6B988EAA8BCFA7D6AE
BA9C9AAFA2938B9291AD9B90707A7D9163725A6851995EB1
76837F6F54538E8566798B7385718081
8F63797E9483D63D6439A34FA0D94EBA7057BA572888FF00
FF4042E26FA57CCF008B70BC00A3002BFD00FF73894F9A4C
680DFF36B484B947764284849D984289728484698B7AA3B5
866E9B7D869435AD50A67A967628FF0F9B40D9BC13D67D51
FF7000214E98FF451266D2689D4DCF67AC39A95579975D81
7D725A7DC869747E312F508677792A584974726A41706163
7C4E4E4E3F544A3D5B2C50595570556D775244533044485E
54745D575853565F472A7EC388647E666EB0E9C968444A8A
AFDAEDDB7FD9BCCEC3D1DAE1BF83A9748D797E7A776D927E
A0637FA2747A6A87A56378686A9D56828681696E907B736B
6A827C7C61857E8E698B836167656A67
88885EB571936A30A841AC779BB864CD668655555FFF00FF
00C8912A64D2A1FF00FFFFFFB8390FD87E8D67672A9D63D9
56B98C9E6C57BA846783BA1DDE8B8880948EA595C0726E60
9B867066566CACA87EA088A0989E25FFE03FD97F5397CE62
4F00FE00FFA069FF6FA4596D8377916AB1737A61B276A48C
84597D5C89828580ABA9BDBD99A69BBBB2ABA8C2A5A3C3B1
CBA4C6BEFFDEE7DAE8B697DDC9DDE3BBE0F2FBA9BCB8B7DF
D7CDBBBBBBD3A8B6BCA0777C86DAFFC08456834B6880A285
778890A18462868F64615A65597E949580676D878881807E
678E71A86891766E84647D7F874D8493667176779893867E
94668B987099AC83747E839D809DC0C4
8B87F468C72F8363A753A88F9DB4375944833577AD9DEA00
FF56777E0AFF9D62FF0009FF00B2B337B574A2699A68739C
8187A74A6C797190504B6BA07AB54F8871864F8358947FAB
7EC54B8CA1635472554CB3847881F700FF8E85DE0AE635C8
4EFFD634BC58C261A67A71518EC9656C81814CB07F7A9B8B
7D7A955677A67E82838958616A75708D71956A765C6F8165
715B69536F877C7A878882895B7D6C72786C749488919677
83707467675B8B898354887063574A616A5BA17378928A94
846072746882C2945F929692405F697C817E868557966F75
6EA88A6F676C928393828B809C577378809575759489865F
717F726B8E676F578E917D647B9E7B71
7596A9607DB378326295B2989F66958395935ACC7C797DA4
296AE74AD75E577CCE00C0621B947573A5A174A674819445
B671925C999645EC8C00694CE5B27B968C79927A7B668A5C
6E7B958C6C867B848D6FA1955D6FA38D1C99739D4BA46D9F
9300AD5195896D8E617D626B776FB5808C8DC56785A47858
8594817D6F8F81808B8E7B86965D896C7B7CA6887E857084
6C806F76816D7456787F8979736C839E847F806F89826F7C
858D7E887CA68678BC92657F7D828E8FB07F967C6977986D
74907C818C6B5E6F5388836D989B7F65978964935361637A
A27483BB7E9B84827B47866B837E8767688E897377866BA2
928B7682845C8A677BAA828577788AA0
7B6D899C27C4908A558E764E42837A89747F7D807973ACA0
71A1956AA47D3A6F7AE974606B8B9370966D7353648C8082
AEAF7C6689C757FF7900FF3AC3C8699C71797E7C5A7E8484
79665D6E8F6F987F676588768586656991A56C6475AB7F89
98DCC96D8B62638B8C68808260AE6CB08C7952BC8B998C89
729EDF6466A66A8D82827D4A8F95788B7873848A5D81845B
956D7F7D85999A929B8D86848D8C9D8D8F958E6990686874
6D7981848F81585F718E5D93885C849C727870747D918D82
71808B73767B80766682747B8E7794858782779B9278777C
6E8972774F704C6268855D84906D6D70867D60719B6B9E6C
75838F8D9FA2856DBF75678C9077727A
A2785C46C754AD768D7F9B7C179674484C68B123A48B80AB
73658EA38E5D8267995A7D836C82C25BBA905D7EB25C4895
8BB6856DADAF87FF7400FF2EEDF4569C829F5B7988638F76
8F6A80A767AC619581A1897D7C8A9871875C927790939B65
7B74819E8C8CA0803DAAB9659C6C7B635276976298AF8261
7171495D819D6D7C787390718A827A86738A8473929A7AAB
8C73807C6E6CA5883F6A62729475758B65666B8954956295
7E788A7E8691918992708776798E7A7F7F857E8398875D6F
898B768F8E8F62768B95A4749484668A7DA87D747B959266
C9888BA98180A99B6D768C939B7D85A57A768580468F6188
7F536893779C91A08B9D736F895A5989
9F8774B29F63B45B77735E3E43866E5F0F83C9469C7A9DA2
55BA70A8686B8BD36B917A648E9C6CC9883C5771A99C8E49
558C799676DA0FFF0E00FF05F0FF3F9D8E7B888D7C8B7F83
7F7574928D86837B7573977780768F92707C788073838387
85887A7E737E8E847D60898987838C5C6A8C837E8EAB727A
7D77666F7D79947581827F8490837E72706971837B6B8880
828C787666656572647D8A958B768CA392878C8E917F7272
827E808082797F836E8A817780657379828B8E7E8280827A
6C7B7A73727780716C6875737D7A6B698873717A7F82706F
6C788389849C7D797C7884818079766F796C6D787182838E
8A808D897E8B8C797D7D737A787C7575
902A9B32D5A2BF7CFF1D4DFF2E76CE7FC59DD081B26A8575
9A948478808569B168A29A5CA8787FA562728B92751B9E83
37847D808080827F7C7B667E5282837F8080807F80808077
817F7F7F8787827F7B868380E777828476818076817F8683
7E86848069FF5B8B7A807F7E897F7B9B856486777B865373
7F8D716F8F39897D7E8C4CAB527FB58C696BAAB158C36C8C
5CA4615961657CAF37526CAC7D65768C98A58F2F9A878087
7484678384547F9967877F80808176878B9891948C887584
8080808280807EAD7A8382816E7081868E627267BC6F8777
B17A80B07A84717787626E7F914C64818280828662838375
7694718D8879877D846B66876261827F
A4007B846A979560B49663CBA158A5628A67D3C8909389C6
A9B83BC576786DCA3589BD88C8937F766A5B94DA8374AC87
847484807E83709175779F846A7488828081808380807DC9
76867D8C6A70938190535C5E8C679E6FE67380E472828985
8E415C7E8B8FC1799B7D807C668481858B776D5E549F746F
7EA08B84947083816FF09E6A76957A9C8C5659848A9F70A3
778949BC5A818B9980B9B9B77D667C988F9E71788E7C7E8F
4576828259856E89848E7A7F85807A867E74747199927F72
817E8071827F7F9B7F777E60F0D599964B74A243C6C534BC
4A8780528A80828268A18F816E818E8137897B8B997D718D
76756C6C817C877B7C8783647B76817F
A80071AA352BF16335DC9534DD4851F151AABE9EA57A887C
7E60566D7F7F72B95469B04CE5937699985A8AD44A60826F
791F8679877F817F80A88F7879708060827D8068837F807F
7E705593FFFFFF4000B7623D38BBA8C8A57D80A983857F81
46706A85787F8D7BAD7A7AB892805E8E90886C6E887D797F
7B7B7B46A88282808843E1A03D7E8F495F9A798A4FB39B3C
B26D8EC79288857F7E7B787C7F7887B34D667AB29D948382
8D94947A7179A2988DA49B905F85808080907A7D6E898488
868986768180817A7E8F71831F5E5BCAB1497CCF6599698A
8181808C5C71807DE264906C90758681897F7E938789848E
89846970628C5F8A99878F72A57A8282
7AD600FF867C9AE205FFE124FACF2079DC468C9B9B61867E
7F9E84837E7771757C3DD532918D6FE2B360ADBE268FB631
4294B3873E928480808A6E5F6F988A5F888E8A7781867B6A
938816FF878A00003AF472AFDA6A55628C7E81804B66827E
52898B867E7682827881807D7E9160948182696574727965
9795766366CA798C7DA014A8799E577D785DA42E6E889A4D
946D7770687B7182803B8C7E8176826F7A787F685D945F93
6494AA83A6647EA34B778D969E626F81825E807E6D787B93
8884819B7D7088C000B49BBA9D4A86B7367E786DB7C6627A
63857E7E9B718081824B898A6F737971827F807F7F857784
9276798178748B8199837CB59ACA7981
7AA96F19DD4A6BDE958FEF00FEC04A40CF3B56AF7A5E6A84
6CBE78837B9976726776AF0F8E943881B0D1726D85547F55
A9E3A61D6997898082865D818488897656827B768386969A
0000FFFF00000057FF79CE41429C8388FF7A7B80C978817F
9B005D9F9D6A91669E7C81808083867B9168865688967279
957A7478BC12988281788F59CD3F9564B77F55B19B55937E
A06082A07B7E797AAF5B877E818381657E9E7C9E7592586E
7C7A676F686FB0A2537D619E8971857F8175757F89867179
85868E6B838200A4BB6D93545666825C59A3689C77E67768
7B649E77A47C8D718283797844916A7938897D8081797987
6D927E7A758C858C8F8D9057BE568480
7E8F5C8484BD5CA4EF83A36E4BDB5D44CC4C7E8585687D83
63957B868595736124678267D3BF3F35A7F7839D503C5385
95D5676FA549877E89755F819584676BA3898D4CDC5B0000
00EFFF6D0000239DFFCBA5D7F342F876998E60768F6FAD5A
B569B0924F74869AAB7B82807C97868B12808362A4859862
738D54FE80C77B827D92AB5D76A902CB85918F7377787F73
75988D946C818A7F7B838273687F909F7E86766472806F5F
6D897CA08DA7768D8099775D92A7788076738380779472A2
78737CD813E1777A698F6CEC77978186AB707C6E467686A0
768AA79E7B92706D7F7366716A95686E8A7F807F7F877C8F
944F7CBCA7659AAE80BA31FF435C847E
8080445F4D8C00F5C7765E00C49CDC4F8F5C50A8676D5C82
837C7F87926DA3814AAB9740DEB7276DAEC1A4B187D0A287
38806F418A687F7BA8827F7FA497679A78A10FFFFFD60000
00FFFF0000007B4CFFFB6AEB738C8D62737FBB948761246A
6D68A785817E8E9677818078837E797C6399926F8D8F8956
5DA792238D8E7A807C997786825E585DB5627D8A6EAF74BB
396AB9826C8C6A84817D8083747A6C7C8E9A79AE879EB66C
71845284676BAAC2637EA2A46E5996898C7E7A7DA076DC00
A301DC53A44CB38745B292DE9E777295AA9E825585847794
98945F51966B8F9A439DAA808066849A7A817F977A7A6D7C
742EC88F7969B68EB978AF50A0828180
7D906C9C4EB49E40FF872D00C3C683654D8F6FC4987A7787
7F7E8678866F8F5F00B56617AFAF4190905174B9C78E2B7F
83754C846237A68E7D7B7F7A8946FF000000007EFFFF0000
0088FFE80000CEFDECF532C177977096AC609188B779CB42
736F549483927F83807F816F7A7A88796585628E849947A5
8C5E878C6F7D7C7F7E8F647E85868246E0A086AC90B8B441
A08878A3937F7D6B818A738F7D818381838B568B696A5A81
7F9AB0949E8899807B8F763986BA808B7B8F9B70FCA65878
398F6DB5718D18B4498493369FFF896D8A6CA0689C6D7495
98A3B1BF8F8D605FB68A445874807F7C80807F8697738E93
946F8A7B7E69B807DB4BB0A684877F81
7BA07FA04A997FBF00B138408ED470566D9E5DC58B7E8579
838F906F836E7B508D8D73538BA75F8947726A5E3A73A175
7C6764515D83738378A4EA4B8149EE9D0000008CFFFF0000
0082A0FFB9BC007EFF5E5B758CDC8A86A17F5273816D9A87
6C6EBAA7886986957E807E9083A98B8D8483846D6E9AE094
3FC0826361947A807F82939E8C857D9D3CD863A06D694AB8
629AA57B7E857E847681938E767D7F7C5973907F81666F8C
688169719B4B44977971A2D29037B26B883E68B79B8489BE
7F6CB8899D59B065CD479E926A39647D9B9490AD9778A4B8
7582A8876544A1904CAA3E6ADAB178827F807F82989885AF
98817588799D029264827580A368847F
7BA14899397C477C724C4092E9B9C60039E23999AA777CA8
898F965F8E857C48A4B0586AB48E66816CACD5B7F58F5EA5
DE0BA3FF8C00E55C87AD876A777221A562AA4EEDFFFF0000
002F94FFC400FF81E33D7F579A856F60B9356B9B93A35420
92B57A74966B6D8E7C818074637C89528D7C85634CFD0089
90927A4C3CC174837E89686E6D8D9F7F8B7AB0127E611B71
AD4589616E768D738E958E75AD6B839F848A6E668FCAC1CF
BAB46A276EA79E0094FF0000F18647886B87A37573616695
848479866CB481AC4C9EB06079BCA35A915F7B868689797A
737B8D2D7983BF9770856E7C889DC58D877E7FA181726F76
79F07CBACB0086618686C373906E837F
78AE727766883B7B5262A89F9856355759CB758CDD4A7C91
6FA48D89858579927FC36957AE7D9A838B5BAD7410A18C00
987EFFE50062BB6040926E879EA0594F6398A2A3BCBE1601
1837A0C9FF00A682CF258276647280848C74777E947678B0
C756738485806E9D887D807D7F727B8B56FF009D8DEC989C
8282657C6A867C80807E83AB895C7B7D88654B49F65EA48C
7C547C6A663789936170726963947E65818C6C74826A7055
B1717C87D500E5FF0000EF9F6789607289A172848792A6A4
71807672729C4D55AA9FA099967B98A85E827E89C9909080
8190915470768B6D9A78617183618E817F8A77847F848C71
A100FF21A2BC7B98579E5E5D886C837F
7F896773AC5E509D3383B0D76C263039DCB24A66BB688F78
75849B8481A077638BD15A4C7064806E92E0C589FA4047FF
FFFF00047FA5A3CA71B463858990A573A549976E4B85608C
5C73ACB6AB00765CA08678764D9D937C8C83697F88785362
4866536A7C48AE8F8B947A897396927C5DFF00CCD734BF67
814E5842A39B7C7F7E8B6EAF74649F4F8C81A2A3B25FB081
D361ABCA738B52738D7E8792897081928168937478355B17
5188AA00C0FF161BFFFF5487844E8D9963A4B1647D866A87
A14D713B6F68A37676895F678D53758A7D746B937E758B84
60639CAF7E5C98613A95AC928FBA908786796175976D949F
23E25D9B4A76C093938DA86FA9808180
7CA37A8E9DC187857899AE89A99D47BABA8A00809D2F74A2
6C78A46D788F7B00EBFF3EA6AE5C6DAE437C720033F3FF00
0000155C93A3465E89A967726DB45D899B3C837A7F908D8A
7F8596B175838B8C82859F805E7F7F879399276A799274B3
9AAA96B56E5EAE777E878D866B7C869C00439A6D9358966F
8757A2707FB17881836A7470877F82976F818863988393A0
2F7B52987866629E7A907E7E8282839C5B5E75835481510A
A174D0FF0036C1601CC242B1AA86C46D8D94817C70529A6D
6C9D9F968D8D747868768A3B888B807A708B8D8978827966
857B747B8E875B8C87B288858476847D7E818B855DADA82F
9F4B8C8C8B8E5D8794A58F9B68917E81
89515DA788B99C625E52718A7A5CCC7C62433EA4FA2538DD
25849060737E8128FFBB06B1A25D6E7EBB2400FFFF20005D
5287DA9A6684807ABE6C85A77B89716552675090727FA266
95817CA97A7B8188658F87907F7375967C807D85997892AA
908135BA773F8D78848074AC51D2626D59994A9C6A917C6F
665D7D7E4EBF75827D9175B97275776B609B7864799E648C
38EB23A1AE5B568B737F87677F80657C74A56990609166C0
00FF0000FF158E8FA95DA8817E897073705B715B7E597C75
6E7A7385868F82937B9273887E7F8082739176858B61827A
7F868779857B847F4FA6698487A97A8C7C74AB808E30C057
8588767E639392596F5F8489566F817F
7E8A6D8B68957146946B797379776F7E9D609BFFFF5373D5
0082948680825400CAFF7A6D398A5AAD04FFFFF4000000CC
B45F815C9E82AF50847059ED8EA6947B8281858856816473
789C6E71817F807F7C8C918F768C7DA6806B787B808072AB
E05C52AC00AA708A987F31A586998D68B5966362BB737B82
8C7DC747519E7880836D8A5EA4C5687C679877637B748A58
9A7060FC396E905D73B18D847E815B967991856474B349BB
A500FF70106979A647A3904C6A70627671867795698C7781
7E8E8182737E877B6D8B809B7D84807E8C8A8290848E7986
7E7175626189898A9191BB976A5E8B7EA5809D6DCA80939A
68A15C759799756A9F939F9E517E7F81
7C994D51374CB75E9A4A9759B55086858668ABC34C00A8FF
4F21DB707B895500B7B25BDA867F31FFFFFF001B0057FF3C
FF1F8C987D9A9857A87A4DBDAEB4837A9F947E80838E3580
81988A747E837F7A978872948F546473718985A184858AB8
887C8A9F29BE7D738F64C91D9F86815F79794C564A66618D
617270A667AD77827F838EC36F896F6356905A7F9C637169
9397979BAFC86799587C8676945DB45E9E8161B840B1B300
640B30FB9C8E745E7D6C718D799A907B796A7C7982739B86
7B757E7E817D87A17E787F64896E828A6A8698737B7D797C
AA7E84539EC780969290A97A797A7B9685807B5D8A74AA72
79858E57836D81858379837F9256867F
7D908B724F8E7A58CF73976EBC699365B86DB8963F8FB4DE
0098C3509B9A6E3FD76D04FF0000E9FFD6940000F2B43DFF
768A7E5C62809B899E9239A8B581B36E5B917C7C73837A9B
648A6C4D6D68807D66836E8B82968A6C588F796ECEB386BF
577FF1295281707A79548B39A297786F88B74B4B9480647F
A2669D4D97A37B82836C8B6B8283A2949C569855958D8A8A
89799B9997A5756B60D6AE9478558B9D90A7D39F83D49596
77A6FF00CA77AB45789F905CA28675927C7D849F876F6E68
86678A889F847E6181618458867B8875927F7D828174697D
7B5F848F8F6B5F939294986E549D52D55D788C749E957777
7AA19B98729E69329A7F817C895E847F
8468747D3396529B8B3EABC35D63768C7A908A8457B5B24E
1EB7FF826FCA518097519DEA0000FFB13100FFD77F35C922
998A8A6A3D7CB363A76369E4AC88A2876F7CB18C588A8374
8E8C6A846B9189777B87807F7C8387868B8BBA9F68A96A8D
7859629DE19495516A9A8EA2929ABFA3B46F907C7C67378B
6B705B7867927C80817D587675804C8C7D7E99788E589692
755C8A8C897572754E9E67A19B95A6717C6E00E5A2596FDC
D200E1FF76F30AA778866F788B82A17D73707F6887937C78
639B987373B19375599877A0807799706F6C857E816C9D71
6C8A553B6C7681615E39B8CE28C7686D77795D728F849B6F
78986C88866F819C9B64838C7D74827F
8363927F5465597FCB3D4C578956BC8F6A7096863A897958
839D5B58FF6A4FE9E9230000FFFFA0FF826700A636FF0061
CE539367738BD271A26955B79CCA9372925D8E6E848BA07C
6F93928173739E8B9D6D867F7F8781898B79666F6FA07C84
B068270CB02F63A36F76A5637B986590A079805C7890895F
BA56568562827E7F827675888E6E87655AAF759168567F5A
76B191767A708C739A943E65879280AC9C7635772300FF00
FFFF0081FF009F71806A806C728A717A8F9998AE83948B52
947BA4697F7B949971A99C469FB2768F939770827F81817D
8E8265757C3E75A082D263A687808D8E947B8186777E7E7F
6A5E879960897B866F7EA982877D8181
7C8DA5955D9091B777986D899939A45E5A5CC49E5B57A063
6B9C6F6AD34C6D62B740FF00FF00FF0057C400F562BC59A3
9C939E724879C688936D79B2A180724C978AA2D4636685B2
7C6D72A36B6CAE8C7D7072827F848379777CB576797E5EA0
9C53FF1E6F657F8C9D95A77C85899D9C96BE8C6C6A737463
8572898E86B27A7F7F87958C725F7C877F586D567C9389AD
A0627C797F718B7E80787B7F8F7D5BE7A27F2477B6DB00FF
00FF00B946D093BF788A80937C7885786D7B9B6C9D7A7C78
727A8998624A8458827A7D8A836C387B6EAD5A848070786C
85707D87AA78817AAB1394505A9A9581785C818493727E80
8C803E81A580908687A275A188838080
7A9B9B8C57AE7F419F66865F575790789A728EA86C66545E
715394899E4BFF00FF00FF00FFFF003499B10076008B8B8B
9A4E81725C79B074854E4ACE80EE9363B57D637D7EA0B361
7E7E818791648489AC7C958E6E808385836DA18C7A867E9F
6054A4F15C4A5653B17A52C884816184739B6C63854B9577
95717DC884937D80827388688278668B5B9688798B5C7B75
958D66907F8475827AA276865A843DFD97AAD3000000FF00
E954FFFF5B73949A74888B8882748161919F6C8CA089997F
B3806C8A848654AB9283835A608C3F709D8A7E7DAA9B8987
9B64BA8E4A645B36AB845C8B7D98629673818081818D784A
398A9E4F827B848073546682A0838181
8171838F67927538B790916D8E76428BC7619CAB888F789F
7671A2747593C100FF8279FF000030FF372EFF00FF6B7596
9E649166885C637B7C5F58C370CB544AA58286937785592D
AD787A7D72A49E658872626868688F8385A0C28C9C64645D
FF00B799447489BD5183907B8E7C94995D8A966F5CBC886A
81A273BF9678827E7F88717A7E7A707A7F617C7C827B4C84
60AC8D84729C674A7D7473727B7AAE3BCDFF4D6A921000FF
15FF6654859E798B7E7B7DA29F607A7B8A688A82759C4EAF
7282787D928DA37E81758285515C897459677A6F81838583
6DA4A079AE798DC45B7FAFC6917C807A6E7593567C7B60A4
9E798373636FB39271B86D7F6E7A8080
817497A38D757B5375539B4D858E48D17D716C9E586F6885
6C986B6E967924FF00BB9800FF00AB591BFF00BB8F47997A
B641AE508298446793BAB2867C95776C9A9A7F8AAAB0AB88
61627C94A97E77866886817CA5947C7C807D9573646055FF
00D3776A398562B0647E9169898A5F978774956CA27AAD6F
8C94DA755B75807E807D8D947D8A6E6E947EA88F7B7FAF88
BB696BAD9771999890925E7E956A9C826BFFB2D602FF797B
87B27E9FB5777EA672789A725F817B836E99908685687490
5E7D6B69A5808A726E8F7B6C37698A7A959F71A18B66816C
5E919C4D835DA5899D75988C99A4707D7C925B37A79B908B
7385579F67947A809260718B8963837E
7F80956B755F4E90AC8EA8819EA164D1749785596972AC83
A86B94589B9E00FF00EBB03EFF00BFE953006EC1515FB97A
DB669E8D5B627975A261689134A86F527D81897CDD8A7B71
74A95654744A9077744382A87B7983CF87ACB0557D99FB00
89867485708B9A7A7F7A789584A2478BB379896F86B67797
8A76667B7974827E817F646482857D7981907EA278889379
7E7C7791577384707C6144A28A8B6A494982D8FFE9FFAFA4
04906386817F7D5EA0797679A69C81916952886F7B91A57E
738C808183966D7EA36879785B94868A7E7047BB8E9E8686
9084A76D6E8C4E81949080748F686D6DAE768F80AEB98792
AE8EA07D898B70904C88A8649B56867E
7B9F9D63A17F7B96A7749984B07A778AA8638AAB795D718C
5D64954E8ED451FF0091FF0013FF54FF96459A6E6568A293
D060C77B896D867097605E9C4ACF6466A28E7C7D858C95E6
82FB4A8236AC69947D85AA7EAC417A7D8B8AEE075EBBF28B
B36F55B574A2A099947E866BA3746F9D8996A337A4B2789B
976E7CF08E56857E846A83789A938387A181666C4B817978
6D7A7E6F8EA67670B97C9CA6A896A2A8FF8B8CFB0004FF00
FA62936B979A6A8E8F697C8466806A8B986D658163817CA2
877F807F7F889D6DBD84A499888A877B807F768665786979
8D8B91668018FF917B68787D70927D7966958E9889969D90
888089976A9889576C73617C9561847F
7F819E5C7A69999877627F68B193A861F3A1AD91536E7F99
616DA15CB29D6913FF20FF3183FF00FF00948073715B7CA6
BB69B8478D75C17D76A791597694B676AD987B817F7E6E62
63FF02945D64848B788285BF668FAD876F74B91B567D42A0
8388437A757C977778618B8A9A7B856A95A8A06D7EA14694
834DB5B07E85807F7E89918560717E718385748C5CA97060
747D9081A7A3765765A4936770A6AEE5004C90AF008000E8
347D69937F9D8F635F788E7F90847C6998427C9A6B714561
9C7E817F7C8079A1556C8F8C9B9089A5877F7BB37B6E8A66
A35E84A408FE7186679A5DA08B8A8F707472929C76909697
819C657687855C6E9685989879A77B81
7C93A435B06A5E659E799B5F9B9F5A8CB59ACA745C7A5995
5A80569143984D00FF00FF809D90E400A5856E97868A878D
59E0B45E8B6FAFAB6BAF00C1568F886C95927C786C737368
D49136AE603E8698907A8169968A7A8B896FFA4D4855ABAF
9697986A927A707D7681B4997FB3735FBBA3807779D09A7B
91705A579777827F807C91737E705CA5968C809E8B77A59E
8C9A55528590628B7BA5896D8B7D9564BFFF46876FFF7166
9C8B8B6B796C83B56D6B856684609158938E7B87887778A0
5F8F7997BB9D9F7659A38C729E7F7A7F778B7F803A868D98
733E82C66C72757E91607A836A48A673AD607D7555AF804E
998B5E6181858171654B68799B957F81
7F7BB7708788A667D18179657CAF6892BCA49469956D6B8E
3C9A9BCD788C605C07C80E5889FF476B58AA858E94649092
17E0DF558BD595A4F700869B83868481B972896983368B46
E7A289A6664F6D87878C7E887E388C746541FF00AC668D89
6D8E9F793760848566A37E8F96B1709B8DCEC76B7B9467A3
885D796EA36A84808083807C9365A57F74A88F4D7595726C
94588A83BBBA777E70B877B08174768051005E90FFE96A76
828A62858790845371888B9BB09F819D6F65758C889DA178
616D6FA157BB8160828F5B8183769E5880907D7E9866C37A
768F815D85826C7B707C7E6B738A957B8A7B804BAA99A1A3
5793889A6567856784B965857F5C857F
8175969285AF73548771546597656C8196499D54778D61A4
5483A9BA77628C5C54FF00C45BCC00C193938B7D71676C7B
3097749A6E698F639B519F9AB687718A7D8D84CB708581AC
8ACE8B938E8D998B69897B826B8C5CD96F44FF2BA6874594
6B6C9B9C7A5F7857728D8FC4A678BA7AA77C947B61D68189
574B84828167847E7F8A8C7E7F7B9B8441708B9176756F97
AF787BB29573A57372928B98867F758829A8BC386A627663
7D818267937A91886E759A869B7E7E958F6E81667E807C7C
657B845C618457AF5D6D8C7A79815BC25DA284817E706F67
867F746D87786671A36663825F646E948BB268466C787089
8B6A878A699D9D7ABF78D3A060907D82
80789B3F7BB295AB606FA4689B6C8D96AB92905DA7669BB4
6A81B7616090927C9B22FF00FFC4878382897485AA6B8376
4E8881961553766A855E5DA16F9E7CA05C6F758950728E83
70D3895977CF47AD7F6D8F7C8762729A7140C99F76A76B9E
782EC98D967C8C7D55927A9977823C717398A054819C957E
7C99763864AE7982817A7299849F75899482A8718A65589F
9AAB7C8F95579AA0C58060B9716A658AA26E47FF2EA0777F
6793936A8E92976B906D8C938660987F92AB55925D8C8991
7F68877F7F64AB7143AB46678AA97699AD8B937F83757B84
7C7E8C8C998F648285A19085628958498884708D826F8542
7D6E8A885D7955628784609961AC7A81
7F81A7639282DE5587898E9FB78D93B2A07F8DAEB8819482
4068B9857E6066984B62A7FF00FF5C7F71A570B8A26A9085
939AD18463865880998B8B9A557E8985C05B555F93656CDF
9F7DA470595A58BF669D857F7F81817B5ADD00B05F8A6684
537BB17F9EA09A796D8E5985856A64866A8C805781A58EBA
76A796717CA17D817E88C48B8578878E8A6896906CA17B76
946F698682887299989C6F8A62AB817F5E9BAA8EFF138E78
8A61809179508E86A57D7C847470869573757C9FA563839E
6D845465929F6E8E9F83719E66725A8C82748F7C8180807E
865F705A77949A7FBD8F71B9798DA64F98707876AE99AF72
615B967F7EA3618B89658EB7A8858080
826CC1569295B17E42C2728EAC8125A06F647D83A35780A4
6E99B58D9A779A84748A71932FE77DA060A08F9966926A71
6E94845E83887174A7516F6F84AE8778628B698465A0B2C2
7B47629F745C7590868B50827D8080805DFF00BE98BC83C4
99AAA6497B65919F918D78B688A66A73846C93887F8E8297
626A595C357F7F807E8F8885A3577C7B729A69907B808E8A
956074C77D719E9EB6837A8D828666699369938D60AE8769
7F6B657E978A929085856E8A8E7A8D76A2A389927F70648D
74955B8C8A788494798B768665647D867377898980808080
7C9D63797A84666B6F949263888A83A19E9571919B579266
7A8BBB7D799981667FA172979B9B7D81
8076A79D5B8ABD8D648F7A4A9A623D69848DA7C5BE685D93
856C6DA06C7660523C976F9C2C5DB0B4769C7C83799085B8
7B76C357865AA05FAC125FB4C6752EDC5A70A075726164CC
85829A7C817F769C5C5E67967C8080807B534964B0A48379
9D76646CBA4BA653AF675DA08D5A83A4676E5B837B607C97
6D6F79639B9A7D828370718A929985ADA87074807C92796B
BE7C8A716D7885578D8A78A16DA57072A45E9D6287708F84
857C7F8D6C84B07F59888B957E70798E90928291817F8780
7899649E709474806D856292868A6B735A95AF7A82808080
7F868B649E87A1A4A57382778A6887926180738583867568
92926F9B63638B94857481938D8F7E81
807C907F60869377A681996CC28D76B089BE879A8A645D95
8979C3BE66AB8B78817B56FF00A3A4708FA19199678B5D7D
53C49C4E8B62C562CA2E1CE7935B5CC668B494996E6E7DDC
7D917E60809D68B48966889D7B8080808129FF00985A9C86
758F7F46CB72C26E5E8637B7726180769B827F6D92AB3EA5
7554C21B88A87A83807C7197887B6D577061896B517A746D
61A957A8648E97859B5CA76E838B7F368D749875846A74A1
936CA16296806F6992AB677E918381807470AC82839B7E9B
8F828ACA6E9E718A697D868872547491727F6F8380808080
807E7F9980808C578E7C87628A878D7D8A799D61766E8890
A47F8A6E8163878DA8597E5078788180
7C946F8E549978795C6189778CA46EAFA066889A76937295
80BBBAB06B82757498A245FF00BC836AAC56B0B4518A8868
8456C3696584B554925109D26B6F74A859747EAA866C6AA4
878694748977866F816C98997C808080804FFF00B3A647B5
89B08A91B285946F6BA58C9880448858738B9A996ED17D9E
4496A197446B817E817790AD78825988927B8584886C8194
769B7E77535EA37B937270669BAE6C6F5D9981A25F7C906F
567E34A47C877894819C737F967982708C7D6B9488A0705B
6F5A7C56A06C7C889494908D83946B8E669D758480808080
8080838680748F657D7480B17D6B6B849C8D84748D4F945A
88706B796197915B8E8385819261857F
8269957E69AA944A4CA1884E7C8C939085519141B12D819E
7FB890836D9BAA7B6A8444FF00A07F7F996EE47E8B65B779
6355AE4C6588896F877F06E167C5888569A53C9B79738BBB
6870768B8674908FAC5D98907D808080807869BE689654F7
B3A7636582B18F8E8E923C947E6C8B919B7E599063A03A9B
7088838F73957D7F807D8B8E7983897A8B6B8D6A7C9C427C
A67C84927D8B8EA861A6808F7983726D85559B7D81706F77
8F8E8B6C8189667C8890938F9D507978816385876E879E6A
48A5B996736D8E8492828973549F7F767E83AA8980818080
807F8B759186628769657575867C7B63808E7B728D83A25F
5E6A81A05B71596C7F64965AAB9E7E80
7D888D8C817DA67E6169838045944A7ECA858686995D968E
4D7A77A8909F8CACA79E21FF298B91BC707D83758A71834E
40899C64828192667C6668BE6BBA67767E817D7A6A857082
4E7BA65A882EAFAC8F738F4B857D808080822BFF00BA58BB
70979B80A78B6A5B6C89809A758C6EB38D63738285714D75
907E83727F66837D7F87879587AA686F6C808AA8978DB28B
7E8277836D9D8B8853838C7F867F797B849C639D8796817A
7A7074737E99C36F6E8B58867F807A70857C86787E8B7E6A
85A1847E928B7D889EBDA1B87C8983946F926E977D818080
80817F61A1C9A26B85667B7183856E8E8A9979799A577F4B
545C738D875D72798A898F776474817F
7F80797F7B60A7566D6B975357BB7159C062817AC27589A5
63A0A5747D935A908967A7E43FA67D936A9597ABA37F7856
2691825C7C8A727F8F5949A3FFA46A896E8D748D6954747A
86649A766D5B71A4754395857F7F8080808061FF0080D571
AF788A5D646594916163577A94006574C283929BA2846180
7B99788B4DAD7A80846776A2654DA594B67897A0749A8490
878D8C6C8C76769D7F76866C90B78E907981AF827E888182
797A7F7B88738F9A707F796F5F599F558E56783998909E81
8F8D7CABAF8E7373977E888B7F69968E534E887B80808080
80807C938B675DF38F999A6656A28E6C825D5F9C716B90B2
659A63728C71968A799A95508B828080
7F7E959AAB7F94A06D73958D59A1644AA86AC274A4729595
3E5C68875B637B4C8E91C95499947D9B716C83BE7A8B9961
127E8D849516B26D6B3D48C8836DBC80AD857B7A7D784398
827DC66C857D6092785E839F7C8080808080817D539D7793
A43FB3659B9656C2589D54996388974F987E378A84617C7C
72587B8E6568837E7E8C6D66828270AA738DA6786F6E8C91
A447806E799F8E885BAD71927F9E7596A55A8E7D92907D77
8B8693769994868695816E84738487789E7B779371876752
5BA97D6D48859980887C9E6A97467B4B8363828080808080
80808174ABB837AE09624ACA96A497AD74795E4A887B7888
8060826A7E74837396B35D7A7C997D81
78B7824C6E70ADB962AD6A773AAE7EBFA15A5585A78D7B9E
917B98935883858A9A75FF009C7A887B7685829D488E939D
3FC58863CA0092F9098D7CA060849261947E7E739D5D6489
3653947A644C6B979F59859A7C808080807F80826FBC554B
FF00894F6A609AA5618B8978A765888D948D79608C785760
68507D977C73827E817971847A6933988D636C7D71705673
6EA2879B779190799871787D9264A1827B7961938B7B8580
7F7066788C7064768D897D826E8D76898078668B70AD7B6C
6F947D897B8B66AE628182736DA283A27B73868380808080
80838280844A6971C087209E6C81617B7698A17076896260
867FB0948E82997E7F8A8850558B7E81
81836050755A72696F59666C855E5D929476927485934CA4
866279AE8B82A2758F38FF00937E877D6E8D72915186906D
5B9D7047CC188C916673696A8BA2557E679B6FB5A7586E9E
76685A6A815D7D957F73729F7C8080807F84827F89755F83
3BFA00B565709BA7608C708177576C578F78B7836E927A5C
7F6C837B754E867C817C6674728B869B779C7C8E8EA6AE90
7C536AA9A12C6C8A6763529E877B9D905DC57669826B707A
817A927E9270807D8E62737866789184648E7F694CAE6296
9173855A7E6B62518B807A8A7B8D9D98898DC48C80808080
836D75807F978F896DADE6389E5D7473798193909A818693
73816C778D826C958758A86FA3B47C83
807E8E907053B18B58896A5DA1B78C8EB376C7997E409FA2
5D27785857777E80686BFF00BB918D7F5F8D6B9D65685D6B
8A861C9AFF4A7188A647B696717F5696818B64E2BB5BE598
9A81A196715169876253FFFF707F808085626E818571426B
834EFF2A6E5F84B3988F85588F6C8F3F91A6A0A7796E81A0
A0709E7D88887D817F83AAAB968C716F819993619BB87387
A87E936388A574927DBA8F7A3C8B757D8C956D6B637F8565
618E717C677887957D7DA087729B64766F7E7597527F6E8D
83828553737D886F978296826DAB756A5CD1669187828080
827579807C7C8E67835593F25AB3855BA8809E6B889CAAB9
7095A9768A7D9B8E975A7A818EA67C81
7D90669EC35FA09344A468AC8EBF5C8BAC6B75A7707F8A9B
757E8993665CA9707849FF24B87D868A608E708D7C887985
7C755D93FF22C9A7A0935A863CAD578A7A7D7271B5407D8E
8470856D4D4F88A59174F5DF98838080808181807887E29C
78532BFF009B79A9AA8CA58C715988637E369C5B69A05488
73729165968080807D9563645351737977A36474A6998688
8C68507B5D976B7A767984746B70837D8777998D61818683
8577826B8D867B78789D7B8A868E7184785FB07BA74F795D
8481646C60999973A8616E8E9AA8808568868DA065718180
8080807FA2698F8BA059AC7CEF7A7492BEA269559265845A
778C817F7A9E8F71AEA7936C668D7D81
7AAA68779D5D9691348474576B4E789DAE9BAA82875B6EA5
A268A47C7D696D9C9F442C8A986D9A7C618E75A069787778
A2707A82DC7DB5C25FF587AD56A994717F7B4A8FA24E60A0
87A7AE5987B22CA7882A6981B58580818080807EC760817A
8396A16D538A7B505B835992408D8F679C705C567D4BA06E
8F927B92983C897F7E8A878D91AD5B73957D757A735DA359
7B7A6B92818F745D9D7B6D7D9382936C83C768916E749C80
7F848B6F84947484998C7A8B7C6E9A806D68697B7E7D957B
80738E6CA2976F616FA19E8079927D7A76915B596B847F7F
8080808063769D69B3598978156B717D74844CBEA36CA97E
98958587749B7D5A868296B9C4798380
817D6BAE5E6D7A59319F1E6E598B7B73827886759D61977A
844A9BA69162A69370E600A89282728276878D7E69724384
894FA97B9086907581C5AC7B9BB5BDAD6CA06C909657AC65
87A7985E8989937D984B7DA9907C7F71827F827496865D84
9864AA77FF389E7C85876E838761A5B689525E7299B17A78
A35890CB9F6F84818469AA859B8659A4A58A765A75B79E92
A2A85E714B9571829376B75A7B577C696E158A67858E828B
6684847B86A87D829387778982968C8D7878A1679D855380
9684768C788D6B835160A298778880BC748B906563837DA8
7B827C9D96833C9670779F8BADCF87A8817A9693527A867F
835673857B88757C925993977968837F
8659C092787D8E5D70743F94519824747A7C91908A6D6796
6F4C66AF45A66F9154A95DBB82978D87759B87988A8A838F
A78381796E9B618086985E7EA18289A794876699A468637C
717867876D927079A367489273807F67837F85626A7EA8A1
825C8565577F827C9B8B6C705E91A05F6E6A7F676DA35778
7460782DBE7184827D9765A3677584815F907251723A7579
86736980725276398D8990986687809E92B97E7E8898839B
92796987897B62877F8E6E827B957E94857F8A94727F937A
8B68826486B2874A7DA38D836C879187A3C073477380807B
81807C9A8D828C5D67748D8C77083F9071AA939376616E78
8771AC847DAC608E477E97565A5F827F
836C8AA27396A08B949C3C9F4F8077839D478F8492BB5E9E
536B7C697C7A6C72FF00FC7D91968A79878C7A9C789D9C75
9293908861748D608AC45DA0D885A14F7B7E81479490827A
8681876598669E9365748CD9B07A8084808082707684876C
6E7F8D815BFF00DD6A7B5FB34BA67D78A67EA46498B88372
A7B85040CF59867D836C9C758878799A58898053836C6D8E
76A58E937C8B9787839495999C6F757D8E82829585898B9E
827283758E88906E8B7B9B7C8D8C809A85786E989F6F7AA2
98A47791756764915C697A6E81557D6C7E797285847F8182
8080807E816E7455878487727EA6FF3D7D72A188B7A26796
7E799B805A7B8470978764A8727D7F80
7F866984627E757974B183BD8A8E43B17677C86EBB8A8673
7590B08C7BB46722FF00DA8AA456887E619279D0818A778C
8D74A37B6794774EBF634195EB9B81BBA3537AB3C47996AE
56766383B274868D8287989055837D808080808386617865
968A7D8C62209A3AA966697C8F897572905985755ED07CAD
A4B37C72BD73827E7D94876F7663684D8B7DB0626D937997
8A539C76836496748F7D6F90837071727B797489787D858E
8F7BAB83768C7D90817C87818F827F8C93A3597C52498564
9A968C67B77C893B80AD7F649974A65D76748592947E8180
8080808182777C4B8379807690A2396D727D677C7A80659B
868997B18C8F6A908C8D8CB05B51857E
8171D771739082A46E8C6782766A71B560A3ACA399479A76
438F837A7CA57C01FF6D69759F6E9E7D7EAD6F8A9E617D6E
AB61B56D545F9583958C4596A0847261588985B0605C8DA9
49718B4A9E5D647D8B8A8BBF817E7F80808080807F93856E
8A8C8188597EA800FF7E7FAB755D8761918F897B8A9B885B
797C58A186AD7A8281777E6E80647D687698978276A97088
7A767A9A6865759B6B74746E6F6A97BB6C51857088816689
797D888B9C7C95696382837B758782837160A279A276A190
8896838390939186AC6A6F637A8EAF6E8CA090937B818080
808080808250867F84967772857C81487482BF6E6C6C6A8E
A49B6880849F9D9499899E5B907D8180
8367B4714D8F9A887C9D62A48CA492AE7C7563713E6D9571
7E7087826B8F6FB000FF14AC75788D9884687E948F78B48C
7D819553736B9B78A9817DD9BBD17F688894749AC85C766C
896EA47981887997AD8C9CD4947E8080808080807F9E8558
A292696B53A20CFF00C8787D49B384689B929A767EAF5396
72A18084468180807D90AF8F916C7E8C767898A96C729777
998250618A844F7D64B174B37A757664BB5B8575856E8579
7E978173839C93848B906B5F7B778891837987806F60955F
4A7B816D8D7BB5706892979C73765F779D535E8A88808080
8080808080867C6A8F878D7B86844FB9FF8349786D9E7E6F
6852B97799AF817D6B85984674947E80
8460BA9279808B61408E8489B85E8F6D5F76668F674D716E
938E628D68AA49FF00FF00AC8368776A76907999A16EC779
458D7E687974778482674FC37DBD637F82887A7A5F624AA2
8F5E8B887D88958AC92C388A7982808081808080807C8590
857E6A828666A163FF53888E7D9DBB6E848F52788FBB639A
6AA27A5F934C887E7C998B72756E92759A6987897177817F
6395B0908A778B97796F7E69726840527B8B6880718E7674
796F7B9F84636C769E8B69A46C8573887A7C5D757B7E8386
6D857C909281798C9A94A07A83766448768A60847E7C8180
7F808080807E7D8A8877719D8573A37120718D9B9083988C
7E7F6258666D978C7079AB7B7976817F
826EB24165878A86309F6E45757D559EAF7F737898767C92
7D8A8AB17CA545FF009B37A36F8660A664986AD08F4C9C7B
63648564BD886F87906F4EA6C6D6A967BC737C81865C8E9D
5C99BA838DAAA1AB91438A7B807A818071827E80808083BB
9C69707182656B5DFF0093C5388BA77295827E815BA79174
AC9B65469B83818083736C8C5E646C765A838C598F889481
88A073AD96879397AE8873687F77B7FC6A776E785D7D7192
7C758D669280828D478480947E6B938F7C836F8E8D7F927A
817F808C8BB1619C9C7CB5A65F91855078827D7D819E7C80
A97A867F8082898F8082A07F9458B27599AD828F9097825F
9D60759A955F5D5DB5986B9272897E7F
7E8B896CB87E66B83B8D866F808B74789977728687777A7A
753641776F5AFF1B8400799E5C867E8B709C50AB9B52A794
857C8B738F9335B178643FAAE99E8D2890797C5A9274A619
809E829E617F77973E4A7D7278B07A81717A867F80839997
6A5883757B406A81518D63A19E59B36D797A75744C876A8E
9BB4527A84897F7F817A6F68A57A9295955BA4547E7C4675
608E64A194826A7F9D8D974691920067627C7A8E84908489
7C9A7FA02E8A7F64D9576A8B7E81848D90708D838381916D
727B7F776A75806EC1738288AB8D8892826E9DA489937E85
619B62857F81883C91787D9977A08A8E975D4773708B7B8F
865DA5579B9C729AA64D8F5E6D61847E
7F90457F695181977473797337734740B662937969798091
CE7F8E6F9C9352FF5C006D84698C788F70C956EE2099C342
FF04C168BD61B19C5A835FC9F0A671438F667B7D57767969
458F8087B95688987784B57F637C817D94715A847E827980
7D8F749372AEAF757BF000D1808B704D6B855771635D7E6F
84994C4EB8848081817B808F719971786E84AA956E956BA4
7AAF73B5A37A749C916D8E836C70DA7A9F93627A7C9E87AC
6A7B9E65C99A8584569976747965848E79859C708181834A
6EBB8CA97862748197738190A48A715E6E80927A5A8B7E7F
857D72827F7BA18A75777B8F8C9B7F7A659E925D78928989
976B77878070919E8A9267A4A279827F
7D9E48A367796983A45F49646D9898817F886AAC61877464
6F91429447FF00FF980080869090944A8EA44442FF707251
FF005273FF30FFA37A6292B1CEA86C1E90886871A6758493
6E817E6BE7618F6B937969B84E5D84817C82817F80866EA2
83677F8B96757F5C872D00C2588BB87476815A7CA07F547B
98878EADA8B87A82807B9E896298857FA7A9928D6F7B6C4D
796D66827C97809CA97D849E7E668C7C97887C6971897865
98938DA95573919B89739B7F9089A673947E7664897C8AA2
79AD907B728880827A687F8A699291887590B16B5E8E7D80
82838082817B858782748B8988926789737681884F61816E
87937E855C97748644737A3E659A7C82
7CA335847B6D589E615F8DA29277919797825B9D55938856
C494586E70002DFFFF009789B5A39C579574BD00FF3896B8
9F1A53AEF11BDFB65FAB63BA8AC0757FAA64888A6990759A
00DB6D7F54816A96889A5E978175788186827F93848D4399
7975978A7C8B7489716D2AA58B5590637B886C8F9D7C5182
A58D6F699235887D807F8C824C80847761789C54539E44A1
6B7B937FA353817F87899558A2C98AA1627099898A7D687D
63988DABBC8C934C57A679A786724F8F8460978977949F80
8E7A4F857876798084AB916B4C73968A6291747E9E7D9A7F
6875824D7481B27681996E837E847A909B916B6E75858591
6F798E77A99E5EB69F8C6B8FC966857F
7D9740B63E5D63D35C829F86809E788A8D6187747F8A5578
CA73694CFF00F900FF009699A0ABB34D50B07B37BDA668A4
995774B34787E99945676DB19ACB8393BB789D7B896AB788
60809D7A87429B778E80827E6E8275984F677FA083E18677
816D8191777F7C977B35CC3F8B4E9285B46A985E73B18F89
749D651D72887D807E8C549094859FB68663739A93838472
9B956D966B5D8F9F938D6F7648725242A6827F897B749088
A08D8D889F97777C9A596F6A5CA0877F63707F8D838E9484
97838B738D7A63848A81746C89679A7E966F95887C846B5C
B48B8286865A4E74807C7F8592867F6E7A6456A07B808B8A
9096936E7EA59B72619485847866827F
7F847E54AC5C7ABE33929B4B9D7F92A977756C78855E5C7E
9F575C7311EA0070FF009067B67E9E623FFF5CAC80858D76
8DA28E517CAECF7A7A9C7394A27E9A8068AA6E9B905D73AB
A1875A6B89789A86A257AD93828561C99389837D89C85390
7D837F78698E7C74A1565B898B7E8A7F77E6996375A3CE86
59BB395A8645867E7F858978756790616E7D7C5B8984727B
886A749F8389647989A07BBFE75BBEAB5B7C6E798B9D6D9C
7758857A849B62787C97958F68809F7B8493548B6E6F3D6B
89926E85908C784F716A8B5C737B81675B8C5C748181767F
93387B7A6B8955837D817F887879607C7D7E6367525CA588
7A5C977DA0913F67626CC2AC93977E81
79A27D7C886EA0A960586B958A60907C9674B96B8B69859F
837478FF00F45000FF1AD0378A69BC8B7EC14EBB5971A2C8
8F77694E8D84E29294878E959283A66F78756C8C8E417A9F
94A5A47C5772887C91429E8176787FC87D7A6587849D8A8F
7D8081568C5D73731C98009C7A8CA07672319875739C6F93
6C6E9185C7868080827375808E7476959A808E6C8D8E817F
67917F817A496C945882A863738D4E685D766E7760949D6F
8CA06B77777F9B7B709285888B6D745A8A7C7D549B77A282
4C835EAB777C8470A07365857C47908B3662859A97957F95
7D9B867AA87F8981877F817A7E867881A45C539D878B9045
65957A44B2903B998A6668989059847E
76BC5F8F697350C0836C816D7767CEB079815F9B8D6E6C97
B66D77FF2DFF70D451764879878061977A7C79A15C787F4C
7F6468569B8CAEA3698B7E957D84568C887BB4407B518697
60908B5E80928E70678276B35A7381799668718285775E81
8D75847C946185794EC300CE68C29F668488715C7B927C93
9F4EA454A8B77A80807D797984737C6376636F68737B5339
8C856E7966458983978A74825A7B9290837BD17B8A75948B
7A86808B818D78648F695E7E8680728698A388899563B989
7768767CA34DE88A8E3F9D65A693899E7CAE7991A482817F
50809998899E885E7D997784967B7A5B7290708A7F897D9F
8E878A834E6E677588868F8F7CAC7A82
74CB4D86AF7E80BD767FA07F8B718D63B46E54508694AA73
934D15FF00FF38C35000E4FF00ED58976F7D6D8E9065985B
9679A6835B83B96E90AF75A4A4B53F51D887808EACA8806C
A03F9660718A6D9086628382835F837F9E7DB2A9C7906371
8C70A2969B7D92808C68AF588B075789B775897B70785685
888B7A467A807F807F83986C518A9E6F7D8C8B57797D977C
966D6F6E83937F668952A110A17F44828C8E605186947587
8097834B5DA5905B656B739A947B8BA3ADA1729257957985
929D789ABA877C7F8A6D5873AE669578957A7F8184758280
86809292836C7E8176716D9976848789837764098A967596
AB807DB986944D77B300C27172758180
79B243736F8563B979AA8A79B45AB57B9691A4817F9CA880
8A3E88FF00FF1A7E67009CE1009B8A837E895A98616EB361
8A916D8054628E9E48946A9478E27855967A7BA165818176
768077A3944A7268A08A7C81838189867B807C8B8A6E8577
82838C70856287808F9069E308A0A77E7D4D73A4718974B8
91963C73806C83808273897475769259708E6FA46958996D
93689D9E94847F89739777A09F929C949DA1A9806A6C6985
689A7876734E6D88915871A07A86888C814E8D6A7C528692
7355AEAC98A06A8599837F93A5D485945C678F7C80856771
7E83866B9D7B79878F90898C9064725B968279984E7A6E47
8CAC716F957075907FBDA3A6C269857E
78B570BA8C9C76C29F9D68A59AA59688848E746A84C96F7B
B522AF7B3AFF3EAE7B1CD57C3969AD6B5B627A8FB5369F56
C54FC07AB77B90828CA08D864C658D5BA278AC6F75B17651
7F8EB6A9415A8374837497817E7E90897F818D5D68A06688
985D8F9A5F618785757F7B7285A0689363A94E7E77916DB5
AD927697785C857E807F608C5FAF79AF946A639E7A835C66
9F776C6A7576729063878480833E7877907F5E9D7E847174
9A728B7C8092715F8D6E758275857B896A8F6E86947E55A7
6A5FBD66987BAC7C63817A9D9C995D8B5C9E6F808B7F8382
82755F919889879C867985887F996E808482876C916FA56F
9073A478747284818C6F677BB5B97A83
81817488A146863CA184816C5E616E7A888C775997867E77
46798D579CFF4DA69B0CFFFA028AA28C4F9167B1B2938873
954A76745E7593727B7BA9905A869C66A0A4AD7E9AB46A9A
678686686D605DB7A9A263A88C807E7F837E587C9B687F70
80857F7D92798B9389857387707C036287BAA4B063FF4E69
798897A35271807F7C989CBB8978736F728B726F90989D95
A55AB47FB66A7969925D48EC4375767E65678B7695678965
7E7E7C8086808D76736E5DA5926F63A38299848AA26BA097
658CC175967A918375876C56895A7EA06899738E85807F7F
862F736B7479777D8072817E87827185866D97877A8A9866
A96A99596B8851AF6A5E696445AD7981
78B46D5F948065846D728675796CAE804C5E9B9A84CE7D8B
69617074A9B80090A606BDE30098978454998F759A729284
7E81986A8C7394709B7C9D76669E7F6C9462BD6F87BE9278
756C9E82425EC4948C4F857A8080807E8478A7959783917C
7969837F7E8A687E82888A94804CCC0CA67B5F9575A37569
90758658D05386807E8C8B727C39A87B867B7D966F8B7C97
77586A767B85A4846882777FAB7BA4899F90A2748B857B86
74A48E8C6E79987C5B918D818C8485768D6372757B977389
8D76537E707E48796A8E7995979D77693F9B7C8080808085
80A59088697C649195758280826F769273857D6289836B99
956E89A05F9A9A6A749AA3857D6B827F
7D905662AE717579727AA26BA3AEC2916E8F9ABA49767E6C
62A889C4569F008ADB38A3FF00798C97708E8360737B9D62
8163939B826185409C797F984E9196838B9A8D8353986D51
7F6F8F5C5B75B567A27A877E80807F98869287808D89747A
7283808180868B94938B927DA571851CA68D757F819F686E
AE149B657368827F7D94798985818B8E4F8B9FB49F7D6A6B
829C856D7CB3747F6AA07096797D749676A7716880617791
6F788974887F7C8B5D90876D837B7E70778176887F856E52
82797F6F7CA79E4D89726A6D76A865889E9B6C8280808539
7C607E7184736E807D807F7F7C89978B7F8E7F917D849D6B
688F509592AB89727E7A8D85957B817F
826F80A69E648A9846708C6CAF6CD289486670928C9D487E
37BF76828E803CCEAE60FDF11E3789A45F9097687090805A
777987A472558E7E8D987B83878F867E86748C7782747194
6871697D6D855578688A887F8080847D63AF75857C897C82
837778807B8E577B9359798C857A68764B7D668D4BD36038
7F78835BA55B85818275646E6B7A668085705BA63D7D8284
9E8867609064AC837791A37174726C5D8B8989AB89636E86
808D72867F7175787A856A7E9D81686078967C887E8E819F
749F909E777A798A75508F6C80A65A44908E828080807F91
96AE6093817B997E809796858E8B826C86697D6882727766
C65359719277AF527A9F754DA3678480
826BAAB2AE768C845B7E77696737917E5C8E5A81916A6F88
785685A1BFB8714C87C1EBA5413266727EA8714C787EAC87
6A7485A1878F8C8C749A758AAA9B918BA29DB282A0907166
637D787D5A81BC879C977B7F808273B37A8F8E969D737183
77737292918A5A8E8D927B9187789A961FB87B695CEB5D81
BA9588819FC27983856556716B7C9B6FAD89806080796E8A
8D7EA273917A6E799A83838E2BA46583766AA2968C977C83
946B8A8166726A8582765A6A928EA470847579868678806F
7E7E5E6A509A849E75909E849961828279777F84807C9E97
57747E83926789759A7A70819D81747B95938E779D928975
5E9D836FAB8C6FA6A37980775362837F
865E7670A8597697828748D560925EB054B453AB779051A4
609723A7530AAA0098A6A97B455184688A9A8B8E6C8A9A8F
65867271975093908B7C6B99599C5BA0A67A7D848488755E
7E8997766D62597FC9887F85808269C7B78D8F788A5C8C71
73846B9F7D877B719C939073795F91BA3CAA756364A15C3E
7C906A916C6F827F836C609187687DAA7A6192837B7F898D
84855E6D6C738E5FAB544E49A19C7990938B836990737A83
7A889A6F6D748C62A17A849D7D827F8A7B8F818B775C747F
778E8379C27B7E736F796F81796C61935F73816783828082
797E8271878DA0787F82687F837092807D86A0726C719194
8E6F8D8772AE904D506A85C5837F8080
8462A7A18743BD7952797B767B7C88A37A6C8C7C94807298
8E95993985005E28CE71AA97546C89938E82859974997F71
67937C71996B6B6D7D6D5E927DA075AD887B78BC858F778D
B665708B7F6291A15C927C5884828A628981838F85777486
827D83857C847B7B817F69999A81ABB6B99D79AC6F8A7282
8B8C7B957C7283807F88878E7D803673747B67798B7D687C
7374EB90659B586F55878D736A9B969188638C8F9268867D
77768B69858F6B7E6C6A7286878E9F836C8D619871708981
6B4797767FA959999654A71BAA6D87686B7E8071856D7876
9543836C697270777F88937E89916E8791848B8C87647F5A
509F81796F838E9E7C9663568F5A857F
7F7E8CAA6F3194815D6E92544573965F83737086897DAC79
8FCB718CFF373C7BAB4D6C7438788B7B78858374AB6D8F8B
5480758A7D5A6F858E806F9E4AA370708F73879179697080
AF77973C90847089A79F7D8284626E859E94A99764926B8A
7A8F68827E788E887E889C857063C0977861888791A290A0
738D6AAE80748281855D846FB75B8E759F928293A38A717A
7C5A619960807F757A7A828B948F849F98A8657695997E6F
7FA16C8E90868882796F7B9A777A799183708278A0866296
83906677938A61847F858E817B826B587C6E808082757982
5E9F798E907D6A83888E5F8A7477729F83988589A66F85BB
A87CB0A56988B848898D60778E967E80
7BA27EA39D4A608272B4654E78B983A282BE58477F7D969F
5EBC6E00E9B12BA1FC0E83DB4C6B7F9979AD796E6375889D
646E787A6270837868827373857E688E88A3B35B65746F6C
62968E667484969EB186807E8080808774807F9D93926587
918875A3938480858A8495828B6E8091848E6F808D897140
88346DEE6158847E8374538B7FA27B92B3849A5A8295B274
92827D8F8F71668E6F83568FA8919C597AA269846C797E7D
77788F79945B6A7E768A8A7D526882807C92886D88AE9F81
6D5E7996A8ADA9736F7EC673857782AC6383858080838281
784E907F7F807B6E7C7AA08483848983828F689F7A9B6E98
326972865498645F7F4A8B85A8848080
817D69585A1C8140A6648569875E92795E96996CA2517265
6FA0B200C2E400FF5B7B658D2B70B989649A8C918D8CA48A
73A07885927B7B8178646869A7914851946F8F6F7692834D
8B6CC697856C6B9342D49F7D7F84847485716D926B8E67A5
847275A08F83596D998269786E8659C89475A461937E6463
744A46A94A947D818174B6A64F949E9D68994B87858D9298
91A5957B6C9099A2828167A47095A17E8D59A68780876F86
897F827A748E858F926C6D7B9279836965777E9490748BA4
8389A1678478809E867A8AA1929E866386C58282836D709F
9053817A9D8C936D798F86697D716D9E6A67856F969C767A
5CA576AEA18C6C668E89547DB379827F
80813E7C947EB2669E8990896E8D887979748A7EB693AF81
9F76A84EA5FF00FF00CB63A44A718C8C6D9B6792B578997A
666883B36070976D947B8B8389A36188778F9F5F829E813A
91528AA584869382869738878162716C9B777F7D93797D7C
86896A727F5B9D8C79956B9186913D99760E5E9E799B877B
7A37606C9080807E80818E647C694D646E6D6E979B7EA765
6588816C9177B38A7D8C5A466F306A6B5787746A5FAB7383
9575797DA45B966B8E7B7B988B8262AC796EB66687758184
78896F8D6D7983667E79908A777F9390637F8F7E83747B88
7E8E7C63839CA1747E867C7A988A8989837B749D727A74CB
818A8D6B66684F617F91928F9B3E887D
80836986796598E7959672A3825DB96E79A8696DB47AA3B2
CC4C3CAF9CFF009B0092B0A43FAB95809370759585888C8C
8A849E726399798372AC688E5A9C836D7C828D83CC4FC64E
718181994D6D869A6B9D897F7F818B4F7774629072967CA1
9181868375777673A08C83798D945F00DC00848B9A416F40
8D3375B74B967B80827A62748EC26A639F9996566F609A74
4E72818376557B4E90939C8736697F9C948564C05D7F8D85
7692999788787D9A7271796964778B709D738F766C869373
9B93638C929079A66860B17B7D898E80D250798080837090
7C7E6F887B88716F7B7A7171777A89768C8263966F8C7564
956F888FAF847B7E7C9371916168837E
81788A8B9365666EA43BA467697ABC61738F808D98839F6C
B49C27A9659D7A7CA9BB10CE55717AA15A8CB19D8D7D8B7E
645E726E90517C8162857D9C87B5698BA3A76DA39495897C
B595B1837F40725C723A927B8084707A718471896B99848C
81766764939154A3817E917B83718064FF6C61636A70A0A8
9A7984CC6CA27B8184677170888B7CA27F512C398E6D7A6E
8195548F6A99887E82995D767C89998080947A6F7B7E6A89
7A6D927E788182946A67967B62B47C7C6A8F7E97755F917E
9773925881729D9592746C65935D3D6375818D7F80855481
6D7988687B808D8893708784A78475766D88826B967A8950
73927A97825A727D7C9485A266957D81
79AD647F824D8251BD84879278A663A0926B6C53954CA47C
52BCDEA79C609EFF827E00D3554DAF7C957084929C518E70
7B79937D8162956A817A5562697C497F98A37A6770686367
6985B882816BB8804A7D907D8192786EAE77789477929274
7C7498987782817395898876867C86594E5F5F9D7D76CD95
86A085AE81858181817B72807094886B7E899C5788926847
975CA180634578838987728183A09678767797A4B37C9675
7784889E97827E8160836B876D6F6B92628B7B8C75938787
736881826274B97C9BBC9C7689506BA28D7E877F7F5B5DC2
7D9786739D7C6D9094838F89807380968D8F6887867079A2
85645B6561969A7E787F887AD1838280
7D8B9983C34B8B659148798D64A7638E55797C5F92848089
F100FF3B9D8D5EB3E200ADA75D1C67716C9482968675918E
757D7A867A9A71847C74A6977A86A7874EB678A88262A9A2
AF6F72AB6E29A6A888817D827D724B808C69877870958A9E
81907E86856B826E76938B8A79A16669183976727D66A088
9B8C5FA9934D887E836A7E5B744C855E7E6985969658627F
71945D826E957C8270618574917B98B05A6E717F94858C91
7E6F7686838B8C86767172795E816B6C947764617EA39972
8F7291466D576C6F8A9B698B907C75C17786817B9D837C8A
8164786C7687837D73879D6B7B658B7F7D718977B39F7F6B
6E5A859A7A59C16D55808285A2BB7A82
7E838EBE80866C989BA071C8547C779D539D6C9967A98555
9400FF79886F71619C4AFF460E869372977182686E7470A1
668262927064B176A5698F8B74797F8964B18A88919D789A
A4919E4E6E4B87989C8081836EA2768B6E74B8517D7F8468
6B846F818963948778835E73BE675BD27F49806EAE787A69
73989CE4818C7F817E8D607A96926E798F81829EBA74919B
818676588694A29468947B6BA6BD796F916FA98E74843D86
9168757E85758D6790846E6C9A819187A4717F717392A07A
8BA77099AA708B8F5F644C8A9966858C867079818C67868E
A39A734F807C6A727B787BA273838693907791805C70689A
89748A7281869B866186C18662B17A83
77B496729A757B8B998B6F518C737C8E386681A7947CB644
A600FF1EB0917E7260B522CD495021778A5A7B7D877D7D95
6C7873804C6D6279817677938A926D7D618080728C935671
7A8EBFB967777D7E795D707993748D769470BFB07D817674
8872837D6F8F9B9D827755A89F5E8D84DD618B763464487F
6682A37EA357877F865D715A565E76A16BAA78856AB3739B
917492837C8E76969F62897E727990628D635B7989789A91
847A866862826F8E647A65719092666998747D7082785D75
9A957B626286AB6352729683867A6C81A176669F928A967F
7655818885918286757B808A7F858D767E73CA7379866573
8F978FC2AB48777A578982747A848080
7C9484ACAF396263A94F7D7A7577A660899BCC68A08B755F
B200FF004C9C665E5C943EE7270F3377756F9B6B5D76928C
6E6B7681986494A56F6FA79571A16F8F56529C96724D6E88
896BA95D6B7E8878D03F4073258192A89170918882968F7E
87777F8E8E798487937F5481A6848756FF9E726E4D75896B
5E73888493917F837F867C8F9154AA408C8E61779893604C
676090867298907E5176729D5CA68A7A746A6379428F8980
727C9879A37D6D698B8B758E7D8891797BA08A697B7B977B
887A48658E4E8E6CA49572A8787D8885586F768492738A77
9C7FA77CA58B717683987B937991606385637B92878E6664
7D887A79B248939489A3807384987D81
807B7074A48D7A83C1978671486796A99372748379799B81
C900F30C55DE296F5F74A6F54453458D967782757E807D90
54768D6F6EAF507984896F8B8C93817F8E3772BA90B26F62
7A408E6FB999847E9C8B706498727E9C7E58787E7866A284
8371808D937A78669A8F8592A5BA8E00C779897D83729862
B8639A4189788282836DAA758E72B275447359817E667A83
AA745A7678999265CD9C878364689D929D72A367AB78A38D
6E76656C778C83716775896B77907291906A9BA364BDA36B
8783946794896090879E728F8F7175916E6B957E737C7C8E
816C9886859077836F7F7E8484766C9D767D7096B4568E83
8E9680857E9BA5565884B09F898A7F80
7D90745892BD776D6181DB777BD45B8C5964AD9439885089
DB00FF48A56D57C84A63A7D41CA0209D5284747F98729083
7C7B8F83936072875D87979F739A5F6C827266987E88867A
47719F5C72498068A5646C7E737E7F878775708F8A6F919B
668A7979719B78D86F92678F75B156595F67A48D51779667
6D428D628D7980808367A87B5E8282917F8576A69A995EBE
777B7A8E838F6C4FFF49AC9DB482AD758D5989B17976526A
708A7170618183745FA0898C82918389757F73888B7D6B7C
68596E6A8E81C084A97D9160BBB05F426F797290988C7C94
767B8884845D755F7B778F929C877DA67D9B587C8496737B
7F819799A1648E7C978264AD887F8080
7F7DA7A083785E6A9C9BCC8A956D85BB73AC856F6C798653
0340FF13215430FF00C963FF00AD52578B758B988D8B978C
677391AD7795687F8C89759E93957B944A8BCD9A6F7D9182
50AE9DA5907F93A69767789E857E9D928F548F61828D967A
9B887E71779C7D657B99985DB0A550D7579168694F928984
6F94918766AA79837C97A472A79F8F65686B75AC9B8A8468
8E84717693986F376E806B84794C7D9D7694A1729C7FB871
734B76A9868E7A6871858598887E7998A1638D85A37B7E63
89837F3D99754C43665B7F39B85B7B806D808675A08A6D98
948A98917E6E8B5B7F9E697F9B8C847861795D77A8A06928
996DA16FB7855F9C9A7D7B778B66847E
79A76851A0AD66759165A0907D807997869897A468876495
89CBFFB148E000BA5BBA58C300B9BB36867551A68B86A3A0
21C26F74985A5B796F819BA36D7D8A7A8C9899A480988E82
75858DA4718F6AA0888E935B86799195826F699F7C718373
856A8D919760747D8993736EA09786E5638B688545915056
85A07373789E7C81846865956D945C68987C8764B8858B7D
559D79639687C4A09B8B4D686C82AB4B729E60A43B7F7778
95968278866B8D7294748B658ABAA38D7486647D786C809B
8F90898BC8765B838569896B6796768E7C5A6C90877C7C95
7F8473748C8E76698B8582888284778CA05782839483936C
8F8B80977C9B85828B6E6EA18C4E867D
7D88847B87655F9B8567687A9D47816F76918AA6882576B7
599D3EBD00D934C5848D6200E0A56D97988B5BAC91AB6885
769F74BDA6636F7E6095768437846171837A929D7E7E70B0
8D878451819E838C777271796E7F8C8CA7649D946E649F79
90929B5F797D82709E6B5976C457856E7A7D7D707498B03A
745DB7755B9E7B817E8D725676757D7177836C337BA4897C
7F7955BB887D655D7288DE836B572C727F7287A98E6DB16E
958E95777C8C64658357A676AC7D887490817D8A55655281
7F737A724F9493AC85847CA9B566725E638F796B7B968677
867A909394836B7F6877968E7E7888848072816B90836795
467A548A8A9B8F627C92758787917E81
7F819D9E81547E97848582917F8D918C877673CDAD87758B
61E200FF4287847A693DC244E34D6E91828554F45E956193
8B488195915E84547C7F8495604D8880969D5E9C559EA8A0
8F818A9D5C968D7B705BA5995C858C7E8B868B9C8078827F
61906D8D7A7B8F8DBC67BA78AC0DBE6B4D63816F595E9174
A88F536271B07B83817C7A797E9B8A9B7680689072627B4F
A172765E847681797167BD72C5909A86CC7C7D51C054716A
865A7698B45E63A27D8C7A5F6A7A82657C876F44996D6584
4D547B6A728B91A749787A916C8081947392898974947370
9662867B7C8AA4849D755FACAA7A717A5DA47A8E70BA5779
7092928CB7718A6884749369A6967F81
8179798D71885A768B7C85668B529889535450AF708E875C
A09C4CC17B60BF119F4C8C946486947A705F3FB8708E5F8B
7B9281A176856EA59F89964F65849876A04E8D857C897577
9D6AA8816F7281877E6D827A835B956A797179795B798593
8594648083AB7FB292AE5585186A9CA279528A8281843939
B0976C7B688E7E818272896178908D7578868470719B8362
678969A771A76FA685A1009E936C563867716E3E7E876BBC
82749A976B554C9E8E6F8A6C6F7F9BA086B160A5AA736797
8D9071928865946A877C8077927C826C8C8A788284637566
807399A78B8866606D878A84856B85848587846971539793
6D69B47D9C879E89897A7A7F7D937E82
7F837B6B737C3F45BB69A1698A64736E5D8560AF568D9975
710D7D24FF00FF16FF5AB870817A8B679A826995938B808D
718D888C8D946274838485566875867E778D88727A917481
768B687C7873817696677B708A669870837677917193707A
97946278884680A9815C878B2A9EAD844485755F588BFF7B
A672A86E8A9E7C837E907B838C74B07D876395875A8C757B
8D7485A130A88F335D77E5BE6B1DCF475B919F7672A5796C
776D802A7BA088877E90598168529D7583809F9085809994
718B7B86848379A68A668E7F9574858478708470697BA383
806F706D82777A766A7D687D7A8379815DC56091537E7889
84717E9DB280877B8D9A61A48367837E
7B9D889E818D389F846385796D4BC5634B737F7C82818C51
38D11CD7F108965B85587A798E5A839A7A5978665CB7875B
5BC16E7165B0697A7B829177809E88A6735F5991848A5E7D
7D698EA064A5628B87AB9A8E6D8B6F6486658B768583817B
706866A0858D685F8395505F615B907863615E94468A7E7E
B689804E7A947D828083638078A79B6F546F68816B729380
7E92E44ABE8476A56E187020BED63AB47B6F936279A07CA3
B093AC82A989888D4C929989296884A1868779727C898F62
7A7C868F8F607D8E947F798C5F7C7F957B85919878697359
827692647D8C7E97737473908F75B28E8DBA8E84A2727A94
889A8280856C906A8386876B98808080
7C9B97677D828B664DB6A1937D927D7C9B596EA16F78AA3F
E0488D495ACCC757288B5C76BF6A809382735BA09D9A7D75
629177768D6C75827294768572888F797B707491778B957B
66958485747B92709267928176756F93917577A48D7C9289
8B5685899364618A7546BE11B58A6E9B9F65796EC2708A8C
5B638F7C66997C827D949E7B7294896EA0808D899759816E
ACAE95A0669C525A7DB7D93E038090448D5988C268847376
6BC47F73A5847E82546C87837B827C6F89866D937F787568
7A696C6F767575757F70826F71A181AB927C867B9C656A85
84998270616888A392895A518D7F7592A473779E6B4F84C4
8F9491539367799276728E7894947F81
7C969E80948AA08DB5876D888C699C91EE6776A851AD873D
5AC51600FF00F3FF20FF6C6C83517B8F8BAE907F7C3B847B
927FA5867393778970B0425E6DB379846D68A26D6D8DA285
709E4F8E857C868B5C777E957064697E7F6E789480726791
6553785C785F73B58C31A1718A8D98A5955283B06F84747D
89788A7C8D71828082717C6B7E7984A05E786094707A9B7A
7B6B699783867E7E974AD0D062933B893A8FD3759176A06C
876E93A26D6A948985A4808670689A876C70719C7A776478
837F918FA6716F7C858A958671866F887D718883758E8585
7F7E677D836D93869B9378778A6E8E779FB06F7D625D9062
7D587CA199864A8D9076828F7A857F80
7F85798962538D74989E8C96966A8192817685A272923843
26FF910EFF9F00FF40E837A08A9DA25B947D6B7D8E5A8B8F
62877282697A91898B886B8C6B9087894E957F94A585888D
937C848A5E85815B7C867297608D988D818074A885886F6B
B842868860816A66C37B783F87877D9E7C72937B636F7266
797982826C7E80807C94AC8699879DAE8578767F89AE9495
7B70A37351A292719EBF36ABCF6AA99F6B995D899E8A8583
56837F767D8486AB7C7871826A5D6D7C7D6F7D747B7C8C72
888A73718E7D96887A987F848E7D9884947E707A76798B7B
7F809789837C8479A5748A4E6A87756E7C674C8D7C58797F
6FA15E8A688751938474688084828080
845C9C8569537469647F49877959A8D078738F5A5E4A9A86
7F6A91A05FFF00FF00FF5F79729A59A0A086618E6C7F8E85
8E938981676E918399798182838D596D6A8865858D71858A
84697C817081658F8087668D81887390937B797C806EAA8B
7681786B4EB800E900FF849FAF7B9172A89E47866B978780
778E7F7A7C7D80807B9F9489819B97B67E7A8286525E81A3
69849B419E7498624CE2502172C75E65B67A6A8075749B6B
636C9B6C897D806F7E647B7E7F8B8A7186688C9B775E746B
80946E83889C888089979979878794848576797A7B8290A2
728B648679866F5B7D8C73B2B652A061985FD27E82A7896F
96A49B7A516E928F91777C7B7A8E7E81
7F886274666E7EA4ACC56A7DA89664B48E8A1B9A7E6F6587
768931FF624BC2069F816AC93A9E814A729988376988A899
866F8C738E9C876976638C917348A45F717F70A15A7E9476
7991707A8E84977E88A1788F7B87697F6278928F8866517F
80C02BAF678C8F769D3C65B181AB8EA96974B12F4F81AB99
93828C6674BB79828088646980A182766B99672986996877
5EA0596C6D6086638C7E9F5C34C7659D2F76FD1C9E64849C
7663978267857588797E75998478836EA9808F86716A7675
8E90868F8B9E5F7084989B7278997F7F699C86705F6B7386
7E60834772B95B84819382657C9B6DAC3CA636A17380678D
989FAC908E8CA46E658E6F848D947E81
807F5D6F798079A48C9C8D84B55D4CBA8088A083809C848F
95B34281B2705662137DA28D50E569649479736C76855E88
96818775835D876F8C95747F72819962659779636D8D7D81
827E917663918C707F75538B7C8874A6856F756E3A49A87E
7B6881844DD96BB9B36C66B09664AF729497B65E8470808B
7C6D8F737F7E80807E8C738886958969867BB7608582759E
6189C9915D678FA28580758598587F7AE8BB659F668A937F
5D57585B6D8C8C908598806F7A97738C7E91899279648C65
8A917B8268A17A7799998F7281728D847B827E6E858C8088
88737E58A9AC9D65909F5E61CF4D567F91669F8D95647C97
773D75957F92928E8E79758E6A788080
7E8C79786F95787EBA908B84A57ECE83576A608B7D528778
889F6EA50CB77AB300EC469F6ABE97526E53747D9F9D7273
997881886F9492767D8C93898470818E6F7F5A5F746C6178
886E738C797F8C577B827FA066617E92856377979A6C6159
5C6CB235FFC83BFF7D5D159CA16EA06C787A5F53AC7E876A
6D7467689268838079AE8C7E655C7C7E78A19E70AA696A7F
8A8D64858B72AE7D5D8099688766439F5C60927E7F9E708E
8C4D9381946F7D88A38C7B8383838A78757475727B787B7A
99748F79687193826F8796727E84837A9A727384795E6580
677589AAA5A956A4657C9C9C245D7483667E78A464B37E86
AD5A8595837888A070788C83778A7F80
7F8466727A7C8858A6814C80825E5B9C9564929E63626E5C
6E1D8C6525C08EED00FFD688E842B84D978A7694718F8178
715C76865183806A8F7680997C95978B706F9284A08F7477
7A926A947DAB748D716A917882948D867A917A8E64940079
A6427B62E81BB86779BDCC8BB0A4878E7F9D8076708A6878
95A85B8C857681807D92A1B2AC797E7E81796A5D797A4CA4
90CB7F71777BA07A777491697D65D765D332C6437C4AA831
69927A93868187887C9BAB6A866A9A9770767E816B6D7B63
8F826C917F6E7C9B71828C698B679B8C776E756386798D7D
789D62898F8B737476926C81FF798A766A806B658D786469
5F9E6D8289988368865D7F8278818080
7AA369756989687F80917E316B6E8C8E4951A2917A758C79
A1B48DA675E27DC2FF55B88296B260BD3D988950A0768C99
619590837B80897F47757E759A736172737C698070948C93
70799B8C8E7A8A737B689784896D8D7B7D858E81A03CBF9E
8F7E91FF1D6DAA80BCB9CB919984A5B0AB7681858B766B5E
838E429A6A857F80836F69A764636F82825A865E857F9EA2
6887826F9168777B6C5A667866756DBE02967774999882A4
14867474968A7E6D8579839579987A567A877D758B658D7A
947D866F89929D8773758B81759B66897B969393707D848E
81B479746E7E71935474498E5FBA7B7B926593776D964C9A
716072817768868DAC7D6D7376788080
7D949860937E82727562867F8A7B8F87A359629C686CB96D
6F8F3276E8C400A9B90B7273E555E7758C618C97C3918C6F
8ABD7E8C8F698C7B6E87808B699974797E70718690728880
747280887D6C7A6E86715A68858B84A5805049AD5197AC91
A900EB0ACE9EA17294739390A296287995866D7F92789776
8C95857179768180817B615B77AA658F92637A889BB0707A
6A7C7987669573A07D93978690A08F4EA61173866CC93195
7381B235847B6E978176A178816AA46B825E86786DA19769
9181988AA079A77F6F907D65A48785797882887D955F6188
BF576B36A170A68D66BF3A5F7700A32862AD6287AF4A5A8A
8AA25E63708072667595816B8069837F
7C979FAD647F76835C8E6A86978D5F6E7F68AB746D658892
6E9565B1765288C96016F21FFF03808E3B89578F886B6F8E
73867B6C6185748E8784847083697A86739296706F7B778D
61847894958E6A66746E6CB28E8361CA844EA9B730D75463
E06BB25AFA6B9D77BE81828A813D58809B908E707D976F86
9F91847981907E817AA5638154777F8C557D8BAE938A906E
B48E76894A617C8D66D55B69849C788A446D463000F550F5
4C64B47D72839E8E9B8FC08B7BA1616F628A7B7E96847291
84807791869B8B5D79998D79716B87999574677A80A1A790
AD8C9374875175927E5D78E65D9169C48B9759618832889A
9A8F8B85778086797462786C8473827F
826F825182897E936B6D8B7D765D6D55667C94926D877FB0
3F84834261438B1AE35E00FC00E4A376079A8C6BAE937C7E
7F6A648277877C71658E806A647CB372939A7A8C786E7B85
5F9372948B949C948F7E8E777A4E72B19914F631AD40E270
2D4C486B6E8F6D7C756382998BA68B6E9A8D924967795D2F
8A5D6E268D887E8083696FAA78776C60AF946D747FA48F9B
B7965F7768694C817A896F3C706598B7761ECE9EC000792C
9E7287967C78A46C586465908FA9806E98848E7D7D817981
6F80648282858B7C7267825A8B777589769282B290755E9E
8EA1476C8F369B7B8B77746967A29F9F8C747CB67F649260
876C7E4A62736E82796F93867A987D81
84686593807E966358A97E6A86854E7EAAA78ACA83A3B779
2D51808A8B9282FA41944A92FF876133B09EA8826F66B291
639E6F5FA27A7E88828A8C83728496957A817A7991727C7D
7C48877087A28E823E84895FA4BAC1673A33BE009500FF77
5976883F8FB28CA36F689F827B496AA577949A865A8F7A5D
92867F7B86A17C817F85919E709B6D788E81637C8D7F8850
9F9583877783778A95A765B96F68D394BABE677A96FF8988
B82CD854A7AB91A5A56A999288A78185669BAA9779838276
B3937A7B7A6D7F8AA681768B718C698481675C656AA1BD75
A979ADA0888690B1AF68BD986B866E7B6C4FDD8A94697C5B
5E717D838C5E7F768786837B77867F80
7D99467B82639C6E837D7B82989B50A5759BAA8A6A71778E
6374677B685B819E74D0FF7E7A00FF8E419B09C2DE60A988
6E895CB672C7BD8194C8728D74857E69AF897F8482877A9C
C17062798F8B549D5D56765F7757DB349428FFC600CC62B7
56BA4FC04B95A4A190763A6F81879687A282396E92858459
848373886B9D7C807C998D7443A8569DB1957B78477F5E7B
848253A657A8629F75887E949A8E676D4342A851D21BFF06
B67FFF4EBBAD65957189918E82518B64826FA09D9B747A78
8287837E908F7F934B74A27A6F627362984DA18D839E85A7
69A85A98C6328C7F859248ACFA5B937F872E797F877B8B5D
809C978A6E70838D786E7F8383808080
7D8EA7448C8277779F87817182656B84B6349095558184A4
5F75A8667471A741E858FF5F2CFF00FFDC743A67EA379C4E
AB6D6D7B7F8790926EC76D92709CA87E68879B9E849078CE
72776A893EBE7C97685F68768BF54DC24C71A3FF47E05A6A
5999636F96A891709F886F76679C7A719887698399898A6E
88707D735D9C7B827D91947B9D758D6A7B80876C728AA270
7786857F65A0795785B24F7C434881518B2350BF40B611FF
00954BA0D30988B82B84829083696773A16E828A6B497E6D
8980877EC9877C848772777D948362BC7E7889745F62989B
6A6CC880429344A15492B89B64B260AD90A05B7A8B827390
8D63829C6479C58D48766D677B8E7E80
86576990806978895AA37E8B7151589B5EB2409071756689
71ACC2507C8F7C7D98A900295185DC00BE511B134784C38C
286B84A187617466C281868764905A6994847A96735E868A
86B065A24B9EB2C76062753A76C1437A6E18FF00A30DAC61
507E946F5B6BB88E95619F546D7F5F68A9AE6B6EA2A08089
7A8B8B6568807E808272659B93907897707E927FA0729076
86A46E4C999D6D7C8F78829C959E729F52F6484479539248
FF00FF36CF8B6B7267AD658B6B74CD786990787A77808085
8B709CA0767581869274A462BD7972976395929F9892686E
728F2CCC967B8E40B18123C2D48D8A9589888B717091994C
6CA883968B845994B1728A6F8674817F
7E8D87709B745BA07B5D80A26573929F92704F556C484388
994DC0897D82AE63927C00DEDE6440DB12FFF600FFAC60CA
9D6BBAC2966B89C49B906B7C8C66A09651B77558A47B7E79
964FB57EC51DB09D7655B1C0685EBD5D00D0F6447B4E5151
7F209269B50086767C8DB87D7A7D7B8690A494708B7D9893
72887E777E887F80836A957986AE6399928A89847D746AA0
8F86926C668D4F996E808385686DA16AA770B5729DF97FC3
356300A2C5DF29795FA0296C65776878B29FB35571BE7174
865A7A5B888B808B77A6769385AE817D84887D408C6B808D
5B7E86BA7B7C7AD73A91007F77B35C77B9A7807D84758192
8897BBBD7C828A788879A17A7D7F8080
7C92948172A96675775865837EA342A4956D71828F6E7780
985C9C99776E759D82835FE41949C19EFF232FFF00B38000
589E996695A89039BA9E968DA94391828C8D697367958728
58A88152FF009BC55278A000A5009147B65DB4879A3582A3
00BD9207E3458A7DA84C6B998A7996856191B2827B7F9F80
7A7B8D717C8D7E80836A817D95807688A2777D9B839CA784
64A2837F74898557A98C6582897B8D807C707101C975B6BA
817E562B24FF95B561509688918060757B7459727D90A5A1
8B9692798B816AA6AA7F94C79AC773867ED92BBD649B8264
7A78B27282AA4F9CF970963F748471847C89616C8A75956A
88A6546D906F9E8F9078747D7F7D8080
7D936E809B95727990875D9B6199777DA94EA89188A3657D
918D3CAB8769A666776CC3536A6A4AD43BC23FBAFF4E71F5
00AF9D8A6EB0809D5A6E2D9B449E74BA8571807B6A79968E
45A67C1EFF04B500ACFF00E275005C8467936C6C87CA42A9
49914AFFAB75B67588906A6BA2969A706A8374808A875C87
8D9D8D8372807F8084686F7E7195567895789477ADA18888
8D877582776C786770A45C6F6A996E7B52899CC288AA00DC
778E5A50D800FF00B37D72857C69557188876274A4776EA1
887A787C979360587378726296489086655DE3007B598FB2
9CB17ECE75E43CC55CE051A457846860977B866A886B5C72
755A7996717F918082777C817F8D7E81
7F806D8E536A4C6D996E72807AA228D13F68985179519A77
9C6F9F828A88924FA3884F56876B7B61C088FFAF258A00FF
56638B98767595846B96707059A5C3935C91B07E7D6AAA88
258E81626C88DF887E8F4BC902728A00E1FF4A6C896B8400
9472839E09B2A6CA76B388A5A0757B489589695AA391737F
9C7D9580746D827F7C9B8174707C54756A76A37E5C82966F
8E83889C7FA3767C94798E649E6B86916C7C9B5CD907F120
A5563BC91EFF00FFBBB178D371857074A27CCB8F8C6B8566
86515F7D629C8C838C73699390A66C94B47131FC58AB70AF
6A9B6DA8CE73426C7D70A74D7A986C8B916AB0858B775D84
A77D7B8281757F877992967F78818080
8367A0C47C7E8084519061487EB82F708676AA977F60AB92
93918BA2535E686B7885399B626A5DBC480DFF35A690E184
4DD24881937A8C7B854CA75E85BB2F4A5D87B1907B4FC24F
88529C234FFF4DC6009B312BA400E16573FF90D4268AA45C
7C8A9E87137D6E7A84808F988655A79B74A75C9F69898279
66798A7B8177817F817F7780837EA085BF9D916B7B89989C
7D3D86BE72898F98869898828D769F8A707F917E6B6283C3
699373CB415AC5A7FFD39F989D6A6A8C83828D696C54B09C
4C7A9C98AF816DA1A1937F8B8237C363BAAF269C9A938558
7EA91D6F8060E98071A44F7B5D9D7C50AA72948F697A7E8C
8C83A86F7F857B8B7073888B766E827F
7E88927C8D5AA78365418176BE6475A971917A91958FBA81
9B79AE6E8A66A18953725D885AAC38B6878C00D632813676
0172B36C548C7F7D7D74884F531E77D86080619B6870B093
418B998481FF5D4D92AF00C6A000D68849D17C00ACB85B86
007F8DBF6E898551869E659B7D799476946E655A8C7D708F
678F82748A798180846C5A8B7D8C935D5E8BA38E5C806D93
5D5797867E779898A26E955FA36CA57C8492AC76879E879E
54A70974F60084DE66DB48FF9F5AA4AC8286845F58AE594C
A68473AD5978AC389D9F514765907B665CE17A856A8750B8
67ACC35026F03F42ED8182978D82617F8A568E5789679884
85AD938B6B8D8E8D65858C86776D827F
7E8A5D8998969E8CB11A67B0BC7B50BD838048685F549575
72706AB16783776E92C591929A99599B8373B79FF2346BCF
260056A0A951CC339D70BE888CA798245362C274808AC768
20C10065934FBD5D7C8DA660AA9268A8925E9D9090007B9E
224E59B4A38C4D8093867BBE819FAFB6828B6760977F707D
899885736B7E80807F859472899F8AAA7DEC6791588D7394
6FB381A5B9704F8C73726B8E8E786D7E9B985B8C8E7DA5B1
BC90E4127F533D2BFF4356A36D1CC7BB71839A787B5785CF
95649647B2A8609957BFB6694D8A915FA91CA0D93F827E9D
626C8CBC6A5BD876905A69889D64538C80B36D94808F8B75
626E5B7E4E716A7A867B645B868B7F81
7F8093AF737758787541D91C697A6E7F6DA98E66629F8F80
AB8A92B37978679B5BA17B8B8779695E954FFF149BADBB76
BDFFA9A0367172A29B448799A08078BAAB8EBE793EFF4B05
A6006983A6B4CFA27E71D85C75C727BB49CE4EB869777D6A
969E9236AC7875719C7A65858C87749792B0696F896D706D
82679583709D7C817F838E978F7B61BA474F8D996A92AA8A
78249D7C8F778779778C647963AD778EA1849A8F9281816F
967576FFEE5196FA43D06BDF0070AC3F7A85AB61738C724E
75C5648960974697A35974CE8485A18B3DB08D0A8FD033B2
6D8B6A5F52479988828193737F627EA5A458A5898D7C7A9C
836F74819D99709EA56981849A808280
7E8964805977688871456662B47D77A3599451BF996F9AB8
7A6245875E8E99838E855982877F7E6B9EA79300FF689539
FF8155819D7F17A07D748FA66590947F1DFF7A8BFF353F0C
88875E00FF00FFDE00C094B1D0476FA46380D35BAC94A8BF
6AA2817B8B746687B94B80A446A9777380957E8F9361BD61
A397736E80937D7F855E8A7460875B903F798680787543A0
6D497664A066939C677B818F8586915D89979B6E8F7C7156
84707417174F842B3E1BBE99623F368190D165A987877E93
0010E37D77B021C67155AD757372BA4BC4A2868557629272
7F7780399B6D7D9486678165626078904A7C7A99614E97B0
79955B80908A797F73467EA1B86E847F
7C9692A5816D728B7779BE758D7D78A67C847F9AA1648F7E
9581746DC67B8F8C846826A05E85668066418D7C2D346DA9
76AB6B56459E30C092947876B3C767D38C42FF199F428DE9
73483050A078BE46DFA38E4ABE605D346E83699280587A92
8CB3809E529A97798D7D744A748E7B7C96723D8A878A8255
8570BDB1748A7E8082768C877E776D9C778B6C5B94544C84
7E7E787F8E6A957077787D6F626BB1846A8B6A7488817795
627BA4EC36B15DCCFFB75DE01EB48A42782D43723E609A3E
A20E50A39A60E09370998EAD5D357C00FF4568627B86807E
7667789F85946E8D7E71A763787A8C87698989716A617438
5ABBB9877C5E97928388517A868C7F81
7F867F807A715A5C72957CA4A15AB2975A838997774F7F71
5D6C77AA6BA0A46E876D799B7699746164804A12DB20FF34
77A06A399B7D4B677FA47F5EB9AE3B6A7549A14BD262A26C
87D2789E7CB938FF4E61D6BB6BA274799F9162986E3F5EC6
5D68698B776B6EA47588979A88716F7294737A7D82AB649B
9358968B60947E82807E7D76636F7B899B797C9294A49662
8E8194ACA6A68A6C72A1839676878ABAA75A91B1828F95AC
7A747548BB004EC41BFF0F294CDF3F8FAF64C36468B57392
7779A32F766756786D7094A368C960CC3A9C50A68A759F8F
77A3AC7B72A5877D8D858894887D98A3726C7B716F7E915E
865D686B8450998186948B857E8C7F81
8276917D65578E6A737180609735856E6D787B778F6EAC61
758983B771889724AAA277AC7D9E508C7D9382B78C6270DC
E1988C9A73B9AB5877609C467BA8796A7FA46AE47DEA6FE6
00C6694C61628866AC6B6A39659487807685A4708C3D9260
A595A08188948A648F8E9A878B6191827B5E929D719C8F6D
7D677F9A698D7D80817C916C6E669C959687898760696F68
9A8E94A78A6F8469A9627B6AA0657B7F82CFA3837E717681
6A8E827A55512FA551FF2E56437DB277923692B18C9D6193
809B15D7677B6F9E44B2959F8E58698A8B738AAE80708F6A
918970897B5A877967999D78848569A27A7CA1855F73706F
7D7287738E747896847E827D7C8A7E81
8187548F7761A2B381988C596F995D9A44689664878789A3
77A477AA5C9A7C8D816C78817D54A16F62B7884F5EFF614B
D4599B4F8454A3817066836BB76E8A94AE0000DA397048FF
676B9C646C96607475B366916452956EA5848B7B76977887
8C836966686D777E808079587B6A7E81777348D845786D76
8C73758A69937B7F7E8C93887087859B67A0527B4E8E8582
817EAD7993A16B7F7679906E87709A6980A1418791A6827F
8679AA7C97C2FF50FF4ADB91DE50A79B739B6A8B76837C59
8BA8CE4766B91A79558B9E8374628C70806A7F87758A6667
7F958F856D657690908B78676EB19F98828B8998847B8C7B
8B6E675E7B7F8086959F878777778180
81835BBA8170748B59A08278A1749092707793957C7085B2
61A061B69C8A4B8C837ABC78954A9D8497A1618D79914AD5
22F98794669EAA6D85A3A57C8C6E98998B0000DA86589CD4
587F8B8584AB65947297766487737662886BA386A29066A7
559C67734FDB7E9C8A80697A597DA15F928700FF6882AA62
8082A1986F8B7E80817687A47791728B9A888B7676777A88
5EA88A64709E857E6E838167A37C948F6F8F57876D6E9C7B
588590544BA27E21508773965C86567F719F7684837EAC72
6F8B358F715C9E7A8089756C8169797D797099AA82898078
8E75796B8172716874808987708388807F7E805C5C9A7C82
708B9E755D9D676F7D847C7D78897F80
8471866E898D74776C9A667E9984925A8D837180818871BA
7AA18E837B746AAB4EA8728596A08399776861A060A36478
FD40AF69948C95A14F977A8A6A9750726D5786638A796E8F
8E6882549496748891907A569277867B95928C7A676D7E80
6A82698EB16B879793857F6D778A8E3CA57D01FF6F78945A
6D7792A664768180817A917D8587788F6C8C7B7B82757D81
80726E8480838895906C8A7682837E888B85737481907781
789282BA8C736E80BBA7948C6D9D75878B818463946E8F84
9479869F809C788E8F7378869876989F7890767B8C7B7D66
8A817F82857093905C759A88887A71827C727695877F6785
81697F71A288768C868A7F7C9B828080
836D8A9876845B73549E7BAC737B8D77A784966D71716270
787F8A696D8B7C5D79A06E95477999965AAF46D5688E9C70
5EC98A8184827AA478815F8D5C99788678904F9584837398
988F818AAA909B9C627A6A889979A587837B8C94748D7787
5F696B6EB47BA78B78B099B564879F31A8872EFF6D6B7B79
92787E9F647782807D8D9A95859F866686878E79768E8086
7B86825B81986D748C8A7598988B716E9D89B0AD6A7B849C
78959EA5807A767F58B2696FA07986A1647B79898F8E5D73
9D916F7A7170A5899C539083997A916BA4818A6F65857495
5D79987F6D8E8C7467737F707F70807B7E7455957F72815E
84878A6191799B6163827C7E837B8180
7F817B767A85677859896481AB7E8BB0557C8D5A699A7C74
59A697907A92567783877A776D7178A56F7FB492766B8894
8D758A7A328777AA6E8291786FA196607E898A51A663829B
A6898F7D808875788E74658793568A676B5E8F9D8778859C
927E8B84778C93875F827C8A64647E57956B1CFF4871B075
8C64CF94607B82817F8A7E6F9E8D747A797C7F957F888A70
96826A7AA379707D7B8F9880908F7A8C886C7D7C8B90947B
92859C9768747B777B7B70828C7A847FA966858B71999789
897893835D8663A977638F9C738D74966F7A7EA08C62988F
8DA16866647E887E6B7D807D5C8180A08DAE6D678E707689
8273748493896355957D8B756C7E8080
7B997397797DA38788988C6D918087877D3D82677B706175
6C9088766A8D7785689250935D7661698A54978781837290
816D8B9A7962B76BA6716E6B75936A798F838A5D947E7F76
914F7A64759C636B8A8C917B6E8B8B9E827B7970867A8F8E
8D67A9826A78AA726B8A817389688D739A7933D9857C8583
6636A08678A0808384697A88A474929C995594628D877576
697D839579806E6E77859D86739C6B65927D7B83887F7874
77777C8076906E97927C81777C948A919581846C986B787E
8496708C9270AE667F897679838E7D5F8C719D848A7C807D
AD9F9385859D96878E848F8C7F7D7E918398918B5670817B
738690A45B97827D9A9284907979817F
7C9487A87E80626C94887372927691967E4895836E929956
75945D7E67B580998B5B5E9776766771818785838B7B857F
8472837E69937F938B848860859A96657C6E63767F9363BA
787B7D60779C716F8A7A859CA4557FA7756E80898CA37793
9D57999D6A858F87805D796B73716E6986A945A49D4A7053
7B3EB2897A878382827679897E786D8087927E8E7A8D9977
80668476815E73957F897D7E8D6769789D967C8D768F93AB
80877B4A8B906A738C7A748A886D92667E915B8479896B69
617681857A829084797E6A8C8C894F6568708A516B6E7061
7E808B9B98547C8A6B8569648479738F8A6A8B8D83937F91
677E84697053AB5C9A987B7F769A7D81
7A9E8973955F7D7B655D73796FA0917D7D7B7C5A7F9F7A71
95958A9969D2697D885DA4715D7F73757D9E829981908699
516C988C7C7488836F8F965684848E94887C8C808087737D
66725E7D6C99787B857EA0526D65879181964896696A5D62
87738D7A884D937E7DA36E796B786878956A677B9578C369
8F57B3B46D838483817E679F707584697C8B887F869185A9
9B718F6E99818788838F7779806C787F72A97990828D857E
808E8D878B8E7558A695777D7D846B7A86858E7985858B79
977886837876766E898286677C8B72556D798B786F76737F
86838C6D67A359BF708192A4837885997C7E767B8DA47A79
6177876A7F6F847D8D856980838B7E80
7AA171A5786E719E7F97856A7AA48B946669797A66927C8F
8F657AA774BC5E74906AAE97697A599277858B7B967E7F87
7C71886F8164998D917E6877808AC17B73ABA27B6D9B7574
737679A368B2828A7B6188798480936986967A84A1A87BF1
A9858B9E8595888CA778656B9C6D888A7A837682CE58907A
A138A9BD81B97F857E907F64967B6B80846B7A8A7F95646A
83858165886D51976975848C9470917791667E6B858C7875
818E8B7D70797B8378978778858696847893669C86927D96
7D76788C9D7C9974818995766C82806176767490756F8B8C
97808B6F7FA97581688868767D9657748282648F919E8580
6D878B7B7C885A839E846B7763BB7883
807D56A26D6E838C8F88806764A16A90647B707D7D94A66A
AB84787D7FC46977745AA0A8466A677E868E88826E8B8465
886DAB74837C9281B27199818E7A76717F6B807C71907679
818D757C7D98A07D6BBD9D8E8A6D9492737F7A9A5E689CD5
6A62918F6C79769F8C81678F7770549B847D806CE6726B78
589688879E728982807E7D6F858B7B8577857A7D7D7A827C
8880898185847F898487767B8F7784717D787D8D797A787D
7F8E847F737E82748A8590837D878A7D848B887F7D867C7F
827A777F897F89788381887B7F7683818792887A847D7F82
808084838483778A7C878D817D767A857D817C8C797A6D82
7F777F85888C7980708D6D7983838080
pop
P
% End of image
.5 Mabswid
.14286 .02381 m
.14286 .2619 L
s
.2619 .02381 m
.2619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.02381 .14286 m
.2619 .14286 L
s
.02381 .2619 m
.5 .2619 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .02381 m
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
We can also plot each matrix separately. This is the residual or \
\"average\" part of the picture.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.14"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[wtdata[[1]], Mesh -> False]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -3 -9 ]
[.16947 -0.0125 3 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -6 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(5)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(10)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(15)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(20)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(25)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(30)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(5)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(10)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(15)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(20)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(25)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(30)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3C1D35211B220D0F161A142D1912131212130E11120E1010
1011121011111314
8259303225190F0F1A1A1F24161415100C133452360E0D10
1314101011141223
7D7E5941361911111B21261E192718365F704A2C29141417
1816111215143554
7E736E63543913121B232B44454B63502D1F121013111313
151A11112D585F50
817C6F6763604B211D57654841B8B4691F15131110101315
1D272D5969615F50
7E82766D6B696F66548B56559FB1B5A03F271F181411111B
276267665D595751
818177736B696D6BAAD483AE7ABA9752281D25491B14141F
636D60625F5A554A
777A74756E6D6D716FDEC1A9717D804E211829702818165B
6E62635D5857574F
7A7973746F6A6B666890E3BA98C5BC763D3B6C6E341A1861
69615C5D5D595147
737A73746C6B6A6567A7F4CA9BA7D58F293A7B6F381B163C
6764635E5C585349
71746E71686A6A686BC1F9D8B297A84812226A6839191917
1E60665853525048
686A6E6D726A696C70E0F1D8D4DBDA5C1A2B545C3E1E1819
12255F57564F4E43
6061646B6A686D6D8CF6EDD6CCE6E582222044513B211719
160D455B534F4B48
5D6164686B686A6EA1F1F0C87FA6E5B41F182F2925161919
14121853564E4945
585965676764667B80E8932D184BA9BA2B161A1819171818
1212104A524D4841
4C535E626565676F17A9D8976B63868749262C3023181817
101212394C444340
4A4C4F5C5F5C6364247AEEC2A799A3906C5B41261F191913
1010120D3D494340
44464B545462646D567DEDDCCBAFA0917460492E20181711
101011102644423A
3D3E424C4B575A4A49B6E7DBCBB0998971604E3226181711
1111111122483D39
34393E444A515A253EA7E2E3D6B69F8C7064512F1D191311
1110111322423C35
30383C3E444D4D28224EC9DDD4B7A68F7064522B16151112
11101214303F3931
30393F3F42494E302D3290AEAB8C655E54382E1712111111
1111141E3D383535
2D2F35383944543D2A1D221918120B0A0D0E101211111111
1113153539363431
282A32393B4142664B2B180F100F11121111111011111112
13182F443A33332D
262A3034373B3C537B381915141011121112121111121216
1B2D5A473533302D
24272E3237373C3E5778431E101212121112121312141928
3B6651383430302F
24262A2E343E434A4A656B51381C13141516161C211F3171
894E363634332F2D
20242C323B4049504A5A71623E2C2C3027211B283148808E
5840383939343030
2B303A42494D51535356648D86562F222826363B829C8D56
47433B3734302B2C
47494F535552535354575470849191716363667B87675D65
6E6E726F74747683
BBB3B3B3AEA8AFADA7A6A9AFC6C7D1D5D6CDC9DBD3D9DEE2
DFDCDBCFEFB78CB3
C9D3E4F4EED1DFEFD0E1FFFDF5F2E5EEE4D1CCC7C3C9CDCD
C7CDC9BADB9763A3
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "This shows the details at the coarsest level. These pictures are the \
density plots of the three matrices that are the second element of ",
  StyleBox["wtdata", "MR"],
  ". These matrices are the coefficients of the basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_\(j  k\)\%\((I)\)}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_\(j  k\)\%\((I  I)\)}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_\(j  k\)\%\((I  I  I)\)}\)], 
    "InlineFormula",
    CellTags->"S2.2.1"],
  ", and they are arranged as such."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.15"}],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[ListDensityPlot[
#, Mesh -> False, DisplayFunction -> Identity]& /@
wtdata[[2]]]]\
\>", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -3 -9 ]
[.16947 -0.0125 3 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -6 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(5)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(10)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(15)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(20)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(25)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(30)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(5)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(10)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(15)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(20)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(25)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(30)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
00E7558C80717F827D749073A07A7E6C4F2DFFD2669D737A
829181787E7E698E
A015B26481847A7E7383647A469D58E8FFF900B4B1799B62
688679817226F03F
B2A99A79AC787377846753FF8000D70000B0A09E7D83878A
7C687048BCFF28A1
6F7078627D56ED7E63FFF600FF9495FEE78675787F7B808A
9E5CC7FF007D9897
576E88866879002DFF00A58D5D0043B17896856D817F7B7E
99E2006E747F7061
A29E769D897F90B40057CB6472EEFFB2505464DB78868261
9242CF859E8F7385
7D6F9B7D9E979064C6756B69BC00000037735B1D8E7C7E87
68977892617C8E71
7E744B7F737E7679A91F63AB5B00FFFFFF8799BB75806A68
81755D8671897375
7991C690AEA59F765A8186766F79656D003D456F867E8A7B
9B756E8C8A798CA1
825C7E98AF93667496617981B0D5FFFFDBCB9E93798772D6
69777872848A7568
8D615E5A414E5E9C818F847D5F9600736473697C95758167
9287808377517F5A
5A7B7C848594876170558D96982DCC60826EBC753F7A7F7E
708C5B9988968596
957EA7879D7B958BA6A3B77F12B06E90708A0232AB867E7F
7C78A266785E8079
5289897D4F585E8800A62A00FF6650137A9EFF9B859C787A
787E797C8F90745E
A59884848475A182BA30004E1A0065C9846300003877857F
827F63479B608087
6C7D9981977883B9807CEEFFFFD9726C717DCFEBAE747B6F
7F7D7ED15D9F787B
8379736957806F5558A179313E5C6067848E7975807F7C81
7F7F796D876B5A5A
8F95A2928E5B8F91E0608C979F949A9277787A6B87828080
807F7E8178898D97
77747391839A98720C987372877E717D7B8C8890747C7E82
80807B8178AF7871
80808E8480748494FF5A9A746F8DA896868B88637C7B8379
817E807D897D5669
77897A7E767173490093797B9C42000052143F9F87888282
7C8179825E87818A
908290938590608EF197A3E7FFFFFFFFFFD8AF747E7F7C7D
7D7B726F82807C7B
84797D787C74B0A8594A465E59645C595B6D747F7C7C7D7A
7E71A0797A606885
7D7C8373674E4211406875677178807C787F7E7C787E797B
74636E7F7D718172
96908688818481D56CEAC876667B747C787F7873777B7B6E
8DDD0E9D8D907C7C
62747F737B958C7C87B9007EF489727D7D817F839E8C59DE
031FCD828A918E83
6A7B6B746D72998278AD6BFF0300E0C99B5775774A80D765
B6A96E7F6E79777B
72808A7968697F79719B2100FFFFCA083B7EC5C1BF6B005F
804F716D5A545548
5E56624846504D59504D6BA1310009FFFFACBCD006AFA05B
6E92ADEAFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF2FFFFFF7972FFEDFFA21000
0000000000000000
0000000000000000000000000000327A7A708AF9D9E8F4EB
EAEBDCD7BFD5BF94
A59B838EB1929EC2C2A9898175A6A37B6A717A7288767785
8272686B8B727E7C
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -3 -9 ]
[.16947 -0.0125 3 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -6 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(5)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(10)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(15)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(20)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(25)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(30)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(5)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(10)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(15)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(20)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(25)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(30)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
15DCF25200C376975D81657193787D808071AA6F867C7D7F
834D8A87798A737C
00FF007365937DA33FDA1DA9778377828F9729FF83707A85
718281817B69AF17
89979BA67084749E2FA37B875B817FB6715FFE6E5C7D707C
738086735ED268B8
3DC665854ACB74903E777257AC7D7A897480995C957D8389
845A8495117EA49C
679A217E8F3F7DB1FF0028FF008046EB826283897D80827C
A7E6A55EB3838398
9F89408449C85D9FFF7482B038E200A5A949A7717C81899B
34A79758729C7493
8382508A4FA751FF007A47414DA29563B24AD1CD79776EFF
43CF79AF796F9983
95A74A776D79B500FFFF2F38FF6406CE897939999E41FF00
CAAA5495958E7980
89D25A704CC07C7EFF008C97DF257200C1B81C9B9732FF84
A07E8AA24C9C7A85
A5A99C75527AA97AFF008D6AFF34007760EE4491895EFF00
5E758DA467984B99
9482C858557B8D20FF0069A3CF0000FF3F6F6B66B77F658E
8E508D978F78778A
8E90B2B22B997921FF7F71B51E9EFF9A9467835B96937A5C
C900B9A1809B7281
9FBA874B9868849200AA6F83B86000FF5BA0538F669C7A6C
5AFF27C45F866A90
9484A16F7D9719FF98A534F7204900FF767EA82E9F748167
9445219670837483
6A887F707D9149001A0EFFA300FF00DAAD528D51867C836C
8548FF66B09E589A
798B5C949078FFB9FF008A928DC73A90A66A916D9B7A8192
8166F45F96AA6884
7860849C928163A2FF0095B07186708EBE46AF7083837685
7C8053FF5AA0947E
95687B67B66E7800FF00A79777896E99756AA56D9875827C
818271F715939673
765D6D8694750090F60C9A917BA167917478887C957A907A
7E8676972A5F9076
8351AE8471C700FF733D87827C8F6090847E6F9C756F8D86
83846F934183857C
92517D887FD67F1DF500A662A47F65A18A738587898A7C7F
82806EC56188766A
9260976890A8241675EB00AB5E6E8C7E62817183867C837D
817A894A7F6B8587
807B8D62969F00A0418F37B0679586848082767C7D7C8181
846ADC2A8C7E9473
85887D736B869D8ABE50A76A84757B7E837D7F857D7F7F8A
73B659B275878C7F
8A7D7560887B83ACFF99705E847C85817E828280867C976B
A640767C8E927981
7F7C807C8D7D59C81A85839A6D81798185807E82867C5B8A
7934B55199837788
8A7A7B8183547686644CDD7E8B767C8373828A8B6794FF39
59A079826C928688
8584917671A66F7392A3008BA46C7A5D6282AD84979A5F65
FF5D8073638A8583
958D7363A17572836D9687699083815E8B9B768DD925F5A2
A0878A7462937D82
7E75746DA6678F858766FA378A6865D45200B2238B868378
707A73B0667C9485
5D89866FAC736B889498495B818E8F621FFF429085818374
838664FF00BEAA67
9676846378A01CCEB63491A2568C7B779174857E86728882
885873FF00E5FF0A
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.0300481 0.0192308 0.0300481 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -3 -9 ]
[.16947 -0.0125 3 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -6 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(5)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(10)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(15)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(20)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(25)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(30)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(5)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(10)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(15)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(20)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(25)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(30)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
32 string
32 32 8 [32 0 0 32 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DA9432BF87777D8A7DAA744E9784757667FF00FF0C968781
538C757F7A669A1A
00FF87D45C8D7D778E4F54995955B0BF00FF921CF574627B
80887E6B8EFF0068
8251BE75CD5A8C867280FF00FF00FFE04F945CA44E856D71
696C62E13ED72992
749D7863970887A6FF00FFFF00FF568B996390748B857A6F
84E138AA36A53683
7A8263899935C936BEFFFF006C303671966382727A8572A0
28E59B7DA47A8A75
6E9C8B6DA370BB00FFF70000BADB00AB46805DA65777421C
FF248C726B806C78
72809C5D81A086FFFF00EBFF00BFCD975E94FF54927A7AFF
66A766A5948E7482
85946E9477629B6E00FF6435A3FF0000C2730F916E8CFF5D
7E62A37273928379
90627886A4804D8DC53D8F785C26FFFF22758D748C7D0871
73A1845AB66D7F76
5D99BB2C70657DB471609378497AFF009A757C88757DF000
FF569B8D5EA4629E
6293726F7264C9372A93776DE89100FF4A927B786E73659E
0081726F8D7A9256
917BA47A5C766FBAFF79917748FFAA4A9A8F61A0627B817F
B4AD08917C504A77
4EA2459C49A6149D349940B62443929C7274C43DA38A7A7B
689FFF5C997EB596
BC8E8D6AAA47C2000034FF00FFCE57649425A7FF74947C85
7B901D786E9D797A
717C4C728FBF16FFD800CB753754528F73BE5C47698F7777
7C75E82E75757679
7FA68E899F41C2463099C25BBB6B977C817892719D7C8170
806FB3FF8E739E99
7E66706989A075B8FFB7708E68827E7683727470867C7F7E
8480714D766DA073
8B4A96646B9936D31067908294888E8477699F8B6C7C797F
80817F7976AF9791
73A17D87843DF02690A2796D775E847E798A76767D7F6D88
7C827D6981947861
798860857A8D63F88D79A485869C6FA3687C8C88747A8178
808378A69B7C6A78
80947CA2A92896B3007730996E4AC137886593916C748286
82767A3497939175
6F9E7261A974A4912500FF00FF2B9674677688788083827D
83799DE78F798E88
7C7B727ABC67A806F1C7418E709284868D82747E8B7A8682
6BC6AF3F8A71787C
76727D7E59A146FFFF745A93857978887C788C7685749370
52572D88558C8A7D
827D7C8382859400FF72B86D87748278847A7C7D89774DD8
29EA6C689B6F9079
85707A787B7087AA4600FF50828A639F6D7678896054FF00
FF00C38C658D6D7F
808669906B8C6C63D30000F2BE7C339C606261A0AE7FA3E2
44B58D6D756C7C80
7C866870727E6F73855100FFAE138882ACE2154F2D7E0060
A1756E72977A7C7D
7C89786A797E818273966D008EC9A07800FF11FF624C9961
B993987D897A616D
919974677A6E778C7281E1FF099C5EFF5B00FB346DB6554F
81786FB95B7CBA53
6767A27C698E7183747696695F989C622EFF517F8D72848D
717791837A875E84
7A7D8A766190747D7072828973738487827284747F85897A
7F777C8877747D8E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["This shows the details at the next level.", "MathCaption",
  CellTags->{"S2.2.1", "1.16"}],

Cell[CellGroupData[{

Cell["\<\
Show[GraphicsArray[ListDensityPlot[
#, Mesh -> False, DisplayFunction -> Identity]& /@
wtdata[[3]]]]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00744048 0.31746 [
[ 0 0 0 0 ]
[ 1 .3125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3125 L
0 .3125 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00744048 0.321429 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(10)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(20)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(30)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(40)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(50)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(60)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(10)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(20)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(30)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(40)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(50)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(60)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFF548B85888689957C697A98B28B7C737E8478818C8261
8B89798189828278847D807F7B1FFFFFFF7C81738589917C
828C7A66867D827F8C8272708C807E33
6400EE895D5C847F606E77807D68787D7671758195707A92
768276787F74737775724300FFFF0000009685676767697E
6CAE828778788C74767D7474795F87D1
A9C3199BC86359E55B7F8A82838A7F888D7D877F7789AF77
5E5C826B7D7B672C001CFFFF0042FFA1FF63789B8FB1CFA2
6A71888485827F70799C934E6ACC8215
7A7878543AFFB532A18E6A848580807E7171796F9C9A7572
5178237E544EFFFF00000088FF901F9700AF7B926E75868D
9B82927D7E7E808787389E62FF0079C0
5D6EA5A6A80AAF9B508FAD797981727B7B6767A77268385A
FFFF3F00FFFF53CBFFFF00004FA77A996C82848D9A8C9387
91819389857C847A68E5A7D200AA9167
728B88957FAC5154BCA752917F7787818A827E797B31FF00
0000FFFF00000000003B70FFFE6983A58D8169857B808256
78776E777C6D7842F7FB000BBF8E6B68
134D6046916C55AD0537CE6750827F8089933C00FF0900FE
D8FF1C23FFFFE5A071849E8D498C8675747A84828080847C
6BA0C28E654EA9FF0031D07F7F748C98
AA9993BA787A9F877BF920AAF67B945A9F7BFFFF3900FF17
FF008468220036639172695496848F7D7C7F7E897A8686AD
47000035F9FF0023DAB17A5E7289709A
7C939781AE837E8C736D937F00C9EA7D00FF0000FFAB00FF
7D88938ECA9B7B717B9B90857D8892817C83816C7D798987
F1C0FFFF0061AE6F6D666D5F766E7572
767261796882737A738A5A788B90000091A4FFFF8900FF00
53856A5C43E9DEA1AA83858C835C4763808D7C82739F727D
15880055BC8572A98D8496959C7F7685
969D7C8C7F64848A8B80A4B5B897AFCF7A00000034FF00B0
88D2D27CC5000000344B636C8197AA818B928183877D9393
FF11A1A188BC7440867C7E798F777D75
8082967D648B909E8465533E3E78765F34C5FF89FF00A5A3
673D90D2FFFFFFFFE4D5C27171677A887F736B8D6C834254
00836C96776F6C8F909084897480A89F
475D5F7F8E6D5F597582879C95838F89BE772B50007A9278
8D369C7B00C6003D8A6F708F9488659C95848AA99772FF7A
B39B8C615F7A7499764D79609E867788
9CA1A4ACA68489B1A488716D83807850B45CEA9555D39C90
95FF540000003300006070618243686D817D79A5618600CC
926A729F6D82776B87BD84AD8F736C53
6266734F6F6B68668C87B2979B837B8136C400219B6E8582
3E0000FFFFFFFFC2DDCCBECB7BBF887187777D8076B7A269
689D8866777988C3A86F6574748F78AF
98A697A0847D939D7B5B6C7C3D6160999E55FF9C94789F7F
71847000001900B9702178686F6E8D8C7974847D88487A82
8E806698818C776C39A5A597716D5648
39456E7697976F8CAACF9691AEA87D54597C1F906F8E564A
737A70CEF2ABFF1C70A57B8D9B7C84876C567D8179A68C86
638C9F8B808A6C99C181808D92AA9F85
9FB49E986E8398959C6C68736D666FA2768370717A8A7C88
89879098DFB0956E5E62787F699175768D7D897C80819BDB
BD6F6E8072709D595A8D7DA17B696371
55536A6887797A5B487B74748E9494989B92A77C817D6761
71795100000032FF9BC0909A957485777980827E7E793700
00CA91A095B456878465916D6C887F8E
BE9A65889291BDE1B29F99A07B49425456737791777F9484
829D97FFFFB1FF6064678B975D7C759D7975807E7E7F8BA5
FF08AA7C6F5F936780B37A7F87808C7B
7587AE7F847C4B44698588667B989F94ABA399768A7D5794
639B7200002100598A87727A688A91716D5923907C8C735E
2BE800ADA6926CA97C4E77766464709C
AF965473838D9B976A659B6E9B817F854C5F637B7A778E8B
8476B8B038FFDE74647A72869361747291A4AB76827D8396
8A51DB7C7A678E7E5277787980827E5C
496FB799A574737184929B957F957769C6676D7886535E75
72614D7CA3458979828976697F9B83908C77917C7A7F817D
7E8C7A56936071797D87837B586EA562
9F7F666F7370B2864C406B406F5874A16861857D8084B5A9
7A6E925A96896BA3846A74888852666F507B7A7980807889
8C7E6DA576AA78747B9F869283785D79
A89F87A586915377A3A88C7C7DB599796CA0848C92A59CBF
B2665E9D5C8A90568290888894CA846DA4857D817D7E8082
8879789C6270787E778267749359B499
959B6F4B938AA580619177907450426EAA806A93A77CFAB7
68BBFF9D7E72709486817C42000031817BA7867581827F75
8779867C9875A77E5F7897946879665F
73759B875C5D6A906F4F7D6CA3C28FC5698F7812000000A6
FF8F000069A07C637E729BE8FFB6C68F8658787382707D7F
5C7F7A62708A6FA3A87E755981858887
7673666599B5C47596847892432B827549C398E6FFFF4D70
0D00F5FFA15E56737F7688C9000053A9AF7D63817A798172
8C82837B7564A7467E86A0948181A7AD
7F9685A48128589191807D8DA5AF7C00B4006D6B08EFFFFF
FFFF0038737D997062855316ABE4C3B2826F7C759F74787E
7C8480737CAD7F81718277828C8E9C76
6D69918DA0AF6B807574856A675F9DF160FF495429060000
00003536AB7F6E9786628B684700003A5890867872767985
7981857E95009AAA88A07C907A9B495F
6D70568F6865B7987C697B898C852C3D8A48A0D8E9FFFFFF
FFFFFFDE9D796F858388D3B5EBFFFFFFAB9275777E817695
8884888789B4BE1CA476978C8370AE6E
4B7DB177A091517378824E6A6656BE8C727C6B250000503A
1303292F5B66695569582722594A4F58806D6B82847B8274
838981817F6E7ABA778F88888AB06679
6A5A486A5C7DAD8090AFB980B262877AC5798D8A9D713D4E
8CA0978792768E9D997B888C628B8C617B887F80768B7C7D
74837C837D85676F6D8E86549387639B
AF9B8E8C796B6E8B79574F896640565A0877BB857790B4A3
786591807D755D7072937C777D987F8C757D7D807263737C
867B7C7B8F828A6D9C6C58A37067879D
546976868F94916A88AD9794CD9B90697EE971897F817C77
978D869E9076A783866E86737B8B8F7B6A75777280848780
8185867B808B798474B0B64885BEA96F
9182AFA5894F57956E676550646AA3A6EB2F8276938EAA99
758D7F6C7D777886868E82826D717A897F86817B81947A86
8184778487797E76665B43926D6C5392
8A7A65608BA5775F718194AA907365885E78A07D7E758E8E
7784877C7A736981887F9D826884717B8285769087887082
7B6F777B807E79767C91B38B7D7F8BB0
4F6B8EBE9085BD745479848180987B832D7E667364867363
6167696E7F81858F858188678B8595988F83817C868C7F7E
75787E757E6F7574598D88AA6C917D9F
5C696846718B5F7BB28D87A5A9659D82F71F3A827D86938A
8990A4A292728760777E7186577E889573997E85737B9B74
7A7F857E877F887BA191485E6C869771
A68D97A87C718BAB60908E7965905BAE8EFFDF70984B5764
746F7D7B7B8E5A697A6379657A7A66458D73748F6F6F636B
6E7679796E837D946A59A8A187526D84
717772747C6679696B7488829FC0647FE2707C8A53C4B8AE
96AAA7A7C3AC979D959D90AA7079B18E908A64747F84767F
8B7F7C79A2767DA0413D77798D93AA6E
47627B967E79646C964D66A522A87CFF003A6C81A166268E
97742700000000312A3B656053767C908C7379847D7A7F7E
79737E76897D68A9A77A6C7062888281
7C774C64565583978080775AB19BB780B5B35F2C2C003A04
000DAEFFFFFFFFFFFFFFADB4B4AF6B957F867D7590738D75
787F78767684A46F617FA2738977729F
8591A2AEA28390568188ED3833B6AEB3758BB4F9D4FFFFC2
FFEB896433494B5E6F6C88827C6F8781858F8D857C858C81
857C89836481B789A5697F8C9E9E818B
665F7E795F94746CA08B07916FBB3F5E00A363096A395861
2E675F74917F797A698373817D8A797E797D80897A92867F
7E8078A887A5407876BA728C946F708C
827B6C7989678794642C967DA478FFC2FF3264A4785A7652
85727D907A6D727A72798483856D8777776E8282857F6D6B
775D6565B11B9F384442716B63777B85
A3B59AA19AAE8681B9BD85554EFF4F8000FF7A5DA77C9DA3
848A7A7D7F8593907B7F8A8E7D8E858586918C8C7C8E978A
9FA9BC7E10CA7DA29A7C829E758A786F
6A695E66846E778171616C8B71391E00D0001BEB5C877153
7C768086716F6A7B72737B768373747E817B7B7C77776C7D
668A33B7893662725F9E5C5E7F7A787D
5D667D7981809BA2A4898B98857299FF00FFFF05A56F7093
6E8D80798C797B836E7B7E787E836F787D827A73768F815E
8737E858EC868999644D8B8D7E7F707D
7283816C846888655D7F82737F808259FF0012FF7C0EB052
816A81747C7E7772726E7E786C7873767C789285788B5E2D
68C3153000B343AB82B1998585708689
888A7B7F707E718A7F7C787A778F876A8FE8FB0000FF5775
AF77787C7E6F777475887F717C8E9F826C737D5AB8AECFFF
B8655B9D86648CAA6E866A6967856E77
846E867D7E6D8A75807B77746C889E83608D69FFFF0056FF
35005B6D467485746187688A7152323176B072A800B6C600
6600DB8D61A074708C65748592807F98
6988734F857F7D645938265C4A7658646A9DAB7100FF867F
00FFFFE54A3F6D744553C56679A947B7B7007A1E7411009A
45E03A557162867E7C5260685A727791
978F7E736898899699B2D2896F818455809728E0FF00FF00
FFFF00004FFF465BABFF916E7F3B83507EFF001BFFC2F4D7
9D8929879B7C7A7C757B92899483807A
91898679794F5F545968748F6B7C6BA48AB0D18100FF00FF
5A00FFC8B1CB5E7C0078406D6D9C00CA8B403F4800002720
432FC757876078A47984807C84888275
6B6F757E7C9F936CA799948A73647F6C5D6176B984009E00
00FF625FC96A8A00787D7C7AA7FFFFFFFF620000E8FF23FF
4555659D8E7B827D86697D846F778382
8A978EA37D728CA79361818CA1939F7B7DA88C979CBEE000
FF0F00919C24DCA18C260085000085240F836FFF3FFFB54A
FFC27B816B606C6B475B4D4041544220
60555A51867677343C3C705F3E4B6B71876763684D8627FF
0200FF932203FFFFBAFF99BEFFFFDD208398000023448438
617F64789F868FB7CBE3FFFFFFFFFFFF
5D6E7C9A644F848EA0766D4A9687545D1C484953492E8400
6CE9FF6BC4B00000000000000047BDFFC9FFFFFFFFFFFFFF
FFFFF9CE965C21000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CEFFFFFFFFFFFFFFFFFFFFFFB03500000000000000000000
000000030037608D9194FFFFFFFFFFFF
000000000000000000000000000000000000000000000000
0011000000004301000A0000759DE1FFFFFFFFFFFFFFFAFC
FFFFF2B3ACA09FA7A3977E614755553C
FFFFF7FFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEB6CAFFB889A2ACC7BDDCDAA1846E63738A7D756B747062
665C74817D785A7375677A848887948A
8B82646C708F888E7B776D43545A6B67666488645263626F
7686827F9081628466766156697C878E7E658A717B788987
6D747C848B75AE8286888A87857A89A0
7C877F6B54383F6A767B6A757E8E8A818B8770727B757969
6D6C657D7E82896D6A64716D797A7870646E707D75838577
887477856877758996847694928F705F
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00744048 0.64881 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(10)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(20)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(30)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(40)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(50)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(60)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(10)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(20)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(30)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(40)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(50)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(60)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
35739E17B9E21AAB9140BC76837480978691A660FF5B9F4B
7D798082848279847E807E838076838079739C7D857F7E79
7F70E8937F8280926D8B86858C8F7E8C
15FF88FF78946FB2B14BAF81647E7FB18CA6807FAB7D9D8E
7D897C867E6E8585868381688D9D33998A4A76838C817989
4F787D9583978A7E857879708473A973
E700ACCC00D19C63843C878090708AB1788C6BFA518A8271
7C8D82867C85858C7F6E8B939200F6E000D382748372996D
8A737D79877C8A8472868E8960A0B276
8C5CAA73D91D9A6B5EB36A83837D7E9D55A28B936D979576
797581847E74795785A20325BA9219B067C1559D89718480
87917654877C837899787D6EABD47E8B
A04BCB5B7E967312949C866E8375879D609892668F616C88
AB706998857A389C5D0047979BAF77BF9495888A6C70A37D
7D898D6F7F8187925E8978B435B7A176
AB32D12B7E9462F24C96CA6A7C807799757CB75963578283
58994DFF466389D6736E7BA79CB700C3987C8A7A7A8E8A74
8A83739B8085755FFF00FF00ADA98C7A
944AD84081658C6E98636B70797B6F9836CB7499B01CA0A6
0CA8BD267D897E8280827C7E8558847D8571857D6F699A87
8B9A5AC1827B7A9DAB047BDB49C2697E
893CAF52AE5DBAA146607A7B6FAC6A8C4AED19CA7B00DE00
FF22678C836A7DAD757383847B83817C818A76806C797D94
70BB2F83639F8D3CA6796B9543E08479
9937BB437E66C6732CFF1B4E8D947DBD00FF000941A332FF
00DF6C58B6618FC46B887A6B7F9382877A818F827A8E9286
8F35FF897F7D86655D8475A73E909274
724F9F4A8596B3A538C51EC7767E2CE300FF00FFFF00FF00
89D37467747974AE5B8C7C9091896A8B758384827E6D5C80
9147836C9F999641BE38946F4EAD5585
9058A64AD62AEDAC36A038BB588AA400FF63FF418EFF00A6
3EFB29D369A531A7A0759D48937B7B7D5A7892807F6D6E78
9E865A996F9187899124AC6591AD5185
756E974CCF05E977509172975D7422FF5900682CFF0096FF
288BBA74B86C9F59A58B6786A79A539087778D91B04557FF
00AC95D253AEAA976A58AF6FC3635A88
9151966E926BB97D7D8B56AF698F39FF00FFFFA84C698485
FF21A6AC00FF555E916F705EFF0089AF607C7F966800FF00
C882877F769D7B697C0EE48078906789
8857A95EC51BFF56B8636C935C9E8300FFA9C2FF009A7D00
FF00D1C64A9DA65D9E6F7F46FF0020A279778B6F719D49AC
598B906E7C7F6E5F8429F7618FA36187
76738342C830F8138D2C9A855CA4572DFF00FF0093797687
755A9E586BC6A0409A838E7ACA6E00B2727D7D881624C9BF
53C32EFF3A927F677C46EA7B5C877183
7C60728F6D80E50BCF32866B48E327B400FF00FA755C9482
A8B91CB5A2A452C56C8E62B278904FA9778F715BFF00B6A8
31D144FB3BC380505F6B897E9976697B
727D88AA9B4FF5358765AF6E66CF37BD4FC000E68470AF3B
C945996A34FC02FF67707BE0169E687771777A709F00C97F
767466B47964797D653E9E9F4A689B75
858485AD8258AC4E775A92736BA4478829FF00A156928D3F
ADA23EAA63BD00FF8D7E79A659B5537C6479788100FF76A7
5A8A8997689660B86D47E0867E57787C
7A79888D9D6AC101AC4C7F69738C86B500FF00BF767A885D
ADB83774A12A71C06268B34E5EAC3C7A6D81827B4BFF00F4
5F61975E7DB22FAD785BEF857E833E89
848A5C98C139AE1CA76199817FB13B8500FF00CC8856AD89
7AB400FF002BFF4D7477BC5293835B74736C7A7D7CA400BC
00CA9A7C79626982A45F957288B63A8B
87C35A7CC8489630A957856F56985C6400FF56BF66897793
5EA600FF00E0BE9530908C5071975B807E12837B7E77863C
FF00939BA583877A94478D9F6E985C8B
84AE468DCD607649967A99A71DDA74640000AB9294846E97
801F87C400FF43C259CB5E946A92618457009676797D77B0
0CFF00AC6F97619F709172828E57B176
7ACD6965AE3AAA528D4DB48D30DE308EFF00CF928363A079
B82CFF7E0070A97D8E7387598986837897BC967A85738786
4E2A1AB284A483785A8E76738249C075
66AF74859A378C49AF5DA88B30BA6E03FF40B07F8F53A291
7B97A410D700FF549A798B617C6C7096A463A57582747C4B
9043FF00D46A7E658D73CF60A81C9081
70A951967A7560548E6A7E5E70A7943D0077948A7E619677
929D6C887C47FF784BAD757639757D7E8B459A767F83814C
93763CFF4A9088758D56BD7F815C8479
57C750CB6A6A8044C43A9C7B7BC211FF0000858F7C6CAB70
947767C24560AE9F916A724975A0548A76857E7F807F875B
9E6788D400CC8395737FBD6583437A82
807571CD45A1905AC0608F82598200FFFF00968F754A80B6
5A899C3BA500FF76978063349ECB367BA07B747D7482856E
7E7CA842FF2B9B746C789A4AB82A7C7E
9C877EB24AA07E44BE2DC183715CFFFFFF1C5E75D62FFF03
FF00D36BA71FFF9C7866A8A32C7A24AB8A748C7E7D7D8B69
827C9488E300AB97A6628C7552589179
94887CC43C959C4EBD4EA28E974500D9FF269D00FF72D00F
FF8E14E24879B4CC977760953888667F7E7F8B799A7F977C
806B7D82510075A48E789F98596B9E7D
9A3691B4228A8B5DA56B827386FF00FF2A00D881809F5678
6C7A844F9E4CA699698C8A5FB4876286A677858968778173
7D857A72C000A28F518581884CA48680
BA6C7EBB3E6D7E76A463847F3DFF685F1BE900B28A786D71
7F787C5B9848AE69A26E9A6580775E889A7BA37883878C8C
8B74799098AB70D0778293735CB8787E
9F875C81823CA87E994BB26F40FF274415FF00DBAD3D9C74
76828B706C68D43EC4636F668B846A7B8C837C7582709582
7C847779748EB922C06697544AB76C88
9878728A6B72978A96677C77A19A8D2D31FA00D251B29E6E
55995E846CA0BC698F8F757B7B8578828288808765867C81
7F817F7E856B6D2E8F7AB756B776AA7F
7B7561885EAC6AAD5F63A765AA8883C100FF009B89749183
7C7679778B8C8F948486A87E8F946C9B7F867E7D5D86837B
807F87828F8054FF00ACA346654AB376
5EA7458357BE46AD82639B45BA7EFF00218D357F957F8B8F
8F669C867F708DA476AA86716FA163A7897B85897F8E827B
7F858484827B69D41C84C9268287737F
81637FB64E9E947F7D6C7A4AC200FF0086205799A7697E9A
7E649E828B65717F7C59A75D967F7F7F817B7772957C7E73
866F728591836C6F9D6FA1699EAC8582
8A87767C76776DA26872946BF200FF1FAB3D768FA4608789
8074A964808A8B838C7A8D63996D8168749277806D836D6F
8D89897B99847B52FF42896888A36F84
7F6E8E77B2837DB0715CAB48E500FF0000EB2C838B6C7A84
487E8786737C8169A25A796B7AA18A977E8E79609478728A
8C80768B83618145FF6E5F7D8FA06681
9462A4569AA06FA25F64BB5C88FF77FFA94B2CB363955E71
929E698A9078868F9C5A76598D9353AD62977A8E8B717681
8B837A8B877180388175578386756C81
8B607E6E77C73CA370A277A600FF765EF94E9F888A978169
8D7F6F9C5B77AA9D7B827BA08A9F3FA3887F6E748B6D9183
83848479937682B0B568AC696E9E6F86
9563AA539AA261B5619169B800FF8F2BAE70A3009E7D817D
7B9487847A6EAFA852A07F7B6F946A90567C738882677F8E
7D8D7E80986B708DC195607F5B89AC76
7F6B9F3FBBA464C1737E5ED200FF00FF00FF108F5DC1857B
6A81828C6761AD8C65888C6D60BF705297868F8B748B917A
82808A8F7882B80E209C5E648D6FAE75
934F9C29CE697A5D82A460D656FF00FF00F400FF23BC5E98
908087898B5FA17D6B9895768279955A87807F867C7F768A
8679766C764DB53F7F869850B87D9576
815E9F5EB258817489985886ABDB003E871499DD164FC48D
6F6A8AAD7C9378706D948680876F8D7A88817E8B80778485
8978948C5BA50EE0857F9F3BBA708577
83738950A967806686A44EBEE900824D45E8887FA3777B6C
6186869361997083747D7C88828D9A6D7B838176917A7773
829184A35BBA4AAD848E61378477A974
909D90549F44878687679683690F73FF54C9AC52759044B0
4F93687D878371906F7485826B7E8D747C71877784708A7E
9074A57FEB648B9A738E7957A97D9977
7D83768B8E7D957544907DA4E200FFFF7F4393A27B7E6E85
8C837E777F837583779991717878797E866B718382757C7A
7D866DC200D060A75485846690788A80
787985868F6FA86E8A9D48BB6CFF105D00FF36907F9A6B8D
87887E8578888490667F858380888B85817C846F927B8D95
68AC907FCC687E986A8A56737098777B
857B817B9C79978A738F479A7578FF6FB1C400B69481686F
6D8A6E8971777587826F88889775788B7F88846580A38752
9D2AD3139E779C8BAD6396777E5B977D
917C9F639757A45F968083AA6B883FFF00FF00BE686B8B8C
979E868B6D81778789866B8789838A85738B7488887B6081
82F000B07ECEA25899568D64C271837E
8A756B7883799B5E93AE4EA6589A6B20FF00FF61AB35AB7E
8483768085718F8693807E818F7B887E747F967AB888C254
745DDB93A864AA4F97875D86907C887D
786A5E737659988C6E94459254A6757BFF3000F824C1927D
7B876A7C857B708C828A90768994748D816D7FA54D4700C1
7B3FFF6B879D9480947C917A7D7C7D7C
838D60699571886C599A4B9F657977864779FF00FF00DC84
7AB45D9C8E6D848B738C718F948E968AA85FEB5421CA00ED
2FCF7C8B8887799467868F80867F9876
78888075787D92678D63748E49B765A5948300FF00FF8798
3E4B52A498959489875DBC6CA89F85D822DD46FF00468B8C
854F52A8648D76AC59758167807A897D
9262948E766B866396737F725E9B71748460956FFF00BFEA
40D36879917DA5BA8B7172A0537188D5CF007FFF256E6C79
41987B8E6E9449937A857D6488777981
7376778E82786F7E9F6865866B9980658662B76E54FF3D21
FF41AD98A79721BD3D9078BD6E8EF265647350ED00C142A8
E65F747F4C7659A37961877B75767983
838A649E7F818F41D157837A64A24C94765C849EBA001A61
50A8636897608C798877534200E6DC0646FF6B6D8F4047FF
8385C17A8B6C7F7B88617D89768D887D
87727C7F8981A95F725D90688FAA689C786C9B6C5583FF19
CD6162AF77917EA60085789C00903C57BC0FCF7984688C67
7448C95C99819B647B6282818E8B6184
83836F99788975599361957B8D9A72A573826B6B70FF00FF
30A2885672A78FBE08C2DBD89A5D49AA7E867374568E72AB
6B9B858E766C9C8173819B50AD858480
8583B774A2588172926A93878E995C6D63815C7B958EB300
DB6B7B7F47C78E71FF0046FF0098985C997A90758C74798D
80839266767C78876866768F7D996883
7A8A93707E987C5A718A988B8E738A818A896DA47E7C7E91
5675B165A96F6C7DA5009E714F897A79918F7A927A808963
9A78886E8C8A63B485017567B0987D8A
7D77848D55A087846B867B6762817D847A7F7E807C79958F
78908A75917E5E777DB27A70768589788A76796A72868080
96967E7384A26CDA7C00CF5EA0A2748D
907C6E64A26A957B867F8D7E4D8A7A646674975291857F94
79728690866F80748C6D7E8176819F6E9C876F7F986E648A
859A8276959683FF7A00D158B4B86B8D
8F837A988F72996E7B796F60628277704981A3638D7D8E90
6B9C7893747585A775887D72868D76A3845F6C79938D8665
6B857C8A7BAB49FF4900F344B6F9608E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00744048 0.97619 0.30506 MathSubStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(10)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(20)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(30)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(40)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(50)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(60)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(10)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(20)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(30)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(40)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(50)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(60)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A0FF4EC34973378B6A44747BA4AC8E698AAD9C866B927571
7589796C897F7677837C847061FF2583CE7C7A805583888B
8AA16C537F8C9082747E6A8761995E87
00EB986765D2A16382848F7D7C7F8582617B64909C98798B
679E988076747570607274FF00FF003F6AB86A2491685973
B1517E848F92777B628F8760A18300C5
A010FF26BC00C5BA94BB83776784766A81A68542A872C0C5
6F8DB0718D81A47E7FFF00FFBA23A9C6983A5F6DC470A1C0
9B638D9C727F6C70AE60A846F400FF5B
7C8385FA00FF0068D88D676C89868579986AAFA26F9489AE
AA79648A808997FF02FF56779BD9B8F352A78AA7565E5683
967F896D7D8486A179574CEE009C4C86
805CA79E6E25FF0065B1A677718B868A4A7BB23B6D6C7CC3
AE00C91E00C14633774EE900C634EF2C997765976875A06B
8662A4938089837EFF0080FF0396828C
996962908A1EFF9B0C5599676871877D5D8891AE90A719FF
BFA100FF9665617F76A466A695CF5C84897F977889745B80
526A77576C8449F500FFFF393469B46F
B850846B5B6B961BFF7D2A937A8F8177AE007CFF00FF000B
FF00FF3743879DA57AC9979F5F658C7D8A6D89806D6E8492
90825C847B931E1BCD05968A93937188
6F813B62A89A5662B30FFF37C21FAB9B29FF0000FF00FFE3
4F246B7FCA66AA80718B6E5589898A868B777A6A7E7C776E
A3004FFF5F64CB4C67CF9792A7777680
8F495DC365669E77A49D5EBBCD18F652CB00ADFF00FF8500
78888A9E53863C728674CEC178869F91778B707C6A9CB156
62FF00E5317C5BA4757BA37483728F7C
7A695F5E5D977F405D5D736A8C79B500FF0000FF14FF00B8
558171A48F7CFFA5807E6A6FAD89733E6A7A9568A06B8169
FF003D84B53C5B8263967D8D8E45B479
8C7E977F9BBC73A57AD69E99683DB3FF0020C836FF00007F
888190A611D45A88578D628D52836CB1728C58AC8E747DFF
A3388D857E76737A7CC75976889B847A
839D637991727259B17F305669807B0000CD00B700717334
D34C757B9636A1977597B9A2EC1B9351A17758423275D80D
00A77B767C5D57CC5699915785A2C377
93669556A8967C578287AF83A26B1CFFFF4C00E8FF4050A8
1D8A8ACDC0C14E4E8E74796300DF466B944A7AAA6DFF0098
599C94717D548A61698C619A846EAA7B
848271A55782178C85B174966A8098420000FFFF208A924D
C4FF00B59900A4A47E865C8CD66D946F88739652A8000082
647061A08D95508D7D8A849987BE318E
828364B9846D9A7A6D9472869D8D6878FFFF0025D67C9273
5D0AFF00FD755AB25366909B4E8B8A936A779887D3D27B95
AA6386857461CA669FA265989057618A
8E6E8093989595B4A288298F657A4B712CFFEA916B836D92
8A895487897FE900A66AAD829F9DA09C7E6A7F851A56739D
9A68B67FB58A719E7F897DAB765EA670
867E6E864A70936363779F82B17F80549E88A36258826F85
9775A7A61E913BBE8FA48854734F905D92768078BE984A89
766875746D9EB16C46586082978F2398
9E8B7290928C9F7179C475BA678543985D89A57AAE307E6E
6B8B882CB031EC1A8A8E4EB9767D776B747788806C20468D
97799158745BAEC863896490847B8B83
7B8A6980988B98A3A5693758B164875D92568C7F67926E90
898208FF00FF00ED296E6B8A71905E797F79817E8199FFED
00CB96A7A66E5385769297737092898A
5866804680939A8799A6B59D74B2A2838295608393729A65
9B82DD00FF12CC6073A48D816C8A8594866E7F7E817E19FF
0000AE4F8C5A6AA96F938A713F7C8082
908F4597739E67E353938BA6B95D8B6E86237B857C8A7B77
6C625FFF3B871E6E62667A8E857D858688FF588A96878827
FFFF00BC709A71747D97717084721897
645BCF3ACD738D82A328A18299837085B1CB886880817558
98B24E00AFD2AE7481B8B74D7466618A920095787E7E8488
58E1FF6E8E81A36E8094848B6F616B76
9E7F5A988D96635D607B8C72865EA96F006B74978078A98B
9E6DB882F36A76972F7E77A3AB6F837A75A29A7D7A879290
67750013796F746674877967988D4392
5F8AA66BA61E766C617F776775A76E78CE7B788E6D817679
88835489347349A6A1768D405992606C9153937C80748F95
8664FFFF3C7A86879A9B526766A78F74
7B95A99D8E73A1947A6C6C797589A3E0FFB4947A78595780
75936AAC955BD26F938686B66C9E9D606C75757F807E7C96
7E646B00E89386876573956DA0C29F82
8B7396955B708F846D5E668F6E9D4B000079965265A57E7E
568F3F736690707C6289854F874F856B8E717B74778377AD
8E8245A11058887F77607E6384807E82
7C90A1936E5FB1679B607EAE5277FFFF899F686CBF58FF26
FF02FFB573715F6680726F7E6DB5568A969BA67E7F877F81
7E9B604755C38E869369AC6C947B3985
786DA6A668926874BD8789779065000046698CEA15FF4856
00FF007D67748D708E70781EFF43948073866B80A07E787A
8B836F8176625C7764928F8E8CA1706F
986B818BC546BD8E956D508C85CCFFFF77439E45FF5AC94C
DC82C183A2615587A28E95AB45948B849D96825F60718E83
7F6EA39FD94E848D7A7B815A8281667A
768E5E863E7D7E6B8B796384994F6657BA881290BA985DA4
75A754874A98905D787D676C753BAE8C837D9E8176894C6D
7C728B8B00FF5A808D7D698B7A57C678
877F8B65C05E6A4894B797725971FF878439FD56BC87597A
948EA77E834AC6BB68715FA569827A5997829B7789687383
6F828467A800FF1C8479698388A65388
AD75945D6082B289726B824965FF676488AD53A191913A98
658A8E9E64A7BA3A78A84E578599778C638A6E7979947477
7689926B66942FFF9C6D7FA46C6EBE78
739886748081679B657D7E964FAE66AA00B7988B74835F76
75877D57835B775F807257A1727791A07084806C8B78838E
7F7E86858E529A151B6CAF8C43BFAD7A
75C385798F7896699B629C6CBB79A43FAF2E7B7E7E7E7A57
889E96459CA865A673727A884DAF624696828175837D8C76
83739391947D7FA7CA9B5A8F8F86998B
8F649BC5B2986E98868B84A1958D3FFCAABE81749D82858E
847554D1764A6F7C93B19D898D68A17B897B6598828C777A
8A88708084687F90828277A16652857B
5F616F727EB29DA19C467A84489AF6771A238F8678837F88
79998384A38E706F77816D98977F6F61A9847A7161858E6C
A2A27E7F78687F899AA3946078219C6D
76A8AFD48287824F71786C6260E20026FFBD946F6D9761A1
81887E89A2968378659BA58F7586C3CDA1A294856B735A89
68827C8D85848384597E9BA76EA3A473
9D906A90933D57426C9457BA437FD7D500197D7E7F767D8B
777C95868A6897899E498CB088A679478376786F8783648E
99898D889D5F916A7E8B91828B5A917E
8870B3899D5F7D73A261B568E7384ED8E4AF187FBC567073
806C747260957770997BA8987C7D90B0639288865F97678B
6D7B7C75888D49C3D059707C778D9A6E
5E858BB67B5F647686A66F47828B82669704EC2D8F5D7776
647B5D6B82B5A664895C606972645A63958E6B848AA3816B
9072767B837A8631519692527591AB6C
8DA49C778984854E76949B84004CD4E98ED0005D537D8B6C
7371898277877D867B867C81808C619F9E486C8067876F78
827689B7857B7863FF5B907F53697580
9A8372853A8D4F5C7B8CC0275BD30B00FF00C5F1377D8B82
875F6D36A177556F7B6282A132499D39859189857E816A6C
7C817FA39457807E7B557A80668B518E
828A975E9D4E7D968B687DB8314C7EC904FF6900AB6439CE
52617841AC839D78AD8865A575836B5E847C9472A57D6C7B
68898290927E5C88768CA0569174787C
8569886F90A582B69EAA4985A785FF62E500DDB2744C9663
9772797C7A646A88737C897B5D48888879778A6F7F78948A
A37E76775A6DF4B76BAA42278A6D9376
71817D4F916A7A709AFA098DC3CE00FF579E79A29B7F7D23
92818E827B7F79956C637A86729A765E7E718678817A666E
88427D887ADC42738AC775494F839079
7A837576A14D8D70DD6A6B980076FF00C158AE4988647A85
8A82896188B6776D78A2926785776C756A7E827B8278859A
669B46681041E645948688724A73747B
A1AC698E5DBBB7627A4A932AFF0053FFEBB495A9617D9060
7C7D817F9F718798817C859A6E83916B706F88587B777A84
6DA01AFFFFA67E7B4D91773A837B7478
807B7048898D4C79956F8C8E96FF004F00EA00BED44B629F
8F7D70776385717F72968B8B658D776E84757D7B70A28C68
97204DFDA742BA706A644F5F74629A77
8C9F6A8871A871A4A26F8E528268F000FFCF760043B17699
9C91756C7B95A58C9F8F6F7D737D949C7A72766E887124BB
5DFFFF08677D648067A474906C786F80
8E5C3E606D6F838C818F81A57EB16BED00FFFF00ED00C881
63596A70777C7F666A87768A757E81635A7884508C5AFFD6
647563FF00B140C4745988798A557D7B
889A78AB60897A9D7B6583A25A60A0A48C0000FF00DB8E48
9E7E7084868A8592646C9E8375A0746C61A158C55CFA0062
0000FF36B17870B1925BA0837B5F757C
5F6E785DA15B6A8E9094717E936F8877FFDB180065CA1F2C
B97882729F4A7C7166975182759F619F729BFF18ED00FFAE
850038B372954F9E696B6F7C7785BC72
AA848A5E7281598F897F98727C927F25AD4DFFFF00FF8C0E
BB5F7EA17A7C6069769B679D7B0AB1CC4CFF00E400FF2A53
82057A8C69B36E73B2698FAB7E7B6D7E
7D8B3D49794D92928E7363714D5F94B379637F525800FFFF
00ED82B9323A696D6B8AC3862EBC0013FF00FF003906FF00
ADE886A78C7828926B9C877B737C9B7B
77846541979C7A76886FA78C709533A665670041E28CABFF
FF00C62A21FF00875588706CB500FF9EFFFF005F28EC1D4A
0026F27B77859B657E6E8A7773596280
7B5D6B9B7AA2718E95A25E7880915D9D7274641A4E00BED8
BACCE84AC29CA0803FCC8E71009067AE00FFF45200FF00E4
6C5F96817F9A9D73979E697D9978887D
8C6F99596685746C626C979644A276907EAF81A891FF6F9F
CE90DB00919F8A3C0063D4FFFF00A350FF666716FF7AFF4F
78DD3E687D89A282875A8980796A5D88
718283698978A0B0846D977C849138A951A27893752CFF14
9842D2B718CF7C52FF7000254F95FF471866CC689A4FC967
A83CA55678945E807C715B7CC269747D
918BA192BB726D6098847066576CA8A47C9C869C959B29FF
D941D27D5494C8625100F400FF9D69FF6FA05A6D81768E6A
AD727961AD75A089825A7B5C8780837E
7184508159917DA67DBF4C899D635571564DAE83777FEE00
FF8B83D70FDE38C250FFD037B759BC61A27970538CC3656C
807F4EAC7D7998887B79925776A27D80
8A778F797A66885D6E7A928A6B8479828B6E9D925E6F9F8A
2195729A4DA06D9B9000A95292876C8B617B626A766EB07F
8A8BBF6783A176598391807C6F8D7F7E
70787C7A5B7D828278665E6D8D6F957E6765857583846669
8EA16B6474A67E8795D4C36C896263898A687E8060AA6CAB
8A7853B789968A87719BD76466A26A8A
809B5C7886638C758D6A7FA367A762937F9D877C7B879571
855D8F768E9198657973809B898A9C7F3FA6B465996C7A64
5375946295AA816270714A5E80996D7B
8B7A868A7A897E817E74738F8B84827A747394767E758D90
707B777E728181858385787D737C8C827C61878785828A5D
6A8A817D8BA672797C76666F7C789275
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "In one\[Hyphen]dimensional multiresolution decomposition,we can write a \
signal as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_J\), \((t)\), "=", \(f\_\(j\_0\)\), \((t)\), "+", 
          UnderoverscriptBox["\[Sum]", \(j = j\_0\), \(J - 1\),
            LimitsPositioning->True], \(d\_j\), \((t)\)}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S2.2.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_\(j\_0\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{\(d\_j\) \((t)\)}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " at dyadic points can be obtained using the function\[NonBreakingSpace]",
  StyleBox["MRDecomposition", "MR"],
  ". The function simply does the inverse wavelet transform, and instead of \
adding the details and trend together in each recombination process, it keeps \
them separate. The output is ",
  Cell[BoxData[
      \(TraditionalForm
      \`{{\(f\_\(j\_0\)\) \((k/2\^J)\)}, {\(d\_\(j\_0\)\) \((k/2\^J)\)}, 
        \[Ellipsis], {\(d\_\(J - 1\)\) \((k/2\^J)\)}}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ". But the details (or trend) at a particular level can also be obtained by \
setting all other coefficients except those at this particular level to zero \
and then doing the inverse wavelet transform. In two dimensions because the \
number of coefficients is large, we will not provide the same functionality, \
but show here how it can be done using ",
  StyleBox["InverseWaveletTransform", "MR"],
  ". "
}], "Text",
  CellTags->{"S2.2.1", "1.17"}],

Cell[TextData[{
  "If we call the finest level ",
  Cell[BoxData[
      \(TraditionalForm\`J = 8\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ", then the coarsest level ",
  Cell[BoxData[
      \(TraditionalForm\`j\_0 = 5\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ". This gives the trend ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_5\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " at dyadic points."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.18"}],

Cell["\<\
temp1 = InverseWaveletTransform[
wtdata-MapAt[#-#&, wtdata, {1}], s4,
BoundaryCondition -> Fixed];\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S2.2.1"],

Cell[TextData[{
  "This is the density plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_5\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  "."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.19"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[temp1, Mesh -> False]", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -6 -9 ]
[.20703 -0.0125 6 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -12 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(50)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(100)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(150)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(200)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(250)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(50)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(100)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(150)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(200)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(250)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3F39322D28231F1C1C222A30363A3E42433E3934302D2A27
2525252525242323232528292B2D2E2F2E2A26221E1B1816
14151617181818191A1B1B1C1C1D1E1F2021212222232324
23211F1E1C1A19191A1F252A2F3336393A36312D29272421
1F1F1F1F1E1D1C1C1C1C1C1C1C1C1C1D1D1D1C1C1C1C1C1C
1C1C1C1C1C1C1C1C1D1D1D1D1E1E1E1E1D1C1A1918171615
141415151515151516161717181819191919191818181818
18181919191A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1C1C1B1B1A1A1A19
19191A1A1A1B1B1B1B1B1A1A1A1A1A1A1A1A1B1B1C1C1D1D
1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D1D
4C453E39332E2A27252A2F3337393C3E3F3B3734312F2D2A
2928272727252424242627292A2B2C2D2C2824211E1B1916
15151617181818191A1A1B1C1D1E1F202121212222232323
2321201E1D1C1B1B1C21262A2E3235373834302C29262421
1F1E1E1E1E1D1C1C1B1B1C1C1C1D1D1D1D1D1C1C1B1B1A1A
1A1A1919191918181818181919191919191919191919191A
1A1C1D1F2021222323232322212121201F1E1D1C1B191817
17171818191919191A1A19191919191919191A1A1A1A1A1A
1A1A1A1A1A1A1A1A1B1B1B1B1B1B1C1C1C1B1B1A1A1A1A19
19191A1A1A1A1B1B1B1B1B1B1A1A1B1B1B1B1B1B1B1B1B1B
1B1C1C1C1D1D1D1E1E1E1E1E1D1E1E1E
59524B46403B36322F3134363839393B3B38363432312F2E
2D2B2A292827262525262728292A2A2B2A2723201D1B1917
1516161718181819191A1B1C1D1E20212122222222222323
232120201F1E1D1D1E22272A2E31333536322F2B28252320
1E1E1E1E1D1C1C1B1B1B1C1C1C1D1D1D1D1D1C1B1A1A1918
181717161615151414141414141414151617181A1B1C1E1F
212427292B2D2F3132302F2D2C2B29282624211F1D1B1917
1616171718181819191919191919191919191A1A1A1A1A1A
1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A1A1919
19191A1A1A1A1A1A1B1B1B1B1B1B1B1C1B1B1B1A1A1A1919
191A1B1C1D1E1E1F1F1F1F1F1E1F1F1F
645D56504A45403B38383939393938383736353433323231
302E2D2B2A29272626272728282929292825221F1D1B1917
1616171718181819191A1C1D1E1F20212222222222222222
22222120201F1F1F2024272A2D30323434312D2A27252220
1E1E1E1D1D1C1B1B1B1B1C1C1D1D1D1E1E1D1C1B1A191817
171615141313121211111111111112121416181B1D1F2224
272B2E3235383A3C3D3B39363432302E2B2825221F1C1917
15161617181818181919181818191919191A1A1A1A1A1A1A
1A1B1B1B1B1B1C1C1C1C1B1B1B1B1B1B1A1A1A1A1A1A1919
19191A1A1A1A1A1A1B1B1B1B1C1C1C1C1C1B1A1A19191818
18191B1C1D1E1F202121202020202020
6F68615B55504B45413F3E3C3B3937353434343434343434
33312F2E2C2A292827272728282827272624211F1D1B1918
1717171718181818191A1C1D1E1F21222322222222222222
22222221212121212225282B2D2F3132322F2C2926242220
1E1D1D1D1D1C1B1B1B1B1C1C1D1D1E1E1E1D1C1A19181817
151413121111100F0F0E0E0E0E0E0F101215181C1F222629
2D32363A3E424548484643403C3A3734302C2925211D1A17
151516161717171818181818181819191A1A1A1A1A1A1A1A
1B1B1B1C1C1C1C1C1C1C1C1B1B1B1A1A1A1A1A1A1A1A1919
191A1A1A1A1A1A1A1A1B1B1C1C1D1D1D1D1C1B1A19181717
17191B1C1E1F21222322222121212121
79726B645E58534D4945423F3C3936333232343435363637
373432302E2C2B2928282828272726262522201E1C1B1918
1717171718181818191A1C1D1E2021222323222222222222
22222222232323232426292B2D2F3031312E2B2926242220
1E1E1D1D1D1C1B1B1B1C1C1D1E1E1F1F1F1D1C1B19181716
151312110F0E0D0D0C0B0B0B0B0B0C0D0F13181C2124282D
31373D41464B4E51524F4B4743403D3935302C28231F1A17
141415161717171818181818181819191A1A1A1A1A1A1A1B
1B1B1C1C1C1C1D1D1D1C1C1B1B1A1A1A1919191A1A191919
191A1A1A1A1A1A1A1B1B1C1D1D1E1E1E1E1D1B1A18171716
16181B1D1F2022232424232322222323
817A736D66615B55504B47423E393532303233353738393A
3A3734322F2E2C2A29292828272625242321201E1C1B1A18
1817171718181818191A1C1D1F2022232423232222222222
222223232424242526282A2B2D2E2F30302D2B282523221F
1E1E1D1D1D1C1C1B1B1C1D1E1E1F1F201F1E1C1B19181716
141311100F0D0C0C0B0A0A0A0A0A0B0C0F13181D23272C31
363C42484D5256595A57524E4946423D38332E2A251F1B17
141415161616171718181817181819191A1A1A1A1A1A1B1B
1B1C1C1C1D1D1D1D1D1D1C1B1B1A1A19191919191919191A
1A1A1A1A1A1A1A1A1B1C1C1D1E1E1F1F1F1D1C1A19171716
16181B1D202223252625252424242424
89837C766F6A645E58524C46413B36312F313436383A3B3C
3D3A373431302E2C2A2A29282726242322201F1D1C1B1A19
1818181818181818191A1C1E1F2122232424232222222222
222223242525262727292A2B2D2E2E2F2E2C2A272523211F
1E1E1E1D1D1D1C1C1C1D1E1E1F1F2020201E1D1B1A191716
151312100F0E0D0C0B0A0A0A0A0A0B0D10151A20262B3035
3B42484E53595D61625E59544F4B47413C37312C26201B17
131415151616161718181717181819191A1A1A1A1A1B1B1B
1B1C1C1D1D1D1E1E1E1D1C1B1B1A1A19191919191919191A
1A1A1A1A1A1A1A1A1B1C1D1D1E1F2020201E1C1A19181716
16191C1F222426272928272726272727
8E88827C76716B655F58514B443E3833303235383A3C3D3F
3F3C39363331302E2C2B292827252322211F1E1D1C1B1A19
1918181818181818191A1C1E1F2122242424232322222222
2223242526272728292A2B2B2C2D2D2D2D2B28262422211F
1E1E1E1E1E1D1D1D1D1E1E1E1F1F1F1F1F1E1D1C1B1A1918
171614131212111010100F1010111213161B20262B30353A
3F464C52575C606364605B57514D49443E38332D27211C17
1414151616161717181818181819191A1A1A1B1B1B1B1B1C
1C1C1D1D1E1E1E1E1E1D1C1C1B1A1A1919191919191A1A1A
1A1A1A1A1A1A1A1A1B1C1C1D1E1F1F1F1F1E1C1B1A181817
181B1F222527292C2D2C2B2B2A2B2B2B
8B86817D78746F6A655E57514A443E3936383A3B3D3D3E3F
3F3C3937353332302E2C2A28262422211F1E1D1C1C1B1A1A
1919181818181818191A1C1E1F2122242424242323232323
23242526272829292A2A2A2B2B2B2B2B2A28262422211F1E
1D1D1E1E1F1F1F1F1F1F1E1D1D1D1C1C1C1C1C1C1C1C1C1C
1C1D1D1D1E1E1F1F2021212223242526292C2F3336393C40
43484C5054575A5C5C5955514D4A46423D38322C27211C18
151516171818181919191919191A1A1B1B1C1C1C1C1C1D1D
1D1D1E1E1E1E1E1E1E1D1D1C1B1A1A191919191A1A1A1A1A
1A1A1A1A1A1A1A1A1A1B1B1B1B1B1C1C1C1B1B1B1B1B1B1B
1D2024272B2E30333534333232323332
8784807D7976736F6A645D57514B45403D3D3E3F3F3F3F3F
3E3C3A3836353432302E2B29262422201E1D1D1C1C1B1A1A
1A19181818181818191B1C1E1F2122242424242424242424
2425272828292A2A2A2A2A2A2A2A292928262422211F1E1C
1C1D1E1F2021212222201E1D1B1A1919191A1B1C1E1F2021
232426282A2C2E2F3132343537383A3B3C3E3F4042434445
47494C4E5051535353514E4B4846433F3B36312C27221D19
161717181919191A1A1A1A1A1A1B1C1C1D1D1D1D1D1D1E1E
1E1E1E1E1E1F1F1E1E1E1D1C1B1B1A1A191A1A1A1A1A1B1B
1B1B1B1A1A1A1A1A1A1A19191818181819191A1B1C1D1F20
22262A2E3135383B3C3C3B3A3A3A3B3A
83817F7D7B7976736F69635D57514C47434343424241403F
3F3D3B3A38373634322F2C292624211F1D1D1C1C1C1B1A1A
1A19191818181818191B1C1E1F2122232424242424252525
25272829292A2A2B2B2B2A292928282726242321201E1D1C
1B1D1F202223242424221F1C1A19181716181B1D20212326
282B2E3134373A3D4042444647494B4C4D4D4C4C4B4B4A49
494A4B4C4C4C4C4B4B4947454342403D3A35302B26221E1A
171819191A1A1A1B1B1B1B1B1C1C1D1D1E1E1E1E1E1E1F1F
1F1F1F1F1F1F1F1F1E1E1D1C1C1B1B1A1A1A1A1A1B1B1B1B
1B1B1B1B1B1B1B1B1A1918171716161616181A1C1E202225
282C3034383B3F424443424141414242
807F7E7D7C7B7977746E68625D57524D4A48474645434140
3F3E3C3B3A39383735312E2A2724211F1D1C1C1C1C1B1B1B
1A1A191918181819191B1C1E1F2122232425252525252626
2728292A2A2B2C2C2C2B2A2928272726242321201F1D1C1B
1B1D1F21232526272724201D1A18161515181B1E2224272B
2E32373B3F43474B4E515456585A5C5D5E5C59575552504E
4C4B4A4948474543424141403E3E3C3B38332E2A26221E1B
19191A1A1B1B1B1C1C1C1C1D1D1D1E1E1F1F1F1F1F1F1F20
20201F1F1F1F1F1F1E1E1D1D1C1B1B1A1A1A1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1A1917161514141414171A1D21232629
2D31363A3E4245494B4A494948484949
7E7F7F7F7F7F7E7D7A746E68625D58534F4D4B4A48454341
403F3E3D3C3B3A3937332F2B2724211E1C1C1C1C1C1C1B1B
1B1A1A19191919191A1B1C1E1F2122232425252626262727
28292A2B2C2D2D2D2D2C2A29282625242321201F1D1C1B1A
1B1D20232527292A2A26211E1A17161414171C2024272B2F
34393E43484D52565A5E616467696B6C6C6965615D5A5652
4F4D4B484643403E3C3C3C3C3B3B3A3937332E2A25221F1C
1A1A1B1B1C1C1C1D1D1D1D1E1E1E1F1F2020202020202020
2020202020201F1F1F1E1D1D1C1C1B1B1B1B1B1C1C1C1C1C
1C1C1C1C1C1C1C1C1B1917151412121213161A1E2226292D
32363B3F43484C4F5151504F4E4F4F4F
7D7F8081818282817F79736D67625D5854514F4D4B484543
4140403F3E3E3D3C3A35302C2825211E1C1C1C1C1D1C1C1C
1C1B1A1A191919191A1B1D1E1F2122232525262627272828
292A2C2C2D2E2E2F2E2D2B292726252322201F1E1D1C1B1A
1B1E2224272A2C2E2D29231F1B18161414181D22272A2E33
383E444A50555B6065696C707275777878736E69645F5B55
514D4A4744403C39373738383838383836322D2925221F1C
1B1B1C1C1D1D1D1E1E1E1E1E1F1F20202021212121212121
212121212020201F1F1E1E1D1D1C1C1B1B1B1C1C1C1D1D1D
1D1D1D1D1C1D1D1C1C1917151312111112171B2025292D32
363B4044484D51555756555554555555
7B7D7F8183848484827D77726C67635E595653514E4A4744
4242424141403F3E3C37322E2926221F1D1D1D1D1D1D1C1D
1C1B1B1A191919191A1B1D1E202122232525262727282929
2A2B2D2D2E2F2F302F2D2B2A2826252322201F1E1E1C1C1B
1C202326292D2F31312B26211D191715151A1F242A2E3338
3E444B51575D63696E73777A7D808283827C767069635E57
514D4944403B3632303132333435353534302C2824221F1D
1B1C1C1D1E1E1E1E1F1F1F1F1F2020212121212122222222
22212121212020201F1F1E1E1D1C1C1B1B1C1C1C1D1D1D1D
1D1D1D1D1D1D1E1D1D1A17151412121113181D23282D3136
3B4045494D52565A5C5C5B5A5A5A5B5B
7A7C7F8183848585847F7A75706B67625E5B5754514D4A47
45444544444342413F3A35302C2824211E1E1E1E1E1D1C1C
1C1B1A1A1919191A1A1B1D1E20212223252526272728292A
2A2C2D2E2E2F2F302F2E2C2A2927262524222221201F1E1E
1F2226292C2F3133332E2924201D1B19191E23292E32373C
42484E555B61676C71767A7D80838586847E777069635C56
4F4A45413C36312D2B2C2E2F30313233322E2A2724211F1D
1C1C1D1E1E1E1E1F1F1F1F20202021212121222222222222
2222212121212020201F1E1E1D1C1C1B1B1B1C1C1C1C1C1D
1D1D1D1D1D1E1E1E1E1C191816151515171C22272D32363C
4145494D51565A5D5F5F5E5D5D5D5E5E
7B7D7F8081828383817D7974706C6864615E5B5855524F4C
4A4A494948474645433E3935302C29252221201E1D1C1B1A
19191918181919191A1B1D1E202122242525252626272728
28292A2B2C2C2D2D2E2D2D2C2C2C2B2B2A29292827272626
26292B2D2E30323333302C292725242324272C3034373B3F
44484D52565B5F63676B6E7072757676756F69635D58524C
47433F3B37322E2B292A2B2C2E2E2F302F2C282522201F1D
1C1C1D1D1E1E1E1E1F1F1F1F1F2020202021212121212121
2121212121212120201F1E1D1D1C1B1A1A1A1A1919191919
191A1B1C1C1D1E1F201F1E1E1E1F1F2023272C3135393D42
46494C505356595B5D5D5C5C5B5C5C5C
7D7E7F7F8080807F7E7A7773706D6A6663615E5C5A575452
504F4F4E4D4C4A4946423D3935312E2A272422201E1B1918
17171717181819191A1C1D1E202123242525252525252626
26272829292A2A2B2C2D2E2F2F303131323130302F2F2F2E
2E2F3031313232333332302F2F2E2E2E2F3235373A3D3F42
45484B4E515356585B5D5F6162646464635E59544F4B4642
3D3A3734322E2B292728292A2B2B2C2C2C292624211F1E1C
1B1C1C1D1D1D1D1E1E1E1E1E1E1F1F1F1F1F202020202020
2020212121212121201F1E1D1C1B1A1A1918171716161616
1617191A1B1D1E202223242527292B2D2F33373B3E414548
4B4D4F51535557595A5A595959595959
7E7E7E7E7E7E7D7C7B787573706D6B68666462605E5B5957
5554535251504E4C4A46413D3936322F2B2824211E1B1916
15151616171818191A1C1D1E202123242525242424242525
252626272828292A2B2D2F31333436373838373736363635
353535353434343434353536373738393A3C3D3F41424445
4748494B4C4D4E4F505253545555555554504B4743403C38
3533312F2D2A2826252627272829292929262422201E1D1C
1B1B1C1C1D1D1D1D1E1E1E1E1E1E1E1E1E1F1F1F1F1F1F1F
1F2020212121212121201E1D1C1B1A191817161515141414
141617191B1D1F222427292C2F3235383B3E414346494B4E
50515253545556575757575757575757
807F7E7D7C7B7A7978767472706E6C6A6867656362605E5C
5A595857555452504D4A46423E3B3733302B27231F1B1815
14141516171718191B1C1D1E202123242525242424242424
24242526262728292A2D303336393B3D3F3E3E3E3D3D3D3D
3C3B3A393837363636383B3D3F4142444646464747484848
4848484847474646454646464646464544413D3A3734322F
2D2B2A29282625242324242525262626262422201F1D1C1B
1B1B1B1C1C1D1D1D1D1D1D1D1D1D1D1D1E1E1E1E1E1E1E1E
1F1F20212121222221201E1D1C1B1A181716151413121212
121416191B1E2023272B2F33373B3F4346494A4C4E505253
54555555555555555555555555555555
807E7D7C7A7978767574737271706E6D6B6A696765646260
5F5E5C5B59575553514D4A46423F3B38342E2925201C1815
131315161718191A1B1D1E1F202223252525242423242424
2424242525252627292D3135393C3F424444444444444444
43413F3D3B3A3837383B3F4346494B4E4F4F4E4E4D4D4D4C
4B4A4847454341403E3E3E3D3D3C3B3A393633302E2B2927
252424232221212020202121212222232221201F1D1D1C1B
1B1B1B1C1C1C1D1D1D1D1D1D1D1D1D1D1D1D1D1D1E1E1E1E
1E1F20212122222322211F1E1C1B1A191715141312111010
101316181B1E2125292E34393E43484C5052535456575859
59595857575655545354545455555454
7F7E7C7A78777574737372727271706F6E6D6C6A69676664
6361605E5D5B595654514D4A4643403C38322C27221D1915
121315161818191B1C1D1E1F202224252625252424242424
2424242525252627292E33373C404347494A4A49494A4A4A
49464442403D3C3B3B40454A4E5154575958575553535250
4E4C494643403D3A38373635343331302E2C292725232120
1F1E1E1E1D1D1D1D1D1D1D1E1E1F1F1F1F1E1E1D1C1C1B1B
1A1B1B1C1C1C1C1D1D1D1C1C1C1C1C1C1C1D1D1D1D1D1D1D
1E1F2021222323232322201E1C1B1A19171514121110100F
101316191D2023272C32383F454A5055595A5B5C5C5D5E5E
5E5D5B5A585654535252535454545454
807E7B7977757372707171727272717171706E6D6C6B6A68
67656462605E5C595754514E4B4845413D36302A241F1A16
1314151718191A1B1D1E1E1F212224252625252524252525
25252525262627282A2F353A3F44484C4E4F4F4E4E4F4F4F
4E4C49474442403F40464C52575B5F6264625F5D5A595754
514D4844403B37332F2E2C2B2928262423211F1D1C1A1918
1818181919191A1A1A1B1B1B1B1C1C1C1C1C1C1B1B1B1B1A
1A1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1D1D1D1D
1E1F2021222324242422201F1D1C1B191816141312111010
1114171B1F22262A2F363E454C52585E6262626362636363
62605D5B595654515051525253525252
807E7B797674727170707172727272727271706F6E6D6C6B
6968666463615E5C5A5755524F4C4946413B342E28221D19
161718191A1A1B1C1D1E1E1F202223242525252626272728
28282829292A2A2C2E33393E43474B4F5151515050505150
504E4D4C4B4948484A50575C62666A6D6E6B6864605E5B57
534E48433E38332E2927262422201E1D1B1A181716151414
141415161617181819191919191A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1B1C1C1C1C1C1C1C1C1B1B1B1C1C1C1C1C1D1D1D
1E1F2021222324252423211F1E1C1B1A1917161514141414
15181C2024272B2F353C444A51585E636768676767676766
65625F5C595653514F50515252525151
817F7C7A7876757372727373737372727271706F6E6D6B6A
6968666563615F5D5B59575552504D4A47413B35302B2622
1E1E1D1D1D1C1B1B1C1C1C1D1E1F202223242627292B2C2E
3030313233343537393C404346494C4E4F4E4C4B49494948
494C4F525557595B5F63686C707476787875706B67635E59
544E49433D37322D2827252423211F1E1D1B1A1817171616
151616161717181819191919191A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1D1D1E1E1E
1F202122222324242422211F1E1D1C1B1B1B1B1C1D1D1E1F
2124282B2F32363A3E444A4F555A5F636667676767676766
65625F5D5A5754525051525353535252
81807E7C7A797776757574747473727271706F6E6D6C6B69
686766656362605F5D5C5A585654524F4C47423D38342F2B
28252322201E1C1B1B1A1B1B1C1D1E1F212427292C2F3235
38393B3C3E3F4142444647484A4B4C4D4D4A47444241403F
414850585F656A7075787A7D7F818383827D78726D67625C
564F49443E37312C2827262524232221201E1C1B1A191918
1818181818181919191919191A1A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C1C1D1D1E1E1F1F20
20212122222323242322211F1E1D1D1D1D1F212325272A2C
2F3134373B3E4144484C5054585C5F626465656666666666
65625F5D5A5855535252535454545354
82807F7D7C7B7A78777776757574737271706F6D6C6B6A69
68676665646361605F5E5C5B59585654514D4844403C3834
302D292623211E1C1A1A1A1A1B1B1C1D1F23282C3034383C
3F42444547494B4D4E4E4D4D4D4D4D4C4A4743403D3A3939
3C47535E69717982888A8B8B8C8E8E8E8B868079736C665F
58514B443E37312C282626252524232322201E1D1C1B1B1A
1A191919191919191919191A1A1A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1C1C1C1C1D1C1C1C1C1C1C1C1C1D1E1E1F202021
2122222223232424242321201F1F1F1F2023272A2E313437
3B3D404245484B4E515356595B5D5F616264646565666665
64625F5D5A5856545353545455555454
8281807F7E7D7C7B7A79777675747371706F6E6D6C6A6968
676666656463626160605F5E5C5B5A5856524F4B4744413D
3934302B2723201D1A1A19191A1A1A1C1E23292F34393E43
474A4D4F5153565757565452504F4D4B49443F3B38343332
37465664727E89949B9C9B9A999A9A98948E878079716961
5A534C453E37312B27262626262524242422201F1E1D1D1C
1B1B1B1B1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1C1C1C1D1D1D1C1C1C1C1C1D1D1E1E1F20212122
2223232323242425242322212120202123272C31363A3E43
46494B4E50535557595B5C5D5E5F5F606162636464656565
64625F5D5A5856555354555556555555
838281807F7E7D7C7B79787775747271706F6E6D6C6A6968
676766666564636362626161605F5E5D5B5855524E4B4845
403B352F2A26211D1A1919191919191B1E242B31383E444A
4F525557595C5F60605D5A5754524F4C49423D3834302E2D
3345586A7B8997A4ADACAAA8A6A6A6A29E978F877E756D63
5B534C443D352E28242323232323222322211F1E1D1D1C1C
1C1B1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1C1C1C1C1D1D1C1C1C1C1C1D1D1E1F2021222223
24242424242425252524232222222223252B31373D42474C
51535557595C5E6061626262626161616162636465656565
64625F5D5A5856545354555555555555
83828181807F7E7D7C7A7977757472716F6E6D6C6B6A6968
686767666665656464646464636362615F5D5A5855524F4C
47413A342E29241F1C1A19191919191B1E252D353C434A50
56595C5F616467686764605B5754514D49423B37322D2B2B
31455C708394A3B2BCBBB7B4B1B1B0ACA69F968D847A7066
5D544C443D342D26222121212121212121201E1D1C1C1C1C
1C1C1C1C1C1C1C1C1B1B1B1A1A1A1A1A191A1A1A1A1A1A1A
1A1B1B1B1B1C1C1C1D1C1C1C1C1C1D1D1D1E1F2122232324
25252525252626262625242424242425282F363D444A5055
5A5C5E606264666868686766656463626162636465656565
64615F5C5A5856545354545555555555
838382828180807F7D7C7A78767472706F6E6D6C6B6A6968
686767676666656565656666666665656462605E5B595754
4F484039322C27221E1C1B1A1A191A1B1F27303941495058
5E616466696C6E6F6E6A645F5A56524D48413A35312C2929
304760768C9EAFBFCAC8C3C0BBBBB9B4AEA69C93897F746A
5F574E463D352D26212021212121212222211F1E1D1E1E1E
1E1D1D1D1D1D1D1C1C1C1B1B1B1A1A1A1A1A1A1A1A1A1A1A
1A1B1B1B1B1C1C1C1D1C1C1C1C1D1D1D1E1F202122232425
262626262727282829282727262627292C343C444B52585E
636567686A6C6E6F6F6D6B69676563616061636364646464
63615E5C5A5856555454555555555555
83838382828181807F7D7B78767473716F6E6D6C6B6A6969
6868676767676766666768686868686767666462615F5D5A
564E463F38322C2723201F1E1E1C1C1D212A343D474F575F
65686A6B6D707272716C66605A56524D48413B38342F2E2E
364D667C92A5B6C7D1CFCAC6C2C1BFB9B3ABA2998F857A70
655C524940372E2722212222232222232322201F1F1F1F1F
1F1E1E1E1D1D1D1D1D1C1C1B1B1B1A1A1A1A1A1A1A1A1A1A
1A1A1B1B1B1C1C1C1C1C1C1D1D1D1D1E1E1F202122232426
27272829292B2C2D2D2C2C2B2B2B2C2E3139424A51585E65
6A6B6C6E6E70727272706D6B686663616061626363636363
63605E5C595856555454555555555555
8282828282828181807E7C7A7776747271706F6E6D6C6B6A
69696969686868686868696969696868686766646362605E
5A544D47413C37322E2B292725232222262F3A434D555D65
6A6B6B6B6A6C6D6C6A65605B56524E4A4744424241404143
4B5E728496A5B3C1CAC9C6C3C0BFBEB9B5AEA7A0988F867C
72685D53493E352D27262626272625262524222120202020
201F1E1D1D1C1C1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1A1A
1A1A1A1B1B1B1B1C1C1C1D1D1D1E1E1F1F1F202021222223
25272A2C2F31343637373635353536373A41484F555B6065
696A6B6C6C6E6F6F6F6D6B69676563616061626263636362
62605D5B5A5857555455555656565555
8181828282828281807E7C7B797775747271706F6E6D6C6B
6B6A6A6A6A6A696969696969696969686867676665646361
5E59544F4A47433F3B3733302E2B29282B35404A535C636B
6F6E6B6967676765625E5955514D4A4846484A4D5052555A
626F7E8B98A4AFB9C0C0BFBEBCBCBBB8B5B0ABA69F999189
8074685D51463C332C2B2B2B2B2A29292826252322222221
211F1E1D1C1B1A1A191A1A1A1A1B1B1B1B1B1A1A1A1A1A1A
1A1A1A1A1B1B1B1B1C1C1D1D1E1E1F2020201F1F1F202021
23282C3035393C40424140404040414144494F54595D6165
68686969696A6B6B6A696867656462616061616262626262
615F5D5B5A5857565555565656565656
8081818282828282817F7D7C7A787775737271706F6E6D6C
6C6C6B6B6B6B6B6B6A6A6A6A6A6969696868686767666564
625E5A5753504D4946413D393632302F313C47505A636A71
75716D696564625F5C5854514E4B4847474C51575D62676D
757F88929BA4ACB3B9BABABABABAB9B7B5B2AFAAA5A19B94
8B7E7165584D4238302F2F2F2F2D2B2B2A28272524232323
22201F1D1C1B1A1919191A1A1B1B1B1C1C1B1B1A1A1A1A1A
1A1A1A1A1A1A1B1B1B1C1D1D1E1F202121201F1F1F1F1F20
23282F353A4044494C4B4A4A49494A4A4C5055595D606265
676767676767676767666565646362616060616161616161
605E5D5B595857565555565656565656
7F8081818282828282807E7C7B7978767574737271706E6E
6D6D6D6C6C6C6C6C6C6B6B6A6A6A69696969696969686867
6663615E5B595754514C46423E3A373537424E57616A7178
7B756F6963605D5955524F4D4B484646485059616A717981
888E93989DA3A9ADB1B3B4B6B7B7B7B6B5B3B2AFABA8A49E
96887A6D6053483D3534343333302F2E2D2B292726252524
23211F1E1C1B1A1918191A1A1B1B1C1C1C1C1B1B1A1A1A1A
19191A1A1A1A1A1B1B1C1D1E1E20212222211F1F1E1E1E1F
222A323940464C52565554535253535354575A5D60626365
66666565646464636363636262616160606060606060605F
5F5D5C5B595857565656565657565656
7F8081818283838383817F7D7B7A78777574737271706F6E
6E6D6D6D6D6D6D6D6C6C6B6B6B6A6A69696A6B6B6B6B6B6B
6A6967656362605E5B554F4A45403D3A3C47535E6871787F
817A726A635F5B56514E4C4A4845444448525E69747E8790
989A9C9EA0A4A7A9ACAFB1B3B5B5B6B5B5B5B5B3B1AFACA7
A091827466594D423938383737343231302D2B2A28272726
2523211F1D1B1A1919191A1B1C1C1D1D1D1D1C1B1A1A1A1A
1919191A1A1A1A1A1B1C1D1E1F2122232321201F1E1D1D1E
222B343D454C535A5E5E5C5C5B5B5C5B5C5E616264656667
67666564646362616161616060605F5F5F5F5F5F5F5E5E5E
5D5C5B5A595857565656565757575757
7E7F8181828384848482807E7C7B7978767574737271706F
6E6E6E6E6E6E6E6E6D6D6C6B6B6A6A6A6A6B6C6D6E6E6E6F
6E6E6D6B6A696867645D57514C474340424D5A656F787F86
887F756C645E5A534E4C4A4948454445495664707D88939E
A5A5A4A3A3A5A6A7A8ABAEB1B3B4B4B4B5B6B7B6B5B4B2AE
A798887A6B5E52463D3C3B3B3A37353432302E2C2A292928
272422201E1D1B1A1A1A1B1C1D1D1D1E1E1D1C1B1B1A1A1A
1919191919191A1A1B1C1D1E202123242422201F1E1D1E1F
232C37404A525A6166656463626363636364666768686868
68666564636261605F5F5F5F5F5E5E5E5E5E5E5D5D5D5D5D
5C5B5A59595857575656575757575757
7D7F8081838384848483817F7D7B7A787776757473727170
6F6F6F6F6F6E6E6E6E6D6C6C6B6B6A6A6A6B6D6E6F707171
727271717071706F6C665F59544E4A484955626C7780868D
8E84786E645E58504B494848484545474C5B6A7886939FAA
B1AFABA8A5A4A4A3A3A6AAAEB0B1B1B2B3B5B7B7B7B8B6B3
AD9E8D7E6F625649403F3F3E3D3A37363432302E2C2B2A29
28262422201E1D1C1B1C1C1D1E1E1E1F1F1E1D1C1B1B1A1A
191919191919191A1A1C1D1F20222425252321201F1E1F20
242F3B454F5860686D6D6B6B696A6A6A696A6A6B6B6A6968
6766646361605E5D5C5C5D5D5D5D5D5D5D5D5D5C5C5C5C5B
5B5A5A59585857575657575757575757
7D7F8082838484858583817F7D7C7A797776767574727170
70706F6F6F6F6F6F6E6D6D6C6B6B6A6A6A6C6D6F70717273
7474747474747474726C66615C575451535F6B7680898F95
968A7D72665F58504B4A4A4B4C4B4B4D5462717E8C99A5B0
B6B3AEAAA7A5A4A2A2A5A9ACAFAFAFB0B1B3B5B6B6B6B5B3
AC9D8D7F7063574B4240403F3E3B38373533312F2D2C2B2B
292826242321201F1F1F1F1F1F1F1F1F1F1E1D1C1C1B1B1A
1A19191919191A1A1A1C1D1E202223252524222222222324
29343F4A545D656D7272706F6E6E6E6E6D6D6D6D6C6B6A68
67656462605F5D5C5B5B5C5C5C5C5D5D5D5C5C5C5B5B5B5B
5A5A5958585757565656565656565656
7F808182838485858583817F7E7C7B797877767574737271
717070706F6F6F6F6E6D6D6C6B6B6B6A6B6C6E6F70717273
7373727271717171706D6A6866636261646F7A838D959BA0
A093867A6E655D55505254575A5B5C5F656E78818A949CA4
AAAAA9A9A9AAABABABADAEAFB0AFAFAEADAEAEADABAAA8A4
9D908275685C51473F3D3C3B3A38353433312F2D2C2B2B2A
2A29282828272727262524232221201F1E1E1D1D1C1C1B1B
1A1A1A1A1A1A1A1B1B1B1C1D1E1F202123242526282A2C2F
343D474F5860676D72716F6E6D6D6C6B6B6B6B6C6B6B6A69
6866656362605F5E5D5D5D5D5E5D5D5D5D5D5C5C5C5B5B5B
5A595858575656555555555555555555
80818283848485858583817F7E7C7B797877767675747372
72717170706F6F6E6E6D6D6C6C6B6B6B6B6C6E6F70717272
7371706F6E6D6D6D6D6D6D6E6F6F7072767F899199A1A6AB
AA9D8E82756C635B565A6064696C6E73777B7F83878D9297
9B9FA3A7AAAEB1B3B5B4B4B3B1B0AEABA9A8A6A3A09D9894
8D81756A5F554B423B39383736343231302E2C2B2A2A2A2A
2A2B2B2C2D2E2E2E2E2C29272422211F1D1D1D1D1D1C1C1C
1B1B1B1B1B1B1B1B1C1B1B1B1B1C1D1E2023272B2F33363B
40474F555C62686D706F6D6C6B6A69686768696A6A6A6969
68676664636261605F5F5F5F5F5F5E5E5E5D5D5D5C5C5B5B
5A595857565554545353535454545454
81828383848485858483817F7E7C7B797877777676757473
72727170706F6F6E6E6D6D6C6C6B6B6B6B6C6E6E6F717172
72706E6C6B6A6A6A6A6D707477797C80858D969EA5ACB1B5
B3A6978A7D7269605C626A71777B7F83878685858587898B
8F969EA5ABB1B6BABCBAB7B5B1AFACA9A5A29E9A95918B85
7E746A60574E463E3836353433312F2E2D2C2B2A29292929
2A2C2E303234353636322E2A2724221F1D1D1D1D1D1D1C1C
1C1C1C1B1B1C1C1C1C1B1A1A1A1A1B1C1E242A30363B4045
4B50565B5F64696D6F6E6C6B696867666566676869696969
686866656464636261616160605F5F5E5E5E5D5D5C5C5C5B
5A595856555453525252525253525252
82828384848485858483817F7D7C7B797877777776757574
73727271706F6F6E6E6D6D6C6C6C6B6B6B6C6D6E6F707172
716F6C6A68676666686D73797F83888D939BA3AAB0B7BBBE
BCAE9F9284796F66626B757D858A8F9497918B878381807F
828D98A2ACB4BAC0C3C0BBB6B1AEABA6A09C96918B847D76
6F675F574F47403A353331302F2D2C2B2B2A292828282829
2A2E3134373A3C3E3D39332E2A26221F1C1D1D1E1E1E1D1D
1D1D1C1C1C1C1D1D1D1B1A191818191A1D242D343C434950
56595D6063676A6C6D6C6A69676664636264656667686868
69686766656564636362626161605F5F5E5E5E5D5D5C5C5B
5A595756555352515051515151515151
82838484848585858482817F7D7C7B797878777777767575
74737271706F6F6E6D6D6C6C6C6B6B6B6B6C6D6E6E6F7071
716E6B6866656565676F7880878E949BA1A9AFB5BAC0C4C7
C4B5A5988A7E746A67717D8791979DA3A59C928B837E7B78
7A8795A1ADB5BDC4C8C3BDB7B1ADA8A29C969089827A736B
645D565049433D3733312F2E2D2B2A2A2928282828282929
2B3034383C404244443E38322C28241F1C1D1E1E1F1E1E1E
1E1D1D1C1C1D1D1D1D1B1918171617181C252F38424A5159
5F61636567696C6D6E6C6A69676563626162646566676768
6867666665656464636362626160605F5E5E5E5D5D5C5C5B
5A595755545251504F50505050505050
83838484848484848482817F7D7C7B797878787877777676
7574737170706F6E6D6D6C6C6C6B6B6B6B6C6C6D6E6F7070
706D69676564636467717B858E969DA5ADB3B9BEC3C9CDCE
CBBCAC9E9083786E6B7785909BA3A9B0B1A5988E837C7772
7381919FADB6BEC7CBC5BDB6AFABA69F989189827A716961
59544E49443E3935322F2E2C2B292928282727272828292A
2C32373C4145484B4B443C362F2A251F1C1D1E1F201F1E1F
1F1E1D1D1C1D1E1E1D1B1918171616181C27323D47505961
6769696A6A6C6D6E6D6C6A68676462616061636465666667
6766666565656464636362626160605F5E5E5E5D5D5C5C5B
5A5856555352504F4E4F4F4F504F4F4F
83848484848484848382807F7D7C7B797878787878777776
7674737271706F6E6D6D6C6C6C6B6B6B6B6B6C6C6D6E6F6F
6F6B68656362616266717D88939CA5AEB6BDC2C7CBD0D4D6
D2C3B2A496897E74717F8E9AA6AFB6BDBDAE9D8F8278716A
6A7A8D9CABB6BFC9CDC6BEB6ADA9A39C948B837A71675E55
4E4A46423E3935322F2D2B2928272626262626262727282A
2D333A40464B4F52524A413A322C26201C1D1E1F20201F1F
1F1E1E1D1D1D1E1E1E1B1918171617181D2936414D576069
70706E6E6D6E6E6D6C6B69676563615F5E5F616264646566
6666666565656564646363626161605F5F5E5E5D5D5C5C5B
5A5856545351504E4E4E4E4E4F4F4E4E
83838384848484838381807E7D7C7A797878787878787777
7675737271706F6E6D6D6C6C6C6B6B6B6B6B6C6C6D6E6E6F
6E6B67656361616266717E89959EA7B0B9C0C6CBCFD6DADC
D8C9B9AB9D90857B788695A1AEB7BDC4C4B3A09081766D65
64758898A8B3BCC6CAC3BAB2A9A59F9890877D746B61574E
4743403D3A3632302D2B2927262525242424242526262729
2D343D434A5055595950463D352E27211C1D1F2021202020
201F1E1D1D1D1E1E1E1C1A1A19191A1C212D3A46525D666F
757472706E6E6E6D6B6A68676562605E5D5F606263646465
6665656564646464646363626160605F5E5E5E5D5D5D5C5B
5A5856545351504E4D4E4E4E4F4E4E4E
818282828282828282807F7E7C7B7A797878787878787777
7675747271706F6E6D6D6D6D6D6C6C6C6C6C6D6D6D6E6F6F
6F6C69686665656669727B848D949BA3ACB5BFC6CED6DCE0
DED0C0B2A4988D83808C99A3AEB5BAC0BFAF9E8F81776F67
657484919EA7AFB7BBB6AFA8A19D99938C837A726960574F
4844403D3935312E2C292826252423232322222223232426
2A343D454D545A5F5F554B41383029221D1E202122212121
201F1E1C1C1C1C1D1D1E1E1F202224272C37424C565F676F
747371706E6E6D6C6A6A6867666462616061626363646465
656464646363636362626161605F5F5E5E5E5D5D5D5D5C5C
5B5957555452514F4F4F4F5050505050
7F8080818181818181807E7D7B7A79787777787878787777
767574737170706F6E6E6E6E6D6D6D6D6D6D6D6E6E6F6F6F
6F6D6C6B6A6A6A6B6D72787E84898E949DA9B6C0CBD5DDE3
E3D5C6B8AB9F968C88919CA5ADB2B6B9B8AA9B8E82787169
68737F8A959BA1A8ABA7A29D9896938E8881787169605951
4A45413D3935312D2A282625242322222221202021212224
28333E4750585F64655B4F453B332B231E1F212223222121
211F1D1C1B1B1B1C1D1F2225282B2F3338414A525A61686E
7271706E6D6C6C6B6A696968676664636363646464646464
64646363626262616160605F5F5E5E5D5D5D5D5D5D5D5C5C
5B5A5856555352515050515151515151
7D7E7F7F80808080807F7D7C7B7A79787777777878787777
777574737271706F6E6E6E6E6E6E6E6E6E6E6E6E6E6F6F70
706F6E6D6D6D6E6E707275797C7F83888F9EADBAC7D3DDE5
E7DACBBEB1A79E949097A0A7ADB0B2B4B2A6988D8279726B
69727C848C91969B9E9B989591908E8A857E777068615A52
4C47423E3935302C292726242322222121201F1F1F1F2022
27333F49535C636A6A6053483D352D251F20222324232222
211F1D1B1A1A1A1B1D21252A2F34383D434A51575D63696E
71706F6D6C6B6B6969696968686766656565656564646464
63636262616160605F5F5E5E5E5D5D5C5C5C5D5D5D5D5D5C
5C5A5857565453525152525253525252
7C7C7D7E7E7F7F7F7F7E7C7B7A7978777677777777777777
777674737271706F6F6F6F6F6F6F6F6F6F6F6F6F6F6F6F70
70706F6F6F707172737272737475777A8293A5B4C4D1DDE7
EADED0C4B7AEA69D989EA4A9ADAEAFAFACA1968C827A746E
6B71787E84888B8F91908E8C8A8A8986837C756F68615B54
4E49433F3A35302C2826252322212121201F1E1E1E1E1F21
2633404B5660686F7064574C403830272121232425242322
221F1C1A1919191A1C222930363C42484E53575C6065696D
6F6E6D6C6B6A696867686869696868676766666565646463
6362616160605F5E5E5E5D5D5D5C5C5C5C5C5C5C5D5D5D5D
5C5B5958565554535353535354535353
7A7B7C7C7D7E7E7E7E7D7C7A797877777676777777777777
77767473727170706F6F6F6F6F6F6F6F6F6F6F6F6F6F6F6F
6F7070707172737474716F6E6E6D6E70788B9FB0C2D1DEE9
EEE2D5CABEB6AEA5A0A4A9ACAFAFAEADAA9F948B817A736D
6A6E73787C7F81848686858584848483807A736C66605953
4D47423D38332E2A262423222120201F1F1D1C1C1C1C1D1F
2533414D59646D74766A5C50433A31282222242526252323
221F1C1A181818191C242C343C434A51575B5E6164686B6E
6F6E6D6C6A69686666666768686868686867666565646363
626161605F5F5E5D5D5D5C5C5C5C5B5B5B5C5C5C5D5D5D5D
5D5B5A58575655545354545455545454
797A7B7B7C7D7D7D7D7C7B7A797877767676777777777777
77767573727171706F6F707070707070706F6F6F6F6F6F6F
6F7071717273757575716C6A686666676E8399ACBFCFDDEA
F0E5D9CFC4BCB6AEA9ABAEB0B1B0ADACA79D938A8179736D
696C70737678797B7D7E7F7F808181807E78716B645F5953
4D47423D37322D2925232221201F1F1F1E1D1C1C1C1C1D1F
253443505D6871797B6E6053463C33292323252627252424
231F1C1A181717181C252F38414951595F626466676A6D6F
6F6E6D6B6A68666564656667686868696867666564636362
6160605F5F5E5D5D5C5C5C5B5B5B5B5B5B5B5C5C5D5D5D5D
5D5C5A59585756555454555555555555
78797A7A7B7C7C7C7C7B7A79787776767576767777777777
7776757473727170707070707070707070706F6F6F6F6F6F
6F7071727375767776706A65625E5D5D647A91A6BACBDAE8
EFE7DCD2C9C3BDB6B1B2B3B3B2AFACA9A49B9289817A746E
6A6C6E70717272747678797B7C7E7F7F7D78716B65605A54
4E48433D38322D2825232221201F1F1F1F1D1C1C1C1C1E20
27364553606C757D7F726356483E352B2425262728262524
231F1C19171616171C26323C475059616769696A6A6C6E6E
6E6D6B6A6967656363646667686869696968676564636261
60605F5F5E5D5D5C5B5B5B5B5B5A5A5A5A5B5C5C5C5D5D5D
5D5C5B59585756555555555656565556
7778797A7A7B7B7C7C7B7978777776757575767777777777
7776757473727170707070707070707070706F6F6F6F6F6E
6F70727374767778766F68635E5958575E748B9FB4C5D4E2
EAE4DBD3CBC7C3BDB8B8B7B6B4B0ABA7A29A928A837C7671
6D6E6F707272727375777A7C7D7F8181807A746E67625D57
514B453F3A342E2A2624232221212020201F1F1F20202225
2B3A4956636E777F817465584A40372D2626272829272525
231F1C19171616171C27343F4B555E676D6E6D6C6C6D6E6E
6D6C6B6A6866646262636566676868696968666564636261
605F5F5E5E5D5C5C5B5B5B5B5B5A5A5A5A5B5B5C5C5D5D5D
5D5C5A59585756555555555556565555
78797A7A7B7B7B7C7B7A7978777676757575767677777777
77767574737271717070707070707070706F6F6F6F6F6F6F
6F70717172747575746E6864605D5B5B61738799AAB9C6D3
DBD7D2CECAC8C6C2BFBEBCBAB7B3AEAAA49D958E87807B76
7375787B7E7F818385868788898A8A8A88827B746D68625B
554F49443E39342F2B29282726252525252626282A2B2D30
3743505B6670777E7E7264584B42392F2828292929272625
231F1C19181616181C2834404B565F686E6E6D6D6C6D6E6E
6D6C6B6A6866656362636465666767676766656463626261
60605F5F5E5E5D5D5C5C5C5C5B5B5B5B5B5B5B5C5C5C5C5C
5C5A5958575655545353545454545454
7A7A7A7B7B7B7B7B7B7A7978777676757575767677777777
777675747372727170707070706F6F6F6F6F6F6F6F6F6F6F
6F6F707070717272716D69666361606165748492A0ACB7C2
CACAC9C8C7C8C9C7C6C3C1BDBAB6B2ADA7A099928C85807B
797D82878B8E91949696969695969594918A837C746E6760
59544E49443E3935312F2D2C2B2A2A2A2B2D2F3134373A3D
434D57606971777B7B7063584C433A312A2A2A2A2A282625
23201C1A181717181D2835404C565F686E6E6D6D6C6D6E6D
6D6C6B6A6967656463636465656565656564646362626261
616060605F5F5E5E5E5D5D5D5D5C5C5C5C5C5C5C5B5B5B5B
5A595856555453525152525252525252
7B7B7B7B7B7B7B7B7B7A7978777676757575767677777777
7776757473737271707070706F6F6E6E6E6E6E6E6F6F6F6F
6F6F6F6F6F6F70706F6C6967656464646974818C97A1AAB4
BBBEC1C3C5C9CBCCCCC9C5C1BDB9B4B0AAA39C9690898480
7F848B91969A9EA2A5A4A3A2A1A09F9D99928A837B746C65
5E58534D48433E3936343230302F2E2F3033363A3E414549
4E565E656B72767A796E62584D443C332D2C2C2B2A282625
23201C1A181718191D2935404C565F686E6E6D6C6C6D6E6D
6D6C6B6A6967666463636464646463636363626262626161
6161606060605F5F5F5E5E5E5E5D5D5C5C5C5C5B5B5B5A5A
59585655545351515050505151515151
7B7C7C7C7C7C7C7B7B7A7978777675757475767677777777
77767574737372717170706F6F6E6E6E6D6E6E6E6E6F6F6F
6F6F6E6E6D6D6D6D6D6B6968676767686C747D868E969DA5
ACB3B9BEC3C9CED1D2CEC9C4BFBBB7B2ACA69F9A948E8985
858C949BA2A7ACB1B4B2B0AEACABA9A6A29A928A827A726A
635D58524D48423E3B3836353433333435393E43484C5054
595F65696E727677766C61584E453D352F2E2D2C2B292625
23201D1B191818191E2935404C565F686E6E6D6C6B6C6D6C
6C6B6B6A6968666564636363636262626161616161616161
616161616160606060605F5F5F5E5E5D5D5C5C5B5B5A5959
585655545251504F4E4F4F4F4F4F4F4F
7C7C7C7C7C7C7B7B7B7A7978777675757475767677777777
77767574747372727170706F6F6E6D6D6D6D6E6E6E6F6F6F
6F6E6D6D6C6C6C6C6B6A6868676767696B71787E858B9197
9FA8B2BAC2CAD1D6D8D3CDC7C1BDB8B2ADA7A29D98928D8A
8A929BA3ABB1B6BBBEBDBAB8B5B4B2AEA9A19990887F776F
67625C57514C47423F3C3A39383737373A3F454A5055595E
63676B6D70737576736B61584F473F37312F2E2D2B292725
23201D1B1918181A1E2A36414D5760696F6E6D6C6A6B6B6B
6A6A6A696967666564636362626161606060606161616161
6161616161616161616060605F5F5E5E5D5C5C5B5A5A5958
5755545351504F4E4D4E4E4E4E4E4E4E
7C7C7C7C7C7B7B7B7A797877777675747475757676777777
77767575747372727170706F6E6E6D6D6C6D6D6E6E6F6F6F
6F6E6D6C6B6B6B6A6A696867676768696B6F73787D81868B
939FACB7C1CBD4DBDED8D1CAC3BEB9B3ADA8A4A09C96928F
9098A2AAB2B9BEC4C7C6C3C0BDBBB9B5B0A89F978E857D74
6C66605B554F4A46423F3D3C3B3A3A3B3E444B51575D6268
6C6E707172747574716960584F48413933312F2E2C292725
23201D1B1A18191A1E2A36424D5760696F6E6C6B696A6A69
6869696968676665646363626161605F5F5F606060616161
616161616161616161616060605F5F5E5D5D5C5B5A595857
56555352504F4E4D4C4D4D4D4D4D4D4D
7D7D7C7C7C7C7B7B7A797877767675747475757676777777
777675757473727271706F6F6E6D6D6C6C6D6D6E6E6F6F6F
6F6E6C6B6A696968686867676868696B6C6E707376787C80
8897A6B3C0CCD6DFE3DDD4CCC5C0BBB4AFAAA6A39F9A9694
959EA8B1BAC1C7CED1CFCCC9C6C4C1BDB8AFA69D948B8279
716B655F59534D494542413F3F3E3E3F424951585F656B71
75767575747574726F675F585049423B3533312E2C2A2726
23201D1B1A19191A1F2A36414C565F686E6D6B6A68696968
67686868686766656463626261605F5E5E5E5F5F60606161
61626262626262626262616160605F5F5E5D5C5B5A595756
55545251504E4D4C4B4C4C4C4C4C4C4C
7D7D7C7C7C7C7B7B7A797877767675747474757676777777
777675747473727271706F6F6E6D6D6C6C6C6D6E6E6F6F6F
6F6D6C6B696968676767676768696A6B6C6D6E707273767A
8292A3B2C1CED9E3E8E0D7CFC7C2BDB6B0ACA8A5A29C9997
98A1ACB4BDC5CBD1D5D4D1CECBCAC8C4BFB6ADA49A91887F
766F68625B554F4A4543424140404041454C555D646B7278
7C7B7978767574716D665F58514A433C3734322F2D2A2826
23201D1C1A19191B1F2A36404B555D666C6B6A6967686968
68686868686766656463626261605F5E5E5E5F5F60606161
6262626262626262626262616160605F5E5D5C5B59585756
555352504F4E4D4C4B4B4B4C4C4C4B4B
7B7B7C7C7C7C7C7B7B7A7978777675747475757676777777
777675747373727171706F6F6E6E6D6C6C6D6D6E6E6E6F6F
6F6D6C6B69696867676766666767686A6B6D6F7275777B80
8898A8B6C4D1DCE6EAE3DAD2C9C4BFB8B2ADA9A6A29C9896
969EA7AFB7BDC3C9CDCDCDCCCBCBCBC8C4BCB2A9A0978F85
7C736B635B534C45413F3F3F3F3F3F41454D565D656C7379
7D7C7B79777775736F686059524B443D3734322F2D2A2826
24201E1C1A191A1B1F29343E4851596167686868686A6B6C
6C6B6B6A6968666564636362626160605F60606061616162
62626262626262626262616160605F5F5E5D5C5B5A595857
55545251504E4D4C4C4C4C4C4C4C4C4C
7A7A7B7B7B7C7C7C7B7A7978777675757475767677777777
777675747372727170706F6F6E6E6D6D6D6D6E6E6E6E6F6F
6E6D6C6B6A69696867666665656666686A6D7075797D8187
909EAEBBC8D4DFE8ECE5DCD4CCC7C1BAB4AFAAA6A29C9794
949BA2A9AFB5B9BFC3C6C8C9CACCCDCCC9C1B8AFA69D958B
82776D645A5148413B3B3B3C3D3D3F41454D565D656D737A
7E7D7C7A797877747069615A534B443D373532302D2A2826
24211E1C1B1A1A1B1E28323B444C545C62646668696C6E6F
706F6D6C6A69676564646463636262616161616162626262
62626262626262626262616160605F5E5E5D5C5B5A595857
56555352504F4E4D4C4C4D4D4D4D4D4D
79797A7B7B7C7C7C7C7B7978777675757475767677777777
777675747372717170706F6F6F6E6E6D6D6E6E6E6E6E6E6E
6E6D6C6B6A6969686866656564646566686D72777D81878D
96A4B3BFCCD8E1EAEEE7DED6CEC9C3BCB6B0ABA7A29C9793
93989EA3A9ADB1B6BBBFC3C6C9CCCECFCDC5BCB3AAA29A90
867B6F64594E453C3737383A3C3C3E41454D565D656D747A
7E7E7D7B7A797875716A625B534C453E383533302E2B2826
24211E1C1B1A1A1B1E263038414850575D616366696C6F71
72716F6D6B69676564646464646463636262626262626262
626262626262626262616160605F5F5E5D5D5C5B5A5A5958
5755545251504E4D4D4D4D4D4E4D4D4D
7778797A7B7C7C7C7C7B7A79777676757475767677777777
7776757473727170706F6F6F6F6E6E6E6E6E6E6E6E6E6E6E
6E6D6C6B6A6A69696866656463636465676D737A81868C94
9DAAB8C4CFDAE4ECEFE8E0D9D1CBC6BEB8B2ADA8A29C9793
91959A9EA3A6A9AEB3B9BFC3C8CDD0D2D1CAC1B8AEA79F95
8A7D7064584C4138323335373A3B3D40454D565D656D747B
7F7F7D7C7A7A7976726B635C544C453E383533302E2B2826
24211E1C1B1A1A1B1E252D353D444B52585C6164686D7073
7472706E6B69676564646565656564646464636363636362
6262626262626262616161605F5F5E5E5D5D5C5B5B5A5958
5756545351504F4E4D4D4E4E4E4E4E4E
7778797A7B7C7C7D7D7B7A79787776757475767677777777
77767574727271706F6F6F6F6F6F6E6E6E6E6E6E6E6E6E6E
6E6D6C6B6A6969696866646463636365676E747C83898F97
A0ADBBC6D2DCE6EDF0EAE2DBD3CEC8C1BAB4AEA9A39D9793
9194989CA0A2A5A9AFB6BDC4CAD0D4D7D7CFC6BDB4ADA49B
8F817365584B3F352E303336393A3D41464E575F676F767D
81807F7D7B7A7976726B635C544D463F393633312E2B2826
24211E1D1B1A1A1B1E242B323940464D53585E62676D7175
7674716E6B69676563646565666665656565646463636363
6363626262626262626160605F5F5E5E5D5C5C5B5B5A5959
5856555352504F4E4D4E4E4E4E4E4E4E
767778797B7B7C7D7D7C7A79787776757575767677777777
77767473727171706F6F6F6F6F6F6F6E6E6E6E6E6E6E6E6E
6D6C6B6A6A6969686866646363626364686E767D858C939B
A4B1BDC9D4DEE7EFF2ECE4DDD5D0CAC3BCB6B0AAA59E9894
9294979A9D9FA2A5AAB3BCC3CBD1D7DBDBD3CAC1B7B0A89E
9283746557493D322B2D3134383A3C41474F575F6870777E
8382807E7C7B7976716B635C554D463F393634312E2B2826
24211F1D1C1B1B1C1E232930363B41474D545A60656B7175
7774716E6B69676463646566676666666665656464646363
6363636262626262616160605F5F5E5D5D5C5C5B5B5A5A59
5856555352514F4E4E4E4E4E4F4E4E4E
757678797A7B7C7D7D7C7A79787776757475767677777777
777574737271706F6F6F6F6F6F6F6F6F6F6E6E6E6E6E6E6E
6D6C6B6A6A6969696866646362626364676F7880899097A0
A9B5C1CCD6E0E9F0F3EDE5DED7D2CCC5BEB8B2ACA69F9994
92939597999A9C9FA5AFB9C1CAD1D7DCDDD6CCC3B9B2AAA0
9484736456473A2E272A2E3236383B40464E575F6770787E
8382807E7C7B7976716B635C554E47403A3734312E2B2826
24211F1D1C1B1B1C1E22282D32373C42484F565C63696F74
7674706E6B69676463646667686767676766666564646363
63626262626262616160605F5F5E5E5D5C5C5C5B5B5A5A59
585755545251504F4E4E4E4F4F4F4F4F
747677797A7B7C7D7D7C7A79787776757475767677777777
767574737170706F6E6E6E6F6F6F6F6F6F6F6E6E6E6E6E6D
6D6C6B6A6A6969696866646362626264687079828B939BA4
AEB9C4CFD8E2EAF1F3EEE7E0D9D4CEC7C0BAB4AEA8A19B96
939394959797989BA0AAB5BEC7CFD6DBDCD4CAC1B7B0A79D
918170615244372B24272B2F3436393E444D565E666F777E
8382807E7B7A7976716A635C554E47403A3734312E2B2826
23211F1E1D1C1C1D1E22262A2F33373C424950575E646A6F
72706E6C6968676564656767686868686867666565646363
626262626261616160605F5F5E5E5D5D5C5C5B5B5B5A5A59
585755545251504F4E4E4F4F4F4F4F4F
747677787A7B7C7C7C7B7978777675747374757676767777
76757372706F6E6D6D6D6E6E6E6E6E6E6F6E6E6E6E6E6E6D
6D6C6B6A6A696969686664636262626468707A838C949CA5
AFBAC6D0D9E3EBF2F4EFE8E2DBD5D0C9C2BCB7B1ABA59F9A
96959596969696989CA6B0B9C1C8CED3D3CABFB5ABA39A8F
847567594C3F33292224282C3032353A4049535B646D767D
82817F7D7A797874706A635C554E47403A3734312E2B2825
23211F1E1D1D1D1E1F2225292C3034383D42484E53595E62
666666666667676768686969696969686867666564636362
616161616060605F5F5E5E5E5D5D5C5C5B5B5B5A5A5A5959
585655535251504F4E4E4E4F4F4F4F4F
74767778797A7B7C7C7A7977767574737273747576767676
76747371706E6D6C6C6C6D6D6E6E6E6E6E6E6E6E6E6E6D6D
6D6C6B6A6A6A6969686664636262636468717A838D959DA6
B0BCC7D1DAE4ECF3F5F0E9E3DCD7D1CBC4BFBAB4AFA8A39E
9A9897979695959599A1ABB3BAC1C6C9C9BFB3A89D958B81
75695C51453A2F27212225282C2D30353B454F58626B747C
81807D7B797876736F69625C554E47403B3734312E2A2724
2221201F1E1E1E1F202225272A2D3034373B4044484C5054
585B5E616366686A6B6B6B6A6A6969686767666564636261
60605F5F5F5E5E5E5D5D5D5C5C5C5C5B5B5B5A5A59595858
5756545352504F4E4E4E4E4E4F4E4E4E
75767778797A7A7B7B797876757473727272747475767676
767472716F6E6C6B6B6B6C6D6D6D6E6E6E6E6E6E6D6D6D6D
6D6C6B6A6A6A6A69696664636362636468717B858E969FA8
B2BDC8D2DBE5EDF3F6F1EAE4DDD8D3CCC6C1BCB7B2ACA7A2
9E9B9A9897959494969EA7AEB5BABFC2C1B6A99D91887F74
695E53493F352C2420202325282A2C3137414C566069727A
7F7E7C7A787775726E68625B554E47403B3734312E2A2724
2221201F1F1F202021232426282A2D2F3235383B3E414448
4C51565B6064686B6E6D6C6B6A6A69686766666564626160
5F5F5E5E5E5D5D5C5C5C5C5B5B5B5B5B5A5A5A5959585857
5655545251504F4E4D4E4E4E4E4E4E4E
7576777878797A7A7A787776747372717172737475757676
767472706E6D6C6A6A6A6B6C6D6D6D6E6E6E6E6D6D6D6D6D
6D6C6B6B6A6A6A6A696765636362636569727C869098A1AA
B4BFCAD3DCE5EDF3F6F1EBE5DFDAD4CEC8C4BFBAB5B0AAA5
A19E9C9A98959392949BA3A9AFB4B8BAB8AC9F92867C7267
5C534A41393029221E1F20222426292D333D48535D677078
7D7C7A78767574716D67615B544E47413B3734312D292623
21212020202021212223242526282A2B2D2F30323436383B
3F474E555C62686D706F6D6C6B6A6A68676665646362605F
5E5D5D5D5C5C5B5B5B5B5A5A5A5A5A5A5A59595858585757
5655535251504F4E4D4D4E4E4E4E4E4E
747576777879797979787675737271707071727374757576
7573716F6D6C6B69696A6B6B6C6D6D6D6E6E6D6D6D6D6D6D
6D6C6B6B6A6A6A6A696765646363636569737E88939BA4AE
B8C2CCD5DDE6EEF4F6F1ECE6E0DBD6D0CAC6C1BDB8B3ADA8
A4A09D9A9793908F90979EA4AAAEB1B3B1A496897C71675C
5149423B342C25201C1C1D1F212225292F3A454F5A646D75
7B7A7877747473706C67605A544D47413B3734302D292623
212121212121222223232323232526272828292A2B2C2E30
353E48505960676E72716F6D6B6B6A68676665646361605E
5D5C5C5C5B5B5A5A59595959595959595959585857575756
5554535251504F4E4D4D4E4E4E4E4E4E
747576777778787978777574737271706F70727374757575
7573716F6D6B6A6968696A6B6C6C6D6D6E6D6D6D6D6D6D6D
6D6C6B6B6A6A6A6A6A676564636363656A747F8A959FA8B2
BCC6CFD7DFE7EEF3F6F1ECE7E1DCD7D1CCC8C4BFBBB6B0AB
A7A29E9A97928F8D8D949BA0A5AAACAEAB9D8F8173695E52
48413B352F28221D1A1A1B1C1E1F21252B36424C57616A73
787876757373716F6B66605A544D47413B3734302D292523
212121212222222323232221212222232322222223232527
2C36414B555E666E72716F6D6B6B6A686766656463615F5D
5C5C5B5B5A59595858585858585858595858585757575656
55545352514F4F4E4D4D4E4E4E4E4E4E
7475757677777778777675737271706F6F70717273747575
7573706E6C6B6A6868696A6B6C6C6C6D6D6D6D6D6D6D6D6D
6D6C6C6B6B6B6B6B6A686564636364656A75818C98A2ACB6
C0C9D1D8E0E8EEF3F5F1ECE7E2DDD8D3CDCAC6C2BEB9B4AF
AAA5A09C98938F8D8C92999EA2A6A8A9A59788796B605549
3F39342F2A241F1C191819191B1C1E2228333F4A545E6770
767574737171706E6A655F59534D47413B3834302D292522
2021212222232324242321201F2020201F1D1C1B1B1B1B1D
222E3A46515B646D72716F6D6B6A6A686766656463605E5D
5B5B5A5A5959585757575757585858585857575756565655
55545251504F4E4D4D4D4D4E4E4E4E4E
7374757576767677767574737170706F6F70717273747474
7472706E6D6B6A6968696A6B6C6C6C6D6D6D6D6D6D6D6D6D
6D6C6C6B6B6B6B6B6B686664636363656A76838F9BA5AFBA
C4CCD3DAE1E8EEF2F4F0ECE7E2DDD9D3CECBC8C4C0BCB7B3
AEA9A4A09C9793908F959B9FA3A7A8A9A4968576685C5044
3A35302C28231E1B191818181A1B1D2127323D48525C656D
737372716F6F6F6C69645F59534D47413C3834312D292522
2021222223232424242321201E1E1E1E1D1A181716151517
1B2835404C5760696F6E6C6B696A6A686766656462605E5C
5A5A5A595958575757575757575757575757575656565655
54535251504F4E4D4D4D4D4D4D4D4D4D
727373747475757575747372717170706F70717272737373
7372706F6E6D6C6B6B6B6C6C6C6D6D6D6D6D6D6D6C6C6C6C
6C6C6C6B6B6C6C6C6C69666463626364697684919EA9B3BF
C8D0D6DCE1E8EDF1F3EFEAE6E1DDD8D3CECCC9C6C3BFBBB8
B4B0ACA8A4A09D9A9AA0A6AAAEB1B2B2AE9E8D7E6E615548
3E38332F2A241F1C1A191A1B1C1E21242A343E48525B636B
70706F6E6D6E6D6B68635E59534E48423D3935322E2A2623
2121222223232324242321201F1F1F1F1E1B191817161618
1C26313C464F575F656666666668696969676564625F5D5B
59595A5A5959585858585757575757575756565656565655
555352504F4E4D4C4C4C4C4C4D4C4C4C
717172727373737474737372727171707071717272727272
727271706F6F6E6E6D6D6D6D6D6D6D6D6D6D6C6C6C6C6C6C
6C6C6C6C6C6C6D6D6D6966646261626368768593A0ACB7C3
CDD3D8DDE2E8EDF0F1EDE9E5E0DCD7D2CECCCBC8C6C3C0BD
BAB6B3B1AEAAA8A6A6ACB2B6B9BCBEBDB8A8978676685C4E
433C37322D27211E1B1B1C1E202224282E37404851596168
6D6D6D6C6B6C6B6A67635E59534E49433E3A36332F2B2724
222222222323232323222120202020201F1D1B1A1918191A
1D252E373F464D545A5D5F616366686A6A686664615F5D5A
59595A5A5A5A595959585857575756565656565656565655
555351504F4D4C4B4B4B4B4B4C4B4B4B
707071717172727272727272727171717171717171717171
7171717171707070706F6F6E6E6E6D6D6D6C6C6C6C6C6C6B
6B6C6C6C6C6D6E6E6D6A66646261616368778695A4B0BCC8
D2D7DBDFE2E8ECEEEFECE7E3DFDBD7D2CECDCCCAC8C6C3C1
BFBCBAB8B6B4B2B0B1B6BCC0C4C6C7C7C1B19F8E7D6F6153
47403B353029231F1C1D1E202224272B3139414850585F65
6A6A6A6A6A6A6A6866625D58534E49443F3B3734302C2825
23222323232323232322212120212121211F1D1C1B1A1A1B
1D242B32393F444A5054585C6064676A6B696663615E5C5A
58595A5A5B5B5A5A5A595858575656565555565656565555
555351504E4D4C4A4A4A4A4B4B4B4B4B
6F6F6F707070717171717171717272727271717171717171
71717171727272727271706F6F6E6E6D6C6C6C6C6C6B6B6B
6B6C6C6C6D6E6E6F6E6A66646261616268778897A7B4C0CC
D6DADDE0E3E8EBEDEDEAE6E2DEDAD6D1CECDCDCCCBC9C7C5
C4C2C1C0BFBDBCBBBCC1C7CACED1D1D0CBB9A79584756758
4C453E38332B25211E1F202225272B2F343B42484F565C62
676868686868686765615C58534E4A45403C3834312D2926
2323232323222222222222212122222222201F1D1D1C1C1C
1E23282D32373B40464C52575C62666A6C696663605E5C59
58595A5B5B5B5B5B5B5A5958575656555555555556565555
5553514F4E4C4B4A49494A4A4A4A4A4A
6E6E6E6E6F6F6F6F70707171717272727272717170707070
7071717273737474747371706F6E6E6D6C6C6C6C6B6B6B6B
6B6B6C6C6D6E6F706F6B67646260616268788999A9B7C4D1
DADEE0E2E3E7EAECEBE8E5E1DDD9D5D1CECECECDCDCBCAC9
C8C7C7C6C6C5C4C4C5CACFD3D6D8D9D7D1BFAC9A88796A5B
4E47403A342D26221F20222427292D31363C42484E545A5F
636465656566666563605B57534E4A45413D3935312D2A26
2423232323222222222222222223232323211F1E1D1C1C1C
1D2024282C3033383D444C52595F656A6C6966625F5D5B58
57585A5B5C5C5C5C5B5A5958575655555454555555555555
5453514F4D4C4A494848494949494949
6D6D6D6D6D6E6E6E6E6F7070717172727272717170706F6F
6F7071727374757575747271706F6E6D6C6C6C6B6B6B6B6B
6B6B6C6C6D6F7070706C67656361616268798B9CACBAC7D5
DEE1E2E3E4E7EAEAEAE7E3E0DCD8D4D1CECECECECECDCDCC
CCCCCCCCCDCCCCCCCDD2D7DADDDFDFDED7C5B19F8D7D6E5E
5149433C362E282320212326292B2F33373C42474C52575C
6061626363646464625F5B57524E4A46413D3936322E2A27
252424232322222222222222232324242422201E1D1C1C1C
1C1E212427292C30353D464E565D63696C6965625E5C5A58
56585A5B5C5C5C5C5C5B5958575655545454555555555555
5452504E4D4B4A484748484949494849
6C6C6C6C6C6C6C6D6D6E6F7070717272737271706F6F6E6E
6E7072737475767777757372706F6E6D6C6C6B6B6B6B6B6B
6B6B6C6D6D6F7071706C686563616163697B8D9EAFBECBD9
E2E4E4E4E4E7E9E9E8E5E2DFDBD7D4D0CECECFCFD0CFCFCF
D0D0D1D2D3D3D4D4D6DBDFE2E5E7E7E5DECBB8A592827363
554D463F39302924212325272A2D3135393D42464B505559
5D5E5F6061626362615E5A56524E4A46423E3A36332F2B28
25242423232222222222222323242525252321201E1D1D1C
1D1D1E20212325272C364049525A62686C6965615E5C5A57
56585A5B5D5D5D5D5C5B5958575655545354545555555555
5452504E4C4B49484747484848484848
6B6B6B6B6B6B6B6B6C6D6E6F70717172727170706F6E6E6E
6E7071737475767777757472706F6E6C6C6B6B6B6B6B6B6B
6B6C6C6D6E6F7071716D6866646263646B7D90A1B3C2CFDD
E6E7E6E6E5E7E8E8E6E4E1DEDBD7D3D0CECECFD0D1D1D1D1
D2D4D5D7D8D9DADBDDE1E6E8EAECEBE9E2D0BCAA97877767
595149423B322B26222426282B2E3135393D41454A4E5357
5A5C5D5E5F616161605D5956524E4A46423E3B37332F2C28
26252423232221212122222324252526262422201F1E1E1D
1D1C1C1D1D1E1F2126303B454F585F676B6864615D5B5A58
57585A5C5D5D5D5D5C5B5958575655545353545455555555
5452504E4C4A49484747484848484848
69696A6A6A6A6A6A6B6C6C6D6E6F6F7070706F6F6E6E6E6E
6E6F717273747575757472716F6E6D6C6B6B6C6C6C6C6C6C
6C6C6D6D6D6F7071706D6968666566686F8194A5B7C6D3E1
EAEAE8E7E6E7E8E7E5E3E0DEDBD7D4D1CFCFD0D1D1D1D1D2
D3D5D7D9DBDBDDDEE0E3E7E9EAECEBE8E1D0BDAB99897A6A
5C534C443D342C26232426282A2D2F33373B3F43484D5155
595B5C5E5F606161605D5956524E4B46433F3B3734302C29
26252524232222212122222323242425252322201F1E1E1D
1D1C1B1B1C1B1C1E232D38424C555D64696663605D5C5B59
58595B5C5C5C5C5C5B5A5958575655545354545454545454
5352504E4C4B4A494848494949494949
68686969696969696A6A6B6C6C6D6D6E6E6E6E6E6E6E6E6E
6E6F7071727273737372716F6E6D6D6C6B6B6C6C6C6D6D6D
6D6D6D6D6D6E6F70706D6A6A69686A6C748598A9BBC9D7E4
EDECEAE9E7E7E8E6E4E2E0DEDBD8D4D1D0D0D1D1D2D2D2D2
D3D6D8DADCDDDEE0E1E5E8E9EAEBEAE7E0CFBDAC9A8B7C6D
60564E463F352D2723242527292B2D3034383D41464B5054
585A5C5D5E606161605D5956524E4B47433F3B3834302D2A
27262524232222212121222222232424242321201F1E1E1E
1D1C1B1A1A1A1B1C212B363F49525A616664615F5D5C5C5A
5A5A5B5C5C5B5B5A5A595857565655545454545454545454
5351504E4D4C4B4A49494A4A4A4A4A4A
676768686868686869696A6A6B6B6C6C6D6D6D6D6D6E6E6E
6E6F70707171717171706F6E6D6D6C6B6B6B6C6C6D6D6E6E
6E6E6D6D6D6E6E6F6F6D6C6B6B6B6D70788A9CADBECDDAE7
F0EFECEAE7E8E8E6E4E2E0DEDBD8D5D2D0D0D1D1D2D1D1D2
D3D5D8DADDDEE0E1E3E6E8E9EAEAE9E6DFCFBEAD9C8E8071
635A514940372F282424252628292B2E32363B3F44494E53
57595A5C5D5F6060605D5955524E4A46423F3B3835312D2A
28262524242322212121212222232323232221201F1F1E1E
1D1C1A1A1918191A1E28333D464F565E6362605E5D5D5D5B
5B5B5C5C5C5B5A5959585757565655545454545454545353
5251504F4D4C4C4B4A4A4B4B4B4B4B4B
666667676767676768686869696A6A6A6B6B6C6C6D6D6E6E
6F6F6F6F6F7070706F6F6E6D6D6C6B6B6B6B6C6D6D6E6E6F
6F6E6E6D6D6D6E6E6F6D6D6D6E6E71747C8EA0B1C2D0DEEA
F3F1EEEBE8E8E7E5E3E1DFDEDBD8D5D3D1D0D1D1D1D0D0D1
D2D5D8DADDDFE0E2E4E6E8E9E9E9E8E5DECFBEAF9F918375
675D544B42393029242424252728292C2F34393D42474C51
5557595B5C5E5F605F5C5855514E4A46423F3C3835312E2B
28272625242322212121212122222223232221201F1F1F1F
1E1C1A19181717181C26303A434B535A5F5F5E5D5C5D5D5D
5C5C5C5C5B5A595857575757565655555454545453535353
5251504F4E4D4C4C4B4B4C4C4C4C4C4C
65656666666666666767676768686869696A6B6C6C6D6E6E
6F6F6F6F6E6F6F6E6E6E6D6C6C6B6B6B6B6B6C6D6E6E6F70
706F6E6D6D6D6E6E6E6E6E6F707173788091A4B4C5D4E1EE
F5F3EFECE8E8E6E4E1E0DEDCDAD7D4D2D0CFCFD0D0CFCFD0
D1D4D8DBDEE0E2E4E6E8EAEAEAEAE8E5DED0C1B2A2958879
6C62584E453B322A252425252627282B2E32373C41464B50
5456585A5B5D5E5F5E5B5854514D4A46423F3C3835322E2B
292726252423222121212121222222232322212120202020
1F1C1A181615151518222D36404850575D5D5C5C5C5D5E5E
5D5D5D5C5B5A595757565756565655555554545353535352
5251504F4E4E4D4C4C4C4C4C4C4C4C4C
6464656565656565666666666767676868696A6B6C6D6D6E
6E6E6E6E6E6E6E6D6D6D6C6C6B6B6B6A6A6B6C6D6E6F7070
706F6E6D6C6D6D6E6E6E6F707273767B8395A7B8C8D7E4F0
F8F5F0EDE9E7E6E3E0DEDDDBD9D6D3D1CFCECECECECDCDCE
CFD3D7DADEE0E3E5E7E9EAEBEAEAE9E6DFD2C3B5A6998C7F
72675C52483D332B262525252626272A2D31353A3F44494E
52545658595C5D5E5D5A5753504D4945423F3C3835322F2C
292826252423222120212121222222232323222221222221
201D1A1715131212161F2A333D454C54595A5A5B5B5D5E5E
5E5E5D5C5B5A585756565656565655555554545353535252
5150504F4F4E4D4D4D4D4D4D4D4D4D4D
636464646464646565656565656666666768696A6B6C6D6E
6E6E6E6D6D6D6C6C6C6B6B6B6B6A6A6A6A6B6C6D6E6F7071
71706E6D6C6C6D6D6E6E707275767A7F8798ABBBCBD9E6F2
FAF6F2EEE9E8E6E2DFDEDCDBD9D6D3D0CECDCDCCCBCBCACB
CCD0D4D8DCDFE2E4E6E8EAEAEAEAE8E5DFD3C5B8AA9E9184
776B60554A3F352C26252525252526282B2F34383D42474C
50525456585A5B5C5C5955524F4C4845413E3B3835322F2C
292826252423222120212121222222232323222222222222
211D1A1715121111141D273039414850555758595A5C5E5F
605F5D5C5B59585655555656565655555554545353525251
5150504F4F4E4E4E4D4D4D4E4E4E4D4D
636363636364646464646465656565656667696A6B6C6D6E
6E6E6D6D6C6C6C6B6B6B6B6B6A6A6A6A6A6B6C6D6E6F7071
71706E6D6C6C6C6D6D6F717477797D838B9CAEBDCDDBE7F3
FAF7F2EFEAE8E6E3E0DFDDDCDAD7D4D1CFCDCBCAC8C7C6C6
C7CBD0D4D8DCDEE2E4E6E8E8E9E9E8E5E0D4C8BBAEA3978A
7E7164584C40362C25242424252525272A2E32373C41464A
4E50525455575859595653504D4A4743403D3A3734312E2B
292726252423222120212121222222232323232222232323
221E1A1714121110131B252D363D434B50535557585B5E5F
605F5E5C5B59585655555656565656555554545352525151
5050504F4F4E4E4E4E4E4E4E4E4E4E4E
626363636464646465656565656565666667696A6B6C6C6D
6E6D6D6D6D6C6C6C6C6C6B6B6B6A6A6A6A6B6C6D6E6F7071
716F6D6C6B6B6B6C6D6F72767A7D828890A0B0BFCDDBE7F2
F9F7F3F0EDECEAE7E5E4E2E1DFDCD9D6D3CFCBC8C5C2BFBD
BEC2C7CCD1D4D7DBDEE2E4E6E8E9E9E8E4D9CDC1B5AA9F93
8677695C4E41352A2322232324242527292D31353A3F4348
4C4D4E4F5052535352504E4B494643403D3A3735322F2C29
272625242323222121212122222222232323222222222222
211D1A1815131212141B232A31373D43494C4F5255595C5F
605F5D5C5B59585756565656565655555454535352525151
50504F4F4E4E4E4E4D4D4D4D4D4D4D4D
626363636464646565656565656666666768696A6A6B6C6D
6D6D6D6D6D6D6D6D6D6C6C6C6B6B6B6B6B6B6C6D6E6F6F70
706E6C6B6A6A6A6B6D7074787D81868C95A4B3C0CEDAE5F0
F7F6F3F2EFEFEEECEAE9E8E6E4E1DEDBD7D1CBC5C0BBB8B4
B4B8BEC3C8CCCFD3D7DCE0E3E6E9EAEAE7DDD2C7BBB2A79B
8D7E6E5F504134282020212224242427292D3034383D4146
494A4A4A4B4C4C4C4C4A48464442403D3B3835322F2C2927
252424232322222222222222222223232323222221212121
201D1A1817151414161B21272C31363B40454A4E52565A5E
605F5D5C5B5A595857575757575655555453535252515150
504F4F4E4E4E4D4D4D4D4D4D4D4D4D4D
62636363646464656565656666666667676869696A6B6B6C
6D6D6D6D6D6D6D6D6D6D6C6C6C6B6B6B6B6B6C6D6D6E6F6F
6F6D6C6A69696A6A6C70757A80848A9099A7B5C1CEDAE5EE
F5F5F4F2F1F1F0EEEDECEBE9E7E4E1DDD8D0C9C2BBB4AFAB
A9AEB4BABFC3C6CBD0D6DBE0E4E8EAECE9E1D7CCC1B8AEA2
95847262524234271E1E202224242427292C2F33363B3F43
464646464646474646454342403E3D3A3835322F2D2A2725
232323232322222222222222222323232322222121212120
1F1D1B1918171616171B1F24282C3034393F444A4F54595D
5F5E5D5C5B5A5A5857575757575655545453535252515050
4F4F4F4E4E4D4D4D4C4D4D4D4D4D4D4D
62626363646465656566666666666767676869696A6A6B6C
6C6C6D6D6D6E6E6E6E6E6D6C6C6C6B6B6B6B6C6C6D6E6E6F
6F6D6B6A6969696A6C71767C82878D949DA9B6C2CED9E3ED
F3F4F3F3F2F3F2F1F0EFEDEBE9E6E3DFD9D0C6BDB5ADA7A1
9FA4AAB0B6B9BDC3C8CFD6DCE1E6EAECEBE4DAD1C7BFB5AA
9C8A7765544333251C1C1F2123232426292C2F3135393D41
4343424241414140403F3E3D3C3B39383533302D2A272523
21212222222222222323232323232323232222212020201F
1E1D1B1A19181818191B1E2124262A2D32383F454C51575C
5F5E5D5C5B5B5A5958585858575655545353525251515050
4F4F4E4E4D4D4D4C4C4C4C4C4C4C4C4C
62626363646465656666666666666767676868696A6A6B6B
6C6C6C6D6D6E6E6E6E6E6D6D6C6C6B6B6B6B6C6C6D6D6E6E
6E6C6A69686868696C71777D848A9097A0ACB8C3CED8E2EB
F1F3F3F4F4F5F5F4F3F2F1EFECE9E6E2DBD0C5BBB1A7A099
969BA1A7AEB1B6BBC1C9D1D8DEE4E9EDEDE6DED5CCC4BCB1
A3907B69564433241A1B1E2023232326292B2E3033383C3F
41403F3E3D3D3C3B3B3A3A393938363533302D2B28252321
202021212222222323232323232323232322222120201F1F
1E1D1C1B1A1A1A1A1A1B1C1E202124262B323A41494F555B
5F5E5D5C5B5B5A595958585857565554535252515150504F
4F4E4E4D4D4D4C4C4C4C4C4C4C4C4C4C
6162626364646565666666666666676767686869696A6A6B
6B6C6C6D6D6E6E6E6E6E6D6D6C6C6C6B6B6B6C6C6D6D6E6E
6E6C6A69686868696C71787F868C929AA2ADB9C3CDD7E1E9
F0F2F3F4F4F5F6F5F4F3F2EFEDEAE6E1DACEC1B6AAA09890
8C91989EA5A8ADB3BAC2CBD3DAE1E7ECEDE7E0D8D0C9C1B7
A9957F6C58453323191A1D2022222326282A2D2F32363A3D
3F3E3C3A393838363636363635343332312E2B2926242220
1E1F202122222223232323232323232323222121201F1F1E
1E1D1D1C1C1C1C1C1C1B1B1C1C1D1E20242D363E464D545A
5E5E5C5C5A5B5B5A5959585857565553525252515150504F
4F4E4E4D4D4C4C4C4C4C4C4C4C4C4C4C
6162626363646565666666666667676767686869696A6A6A
6B6B6C6D6D6E6E6E6E6E6D6D6C6C6C6B6B6B6C6C6C6D6D6D
6D6B6A68686868696C727980878D949BA4AEB9C3CDD7DFE8
EEF0F2F3F4F5F6F5F4F3F1EEEBE8E4DED7C9BBAFA3978E86
81868D949A9EA3A9B1BAC4CDD5DEE5EAECE8E2DBD3CEC7BD
AF9A836E5945332318191D1F22222325282A2C2E3034383B
3C3B38373534333231313132323131302F2C29262422201E
1D1E1F2021222223242423232323232323222120201F1E1E
1D1D1D1D1D1D1E1E1E1C1A1A1919191A1E28313A434B5259
5E5D5C5B5A5B5B5A59595958575654535252515151504F4F
4E4E4D4D4C4C4C4B4B4B4B4B4B4B4B4B
616162626364646565656666666767676868686969696A6A
6A6B6C6C6D6E6E6E6E6E6D6D6C6C6B6B6B6B6B6B6C6C6C6D
6D6B6A696868696A6D737A81888E949CA4AFB9C3CDD7E0E8
EDEFF0F0F0F1F1F0EEECE9E6E2DED9D4CBBEAFA3968B8279
757A81878E92979EA6B1BBC5CFD8DFE6E9E6E1DBD5D1CBC2
B49E86715B46342217181C1F2222222527292A2C2E323538
3937353331302F2D2C2D2E2E2E2E2E2D2C2A272522201F1D
1C1E1F20212222232424232323232323232221201F1F1E1D
1D1D1D1D1E1E1F1F1F1C1A18171616161A242E3841495158
5D5D5C5B5A5A5B5A5A595958575654535252515150504F4F
4E4E4D4C4C4C4B4B4B4B4B4B4B4B4B4B
6061616262626363646465666667676868686969696A6A6A
6B6B6C6C6D6D6D6E6E6D6C6C6B6B6B6A6A6A6A6A6B6B6B6C
6C6B6A6A6A6B6C6E70757B81878C9299A2AEBAC5D0DBE4EC
F1EFEDEAE7E5E2DEDAD6D2CDC8C3BCB6AEA1958A80766E68
656A70777E83889098A3AFB9C3CDD5DCE1DFDCD8D4D1CCC4
B8A189735D48352317191D1F222222242627282A2B2F3234
3533312F2E2D2C2A2A2A2B2B2C2C2C2B2A28262422201F1E
1D1E1F20212222232323232323232323232221201F1E1E1D
1D1D1D1D1D1E1E1E1E1B19171615151619232E3741495058
5D5C5B5A595A5A5959595858575654535252515151504F4F
4E4D4D4C4C4B4B4A4A4A4A4A4A4A4A4A
60606061616162626363646566676768696969696A6A6A6A
6B6B6C6C6C6D6D6D6D6C6C6B6B6A6A6A6969696A6A6A6B6B
6B6B6B6C6C6E6F7174787C81868A90969EACBAC7D3DEE7F0
F4EFE9E3DCD8D3CCC5C0BAB3ADA59E968E847A7169615B56
545960676E7379818A95A1ACB7C1CAD2D7D8D7D4D1D0CDC6
BAA38B755E493624181A1D202322222425262627282B2E30
312F2E2C2B2A2928272829292A2A2929292725242221201F
1E1F2020212222222323232323232323232221201F1E1E1D
1C1C1D1C1D1D1D1D1D1A18171615151619232E3741495058
5C5C5B5A5959595958585857575654535252525151504F4F
4E4D4D4C4B4B4A4A494A4A4A4A4A4A4A
606060606060606161626364666667686969696A6A6A6A6B
6B6B6B6C6C6C6C6C6C6C6B6A6A6A69696969696969696A6A
6B6B6C6D6E707274777A7D8185888C929AA9B9C7D4E0EAF3
F6EFE5DDD3CCC5BCB3ACA59D958C847B736B635B554F4A47
464B51585F656B737D8995A1ACB6C0C8CFD1D1D0CFCFCDC7
BCA58D76604B3825191B1E20232221232424252526292B2D
2E2C2A29282727262526272728282828272624232221201F
1F1F2021212122222223232323232323222221201F1E1D1D
1C1C1C1C1C1C1D1D1C1A18161514151519232D3740485057
5C5B5A595858595857575757575654535352525151504F4F
4E4D4C4C4B4A4A494949494949494949
5F5F5F5F5F5F5F5F606163646566676869696A6A6A6A6A6B
6B6B6B6B6B6C6C6C6B6B6A6A696969686868686868686969
6A6C6D6F707375787A7B7D808385888D95A6B7C6D5E2ECF5
F8EEE2D6CAC1B8ACA29990877E746A6158524C46423D3A38
393D434A51575E66707C8995A1ACB6BFC6C9CCCCCCCDCCC8
BEA78E78614C39271A1C1F21242221232423232324262829
2A2928272625252424242525262626262625242322212020
1F202021212122222222222222232323222121201F1E1D1D
1C1C1C1C1C1C1C1C1C1917161514141519232D3640484F56
5B5A59585757585757575757565554535352525151504F4F
4E4D4C4B4B4A49494848484949494848
5F5F5E5E5E5E5E5E5F616264656668696A6A6A6A6A6A6A6B
6B6B6B6B6B6B6B6B6B6A6A69696868686767676767676869
6A6C6E707275777A7D7D7E808183868992A4B6C6D5E3EDF6
F9EDDED0C2B7AC9F93897E746A5E5349413C3733302C2A2A
2B30363C434A515A63717E8B97A2ADB6BEC3C7C9CACDCDC9
C0A99079624E3B281B1D2022242322232323222222242527
272625242322222121222223232424242423222221212020
202020212121212222222222222323232221201F1E1E1D1C
1C1C1C1C1C1C1C1C1C1917161514141518222C353F474E55
5A5958575657575656565656565554535352525151504F4F
4E4D4C4B4A4949484848484848484848
5E5E5E5D5D5D5D5D5E606263656668696A6A6A6A6A6A6A6A
6B6B6B6B6B6B6B6B6A6A6969686867676767666667676768
696C6E7174777A7D7F7E7D7E7F7F81858C9FB3C4D4E2EDF7
F9EBDACBBBAFA394877B7065594D41362E292623211F1E1E
21252B31383E464E596674818E99A4AEB7BDC2C5C8CBCCCA
C1AA917B644F3C291D1E2123252422232322212120222324
252322212120201F1F202021222222222222222121212020
202021212121212122222222222223222221201F1E1D1D1C
1B1B1B1B1C1C1C1C1C1917161413131418212B343E454D54
595857565556565656565656565554535352525151504F4F
4E4D4C4B4A4948474747474747474747
5E5D5D5D5C5C5C5C5D5F6163646667696A6A6A6A6A6A6A6A
6A6B6B6B6B6A6A6A6A696968686767676666666666666667
696C6F7275797C7F817F7C7C7B7B7C7E859AAFC1D2E1ECF6
F8E9D7C6B5A89A8B7C6F63564A3C30251C19171615141415
181C21272E353C454F5D6A7885909CA6AFB7BDC1C4C9CAC9
C1AA927B65503E2B1F20232526242323232221201F202222
232221201F1F1F1F1F1F1F20202121212121212121212121
212121212121212121222222222222222221201F1E1D1C1C
1B1B1B1B1B1C1C1C1C1917161413131418212B343D444C53
575756555455565555555556555554535252525151504F4F
4E4D4B4A494848474646474747474747
5D5C5C5C5B5B5B5B5C5E6062646667696A6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6A69696868676767676666666666666667
686C7073767A7E81827E7A77757373747B90A7BACCDCE8F3
F5E6D4C3B1A59888796C5F5246372A1F1614131212111213
161A1E242A303740495764717E8A959FA8B0B7BBBFC4C6C5
BEA8917B6552402E2223252628252323232220201F202122
222120201F1F1F1F1F202020202121212121212121212121
212121212121212121212222222222222221201F1E1D1C1B
1B1B1B1B1B1C1C1C1C1917161413141418212A333C434A51
565655545454555555555555555453525251515150504F4E
4D4C4B4A494847464646464647474646
5B5B5A5A5A5A5A5B5C5E6062636567686969696969696969
696A6A6A6A6A6A6A69696968686867676767666666666667
686C7074777B7E81817A736E69656362697F97ABBFCFDCE9
EDE1D2C4B6ACA294877B6F63574A3D322A27252322212021
2225282C31363C434C5865717C87919AA3AAAFB3B7BBBDBC
B5A28C796553433227272828292624232322212121222324
252424232323232424232323232323232322222221212121
212121212121212121222222222222222221201F1D1D1C1B
1A1B1B1B1B1C1C1C1C1917161513131417202A323B424950
555554545354555555555454545351515050504F4F4F4E4E
4D4C4B4A494847464646464647474646
5959595959595A5A5B5D5F61636466676868686868686969
696969696969696969696969686868686868676767676767
696D7174787C7E817F766B645C565250556C859BB0C1D0DE
E5DCD0C6BBB5ADA3998E82776C605449413D3A3836333130
313234373B3F4349505B66717C858E969EA4A8ACAEB2B3B2
AC9B8776645446372C2B2B2A2A2724232222222223242627
282827272728282828282727262626252424232322222121
2020212121212121222222222222222222211F1E1D1C1B1B
1A1A1B1B1B1C1C1C1C1A171615141414172029323A41484E
5354535353545555555454535251504F4E4E4E4E4E4E4D4D
4C4B4A49494847474646464747474647
575758585859595A5B5D5E60626465666767676767686868
686869696969696969696969696969696968686868676767
696D7175787C7F807E72655B5149433F445C768CA3B5C4D4
DDD7CFC7BFBCB8B0A89E93897E72685D55514D4A4743403E
3E3E3F4144464A4E545E68717B838B93999EA2A5A7AAABA9
A49483746456493B312F2E2D2C2825242323242425262829
2B2B2B2B2B2C2C2C2C2C2B2A292828272625242423222121
2020212121212122222222222222222222201F1E1D1C1B1A
1A1A1B1B1B1C1C1D1C1A181615141414172029313940464D
51525252525455555554535251504E4D4C4C4D4D4D4D4C4C
4C4B4A49484847474646464747474747
55565657575858595A5C5E5F616364656667666666676767
676868686969696969696969696969696969686868686768
696D7275787C7F807C6E5E52463B342F334B667E95A8B8C9
D4D1CDC8C4C3C2BDB7AEA49B90867C726A65615D5954504D
4B4B4B4C4D4F515459616A727B82898F95999C9D9FA1A2A0
9B8E7F7264574C40373432302E2A26252424252627292B2C
2E2E2E2F2F30303131302E2D2C2B2A292827252423222120
2020212121212122222222222222222222201F1E1D1C1B1A
1A1A1B1B1B1C1C1D1C1A18161514141518202830383E444B
4F5051515253545555545251504E4D4B4A4B4B4C4C4C4C4C
4B4A4A49484747474646464747474747
54545556565758595A5B5D5F606263656666666666666666
66676768686869696969696969696A6A6A69696969686868
696E7276797D7F807C6A584A3B2F2720233C58718A9DAEC1
CDCDCAC8C6C8C9C6C2BAB0A79D938A8078736F6A66615D59
56555454545556585B636A72797F858B9093959697999998
93887B7064594F443C383532302B282524252628292B2D2F
3031313232333435353332302F2D2C2A2928262524232221
2020212121212222222222222222222221201F1E1D1C1B1A
191A1A1B1B1C1C1D1C1A1817161515161820282F373D4349
4D4F4F5051525454545352504F4D4B4A494A4A4B4B4B4B4B
4B4A4948484747464646464647474646
5253545455565758595B5C5E606162646565656565656566
666667676868686969696969696A6A6A6A6A696969686868
696E7376797E80807B67534332251B13152F4B657E92A4B8
C6C8C8C8C8CDD0CFCCC4BBB3AAA0978E86817C78736E6965
615F5D5C5C5B5B5C5F656C72787D82888C8E8F9091929291
8D83786E645A5248413D3935322D29272526282A2C2D2F31
333334353537383838363433312F2E2C2A29272625232221
2020212121212222222222222222222221201F1E1C1B1B1A
191A1A1B1B1C1C1C1C1A1817161616161920282F353B4147
4B4C4D4F505153545452514F4E4C4A494848494A4A4A4A4A
4A4A4948484747464646464647464646
5151525354555657585A5C5D5F6061636464646464646565
656666676768686868696969696A6A6A6A6A6A6969686868
696E73767A7E7F8079644E3C2A1B100708223F5973879AAE
BEC2C5C8CBD2D7D9D8D1C9C1B8AFA79E96918C87827C7672
6E6B68666563626264696E74797D8185898A8A8B8B8B8B8A
867E756D645C554D46413D3935302C2927292B2C2F303234
36363738393A3B3B3B39373533312F2D2B2A282725242221
2020212121222222222222222222222121201E1D1C1B1A1A
191A1A1A1B1B1C1C1C1A1918171617171A20272D34393E44
484A4B4D4E5052535352504E4D4B4948474748494A4A4A4A
4A494948474747464646464646464646
505152535455555758595B5C5D5F60616262636363646464
6565666667676768686869696969696A6A69696969686868
696E7376797D7E7E78624A3725150900011A37506A7E90A5
B6BDC2C7CDD6DDE1E1DAD2CAC2BAB2A9A19C98938E87817C
7874716F6D6B6968696D72777B7F82868889888888888785
827B746D665F58524B46423D3934302D2B2D2E3032333537
3839393A3B3C3C3D3C3A38363432302E2C2A292726242221
20202121222222222222222221212121211F1E1D1C1B1A19
19191A1A1B1B1C1C1C1B1918181717181A20262B31363A3F
4346484A4C4F515253514F4E4C4A4947464748494949494A
49494848474747464646464646464646
50515152535455565758595A5C5D5E5F6061616262636364
646565666667676768686868676767676868686868686767
696D7274777B7C7C75614A3827180D03041C364E66788A9E
AEB6BDC4CAD4DDE1E2DBD2CAC1BAB1A9A19D9995908B8580
7C79777472706F6E6F73787C8084878A8D8D8C8C8B8B8A88
857E777069635C56504C4844413C39363434353637383839
3A3A3A3A393A3A3A3938363432302F2D2B2A282725242221
21212121222222222222222121212120201F1E1D1C1B1A1A
19191A1A1B1B1B1C1C1A1919181818191A1F23272C303337
3B3F4245484C4F5152514F4E4C4B4A48484849494A4A4949
49494848474747464646464647474646
5051515253545455565758595A5B5C5D5E5F5F6061626363
646465656666676767676666666665656566666767676767
686C707375787A7973604B3A2A1C12090A1F374D63748496
A6B0B8C0C8D3DCE1E3DBD2CAC0B8B0A7A09D9A96928D8884
807E7B797876757475797E82868A8D90929291908F8F8E8C
88827B746D67615A55524E4B4845413F3D3C3C3C3C3C3C3C
3B3B3A393838373635343331302F2D2C2B29282625242221
212121222222222222222221212020201F1E1D1D1C1B1A1A
19191A1A1A1B1B1B1B1A1A19191919191B1D202326292C2F
33373C4044494C4F51504F4E4C4C4B4A494A4A4A4A4A4A49
49494848474747474646474747474747
50515152525354545556575758595A5B5C5D5E5F60616263
636465656566666666666565656464646464656666666767
686C6F7173767777715F4C3C2D20170E0F22384C606F7E8F
9FAAB4BDC6D2DBE2E4DCD2CAC0B8B0A8A09E9B9895918C89
8583817F7D7C7B7A7C8084888C8F9295979695949392918E
8B857E77716B655F595754524F4C49474544434241403F3E
3D3C3A38373635343231302F2E2D2C2B2A29272625242322
2121222222222223232221212020201F1F1E1D1C1C1B1A1A
191A1A1A1A1A1B1B1B1A1A1919191A1A1B1C1E2022232528
2B31363C41464A4E50504E4D4C4C4C4B4A4B4B4B4B4A4A49
49494848484747474647474747474747
505151525253535454555556575758595A5B5C5E5F606162
636464646565666666656464636362626263646566666667
686B6E70717475746F5E4D3E30251C141525394B5D6B7989
97A4AFBAC4D1DBE3E6DDD3CAC0B9B1A8A19F9D9B9994908D
8A8886858382818182868A8E9295989A9C9B9A9896959491
8E88817B746E68635E5C5A585654514F4D4B494745444241
3F3D3A38363433312F2F2E2D2C2C2B2A2928272624232322
212222222223232323222121201F1F1E1E1D1D1C1B1B1A1A
191A1A1A1A1A1A1B1B1A1A1A1A1A1A1B1B1B1B1C1D1E1F21
242A31373D42474C4F4F4E4D4C4D4D4C4C4C4C4C4B4B4A49
49484848484747474747474747474747
5050515152525253535454545555565758595B5C5E5F6061
626363646465656565646363626161606061636465656666
686A6D6E707272726D5D4C3F31261E171726384859667281
909EACB8C4D2DDE6EAE2D7CEC4BDB6ADA6A5A3A29F9B9795
92908E8C8B898988898D9194979A9D9FA09F9D9B98979592
8F89837D77726C676361605E5D5B585754524F4D4A484644
413E3B393634312F2E2D2D2C2C2B2A2A2928272524232322
222222222323232323222120201F1E1E1D1D1C1C1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1A19191918191A
1D242C333A40454B4E4E4D4D4C4D4D4D4D4C4C4C4B4B4A49
48484848484747474747474747474747
505050515151525253535353535454555657595B5D5E5F61
62626363646465656564636261605F5F5F60626364656666
676A6C6D6E7070706B5C4C403329211A1A28384656616D7B
8999A8B6C4D3DFE9EEE5DBD2C8C1BAB2ACAAA9A8A6A29E9C
999795949291908F9093979A9D9FA1A3A4A2A09D9A999693
908A857F7A75706B6766656463615F5D5B5855514E4C4946
43403D393633302E2C2C2B2B2B2A2A2A2928262524232322
2222222323232323232221201F1F1E1D1D1C1C1B1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1A171615141414
171F272F363D43494D4D4D4C4C4D4E4E4D4D4D4C4C4B4A49
48484848484747474747474747474747
505050505151515252525252525252535456585A5C5D5F60
616262636363646464636261605F5E5E5E5F616364656566
67696B6C6C6E6E6E695B4D42362D2620202B3946545E6875
8494A5B4C3D3E0EBF0E8DDD4CBC4BDB5AFAEAEACABA8A4A2
9F9D9C9A99979696979A9D9FA2A4A6A8A8A6A3A09D9B9895
918C87827D78736E6B6A6A6968676564625E5A56524F4C49
45413D3A36332F2C2A2A2A2A2A2A29292927262524232322
2222222323232323232221201F1E1D1D1C1C1C1B1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1D1C19161411100F0F
111A232B333A40474B4C4C4C4C4D4E4E4E4E4D4D4C4B4A49
48484848484747474747474747474646
4F505050505051515151515151515152535557595B5C5E5F
6161616262626363636261605F5F5E5D5E5F616264646566
67696A6B6C6D6E6D695C50453B322C2626303B47535C6571
7F90A2B2C2D2E0ECF2EADFD7CDC7C0B8B3B2B2B1B0ADAAA8
A5A3A2A09E9D9C9B9C9EA1A3A6A7A9AAAAA7A5A29F9C9A96
938E89847F7A75716E6D6D6D6C6B696866625E5955524F4B
47433E3A36332F2C2A292929292929292927262524232322
2222222323232323232221201F1E1D1C1C1B1B1B1B1B1A1A
1A1A1A1A1A1919191A1A1B1B1C1C1D1D1C191512100D0C0C
0E16202830373E44494A4A4B4B4D4E4F4F4E4E4D4C4B4A49
48484848474747464646464646464646
4F4F4F4F4F5050505151505151515152535456585A5C5D5F
60606060606161616161616060605F5F6061626364656566
67696B6D6E6F70706C60544A4139332E2D353F4A545B646F
7C8EA0B1C2D2E0EDF3EBE1D9D0CAC4BDB8B7B8B7B6B3B0AE
ABA9A7A4A3A19F9E9EA0A2A4A5A7A7A8A8A6A3A09D9B9996
928E8984807B76726F6E6E6D6C6B696865625E5A56534F4C
4844403C3834312E2B2B2B2A2A2A29292827262524232322
22222222232323232221201F1E1D1D1C1B1B1B1B1B1A1A1A
1A1A1A1A1A1A191A1A1A1B1B1B1C1D1D1C191613110F0E0E
10171F272E353A4145464748494B4D4E4E4E4D4C4C4B4A49
48484747474646454545454545454545
4E4E4E4F4F4F4F505050505051515152535456585A5B5C5E
5F5F5F5F5F5F5F5F60606061616161626263636465656666
676A6C6E707272726F655A5047403B36353B444D565C636D
7A8C9FB0C1D2E0EDF3ECE3DBD3CEC8C1BDBDBDBCBBB8B5B3
B1AEABA9A6A4A2A0A0A1A2A3A5A5A6A6A6A3A19F9C9A9895
928D8984807B7773706F6E6D6C6A686664615D595653504C
4945413D3A3633302E2D2C2C2B2A29292827262524232322
22222222222222222221201F1E1D1C1C1B1B1B1B1B1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1D1C19171513111110
121920262D32373D4143444647494B4C4D4D4C4C4B4B4A49
48484747464545444444444444444444
4D4D4D4E4E4E4F4F505050505051515253545657595A5C5D
5E5E5E5D5D5D5E5E5E5F6061616263636464656565656666
676A6D6F7173747472685E554D46413D3C414850585D636C
788B9EAFC1D1E0EDF4EDE5DDD5D1CCC6C1C1C2C1C0BEBBB8
B6B3B0ADAAA7A5A3A2A2A3A4A4A4A4A4A4A2A09D9B999795
928D8984807C7874716F6E6D6B6A676663605D595653504D
4A46423F3B383532302E2E2D2C2B2A292827262524232222
21222222222222222221201F1E1D1C1B1B1B1B1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1C1A171614131313
141A20252B3034393D3F414345484A4B4D4C4C4C4B4A4A49
48484746464544434343434343434343
4C4C4D4D4D4E4E4F4F4F4F505051515252545657585A5B5C
5D5D5C5C5C5C5C5C5D5E5F61626364656666666666666666
676A6E7072747676746B625A534D484443474D535A5E646C
778A9EAFC0D1DFEDF4EEE6DFD8D4CFC9C5C6C6C6C5C2BFBD
BAB7B4B0ADAAA7A5A3A3A4A4A4A3A3A2A2A09E9C9A989794
918D8985807C787571706E6D6B696765625F5C595654514E
4B4744403D3A373431302F2E2D2B2A292827262524232222
212122222222222221201F1E1D1C1C1B1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1C1C1C1A181716151515
171B2025292D3135393C3E414346494B4C4C4B4B4B4A4A49
48484746454443424142424242424242
4B4C4C4C4D4D4E4E4E4F4F4F505051515254555658595A5B
5C5C5B5B5A5A5A5B5B5D5F60626465666767666666666666
676A6E7073757778766E665F5954504D4B4E52575C5F646B
76899CAEC0D0DFECF3EEE6E0D9D5D2CCC9C9CACAC9C7C4C2
BFBBB8B4B1AEABA8A6A5A5A5A5A4A3A2A1A09E9C9A999795
928E8A85817D797572716F6D6C69676563605D5A5754524F
4C4845413E3B383532312F2E2D2B2A292827262524232222
212121212121212121201F1E1D1C1B1B1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1C1C1C1A191817161616
181B2023282B2E3236393C3F4245484A4C4C4B4B4A4A4A49
48474645444342414041414142414141
4B4B4B4C4C4D4D4D4E4E4E4F4F5050515253555657585A5B
5B5B5A5A595959595A5C5E60626466676868676766666666
676A6E7073757778777069645E5A57545354575B5F61656C
76889CAEBFD0DEEBF3EEE6E1DAD7D4CFCBCCCDCDCDCAC8C5
C3BFBBB8B4B1ADAAA8A7A7A6A5A4A3A2A09F9E9C9A999795
938E8A86827E7A767371706E6C6A676563605D5A58555350
4D4946423F3C39363331302E2D2C2A292827252424232222
212121212121212121201F1E1D1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1C1B1A191818171717
191C1F2226292C2F32363A3D4044474A4B4B4B4B4A4A4A49
48474645444341404040404141414041
4A4A4B4B4B4C4C4D4D4E4E4E4F4F5051515354555658595A
5A59595858575757585B5D60626466686968676766666666
676A6D707375777877726C67625F5D5A595A5C5F6364686D
77899DAEBFCFDDEAF2EDE7E1DBD9D6D1CECFD0D0D0CDCBC9
C6C2BEBAB6B3B0ACAAA8A7A6A5A3A2A19F9E9D9B9A999795
938F8A86827E7A767371706E6C69676562605D5B58565350
4E4A4743403D3A373433312F2E2C2A292827252424232221
2121212121212121211F1E1D1C1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1919191919
1A1D1F222427292C2F33383B3F4346494B4B4B4A4A4A4A49
484746454342413F3F3F404040404040
494A4A4A4B4B4B4C4C4D4D4E4E4F4F505152535456575859
5958585756565656575A5D5F626466686968676766666565
66696D6F7274767776716C6864615F5D5C5E606367696D72
7B8D9FB0C0CFDDE9F0ECE6E1DCDAD7D3D0D1D2D2D1CFCDCB
C8C4C0BCB8B5B1AEABA9A8A6A5A3A19F9E9D9C9B99989795
928E8A86827E7A777371706E6C69676462605D5B58565451
4E4B4744413E3B38353332302E2D2B2A2827262524232221
2121212121212121201F1E1D1C1B1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1A1A
1B1D1F212325272A2D31363A3E4246494B4B4B4A4A4A4949
484745444342403F3E3F3F3F403F3F3F
494949494A4A4A4B4B4B4C4C4D4D4E4E4F51525355565758
585857565555555556585B5E606264666766666565646464
65676A6C6E707172716C67635F5C5A59595D62676C70767D
8696A6B5C3D1DDE8EEEBE5E1DCDAD7D3D0D1D1D1D1CFCCCA
C8C4C0BCB8B5B2AEABA9A8A6A4A2A09F9D9C9B9998979593
918D8985817E7A777472706E6C6A676563605E5C59575452
4F4C4845413E3B3836343231302E2C2B2A28272524232221
212121212121212121201E1D1C1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1919191A
1B1C1E20232427292C31363B3F43474B4D4C4B4A49494847
464545444342403F3F3F3F4040404040
48484848494949494A4A4A4B4B4C4C4D4E4F515254555657
585756555454545454575A5C5E6062646564646463636363
646567686A6B6C6C6B66615D59565453545B636A72787F88
929FADBAC6D2DDE7ECE9E4E0DCD9D7D3D0D1D1D1D0CECBC9
C7C3BFBCB8B5B2AEACAAA8A6A4A29F9E9C9B999896959492
8F8C8884807D7A767472706E6C6A686563615F5C5A585553
504C4945423E3B3836343332312F2E2D2B2A282625232221
212121212121212121201F1E1D1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1919191919
1A1C1E20222426292C31373B4045494C4E4D4C4A49484746
45444443434241403F3F404040404040
4848484848484848484949494A4A4B4B4C4E4F5152545556
57565554545353535356585A5D5E60626363626262626262
626364656667676766615B5754514F4F515A646E78808892
9CA8B4BEC9D4DDE5EAE7E3E0DCD9D6D3D0D0D0D0CFCDCBC8
C6C3BFBCB8B5B2AFACAAA8A5A3A19F9D9B99989795949290
8E8B8783807D79767472706E6C6A686664615F5D5A585654
514D4946423F3B383635343332302F2E2D2B292725242321
212121212222222221201F1E1D1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1918181819
191B1D1F222326282C31373C41464A4D4F4E4C4A48474645
44434343434241404040404040404040
4747474747474747474748484849494A4B4D4E5051535455
5655545353525252525457595B5D5E606161616161616161
6161626262626262605B56524E4B4A4A4D5865717D87919C
A7B1BAC3CBD5DDE4E8E5E2DFDBD9D6D3D0D0D0CFCECCCAC7
C5C2BFBBB8B5B2AFACAAA7A5A3A09E9C9A9897969492918F
8D8986827F7C79767372706E6C6A68666462605D5B595754
514E4A46423F3C39363534333332302F2E2C2A2826242321
212121212222222222201F1E1D1C1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A191918181818
191B1D1F212325282C31373C42464B4F514F4C4A48474544
42424342424241404040404040404040
464646464646464646464747474848494A4B4D4F50525355
5554535252515151515356585A5B5D5E5F60606060606060
60605F5F5E5E5E5E5C56514E4A4746474B586774828E99A5
B0B8C0C7CDD6DDE2E5E3E0DEDBD8D6D3D0D0CFCFCDCBC9C7
C4C1BEBBB8B5B2AFACA9A7A4A29F9D9B989796949391908E
8C8885827E7B787573716F6E6C6A686664625F5D5B595755
524E4A46433F3C3937363534343331312F2D2A2826242321
202121212222222222211F1E1D1C1B1B1A1A1A1A1B1A1A1B
1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1919181819
191B1D1F212325282B31373D42474B4F514F4C4A48464543
41414242424141414040404040404040
45454545454545454545454646474748494A4C4E50515254
545352515150505050525456585A5B5D5E5E5F5F5F5F605F
5F5E5D5C5B5B5A5957524D4946444343495768778693A0AD
B8BFC4CACFD6DCE0E3E1DFDDDBD8D6D2D0D0CFCECDCBC8C6
C4C1BEBBB7B4B2AFACA9A6A4A19E9C999796959392908E8D
8A8784817D7B787572716F6D6B69676563615F5D5B595755
524F4B4743403D393736363534333231302D2B2926242321
202121212222222222211F1E1D1C1B1B1A1A1A1A1B1B1B1B
1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1A1A1919191919
1A1B1D1F212224272B31373D42484C5052504D4A47454442
40414142424141414040404040404040
4544444444444444444444454546464748494B4D4F505253
53525151504F4F4F4F51535557585A5B5C5D5D5E5E5F5F5F
5E5D5B5957565554524D4845423F3F40465669798A99A7B5
C0C5C9CDD1D7DCDFE1E0DEDCDAD8D5D2D0CFCFCECCCAC8C5
C3C0BDBAB7B4B1AEACA9A6A3A19E9B9997959492918F8D8C
898683807D7A777472706E6D6B6967656361605E5C5A5856
534F4B4744403D3A3737363635343332312E2B2927252321
202121212222222222211F1E1D1C1C1B1A1A1B1B1B1B1B1B
1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1A1919191919
1A1B1D1F212224272B31373D43484D5153504D4A47454341
3F404141424141414140404040404040
4443434343434343434344444445454647494A4C4E4F5152
525251504F4F4F4E4F5153545657585A5B5C5D5D5E5F5F5F
5E5B59565352504F4C4743403E3C3C3D4456697B8D9CABBA
C5C9CCCFD2D7DBDEDFDFDDDCDAD8D5D3D1D0CFCECCCAC8C6
C3C0BDBAB7B5B2AFACA9A6A3A19E9B9896959392908F8D8B
8986837F7C79777472706E6D6B6967656362605E5C5A5856
534F4B4844403D3A3737363635343332312E2B2927252321
202121212222222222201F1E1D1C1C1B1A1B1B1B1B1B1B1B
1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1A1A1919191A
1A1C1D1F212224272A31373D43484D5153504C4A46444340
3F3F4041414140404040404040404040
4242424242424242434343444444454646484A4B4D4E4F51
5151504F4F4F4F4F4F515254565758595A5C5D5E5F606060
5F5B5753504D4B4846423F3E3D3B3C3F46576A7B8C9CAAB9
C4C9CCCFD2D7DBDEE0DFDEDDDCD9D7D5D3D2D1D0CFCDCBC8
C6C3C0BCB9B6B3B0ADAAA7A4A29F9C9A97969493918F8E8C
8A8683807D7A777472706E6D6B6A68666462615F5D5B5957
54504C4844403D3937363535343331302F2D2A2826252322
212121212121212121201F1E1D1C1C1B1A1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1A1A19191A1A
1B1C1D1F202224262930363C42474B50524F4C4946454341
3F404041414040404040403F3F3F3F3F
414141414142424242434343444445454648494A4C4D4E4F
50504F4F4F4F4F4F4F515254555657585A5C5D5F60616262
615B56514C4945423F3D3C3C3C3B3D4047586A7B8B9AA9B7
C2C7CACED1D7DBDEE0E0DFDEDDDBD9D7D5D4D4D3D2D0CDCB
C9C5C2BFBBB8B5B1AEABA8A6A3A09D9B9897959492908F8D
8A8783807D7A777472706F6D6C6A68676563615F5D5B5957
54504C4844403D39373534333231302F2D2B292826252422
2221212121212120201F1E1D1D1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1A1A
1B1C1D1F20212325292F353B40464A4E504E4B4946454341
4040404141403F3F3F3F3F3F3F3F3F3F
404040404141414242424343434444454647484A4B4C4D4E
4F4F4F4F4E4F4F4F5051525455565758595B5E5F61626363
625B544E4844403C3A3938393A3B3D4148586A7A8A99A6B5
C0C5C9CDD1D6DBDEE0E0E0DFDEDCDAD8D7D6D6D5D4D2D0CE
CBC8C4C0BDB9B6B2AFACAAA7A4A19F9C9A98969593918F8E
8B8884807D7A777472706F6E6C6B6967666462605E5C5A58
55504C4844403C393635343231302E2D2C2A292726252423
22222121212020201F1E1E1D1C1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1A1A
1B1C1D1F20212325282E353A4045494D4F4D4B4846454342
4040414140403F3E3E3E3E3E3E3E3E3E
3F3F3F40404041414242424343444445464748494A4B4C4D
4E4E4E4E4E4F4F4F5051525455555657595B5E6062636465
635B534C45403B3734343537393A3C41495869788896A4B2
BDC2C7CBCFD5DBDEE1E1E0E0DFDDDCDAD8D8D8D7D6D4D2D0
CDCAC6C2BEBAB7B3B0ADABA8A5A2A09D9B9997969492908E
8C8884817D7A777471706F6E6D6B6A68666563615E5D5A58
55514C4844403C3936343331302E2C2B2A29282625252423
2322212120201F1F1F1E1D1D1C1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1A1B
1B1C1D1F20212325282E34393F44484C4E4C4A4846454442
41414140403F3E3E3D3D3E3E3E3E3E3E
3D3E3E3F3F404041414242424343444445464748494A4B4C
4D4D4D4E4E4F4F505051525354555556585B5E6062646566
635B5249423C36312E2F313336383B40495868778795A3B1
BCC1C6CACFD5DADDE0E0E0E0DFDEDCDAD9D9D9D8D7D5D3D1
CFCBC7C3BFBBB7B3B0ADABA8A6A3A09D9B9998969492908E
8C8884817D7A777371706F6E6D6B6A68676563615F5D5B58
55514C4844403C38353332302F2D2B2A2928272625252424
23222121201F1F1E1E1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1A1A1B
1B1C1D1F20212325282E34393E43474B4D4B494846454442
41414140403F3E3D3D3D3D3D3D3D3D3D
3C3D3E3E3F3F404041414242434344444546474848494A4B
4C4C4D4D4E4E4F505051525354545455575A5E6062656666
645A50473E38322C292A2D3034363A40485767768593A1AE
B9BFC4C9CDD3D9DDDFE0E0E0DFDEDDDBDADADAD9D8D6D4D2
D0CCC8C4BFBBB8B4B0AEABA9A6A3A19E9C9A98969493918F
8C8884807D79767371706F6E6D6B6A68676563615F5D5B58
55514C48433F3B383433312F2E2C2A292727262525252424
23222120201F1E1E1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1B1B
1C1D1E1F21222426292E34393E42464A4C4B494746454442
41414140403E3E3D3C3C3D3D3D3D3D3D
3B3C3D3D3E3F3F404141414242434344454546474848494A
4B4B4C4D4D4E4F505051525253535454565A5D6063656767
645A4F453C342E2824272A2E3235393F47566573818F9DAA
B5BBC1C6CBD2D7DCDFDFDFDFDFDEDDDBDADBDBDAD9D8D6D4
D1CDC9C4C0BCB8B4B1AEACA9A7A4A19F9D9B99979593918F
8C8884817D797673706F6F6E6D6C6A69676563615F5D5B59
55514C48433F3B373432302E2C2A28272625252525242424
242221201F1F1E1D1D1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1B1B
1C1D1E2021222426292E34383D4145494B4A484745454443
424140403F3E3D3C3C3C3C3C3C3C3C3C
3A3B3C3D3E3E3F4040414142424343444445464647484849
4A4B4B4C4D4E4F4F505151525353535455595D6062656667
64594E443A322C252224282C3033373D4552606E7C8996A2
ADB5BBC2C8CFD6DBDEDFDFDFDFDEDDDCDBDBDBDBDAD9D7D5
D2CECAC5C1BDB9B5B1AFADABA8A6A3A19E9C9A9896949290
8D8985817D7A767370706F6E6D6C6B6968666462605E5C59
56514C48433F3B3734312F2D2C2927262524242424242424
242221201F1E1D1D1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1A1A1A1B1B
1C1D1E20222325272A2F34383D4145484A49484645454443
424140403F3E3D3C3B3B3C3C3C3C3C3C
3A3B3C3C3D3E3F3F40414141424243434444454646474748
49494A4B4C4D4E4F4F5051515252535455585C5E60626464
61574C433A332D272325282B2E303439404C5864717D8995
A0A9B2BAC2CBD3D9DEDFDFDFDEDEDDDCDBDCDCDCDBD9D8D6
D3CFCBC6C2BEBAB6B3B1AFADABA9A6A4A2A09D9B99979492
8F8B86827E7B7774717170706F6E6C6B6A68666461605D5B
58534E4944403C3734312F2D2B2927252424242424242323
2322211F1E1E1D1C1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1A1A1A1A1A1B
1B1D1F21232527292C3135393D4145484A49474645444442
4141403F3E3D3C3B3A3B3B3B3B3B3B3B
393A3B3C3D3E3E3F40404141414243434344444545464647
4849494A4B4C4D4D4E4F50515252535355575A5C5E606161
5E554B433B342E292526282A2C2E30353B45505A66707B86
919CA7B2BCC6CFD8DDDEDEDEDDDDDDDCDBDCDCDCDBDAD8D6
D3D0CBC7C3BFBBB8B4B3B1B0AEACAAA7A5A3A09E9B999794
918C8884807C787572727171706F6E6D6B6A686563615F5D
59544F4A45413C3834322F2D2B2926252323232323232323
2321201F1E1D1D1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1A1A19191A1A
1B1D1F222426292B2E33373A3E4245484948474645444342
41403F3F3E3C3B3A3A3A3A3A3B3A3A3A
393A3B3C3D3D3E3F40404041414242434344444445454646
474848494A4B4C4D4D4E4F50515252535457595B5C5E5E5E
5B534B433B35302A272728292B2C2E31363F48515B646E79
84919EAAB5C1CCD6DCDDDDDDDCDDDDDCDBDCDCDCDCDAD8D6
D4D0CCC8C4C0BCB8B5B4B3B1B0AEACAAA8A5A3A09D9B9895
928E8985817D79757372727271706F6E6C6B69666462605E
5A55504B46413C3834322F2D2B2826242323222222222222
2221201E1D1D1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1A191919191A
1B1D202326282B2D3134383B3F4245484948474645444342
41403F3E3D3C3B3A39393A3A3A3A3A3A
38393A3B3C3D3E3F40404041414242434343444444454545
46474848494A4B4C4C4E4F5051515253545658595A5B5C5B
59524A433C36312C29282828292A2B2E323840485158616B
768594A1AFBCC8D3DBDCDBDBDBDBDCDBDADBDCDCDCDAD8D6
D4D0CCC8C4C0BDB9B6B5B4B3B2B0AEACAAA7A4A19F9C9996
938E8A86817D79767373737272716F6F6D6B69676563615F
5B56504B46413D3834312F2D2A2825242222222222222222
21201F1E1D1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1A1919191919
1B1E2124272A2D303336393C3F4245474948474544434341
403F3E3E3D3B3A393939393939393939
38393A3B3C3D3E3F3F404040414142424343434344444445
4546474848494A4B4C4D4E4F5051525253555758595A5A59
575049433C37322E2A2928282828292B2E33393F474D555E
69798A99A8B7C4D1D9DAD9D9D8D9DAD9D9DADBDBDBD9D7D5
D3CFCCC8C4C0BCB9B6B5B5B4B3B1AFAEACA9A6A3A09D9A97
948F8A86827D7976737373727271706F6E6C6A686664625F
5C56514C46413D3834312F2C2A2725232121212121212121
21201F1E1D1C1B1B1B1B1B1B1B1B1B1C1C1B1B1B1B1B1B1B
1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1A1A1919191919
1B1E2125282B2E3235383B3D404345474847464544434241
403F3E3D3C3B3A393838393939393939
37383A3B3C3D3E3E3F404040414142424343434343434444
444546474848494A4B4C4D4F505051525354565757585857
554F49433D38332F2B2A2828272727282A2E32383D434952
5D6E8091A2B2C0CED7D8D7D7D6D7D8D8D7D9D9DADAD8D6D4
D2CECBC7C3BFBCB8B6B5B4B4B3B1B0AEACA9A6A3A09D9A97
938F8A86817D7975737272727271706F6E6C6A686664625F
5C56514B46413C3833312E2B292624222020202020212121
211F1E1D1C1C1B1B1A1A1B1B1B1B1B1C1C1B1B1B1B1B1B1A
1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1A1A1919191919
1B1E22262A2D303437393C3E404345464747464544434241
403F3E3D3C3A39383838383838383838
3738393A3B3C3D3E3F404040414142424242434343434343
44444546474849494A4C4D4E4F5051525354555556565655
534E48433E3935312D2B29282726252627292C3035393E46
516377899BACBCCAD4D5D4D4D3D5D6D5D5D7D8D8D8D7D5D3
D0CDC9C6C2BEBBB7B5B4B4B3B2B1AFAEACA9A6A29F9D9A96
938E8985817C79757272727171706F6E6D6B69676563615F
5B56504B45403C3733302D2B282623212020202020202020
201F1E1D1C1B1B1A1A1A1B1B1B1B1B1C1C1B1B1B1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1A1A1919191919
1B1F23272B2F3236393B3D3F414344464746454443434241
3F3E3D3C3B3A39383737383838383838
3738393A3B3C3D3E3F404040414142424343434343434343
43444546474748494A4B4C4E4F5051515253545555555554
524D48433E3A36322E2C2A28272625252627282B2F32373D
485B708396A7B7C6D1D2D1D1D0D2D4D3D3D5D6D6D6D5D3D1
CFCCC8C4C1BDB9B6B3B2B2B1B0AEADABA9A6A3A09D9A9794
918C88847F7B7874717170706F6E6D6C6B69676563615F5D
5A544E49443F3A35312F2C2A272522211F1F1F1F1F1F1F20
1F1E1D1C1C1B1B1A1A1A1B1B1B1B1B1C1C1B1B1B1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1B1A191919191A
1B2024292D3134383B3D3E40414344454645444443424140
3F3E3D3C3B3A39383737383838383838
3738393B3C3D3E3F40404141424243434343434343434344
44454546474748494A4B4C4D4E4F50515253545455555555
534E48433E3A36322E2D2B2A2928282829292A2C2F31363C
46596D7F92A3B2C1CCCDCDCDCDD0D2D2D2D4D5D5D5D4D2D1
CECBC7C4C0BCB8B4B1AFAEACAAA8A6A3A19F9C9A97959290
8D8985817D797673706F6D6C6B696766646361605E5C5A58
55504A45403B37322E2C2A28262421201F1E1E1E1E1F1F1F
1F1E1D1C1B1B1B1A1A1A1B1B1B1B1B1C1C1B1B1B1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1B1A1A19191A1A
1C21262A2F33363A3D3E3F40414243444444434342414040
3F3E3D3C3B3A39393838393939393939
37383A3B3C3D3E3F40414142424344444444444444444444
44454646474848494A4B4C4D4E4F50505153545455565655
534E48433E3A36312E2D2C2C2B2B2B2C2C2C2C2E3032363B
45576A7C8E9EADBCC7C8C9CACACDCFD0D0D2D3D4D4D3D1CF
CDC9C6C2BEBAB6B2AEACA9A6A4A19E9B98969492908E8C8A
8784817D7A7774716E6C6A686664615F5E5C5B5A58575553
504B45403B37332F2B2928262422211F1E1E1E1E1E1E1E1E
1E1D1C1C1B1B1B1A1A1A1B1B1B1B1B1B1C1B1B1B1B1B1B1A
1A1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1B1B1A1A1A1A1B
1D22272C3035383C3F40404041424243434242424140403F
3E3D3D3C3C3B3A3A39393A3A3A3A3A3A
37383A3B3C3D3E3F40414242434444454545454545444445
45454647474848494A4B4C4D4E4E4F505152545455565656
544E49433E3A36322F2E2E2D2E2E2E2F2F2E2E2F3032353A
435567798A99A8B6C0C2C3C5C6C9CBCCCDCFD0D1D1D0CECC
CAC7C3BFBBB7B3AFABA7A4A09D9995928F8E8C8B89888684
827F7C797674716F6C696664615E5C59575655545351504E
4B46413C37332F2B282725242321201F1E1E1D1D1D1D1D1D
1D1D1C1C1B1B1B1B1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A
1A1A1A1A1A1A1A1A1A1A1B1B1B1B1C1C1C1C1B1B1B1B1B1C
1E23282D32363A3E41414141414142414141414140403F3E
3E3D3D3C3C3B3B3A3A3A3A3A3A3A3A3A
37393A3B3C3D3F4041414243434445454646454545454545
45464647474848494A4B4C4C4D4E4F4F5052535455565756
544F49443E3A36322F2F2F2F303031323231303031323539
425264758594A2B0BABCBDBFC1C4C7C8C9CBCCCDCDCCCBC9
C7C3C0BCB8B4AFABA7A29E9A96918D898685848382817F7E
7C7A787573716F6C6966635F5C59565350504F4E4D4C4A49
46413C38332F2C282524232221201F1E1E1D1D1D1D1D1D1D
1D1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1A1A1A1A1A1A1A1A1A1A1B1B1B1C1C1C1D1C1B1B1B1B1C1D
1F242A2F34383C404342424141414140404040403F3F3E3E
3D3D3D3C3C3C3B3B3B3B3B3B3B3B3B3B
37393A3B3D3E3F4041424243444545464646464646454545
45464647484848494A4A4B4C4D4E4E4F5051535455565656
544F49443F3B373330313132323333343532313030313337
3E4F6070818F9CAAB4B7B8BABCC0C3C5C6C8C9CACAC9C8C6
C4C0BDB9B5B1ACA8A39E99948F8A86827F7E7D7D7C7B7A79
78767472706E6C6A67635F5C5854514D4B4A4A4948474644
423D3834302C292523222121201F1E1E1D1D1D1C1C1C1C1C
1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1A1A1A1A1A1A1A1A1A1B1B1B1B1C1C1D1D1D1C1C1C1C1D1E
20262B30363A3E42454443424140403F3F3F3F3F3F3E3D3D
3D3C3C3C3C3C3C3C3C3C3C3C3C3C3C3C
38393A3B3D3E3F4041424343444546464747464646464646
4646474747484849494A4B4C4D4D4E4E4F51535455565656
544F4A45403C383432323334343536373734313030303134
3B4B5C6C7B8996A3ADB0B2B4B6BABDBFC1C3C4C4C5C4C3C1
BFBCB8B4B0ACA8A39E99938E88837E7A7676767675747473
72716F6D6C6A696764605C57534F4B484545444443424140
3D3934302C2926232020201F1F1E1E1D1D1D1C1C1C1C1C1C
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1A1A1A1A1A1A1A1A1B1B1B1C1C1D1D1D1D1D1D1D1D1E1F
21272D32373C4044464543424140403E3E3E3E3E3E3D3D3C
3C3C3C3C3C3C3C3C3C3C3C3C3C3C3C3C
38393A3B3D3E3F4041424343444546474747474646464646
4646474747484848494A4A4B4C4D4D4E4F51525455565656
55504B46413D393533343535363738393935333130303133
3948586776838F9BA4A8AAACAEB2B6B8BABBBDBDBEBDBCBA
B8B5B1AEAAA6A19D98928B86807A75706D6D6D6D6D6D6C6C
6B6A696867666563615C57524E4945423F3F3F3E3E3D3C3B
3935302C292623201E1E1E1E1E1D1D1D1D1C1C1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1A1A1A1A1A1B1B1B1B1B1C1C1D1D1E1D1D1E1E1E1F21
23292E34393D41454746444241403F3E3D3D3D3D3D3D3C3C
3C3C3C3C3C3D3D3D3D3D3D3D3D3D3D3D
38393A3B3C3D3E3F40414243444546464747464646464646
454646464747474848494A4B4B4C4D4D4E50525455565757
56514B47423E3A37343536373838393A393633312F2F2F31
374453616E7A8591999C9EA1A3A7AAACAEAFB1B1B2B1B0AF
ADAAA6A39F9B97928D87817B76706B666363636464636363
636261605F5F5E5D5B56514C48433F3C3939393939383736
34302D292623211E1D1D1D1D1D1D1D1D1C1C1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1B1B1B1B1B1B1B1C1C1D1D1E1E1E1F20202123
252B30353A3E424648464442403F3E3D3C3C3D3D3D3C3C3C
3B3C3C3C3C3D3D3D3D3D3D3D3D3D3D3D
3738393A3B3C3D3E3F404142424344454545454544444444
4444454545454646464748494A4B4C4D4E50525456575859
57524D48433F3B3734353636363737373733302E2D2C2D2E
333E4B57636D7781888A8C8D8F92949697999A9A9B9A9998
9694918E8A87837F7B76706B66615D595656565757575656
56555554535352514F4C4744403C39363434343434333231
302D2A272422201E1D1D1D1D1D1C1C1C1C1C1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1C1C1D1F2022232426
292D32363B3E424546454342403F3E3D3C3C3D3D3D3C3C3C
3C3C3C3C3C3C3C3C3C3C3C3C3C3C3C3C
373838393A3B3C3C3D3E3F40414242434343434343434343
434343434343444445464748494A4B4C4D50535557585A5A
59544E4944403C38353535353535353534312E2C2B2A2A2B
2F39434D57606870767778797A7C7D7E7F80818282828180
7F7D7A7774726F6B68635F5B57534F4C4A494A4A4A494949
494848474746464544413E3B383533302F2F2F2F2F2E2E2D
2C2A27252321201E1D1D1D1D1D1C1C1C1C1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A
1A1B1B1B1B1B1B1B1B1B1A1A1A1A1A1A1B1D1F212426282A
2D3034383B3E414345444241403F3E3D3C3D3D3D3D3D3C3C
3C3C3C3B3B3B3B3B3B3B3B3B3B3B3B3B
36373838393A3A3B3C3D3E3E3F4041414242424241414241
41414242424242434344454748494A4B4D50535557595A5B
5A55504B45413D393635353535343333322F2C2A29282828
2B333C444D545A616666666666686969696B6B6C6C6C6B6B
6A686563615E5C5956534F4C494643403E3E3E3E3E3D3D3D
3D3C3C3C3B3B3B3A39373533302F2D2B2A2A2A2A2A2A2929
2827252322211F1E1D1D1D1D1C1C1C1C1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A
1A1B1B1B1B1B1B1C1C1B1A19191919191B1D202326282B2E
303336393B3E404243434241403F3E3D3D3D3D3D3D3D3C3C
3C3C3B3B3B3B3B3A3A3A3A3A3A3A3A3A
363637373839393A3A3B3C3D3E3F3F404040404040404040
4040404040404141424344464748494A4C4F5355585A5B5C
5B56514C47423E3A3736363534333231302D2B2927262626
282F363C42484D5255555454535454545455565656565655
5453514F4D4B49474542403D3B3836343232323232313131
31303030303030302F2E2C2B292827262525252526252525
2524222120201F1E1E1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A
1A1B1B1B1B1B1C1C1C1B1A19191818191A1D2125282B2E31
3436383A3C3E4041424141403F3F3E3D3D3D3D3D3D3D3C3C
3C3C3B3B3A3A3A3A3939393A3A3A393A
3536363737383839393A3B3C3C3D3E3F3F3F3F3F3F3F3F3F
3F3F3F3F3F3F3F40404243444647484A4C4F5355585B5C5D
5D58524D48443F3B38373635343331302F2D2A2927262525
262B3034393D404446454443424141404041424242424242
41403E3D3B3A38373533312F2D2B2A282727262626262525
252525252526262625252423222121202020202021212121
2120201F1F1E1E1E1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A
1A1B1B1B1B1C1C1C1C1B1A19181818181A1E22262A2E3134
37393A3B3C3E3F404140403F3F3E3E3D3D3D3D3D3D3D3C3C
3C3B3B3A3A3A39393939393939393939
353536363637373738393A3A3B3C3D3D3E3E3E3E3E3E3E3E
3E3E3E3E3E3E3E3F3F414244454647494B4F5255585B5D5E
5E59534E4945413D39383736353332302F2D2A2927262524
25282B2E31333537383735333231302F2F2F303031303030
302F2D2C2B2A29282725242221201F1D1D1C1C1C1C1B1B1B
1B1B1B1C1C1C1D1D1D1D1C1C1C1C1C1B1B1C1C1C1C1C1D1D
1D1D1D1D1D1D1D1D1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A
1A1B1B1B1C1C1C1D1D1B1A19191818181A1E23282D303438
3B3B3C3C3D3E3F3F403F3F3F3F3E3E3D3D3D3D3D3D3D3C3C
3C3B3B3A3A3939383838383839383838
3535353535363636373838393A3B3B3C3D3D3D3D3D3D3D3E
3E3D3D3D3D3D3D3D3E404143444547484B4E5255585B5D5E
5E5954504B47433F3B3A3937363432302E2C2B2927262524
24252628292A2B2B2B2927252321201E1E1E1F1F1F1F1F1F
1F1E1D1C1C1B1A1A19181717161515141413131312121212
12121213131414151515161616171717181818181919191A
1A1A1B1C1C1D1D1D1D1D1D1C1C1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1A
1B1B1B1B1C1C1D1D1D1C1A19191818191A1F252A2F33373B
3E3E3E3D3D3E3E3E3E3E3E3E3E3E3D3D3D3D3D3D3D3D3C3C
3C3B3B3A393938383738383838383838
343434343535353536373738393A3A3B3C3C3C3C3C3D3D3D
3D3D3D3D3D3D3D3D3E3F4142444546484A4E5154575A5C5D
5D5955514D4A46433F3E3C3A383633312F2D2C2A29272624
242424242424242322201D1B191715131213131414141414
14131312121111101010100F0F0F0F0E0E0E0D0D0D0C0C0C
0C0D0D0E0E0F0F1010111112131314151516161616171717
18191A1A1B1C1C1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1C1C1C1D1D1D1C1B1A1919191A1C21272C31363A3E
41403F3F3E3E3E3E3E3E3E3E3E3E3D3D3D3D3D3D3D3D3C3C
3C3B3A3A393838373737373737373737
33343434343434353536373839393A3B3C3C3C3C3D3D3E3E
3E3E3E3D3D3D3E3E3E404143444547484A4D4F5254565859
59585553514F4D4B484543403D3A373532302F2D2B292826
252525252424242322201E1C191816151414151515151516
161514141313131212121111111111101010100F0F0F0F0F
0F0F10101011111212131314141515161616171717171818
18191A1A1B1B1C1C1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1C1C1C1D1D1C1B1B1B1B1B1C1F24292F34383C40
424241403F3F3F3E3E3E3E3E3E3D3D3C3C3C3C3C3C3C3C3C
3C3B3A39393837373737373737373737
33333333333434343536373738393A3B3C3C3C3D3D3E3E3F
3F3F3F3F3E3F3F3F3F414243454647484A4C4D4F51525354
5556565555555453514E4A46433F3C38363432302E2C2A29
28272726262625252422201E1C1A19181717181819191919
191918171716161615151515141414141313131313131313
131313141414151515151616161717171718181818181819
19191A1A1B1B1B1B1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1C1C1C1D1C1C1D1D1D1E1F22272C31363A3E42
444342414040403F3F3F3E3E3E3D3D3C3C3C3C3C3C3C3C3C
3B3B3A39383837373636373737373737
32323233333333343435363738393A3B3B3C3D3D3E3E3F3F
403F3F3F3F3F40404041434445464748494A4B4D4E4F4F50
5254565758595A5A5955504C4844403D39373534322F2D2B
2A292828272726262523211F1E1C1B1A191A1A1B1B1B1B1C
1C1B1A1A1919191818181717171716161616161616161616
161616171717171717181818181818181919191919191919
191A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1C1C1C1D1D1E1F202123252A2F34383D4044
46454443424141403F3F3E3E3E3D3C3C3B3B3C3C3C3C3C3C
3B3A3A39383737363636363636363636
32323232323333333435363738393A3A3B3C3D3D3E3F3F40
4040404040404041414243444546474849494A4A4B4B4C4C
4E5255595C5E6061615C57524D4945413D3B39373532302E
2C2B2A2A2928282726242321201F1E1D1C1D1D1D1E1E1E1F
1F1E1D1D1C1C1B1B1B1A1A1A1A1A19191919191919191919
191A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1C1C1D1E1F2021232426292D32373B3F4245
47464544434241403F3F3F3E3E3D3C3B3B3B3B3B3B3B3B3B
3B3A3938383737363636363636363636
3131313132323233333435363738393A3B3C3D3D3E3F4040
414141414141414142434444454647484948484848484849
4B50565A5F62656767625C57514D4844403E3C3A38353230
2E2D2C2B2A292827262422211F1E1D1C1C1C1D1D1D1E1E1E
1E1E1D1D1C1C1C1B1B1B1B1B1B1B1B1A1A1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1C1C
1C1C1B1B1B1B1C1C1D1E2022232527292C3035393D414447
49484645434242403F3F3E3E3D3D3C3B3A3B3B3B3B3B3B3B
3B3A3938373736363535363636363636
3030313131313232333435363738393A3B3C3C3D3E3F4040
414141414141414242434445464647484847464646454546
484F555B6166696D6D67615B55514C4743413F3D3B383533
312F2D2C2A292827252422201F1E1D1C1C1C1C1D1D1D1E1E
1E1E1D1D1C1C1C1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C1D1D
1D1D1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1C1C1C
1C1C1C1C1C1C1C1D1E20222426282A2C2F33383C3F434649
4B494746444342403F3F3E3E3D3C3B3B3A3A3B3B3B3B3B3B
3B3A3938373636353535353535353535
303030303131313232333435363738393A3B3C3D3E3F4041
414141424242424242434445464747484846454443424243
454D555C63686D71726D66605A55514B474543413F3B3835
33312F2D2C2A29272625232221201F1E1E1E1E1E1F1F1F20
201F1F1E1E1E1E1D1D1D1E1E1E1E1E1E1E1E1F1F1F1F1F1F
1F1F1F1F1E1E1E1E1E1D1D1D1D1D1D1D1D1D1D1C1C1C1C1C
1C1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1C1C1C1D
1D1C1C1C1C1C1D1D1F212426292B2D3033373B3E4245484A
4C4A4846454342403F3F3E3E3D3C3B3A3A3A3A3B3B3B3B3B
3A3A3938373636353535353535353535
2F3030303030313132333435363738393A3B3C3D3E3F4041
414141424242424242434445454647484746444342404040
434B545C63696E73746F69645E5A56524D4A4845423E3A37
3432302E2C2B2927262523222120201F1F1F1F1F20202021
2120201F1F1F1E1E1E1E1E1F1F1F1F1F1F20202020202021
212020201F1F1F1F1E1E1E1E1E1E1E1E1D1D1D1D1D1D1C1C
1C1C1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1C1C1C1D1D
1D1D1C1C1D1D1D1E202326292C2F3235383B3F4244474A4C
4C4B4947454342403F3E3E3D3D3C3B3A3A3A3A3A3A3A3A3A
3A393837373635353434353535353535
2F2F30303031313132333435363738393A3B3C3C3D3E3F40
404040414141414141424344454546474745434241404040
434A52595F656A6E706E6A6764625F5C58534E49443F3A35
312F2D2C2A282624232221201F1E1E1E1D1E1E1E1E1E1F1F
1F1F1E1D1D1D1D1C1C1C1D1D1D1D1E1E1E1E1E1E1E1F1F1F
1F1F1E1E1E1E1E1D1D1D1D1D1D1D1D1D1D1D1C1C1C1C1C1C
1C1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1C1C1C1C1D
1D1D1C1C1D1D1E1F2125292D3235393C40424446484A4B4C
4D4B49474543413F3E3E3D3D3D3C3B3B3A3A3A3A3A3A3A3A
3A393837363635343434343535353535
2F2F3030303131323233343536373838393A3B3C3C3D3E3F
3F3F3F3F3F40404040414243444545464644434241404041
434950565B6064686B6B6B6A69696866625C544E47403A33
2E2D2B2928252322201F1E1E1D1D1C1C1C1C1C1D1D1D1D1D
1D1D1C1C1B1B1B1B1A1B1B1B1B1C1C1C1C1C1C1D1D1D1D1D
1D1D1D1D1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1C1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1A1B1B1B1B1C1B1B1C1C1C1C1D
1D1D1C1D1D1D1E1F22272D32373C40444749494A4B4C4D4D
4C4B49474442403E3D3D3D3D3C3C3B3B3A3A3A3A3A3A3A3A
39383837363535343434343435343434
2F2F3030303131323233343536363738393A3A3B3C3C3D3E
3E3E3E3E3F3F3F3F3F404142434444454544434241414141
43484E53585C5F6367696B6C6D6F6F6E6B635A5249423A33
2D2B2A28272421201E1D1D1C1C1C1C1C1C1C1C1C1C1C1C1C
1C1C1B1B1A1A1A1919191A1A1A1A1B1B1B1B1B1B1B1B1C1C
1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1C1C1C1C1C1C1C1D1D
1D1D1D1D1E1E1F21242A31373C42464B4E4E4E4E4D4E4E4D
4C4A48464442403E3C3C3C3C3C3C3B3B3B3A3A3A3A393939
39383737363535343434343434343434
2F2F303030313132323334353536373839393A3A3B3C3C3D
3D3D3D3D3E3E3E3E3E3F4041424344444543424241414141
43474C5054575A5E62666B6E71747677746B60564C433B33
2C2A29272623201E1D1C1C1B1B1B1B1C1C1C1B1B1B1B1C1C
1C1B1A1A191919181818191919191A1A1A1A1A1A1A1A1A1A
1B1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1A1A1A1A1A1A1A1B1B1B1C1C1C1C1C1C1C1C1C1D1D
1E1E1E1E1F202122262D343B42484D525554535150504F4D
4C4A484644413F3D3B3B3C3C3C3B3B3B3B3A3A3A39393939
38383736363535343434343434343434
2F2F2F303031313232333435353637383839393A3B3B3C3C
3D3D3D3D3D3D3D3D3E3F4041414243444443424141404041
42464A4E5154575A5F656C71767A7D7F7D72655A4F453C32
2B2A29272623201E1D1D1C1C1C1C1D1D1E1D1D1D1D1D1D1D
1D1C1C1B1A1A1A191919191A1A1A1A1A1A1A1A1A1A1B1B1B
1B1B1B1B1B1B1B1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1A1B1B1C1C1D1D1D1D1D1D1D1D1E1E
1F1F1F1F20202223272F383F464D53585B5A57555251504E
4C4A484644413E3C3B3B3B3B3B3B3B3B3B3A3A3939393938
38373736353535343434343434343434
2E2F2F303031313232333435353637373839393A3A3B3B3C
3C3C3C3C3C3C3D3D3D3E3F40414242434342414140404041
4245484B4F5153575C646C72797F838684786A5E52473E33
2C2A29282724211F1E1E1D1D1E1E1F1F201F1F1F1E1E1F1F
1E1E1D1C1C1B1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1A1A1A1A1A1B1B1C1C1D1E1E1E1E1E1E1E1E1F1F
20202021222223262A323B434B52585E615E5B585452504E
4B49474543403E3C3A3A3B3B3B3B3B3B3B3A3A3939383838
38373636353534343434343434343434
2E2F2F3030313132323334343536363738383939393A3A3B
3B3B3B3C3C3C3C3C3D3E3F3F404142424342414040404041
424446494B4D4F5257616B737B82878B8A7D6F62554A4035
2D2C2B2A282522201F1E1F1E1F1F2021212120201F1F1F1F
1F1E1D1D1C1B1B1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1C1C
1C1B1B1B1B1A1A1A1B1B1C1C1D1E1E1F1F1F1F1F1F202021
21212223242526282D363F4750575D6366625E5A5653514D
4A48474543403D3B3A3A3A3B3B3B3B3B3B3A3A3938383838
37373636353534343434343434343434
2E2E2F3030313132323334343536363737383839393A3A3A
3B3B3B3B3B3C3C3C3C3D3E3F404041424241414040404041
42434547494A4C4F545E69727A82888C8B7F7165584E453A
33312F2E2C2825222120202020212122222120201F1F1F1F
1F1E1D1D1C1C1B1B1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1C1C
1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1C1C
1C1B1B1B1B1B1B1B1B1C1C1D1E1E1F202020202020212122
2324252628292B2E323B444C535A606668645F5B5653504C
49474644423F3D3B3A3A3A3A3B3B3B3B3B3A393938383837
37373636353535343434343434343434
2E2E2F2F3030303132323334353536373738383939393A3A
3B3B3B3B3C3C3C3D3D3D3E3F3F4040414140404040404041
4143444647484A4D515A646C737A7F84847B71675E564F47
403D3A37332F2A272423232222212121201F1F1E1D1D1D1D
1C1C1B1B1B1B1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1A1A1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1C1C1D1D1E1F1F2020202020212223
25272A2D303336393D444B51565C606465615D5954514E4A
47464443423F3D3B3A3A3A3A3A3A3A3A3A3A393838383837
37373636363535353435353535353535
2D2E2E2F2F2F303031323333343536373738383839393A3A
3B3B3B3C3C3C3D3D3D3E3E3E3F3F3F4040403F3F3F404041
414243454647494B4E565E656C71767A7B766F6A635F5A54
4F4A45403C36312C29272625242221201F1E1D1C1B1B1A1A
1A1A1A1A1A1A1A1A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1B
1B1B1B1B1B1B1B1C1C1C1C1D1D1E1E1F2020202021222324
272B3034393D4045494D5155595C5F61625E5A56524F4C48
45444342413F3D3C3B3A3A3A3A3A39393939383838383838
37373736363635353535353535353535
2D2D2E2E2E2F2F3030313233343536363737383839393A3A
3A3B3B3C3C3D3D3E3E3E3E3E3E3E3F3F3F3F3F3F3F404041
42424344454647494C52595F656A6E7173716E6B68666360
5B554F49433D37322D2B2928262422201E1D1C1B1A191918
1818181919191A1A1A1A1A1A1B1B1B1B1B1B1B1B1B1B1C1C
1C1B1B1B1B1B1B1B1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1A1A1B1B1B1B
1B1B1B1B1B1C1C1C1C1D1D1D1E1E1F202021212223242527
2A2F353B41464A4F535557595B5D5E5F5E5B5754504D4946
43424241403F3D3C3B3B3A3A393939393838383838383838
37373736363636353535353536363535
2D2D2D2E2E2E2F2F3031323334343536373738383839393A
3A3B3C3C3D3D3E3E3E3E3E3E3E3E3E3E3E3E3F3F3F404141
42424243444446474A4F54595E6165696B6C6D6D6D6D6D6B
686159524B443E37322F2D2B282522201E1D1B1A19181717
171717181819191A1B1B1A1B1B1B1B1B1B1B1C1C1C1C1C1C
1C1C1B1B1B1B1B1B1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1A1A1B1B1B1B
1B1C1C1C1C1C1C1D1D1D1E1E1E1F20212122222325262729
2D343B42494E54595C5D5D5D5D5D5D5D5B5854514E4A4744
414140403F3E3D3D3C3B3A3A393938383838383838383838
38373737363636363636363636363636
2C2D2D2D2E2E2E2F2F30313233343536373737383839393A
3A3B3C3C3D3E3E3E3F3E3E3E3D3D3D3D3D3E3E3F40404142
4242424242424344464B4F53585B5E6265696C6F71747575
736B625A524A433C3633302D2B2723211E1C1B1918171616
161617171819191A1B1B1B1B1B1B1B1B1C1C1C1C1C1C1C1C
1C1C1C1B1B1B1B1B1A1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1A1A1A1A1A19191A1A1A1B1B1B1B
1C1C1C1C1D1D1E1E1E1E1F1F1F202122222323252627292B
2F3740484F565C62656463615F5E5D5B5956524F4C484542
3F3F3F3F3F3E3D3D3C3B3A39393838373737373737383838
38373737373736363636363636363636
2C2C2D2D2D2E2E2E2F303132333435363737373838383939
3A3B3C3C3D3E3E3F3F3E3E3D3D3D3D3C3D3D3E3F40414142
434241414141414244474B4F5255585B60656B7074797C7D
7C746A61585049413A3734312E2925221F1D1B1A18171615
1516161718191A1B1B1B1B1B1B1B1C1C1C1C1C1C1C1C1C1C
1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1A1A1A1A1A1A1A1A1B1B1B1B1C
1C1C1D1D1E1E1F1F202020202122232425252627282A2B2E
323C454E565D646A6D6A6764615F5D595653504D4A464340
3E3E3E3E3E3D3D3D3D3B3A39383837373737373737373838
38373737373737373737373737373737
2C2C2C2D2D2D2E2E2F303132333435363637373738383939
3A3B3B3C3D3E3E3F3F3E3E3D3D3C3C3C3C3D3E3F40414243
43424140404040404144474A4D4F515459616A71777D8285
857C72685E564F463F3B3835312C2724201E1C1A19171616
1516171718191A1B1C1C1B1B1B1B1C1C1C1C1C1C1C1C1C1C
1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1C1C1C1C1C1B1B1B1A1A1A1A1A1A1A1B1B1B1C1C
1D1D1D1E1E1F202021212222232425272828292B2C2D2F32
37414B545C646B7173706B66615E5B5753504E4B4844413E
3C3C3D3D3D3D3D3D3D3C3A39383837373636373737373838
38383737373737373737373737373737
2C2C2C2C2D2D2D2E2E2F3031323334353636373737383839
393A3B3C3D3E3E3F3F3E3E3D3D3C3C3C3C3D3F4041424343
444241414040404041424447494A4D50545E6870787F8589
8981766D635C544C44413D3935302B2723211F1D1C1A1918
17181819191A1B1C1C1C1C1C1B1C1C1C1C1C1C1C1C1C1C1C
1C1C1C1C1B1B1B1B1B1B1B1B1B1B1B1C1C1C1B1B1B1B1B1B
1B1B1C1C1C1C1C1C1C1C1C1B1B1B1B1B1B1B1B1B1C1C1C1D
1D1D1E1E1F2020212223242527282A2C2D2E30313335373A
3F48515961696E7476716B66605D5954504D4B494643403D
3B3B3C3C3D3D3D3D3D3C3A39383837373636373737373738
38383737373737373737373737373737
2C2C2C2D2D2D2D2E2E2F3031323334343535363637373838
39393A3B3C3D3D3E3E3E3E3D3D3D3D3D3E3F404041424344
4443434242424242434446484A4B4D50545D656D747B8084
847D756D655E58514B4743403C37322E2B2827252321201F
1E1D1D1D1D1D1D1D1D1C1C1C1B1B1B1B1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1B1B1B1B1B1B1C1C1C1C1C1C1C1C1C1C
1C1C1C1C1D1D1D1D1D1D1D1D1D1D1D1D1D1D1C1C1C1C1C1D
1D1D1D1E1E1F20212225282A2D303336393B3D404244474A
4D53595F64686C6E6F6B66615D5955514D4B494745423F3D
3C3C3C3C3C3C3C3D3C3B3A39393838373737373737373737
37373737373736363636363636363636
2C2C2D2D2D2D2E2E2E2F3031313233343435353536363737
3839393A3B3B3C3D3D3D3D3E3E3E3E3F3F40414142434444
45444444444444454647484A4C4D4E51545C63697075797D
7E78726C66615C56514E4A46433E3A3633302F2D2B292826
25242221201F1F1E1E1D1C1C1B1B1B1B1A1A1A1A1A1A1A1B
1B1B1A1A1A1A1B1B1B1B1B1B1B1C1C1C1C1C1C1C1C1C1C1C
1C1C1D1D1D1E1E1E1E1E1F1F1F1F1F1F1F1E1E1D1D1D1D1D
1D1D1D1D1E1E1F2023272B3034393D4145484B4E5154575A
5D5F6163656767686764605C5855514E4B49474544413F3E
3C3C3C3C3C3C3C3C3C3B3A3A393938383838383837373737
37373736363636363636363636363636
2C2C2D2D2D2D2E2E2E2F3030313232333334343535363637
373839393A3A3B3C3C3D3D3E3E3F3F404041424243434445
454545454646474748494A4B4D4E4F51545A61666B707477
7875706C6763605B5754504D4945413D3A38363432302F2D
2B2927252422211F1E1E1D1C1C1B1B1A1A1A1A1A1A1A1A1A
1A1A1A1A1A1A1B1B1B1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C
1C1D1D1E1E1E1F1F1F2020202021212121201F1F1E1E1E1E
1D1D1D1D1E1E1F21242A30363B41464B5054585B5F626668
6A69696866656462605D5A5754514E4B4846454442413F3E
3D3D3C3C3C3C3B3B3B3B3A3A393939393938383838373737
37373636363635353535353535353535
2C2D2D2D2D2E2E2E2F2F3030313132323333343434353536
37373838393A3A3B3C3C3D3E3F4040414242434344444545
464647474848494A4B4B4C4D4E4E505154595E63676B6E71
73706E6B686663605D5A5753504C4844413F3D3C3A383634
312F2C29272523211F1E1D1D1C1B1B1A1A1A191919191A1A
1A1A1A1A1A1B1B1B1B1B1C1C1C1C1C1D1D1D1D1D1C1D1D1D
1D1D1E1E1F1F20202121222222232323232221201F1F1F1E
1E1E1D1E1E1F2022252C343B43494F555B6065696C707476
77736F6C6764605C59565452504D4A474544434241403F3E
3E3D3C3C3C3B3B3B3B3A3A3A3A3A3A393939383838373737
36363636353535353535353535353535
2C2D2D2D2D2E2E2E2F2F2F30303131323233333434353536
3637373838393A3A3B3C3D3E3F4041424343444444454546
46474849494A4B4C4D4D4D4D4D4E4E4F52565B6064686B6E
6F6E6D6C6A69686663605D5956524E4B48464442413E3C3A
3734312D2A272522201F1E1D1C1B1B1A1A19191919191919
191A1A1A1A1B1B1B1B1C1C1C1C1C1D1D1D1D1D1D1D1D1D1D
1D1E1F1F2020212122232324242525262624232221202020
1F1F1E1F1F1F2123272F38404950575E656A7074787D8183
827D767069645E585452504E4C494644424140403F3F3E3E
3E3D3C3C3B3B3B3B3A3A3A3A3A3A3A3A3A39393838373737
36363635353535343434343434343434
2D2D2D2D2D2E2E2E2F2F2F30303031313232333334343535
363637373839393A3B3C3D3F404142434444454545464647
4748494A4B4C4D4E4E4E4D4D4D4D4D4E5054595D6164676A
6C6C6C6C6C6C6B6A6965625F5B5854514E4C4A494744423F
3D3935312D2A272421201F1E1D1C1B1A1A19191919191919
1A1A1A1A1A1B1B1C1C1C1C1C1D1D1D1D1D1D1D1D1D1D1E1E
1E1F1F202121222223242525262728282826252423222221
212020202121232529333C464F575F676E74797E82888B8D
8C847B736B635C554F4D4C4A484542403F3E3E3E3E3E3E3E
3E3D3C3C3B3B3B3A3A3A3A3A3B3B3B3A3A3A393838373736
36363535353534343434343434343434
2D2D2D2D2D2E2E2E2F2F2F2F303030313132323333343435
363636373838393A3B3C3E3F404243444545464646464747
48494B4C4D4E4F5051504F4E4E4D4D4E4F52565A5D606366
68696B6C6D6E6E6E6E6B6764615D5A575452514F4D4A4745
423D3934302C29252321201F1E1D1C1B1A1A1A1919191A1A
1A1A1A1B1B1B1C1C1D1D1D1D1D1D1E1E1E1E1E1E1E1E1E1E
1F1F2021222223242425262728292A2A2A29272625242423
23222223232425282D37424C565E676F777D83888C919596
948B80766B6259504948474645423F3E3C3C3C3C3D3D3E3E
3E3D3C3C3B3B3A3A3A3A3A3B3B3B3B3B3B3A393938373736
36363535353434343434343434343434
2C2C2D2D2D2D2E2E2E2F2F2F2F3030313131323233343435
353636373838393A3B3C3E3F414244454646464647474748
494A4C4D4F5051525251504F4E4D4D4D4E5154585B5D6062
65676A6C6D6F7172716F6B6865625F5B58565552504D4A48
443F3B36322E2A27242221201F1E1D1C1C1B1B1B1B1B1B1C
1C1C1C1C1D1D1D1E1E1E1E1E1E1E1F1F1F1F1E1E1E1E1E1E
1F2021222223242526272828292A2B2B2B2A282726262525
2525262728292B2E343E49535D666F777F858A8E9196999A
978C80756A60574D46454443423F3D3C3B3B3B3B3C3D3E3E
3F3E3D3C3B3B3B3A3A3A3B3B3B3B3B3B3B3A3A3938383736
36363535353434343434343434343434
2B2B2C2C2C2C2D2D2D2E2E2F2F2F30303131323233343435
3536373738393A3A3B3D3E3F414243444546464647474848
494B4C4E4F5051525251504F4E4D4D4C4D5054575A5D5F62
65686A6C6E70727373706C6966625F5C585653514E4B4744
413C3835312D2A2725242322222120202020202020202121
2121212020202020202020202021212120201F1F1F1E1E1E
1E202122232425262727282828292A2A2A29282727272728
282A2C2F3234373B414A545E676F767E8487898B8D8F9090
8C837970665D554D4745444342403D3C3B3B3C3C3C3D3E3F
3F3E3D3D3C3C3C3C3B3B3C3C3C3C3B3B3B3A3A3938383737
36363636353535353535353535353535
2A2A2B2B2B2B2C2C2D2D2E2E2F2F30303131323233343435
36363738393A3A3B3C3D3E3F404243444445464647484849
4A4B4D4E4F50515252514F4E4D4C4C4C4D5054575A5D5F62
65686B6D6F71737474716D6A66635F5C5855524E4B474440
3D393633302D2A2826252525252424242424252525262626
27262525242424232323232323232322222120201F1E1E1E
1E202123242526282828282828282828292828282828292A
2C3034383C4044494F57606870777D838788888887878684
80797169625B544D4846454443403E3D3C3C3D3D3D3E3E3F
3F3F3E3E3D3D3D3D3D3C3C3C3C3C3C3B3B3A3A3939383837
37373636363636363535353535353535
29292A2A2A2B2B2B2C2D2D2E2E2F30313132323333343435
36373839393A3B3C3D3E3F4040414243444546474748494A
4B4C4D4F505152535351504E4D4C4C4C4C5053575A5C5F62
65686B6D6F72737474716E6A6764605C5855514D4945413E
3A3734322F2D2B292727272727272728282829292A2A2B2B
2B2A2929282726262525252525252424242221201F1F1E1E
1E202223252628292A29282827282828282829292A2B2C2E
31353B40464B50555B636A71787E83888B898784817F7D79
756F69645E58524D4847454443413F3E3D3D3D3D3D3E3E3F
3F3F3E3E3E3E3E3E3E3D3D3D3C3C3B3B3B3A3A3939383837
37373737363636363636363636363636
282929292A2A2A2B2B2C2D2E2E2F30313132323333343535
363738393A3B3C3D3E3F3F40414142434445464748494A4B
4C4D4E4F505152535351504E4D4C4C4B4C4F53565A5C5F61
64676A6D6F72747575726E6B6764615D5955504C48443F3B
383533312F2D2B2A2929292A2A2A2B2B2C2D2D2E2E2F3030
302F2E2C2B2A2929282827272727262625242221201F1E1E
1E2022242627292A2B2A29282828282828292A2B2C2D2F31
353B424950565B62686E757A7F85898C8D8A85817C78746F
6A66625E5A55514D494746444341403F3E3E3E3E3E3E3F3F
3F3F3F3F3F3F3F3F3F3E3E3D3D3C3C3B3B3A3A3939383838
37373737373737373737373737373737
28282929292A2A2A2B2C2D2E2E2F30313232333334343536
3738393A3B3C3D3E3F3F4040414142434345464748494A4B
4C4E4F50515253545452504F4E4D4C4C4C4F5255585B5D60
6266696C6F72747676736F6C6865625E5A56514C48433E3A
36343331302E2C2B2B2B2C2C2D2E2E2F3031323233343435
343332302F2E2D2B2A2A2A2A292928282725242221201F1E
1F21232527292B2C2D2C2A292828282829292A2C2E2F3134
39404850585F656C73797E83878C9092928C857F79736D67
625F5C5956524E4B484745444241403F3F3F3F3F3F3F4040
4040404040404040403F3F3E3D3D3C3C3B3B3A3A3A393938
38383838383838383838383838383838
2828282929292A2A2B2C2D2E2F3030313233333434353636
3738393B3C3D3E3F404040414142424344454647494A4B4C
4D4E505152535455555351504E4D4D4C4D4F525557595B5E
6165686C6F7274767674706D6A6764605C57524D48433F3A
37353332312F2E2D2D2E2E2F303132333435353637383838
3837353432312F2E2D2C2C2C2B2B2A29292725232221201F
1F222426292B2C2E2F2D2C2B2A2A2A2A2A2B2D2F31323538
3D464F5860686F767D82868A8E929596948D857D766E6860
5B595755534F4C4A48464543424140403F3F3F3F40404040
414141414141414141403F3F3E3D3D3C3B3B3B3A3A3A3939
39393939393939393939393939393939
2728282829292A2A2B2C2D2E2F3031323333343435363637
38393A3C3D3E3F40414141414242434344454748494A4C4D
4E4F505152545455555352504F4E4D4D4D4F525457585A5D
5F63676B6E7174757674716E6B6865625E59534E49443F3B
37363533333130303030313233343536373839393A3B3C3C
3C3A3836353332302F2E2E2E2D2C2C2B2A28262523222120
212325282A2C2E30302F2E2C2C2C2C2C2D2E303235373A3D
434C566069717980878B8E9193969898958C837A71686058
525151504F4D4A4948464543424141414040404040404141
41414142424242424241403F3E3D3D3C3B3B3B3A3A3A3939
39393939393939393939393939393939
2828282929292A2B2B2C2D2E303132333434353536373738
393A3C3D3E3F40414242424243434344454647494A4B4C4E
4F5051525354555656545251504F4E4E4E5052545658595C
5E62666A6D7072757574726F6D6B6966625D57524D48433F
3B3A393736353433323333343535363738393A3A3B3C3C3D
3C3B393736343331302F2F2E2E2D2C2B2A29272624232322
222427292B2D2F30313130302F3031323335373A3D3F4246
4B555F68717981888E9092949596979692897F766C635B52
4C4C4C4C4C4A494847464443424141414040404040404040
414141414142424241403F3E3E3D3C3B3B3A3A3A39393838
38383838383839393939393938383939
2829292A2A2B2B2C2C2E2F3031323334353636373738393A
3B3C3D3E4041424344444444454545464748494B4C4D4E4F
50515253545556565655535251504F4F4F5152545658595B
5D6165686B6E7072747473727171706E6B67625E5955504C
484543413F3C3A3836353534343434343434353535363636
363534333231302F2E2D2D2C2B2A2A292827272626252525
252628292B2C2D2F31323436383A3C3F414446494C4F5256
5B636B727A80868B8F90908F8F8F8E8C8880787068605851
4C4C4C4B4B4948474644434140403F3F3E3E3E3E3E3E3E3E
3E3E3E3E3E3E3E3E3E3D3C3B3A3A39383837373636353534
34343434343434343534343434343434
292A2A2B2B2C2C2D2E2F30313233343536373838393A3B3C
3C3E3F40414243454546464647474848494A4B4C4E4E4F50
51525354545556565655545352515150515253555658595B
5D606366696B6E70727374757676777675716D6965625E5A
56524E4B4744403D3A383735343231302F2F2F2F2F303030
302F2F2E2E2D2D2D2C2B2A29282827272626262727272828
2929292A2A2B2C2E3034383C4145484D505356595C5F6366
6A70777C81868A8D8F8E8C8A888684817D76706A635D5751
4D4C4B4B4A484746454341403F3E3D3D3C3C3C3C3C3B3B3B
3B3B3B3B3B3B3B3B3A3A3938373736353534333332323131
30303030303030303030303030303030
2A2B2B2C2C2D2E2E2F303132343536373839393A3B3C3C3D
3E3F4142434445464747484849494A4A4B4C4D4E4F505151
52535454555656575756555453525252525354555657595A
5C5E616466696B6E70737577797B7D7D7D7A7774706D6A66
625D5954504B47423E3C39373432302E2C2C2B2B2B2B2B2B
2B2B2B2B2B2B2B2B2B2A29282726252525262728292A2B2C
2C2C2B2B2B2B2C2E31363D43494E53595E6164676A6D7174
777C8184888B8D8F8F8C8985817E7B77726E69645F5A5551
4D4C4B4A494846454442413F3E3D3C3B3B3A3A3A3A3A3A3A
3A39393939393838383736363534343333323130302F2F2E
2E2E2E2E2E2E2E2E2E2D2D2D2D2D2D2D
2B2C2D2D2E2F2F3031323334353637393A3A3B3C3D3E3E3F
404143444546474849494A4A4B4B4C4C4D4E4F5051515253
53545555565657575756565554545353535455565757585A
5B5D60626466696B6E72767A7D8082848583807E7B787572
6E68635E58524D48433F3C3835322F2C2A29282827272626
2627272828292A2A2A29272625252424242627292B2C2E2F
302F2D2C2C2C2C2E3139414951585F666B6F7275787C7F82
85888A8C8E9090908F8A85807B76726D6865625E5B575451
4E4C4B4A494746454442403F3E3C3B3B3A39393939393938
3838383737373636363535343333323131302F2E2E2D2C2C
2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B2B
2D2E2E2F303131323334353637393A3B3C3D3D3E3F404142
434445464748494A4B4B4C4D4D4E4E4F4F50515253535454
55565657575758585857575656565555555656575758595A
5B5D5F61636567696C72777C8084888B8C8B89868482807C
78726C666059534D47433F3B37322E2B2827262525242424
242425262728292A2A292726252424242426292B2D2F3133
3432302E2D2D2D2E323C464F59616971787C7F82868A8D90
9294959696969694918B847E77716B65605D5B595754514F
4D4B4A4948474646454341403E3D3C3B3A3A393939383838
37373736363636353534343332323130302F2E2D2C2B2A2A
29292929292929292929292929292929
2F3030313233333435363738393B3C3D3E3F404141424344
45464748494A4B4C4D4E4E4F4F5050515152535454555556
56575758585858595958585857575757575757585859595A
5B5C5E5F616365676A71777D83878C8F9291908E8C8A8885
817B746D676059524C47423E3934302C2927262524232222
2223252627282A2B2B2A28272625242425282B2D30333537
383532312F2F2F30343F4B556069727B83878A8E9195999B
9D9D9D9D9C9B9996928A827B736B645D5857565453514F4D
4C4B4A4948484747464442413F3E3D3C3B3A3A3A39393838
383737373636363535343333323231302F2E2D2C2C2B2A29
29292929292929292929292929292929
31323233343535363738393A3C3D3E3F4041424344454647
47484A4A4B4C4D4E4F4F5051515252535354555556565757
575858585859595959595959585858585858585959595A5A
5B5C5D5E5F606264686F777E848A8F94979796959392918E
8A847C756E676058514C47413C37322D2A28262524222121
2123242527292A2C2D2B29282726252526292D303336393C
3C393634323131323743505C68727B858D9195989B9FA2A4
A6A5A4A2A09E9B9791887F766E655D5651505050504F4E4D
4D4C4B4A494948484745444241403E3D3C3C3B3B3A3A3939
38383737373636363535343333323231302F2E2D2C2B2A29
29292929292A2A2A2A2A292929292929
3233343535363738393A3B3C3D3E3F404242434445464748
494A4B4C4D4D4E4F50505151525253535454555556565757
57575858585858585858585858585859595858585859595A
5A5B5B5C5D5E5F61656D757C83898F949898989796969593
8F89817B736C655E58524D47423D37332F2C2B2927262424
242526282A2B2D2E2F2D2C2A29292828292C3033373A3D3F
403D3A38363535363B4755616D77818B93979A9C9FA2A5A7
A7A6A4A19E9B98938D847B72696058514C4C4D4E4F4E4E4E
4E4D4C4B4A4A4A4A49474645434241403F3E3E3D3D3C3B3B
3A3A3A3939393838383737363535353433323130302F2E2D
2D2D2D2D2E2E2E2E2E2E2E2E2E2E2E2E
323334343536363738393A3B3C3E3F404142424344454647
4849494A4B4C4D4D4E4E4F4F4F5050505151525253535354
545454545454555555555555555555555555555556565757
5857575859595A5C60676E757C82878C909090908F8F8E8D
8A85807B75706A645F5B56524E4945413D3A373533312F2D
2D2D2F2F31323334343331302F2F2F2F2F3235383A3D4042
43413F3D3C3C3D3E424D59646E777F888E90929394969898
98979593908E8A86817A726B645D57514D4D4E4F4F4F4F4F
4F4E4D4D4C4C4C4C4B4A4948474645454443434242414140
403F3F3F3E3E3E3E3D3D3D3D3D3D3C3C3C3B3B3A3A393939
393939393A3A3A3A3A3A3A3A3A3A3A3A
333334343536363738393A3B3C3D3E3F4041424343444546
474748494A4A4B4C4C4C4D4D4D4D4D4E4E4E4F4F4F505050
505151515151515151515151525252525252525353545455
55555454555556575A61686E74797E838687878787878786
84817E7A77736F6B6764615D5A5753504C494643403D3B39
373738383939393A3A3937373636363637383B3D3F414345
46454444444445464A545D666F767D848989888888888887
86868483817F7C7975706A65605B56524F4F505151515151
5151504F4E4E4E4E4E4D4D4C4C4B4B4A4A49494848474746
464645454545444444444545454545464645454545454545
45464647474748484848484848484848
3435353636373738393A3B3C3D3E3F404141424344454546
47474849494A4B4B4B4C4C4C4C4C4C4C4C4C4D4D4D4E4E4E
4E4E4F4F4F4F4F4F4F4F4F4F505050505050515152525353
5353525252525354565C62686E73777C7F80808080818281
807F7D7B797674716E6C6A686663615E5B5753504C494643
4141414141414040403F3E3E3D3D3D3D3E3F414244464749
4A4A4A4A4B4C4D4F535A626A71777C82858482807E7D7C7A
797877767573716F6C6864615D5A57545252535354545454
5454535352525252515151515151515050504F4F4E4E4D4D
4D4C4C4C4C4C4C4B4C4C4C4D4D4E4E4F4F4F4F4F50505050
51515253535454545555545454545454
363637373838393A3A3B3C3D3E3F40414242434444454647
474848494A4A4B4B4B4B4B4B4B4B4B4B4B4B4B4C4C4C4C4C
4D4D4D4D4D4D4D4D4D4D4E4E4E4E4E4E4F4F4F5050515252
52515050504F505053585E63686C70757879797A7A7B7C7C
7D7C7C7B7B7A79777675747372706E6C6965615D5955524F
4C4B4B4A49494847474646454545454546474748494A4C4D
4E4F5051535456585B61686D72777B7F817E7B787572706D
6B6B6A6A6967656462605E5C5B5957565556565757575858
585757565656565555565656575757575756565555545454
535353535353535353545555565657585859595A5A5B5B5C
5C5D5E5F5F6061616161616161616161
383839393A3A3B3B3C3D3E3E3F4041424344444546464748
4849494A4A4B4B4B4B4B4B4B4A4A4A4A4A4A4A4B4B4B4B4B
4B4B4B4C4C4C4C4C4C4C4C4C4D4D4D4D4D4E4F4F50505152
52504F4E4E4D4D4D4F545A5E63686C70737475767678797A
7B7C7D7E7E7E7E7E7E7E7D7D7C7B7A7876716C68635F5B57
54535251504F4E4D4C4C4C4B4B4B4C4C4C4D4D4D4E4F5051
525456585A5B5D5F63686D7175797C7F7F7B76726E6A6763
61605F5F5E5C5B5A595858575656565656575758595A5A5B
5B5B5A5A5959595959595A5B5B5C5C5C5C5C5B5B5A5A5A59
59595959595959595A5A5B5C5D5E5E5F6061616263646465
666768696A6A6B6C6C6C6C6C6C6C6C6C
3B3C3C3C3D3D3E3E3F40404142434445464647484849494A
4B4B4B4C4C4D4D4D4D4D4C4C4B4B4B4B4A4B4B4B4B4B4B4C
4C4C4C4C4C4C4C4C4C4C4C4D4D4D4D4D4E4E4F5050515252
52514F4E4D4C4C4C4E52575C6064686C6F70727374767879
7B7D7F80828384858586868686868584827D78736E6A6561
5E5C5B595856555453535352535353545454535454545556
575A5C5F616365686B6E7276797B7E7F7E79746E6965615C
59585857565554535353545455565758595A5B5C5D5E5F60
60605F5F5E5E5E5D5E5F6060616262636362626161606060
5F60606060606061616263646565666768696A6A6B6C6D6E
6F707172737475767777767676767676
40404141414142424344444546474848494A4A4B4C4C4D4D
4E4E4E4F4F4F4F504F4F4E4E4D4D4C4C4C4C4C4C4D4D4D4D
4D4D4D4D4D4D4D4D4D4D4E4E4E4E4E4E4F50505152535354
5452504F4E4D4C4C4D51565A5E6165686B6D6E7072747678
7A7D80838588898B8D8E9090919191918E8A847F7A75716C
6866656362605E5C5B5B5B5B5B5C5C5D5D5C5B5B5B5B5B5C
5D6064676A6C6F717476797B7C7E7F7F7E78716B65605B56
52515150504F4E4E4E50525456585A5C5E5F606162646566
66666565646464646465666769696A6B6B6A6A6968686867
6768686869696A6A6B6B6C6D6E6E6F707172727374757677
787A7B7C7E7F80818282828181818181
49494949494A4A4A4B4B4C4D4D4E4F4F5051515252535354
545455555555555555545453525251515151515152525252
525252525252525252525252535353535354555656575858
58565453525150505154585B5F6265696C6D6F717375787A
7D8084878A8D8F92949698999A9B9B9B99958F8A85817C78
7472706F6D6B696766666666666767676866656564646465
666A6E7175777A7C7F80828283848484817B746E68625D58
54535353535251525255585A5D60626567696A6B6C6D6F70
70706F6F6E6E6D6D6D6F7072737474757675747372727171
717273747575767777777878787879797A7A7B7B7C7C7D7E
7F81838587888A8B8C8C8B8B8B8B8B8B
5B5A5A5A5A5A5A5A5A5A5B5C5C5D5D5E5E5F5F5F60606061
61616161616161616160605F5F5E5E5E5D5E5E5E5F5F5F5F
5F5F5F5F5E5E5E5E5E5E5E5F5F5F5F5F6060616161626263
62615F5E5C5C5B5B5C5F6265686B6E717476797B7D808385
888A8D8F929496989A9C9E9FA0A1A2A2A19D9894908C8885
81807F7E7C7B797877777676767677777776757474737474
75797D808487898C8E8F9090909191918F8A85807B76726E
6B6A6A6A6A6969696A6C6E70727477797B7C7D7D7E808181
82818180807F7F7F7F80818384848586868583828180807F
7F81848587888A8B8B8A8987868585848383828281818181
828487898C8E90929392929191919191
6E6D6C6C6C6B6B6B6A6B6B6C6C6C6C6D6D6D6E6E6E6E6F6F
6F6F6F6F6E6E6E6E6E6D6D6D6C6C6C6B6B6C6C6D6D6D6E6E
6E6D6D6C6C6C6C6B6B6B6C6C6C6C6D6D6D6D6D6D6D6E6E6E
6E6C6B6A69686867686B6D707376787B7E808386898B8E91
939597989A9B9D9E9FA1A3A5A6A7A8A8A7A4A19D9A979492
8F8E8E8D8C8B8A8988888787878787878786858484838384
85898C909396999B9D9E9E9E9E9F9F9F9D9A96938F8C8986
848484848483838383858688898B8C8E8F90919192939494
9494939392929191919293949596969797959392908F8E8E
8E9195979A9C9EA0A09D9A979493918E8C8B898886858383
83868A8D909395989999989796979797
7F7E7D7C7C7B7A7A7A7A7A7A7B7B7B7B7B7B7B7C7C7C7C7C
7C7C7C7B7B7B7B7A7A7A7979797878787878797A7A7B7B7B
7B7B7A797979787878787878797979797979797979797979
78777675747473737476797B7D7F8284878A8D909396999C
9E9FA0A1A1A2A3A4A5A7A9AAACADAEAEAEABA9A7A4A2A09E
9C9C9C9B9B9A999998979796969695959594939392929292
93979B9EA1A4A7A9ABABABABABABABABAAA8A5A3A19F9D9B
9A9A9A9A9A999999999A9B9C9D9E9FA1A1A2A2A3A3A4A4A5
A5A4A4A3A3A2A2A2A2A2A3A4A5A5A6A6A6A4A1A09E9D9C9B
9BA0A4A8ABAEB0B2B2AEAAA5A19E9B9895928F8D8B888685
85888D9094989A9E9F9E9D9C9B9C9C9C
908F8E8D8C8B8A8989898989898989898989898989898A8A
898989888888878787868686858585858585868787888889
898887878686858584858585858585858585858584848484
838382818080808080828486888A8C8E9094979A9EA1A4A7
A9A9A9A9A9A9AAAAABADAFB0B2B3B4B4B4B3B1B0AEADACAA
A9A9A9A9A9A9A9A8A8A7A6A6A5A5A4A4A3A2A1A1A1A0A0A0
A2A5A9ACAFB2B5B7B9B9B8B7B7B7B7B6B6B5B4B4B3B2B1B0
B0B0B0B0B0AFAFAFB0B0B1B1B2B2B3B3B4B4B4B5B5B5B5B5
B5B5B4B4B3B3B2B2B2B2B3B4B4B5B5B5B5B2B0AEACAAA9A8
A9AEB3B8BCC0C2C5C5BFB9B4AEAAA6A19D9995928F8B8886
868A8F94989C9FA3A5A4A2A1A0A1A2A1
9F9E9C9B9A99989796969696969696969696969695959595
95959493939392929191919090908F8F9090919293939494
94949392919190908F8F909090909090908F8F8F8E8E8E8D
8D8C8C8B8B8A8A8A8B8C8D8E90919395979B9EA2A5A9ACAF
B1B0B0B0AFAFB0B0B0B3B5B7B8BABBBCBCBBBABAB9B8B8B7
B7B7B7B7B8B8B7B7B7B6B5B4B3B3B2B2B1B0AFAEAEADADAD
AEB2B6B9BDBFC2C5C6C5C4C3C1C1C1C0BFC0C0C0C0C0C0C0
C0C0C0C1C1C1C1C1C2C2C3C3C4C4C4C5C5C5C5C5C5C5C5C5
C5C4C4C3C2C2C1C1C1C1C2C2C3C3C3C3C3C0BDBBB9B7B5B4
B5BBC2C7CCD1D4D6D6D0C8C1BAB5B0ABA5A09C98948F8C89
898E94999EA2A6AAADABA9A8A7A7A8A8
ADACAAA9A7A6A5A4A3A3A3A3A3A2A2A2A2A2A1A1A1A1A1A1
A0A09F9F9E9D9D9C9C9B9B9B9A9A9A9A9A9B9C9D9D9E9F9F
A09F9E9D9C9C9B9A9A9A9A9A9A9A9A9A9A99999898979797
96969695959595959596979898999A9C9EA2A6AAADB1B4B7
B9B8B7B6B6B6B6B6B6B8BBBDBFC0C1C2C3C3C3C3C3C3C3C3
C3C3C4C4C5C5C5C5C5C4C2C1C0C0BFBEBDBCBBBBBAB9B9B9
BABEC1C5C8CBCED0D2D0CECCCACAC9C8C8C9CACBCCCDCDCE
CECFCFCFD0D0D1D1D2D2D2D3D3D4D4D4D4D4D4D4D3D3D3D2
D2D1D1D0D0CFCFCECECECFCFCFD0D0D0CFCCC9C7C4C2C0BF
C0C7CFD5DBDFE3E6E5DED5CDC5BFB9B3ACA7A19D98938E8B
8B90979CA2A7ABB0B3B1AFADACADAEAD
BBB9B7B6B4B3B1B0AFAFAFAFAFAFAEAEAEAEAEADADADADAD
ACACABAAA9A9A8A8A7A7A6A6A5A5A4A4A5A6A7A8A9AAAAAB
ABAAAAA9A8A7A7A6A6A6A6A5A5A5A5A4A4A3A3A2A2A2A1A1
A1A0A0A0A0A1A1A1A1A1A2A2A3A3A4A5A7ABAFB3B6BABDC0
C1C0BFBEBDBCBCBBBCBEC0C2C4C5C7C8C9CACACBCBCCCDCD
CECFD0D0D1D1D2D2D1D0CFCECCCCCBCAC9C8C7C6C5C4C4C4
C5C8CCCFD3D6D8DBDCD9D7D5D3D2D1D0D0D2D4D6D8DADBDC
DEDEDFDFDFE0E1E1E2E2E2E2E3E3E3E3E2E2E1E1E0E0DFDF
DEDEDDDDDCDCDBDADADBDBDBDBDBDBDBDAD7D4D1CECCCAC9
CAD2DAE1E7EDF0F4F3EBE1D8CFC8C1B9B2ABA5A09B948F8C
8B91989EA5AAAFB4B7B6B3B1B0B1B2B2
C4C2C0BFBDBCBBBAB9B9B9B9B9B8B8B8B8B8B8B8B8B8B8B8
B7B7B6B5B4B3B3B2B1B1B0AFAEAEADADADAEB0B1B2B3B4B5
B5B4B4B3B2B2B2B1B0B0AFAFAEAEADADACACABABABAAAAAA
AAAAABABABACACADADADADADADADAEAEB0B4B8BBBFC2C5C7
C9C8C6C5C3C3C2C2C2C4C6C7C9CACBCDCECFD0D1D2D4D5D6
D7D7D8D9D9DADADADAD9D7D6D5D3D2D1D0CFCECDCDCCCBCB
CCCFD3D6D9DCDEE0E1DEDCDAD7D6D5D4D4D7DADCDFE1E2E4
E6E6E7E8E8E9EAEAEBEBEBEBEBEBEBEBEAE9E9E8E7E7E6E5
E5E4E4E3E3E2E2E2E1E1E2E2E2E2E2E2E0DDD9D7D4D1CFCE
CFD8E1E8EFF4F8FCFBF2E7DDD3CCC5BCB4ADA6A09A938E8A
8990989EA6ABB1B7BAB8B5B3B2B3B4B3
C3C2C1C0BFBEBDBCBCBCBCBDBDBDBDBDBEBEBFBFBFC0C0C0
C0BFBEBEBDBCBCBBBAB8B7B5B4B3B2B1B1B2B4B5B7B8B9BA
BABABABABABABABAB9B8B7B5B4B3B2B1B0B0B0B0B1B1B1B1
B2B3B4B5B6B7B8B9B9B9B8B8B8B8B9B9BABDC1C4C6C9CBCD
CECDCCCBCACAC9C9C9CACBCCCDCECFD0D1D2D3D5D6D7D8D9
D9DADADBDBDBDBDBDAD9D7D6D4D3D1D0CFCECDCDCCCBCBCA
CBCED0D3D5D8D9DBDCDAD7D5D3D2D1D0D0D2D5D7D9DBDCDE
DFE0E0E1E1E2E3E3E4E4E4E4E4E4E4E4E4E3E2E2E1E0E0DF
DEDEDEDEDEDEDDDDDDDDDDDDDDDDDDDDDBD8D4D2CFCCCAC9
CBD3DCE3EAEFF3F6F6ECE2D8CEC6BFB6AEA7A09A948D8783
838A939AA2A8AEB4B8B6B3B1AFB0B1B1
C1C0C0BFBFBEBEBDBDBEBFC0C0C1C1C2C3C4C4C5C6C7C7C8
C8C7C7C6C5C4C4C3C1BFBDBBB9B7B6B5B4B6B7B9BBBCBDBE
BFC0C1C1C1C2C3C3C2C0BDBBB9B7B5B4B3B4B4B5B6B7B7B8
B9BBBCBEBFC1C3C4C5C4C4C4C4C4C4C4C5C7CACCCECFD1D2
D3D3D2D1D1D0D0D0D0D0D1D1D1D2D2D2D3D4D6D7D8D9DADB
DBDBDBDBDBDBDADAD9D7D5D4D2D1CFCECCCCCBCACAC9C9C8
C9CBCDCED0D2D3D5D5D3D1CFCECDCCCBCBCDCFD0D2D3D4D6
D7D7D8D8D8D9DADADBDBDBDCDCDCDCDCDCDBDAD9D9D8D7D7
D6D7D7D7D7D7D7D7D7D7D7D7D6D7D7D6D5D2CECBC9C6C4C3
C4CCD5DCE3E8ECEFEEE5DAD1C7BFB8B0A7A099938D85807C
7C848D959DA4AAB1B5B3B0AEACADAEAE
C0C0BFBFBFBFBFBFC0C1C2C3C4C5C5C6C8C9CACBCCCDCECF
CFCFCECECDCCCCCAC9C6C3C1BEBCBAB8B7B9BBBDBFC0C1C3
C4C5C6C7C8CACACBCAC7C4C1BEBBB9B7B6B7B9BABCBCBDBF
C0C2C5C7C9CBCDCFD0CFCFCECECECECECFD0D2D3D5D6D6D7
D8D8D7D7D7D6D6D6D6D6D5D5D5D5D5D5D5D6D8D9DADBDCDD
DDDDDCDCDBDBDAD9D8D6D5D3D1CFCECCCBCAC9C9C8C8C7C7
C7C9CACBCCCDCECFCFCECCCBC9C8C8C7C7C8CACBCCCDCECF
D0D0D1D1D1D2D2D3D3D4D4D5D5D5D5D5D5D4D4D3D2D1D1D0
D0D0D1D1D2D2D2D2D2D2D2D2D1D1D1D1D0CCC9C6C3C1BFBD
BFC7CFD6DDE2E6E9E8DFD5CBC1BAB2AAA29A938C867F7975
757E889099A1A7AEB2B0ADABA9AAABAB
BEBFBFBFBFC0C0C1C2C3C4C6C7C8C9CBCCCED0D1D3D4D5D6
D7D6D6D5D4D4D3D2D0CDC9C6C3C0BEBBBABCBFC1C3C4C5C7
C9CBCCCECFD1D2D3D2CECAC6C2BFBDBAB9BBBDBFC1C2C3C5
C7CACDCFD2D5D7D9DBDADAD9D9D9D8D8D8D9DADBDBDCDCDC
DDDDDDDCDCDCDCDCDCDBDAD9D8D8D7D7D7D8DADBDCDDDEDF
DFDEDDDCDBDBDAD9D7D5D3D1CFCDCCCAC8C8C7C7C7C6C6C5
C5C6C7C7C8C8C9C9C9C8C7C6C5C4C3C2C2C3C4C5C6C7C8C8
C9C9CACACACBCBCBCCCCCDCDCECECECECECDCCCCCBCACAC9
C9CACACBCCCCCCCDCDCDCCCCCCCCCCCBCAC6C3C1BEBBB9B8
B9C1C9D0D7DCE0E3E2D9CEC4BAB3ACA39B938C867F78726F
6F78828B959DA4ABB0ADAAA8A6A7A8A8
BFC0C1C1C2C2C3C4C5C7C8CACCCDCFD1D2D4D7D8DADCDDDE
DFDFDEDEDDDCDCDAD8D4D0CDC9C6C3C0BFC1C4C6C8CACBCD
CFD1D3D5D7D9DBDCDBD6D1CDC8C5C2BFBDBFC2C5C7C9CACD
CFD2D6D9DCDFE2E5E6E6E5E4E4E4E3E3E2E3E3E3E3E3E2E2
E2E2E2E2E2E2E2E2E1E0DEDDDCDAD9D8D8DADCDDDFE0E1E1
E2E1DFDEDDDCDBDAD8D6D4D2D0CDCBCAC8C8C7C7C7C6C6C6
C5C5C5C5C5C6C6C6C6C5C3C3C2C1C1C0C0C1C2C3C4C4C5C6
C7C7C7C7C8C8C8C9C9C9CACACBCBCBCBCBCAC9C8C7C6C6C5
C5C6C7C8C9C9CACACACACAC9C9C9C8C8C6C3C0BDBBB8B6B4
B6BEC6CDD3D9DCE0DFD5CAC0B6AFA79F968E878079726C68
68727D879199A1A9ADABA7A5A3A4A5A5
C0C1C2C3C4C5C6C7C9CACCCED0D2D4D6D8DADDDFE1E3E4E6
E6E6E6E5E4E4E3E2E0DBD6D2CECBC7C4C3C5C8CACDCED0D2
D4D7DADCDEE1E3E4E3DED8D3CECAC6C3C1C4C7CACDCED0D3
D6DADEE1E5E8ECEFF1F0EFEFEEEDEDECEBEBEBEAEAE9E8E8
E7E7E8E8E8E8E7E7E6E4E2E0DEDCDBDADADBDEDFE1E2E3E4
E4E3E1E0DEDDDCDBD9D7D4D2D0CDCBC9C8C7C7C7C7C6C6C6
C5C5C4C4C3C3C3C2C2C1C0C0BFBFBEBEBEBFC0C1C2C2C3C4
C4C5C5C5C5C6C6C6C6C7C7C7C8C8C8C8C8C7C5C5C4C3C2C1
C1C2C4C5C6C6C7C8C8C8C7C7C6C6C6C5C3C0BDBAB7B5B2B1
B3BBC3CAD0D6D9DCDBD2C7BDB2ABA39B928A827B746C6662
636D78838D969EA6ABA8A5A2A0A1A3A2
BFC1C2C3C5C6C7C9CACCCFD1D3D5D7D9DCDEE1E4E6E8EAEC
EDEDECEBEBEAE9E8E6E1DBD7D2CECBC7C6C8CBCED0D2D4D6
D9DCDFE1E4E7E9EBEAE4DDD7D2CDC9C5C4C7CACED1D3D5D9
DCE0E4E8ECF0F4F8FAF9F8F7F6F6F5F4F4F3F2F1F0EEEDEC
EBEBECECECECECECEBE8E5E3E0DEDDDBDADCDFE0E2E3E4E5
E5E4E2E0DFDDDCDAD8D6D3D1CFCCCAC8C6C6C6C6C6C5C5C5
C4C3C2C1C0BFBFBEBDBDBCBCBCBBBBBBBBBCBCBDBEBEBFC0
C0C0C1C1C1C1C1C2C2C2C3C3C3C3C3C3C3C2C1C0BFBEBDBC
BCBEBFC0C2C2C3C4C4C4C3C2C2C2C1C1BFBCB8B6B3B0AEAD
AEB6BFC5CCD1D5D8D7CDC2B8AEA69E968D847C756E67615D
5D68747E89929BA3A8A6A29F9D9FA09F
BFC1C2C4C5C7C8CACCCED0D3D5D7DADCDEE1E4E7EAECEEEF
F1F1F0F0EFEEEEECE9E4DFDAD5D1CDCAC8CACDD0D3D4D6D9
DBDFE2E5E8EBEEEFEEE8E1DAD4D0CCC8C6C9CDD0D4D6D9DC
E0E4E9EDF1F6FAFDFFFFFEFDFCFCFBFAF9F7F6F5F4F2F0EF
EEEEEFEFEFEFEFEFEEEAE7E5E2DFDEDCDBDDDFE1E3E4E5E6
E6E5E3E1DFDEDCDAD8D6D3D1CECCC9C7C6C5C6C5C5C5C4C4
C4C2C1BFBEBDBCBBBBBABABABABAB9B9BABABBBBBCBCBDBE
BEBEBEBFBFBFBFBFC0C0C0C0C1C1C1C1C0BFBEBDBCBBBAB9
B9BBBDBEBFC0C1C2C2C2C1C0C0C0BFBEBDBAB6B4B1AEACAB
ACB4BCC3C9CFD2D5D4CBBFB5ABA39C938A8179726B635D59
5A65717C879099A2A7A4A09E9B9D9E9E
C1C2C4C5C6C8C9CBCDCFD1D3D6D8DADCDFE2E4E7E9ECEEEF
F0F0F0EFEEEEEDECE9E4DFDAD5D1CDCAC8CBCED0D3D5D6D9
DBDFE2E5E7EBEDEEEEE7E0DAD4D0CCC8C6C9CDD0D4D6D8DC
DFE4E8ECF0F5F9FCFEFEFDFCFBFAFAF8F7F6F5F4F3F1F0EE
EDEEEEEFEFEFEEEEEDEAE7E5E2E0DEDCDCDEE0E2E4E5E6E7
E7E6E4E2E0DFDEDCDAD7D5D2D0CDCBC9C7C7C7C7C7C6C6C6
C5C4C2C1C0BFBFBEBDBDBCBCBCBBBBBBBBBCBDBDBEBFBFC0
C0C1C1C1C1C1C2C2C2C3C3C3C3C3C3C3C3C2C1C0BEBDBDBC
BCBDBFC0C2C3C3C4C5C4C3C3C2C2C1C1BFBCB8B6B3B0AEAD
AEB6BFC5CCD1D5D8D7CDC2B8ADA69E958C837B746D655F5B
5B66737D89929AA3A8A6A29F9D9EA09F
C2C4C5C6C7C9CACBCDCFD1D3D6D8DADCDEE1E4E6E9EBECEE
EFEFEFEEEDEDECEAE8E3DED9D5D0CDCAC8CACDD0D3D4D6D8
DBDEE1E4E6E9ECEDECE6DFDAD4CFCBC8C6C9CCD0D3D5D7DB
DEE2E6EAEEF3F6FAFCFBFAF9F8F8F7F6F5F4F3F2F1F0EFEE
EDEDEDEEEEEEEDEDECE9E7E4E2E0DEDDDCDEE1E3E4E6E7E8
E8E7E5E3E1E0DFDDDBD9D6D4D1CFCDCBC9C9C9C8C8C8C7C7
C7C5C4C3C2C2C1C0C0BFBFBEBEBDBDBDBDBEBFBFC0C1C2C2
C3C3C4C4C4C4C5C5C5C5C6C6C6C6C6C6C6C5C4C3C2C1C0BF
BFC0C2C3C4C5C6C7C7C7C6C5C5C4C4C3C2BEBBB8B6B3B1AF
B1B9C1C8CFD4D8DBDAD0C5BAB0A8A0978F867E767067615D
5E68757F8A949CA5AAA7A3A19EA0A1A1
C4C5C6C7C8C9CACCCECFD2D4D6D8DADCDEE1E3E6E8EAECED
EEEEEEEDECECEBE9E7E2DDD9D4D0CDCAC8CACDD0D3D4D6D8
DBDEE1E3E5E8EBECEBE5DFD9D3CFCBC8C6C9CCCFD3D5D7DA
DDE1E5E9EDF1F5F8FAFAF8F8F6F6F5F4F3F3F2F1F0EFEEED
ECEDEDEDEDEDEDECEBE9E6E4E2E0DEDDDCDFE1E3E5E6E7E8
E9E7E5E4E2E1E0DEDCDAD7D5D3D0CECCCACACACAC9C9C9C8
C8C7C6C5C4C4C3C2C2C1C0C0BFBFBEBEBEBFC0C1C2C3C4C4
C5C5C6C6C6C7C7C7C7C8C8C8C8C9C9C9C8C7C6C5C4C3C2C1
C1C3C4C5C6C7C8C9C9C9C8C7C7C6C6C5C4C0BDBAB8B5B3B1
B3BBC3CAD1D6DADDDCD2C7BDB2AAA29990887F787169635F
5F6A76818C959DA6ABA8A4A2A0A1A2A2
C4C5C6C7C9CACBCCCED0D2D4D6D8D9DCDEE0E3E5E7E9EBED
EDEDEDECEBEBEAE9E6E1DDD8D4D0CCC9C8CACDD0D2D4D5D8
DADDE0E2E5E8EAEBEAE4DED9D3CFCBC7C6C8CCCFD2D4D6D9
DCE0E4E8ECF0F4F7F9F8F7F6F5F4F4F3F2F1F1F0F0EEEDEC
ECECECECECECECECEBE8E6E4E2E0DEDDDDDFE1E3E5E6E7E8
E9E8E6E4E3E2E1DFDDDBD8D6D4D1CFCDCBCBCBCBCACAC9C9
C9C8C7C6C5C5C5C4C3C3C2C1C1C0C0BFBFC0C1C2C3C4C5C6
C7C7C7C8C8C8C9C9C9CACACACACBCBCBCAC9C8C7C6C5C4C3
C3C4C6C7C8C9C9CACACAC9C9C8C8C8C7C5C2BFBCB9B6B4B3
B4BCC5CCD3D8DCDFDED4C9BEB4ACA49B9289817A736B6460
616B77828D969EA7ACA9A5A3A0A2A3A3
C4C5C6C7C9CACBCCCED0D2D4D6D8DADCDEE1E4E6E8EAECED
EEEEEEEDECECEBE9E7E2DDD9D4D0CDCAC8CBCDD0D3D4D6D8
DBDEE1E3E6E8EBECEBE5DFD9D4CFCBC8C6C9CCCFD3D5D7DA
DDE1E5E9EDF1F5F8FAF9F8F7F6F6F5F4F3F3F2F1F0EFEEED
ECEDEDEDEDEDEDECEBE9E6E4E2E0DEDDDDDFE1E3E5E6E7E9
E9E8E6E4E3E2E1DFDDDBD8D6D3D1CECCCBCBCACACACAC9C9
C8C7C6C6C5C4C4C3C3C2C1C0C0BFBFBFBFC0C1C2C3C4C4C5
C6C6C6C7C7C7C8C8C8C9C9C9C9CACACAC9C8C7C6C5C4C3C2
C2C3C5C6C7C8C9C9CAC9C9C8C7C7C7C6C5C1BEBBB8B5B3B2
B3BBC4CBD2D7DBDEDDD3C8BDB3ABA39A91888079726A635F
606A76818C959EA6ABA9A5A2A0A1A3A2
C4C5C6C7C8CACBCCCED0D2D4D6D8DADCDFE1E4E6E9EBEDEE
EFEFEEEEEDEDECEAE8E3DED9D5D1CDCAC9CBCED0D3D5D6D9
DBDEE1E4E6E9EBEDECE6DFDAD4D0CCC8C6C9CDD0D3D5D7DA
DEE2E6EAEEF2F6F9FBFBF9F8F7F7F6F5F4F4F3F2F1F0EFEE
EDEDEDEDEDEDEDEDECE9E7E4E2E0DFDDDDDFE1E3E5E6E7E9
E9E8E6E4E3E2E0DFDDDAD8D5D3D0CECCCACACACACAC9C9C8
C8C7C6C5C4C4C3C2C2C1C0C0BFBFBEBEBEBFC0C1C2C3C4C4
C5C5C6C6C6C7C7C7C7C8C8C8C8C9C9C9C8C7C6C5C4C3C2C1
C1C2C4C5C6C7C8C9C9C9C8C7C7C6C6C5C4C0BDBAB8B5B2B1
B3BBC3CAD1D6DADDDCD2C7BCB2AAA29990877F787169635E
5F6A76808C959DA6ABA8A4A29FA1A2A2
C4C5C6C7C9CACBCCCED0D2D4D6D8DADCDFE1E4E6E9EBECEE
EFEFEEEEEDECEBEAE8E3DED9D5D1CDCAC9CBCED0D3D5D6D9
DBDEE1E4E6E9EBEDECE6DFDAD4D0CCC8C6C9CDD0D3D5D7DA
DEE2E6EAEEF2F6F9FBFAF9F8F7F7F6F5F4F3F3F2F1F0EEED
EDEDEDEDEDEDEDEDECE9E7E4E2E0DFDDDDDFE1E3E5E6E7E9
E9E8E6E4E3E2E0DFDDDAD8D5D3D1CECCCBCACACACAC9C9C9
C8C7C6C5C4C4C3C3C2C1C1C0BFBFBFBEBEBFC0C1C2C3C4C5
C5C6C6C6C6C7C7C7C8C8C8C9C9C9C9C9C9C7C6C5C4C3C2C2
C1C3C4C5C7C7C8C9C9C9C8C7C7C7C6C6C4C1BDBBB8B5B3B1
B3BBC4CBD1D7DADEDDD3C7BDB2AAA29990887F787169635F
5F6A76818C959DA6ABA8A5A2A0A1A2A2
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "Similarly, the details can be obtained by keeping the appropriate detail \
coefficients and doing the inverse transform. Here we get ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(d\_5\%\((I)\)\) \((x, y)\) + \(d\_5\%\((I  I)\)\) \((x, y)\) + 
        \(d\_5\%\((I  I  I)\)\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  ". We can also get, say, ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_5\%\((I)\)\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " by keeping only the coefficients at position ",
  Cell[BoxData[
      \(TraditionalForm\`{2, 1}\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " of ",
  StyleBox["wtdata", "MR"],
  " and setting the rest to zero."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.20"}],

Cell["\<\
InverseWaveletTransform[
wtdata-MapAt[#-#&, wtdata, {2}], s4,
BoundaryCondition -> Fixed];\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
This is the density plot of the details at the coarsest level.\
\>",
   "MathCaption",
  CellTags->{"S2.2.1", "1.21"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[%, Mesh -> False]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -6 -9 ]
[.20703 -0.0125 6 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -12 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(50)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(100)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(150)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(200)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(250)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(50)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(100)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(150)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(200)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(250)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
02366C95BBCFDCEBE7BA8B634A637D8A9071544340668EA9
B9A893897A6554444782BAE4F4B97B51313A494C576D8399
A69D928C858687848179726D6B72797E84888C8F8E837870
6A6E73757A828A9195938F8D86756559587491A6B4AB9F99
90867D736D757E8488858282807F7E7D7C7E7F7F7E79736E
6A6A6967645F5A5652504D4B4944424246505C6B7E99B6CF
EDFFFFFFFFFFCA8E5D5A5D55555E697785939FABAFA29488
7F7F7F7D7C7B7A7A7A797877787A7C7E7F7F7E7D7D7C7B7B
7D858C92948A8079788898A2A69481746B7076787B7D7E80
817D7A7776797C7F818385878885827F7C7B797775716D6B
6B6F757A7D7D7D7F838E99A2A8A7A5A6
2B5F91B7D0BDA597846D58433E6890AFBD9771594B647E8D
98959090886D5642427BB2D9EBB8835F434953535B6F8396
A2998E88838484827F78726D6B71777B81899095968B7F76
6F70727274777B7F848B919695847468626F7D878E8C8888
86817C77757B8286898683817F7D7B79797D808384827F7E
7D7E7F7F7F7D7B7A78777573727170707073767A7E848A90
97A1A9B0B1A395897E78736D6C737C828887868685848381
80808181817F7D7B7A7C7D7E7E7E7E7E7E7E7E7E7E7E7E7E
7F808182817C78747583909A9D8E7F746C7176787C7E8184
86817D7A787B7D7E7F808081807E7C7A797B7C7D7D7D7C7C
7C7D7D7E7E7B79777981899095939192
5185B5D8E4AD724927232722316AA2D1E9BD8F7159636F70
76818B96967558423F75A9CEE0B68A6D55575D5A5F718293
9D948B85808182817E78716D6B6F75797F8A949C9F93867C
7371706E6D6C6D6E7484939FA49382756B6A6A68696E7378
7C7C7C7C7E828588898683817E7B7876767B81868A8B8B8D
8F929597999B9C9D9E9D9D9C9B9C9D9C99948D867C6E5F52
442E1C0E103963859D93878380878E8F8C7D6E635E67737A
8182838586827F7C7A7E818485827F7D7C7D7E7E7F808181
817C777370707070737F899195897D746E7277797C808488
8A85817D7B7C7E7E7E7C7B7A79777676777A7E8285888B8D
8E8A85827D78736F6E747A7F83828081
6EA2D0F1F4A04B0E0000020A276CAEE9FFDAA6856664645B
5B72879AA07C5A433E70A2C4D6B48F786463656063728290
989188837E8081807D77716D6B6E73767D8B97A1A5998B81
77726F6A66636262688096A7AF9F8D8071665C514D57636D
76797B8084868889888683807D797674747B82888E919397
9B9FA3A7AAAFB2B6B8B8B8B7B7BBBDBCB8AD9F907C5F4126
0700000000003E82B4A794928D959B9990765D4A40526674
818383888985807C7A8085888985807D7A7C7E7E7F818384
82786F6864676B6D727B838B8E857B75707377797C81868A
8C8883807D7E7E7E7D7A777674737373757B81868B919699
9A938B847C76706A676B707376757474
76AFE0FFFF9E3A00000000001765B1F4FFF0BE9E7C6B5D48
42618098A4815F4A44709BB8C8AE9180706C6B666674818D
948D85817D7F81807E77706C6A6D71747B8B9AA5AB9E9085
79726B635E5B5B5B64809AAFBAA89283716051413A485966
73787D84898A8A8A8886827F7C7773717179828A91969AA0
A6ABB1B6BCC2C8CED1D3D3D2D2D5D5D2C9B7A18A6E492303
0000000000003082BFAE97928C9AA5A59B79573D2F466071
8184858B8D87827D7A81878B8C86807B787A7C7D7E818284
82776C645F646A6D72797F8487817A767375787A7D82878B
8D8985827F7F7F7D7B7773706E6D6D6E7179818990989FA4
A59B8F867C726A625E646B7175737172
4089CBFBFFBB672C00000000004597DCFFF3D4C4A9856340
2E4D6D84937E6A605F7C99ABB5A18B7D706D6C686975808A
918C86828082848482786F6965696F737B8B99A5AA9F9187
7B6D615650555E64718DA6BAC2A688725D544E4544526270
7C8184898D8E8E8D8B86827D78736E6B6C757F8891979DA5
ADB5BEC6CED7DEE4E9EDEEECE8DFD3C6B2917051351E0B00
000000000B3A678FA891796B6686A4B6BA95705646586C78
8386888D8F89837E7B80858888827C777475767778797B7D
7D7A777573747676787B7E81827F7C7A797A7C7C7E818486
8886848280807F7D7A746E696562616164707D88929CA4AA
ACA1958A7D6C5D504C61788996918C8E
0B62B3EFFFD7986E3F16000000277CBFF4F0E4E5D29E6B3C
203D5D71827B74767A88969FA2948479706D6D6A6C767F88
8E8A86848285888885796E6561666E737B8B99A5AA9F9289
7B69584943516370819AB0C3C7A37D614A4B4F4E525F6D7B
87898A8D8F90908E8B86807B76706B6868717C8690969DA5
AEB9C4CED8E1EAF0F5FAFCFAF2E0C9B3976C421F04000000
0E3E6F99B6AEA09C8E7259423E6FA0C3D6B18A72616C797E
8387898E908A847F7C7F8384847E78747171717172737476
787D82868885817F7D7E7F7F7F7E7E7E7E7E7F7F7F808182
8282828281807F7D79726A645F5B58575B697986939DA5AC
AEA3968C7D665342406286A2B6AFA7AA
0048A4E8FFEAB89A6E310000001069ACE4F0F3FFF4B27037
132F5063767A7D888F9293939088807872706F6D6F777E85
8A88868484878A8B887A6D635D646C727B8B99A5ABA1948A
7C65503F384D65778CA4B8CBCCA277563D444F525B677483
8E8F8F909091908E8B857F7A756E6965656F7A838E959CA6
B0BCC8D4DFEAF4FBFFFFFFFFFDE3C5A98552220000000000
1F72C1FFFFFDC8A57E5E4325215F9ECEEBC59D8672798281
84878B8F918B84807C7F8282817C76726E6E6E6D6E6E6F71
757F899296908A85817F7E7B7A7D7F8183828181807F7F7E
7E7F818282817F7C787068615B56525054647684939EA7AF
B1A6998E7E624B3836628FB3CDC4BABE
003895DAFFF4D3C29D55130000095790C5DFF0FFFFBE763B
142E4E5E707B84939B958E88827F7C777472717172787D83
8686858585898C8D8A7B6C615B636C727C8C9BA7ACA19389
79604A37314C6B8299ADBDCCCBA074513946565E6974808D
9694918F8D8C8B8885817D7A76716D6A6B727A81898D9299
A0AAB3BCC5CFD7DEE3E6E7E4DAC4AA9274461D0000000F23
4FB1FFFFFFFFE1A76C492E0B074D94CDF1D0AB9886878881
7F84898D8F89827E7B7D7F807F7B7773716F6F6E6E6D6E6F
7482909AA0988E88827F7D7A797C8184868482817F7E7C7A
7A7C7F8182807F7D7A736D68635D59565968788591999FA4
A4998C82745F4E41446F9CC0DBD2C8CC
0C4F91C3E8E1D3CDB7845328102D4F6582A6C4E3E9B37B51
364E6977848483888A8783807D7C7B7A7977767676797C7F
8283838485888A8B897B6E645E666F768091A0ACB1A18F81
705A473634547791A9B2B7BFBB9A7A5F4E5B6B747F89929C
A0988E867F7C79767476787B7D7F8284858584837F79716B
64615D59565554535149413D3D4A58646E6C6B6F76889CAB
C4F5FFFFFFFFC4905D391D00003978ABD0BEA9A1958C8376
6E767E83867F787472767B7D80808182827F7D7B7A797979
7C868F969990867F797A7B7B7C7E818485827F7D7B7A7A79
787A7C7D7F7F7F7F808386888985817E7E848A8E8E867C75
6C60574F4F5F718193A2B1C1CBC9C7C8
43698FACC4CBCED2CBAF91775F524A40456F98B9C9A68169
5A6F858F978C817C78797A797A7B7C7D7D7C7B7A7A7A7B7C
7D80828485888989877A6F66626972798395A5B2B5A18B7A
67544638385C829FB6B4B0B0AA95816F6573828B959CA2A8
A899897C706B6762626A747C858E969C9E968C827563513E
2B1A0A00000000000000000000000D3B6A91B7DFFFFFFFFF
FFFFFFFFFFD3A47A522F130000295E89ABAAA4A8A2907D6A
5E6873797D766F6C6B71777B80868B8F928F8B8986858483
83888D9191877D7671757A7C7F81828384807C7977777777
7778797A7C7D7F8187939FA8AEACA9A6A29F9B9489725B49
392D26222D6094BFDDD1C2BDB7BCC1C0
67778795A6BCD0E0E7D8C5B59B6D431F11417398B19D877E
788998A0A19181756C6F737476787B7E807F7E7D7D7B7B7A
7A7E818486878888857A7068646C757B8598A8B6B9A18773
605045393D648CACC2B7AAA49A8F84797583939EA8ADB0B3
AF9C877667605B555662707D8A98A4AEB0A493836E553A1E
0100000000000000000000000000001561A9EDFFFFFFFFFF
FFFFFFFFDFB9936B47250A00001B486E8F9CA4B1B1967A62
525E6B71766E6765666C7379808992999E9A96928F8E8C8A
888B8D8F8D8277706B72797E82838284837F7B7774757576
767676787A7B7E828A9EB1C0CBCAC6C2BBB2A69884624127
110501001562AEEDFFF5D0BBAAB4BEBB
888584858DABC7DCEAE8DFD8C2844A1A012C5B7B96918B8E
929BA2A6A39381746A6D727376787B7E818080807F7C7977
777B808486878787847A7069666D767C8699AAB7BA9F836D
594E463D43698FAEC2B3A1988F8D8C878896A4AEB6B6B4B2
AA947E6B5A504A4446596E8093A2AFB9BAA790795E432707
0000000000000000000000000000000A5FB6FFFFFFFFFFFF
FFFFFFE5AD97846951301605011E3F5B778DA0B4B899785E
4D59686E736C6564656C747B828C949CA19E9A9794928F8C
8A8B8B8B897E736C6870797F83838282817D787471727373
74747476787A7F838EA6BED1DEDEDBD7CDBBA6907654341A
050000001569BBFFFFFDCDB098A4B1AD
908C89878A99A7B1B8B5AEAAA089725F545D69717A818890
95928E8B8889898887837F7C7A7B7C7D7E7F7F80807B7773
72787E818586858683797069656B73788194A5B2B59A7E69
564E494347617C93A49D959392989FA2A6AEB4B8B7AC9E92
83705D4D3E312823294C708EA6ADAFB2AA8D6C4E32261A0B
0000000000000000000000000000234770A0CDF5FFFFFFFF
FFE1B3886B7A8A9090745949404B5A63718597A7AC947A67
5A6572777C777271727980868A8A89898A8B8C8D8C888380
7E828688887F766F6C71787B7F7F7E7E7D7874706C6C6D6D
6E6F7174787C828892A6BAC9D5D8D6D5C9A88668504C4B48
4746484E5C80A3BFCFB79E8C7F858C8A
94918E8B89888785837E7A76788999A5A9927B6B62738590
9686776E6C7E8F9BA2988C867F7E7E7B7A7C7E80807A7471
70767C808484848582796F68646970747D90A0AEB0967A65
54504E4A4D5B6A798587898E94A1AEB6BCBEBDBBB39E8772
5E5043362B1B110C15447399B5B2AAA797724D2A1013191A
1806000000204B6D898E909799938C8480878D90908C8682
775A412D2C5E90B6CDB69C8D7F7A766E6D7D8D999E8D7C70
69727C8185827F7E7F868C9091877E7773787E81837D7874
737A818687807974707477797A7B7A7A7975706D6A696868
696C7074797E838A92A2B1BDC6CBCBCBBD9065422E48667A
8C9397A0A296887C72706E6A67676767
9E99928C84776A6159565656638FB9DAE6B5835F49658393
9B82695C587593A7B3A6978E85827F7A777A7D7F7F797370
6F757B7F8383838481786F6864686E71798C9DAAAD937762
5252555456595E666E757D8692A6B9C7D0CEC6BFB194765A
42372E251B0A0000053D75A1C0B7A8A08B60360F00041622
2C1E16182B67A5D6FFFFFFFFFFFFD7B18D78654D392A1D14
0A000000003D8FD0FDEBD1C6B39E8A726473838D93877C77
747B83888C8A8888898F95989686766A626B747A7D76706D
6C747C82857F7976737577787878787776726E6B68676666
676A6F73797E848A92A0AEB7BFC4C5C6B7804D251344789D
BECAD1DCD6A7774F323C494D514C4849
9B97918B816B57473B3638394B8BC8F8FFCD8B5C3E5F8293
9B7C5E4D496B8EA6B7AB9D968E8781797476797B7C787574
74797E828484838380776F6864666A6D75899BA9AD937864
555A6062635F5C5D616B76818DA0B1BFC7C0B5AB9B80654B
38373836332317121A4A799DB6A9978D795737190A213B51
6259555D74B6F8FFFFFFFFFFFFFFFFCA906A461C00000000
0000000000278ADBFFFFF2EAD6B79876606C7A8187817C7D
7E83888C8F8F8E8D8E94989A9783706158626D7478726C69
6971797F827F7B7977787A7A7A7978777573706E6D6C6B6B
6C7074787B7D7F8287939DA5AAADABAB9C693A160C4C8EBE
E8F3F7FFF1AE6A30071A3039423B3436
7E7F7F7E7A6B5D52483F39354073A3CADDB48A6D5A6F858F
91775E4F485D73829094979C9C9084797170706F71777E84
898B8B8C8C8A87837F776F69656465666E879FB2B99F8471
646C76797C797777777B7F81817C76716B635C5753535557
617B95ABB9B1A7A0978D83786E66605D5F6E7F8FA2B6CADE
EBE4DEDDE2FEFFFFFFFFFFFFFFFFCD9F7662503A281B110B
02000000002978B7E6E0D2D0C3A98F73616A74797E7D7C7E
818385878887868585888B8C8A7E72696469707377757373
74787C7F81807F7E7E8184858683817F7E7E7F8080828485
8688898A877A6E645E677075776C615B534439323C71A7D0
EDE6D8D1BD956D472D343E4246413D3E
5F676F73756E6761594A3E34375A7D99AA9A897F77808889
867360534B50595E697D90A1A998867A6E6A686466768795
9F9C9897938F8A847D766F6A656261606886A3BAC5AB917F
737E8B91969592918F8C867F72573C26140C0909122B4967
8CBFEFFFFFFFFFFFFFCC8B542A272F324986C5FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF6E8D4B18F725D5C5F5C5B585453
4B2B0F0000306791B2B2AEB0AB9884716469707276797B80
8383828281807E7C7B7C7D7E7D7976737172737476787B7E
807F7F808081828284898D90928D8987868A8E9195999C9F
A0A09D9A90765D47383F474B49321C110E233D516D96BBDC
ECD2B49D867C72635854514E4C4B4B4B
4655636E75716B675F4B392B2846647C8F8F8D8F8E8C8984
7B6D5F534A4645444D6E8DA6B4A0897A6C65615A5C748DA1
AFA9A29E98938C847C76706B66605D5C6485A5BECBB39988
7D8C9BA3A8A7A4A19C968C816B3E110000000000000A3D6F
A8EEFFFFFFFFFFFFFFFC933A0000060E3494F7FFFFFFFFFF
FFFFFFFFFFFFFFFFFFEDD7BFA7896E584B54606870727275
6F4D2F1810355C789096989F9F90817268696B6A6D747C82
8784817F7D7B7977757574747475767878767473747A8084
8784817F7F8285878A8F94989A958F8C8B91989DA3A9AEB1
B3B1ADA6977450311B2026282301000000073C6791B3CFEB
F3CCA17E636971706E63595450515252
364C61717C79747168513C2B243B55687B868E999D93877D
726A625951463E383F658AA7B8A288796A615C55587694AC
BDB4A9A39B958D847B756F6A665F5C5A6284A6C0CFB89F90
889AADB7BEBBB5AFA69988755A2900000000000000084580
C1FFFFFFFFFFFFFFFFFF932D0000000735A0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFE5C9AF937B65544845556878878D9197
9272533B2D415766757E858F93887D746C6A696768727C84
8A85807D7A78767472706F6E6F74797E807C7775757D858A
8D88827F7D7F83858990979DA099938F8E98A2A9B1B8BDC0
C0BAB1A6936C45220A141F242000000000004479A9C2D2E8
E8BB8C654A5F76808677675F595B5E5D
4660798C988E827B705D4C3D39516B7E8E8E8C8E8C857D75
6E6D6C6A68605A565A738C9EA7947F726662615E64819EB5
C4B9ABA298928C837A726B66615E5D5D6785A3BBCAB7A397
94AEC7D5DDD2C3B6A3816041281D160F0E101723375B82A6
C9E7FFFFFFFFFFFFF8BB7E4B2934485570A0D1FFFFFFFFFF
FFFFFFFFFFFFE7CEB6A7998A7E716861606B77828B909296
927B66554B5867717C838A9193897E756E6D6D6B6D757E85
8985817E7C7B7A7978777777787B7E8183817F7E7E84898C
8D87807B7774737174818E999F978F8C8C9CACB7C0C4C5C6
C0AC96826C5139231D3D5E7780552B11072F5B7995A2ABB8
B9A0856F6273848E9385776F696B6E6D
587692A7B3A3918577695D514F688195A1978A847C78746E
6C71767B7E7A777678838E959787776D646466676F8AA4BA
C6B9AA9F948F8A827A7068625E5E60636D869FB5C1B2A39A
9AB9D8EAF3E1C9B79B6B3E17011C3B526A747E8E9DAEBCC6
C9BCAC9F91857B7068686A6C728393A1A99D90888080817F
7E7E7E7F8082848687868483827F7D7B7C81868A8D909192
8F83776D6870797E858A8F93948A7F777071727173797F85
888581807E7E7E7E7E7F7F80818283848585868686898C8D
8C857E78726A6560617284939C938A87889CB0BDC7C9C7C5
B99A7A5F483B332B356B9FC9DFB48668536172777E818388
8A847E7A7986929A9D92867E787A7D7C
6284A3BBC8B59F9181766D6261778D9EA799898076706C67
67737F8A918F8C8B8A8C8E8D8A7D716863656A6D7891A9BE
C8BAA99C908C8881796F66605C5F646973879BADB8ACA29B
9FC4E6FCFFEFD1BB985C250000185380AAB9C6DAE6EAE8E2
CFA3744C29160900022D5B81A5BBCAD9D39E66360E080600
000000000B1E3246565D636B727B83898E9296989A9C9D9D
9C97918D8986858382878A8D8D867E7874757676787C8084
878481807E7F80808183848687878888898B8C8D8D8F8F8F
8C857D766F645B5454687D8D99908784879EB4C3CECEC9C6
B78E66462D2A2E30468BCEFFFFF8C7A78987877C746B6460
6067707983919DA9AEA3978D878A8D8C
6C8EAFC8D5C0A798887F79706F8294A2AA9B8B8176706B65
667686939D9C999997948F8A847B736D69696B6D758BA1B2
BBAE9E938987847F7A70686360666D737C8A97A4AB9E938B
8EB0D0E5EFD7BBA789572B0700397AACDBEEFDFFFFFFF5DE
B977370000000000000D5999CEE1E9F3E192400000000000
000000000000001632404C5B697987929A9D9E9FA0A1A2A1
A1A1A1A19E968E878285888989837D7A77787A7B7C7F8184
858381807F808182838587898A8A8A8A8B8C8D8E8E8E8E8D
8A837C766E635A5353667989938A807C7D91A5B1BAB9B4B1
A37C573A272E3D4866ADF1FFFFFFF2D1B0A2957F6D5C4F45
445365748594A2B0B6AB9E948C909392
6C8AA6BCC7B5A092847D78706E7C89949C9994928E847B73
707882898E8D8C8C8D92969898948F8A827161544F607380
8A847D7A787B7D7D7D7A777575787C7F848F989E9B7E624B
3D48545C625B55565D758DA2B3B8BCC2C9DEEEF6F0CCA37F
57280000000000001E5081ADCCC6B9AF9769390B00000000
000000000000001B33404C5B68747E878D9092939497999A
9A9A9A99968F88827F81858686827D7A78797B7C7D7F8183
848382818080808080818282838486868683807E7C7D7F7F
7F7C7A7876747271727C858C8D807369616161605F616264
655E59585C6D8191A7CBEAFFFFEECAAE95918D83796B5F56
52545A5F697E92A3AC9D8D827A7E8280
6B849CADB7A8978C807A756E6C747D858D969DA4A6998B80
787A7E7E7F7E7D7E828F9BA4AAABA8A59A79593E2D39474F
585A5C63696F767B80838587898C8E8D8E949694875D320F
000000000000000B3391EAFFFFFFF8D2B4C7D6D2C18A5024
000000000000244F7892A6BCC2A685684D4238291D150F0A
04000000000015283B46505D686F757A7F828587898D8F91
9291908E8C87827E7B7E818384817D7B7A7A7C7C7D7F8082
8382828181807F7D7C7C7C7C7C7F8182817B746E6B6E7173
7577797B7F868C9193928F8B84766758483422130A0D151D
2C445E7892AAC1D5E2E1DCD7CCB59E88787E8486857B716B
6359524B4E688195A08E7C70676B6F6E
6F8396A5ACA091877E7975706E72777B8495A4B1B6A79689
7E7C7B78777576787E8F9FACB6BABAB9AC815531171C2629
313A43505D66707A838A8F94979B9C9B9896908771400E00
00000000000000000FA2FFFFFFFFFFE9B0C0CEBFA55E1700
0000000000003C78AAB9C0CDC597673C1C253030312A2321
1A0900000002192B3E495360696E7175777A7D7F81848688
898988888683807E7C7E808282807D7C7B7C7D7E7F7F8080
8182828282807E7C7B7A7978787B7D7F7E746B645F626669
6D71777C84929EA7ABA195897B6E5E4D3613000000000000
002D5F8DB8D8F3FFFFF8D8BDA29488776F7780868A827974
6B5A4C3F3E5A768A96836F635A5E6361
6E7F8E9AA0968A827A76736F6D6E70737C94AABBC3AF9A8A
7D7A7873717071747B8B9CA9B4BBBDBEB1865A3518151613
17233343545F6B78848D959BA0A9AEAFAA9A857052240000
000000000000000000A6FFFFFFFFFFEFABB2B79F7F390000
000000000015558FBCC4C4C9BA834D1C001A394957514949
422D190903182F4151585E676D6F70707275797B7D7E7F80
8080807F7F7E7D7C7C7D7F80807F7E7D7D7E7F7F80807F7F
7F81818282807D7C7A79777676797B7D7B71675F5A5E6266
6B7178808A9EB0BDC0AA917B675F56483306000000000000
002B679DCEEEFFFFFFF3C39A7874746B6A737C868C87817E
76614E3E39536E818C7A665B52565A59
64758591988E847D75716D6967696D717B94ABBDC3A78974
646B73767979797B7E8285888B8F939491877A6F614C3929
202B3945515B66737E848A9099B4CAD7D3A36F451E0A0000
0000091E2E221C1F337DC4FBFFFFE6D2B8A48F745A402815
0D233B4F5E56504F546B8190926E4B322645657A8A86807F
775D46322A4662778680787775767776777E848A8C86807C
79797A7A7A7A7A7A7A7A7B7B7C7D7E80808080807F7F7F7F
7E7F7F7F7F7E7D7D7C7B7B7A7A7C7D7F7E78726D6B6F7479
7E81858992AABFCECC9E6E482E3E4E5351321301000A2031
47627D96ACB8C0C7C3A78B73636C777C818181838382817F
7A6E63595666757F85796B635D5F6261
5B6C7C8890887E78726C686361656B707B94AABCC09D785D
4C5D6F798282818382786F686365686A71869AA8AA856045
313A464B545B646F797B7F828FBBE1FBF8A7551800000910
2B69A5DAF7CEA0826353463434628EB1C19263453247606C
81A8C9E5E5994D13001540586B5C4E4D547393AABBB9B3B1
A78B705A517395ACBBA792877D7C7D7B7C8690979A8E8279
72737575757677797A797877787C7F82838281807F7F7F7E
7E7D7C7C7C7C7D7E7E7E7E7E7E7F8081817F7D7D7D82878C
8F8F909096B2C8D8D28F4D1B00224B647663514C4D667F91
9D99928F8880776D645C565052677C8D988F847F7A7D7F7F
7E7B787675797D7F7F78726D696A6C6B
5464737E857F78746E68625D5C60676D7893ABBEC1976D4D
3A526B798686848783715F5146464A4B5A87B1D2DEAE7B57
3B434E4F555B626D7576787A8AC3F5FFFFA93C000000122F
64C0FFFFFFFFFEC88536000000004D95C07C391709417FA5
D3FFFFFFFFDA5A000000122C4847495A6F96BCDBF0EFE9E6
DABCA0867CA0C4DDE9CAAA958481817C7D8A96A0A4928074
6A6B6D6D6E7174787A787675767B8083858381807E7E7E7D
7D7B7A7A797B7D7E7F8080808181818182838587898F9499
9C9A98969BB9D2E3D9863500000D4A7191877C7F87A6C3D4
DBC2A58E745B442E1F20272C3A597793A395857B747B8284
87898A8C8B86807C7775747170707070
5663707A807C76746F67615B595E656B7691A8BBBE916443
304C6A7B8A8A878A846E5846393638394B86BEEAFFCD9872
555B656365686B727772706E7DBCF3FFFF9C210000003972
BDFFFFFFFFFFFFDC811E00000000297FB15B080000369BDF
FFFFFFFFFFFF7000000000173743527090B7DBFBFFFFFFFE
F0D3B79E94BBE1FBFFE0B89D8682827B7C8A98A4A8937F70
65676A6A6C70757A7D7A7775757B80838583817F7E7E7E7D
7C7B7A79797B7D7F818181818181818182868B8F94989CA0
A19A948E90AEC6D7CE7B2B0000175E90B9B2AAAFB8D6F1FF
FEDAB08E6944240500000E1C32557696A998847870798488
8D93989D9D92867C7576787777777676
72797F84878582807B736B646062666971899FB0B38E694D
3E566F7E8B8B888A86796C625853504F5983ACCDE0C8AE9D
90979F9F9F9A94918A78695B5C8CB7D8D66C07000028A9FF
FFFFFFFFFFFFAE4D061B383D4B5D6C827A1B0000000B9AFF
FFFFFFFFFFFFA54C0C203D485B6A7C95ADC3D6E7EFE3D3C6
B5A08D7B789FC6E2EFCDA9917C7877706F7D8A959A8A7A70
686C7172767B808588837F7C7A7C7E7F807F7F7E7E7E7D7D
7D7C7C7C7D7E808182807E7D7C7C7D7D7F868C9194949393
8D7D6D605B70849396714F3A3974B1DDFBE6CFC3BAC4CDCD
C8B8A696816347302129363F4E647B909C8E8076717A8489
8F94989D9D958D86807F7F7E7D7C7C7C
8D8E8E8E8D8E8D8C887E756D676667676D8296A5A98C6E59
4D6075818C8A87888885827F7B726B676A8098ABBBBEBFC3
C7CFD5D7D4C8BAAD9B7E634A40607E96943B00000068FFFF
FFFFFFFFFFAA3000001EACFFFFFFAF8545000000000094FF
FFFFFFFFFFFFD6A47D7B7E7B8091A4B7C7CCCFD3CEB79F8B
776A60565A81A7C4D4B79883716D6B6564707C878C817670
6C71787B80858B90928D87837F7E7D7B7A7B7C7D7E7E7D7D
7D7E7F8081828383837F7B79777779797C848B90938F8984
796048352A3544515F6874849CCEFDFFFFFFECD0B5ACA496
8E94999D9B846E5F545961656C767F898D847B75727B848A
9093969A9B97938F8B88868381818281
A19D98949193959592877C746D6A69676B7D8E9CA0887060
576779848D8B8888898D919392867C75727D8A95A4BCD2E7
F7FEFFFFFEEDD8C3A8815C3A273E556968190000009AFFFF
FFFFFFFFF9650000001BF4FFFFFFD7831E000000000099FF
FFFFFFFFFFFFFBE0C8B6A79996ACC3D5E0D9CEC6B7997A60
4B44423F496F94B3C3A98D7A6965645D5D68747E847C7571
6F757C80858C92989A948D88827F7C7876787B7D7E7D7D7D
7D7F818283848485847F7A77747577787B848C91938C837B
6C4D2F18070A131C325E8DB8E5FFFFFFFFFFFFE4BEA69278
6C7E92A1A89582766F757D8184848485847D7773727A838A
9195989B9D9B999693908C8886878787
AEA59D9692969A9C9A8E8178706C6A676A7B8A979C887568
616E7C858C89858587939DA4A5988A827B787A7B88ADD3F2
FFFFFFFFFFF7DFC6A983603E29394958510000000098FFFF
FFFFFFFFB52C0000002AFFFFFFFFEA7D06000000000094FF
FFFFFFFFE7F9FFFFFCDEC1ABA1BBD5E5EFE3D3C8B38A6340
27282E303E6082A0B19A8070615F5F5A5B65707A807A7370
70777F848A92999FA19B938D87807B7572767A7D807E7D7D
7E80828485858585847E79757273757578828A9091897E75
64452710000000021A5A9CD6FFFFFFFFFFFFFFE0B5977D5F
536F8CA3B3A3928B858D9598989088837D78747171798189
909395989A9A9A9996928E8A87888888
A299918A868E969A9A8D7F766E6B6B696E8192A1A7937E70
67717C8387827E7D7F8B979FA2988C847C736D686C8AA7BF
D1CFC9C8C1B3A4958985827A788A949F7F0000000000FFFF
FFFFFFCE6F360C000061F2FFFFFFB0631800000000227AC5
FBEAD5D0CAD6DEDED7BCA28F88A4C1D5E8F5FCFFF8BD8151
2E354144516A829AA590796A5D5F636265717C868A7E726B
67717C848C949BA2A5A099938C837A716D747C8185827F7E
7E80828384848484837E79767371706F727D8890938C827A
6F6052463D383739446689A8C5DDEFFFFFE3C1A48A7D7467
657B92A5AF9E8C817B86909598928B87817A736D6B737C83
8A8C8D90918F8D8B8885827F7D7E7E7E
948B837D7A859097998B7D736C6B6C6C72879BABB29D8677
6C737C7F817C76747684919A9E968C867C6E615552667A8A
938B817C766F6A656985A1B1C2DAE3EBB600000000008AFF
FFFFC274314967626D94B7D8E2AC754E354E6A788271615B
5D7690A2B0B0ADAEA8927E6F6B87A6BDD9FEFFFFFFEA9F64
3845565A657483949B8772645A60686B727E899396857367
606C78818A939BA3A8A39D979084796F6A747E858A86817F
7E7F818182828282817E7A7875716E6C6D79848C918B847F
7C7E8181817B76727071747579848F97988675685F656D72
7A8997A4A89684776F7C899196928D8B867C726A666E787E
848585868683807D7A79777574747474
8C837A7472808D96998B7C736B6C6E6E758BA0B2B9A48E7F
72777C7D7D76706D70808F9BA19B928B8069534036465762
685B4D47424042445485B6D6F4FFFFFFDA00000000002EFF
FFFF6A2000449CC3DEBE998974605240468DD0FFFFAE4B06
00124D6E8D8C8992917C695B597494ABCBFFFFFFFFFFAB68
36485F6570767C888B7A695D565F6B727B87929C9E897465
5C68767E89939CA6ABA6A09A9285796D687380888E888280
7D7F8080818180807F7D7B7977726D6A6B747E878C878381
8494A3ADB2AAA0988C7A685649494A4A483F39373A4C6070
808D98A3A6958577707E8C949A96908D877C7168636B747A
7F7E7C7D7C79777471706F6D6C6C6C6C
8379716A6978869095887B746D6E7070778EA4B5BCA79080
7375797877706A686B7D8F9CA49E948D80644A3223303D45
493A2C2622242B32487FB5DCFFFFFFFFFF000000000000AE
FFB12D000051C6FFFFCC6C31061F414D71C9FFFFFFD13F00
000027527971656D6B5A4B3F3D557186A7E4FFFFFFFEAA6A
3C5069707A7C7C83837364595462717B87939DA7A7917A69
5D656E737C88939EA5A19B968F84796F6A7581898E888380
7D7E7F7E7E7E7E7E7E7E7E7D7C797573717375777A7A7C7F
89A7C4D9E4D7C4B59E7C5A3920191612110F1016233E5A72
878F959C9D8F81756E7C899197938E8C877C7268636B7379
7C7A76757372706E6C6A696867676767
7C7268615E6A778086817B7976747371758A9EACB19A8271
64676C6D6E6A67676D8296A5ACA1938979614A3529384954
5C544D4B4A4A4C5058667885A6FFFFFFFFB9000000001E78
B9844D3B387AB7DDE2852A00001C71A8DAEBF2FFF4A3520E
001C54758B70524434281F15111B29354A749ABBC8A2795D
4A5B6F778186898F8E7C6A5D586A7D8A98A3ACB4B5A38F7F
6F655C535160707D87858181807E7D7A797C7F818281807F
7D7C7A7978797A7B7D808486899094979279604F4550616C
83B0DAFCFFECC6A8876A4F311D21272C312C2A2E364D6477
8688888A887F776F6B747D83878582827F79746F6D757C81
847F79757273757574716D6B696A6A6A
776C6159565F697177797B7E7F7A7572748697A4A68E7562
555A6164676565686F869CACB4A49184725E4C3B33445765
71727276777573746D4E382943CEFFFFFFFFEB92484A5345
465B72889BA2A3A8943E00000024A2FDFFFFC3A38071654F
4868869BA0724220020000000000000000091E3242464950
5865727C858E959A998471625C718797A6B0B8C0C0B3A394
81654B34283B505F6C6A686B6F78808689847E7A777A7C7D
7D797674737476787C838A8F96A6B1BAB27E4C271129485C
7EB7EBFFFFF9C2986F59462D202F3F4E58514A4A4E5F707C
84807A7774706E6A696D72757877777777777676777E858A
8B837B7571767A7C7D78736F6C6D6E6E
71655A524E565E646C737A81857E78737384949E9F856B58
4A50585C6161636771899FB0B7A48F7F6D5C4E3F3A4A5C6B
7980868C908F8B8B7B3C090000A9FFFFFFFFFFFFFFD06906
00257EB7E1C5A095701000000018BFFFFFFFB0703D557274
7E93A3B3AD6F300000000000000000000000000000062B4C
68727A848D979FA4A18B7666607791A2B3BCC3CACBC0B2A4
8E653E1C091F3749585654596172838F958A7E756F757A7C
7D7873706F7073767B848E95A0B7C8D4CA833D09000C3651
7CBFFDFFFFFFC895644D3B21162C455A6A6159595B6A7982
877C706862636565666667696A6C6E707275797C7F868B90
90867C746F767D81827C75716E6F7070
6E645B5450545A5F65707A8389817A747483919A9A806653
464D565B6162656A748BA1B1B8A48D7C6B5D524744536574
84909BA5ABADA9A8903100000070FFFFFFFFFFFFFFFF7800
00008CE1FFDD9577460000000024CCFFFFFF964710447C91
AAB8BEC9BB742A0000000000000000000000000000001446
6F767A848B979FA39F8A7666617992A4B5BEC4CACBC4B8AB
9463340C00112F44564F494C546D85969F907F746C72797B
7C76716F6D6E70737985939CA9C3D5E3D6812E0000003155
85C5FEFFFFFFC28D5B4738201A365570837A6F6D6C788388
8879685C555B6266696663636366696B6F767C81878C8F93
92877C736F7780858780797471727373
77726E6A68696B6C70767D8386827D7A7A87939A9B867263
5960696E737272747B8EA0ADB3A3908374675B514E5D6E7D
8D9BA8B3BCC7CACDB13D0000000EAFFFFFFFFFFFFFFF5200
00008FEDFFD77F542A1E1A0A155CA1DAF8C187634A607A83
92ABBECEC6823C0300000000000000000000000000001437
555C616A71797E817F71645A586A7D8B99A3ABB2B4AEA49A
865A310F002955748870584D4B678395A094867F78797B7A
78767473726E6C6C71869BAAB7C3C8CDBA6B2100000D5384
B3CADBF2F5CFA582625246373553728B9D91857F7B848B8D
8B7A695D56626F777D7872716F6F7070737A80868B8C8C8D
8B827A726F77808588827B7774757676
81818181807E7D7B7B7D808183817F7E808B949B9D8E7F73
6C747B8084807E7E81909EA8ACA092897D70655B58677785
95A4B3BEC9DEE8EECF4B000000002D80D8FFFFFFFFDD3000
00008CEBFFCA6B391A4E85A2B394756459697A83897F7772
769AB9CDCC91532400000000000E2031381F060000061E2F
3F464B545A5E6062615A5450505C69737D8891999C968E87
7853331813487EA5BB936951446180929F978D8984817D78
7576777978706A666B86A0B2BFBEB7B39D581900002576B1
DCCBB4ADA09588786A5E564E526F8DA5B5A89990898E9191
8C7B6B5F5A6A7C88908A82807C7A7976777E858A8D8B8886
837D77727078808588837D7A77787A79
888C9092938E8A868382818080808181848D959B9D92867E
7A81898E918C888687929CA3A69D938C83786E6765738290
A0B1C1CDDAF5FFFFE9550000000000004EBAFFFFFFD42300
000090F2FFC0551A026ED8FFFFC6580F00216389A6907972
7499BCD0D29D663D1C1819131937546D7755331B0B162329
31363C444A4B4C4D4E4C4A494B525A6068737D8589857E7A
6E4F351F205E9BC9DFAA74513C5D7F92A09A91908C857E77
72767B7E7E7269646785A1B5C2B9ABA38B4D1500003690D2
F9C893755B646E6D6D6762626B8BA9C2D0C1B0A49A9A9994
8D7B6B5F5B7085949F978D8984817E7A7981888E918C8682
7E7A7672717981878A85807D7B7C7D7D
8E94999D9F9A94908B86827D7A7B7D7F838C949B9E958C86
8289909496918B888890979C9E978F8A837B7570707B8893
A2B4C5D0DFFDFFFFF5610000000000000064E4FFFFD72B00
000076C7F8A24D1F199EFFFFFFE4420000005997C49F786C
688BADC0C7A886705B55524C52779BB7C4A27E654E49463D
3A3E43494D4C4B4C4C4B4A4A4B4E53565C67727A7E79716E
66534539407DB8E4F7BB7E553B5B7E909F9A93938F877E76
71787F8485796E67688199AAB3A8998F7B4E26040152A2DD
FBBA754A2B425D68736F6C717C9CBAD1DDCEBBAEA19E9A92
897A6C6261778D9EA9A096918B86827D7B838A8F918A827D
79767472737A82888C8883807E7F8180
8C8F91939495949490877E77706E6D6C7080909CA3968980
7A7D8081817E7C7A7C838B9091897F797371717072767C83
8D9FB0BCCAE0EDF3D96E0300000000000068FFFFFFFF7100
00000F2746566784A8E8FFFFFFC74800000D6DA7CFA1705C
4F62798597AFC6DDEBE0D6D0D2ECFFFFFFFFFFF6E4CBB39B
8A8B8E8D8C8884837E72675F5A5F6569707A828B8D80736B
666E777D8BACCAE1E6B4825D46617E8D9A938B8A86807B75
747C858B8E87807B7778797979797A7B7A726B66688299AA
AE8D6C544454656F77716B6C738EA8BBC6B9A99E938E8982
7C746F6B6D7F909EA69F96908A85817C7A80868A8B847D78
74727271737B848B8F8B868482838484
8A898887888E939695887A7067615E5A5E758B9DA797857A
7070706E6D6C6C6D6F777E84867B706863686D7173727172
78899AA5B1BFC7CABA7A3907000000000073FFFFFFFFB741
00000000000B83E7FFFFFFFFFBA55207003181B6D6A26B50
3A3B454963B0FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
D5D4D4CEC9C4BDBAB19A85746970787D848D949C9D89766A
6888A8BFD2D6D6D9CFAA856553677D8A948C82807C797875
76818B9398979390876F57453C4B5D6A7D98B0C5CCAE8D75
61616461626971797D736A65677D93A3ACA2958D847E7972
6E6F72747985919BA19B938E8984807B797D8184857F7874
70707070737D868D928E898684858786
8A868381818B959B9A89776A5E57524D526E899FAA988477
6A68676260606263676E747A7B70655C58626C7276706A67
697887929CA4A8AAA28769522E0000000060FFFFFFFFEB86
15000000000095FFFFFFFFFFD4915310004190C7E4A76746
261A1A1739B2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBF3ECE4DFD4B69983747B858A91979DA5A58B7565
679BD0F5FFFCE4D7C2A5896E5E6D7D888F867C7975747574
7885929BA2A4A3A294663B1A0923445A7DB5E7FFFFD68950
273D57616D72768084786C64627486929A9187817A736C66
646C757C848D949C9F9A948F8985807B797B7E808079736F
6D6D6F71747E878F94908B8986888989
89837E797987939B9C88736557504D484D6B889FAB978173
6563615C5A5B5D5F62696F75766A5F5754606D767B726864
626B757C8286888A8B92939680230000005BFFFFFFFFFFC2
570000000000A0FFFFFFFFE9AA7E57210E559DD0EAAE6E4B
260900000C9DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDF9EECBAA907E858E92989EA2AAA88C7464
67A7E5FFFFFFE2C8AC9A897468737F878C8176716D6F7274
7A8997A1AAB1B2B2A05E20000004385C8DD0FFFFFFE98336
02265063777C7F8A8E7E6E625B6A788187837D7A766D6660
5F6A7680898F93989A95908B8683817E7C7C7C7B7A76716F
6D6E7072767E868D918E8A8886878988
8A827B7574818C9394816E60565557565D748A9CA5917D6F
64676C6C6C6B6A6B6D73797E7F756B64626E7A8287817B77
726D6864636A72778095A6B6B06B2B000066D5FFFFFFF6D9
9400000000008FFFFFFFF8D09D7A5D3225619DC9E2BC917A
58250000004DBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
C7D3E3E3E7E9E9EDE7C9AC9482858B8B8E92969C9B867468
6A98C4E5F6D8B7A28D847E736F79838C9082746C676A7073
7A8A99A5AEB8BBBDA8570A000002538CC2DDF0FFFFC47F46
2036515D6E7C89999F88705F556270787F828387867D746D
696E74787D83898E9089827C797F848788827C7875767777
77777778797C7F828483818180818181
8A817972707B858C8C7B695E565B63676F7F8D999E8B796B
626C777C807C7977787E848889807873717C868D91908D8C
85715E5048515D667797B5CFD7AF866958718C99ABC7DAEB
D13B000000007DF8FFFFD2B6927863443B6B9CBED6C8B4A9
8C45050000034F87AC8761534C668497B4E9FFFFFFFFC390
6D85A1ADBCC5CDD8D9C1A895858486838286898D8D80746C
6C87A0B2BAA38B7B6E6F7271747F88919483736861666D72
7B8B9BA7B2BEC2C5AF510000000570BCF6E7D0CDBC9C7B5A
434A5458647C93A7AF91735D4F5B69707A838B94978E837B
7473727070777E84877D746E6D7A868F93887D7671777C7F
81807E7E7D7B79787778797A7A7A7A7A
897F756D6A757F858776655A555F6C737D878F9899867467
5F6E7D868D88827F7F858B8F9089827D7C858E94989A9A9A
9071533C2E3847526999C8EFFFF4DBCAAF80552C2479C9FF
FF720000000072D5FFE7AB9378706B5C5C7D9EB7CAD0CECD
B35C07000000001C2F06000000000A244883B7E6F7B9784A
2D50778CA2B1BCCCD0BDA896888685807E7F8183837B7570
6F7C8991927C67584F5B69717B858D95968371635A626B71
7C8D9EABB6C4CACFB54B0000000285E2FFF4BEA68A7F7562
5655585A64829DB4BC99745A48526066707E8C9AA1988C85
7C76716A676E767B7D736963637688959C8C7D736D768086
8A878483807A75706D6F727476757474
887E746C68727C828474655C586777828C91949896837263
5D6F828F98918985848B919596908A86848A9194989FA2A4
9B755035232C3B476198CEFBFFFFFFFFEF831E000033BAFF
FFB3260000016BABD8B38979696B6F6C71859AA9BAD0DDE6
D2751800000000000000000000000000001146768C5D2B0B
001B4057718698ACB6A99A8E8382817D7A79797978767471
707272726D5B4A3D394C606F7E88909999847060565E6970
7B8EA0AEBBC7CCD1B64A0000000A96FAFFF7AD85626A736D
69615C5B6384A3BBC39D765B47515E646E8090A0A99F928A
80776F66626971777A6E645E5E7387969D8D7C716C78848B
908D8987837B736C686B6F7274727172
867E77716F7982888A7D7169677788949D9F9FA19C877362
5B6E818F988F86828088909496908A868283848487929BA2
9F80624C3D414A506291BEE2FEFFFFFFE06000000018C0FF
FFFF90491643748696887875706C696568768692A1B9CCDB
D28D48110013394B53310D00000000000000000007000000
00000000022548657A756D6C6A71787A7B7874716E6F6F6D
6C6C6A696455473D3A4B5D6B7986909A9C867160565D676D
788EA3B4C1C6C4C3AB550500002496E7FFE7AD8F72757971
6C645E5C62819DB4BD9D7B6455617076808D98A3A7998A7F
75706D6868717B83877B716A677480898D847A74727B858B
8F8D8A8885807A75727477797A797879
847F7A777780888F91867B75748697A3ADACA9A9A18A7462
596C808D968D827E7C868F9496908985807B77737484939E
A18B75665A585A5B6688ABC5DAE7E8EDCA4000000003C3FF
FFFFF5C391867D63555F6A747A6E635F5E68737B88A2B8CB
CDA1765546739FB8C5AD8D75480000000000000000000000
00000000000000213D40424A536270797E77706A65676969
69686665615449413F4C5B677483909C9E887262565C656A
758EA6BAC7C3BAB59F602600003E93D0F9D6AE9985828076
6E66615D627D96ABB49A806E6371818992999DA3A3938275
6B6A6C6B6E7A858F93897E7772767A7B7D7A7877787F858A
8D8C8A898884817E7C7E7F8081808080
827F7D7C7D858D93968C837E7E91A4B2BBB8B1AEA48C7562
586C808E988D817C7A858F9599928B8780766D65657A8E9E
A59584796F6A686469819AAABCD2DEEAC92B00000000BBFF
FFFFFFFFFFC481390E31586F8171605D5B5E64677290ACC4
D0B79E8D8BB6E0F7FFF4D8BF870800000000000000000000
000000000000000008131E2F4056697880766B625B616667
67635D5A554D4540404B58637081909DA18A7363575C6468
738EA8BDCAC1B2A99568401E165596C5E4C7A7968584847D
776D655F627A91A4AD9983766F7E8F98A0A3A3A5A18F7E70
65676A6B707E8B969C9388817A777571707376797D82868B
8E8D8C8B8A8886848384848585858484
81807F7F818991989A8F86808095AAB8C2BDB6B1A68E7763
596C808E978B807A798591989C958D888072665B5A728A9C
A79D9089817A746D6C7B8A929FBBCDDDBF2300000000A7FF
FFFFFFFFFFF1811A00104C6E8A7763625E5C5D5C64819EB7
C8BCB0ABB1DBFFFFFFFFFFFAC23400000000000000000000
00000000000000000000071F3751687C8577675B525A6264
666461605D544C46454E59626D7F8F9DA18C7565595D6366
718EA9BFCCBEACA18D6C4F35306295BBD4BCA19386878884
7F73696263778B9BA494847B7786969FA6A5A1A09A8B7C6F
66676B6D73808D999F99918B847B736B676D74797F83868A
8D8D8C8B8A8A8A898989898989888888
81807F7E808A949B9C8B7A6F6C829AA9B6B4B0AFA7907A67
5D6D7F8B9289807C7C89969EA29B928D8475685D5B728A9C
A79E928C847C756D6C78858D98AFBECBB642000000006FCD
FFFFFFFFFFE97413000E4D6F8D83767B7A746F696A8094A4
AB9682767493B2C5D6E0E2E2C8731D000000000000000012
2D3B45514E2A06000000182D465D7288917D67574B525A5D
64727F8B8E7A65564D56626872818E9A9E8A75675C5F6568
728DA7BBC7BDAEA48F6239170F4F90BFDDBE9B8879828B8C
8A7D716967768691968A7E76737D878D92908D8C8A86827E
7A767471727B848B919190908D8379716B6E7375797F858B
8E8C89878688898A8A8A8A8A8A8A8A8A
82807E7D7F8B969E9E856D5D566E8899A7A9A8ABA6917D6C
626F7E878D867F7C7D8C9AA4A9A0969086786B605D748A9B
A69D928C857C756E6C76818892A4B0BAAD631C000000385F
91D6FFFFFFDC681000104F71908E8A92948B827874818C93
9070523D33486070859CB0C4CAAF937D6C7075767462554E
5CABF4FFFFCF631600032D40596D7F969F846854464C5558
64839FB7C0A07E66555F6B6F77828C97998876696062686A
748CA4B6C2BCB0A892572200003A8AC4E9C1967F6E7D8D91
9285776F6C7680878A8178726F73787B7D7B79797A82888D
8E857B7571757B7D82898F95968B807771707170737B838A
8F8B8684828588898A8A8A8A8A8A8A8A
82807E7C7E8C98A1A0826550465F7B8D9DA1A2A8A5928070
66717D8489827D7B7E8E9DA8ADA4999187786B605D728899
A49D94908A827A726E747A7E85929DA49F7A53381F120D06
1E86E8FFFFD95F0A00105275969898A3A69B8F83797F8281
775331190B1B3040597CA0C3E0EEF9FFFFFFFFFFFFD1A580
85FFFFFFFFFFA73300083B4C667888A1AA8A695241465155
6590B9DBEAC195765F67727379828A949686766C64656A6C
748BA2B2BDB9B0AA93511500002C83C2EBC2957E6C7D8F93
95897C7570757A7D7E7973706E6E6F6F6F6C6A696C7C8C97
9D908178707274747885919B9F92857B7270706D6F788189
8E8984818084878A8B8B8A8A8A8B8B8B
83807E7B7D8C98A29F7D5B4236506C7F9095989F9F8F8073
6B727B80837C7775788A9BA8AEA3968D82756A5F5D718594
9F98908C86817D7774767A7B808B949A9A8C7A6E56200000
0050C8FFFFD3590900125476989EA0ADB2A79A8C8182807B
6C421A0000001225426891BBE6FFFFFFFFFFFFFFFFFFD294
90FFFFFFFFFFE05200164E5C768897B2BA946E544048555B
6EA0CEF5FFD7A581666D77767A8188909385776E67686B6D
748A9FAFB9B9B2AE964B0700001E7EC4F2C799826F7D8B8D
8E857C777374767777757372706D6A686662605F647A8E9E
A69482766C6C6E6D728394A1A899897D73706E6A6A747E87
8D88827F7E8184868787868686868686
85817E7B7C89949C9873503629425E718184848A8A827972
6C727779796F666062788E9DA59584786D655F57576A7D8C
95897D7772777C7F828486888D9EABB3B08B664A30190C00
117BDFFFFFD45C09000F5072939797A4A9A1978D868D9393
87592C0C001A3E5976889BB4CCE3F9FFFFFFFFFFFFE98D45
3EF6FFFFFFFFE564042E6370889FB3CFD8AC80614C5C707A
8EB1D2EEF7CC9F7D63697271757D858D9084787069696B6C
72889DADB8BBB7B69E4B0000001982CDFFD8A9937D7B7B71
6B6C6D6F7275797C7F808181807B76726F6C6B696C7C8B97
9B8774665D62696D76889AA9AF9D897B6E6B6A6666707A83
8985817F7D7B79777575757575757575
87827E7A7A868F95906B482D1F3853657574727576757370
6F7173757264574D4D6781939C8873655956555254657684
8A7B6B625E6C7B868F9192949BB1C2CDC5884C1F02112A37
59ACF7FFFFD4600B000D4C6E8E8E8D999E99948D8B9AA5AC
A471401D0E3C6D90AEACA8AEB1B1B3B0B9E6FFFFFFB14600
00ADFFFFFFFFE1742147778299B4CBE8F0C0906D576F8A99
ACC0D1E2E4BE977861656D6D717A828B8E8479726C6A6B6A
71869CABB7BDBCBDA54C0000001485D5FFE8BCA88F7C6B54
46515E6872777B82888B8E8F8F89837D78777674757F888F
8F7A65574F59666E7B8E9FAFB49F897869676663636C767E
848381807D766F696464656566656465
89837E7978828B908B654025162E495A69656264656A6F70
727271706B5A4B3F3D5A768B957E6556494B504F5462707D
826F5C504D637A8B9A9B9DA0A7BFD3DFD489410B00103D58
82C4FDFFFFCE611000114C6B898987929796949091A5B4BE
B77E4820104A86B0CEBDA9A3998E867A81BEF5FFFF9A1E00
007EFFFFFFFFEB893F618D95AAC6DFFBFFCF9B76607E9EB0
C3CED4DEDAB7937660646A6A6F777F888C8379736E6B6B6A
708599A8B5BEC0C3AC4C0000000E85D9FFF4CAB89C7C5E3C
2A3D546474797D868D92979999928A837D7C7C7A7B81878B
88715B4C4452626E7D91A2B3B8A28A77676564606069727A
818181817E73675E5657595959585758
8B837D76747E878C876441281A314B5C69625B5A5B646E73
777674736D5A4A3C3A577489937A6050434A52545A65707A
7C675346435D798E9FA1A1A4ACC8DEECDE863100000A4D78
ABDDFFFFFFCA651600144A688483808A9092949398ADBFCB
C4884E2414579BCAEAD0B1A490796751559EE1FFFF910E00
0057FFFFFFFFE29458779BA2B4CFE6FFFFD09C766183A8BD
D0D2D0D2CBAC8D735F6268696E767E878B837A746F6D6C6B
708498A6B2BEC2C7B04F0000000C83D7FFFDDCD1B686572A
102C4B60757A7F8A92979C9E9D968E878181817F7F838588
836C5747405063718193A3B2B6A18A786865645F5F677077
7E828386837465584E50535253525151
8D8278706C79848C8B7056443B546D7E897C6E67646E787E
838586898676685D5A728999A18A73645A616A6D72777A7F
7E6D5D524F647A8B9895939299BAD4E5DA7D240000004776
ABDEFFFFFFCF691A001448637D7D7C878E9397999EAFBCC5
BC824A22135497C6EADDCCCABFA9968183C7FFFFFFCB5F12
0069E0FFFFFFB786617A97A0AFC0CDDDDBAC7E5C4B6E93AB
BFC0BDC0BAA1887262656B6C707880888C847B76726F6F6E
728597A4B0BBBFC3AF57060000147AC2FEFFFAFFEEA96427
0221465B71797F8D969694938F8B86817D7B7A787980868B
89766356505E6E7986939DA8AA9B8B7D716C686261687077
7F888E9594837263595B5E5E5F5E5C5D
9081746A6674828C8F7D6C615E778FA0A89581756E778287
8E93989D9E91867D7A8C9DA9AD9A877A7179828589888686
8275695F5C6B7A868F8A858288ACC9DDD373160000004174
ADE0FFFFFFD36E1F0016465F787878838C939A9DA2AEB7BC
B27A451F114E8FBEE4E6E3ECEAD1BBA7A7E7FFFFFFFFAC6F
4978AAC4D3AE89766A7C919CA7AEB1B6AE86604234577D96
ACACAAAEA996837165686D6F737A82898C857D7873717171
758697A3ADB7BABEAC601900001D71ABE3FFFFFFFFC87129
001C44597179808F97928B8681807F7C79767372737D868E
8F807066616C7A828B91969C9D948B827A726C66646A7278
808D99A3A5927F7065686C6C6C6B6A6A
92817165606F7F8A92877D787A93AABAC0A88F7E737D898F
979FA5ADB0A69B94919EABB4B6A59488808A94989B958F8A
84796F67636E798289827D797EA5C5DCD168030000004582
C1EDFFFFFFD472240018455C7373737E88919A9FA5AFB5BA
AE784620145090BEE7F2F7FFFFE6C7ADA9E9FFFFFFFFDDAD
82746B595157606B77838F9BA2A09B978B69492F26496E89
9E9C989A96897B6F666A6F71757D848A8D857E7874737474
788796A1AAB3B6B9A9682A0000276A99CDFDFFFFFFE07928
00164358717981919990867E77797A797874716F707C868F
928579716D78838A90919091918E8A868178706A676C7278
8091A1AEB29E88786C70747475747373
938170635E6E808D96918C8B90A6BAC8CCB1978377808C92
9AA1A8B0B4ACA49F9CA6B0B5B6A8998F89949EA4A69F9690
887F766E6A71787E837E7B787EA3C2D8CC5C000000004C93
D8FBFFFFFFD17529001C475D7472717B848E979DA2ABB0B3
A772411D114B89B6DFEDF4FFFFD2A58077C3FFFFFFFFEAC3
935B2A00000E3E6282888B95988F8377674D35211C3D617B
908E898A877E746B656A70747980868C8E867D7772737576
7B88949EA6ADAFB2A46F3C1606316386B2EAFFFFFFE37E2F
002351677E80818B8F877E76717478797975716F717C878F
938A807A7780898F938E898684858786847C746F6C6F7478
8093A4B3B8A4908075797D7E7F7D7C7C
9583736863768A98A29A918D8D9AA6AEAF9D8A7D747B8387
8B8B8B8D8D898683848D959B9D91867E7A858F969B9A9796
9285796E686E767B81868C9098B2C5D2BF4E0000000060B4
FDFFFFFFFFC671290023516A817C767D81878C8E919CA3A8
9D65310A0037759FC0BCB0AF96430000002099EDFFD38150
1C000000000033668E8C858984786A5A4A3A2D22223F5E76
8988848582786D645F6871787F85898E8F8479716B6F7477
7D87929AA1A5A6A69B724A2C1D3A5B728DABC4DCDFA97349
335D88A2B2997E70656B7274777A7D8183807C7A7A82898D
8F877F79767F878C8E87807C787B7D7E7F7B787776767879
7E8D9CA7AC9E8F847C7F848485848383
9686776D6A7E93A2ABA0938C878C919291877D7570757A7D
7D766F6A6766676769727A82857B726C6A747F868E93979C
9A8A7A6E666B7377808F9EA9B4C2C9CEB3410000000073D3
FFFFFFFFFFBA6E29002B5A778E867C7E7E80817F808E979E
935A240000256288A18D6F5F3100000000002BA1E6861C00
0000000000002F6D9A91817E73645442332D2A272C445D72
828381837F73675D5865737C85898C908F82756A646B7378
7F878F969B9C9C9A91745841344455616C6E7076786F6964
6B95BDDAE2B07B563D5168737E8182888C8A878584878A8B
8B837C77757C8388898178726E717476787A7C7E807D7B7A
7C87929A9E958C86828588898A8A8989
96877A706E849AAAB3A69890878685817E7975716F727576
74685B524C4F525559616970746D6662616B767D869099A1
A1907E70676A70727C94ABBBC8CECBC9A9350000000082EC
FFFFFFFFF7B06B2A05326381998D80807C7A787372818C94
8A511A0000175071846740270000000000000065BB4E0000
000000000000266FA3947C7463513F291B1E25293346596B
797C7C7E7B6F6258546475808B8E8F928F8071655E68737A
82878C929594928F887767584D4E51514E3D2F282A45647B
99C2E5FFFFBF7943203E60728485858D91908E8C8A8B8B8A
88827D78767C8286867B706964686E71757B808588837E7B
7B838B9094908C8A898B8E8F91909090
95887C7372879BA9B1A4968D837F7B76716E6C69696D7072
70625449414245464A545D666B645D5A5A636E757F8B969F
A18F7C6F65676C6F7A99B6CCDBDBD1CCA62E000000008BFD
FFFFFFFFE7A7682B0A376988A19384817C77726B69798790
88501B00001245627158331B000000000000004FAD3C0000
0000000000002D7AAF9C8176624D3921131E2C36424F5B68
73787A7E7C6F625854667885909191938F7E6E615A66747D
86888A8D8F8C89857F79736B635C544D41230B00002D628B
B5DAF7FFFFC4773A13365F758989878E9291908F8C8C8B89
87817C78767B818484786C645F63696D727A82898C86807C
7A7F8487898989898A8C8E8F90909090
91867C74717D8890948C837D797D80807D70635A56616D75
7B77726F6A5D5248455667737A6F635C5A6570787F84888D
8B7C6E635C61696F7D9DBCD3E3E8E3E0B9360000000084F9
FFFFFFFFDEA1672D0D3968869E9183817D79766F6F82929D
986635110029546C838E8E926D000000000028AAFBA03B07
0000000000065597C5B6A19989715A41323F4E586265686D
737A808484786C636170818C949492938E7E6F625C6A7983
8C8A88898885827E7A7A7977746F69655E4E42393A516B7F
96B2CADFDFAC785037516E7E8C8985878888878685868788
86807A75747B8286877B706863676C6E72787D8386827E7C
7A7D7F80817F7D7C7B7C7E7E7F7F7F7F
8C847B75707376787975716F707B858C8C745C4C44576D7A
878D9196937A614D445B73838C7B6A615C67747B807E7B7B
776B6059555C666E7FA0BFD7E9F4F4F4CD3F000000007BF3
FFFFFFF4D49C662F123A66839A8F83827F7C7A75778B9DAA
A87C51332440627693C3E9FFFF7B000000099FFFFFFFB68F
613F2503003D7FB2D8CEBFBBAE957C635462727B827C7574
747D868B8D82776F6D7A8891989693918C7D6F635E6E7E8A
928D8785817E7B78777A7E8183817F7E7D7D7D7D7C787573
768798A4A79079685F6F7F899089827F7C7C7C7B7C808386
877F7873717A82888A80756F6A6C6F717376797C7E7E7C7C
7B7B7C7B7A76726F6D6D6E6E6F6E6E6E
88827B76716D696664626262667786919273553F354F6B7D
909CA5B0AD8B694D405D7B8E98836E625A67737A7E78716D
675E56504F57626D7FA2C4DDF2FFFFFFDB450000000076EF
FFFFF6E9C8966532173D6783998F8483817D7B777A90A4B3
B48E684F41536B7A9BE5FFFFFFEE77200074F0FFFFFFFFEC
C59A744C3D6EA2C8E6DFD4D4C9AF967E6F7F90999E908179
75808B92958A7F7976828E969B9893908A7B6E635F70828F
978F85817B787672737B838A90909091949CA2A6A3907C6D
636B747A7E7B78787A858E95978C807871727474767C8186
877F76706E7882888B8279736F70727273757678797A7B7C
7B7A7775726D69656262626262616161
85807A767069635E5A5B5D5E647889989975533B304E6F85
9BAAB4C1BF9974564667889CA78F76685E6A767B7E766D67
615A54504F555E68799EC1DBF2FFFFFFE64B0000000072EC
FFFFECDDBC8F64351C406782978E8585837F7D787B92A8B8
BC9D7E6B5D616C7394F4FFFFFFFFEAA37FD4FFFFFFFFFFFF
FFDEB2897395BBD4E8E4DDDED6BEA7928596A6B0B39F8C7F
78838F979A9085807D8791979B96908C85786C6260738694
9C91847D76747270717B868F979A9C9FA4B3BFC6C3A5866E
5952504A4E617588979DA0A5A2907E6E63666B6C70788088
8A80756E6A7681898D867F7A777879797977767576787A7B
7B797775726C67635F5E5D5C5C5C5C5C
837D77726F707273757475767A87939C9B7D604B43618298
ABAEAEB3B099837068839EB0B9A1897A6F777F8284817D7B
77716A66615A57566086ACC8E1F9FFFFEA4A0000000074F1
FFFFE4D1AE87633823446881958F878886807A74768CA1B0
B6A18B7E6F5B50475DC3FFFFFFFFFFEBCBEDFFFFFFFFFFFB
E9C7A88C7F97B1C2CFC9C0BEB7A7988A8494A4AEB3A18F83
7C858F94968D847E7C848C91938D8580796E655D5D738898
A294847B73737472747C858D939495979BA7B1B7B6A79586
7251351D17416E8FACB3B5BCB7997B604E5660656D78838E
9385766C677481898F8B878584878A8C8B86807C79787877
787C7F82837F7B787572706E6C6D6D6D
827B746F6D7782898F8E8D8D8E969CA09D846D5C567493A9
B9B0A6A29C958F88899FB3C3C8B29A8A7D8287888A8C8D8F
8E88817C73605045486F98B4D0ECFCFFEA490000000076F5
FFFFDCC4A080633D2A496A8194908A8C89807870708599A7
AEA3968F7F57361F298FF7FFFFFFFFFFFFF9E9D1C0C2C4C3
BFAA978A8593A3AEB4ABA19B958D8780808F9FAAAFA09186
80868D919189817C7980878B8C837B756E655F595B738A9C
A696857A71737776787D83888D8C8C8D9099A1A5A7A7A29E
8C531F0000256594BCC5C8D3CDA278533A47575F6B798796
9C8A786B6472818A91908E8F90969B9D9C938A827C797775
767F889095928F8D8A8784807E7E7F7F
8178716C6C7C8C98A19F9D9C9CA1A4A5A08B77686583A1B7
C5B4A29992969C9DA3B6C6D3D7C1A997898B8E8D8E93989C
9D98918C80644B39365D87A4C2E1F5FFEA4B0000000077F4
FFFFD2B8947A6342324D6B80928F8B8E8C81776E6C8093A0
AAA8A2A292582703056EDBFFFFFFFFFFFFFFDBA0798BA2AA
B1A59A9694999EA09F958B847E7E7F7F83919EA9AEA1948A
83888D8F8F87807B797E8386867C736C655F5B575B748C9F
A99885786F73797A7C7E8184878788898C959EA3A7ADAEAE
994D0700000C5F9ACED8DAE7DEAA754829394E586779899B
A38E796A6170808A939494989BA2A8ABAA9D90857C787673
74828F9AA2A09C9B9894908C898A8B8A
80776F6A6C7E92A0ABA9A5A3A2A4A5A5A08D7C706E8BA9BE
C9B1988A808D9DA5B0C1CFDBDEC6AD9A8B8C8E8D8F979EA4
A7A29A9487674A332E557F9CBAD8EBFEE24A0000000079F2
FFFFC8AC8875654A3E556E8191908D908E81756B68798B97
A2A8AAAFA15F23000050B3FCFFFFFFFFFFFFBA6B37598092
A39C9496979694918C81776F6A6F767B838F9AA5A99F948C
86898C8C8B857E7A777C808382776D665F5B59575D748C9E
A89684776E757B7E807F7F8081808181848E989DA3ADB1B4
A14F030000035995CCDDE6F8F1B2723D192E4855677B8CA1
AA927B6A6070808A9395979A9FA6ACB0AFA192867C787572
758493A0AAA7A3A29F9B989491929392
7E77706B6C7987929995918E8D9297999683716462809DB2
BC9F826F63707F8794AABDCED2B597806F757D7E838B9299
9C948B8479635142426991ADC6D8DFE9CB440000000080F1
FFFFBE9F7D736C5851637686939290928F8073676371808A
95A1AAB3AB76452112447BA1CAEEFFFFFFD17F3E17467996
AC9D8C8883878A89867B7169656B72777E89949EA39C948E
898B8C8B89827C77757B818484796D655F5D5E5E63758694
9C8F817871777D8082807F7F7E7B7877798590989EA2A1A1
935F2E09002353759CC5E6FFFFBC6D310926495A708292A6
AE97806F6573828A918F8D8E8F959A9D9D92888079787877
7A86909A9F99928E8B8C8D8D8D8D8D8D
7D77716D6C757D8387817C787780888D8C796659567490A4
AC8C6C57495462697691A8BDC3A27F66545E6B6F777F868E
90867B736B605953597EA4BED3D7D2D0B0400000000086EC
FFF5B3937372736764717F8B949492938F7F70645E68757D
8899A7B3B28D684D383E484B5A82A5C4CA884618013A769C
B69D82766C76808282776D6763686E7379838C959A96918E
8B8B8B89867F7974727A8287887C6F67616264656A75808A
8F877E78747A7F8284817F7E7B75716D6E7C89939996908C
836F5C4D43474F556BAAE2FFFFC36A2900224B60788896A9
B19B85746976838A8F8983807F83878989837C7875787B7D
80878D92938A807A767B818588878586
7D77726F6D72787C7D756E6968737D8485726154516D889A
9F7C5942323D4C54638099B0B8936E53414E5E656F777E87
8A7E7269625F605F698DAFC8D9D1C2B9983D000000108CE6
FFE7A8886B717974747D868F959694948F7E6E6159606A70
7B91A3B2B69E826C52331700002350728048120000266895
B1937261556473797C7166605D62696D737B838A8F8F8E8D
8B8A8986837C76716F788187897D706862656A6C70767C82
85807B78767C828586837E7B776F68636371808B928B837E
7A7E81837E634D3C4493DEFFFFC8682500204E657F8E9AAC
B39E88776C78848A8D847B767376797A7A77747373787D81
85888B8D8B80756C68717B8186848283
807B767270737577766C645E5C69767F82705F535068808F
92714F382832404756728BA2A98561473645565E69717881
84786B635E61676B7899B9D0DCC8AF9D7E410B00003392D8
FFD39C7F66717E7D81868B91959593918B7A6A5D555A6166
71889DAEB6AB9A8C7139050000000F2B3B15000000266797
B38E664E3F556C767D7367625F63696C70757A8083848485
848482817E78736F6E79848C8F83776F6A6E727477787A7C
7D7B7977777D838788847E7B756C645D5C6B7B878E837973
73899CABAA7A4E2D2A80D2FFFFC96C2E05295368808E99AB
B19C87766C7783898B81766F6A6B6D6E6E6D6C6D6F777F85
8A89878682766C635F69747B817F7C7D
8C87817C797C7E7F7D7268615F6D7B85897B6D63606F7E87
88725C4D434A555A64768694987F655246515D636B727980
837B726D696B70727D9DB9D0D7B6937961544B40456F99BB
CDAF8F7B6C737B7D8085898E918E8A87807062564F555D63
6E8295A5AFACA49D8D6945250E131A1D20140D0C1A5084AD
C1946647355270808C837976737476757575767675716C69
676B7073767371717582909A9F978D878281817F7F808182
817C7773737A82878A86807D79716A646372818C93887E77
7585939D9C76533A397CBDEBFFC4855B3C495B5F6A7D8EA0
A7927C6C62707E85898077726E6E6E6E6D6865646673808A
9089817B76716D68666B707476757474
98918B858284878886796E656372818C91867B746F767D80
80756B6460656B6E737B818788796B60595F666A6F757A80
837E7A7775767879819DB7CBCFA3785848688BA0B0A89F9C
968C827972757A7C7F84888B8C87817C74675B514B525B62
6D7C8B99A4A9ABABA698877763462C170C1B2F3E567EA1C2
CC9965402B4F758C9D968C8B8785837E7976726D685E554F
4C555F676E6F70737A8A99A5ADA8A29E98948F8A86878787
857D75706E7780878B8783807C76706B6B798792988E837C
7881888D8B725C4C4C79A5C4D6BB9C89756B6458576D8394
9C866F615968788187817A777372716F6C65605C5E70818E
95897B726B6D706F6F6E6D6D6C6C6C6C
A19A928C888A8C8D8A7C6F656273838F968E847F7A797977
7676767677777879797A797977716C6865686B6D7175797D
807E7D7D7D7E808188A1B6C8C792603B3179C0F1FFD9A381
666D77757778797C8084878989827A736B60564D4A515A62
6C77828E9AA8B4BCC0BEB7AF9A612B00001747688BA5BAD2
D29960341D497896ADA69D9C98938D847B746D655D4F443B
3945535F6A6C6F757E90A1AFB8B6B2AFAAA39B938D8C8C8A
877D746D6B757F878C8984837F797470707E8B959A8F847C
7880878B8976645856718DA2B1B1ADADA4886E574C637A89
917B66595363747F86817B797573706D69615B56586D8291
9988766A62686F72736E696664646565
A59D958F8A8D91928F7F7065627487949D968D88827C7771
6F7882898D8985837F7A76716E6F70717272737576787A7C
7E808184858586858A9EAFBCB9814E292588E9FFFFFAA167
3B516B727C7B7B8185888A8B8880776F665D554E4C525B63
6B7178808CA0B2C0CBD4D6D8C47C370100246692BBC5C9D7
CE92582912467CA0BDB5AAA9A49C93887C72695F54463A32
303E4E5C686A6D737C8EA0ADB7B8B7B6B3ABA29991908E8B
877C726B69737F878D8A8685827D797575818D969A8F837B
767D8488887D726B686C7377829CB4C7CBA47D5F4C607580
85715D524E60727F88847F7D7975716C67605A56586D8191
99877568606972767870686360616262
99928A848189909493806E615D748B9BA69C918B837C766F
6E7D8B959B9289837D7C7C7A78787778797C7F828482807F
7F8387898B86827F808D99A29F734D313392EDFFFFEF904F
223E616E7E8488949B9B9997928B82797068605956585C60
6466696F77899AA7B1B6B7B9AC7C502C1F5288ACC9C6BDBD
AC76441A0A427DA6C5B9A9A59D968E82776D635A524B4642
444F5C676E6A66656876838E979A9C9F9F9D9A96928F8B87
8278706A68747F888E8B8685827E7A76767E878D8F847972
6F7B888F95938F8D8569523F3E6FA1C5D9B8947D6B737B7C
796A5B5351647785908C86847F79736C6766666669747F88
8D857D7874787C7D7D77716C696A6B6B
8D857E7977838E9697816C5D59738EA1ADA0928B827B766F
6F8193A0A7998B817A7E828283817F7E7F858A8E908A8581
7F858B8E8F877F79767C818683664E3D469AEAFFFFDE7E3C
0F30586A7F8A94A4AEABA6A29B948C837A736C6662616161
615F5E5F6371808B94969596917C69595981A9C5D6C4AEA0
885A300D03407EADCEBDA8A0948E887C72685F5753535658
5C656D74776C6159565E686F767B80858A8D9092918D8782
7C756F69697480898F8B8785827E7B77767B8184857A6F69
68798B96A1A7AAADA068340B00448ABDDFC7AA9D8D888278
6D635A5354687C8D98948D8B857D756D686D73777B7C7D7F
8184868888878583807D797674747575
847C7570707F8E999C836C5C577592A6B3A5958C837B766F
70879CADB5A390837A8086888A888686888E94999A918882
7F879094958A7F766F6D6C6B67584D4655A4EDFFFFD3702B
00235067818F9CB0BBB6AFA9A19A9288807A75706B696665
625B5551525E6A757E81848A8C87838087ABCCE3EBCBA68B
6B422001003E81B5D8C3AA9E908A84796E655D56545A6268
6E74797E7D6D5D51494E55595F656C737A82898F918C8580
7A746E69697480898F8C878582807D7A787B7D7F7E736963
64768996A4B5C0C9BA681B0000207BBAE9D6BEB6A8978672
625B5753576B80929E9A94928C82786F6A737D8488817A77
77828C9498938D898583807D7B7C7C7C
7E756D67677A8D9B9F866E5D577492A5B1A190867D787671
748BA1B3BBA58F80757D85888B8B8B8C8E959B9F9F948880
7B858F94968C81796F62574E49494E5267A8E3FFFFC26624
001E4A617C8C9BB0BDB7AFA8A09A938A83817F7D7B7A7877
7263564C474F5A626A6F747C838A9198A5C6E3F8FACE9D78
512E1300003E85BCE2C8AA9A89847F736A64605D5E6A7680
888D8F918D79655448494B4C4F555B636B77818A8E89827D
78736F6B6B7580888E8A868482807E7B797A7B7C7A6F6761
62758895A5BCCCD9C96A1000000867A8DED9CDD1C7AA8B6D
56545653596D8395A3A09B9994887D736E7A858E91847871
6F80929DA49B918B8585858382828282
8375685F5D748A9AA08972625B6F84919788776E686C7275
7C8D9CA8AC978272676B7173787F868D9395979895897E74
6F767F83888B8D8F8768493326374C59719FC8EAF1AC6632
0F284554667480919C98928F8A86827E7D848C9198A2A9AE
AA8D705849515B60676C7179807D7D7E8AB6DEFAFFCF986F
46270F0000428BC5EBCCA896827B766B65696F747D8C9BA8
B3B8BABCB6A28D7A6A65625D5A5A5C5E646F7A8389847E7B
7774737070787F8589868382807E7C7A797C7E807F766E69
697787919DAFBCC6BA6F280000104F79A4BED1EAEDBF8F68
494C5352596D8194A3A3A2A3A094887C767E868B8D81766F
6E80919DA4978A817B7E828384838383
88766558556E8698A18C7668606C777D7F6F60575461707A
848E959D9C897465595B5F606673818D9694918F8A7E7268
636970747B8C99A49F6D3C1906264B637E97ABC1C3966845
2B354348515B66737B79767675727171758495A2B1C6D6E3
E1B68B684E555F61666B70797D7167626BA2D6FAFFCF9368
3E210C00004591CDF3D0A7917A736F64626E7E8C9CADBDCD
D9DEE0E1DAC7B19D8B827A7169635F5C5E68737C837F7B79
77777776777B7E828482807F7E7C7A78787D8285867E7671
707A858B94A0A9B0A775441F091E3A4B6AA1D3FFFFD29263
3F4652525B6C7F92A1A5A8ABAA9E91867D828688877D746F
6F80909CA192827770777F8386848283
8B7561524D688396A08E7A6E64696E6E6C5C4E4544586E7E
8C8F90938F7D6A5A4E4F53545A6C7E8D98938C8981756A60
5A5F666A748DA2B3AF6E3001001A4E718F919097947F6854
4442423F4149525C636363656766686A72869CAEC2DFF7FF
FFD6A07655585E5B5E636872766659525B99D2FBFFCE8D60
341A0900004996D4F9D1A48B726B685E5E72899EB4C7DAEC
F9FDFEFDF6E2CCB7A3978B7E72675D5655606B757D7A7777
77797B7B7C7D7E7F7F7E7E7D7C7A7877787E84888A837C78
767C83878C959CA09B7B5B43302827243988D4FFFFE29561
384352545D6D7E90A0A7ACB2B1A6998D84868887857B736D
6E7F909DA2907D7069737E8488868484
8C7560504B6681939E8F7E736A6A6B686353463D3D556F82
918F8B8A847463554A4A4D4E55687B8B958E857F776C6259
555D666C7995ADBFB96D230000105380A1917E7971706E67
5F53483E3A40484E5455575B5E5C5D606A8199AEC6EAFFFF
FFEBB2856060635C5C626872745D4A3D458ACBF9FFCE895B
2E150500004897D7FDD3A3886D67655C5F7793ABC4D6E7F8
FFFFFFFFF7E7D5C3B2A69A8D81716358545D68707878787A
7B7D7F80807F7E7C7B7B7B7B7B797776777F868B8E87817D
7A7D808184898D8F8D807268593A210E1975CFFFFFE6945E
34425557616F7D8E9EA5ABB2B2A79B9087878684817A736F
707F8E999D8A786C646F7B8287858283
8A776659556B82929B8F817973787C7D7B6C5E5452647684
8E8C888783766A60585A5D5E636E7982878077726C635D58
5A6F8493A3B2BAC2B15E100000065891BAA2877E757C8280
7B6D5E534C535B60646260615F56504D51678093ACCFEEFF
FFE2B38F716F706968717A84825E3E272A77C2F6FFCE885A
2C0E0000003C90D3FDD4A58C736F6F66687E96AABDC7CED7
DAD0C5BAB1AEACA7A3A09D9A9486786D666A6F72777D8288
8B898583817F7D7B797A7B7B7B797776777F868C8E87807C
78797A7A7B7F82848583807F76573C282D79C2F8FFCE885A
37465A5F69747E8C989DA0A4A39A8F867F7F7F7E7D7A7877
787E85898A80766E6A70767A7D7C7A7B
87796D646172838F978E847F7C858E939385776D68727E85
8B898685827B736C686B6E707375787A7A726B66615C5A58
6182A3BBCCCCC5C1A5510200000360A3D2B593877D899596
9484746860676F7376726E6C67574A403E4F63748AABCAE4
EFD3B39B85807D74727E8A94906034151367B9F3FFD08A5C
2D0B0000003189CFFBD4A79079787971718396A5B1B2B0B1
AB9783726973808891989FA6A79A8C817776767476818C95
9A938B86817F7D7A78797A7C7C7A7877787F878C8E87807B
767575747476787A7E868D9391745B47477EB2D8E8B37C58
3D4D60677279808A91939495928B837B76777878797B7D7F
807E7C7B797775727172737374737373
867C736D6B77838C928D8784848F9AA1A395887E777D8486
888683817F7B787573777A7C7D7A76736F67605B57555658
6690B9D8EBE0CCBF9C480000000467B0E2BF98897D91A4AA
AB9986796F757C7E7E7A747068554336313D4E5B6F90AFCB
DACAB6A99A91897D7988959F985E29020057B0EEFFD18B5F
300A0000002A84CBF9D3A8927D7D8079798897A3AAA39993
866A513C324760728696A4B3BAAC9C90857F7B757584939F
A59B9089827F7D7976787A7C7D7A78777880888D8F89817B
7673706E6C6B6C6D74899DADB192735C547BA2BBC49C7358
4555676F797D80878B8A8988857F7A7471717272747B8186
877E756F6B6E727475726F6D6C6C6D6C
86817C79787D83878B8886868995A0A8AB9F938A83848786
86848181807F7F7E7F84888B8B837A736B625A555252575C
6E9ECBEEFFE9C9B38C42000000167AC4F6CEA28E8094A9AF
B1A08F847C808687888A8A89836E59483B3736363F5E7D98
AFB5B7BCB9A48E7A6F8598A49F6027000055B1F2FFD9966D
3E150000002982C7F4D0A7927F81857F7E878F9495897B70
604227120A24435B7690A7BEC9B8A49587807B73728394A1
A99E928A837F7D7876787A7C7D7A78777881898F918A827C
76716E6A676564656D8BA8BEC7A8897264798D989B846D5F
56626F767E7F808384817E7B7774716F6D6D6E6F727B838A
8B80736B656D74797B756F6C696A6B6B
8A8A898987837E7B797C7F81858C9297999087817C7F8283
85858587878787878991989D9E968C857C70655D595D646B
7CA5CCEAF7D5AF9371431D000055AFF5FFEBB3937883908F
8E847C79787B818691AEC8DCE4D2BAA788511D000000152E
5185B4E1F1B87D51375D849AA16D3E212179D0FFFFFABD97
6A3F1B00003C8AC6ECC9A28D7A7E827C78736D68625A524B
4130221816263A4B6286A8C4D1B3927A67686B696B77828D
94908B8884817E7B787A7C7D7E7B797879838C92958D847E
77736F6C696666666E8BA7BCC5AC907C6D6F737273747679
7B7A7979797C7D7E7E7974706D6E6F6F70717273767B8085
87837F7C7A7E8183837F7B7976777878
8D91959896887B706A70787C8082838585807B7775797D80
8386898D8F8E8E8E919BA5ACAFA79E978D7E716661677179
88AAC9E2E8BE9171544741374794DEFFFFFFC2997574756C
6867696F75767B8397CCFEFFFFFFFFFFD36D0A0000000000
0059B1FFFFCA6C2A00356D8B9E7855454D9EEEFFFFFFE0BD
9267411A105193C4E4C29C87757A7E7972604E4034302D2A
27242224272D353E507DA7C8D5AB7F5F47505D5F656B7179
808283858683807D7B7C7D7E7E7B79787A848E9598908680
7975726E6B696869708BA4B7C0AC968775665A4C4A647E93
A093847C76787B7A78716B6765696E7175757678797B7D7F
82868B8E908F8D8C8A89878584848484
8E989FA5A38D78675D6772787D7B7A7B7A78767473767A7D
81878C919595959699A6B2BABDB5ABA398887A6D67707D85
94B0C9DDDFAC79543B4A606C89C8FFFFFFFFCEA0766B6353
4C535E6C78787C859FE5FFFFFFFFFFFFFF82000000000000
0033AEFFFFDB610F00195D809B80676270BBFFFFFFFFFADA
B2865F372A6098C1DBBA978271777C786E5236200F0D0D0B
0D141B262E2C2C304075A5CBD9A7724D324153596163656B
71787E838684817F7D7E7F7F7F7C7A797B858F979A918881
7A7673706D6B6A6A728AA1B3BDB1A09683614228225284A9
C0A98E8073767976726A625D5C636C727878787A7B7B7B7C
7F89939BA09C979491908F8E8C8D8D8D
8D99A4ABAA91786559636F757A777373727272727375787A
7F868D949998969699A6B2BBBFB8AFA89E8E7F736D77838C
99B0C4D5D2986037245284A7CCECFFFFFFFDCFA98369523A
2F435A70827B787F96DCFFFFFFFFFFFFFF95000000000000
0023ADFFFFE05B0100034769877B71788DCFFFFFFFFFFFE0
BA93704C3F6D9CBED2B3917C6C747A786E4E2E1502000000
03101E2E38302B2A376C9DC2D09D674126394F5862605F64
69727A81868482817F80807F7F7C7A797B8690979A918780
7A777572706D6C6D73899EADB7B2A8A18E5B2D08004186B8
D8BA988675777A746F665E5958626D767D7C797A7A797979
7D8B99A4ABA39B959191929190909090
858F999FA09181756D72787A7D7B797A797A7A7A7A797979
7B838B91948E8885848C959A9E9C9997928579706B727C82
8DA5B9CAC7884C20125FADE4FFDDB097859DB3BBB5804C27
16406D8B9E856C625E748C99ADD3F0FFFA9A370000000000
004BAFFFFFC55E1700002331454F5C718FC6F9FFFFFFCDA6
806B5C47456F9ABBCDAD8A75646F7A7B78655244372C231A
17212B353C3632323B5F829CA784614838495C656F6E6E71
74797D808282818181807F7F7E7B797879838D94978E847D
77767573726F6E6D73879BA9B3B1AAA692551D00002D79B0
D6BD9F928483837B746C6560606B7780867E76726F727679
7E8A969FA4998E867F81838282818181
7D858C92958F89858180807F7F7F808181828182817D7A77
7780878D8F857A736F73777A7D808285847C736E6A6F7477
8097ABBDB9783B0E056ED4FFFFC95A0F003D94C8E1964A1C
054382A7BB9264492B100000002D71A6C59E735A433C3930
3B78B2DEEEAB65340A0405000625496A8FBBE1FFFFD29769
44424640497096B7C8A7846D5D6A797D817E7A78715E4C3D
33383E4245413F4045586A787F6F5E534E5C6A737B7D7D80
8181807F7E7F818181807F7E7D7A787778818990928A817A
7575767574716F6E738698A5AEB0ACAA95511100001D6DA8
D2BEA59D928F8B827A736D686875818B8F81736A646B7479
8089929A9B8E81766E70737374737272
767C83888C8E8F90908B86817F81838485858586857F7A76
747D858A8B7E70665E5F6160636A72787C77716E6C6E7171
778C9DACA7662B00007CF6FFFFC11B0000007ACEFEA24510
004491BCD19B5D350300000000001764A4A6A2AFB0A29382
7B99B4C2C29769482505000000063D6A96B7D0EBEBAE6F3C
18263940527495B4C2A07E665666777E8890969C9B836C58
4A4D5152524F4C4C4D52575B5E5C5A595C68747D85878789
8885817D7B7E808282807E7D7C797876777F878C8E867E78
73757777777471717484949EA6ACACAD994D0700001067A4
D3C1AAA59C9791867D78736F6F7D8A94978471645C667278
808990989888786A616468696A696868
6F74797D828A9096989087817D8185878888888886807A75
737B82868678695E55535351535C666F7674727271706F6D
6F7D89938D552300028CFFFFFFB7000000005EC4FFA94B1B
0456A6D1E4AB683B00000000000000398AACC6EDFFF1DCC7
B6BABCB4A9947D6A4E18000000003C6E9CB2C0D3CE8E4D19
000F2E3E577692AFBC9A78605161757E8DA1B2C2C7AE9480
6F6F716D6B696767655E57535259616870777F868C8E8F90
8F89837D7A7C7F81827F7D7C7B797877787E84888A837C77
737577787975737275839099A1A9ACAE9B500A00001469A7
D4C3ADA89E9992877E7976737584939EA18A726157637178
81888E9594837163585C616263626061
676B7074797E838788827C78767C8286888582807E7C7B79
797C7F807F776E686362636264686D72777A7D7F7F7B7671
6D6B696861432C1A299CFFFFFFB70B0000004796CFA06E5D
598FC3E0EECEA78B6321000000002D6599AEBED9E7E0D7CD
C6D0D8D7D3C7B7A99059270000255D85A9B4B8C3B980481B
00132F3F56738EA9B595745D4F5D707B8CAAC6E0EEDECBBE
B1B0AFAAA7A8A8A9A69B90888285888A8C8A8888888B8D8F
8E8A85817E7E7E7D7C7B7A79797A7A7B7C7F828384807C7A
77777777767371717583929CA4AAABAD9E632D02003E89BE
E2C8AA9C8C88857C75716E6D71869AAAAF957A685C67737A
81888D93938474685F62656667666465
60656A6D717475787875726F6F777F8588837D7977797C7D
7D7C7B7B7977757372737475767676767880878C8D867E77
6D5B4B3F37353A3C55ABF8FFFFB73000000030628F9090A0
B0C8DEECF3EDE1D7C39A7352425E7E96ABAFB3BDC4C7CACC
D1E2F0F9FDF7ECE3CD98663C29517D9AB3B5B1B4A7774922
0A1B324054708AA4AE8F705B4E5B6C778BB1D5F6FFFFFAF4
EDEAE7E0DCE0E3E4E2D5C7BCB2B0ADA9A49A908884878A8C
8D8A8785837F7C7977777777787A7D7F80807F7F7E7E7D7C
7B797675737170707484939EA7ABAAABA1764F312A68A7D3
EECCA68F7A7878716C6867676E88A0B3BB9F826E616B767B
82878C919185796F67696B6B6B6A6A6A
5B5E6266696B6C6E6F6D6B696B747E8588817A7572777D7F
817C78757376787A7C7D7E7F7F7C797778848E95978F837B
6B4D321D142A45597AB7ECFFFFB04400000018345B83AAD6
F7F9F7FAFBFFFFFFFFEACEB8A7A8ABABADADAFB4BBC5D0DB
E6F4FFFFFFFFFFFFFFCB95684F7093A8B9B2A7A3946A4221
0C1D323F536E869EA88B6D594D5869758CB9E6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEEDFD2CECAC3BAA9988A81858A8C
8E8C898886807B7673747575777B7F8284817D7B797B7E7E
7E7A767472706F707484939FA8A9A8A9A1856C575689BCE0
F2CBA1866E6D6E69676363646E8AA6BBC4A78872636D797D
83878A8E8E847A726B6C6E6D6D6D6C6C
5B5E62656768696A6A68676668737D8589827B7674797E80
817B757271777E838787868685807C787986939A9E968B83
714924070029597BA0C0D9F1EFAE6A350A0204001765B5FA
FFFFFFFEF9FFFFFFFFFFFFFFF4E3D2C3B7B1ADABAEBECFDF
EEF9FFFFFFFFFFFFFFE5B1876C849FACB6ADA19B8C69472C
1B283945566E8499A2876C5A4F5969748BB7E3FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF2E4DED7CEC2AC98877C81888B
8E8C8A8987817A7571727475777B808485807B77757A7E81
827C7774716F6F6F7483939FA8A8A5A59F8C7B6D6E9BC7E6
F3CA9F8067676965636060636D8BA6BDC6A98A75656F7B7F
8487898C8C847C767071727171707070
696D71747777777877726F6C6C757F868B8A898887837F7C
797777767881898F928A827C787879797C858E959A9B9897
8A5E35160D437BA5C5C3BDBDB9B5ACA1853A0000002390E3
FFFFF2EDE1D8D0C1B8C1C9CFD3D2D0D1CFC8C2BDBCC8D5DE
E5E5E3E2E2E8EBEADFB790705E718794A0A2A2A69F82654E
3E475359647585949A846F605863707A889FB5C9D9DAD9DA
D9D5D2CDCBD2D8DCDDD8D2CCC5BEB5ACA292847871798288
8C8A868684807C7976767777787B7E81827D7976757B8083
857F7A76737171707482909BA3A4A1A2997B604A487EB3D9
EECBA48B74717069656364666F869DAFB69D8371646F7A7F
85888A8D8D867F797475767575757575
787C818486868685837D7772717880868C92969A998D8077
7073787A7F89929A9B8C7D726B70767A7F84898E949DA4A9
A1744929215E9BC9E4C29F8984BCECFFFD72000000006AC7
FFFBDEDCCAA6835F4C648194A9B8C6D7E1D8CEC7C2CBD2D5
D4C9BDB4ACACABA89F846A574D5C6E7A8998A5B2B49C836F
61656C6D727D879093837267616C78808686858686858381
8080808081868A8E93999EA2A39A90888077706A68717C84
8A878382807F7E7D7B7B7A7A7A7B7D7E7E7B7876767C8185
87827D797674737174818D979E9F9E9E92694427225E9BC8
E4C7A795837D786E6868696A718292A0A5907B6C636E7A80
87898B8E8E87817B77787A7A7A7A7979
84888D9093918F8E8B837C77757A81868C969FA6A7948274
6A71797C838F9AA4A5917D6E646D767C8284868990A0AEB8
B48458362F73B8EAFFC181574FC0FFFFFFA60000000050B8
FFF4D2D1B9814C1A002C5D7FA2B9CCE5F1E3D3C5BBC2C8C7
C3B2A19387827E787162564E4A535E68768FA6BAC4B19D8E
8181817D7D83888D8D81756C68737E8484725F524643423F
3E4043474B4E52575E6E7D888E83776E6663615E5F6B7680
8784807F7D7F807F7F7E7D7C7B7C7C7C7C797775767D8388
8A857F7B7875747274808B93999B99998C5E35140D4C8DBB
DBC3A7998A837D726B6B6C6D727E899396857569636E7A82
898A8B8E8E88837E7B7C7E7F7F7F7E7E
8D9196999B9895928E87817C797B7E818695A2ACAE988272
676F787C83909BA5A7917C6C626C787F85838283899EB0BF
BE9064443D81C3F4FFB567312BBFFFFFFFC8000000003DAB
FFEECCCDB1661E00000034608CA5BAD6E3CFB9A6979DA3A0
9B8A796C6059534D48454243464B535C6B8AA7C0CEBFADA2
9693908986888B8C8B8178706D7983888466472F1B15130D
0B0E12191E20232932485D6E776C6058525356575B68747E
86837F7D7C7E80818180807F7E7E7D7C7B797775767D8489
8B86817D7A777674757F89909597959487582C0B013B78A4
C3B5A29C928A837871717272747A8086877A6E65626E7B83
8B8C8C8E8D89847F7D7F818283838282
8B8F939596918B878382807F7C77726F7182929EA3938276
6D6F7272757F889093867A726D767F8589827D7A7C90A2AF
AF8863483F70A0C2CF90562D2DAFFFFFFFB4000000004BB3
FFFADEE1C46E1A0000001B42676D707D7E654C35252C3436
3A3A3A3D3F40424344413F4044505D697991A7BAC3B3A093
87898B88888C90939285786E6977848A89735B48362C2319
1314171A1E1F22272F3F4F5C655F585553575D60666F7981
8684807F7D7E7F7F7F81828384848484837E7975747B8287
8A85817E7C7978767780888D9193919085613E2418375971
878D90989A9289817A7A7A787778797A786E665F5F6D7C87
8F908E8F8D86807A767B808486858484
898C8E908F88817C787C80828073675E5D6F818F968D817B
74706D68676E757A7E7C79787980868A8B8278717082929D
9E80624D435F7B8F956D4930369FFFFFFF9B000000005BBA
FFFFF1F7DB7B1D0000000829453A2B2A1F02000000000000
00000315252E363F4542403F435568778798A6B3B6A49182
777C8385898F959A9989786B6574838C8F817267594A3B2D
232122222425282D333D464F56555454565D656B71787E84
878582807E7E7E7D7D8185878A8B8B8B8A827B76737A8085
8884817F7D7C7A797A80868A8D8E8D8C846B534033373F44
50667D919E978E898483827F7B7773706C645E5A5C6C7D8A
9492908F8C847C7470777F8488868585
898B8D8E8C847C757179818684715F524D6176848E89817E
797169625E62676B7073777C80868B8F8E81746A66768690
927D67574D56606768503D303C95E6FFFF8D0000000060B6
FFFFFEFFED8115000000000B220D00000000000000000000
000000000C1924323B3B3A3B41576E7F909CA6AFB09D8979
6E7680848B92999F9F8C796A6373848D928A7E766A564330
2220201E1E2022272C32394046484B4F545F6971797E8185
878583817F7E7D7C7C82878B8E8F90908E867D7673797F83
868481807F7E7D7B7C808587898A89878171605244352920
23476D8BA19B93928E8D8B857F766D665F5A58565A6C7E8C
979591908B8279706C757F858A888687
8688898A887F766F6C77828989725C4D46596E7B86848181
7D72675E575B5F63686F767D84898D918F817266606E7B83
86796B625954504D49403C38478DCCFCFF7D0000000063B0
F5FFFFFFFF921F0000000003170000000000000000000000
000000000D1B26353E3E3E3F455C7384939BA0A6A4927F70
66707B8189939AA2A28C77665E6F828D95938E8B826B5540
302D2B28282A2E33383A3D4145494E5359646F7880828486
878583817F7D7C7B7C82888C909191918F877E7874797E81
84838181807F7E7D7D808284858584827E7870695C412917
13375D7A929594999A97928B82776C615A5656555A6C7E8D
98938D8B857D766F6C747D8489878485
7E818486857D746E6C78848C8D7C6B605965727A80818182
7F74695F5B626B71767676787A82888D8D82776E6970777B
7D7974716D6A676460554E47518DC2EBEC77060000005B9F
E1FFFFFFFFBA4B0000001C384F4435342A0E000000000000
101F2E3F4C5053575A5958575A66727C848A8D919084786E
686F777B828D969F9E866E5D54677C89969A9B9F9B867160
514E4D4A4B535B646A6A696B6B6A69696A70767B7F818284
8582807E7C7B7B7B7C8085888B8A888785817D79777B7E81
8382818180807F7E7D7E7F7F7F7D7A78787C80828072645B
5351515259728BA0ACA2958D847C756C6562605E616F7D88
8F867C77727374747577797B7D7C7C7C
777B7F82827B746F6E7A868E92867B736E7277797C7F8183
81766B63606C7981877F7672707A83888B847D7874747575
76797C7F81807E7E7A6E645A5F90BCDCD9710C000000518D
CDFDFFFFFFE17622001B516D898C8D999B857160586C818F
999691908D87817B767472706F70727476797C7E7E78726E
6C6F73757A87919A9A8066544B607685959FA7B0B2A08E7F
72706F6C6F7B88949C9A9695918B857F7B7B7C7C7D7F8182
83807D7B797A7B7C7D7F828485827F7D7B7B7B7B7B7D7F80
8181818180807F7E7D7D7C7B7A75727072808F99A1A3A1A1
956D472A205081A5BDAC999086827F78726D6A6768727C84
867A6D64606A747A7E7A767372737473
7175797D7E77726E6E7B8790958E86817C7A7977767C8084
84786D666372818B9083766E6A747F858985817F7B76716C
6C77828A908D8A88857E78717393AEC2BA65130000014C80
BCFAFFFFFFFF9D4E1B477A95B2C0CBE0E9D9C9BDB9D1E9F7
FEEEDCCEC0B4A89A8F8B8884807A74706E6D6E6E6E6C6A6A
6A6B6D6E73818D97977B604D4459718294A6B5C5CBBCAB9E
93908F8C8FA0B0BEC7C2BBB6AFA69C928A8683807E7F8081
827E7B7978797B7B7D7E7F80807C787574777A7C7E7F7F7F
8080808080807F7F7E7B7978766F6B696E869EAFBFCACFD4
C47F3D0900357AA9CBB69D94898887807A76726E6E757C81
817061565262737E857C736D696B6D6D
6D7276797B76716F707D899197948F8C88827C76747B8186
877D736C6B7B8B969B89786C656F7B818686858683797069
687787929B9792908F8F908D8F9FABB3A65D180000054470
A9F2FFFFFFFFB468366295B0D0E6FAFFFFFFFFFFFFFFFFFF
FFFFFFF9E3D2C3B1A29D99948E8378716B69686767686A6C
6D6C6B6B6E7D8A9494785D4B42556D7D91A6BACED8CBBCB2
A8A4A39FA2B5C9D8E2DBD1CBC2B6AA9E938D87817E7E7F81
817E7A7978797B7C7D7D7E7E7D7874706F74797D80807E7E
7E7F808080807F7F7D7B7876736C67656C89A7BDD2E4EFF9
E78D3700002173AAD3BCA1988E8D8D86807C787473797E82
816F5E524E6276848C81746D676A6D6C
747577797A78767577818A9095918D8A87827E7A7980878C
8E867E79798896A0A3907E716970797D8285878A8A817871
6F7B889298918B888A9BABB4BCC0BEBCA7601D0000003257
8DE0FFFFFFFF9A450F437E9EC2D7EAFFFFFFF3E6E0F5FFFF
FFFFEDDDCDC1B7AAA09C9996928A837E7A7A7B7B7B7B7A7B
7A767370717D8891917962524A596A778698A9B9C2B8ACA4
9B94908A8C9FB3C2CBC4BAB4ACA39B928A86827F7D7E7F80
817F7C7B7A7B7C7D7D7E7F7F7E7A767372767A7D7F7E7E7E
7E7F808080807F7E7D7B787775706C6B7189A2B4C5D5DEE5
D5843700002772A5CCBBA5A097928D837C79787677808A91
9385776D6876838C918A827D7A7B7D7D
7B7A7979797A7B7C7F858B8F928E8A878482807E7E858B91
948F8A878794A0A7A89683766C7177797E83898E90887F7A
7780888F9289817E83A4C4DAE8E0D2C8AB631E0000002244
78D0FFFFFFFB7D2100216488B0C3D4EEFBE7D2C1B7C7D6DD
DFD3C5BCB2ACA7A09B99979593908D8B8A8C8E8F8F8D8B89
86807A75737D878E8E7B685C545E69717B8A97A3AAA39993
8B827B73738699A8B1A9A09A948F8A847F7E7D7C7B7D7F80
81807F7E7E7E7E7D7D7F8081807D797776787A7C7E7D7D7D
7E7F8080807F7E7D7C7B7A797874727176889BA8B5C1C7CD
BE7A3907002F729FC3B8A9A8A1968C7F767576767A8794A0
A59A8F878289909395928F8D8C8D8D8D
7F7C7A78787B7F8185888B8E8F8D8A888584838283888E94
97959392949FA9AFAE9B87786D7075767B838B93978E8680
7D82888D8F847D7982B0DBFAFFFBE2CFAB631E0000001635
69C5FFFFFFF06C0B000E577EA9BDCEEAF6E1C9B7AAB6C2C6
C7BDB3ACA6A3A19D9B9998979695949494989B9D9E9B9895
90877F77747D858A8B7C6D635C61686C727E899399948E8A
83786F6665788B99A29A918C8683817C79797979797C7E80
82818080807F7F7E7E7F8081817E7B7977797B7C7D7D7D7D
7D7F8080807F7E7C7B7B7A7A7A7776767A8896A0AAB6BDC3
B6783C0E0033709ABCB6ADAFA99B8C7D727377777D8D9CAA
B2A99F9A959799999999999999999999
85807B78767B8185898B8D8F908C888683838484868A8E92
9698999B9DA5ABAFAC9985766B6F74767B838C9498918A85
81848688887C736F7AB3E9FFFFFFF2DBB261150000001339
70C8FFFFFFE55E00000048719CAFBED9E4CDB5A1929BA5A7
A8A29C999696969696959494949597989A9FA3A6A7A39F9B
958B8279747C8387887E736C676769696C767F868B888380
7B6E635A58697C89928C84807B7A797675757576777A7D80
8283828382817F7E7D7F8081817F7D7B7A7B7C7C7D7D7D7D
7E7E7F80807F7D7C7C7B7B7B7B7A797A7D8690969EA9AFB5
AA73401808396F93B2B3B0B5B19E8A786B6E74767E8FA0AF
B8B1A8A29D9D9D9B9A9C9D9FA0A09F9F
8D847C7673787F83898E9398999188827D7F818284848587
8990969A9D9D9C9A94847568616A747B8284868A8B898784
81807F7E7B6B605A65A2DDFFFFFFFFF0C458000000002A6C
B4F3FFFFFFE36503000041648A99A5BBC4AF988679848F93
97938E8D8C8C8C8B8B898888888A8D8F9295989B9C999591
8C847C757279818689827B7672706E6D6E79848C908B8480
796D6258556677838D898483807F7D7B79777676767A7E82
8485848584817F7C7B7D7F8081807E7D7D7D7E7E7E7E7E7E
7E7E7F7F7F7F7F7F7E7D7C7B7A7979797B838C9197A0A5A8
9F70452416406D8DA9B0B3BBB89F846E5D626A6D758696A5
ADA1938B858A90939594939494949494
94887D7570757C818790989FA194877D767A7E80827E7B7A
7C8690979B948B857D70645A576675818A8681807F818282
807C77756F5C4E46508FCEFBFFFFFFFFD34E0000000043A0
F8FFFFFFFFE06C0D00013B5979838B9DA4907B6B616D7A80
86848282828281807F7D7C7B7B7E8285888A8D8F8F8C8986
827C76716F777F85898682807D787571717D8991968F8680
786C61585563737E888786878684827F7C7A7775757A7F83
8686868785827E7A787B7E7F818080808080808080807F7F
7F7E7E7E7E7F8081817F7C7B797878787A81888C91979A9C
946E4A2F24476D87A0ADB5C0BE9E7E63505761656D7D8B99
A08F7E726B7683898F8C888887888888
9A8C7E746E747B7F86929CA5A79685786F757C80817A7471
72808D969A8D7F756A6058505063768690877E79767B8081
8079716D654F3F343E80C2F1FFFFFFFFE1470000000056C9
FFFFFFFFFFD86C0F0000314B666C707F836F5C4C434F5D65
6C6E6E72747474747472706F6F747A7E828486888986827F
7C76726E6E767E848989898A88817A74737E8A92958D837C
74685D54515D6A757E808285878583807D7A767373797F84
8888888887827D79777A7D7F818181828383828281818080
7F7E7E7D7D7F818383807D7B79797878797E8285888B8B8C
856A513E37506C8196A8B6C5C49E7859444D5A5E68768492
978370625B697982898681807F808181
9A8C7E746D72797D838F99A2A4927F7168717A7F81776E69
697887919586756A5F57514B4E647A8C978C7F7872787C7D
7C756D685F4836293273B4E3FFFFFFFFDB390000000068E9
FFFFFFFFFFCF6D1300002C435B5D5E696B594739313D4A53
5B5F62686B6C6B6B6B686665656B71767A7D8082827F7B78
74716E6C6D757D848A8C8E908F877E7875808B91948B817B
72685F56535D6871797E8186888683817D79757170787F85
8A8A898987827D7976787C7D808182848584838382818180
7F7E7D7D7D7F828384817D7B79797978797C7F8182838282
7C68564945586D7C8EA4B6C6C69D72523B48575E68737D88
8B786557505F707A827F7A7978797A7A
8B8279736E7276787B818589897D7168636D777D80766D67
65717C83877F77716B625B55576E8496A2998F89827E7972
6C6B6A6A644E3C303771ABD4F0E8D4CA9D18000000006FEA
FFFFFFFFFFC369160006334A62646570736251443C455056
5D62676C6F6E6C6A6866646262666B6E72777B7F807B7671
6E6D6D6C6E767E858B8C8D8E8D87807A787F878B8D87817D
77716C67666C747A8084878A8B87827D78736E6A6A747E86
8C8A878684817D7A78787A7B7C7E80828383828281807F7E
7D7D7D7D7E7F8081817F7D7B7A7979797A7E818385868686
806C5A4C475A6F7E8FA3B3C2C1986E4E3A4D636E797A7A7E
7E72675E59626C737878777878797979
7C7875727072737474737272706964605F6A747C80766D67
646B72767A7A797A786E665F61778E9FAAA69E9A92837566
5D646A6E6D5745393D70A1C3D7C0A08C61000000000075E4
FFFFFFFFFFB8651A000F3B526A6E6F7A7D6D5E524950585D
62686D7275726D6B67656361606366686C72797E8079726D
696A6C6D70787F868B8C8B8C8A86817D7A7E83858684817F
7D7B7978787C8083868A8C8E8E87807A746E696464717D87
8E8A8583817F7E7B7A797878787B7E8082828181807F7D7C
7B7C7D7E7E7F7F7F7F7E7C7B7A7A7A7A7B7F8386888A8A8B
85705D4E485B718090A1AFBCBA936C4D3B546F7F8A827976
726E6B6764676A6C6F72757779797879
707172727272716F6D6964615D5B5A595B67727B7F766C66
6265696A6E74797E80766D67687F96A6B1AEA8A59B85705C
505E6B7476604B3E3F6B94AFBC9D775F3600000000007DE4
FFFFFFFFF7AD6421001942597073747E8173655A52575E60
656B717679746E6A6663615E5D5E6062666E757B7D756D67
63666A6D717980878C8C8A8A8885827F7D7F818282828181
818284858788898A8B8F919291888079716A6560606E7C87
8F8A84817E7E7E7D7B79777575797C7F81818181807E7C7A
797B7D7E7F7F7E7E7E7D7B7B7A7A7A7A7C8084888A8C8D8D
887461524C5E7280909FABB7B58E684A3B58788B9787766D
66686B6A6A686766686C717578777677
696D71747673706D69645E5A565656575B67737C81796F69
6464666568727B84887D746E6F8398A6B1B1ADACA2876C55
495E7482886E55454266889DA5835D4320000000000C7FD8
FFFFFFFFE6A6662B07264A5F75797B85887C6F655E626769
6D72777C7E79726E6965625F5D5E6062656D757B7E756C66
62666B6E727980878B8A8988868482807F7F7F8080818182
84878B8E90908F8F8F92939391898078716A645F5F6D7C87
8F8983807D7E7F7E7C79767474787C7E81818081807D7B79
787B7D7F807F7E7D7D7C7B7A7A7A7A7B7D8186898C8E8E8F
8A7765575161727E8C9CA8B4B38E694D3F5F8095A18C766A
61666D6E6F6B6766666C727679787778
7074797C7D7874706D6F7172716B656263707D868C847B75
71727373757C83898B817771707D8B959DA1A3A5A0866D58
506F8DA1A986624B405F7F919A866E60481A0000002477B6
E8EBE5EADAA46E3E20375363747B818B8F8479706A707679
7C7F808283807D7A76706B6664676C6F73797E83847E7772
6E6F707072787D82868787878783807D7C7E818384838383
838383848487898B8C8D8E8E8C86807B76706A6666727D87
8D8883807E7F7F7E7D7B7877777A7E8082828181817E7C7B
7A7C7E808180807F7F7D7B7A79797B7C7D8185888B8C8B8B
87786B605B626C737E94A7B7BA99775E506A85959E8F7E75
6E6F72717171727375787B7E807F7F7F
787C8083847D7773727B858B8D81756E6B78868F958E8681
7E7F818183878A8D8D837A7470777F838990969C9A826C5B
5981A7C2CC9E70503E597685918D858477502D120A3A6D92
B4C1C9D6D0A4765138495D67747D8691978C827A757C8488
8B8A898888888786837B736E6B71787D8285888B8B87827E
7A77757272767A7E8283858786827D7A787D828688868482
817E7B79787D8286898887878684817F7C76726E6D767F86
8A8783817F80807F7E7C7A79797C808284838282817F7E7C
7B7E808182828181807E7B7978797B7C7E82858889898887
837A706964646768718CA5BAC1A2836D607488939B918681
7B78777473787D818485858686868787
7C8185898A827A757584929DA1918177727F8D969C968F8C
898A8B8B8B8E909290887F787374767679838C95967F6B5C
5D8FBEDFEBB57D573E536C78858C919A987B604B40516471
829AAFC3C7A27D624E59666C76828D99A0968C86828A9297
9A96918F8D8F90908E847B74717982888E8F9091918E8B88
837E79747275797B7E80828585807B77767D83888B888583
807B777372787F848785838281828282807C777473798085
88868382808081807F7D7C7B7B7E81838584838281807E7D
7D7F818283838382817E7B7877797B7D7F82858889898785
827B75706B6563616886A3BAC5A98D7A6D7D8D949A938C89
85807C78777E868B908E8C8C8C8C8D8D
8085898C8D847C76778B9EACB29F8B7E768390979D989391
90909190909293939189827B7672706D6E767E8688746358
5F9AD2FBFFCA885B3A4C636C7C92A6BBC2A98E7A68605C55
597B9BB4C0A2836E5F666F717886929FA69C928C88919A9E
A19B96928F939698968B8078757F8A92989897989794918D
89827C767375787A7D7F8183837E7975747C83888C888482
7E78736E6C737A8084817E7D7C80838585817D7A787C8083
8584838382828181807E7C7B7B7E81848684838281807F7E
7D7F818283838383827E7B7877797B7D8083858889888684
817C77746F68625E6483A1B8C3A98E7C707D8B929794908F
8C85807B79838C94999591908E8F9090
8285878988817A75778B9FAEB4A08B7D737C858A8D8A8787
8687878787898A8B8A85807C78777674716D686662544B44
5299DCFFFFD78A552E415B657AA3C9EBFAD2A6876A5F584B
4E7295B2C1A38471626973757C88939EA3978A827D858D92
95918D8B8A8F929493877B73707D8B959D9C9B9C99948D87
817D7A7776797D8083828181807B7773727980858884807E
7B77736F6D72777A7D7B7878797F85898B85807C797C7F80
8283848585848382807C787574797F8386848382817F7E7C
7C7D7F8081818181807E7B79787A7C7E8083868889878583
807B76726F6C6B6A6F879CADB293755F53677D8A94908B8A
88837F7B7A838C9397928D8B888A8B8A
83848485837D7774768B9FADB39F8A7B70757A7B7D7C7C7D
7D7D7D7D7E7F818282807E7C7A7C7D7C766554483E353332
4798E4FFFFE28B4F2337535D78B2E8FFFFF5B98F685C5546
476D92B1C2A48471636B76797F8A939C9F91827771788084
8886848485898D908F82766E6B7A8B969F9F9E9F9C928980
79787978797D8286888582807D79767271777D8183807D7B
787673717072747576757373757E868C8F89827D7A7B7D7D
7E818487888684827F79746F6E757D8286848281807F7D7B
7A7B7D7D7E7E7F7F7F7D7C7B7A7B7D7E8083868889878482
7E7974706E7074767C8B98A3A17E5C4337526F82918B8585
82807E7B7A838B91948F898582848584
86848382807A7673778DA1B1B7A28C7C6F70727171727476
7878777878797A7B7C7D7D7D7D808180785C412E201D2225
4099ECFFFFED8D4B1B2F4C5776BFFFFFFFFFCD9A6B5B513D
3D658EB0C3A58573656E797C828B939B9D8D7D71696F777B
7F7E7E7F80868A8E8D80736B68798B98A2A2A1A19E92867C
747578787B80858A8C87827E7A77747170757B7E817D7A77
7574737170707071716F6F6F727D878F948D85807C7B7C7A
7B8085898B8885837F78716C6A727B82868482817F7E7D7B
7A7A7B7B7C7D7D7E7E7D7C7C7B7C7D7E8083868889868381
7D78736F6E747A7E848E959B956F4B302342647A8C888283
817F7E7B7B838B91938D86827E808181
8684817F7C787572768CA0AFB5A18C7C6F6D6C68676B7075
7876747473747576777B7E7F818586867C5A392110111A20
3F9BF1FFFFF28F4B1829444D6DBFFFFFFFFFD59E6B5B513D
3B648CAEC2A5867467707A7D828A90979888786C64697074
7778797B7E83888B8B7E726A68798B97A1A3A2A3A0938579
717377787C82878D8F8A837F7A77767372767A7D7F7C7876
747575757472706F6E6C6B6B6E7A8690958F87827D7B7A77
787E858A8D8A85827E77706A68717B81878481807E7E7D7B
7A7A7A7A7B7C7D7D7E7D7C7C7C7D7D7E7F83868889868380
7C77726E6D757E848A9094978F69452A1D3C5E7588837D7F
7E7D7C7A7A81888D8F89837E7B7C7E7D
82807F7D7B777471748697A4A99A8A7F74706D6868717B83
88827C7875767778797F84878A8C8C8C83674B3728272E32
4DA2F1FFFFF19556232838374F9BE4FFFFFFC69A72645B4A
486889A5B59F87796F747A7B7E83888D8E82776F6A6E7376
797B7D808386888A89807873717D8A939CA0A2A5A3978A7F
777778777980868C8F8B878481807E7C7C7E808182807D7C
7B7C7E7F7E7A7774716E6B696A76818A908B86837F7B7874
737C848B8E8A84817D78736F6E757D838683807E7C7D7E7F
7E7E7D7C7C7D7E7F807E7C7B7A7B7C7D7E83878A8B878380
7C77726F6E737A7F8590989F9C7F624C40536976817D7879
78777776767A7E8183807D7B797A7B7B
7E7D7C7C7B76737072808E989D93888179736E6969788691
978E837D78787A797C83898F939493928A745E4E43404345
5CA8EEFFFFEC9A602F2A2D243376B7EEFFE1B193756C6659
5770899EA999877C74767978797C8083847E787371737678
7B7E81858788888887827E7A7A81888E949BA0A5A59A8E84
7C7A7876767D848A8E8C8988878786858585858585838281
8184868888837E7A76706C6868727C848A888584817B7671
707A848B8F89837F7B797775747A7F8486827E7C7B7D8082
83817F7E7D7F8081817E7C7A797A7B7B7D82878B8C888380
7C77736F6E7175797F8F9DA8AB957F6F636B74787B787474
73737272727475777878787979797979
7B7B7A7A79757270717B868D928C85827C746E68697B8D9B
A295877F78787A7A7C858D94999A9998927F6C5E54515455
68ABE9FFFFE69C67382B2617205B95C6E4C29D87736F6E67
677A8C9BA395867D757577757577787A7B79777574757778
7A7E8386898886858482817F7F8285878B959DA4A59B8F86
7E7A7874747B83898E8D8B8B8B8C8C8C8B8A888786858584
85898D90908A847F79726C67666F787F85858484827B746F
6D78838B8F89827D7A797978797D818486827D7A797D8184
8683807F7E808182827F7C7978787A7A7C82878C8D898480
7B77726F6D6F73767D8FA0AEB4A493877C7C7B787673706F
6E6E6F6F706E6D6D6E71747678777777
7A7978787774716F707981878B8782807C736C67687D91A0
A899898077787B7A7D868F979D9E9D9C9787766A615F6263
73ACDFFFFFD998693F2E241315426F95AE9982776D717675
7987949FA29382766D6F7272737374767778797A7A7A7A79
7A7F83868886838180808080807E7D7C7E8A949CA0968B84
7C787672717980878C8B89898A8C8E8E8E8C898785848484
858B919597918A857E777069676E767C81828284837B756F
6E78828A8E87807C797A7C7C7D80838586817D79787D8285
8784817F7E808283837F7C79787879797B82888C8E8A8481
7C77726E6C6C6F727A8EA1B1B9AEA0968C87817A75737271
71707070706D6B69696E73777A797878
7D7B787674727170727C868D90887E78716B666163778A99
A194857C757679797C848C93999B9B9C97837163595D6468
78A4CDEDF6C1875D38312E232334465866615C5D606C7880
8B9BA8B2B193755D4D59676E7577787C7F8182838382807E
7C7E7F80807E7C7A79787675736E696667737E868B827A74
6F6F706F70777D8386817D7A797E82858684817F7D7B7A79
7B848C9397948F8C878079736F757B7F82828182817D7976
757B818688837E7B787A7C7C7E81848687827D79787C8082
8482807E7E7F8182827F7C7B797878787A80878C8F8A8582
7D77716C696A6C6D75899CABB3A392867D7E807F7F818386
87837F7C7A787776767A7E8184838283
817D78747271717174808B9396897B716763615D60728391
998D8078727477777A81888E9397999B96806A5A5059656D
7C9DBAD1D6A7765032353B38352C2422242D39445265788A
9BAEBCC7C39568442E435C6A787A7C83878A8C8C8C898582
7F7D7B7977767574726F6C69655E5751515C6870766F6864
6265696C6F757A7E8078716B696F767B7E7B78777572706E
707B878F969593929089827C787C8082848280807F7F7E7D
7D7F8081817F7C7A797A7B7C7E81848787827D7A787B7E7F
817F7E7D7D7F8081817F7D7C7A797877787F868C8F8B8683
7E77706B6767696A708496A5AB9783756B747E83898F9499
9B958D88838384838386898C8E8D8C8C
847E78737070717276828E979989776B605E5D5B5F6F7F8D
94897D76717376777A80868A8F94989A967F68574E5B6B75
8397A8B7B7906848313C484A462405000000182D46607A94
ABBFCDD7CF975E31163353677A7C7E878D91939494908B86
817D7974717171706E6A66635D534A42404B576167625C5A
5A5F65696E73777B7C7268615D666F7478767372706C6A67
6976838D9697979896908A837F81838383817F7E7E808283
84827F7E7C7B7A79797A7C7E7F82858787837E7A787A7C7D
7E7E7D7D7D7E7F80807F7E7D7B797776777F868B8F8B8784
7F776F69646466676D8092A1A6907B6C63707E879199A0A8
ABA298918A8B8C8B8C8E919395959494
867F78726F7072737885919A9C8975675B5C5F5F63707C88
8E847A746F7377797B7F83868A909598947C66544C5D717D
8A92989E9A7C5E44344658605B2C00000000081F3B597694
AFC8DAE8DF9D5B2707274D63797D808A9296989998948E88
827B756F6B6C6E6E6D67615C55493E36323E4A535A565252
535A61656B717579796E6259545D666C71706E6E6D686562
64717E889195979A9B948E888384858584817E7D7D818587
88837E7B787979797A7B7D7E8082848686827E7B797A7C7C
7D7D7C7C7D7E7F80807F7E7D7C797775767E868C8F8D8986
81776D65606266686F7F8E9B9F8A75665E6D7D87939CA4AD
B1A79D958E8F908F909295989A999899
867F7874717376777C88929A9B89776A60666D70757B8086
887F77716D747A7F82817F7F80888E92907964544D637988
94918C8B8472605048596A747454341E0F152027354B637A
95BCDDF7F7B26B35112C4C5D6F767D899295959694918C87
81787069656A6F7272685D554C41372E2B36424C53514E4F
5054595C616B737A7C6F625852575D616467696D6E696562
636B757C838A9096989189827E8184858582807E7E818486
86837F7C7A7B7D7D7E7F7F808081828282807E7C7B7C7D7E
7E7E7D7D7D7E8080817F7E7D7B797775767F878E92908C8A
8475675C56606B737D858D9596887A706970797D848B9197
9A96908C8886858384898E9396959494
857F79757275797B808A92999A8A796D66707B8186858485
837B746F6C757E8488827D797881898D8C7662544F688192
9D91837B726A635C5B6D7E8B90806E6255473C33313F5261
7BAEDCFFFFC47B451F344E5867707A8892929292908D8A85
7F756C64606A7378796B5D53483E362E2B36414B52515051
525354555967737D8173655B535558585B61676E716C6765
64686D7076808990948C837C787D8285868481807F818384
84817F7D7C7E80828382818180807F7F7E7E7E7E7E7E7F7F
807F7E7D7D7F808182807E7C7B7877757780898F94928F8E
877462534D5F72808B8C8C8F8E8780797474747475797D80
83838283817D7A77777F868C918F8D8E
86807A7674777B7E838C949A9B8B7B6F6A77858E948D8682
7D77726D6C7681898C837A74717A8389887360524F6A8699
A38F796C61616463697E91A1ACA59C95886C513B2E36444E
67A4DCFFFFD18750283A5057636E79879291908F8D8B8985
7F746A605D69757D7F6E5D51453C352E2C35404951515052
535251505464737F8476675D54535351535C656E736E6966
646566676B77828C91887F79757C8285888582807F818383
84817F7D7C80838586848281807E7D7C7B7D7E7F80808080
807F7E7D7D7F818282807E7C7B7877757780899094949290
89735E4D475E778996918A898584827E7A75716D6B6C6F70
7376797C7D7873706F7881888D8C8A8A
87807A7674777C7E838C949B9C8D7D726D7C8C969B918680
7975736F6F79828A8D837A73707A838988725D4F4C6A899E
A99177685C5F6668728DA8BECECFCAC7B88F65442D334047
5F9CD5FFFFD48E5C3745575B646E7986908F8C8C8A888582
7C7269605E6D7C868A7A695E534E4B46454E575F65646263
615C5854566878858B7F7169605D5B5859636D767C77716F
6C69676465707B8488817A75737A81858885817F7E7F8182
83807E7C7C808486888683817F7D7B79797B7E8082818181
807F7E7D7D7F808182807D7C7A7877767881898F94949291
8A725C4A45617E93A1978C868182827F7B756F6A66656564
666C72787A746E6A69737C8388878585
8B827A74707275767B88939DA08F7F736C78848C9089827E
7A7B7C7B7C7D7F8182828181828A909490745A47416487A0
AF9B867B706967636E9CCAEEFFFEF0E7D09E6D43293B5463
7BA0C1E0E9BA89654A57666B72787D858A8A898886817C77
736E6B686B7B8B98A19B959290959A9DA1A8AEB3B4ABA199
8F8479706D7B8A969D97908D8A898886878B909395918D89
85807A757272737374737273757A7F8385807B77767A7F82
837F7B79787C8183858381807E7C7A78787B7E8183828080
7F7F7E7E7E7E7F80807E7D7C7B7A7A797B81878C8F908F8F
88735F504D6A879DABA2959088827C746F707273746F6C6A
6A70777C7E77706C6A71797E82807F7F
8E847A726C6C6E6E7383929EA29280746C747C8083807D7C
7C80848788827C797880888E93999CA099785840375D849F
B2A595908775685D67A7E7FFFFFFFFFCDEA8744429476A81
98A3ABB8B99E826C5E6A777D8382818283858585837B746F
6B6C6F7179899AA9B6BABEC4CBD9E5EFF7FDFFFFFDEEDCCD
BCAA9A8C848F9CA5AEAEADB0B2B2B3B3B2B1B0AEACAAA6A2
9D968E877F756C6460666C71777A7E82827C75706E757C81
837E797574797D8082817F7E7D7B7978777B7F8183817F7E
7D7E7E7E7E7E7E7E7E7D7C7B7B7B7C7C7E8285888A8B8B8B
8674645857738FA4B2A99E988F827669626C767D827B7470
6F757C7F817A736F6C7176797C7B797A
908579716A6969696D7F909EA49382766D7277797B7A7A7B
7E858B9192867A73707E8D97A0A4A5A89F7A573B3158819E
B3ADA3A39B806A5962B0FEFFFFFFFFFFF4B87F4A2C517B95
ABA1969590877E75717C878F938B837F7B7D7F7F7E756C67
656A72798393A4B6C6D1DDE9F7FFFFFFFFFFFFFFFFFFFFF4
DEC7B3A0959DA8B0BABFC4CBD1D3D3D4D2CEC9C3BEBCBAB6
B0A79D9388766558515B676F777A7C808079716B69717A7F
837D777372767B7E807F7D7D7C7A7877777B7F8284827F7E
7D7D7E7E7E7D7D7D7C7C7C7C7C7D7E7F8082838485878788
84766960607B96AAB7AFA49E938272625B6A79848B817772
70767D81827B74706D70737476757474
91857A71696868676C7E8F9DA39483786F7173737476787C
8089919798897A6F6C7C8E99A4A8A9ACA37D593D32557C96
ACADAAAFA9876A545AADFFFFFFFFFFFFECB887573E638BA5
B59C82766C71797B818E99A4A797877A72787E818178706C
6B737C85909EACBCCDDEEFFFFFFFFFFFFFFFFFFFFFFFFFFF
F1DAC5B1A4A9B0B6BEC7D1DBE3E3E2E1DFD9D2CBC5C3C1BD
B8AFA59B8F7964544B57656F797B7C7F7F78706A6770797F
827D777472767A7C7E7D7C7C7B7A7877787C7F8284817F7D
7C7D7E7E7E7D7C7C7C7C7C7C7D7E7F808181818181828283
8278706A6B8197A7B2ACA39E95827060596B7D8A92877C76
72787E81827D77747171727272727171
8F857B746F6F717276828E989C91857D7575757475787D81
858B9195958A7E76727A82888E979EA4A0836752465B7280
8F969BA4A180634D4E91D3FFFFFDD6BEA5988E7E7785949F
A28D776A626A757C879BAEBEC3A88C786C7C8E99A19C9797
96989B9EA1A7AEB6C0D1E2F0FCFFFFFFFFFFFFFFFFFBF2E9
DFD1C5B9B1AFAFAEB1BAC3CBCEC6BCB6B0B0B0AEACA9A6A4
A09C98938C7F7268626970757B7D7F81827C777371767C80
827F7C7A797A7C7D7E7D7C7B7B7B7B7B7C7E808182807F7D
7C7D7D7D7D7D7D7D7D7D7D7D7D7D7C7C7B7C7C7D7D7D7D7D
7C7A787678818A909593908E8A7F766D6A76838C91887E79
75787C7D7F7E7D7D7C7A787675757575
8D857D7774777A7C80878E93958E86807B797775767B8185
8A8D8F92918A837D787777757885919A9C8874665C61686B
72818D9A9B7A5C464273A3C5D6AD846A5B7692A2ADA59B97
8F7D6D5F5863707A8AA7C1D8DEB78F73627D9AABBABBB9BD
BEBAB7B3AFADABAAADBDCCD7DCCDBDB3AAACAFAFB1B7BDC1
C4C1BEBBB6AFA8A29FA8B0B5B5A493867E848B8E908D8988
8788898A8984807D7A7B7B7C7D7F818484817E7C7B7D7F81
82818080807F7F7E7E7D7C7B7B7D7E8080808080807F7E7E
7D7D7D7C7D7D7E7E7E7F7F7F7F7C7A787777787979787776
777C818486817C7876797C7E7F7D7B7A7B82888C8E88817C
78797A7A7B7F828586827E7A78797A7A
8B847E7A787C8184888A8D8F908C87837F7B7774747B8389
8E8F90908F8B86817C746E68697989949A8D7F766C656059
5A7187979B79584036597C949C6E42261F5A95BED8C1A596
8371615049586A798EB2D2EFF6C4926E5A7CA1B8CDD1D3DA
DCD5CDC4BBB2AAA19EAEBDC7C7AC8F7B6C6D7172788898A7
B3B8BBBFBDB1A599929BA3A7A48D76665C6570777C787474
757B8185898A8B8C8B8884817F8183858684838282828282
828384858583807F7D7C7C7B7C7E81838482817F7E7E7E7E
7D7D7C7C7C7D7E7E7F808081807D79767474747474727171
737F8A92948271645C646D72787C7F84888B8D8E8E898480
7C7A79777880878D9089827E7A7C7D7D
88837E7A797E84888C8C8C8C8B898683807A7571717A838A
8F8F8D8D8C8987837E7268605F70818D958E858078695B4F
4E6C889DA37D563B2A445D6B6C3C0F0000408FC8ECCEA995
7D67554038495F718BB8DFFFFFCD8E60456991A8C0C9D1DD
E2DACFC5B7A797867E8B989F9C7A59402E2E32333C51687D
909BA2ABADA091847B848C8E8A725A493F4B586168646061
646E7880878D929698918A84808285858686868787858382
818486888985817F7D7C7C7B7C7F82858684817F7D7E7E7E
7E7D7C7B7B7C7E7E80818384837F7B77747271706F6D6D6D
718495A2A48769534552616A747B828A90908F8E8C898682
7E7B787677818A91958E86817D7F8180
837D787473787D8185898B8E8E87807A75706C6969727B83
888886868583817E7B746D6868737E868B847C78736B645E
6386A6BEC3905D38203C58686A3C120000306E9ABBB3A4A0
8F6844241329465979B3E5FFFFC976370B203B46576A7D92
A09E98948870563F2F363D3F3D2C1B100704040308182837
454E555D615B55504E565E62625649413C444D5358575759
5E69757F878A8D8F908C878380818383838383838382807F
7F8285878784817E7D7D7D7D7D7F81838482807F7E7E7F7F
7E7D7D7C7C7C7D7D7F8386898A8784817E78736F6C6B6B6B
738EA7BBBE956C4E3A4D626E7A7D80868B8B8B8B8A878380
7D7B7A797A80868B8E8A858380818382
7F78736E6D71767A7F858B8F90857A726A666461626A737B
81817F7F7F7D7B797775737171777C80817A736F6D6C6E6E
79A0C3DEE2A46636183758686D441D070026506D88959DA8
A06A350D000E2F4467ABE7FFFFC35F130000000000102C49
5F6363655B3C1B0000000000000000000000000000000000
02080D14191C1F22262E353B3F3E3E3E3F4245484C4D5053
5966737E86878687878584828080818080807F7F7F7E7E7D
7E8083848583807E7D7D7E7E7E7F80808180807F7F7F7F7F
7F7E7D7D7C7C7C7C7E84898E91908E8C887E756D68686A6C
7698B7D0D5A2704A334A6573817F7E82848687888784817E
7C7C7C7C7D7F82858685848483848484
7B746F6B696D72767B838A909084766C63605F5C5D656E76
7C7B797A79787876757676767778797A79736D6B6A6D7377
86B2D8F5F8B36C35122F4F5E633F1C09001B3A4E658197AC
A96B2C0000001F3359A4E7FFFFBF4E000000000000000015
32393C423914000000000000000000000000000000000000
0000000000000000050C12181F272E353A3B3B3C3F42474B
53616F7B848483838383838180807F7F7E7E7E7D7D7D7C7C
7C7F82848482807E7D7E7F7F807F7F7F7F7F7F7F7F808080
807F7E7D7C7B7B7B7D858C92969695948F82756B64656A6C
78A0C4E1E6AC71452A46657684817D808283848483817F7D
7C7C7D7D7E7F80818283848686868686
79736E6A696C70737881898F9082746A615F5E5C5D646B72
7878787979787775747678787979797A78716A67676D767C
8EBDE6FFFFBF73391230515F66482A1C1422354052738FA7
A86A2C0000001B2D519CDEFFFFB748000000000000000000
1D262B332C07000000000000000000000000000000000000
00000000000000000004090F1624303B42403E3E3F43494D
5563707C84827F7F7E7F8180807F7E7D7D7C7C7C7B7B7B7B
7C7E808283817F7E7D7E7F80807F7E7E7E7E7F7F80808081
807F7D7D7C7A7A7A7C858D94999B9C9C978472645B60696F
7EA6CBE8EDB173462946667785817C7E7F808181807F7D7C
7B7C7C7D7E7D7D7E7F81848788888788
7E7A777573747576797F85898B837B76706D6B68686C7175
797E838788847F7B7774716E6F7982898C7F726B66676C6F
7FB1DFFFFFC47D48254465757F69534A4552626B747E858C
8764422819273B475F91BDE1EAAA653105000000000F2A43
585C5E625E4A3421110B07010311212E362E25201C1E2122
23222122252C343B414345484B535A5F63615F5E5E616365
69727A8286827D7B797C7F8081807E7E7D7C7C7C7B7C7C7C
7D7E808182807F7E7D7D7D7D7E7E7E7E7E7E7F7F7F808181
817E7B7A787777777A838C92999FA2A59E80634C41536977
8BA8C0D7D9A97752394E65707C7B797D7F7F7F7E7D7C7B7A
79787777777A7E818384858788888788
8281807F7E7C7B7A7A7E818485848381807C787674757678
7B858D949790878179726C6666798B999F8D7A6F65626261
6EA3D4FAFFC785573857788996897C7877849198998B7C70
655F5A5553575D636E869CAEB59C826F5F5E605E616F7E8B
95949293918D8985817F7E7C7E8891999D958D8884888C8D
8D8883807E8082848484838383838484848381807F7E7E7E
7F82858787817B7775797D8082807E7E7D7D7C7C7C7C7D7D
7E7F808080807F7E7D7C7C7B7B7C7E7E7F7F7E7E7E7F8181
817D7A77757474747780899097A0A6ABA37B553829486A80
98A8B4C2C29F7C5F4C57656B7375777D807F7D7C7B7B7B7A
7875727071777E838887868686878787
8586868685827E7C7A7C7E808285878A8B8782807D7B7A79
7C89959EA2988C847B716961627A92A4AC967E70625D5D59
669BCDF5FFC98D6349688A9CABA8A3A4A6ADB2B3AC8F725B
4E5D6E79817C7777787B8083888F979EA4A5A7A9ACB1B6BA
BCB8B5B3B4BDC7CED5D4D4D5D8E0E8EDEFE8E0DAD6DADCDD
DBD2CAC3BDBCBBB9B7B4B1AEABA9A6A3A19F9D9B99979492
908F8E8C888079726F757B7F82807E7E7D7C7C7B7B7C7D7E
7F7F7F7F7F7E7E7E7D7C7B7A7A7B7D7E7F7E7E7D7E7F8181
817D787673727272757E878E95A1AAB0A8794B2919406B88
A2A7A9B1AF98806B5C6167696D71757B7F7D7B7A79797979
78736F6C6C757E858A88868685868786
87898A8B8A86817E7B7B7C7D7F858B90928E898683807D7B
7D8C99A4A89B8E847A716A63657F97AAB2997E6E5E585651
5C90C0E7F8C48E6B54708E9FB0B6BBC3C9CDCDCCBF956D4D
3D5F839BAC9E8F8A82766D656887A7C1D6DADBE0E2E1DFDC
D8D1CDC9CBDDF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFAF2EAE6E2DED9D5D1CDC8C2BCB7B3B1AFADABA7A3A0
9C98938E897F77716D73797E82807E7D7D7D7D7C7C7D7E7E
7F7F7E7E7E7E7E7E7D7C7B7A7A7B7D7E7F7E7E7D7D7F8081
817C787573727272757D858B929DA5ACA374472516416E8E
A7A39D9E9A8F83766D6C6C6B6C71777C807E7B7A797A7B7C
7A746E6A69737D858A88858483848585
82848586868482807F7E7E7D7E83888C8E8985827F7E7F7E
808A939A9C90847B7476797A7E8B979FA08A7362544E4D49
5380AACCDAAE80614B5A6D758497A9BCCAD0D2D4C99F7655
456C94AFC1AF9B92887F7A73748CA4B7C7C7C5C7C7C8C8C7
C5C0BBB8B9C4CFD9E1E4E6EAECF0F2F3F3F1EEEBE9E9EAE9
E7E1DBD5D0CDCAC6C3C0BEBBB8B2ACA8A4A4A3A2A19E9B98
95918D8A857F7A7573777B7E807F7D7D7D7E808081807E7E
7D7D7E7E7E7E7E7E7E7E7E7D7E7E7F7F7F7F7E7D7D7F8080
807E7B79777778787A7F85898C8D8D8D856B53403A58778D
9E98908E8A85807A767778797A7E82858785838281848687
867D746E6B737C828684828180818282
7E7E7F808081828282817F7E7E82858788847F7C7A7D7F80
83888C90908479716E7B8890979794938D7A67584C474644
4D7194AFBA96715743454C4D587695B0C6CDD0D5CDA57F5F
5179A3BED0BAA3978B88878384919EA9B1ADA9A8A6AAADAE
AEAAA6A4A3A6AAACAFB3B6B9BBBCBCBDBDBDBDBDBCBCBBBA
B8B7B5B3B1AEACAAA8A7A7A5A39E9A96939495959492908E
8C8A8785827F7C7A797A7C7E7F7E7D7D7E80838485827F7D
7B7C7E7E7E7E7E7E7E7F808181818080807F7E7D7D7E7F80
807F7E7D7D7D7D7E7E828486857D756F6964615E60707F8C
948C837E7A7C7E7E7F828487898A8C8D8D8C8A89888D9092
91867B736E747B7F82807E7E7E7E7E7E
7B7B7C7D7E8082848583807E7E81838585817D7A797C8183
8687888A887D726B6A7F93A1A9A0948B8070605246424240
48647F949E836653423A36323A628AACC8D0D3DAD3AB8565
5885B2D0E3CAAE9F918E8D8888939DA6ACA7A29F9DA0A3A4
A4A09D9B99989797989CA0A4A6A4A1A09FA2A5A7A7A6A4A3
A2A3A4A5A5A2A09D9C9C9D9D9B96908C898B8E8F8F8D8B8A
88868481807F7E7E7D7D7D7D7D7D7D7D7E8285878884807D
7A7C7D7E7F7E7D7E7E80828384838281807F7E7D7D7E7E7F
8080808080818282838383827E706258535F6C757E83878C
8C81766E69737D848A8C8E919393939392918F8E8E93989B
9A8D807670757A7D7F7D7C7B7B7B7B7B
7979797A7B7F82858683807E7D7F8283837F7B78777C8083
8585848481766D66678098A9B2A28F8273675C5047454545
4B5D6F7D83725F5244352B2127537FA3C0C4C4C9C3A4866D
648DB7D3E3C9AD9D8E8E8F8B8B90969C9F9993908D909394
9492908E8B87837F7E83888B8D89848281858A8D8F8C8A88
888C8F9293918F8D8C8E8F8F8E8A85817F82858788868584
8281807F7E7F8081817F7E7D7C7C7D7D7E8286888985807C
7A7C7D7E7F7E7D7D7E80838485848381807F7E7D7C7C7D7D
7E8082838585858583817D7A7465574D4B62798A97928B89
83776C625E6C7C8791939497989795939190908F8F959B9E
9D90837871757A7C7E7C7A7A79797A7A
7C7B7B7B7B7D808282817F7D7D7F8182827F7D7B7A7B7D7D
7E7F80807F766F69697A8B979C8F80756B65605A56595D60
64686C6F7069615C54473C34375A7C97A89B8B837B787672
768CA2B2BAA6908176777A797B80858A8C89848280818282
83828181807D7B78787C7F82837F7B78777C808384817F7D
7C7E8182838382828282828282807F7E7D7F81828382807F
7E7E7E7E7E7F8081817F7D7C7B7C7D7D7E80828484817F7D
7B7D7E7F7F7E7D7D7D7E808181828282817F7C7978787879
7A7F83878985817E7A736C67636466686E7D8B979D948880
776F6861606D7C8790919091908B86817E7F8282858A8F93
93897E7671757B7E807E7C7B7A7B7B7B
7F7E7C7C7B7C7D7E7F7E7D7C7C7E808182807F7D7C7A7977
777A7C7E7E78716D6C757E83857C726B66656666686F767B
7D756C6661646768675C534C4D647A8B9071533F354D6879
888B8C918F8173675F6267696C7074787B79777674747372
72737475767574737376787A7B7774717074777A7B787574
72737474747677787877767676787A7B7C7D7D7E7E7D7C7B
7B7C7C7D7E7F8080807F7D7B7B7C7D7D7E7E7E7F7F7E7D7D
7D7E7F7F807E7D7C7B7C7C7D7D808183827E7A7674747474
777E858A8C867E7972665C545364768491979CA1A0938578
6E696662636F7C878F8D8A89867E77706C6F74767A7F8387
8880797370767C7F82807E7D7C7C7D7D
817F7D7B7A7B7C7C7C7C7C7C7C7E7F7F80807F7E7D797673
7175797B7C77726F6D717577766E66615F646A6F75808A92
927E6A5B525D6970746B615B5A69757E794D2305002C5F83
9C8E7C756B635C524D545C6166656465656565656462615F
5F6265676968666565676869696663605F63666869666462
61616161626467696A696867686D71757777777777777675
76787A7C7D7F8081817F7D7B7A7B7D7D7E7D7C7B7B7B7C7D
7E7F7F80807F7D7C7B7A7A7A7A7E8183837E787471717271
747D868D8F877D766C5D514747638096A8ABAAADA8968372
6463646265717C868E8B878580766C635E63696D72777A7F
807B767271777D8183817F7E7D7D7E7E
83807D7B7A7A7B7B7C7B7B7B7C7C7D7E7E7F7F807E797470
6F73797C7E7A76737170706E6C676360616A747C85919CA4
A3896F5A4F61748088827A76727778786A370900001C5E8D
AC91726354515049474E565D625F5C5C5B5D5F5F5F5B5754
54585D60636260605F606161605D5A58575A5D5E5F5D5B59
58585858595C5F626362606061676D727575737373737372
7376797C7E7F8081817F7C7B7A7B7D7E7E7C7A79787A7C7D
7E7F8080807F7D7C7B7A7979797D8082837D787471717273
767F878D90887F796F5D4E42426588A3B8B6B0B0A895816F
6162656569737D868C8883807A70675F5A5F65696D717478
7A77747373787E82858381807F7F8080
85817D7B797C7F80817E7B79787A7B7C7E7F8081807C7875
747B818688847F7C7A7A7A79797777777A828B9299A0A6AB
A99480706A7D92A0ABACA9A9A59B8F837251341D18457395
AB9780746968686462636567696A6B6D6F737679786F665F
5B61676B6E6D6C6C6B6C6C6C6B6866646364666767666565
6566676768696B6C6C6B6A6A6A6F73767977767575757676
77797C7E80808080807E7C7B7A7C7F80817F7D7C7B7C7D7D
7E7E7F7F7F7F7F7F7F7E7D7D7D7E7F807F7C797676797D7F
828587898A8D8E8E89756255516D8A9FAEA8A09C968C8278
706D6B686A7580898F88817C777674717070707172747577
797878797A7E81848685838382828383
87827E7A797E828586817B7875777A7B7D7F8082827F7C7A
7A828A90938E88858282848485888B8E93999FA5A9ACADAE
AB9D91878599AEBDCBD1D4D7D2BDA5917D6D6053526D899E
AC9E8F877F8182807E79747271767B7F848A8E929183756A
636A72767A79787878787878777472706F6F707071717272
73757778797877777676757575777A7B7C7B797877787979
7B7D7F818281807F7E7D7C7B7B7E80828482807F7E7E7E7E
7D7E7E7E7E80818282828181807F7E7D7C7B7A7A7B81878C
8E8A868485909BA3A38D786962768A979F978D8883848482
7F78716D6C78838C90877E79757B828586827C7977777878
797A7C7E808284868786868585858585
89837E7A797F85898A837B767376797A7D7F808384817E7C
7D8791989C96908C888889898B9299A0A6ACB1B5B8B7B5B3
B0A79F999BAFC5D5E4EFF6FDF8D8B69B847F7D77798898A5
ADA2968F898D929291887F79767D858B91999FA5A4928072
69717A7F83828182828282817F7E7C7B7978787777797B7D
7E8082848482807F7E7D7D7D7D7E7F7F7F7D7B7A797A7B7C
7D8081838482807F7D7C7C7B7C7F828485848281807F7F7E
7D7D7D7D7E80828485848483827F7D7B7A7A7B7C7F878E95
978E857F7F92A4B0B49F897A717F8D94988C7F78737C8489
8A817872707B868D90857B74727E8A92968D847E79787877
777B7F83868686878888888887888888
8A847F7B7980868B8C847D777476797A7C7F818485827F7D
7F8A959DA19A928E8A8A8B8C8F97A0A8AFB3B5B9B9B6B2AE
ABA7A4A3A7B9CCDBEAF7FFFFFFE5C3A68F88857F8093A5B6
BFB0A19891989EA09F9489817D848B9096A0A8B0B09B8777
6D757F84888888898A8A89888785848381807E7D7D808385
87898B8C8C8A87858383838383838282827F7D7C7B7C7E7F
8081828484827F7E7C7C7C7C7C7F828486848281807F7F7E
7E7D7D7D7E81838586858483817E7B79787A7D7E828B939A
9C90857D7D93A9B8BEAB96887D828788877C736D6B78848D
92887E78757E878D8E8379727181909BA19589817B7A7A78
787C8185888887878787888888888888
8C86817D7B8186898B86817E7C7C7C7C7C7F838586817C79
798590989C9288817C7F8283868B8F949899999999979695
93918F8F929CA8B1BCC7D1D7D9CEBFB39E6E44221C65AEE4
FFDFB49D89929C9C9B948D898582807D7F8C97A0A2907D70
676E767A7E808285878786858483817F7E7D7C7B7C7E8184
85868585858382808080818181818181817F7E7D7C7D7E7E
7F7F7F7F7E7E7D7D7C7C7C7C7C7E7F81817F7D7B7A7C7D7E
7F7F7F808082838383807D7A787879797A7A7B7D7F858B90
938F8B898A99A6AFB2A39285797069615E666E767D818489
8B87837F7D8287898A827B7676818D95998E847D787A7D7D
7F7F8081828281828282828383838383
8D88837F7D8185878987868583817F7D7C80848787807974
74808B93968A7D756F73787A7C7D7E80807D7B7978797A7A
7B7A797A7B7F83868B939A9EA4B1B9BFAD5708000037B2FF
FFFFC29E7F8A979493918F8F8C80746B6877858F9384746A
63686E7074787C8083838282817F7E7C7A7A7A797A7D7F82
8381807E7D7D7D7C7C7D7E7F7F7F7F7F7F7F7E7D7D7E7E7E
7E7C7B7A797A7B7C7C7C7C7C7C7C7D7D7D7A787676797C7E
8081818282828282807B76727073777A7C7B7B7C7D808386
898C8F91949A9FA2A1988E8578624F3F3A526C7F8E8A8484
838586858585868685817D7B7A82888D8F867E78757A8083
85827F7D7B7C7C7C7C7D7D7D7E7E7D7D
8D8884817F8184868788898A8985817E7D818587877F7772
707C88909284766C656B727577757373706B66615E606264
66696B6E6F6B6867676B71737D9CB5C9BC4B0000001CB7FF
FFFFCFA27C8897919192929593806E615A6A7A858B7E7068
63666A6C6F75797F8282828281807E7C7A7A7A7A7B7E8183
84817E7C7A7B7B7B7B7D7E7F8080807F7F7F7F7F7F7F7F7F
7E7B79767577797B7C7C7C7C7C7C7B7B7A77747373777B7E
81828383838382807D77716C6A70767A7E7C7B7B7C7D7E7F
828990969A9B9A9996938E897C593A221A3F6683988F8482
80858A8B8C898583807F7F7E7E83878A8B837B76737B8388
8B857E7B77787878787879797A7A7979
8A8683807E80818284878A8C8C87827E7C808486867D756F
6D79858C8E80716660666D7173706C69665E58524E505355
585D6165655E56514C4746424C7FABCECA5100000011ADFF
FFFFC498727E8C87888D9096957F6A5A5262737E847B706B
67696C6D6F74797D81818181817F7E7C7B7B7B7B7C7F8183
83807C7A78797A7B7C7D7E7F80807F7F7F7F808080808080
7F7B78757476797B7D7D7D7D7D7C7B7A7876747272767B7F
828384848483817F7C756E69676E767C80807F80807E7B7A
7A81878C8F8B8784838B91948B613A1D113B68879E91827E
7A838B8D8E89837F7C7D7F7F80828486857E7873717B858B
8E877F7B767676757575767777777777
7F7C7A7877797A7B7D7F828485827E7C7A7D8081817A736E
6D78838B8D81756C676B7072747371706F6A65615E5E5F5F
6165686B6B67625E5438200E115495C5D88D421000397CA6
C09D786456606B6E747D848C8D7D6E625D6B798389847E7B
797B7D7D7E7E7E7F7F80808181818180807F7E7E7E7F8081
817F7C7B7A7B7D7E8080808080807F7F7F7F7F7F7F818182
827F7D7B7A7C7E808181818181807F7F7E7B7A78787B7D7F
818282838382817F7D77726E6D737A7E848A8F93948C827A
71686058535254555F809EB6BF9A745949617A8891867A76
7379808486827E7B79797A797A7C7E80807A74706F788188
8C8984827F7C79767576777979797879
747372717172737475787B7D7E7C7B7A797A7C7D7C76716E
6E7882898C837A736F7174747677787979777472706E6D6B
6B6E72737373706F602F0300002E7FBAE2C7A6957D654D33
22272F353D444C57616D7780847B726C6A7581888F8D8B8B
8B8D8E8E8D8884807E7F808081828384858381807F7F8080
7F7E7D7C7C7E81828382818080807F7F7F7E7E7E7F818284
848381808081838485848484848484838381807F7E7F8080
81818182828180807E7A777574797E8288939DA4A698887B
69513A281B1C232A3F75AAD6EFD0AD9582868B87837B736F
6C71777B7E7B79787776757474777A7C7C77716E6D767E84
8989898988827D7875777A7B7C7B7A7B
6C6C6C6C6D6D6E6E6F72757879797878787879797873706D
6E7780878A837C777474757576787A7C7D7D7C7B7A777471
6F7376767678777563200000000B6BB0EAF1EDF4DB822800
000000112A2F344452606D787E7A7572717A83898F919396
98999A99978F87807B7C7E7F8082848687858382807F7F7E
7D7C7C7C7C7F8284868482807F7F7F7E7E7E7E7E7F818385
868584848385868788878786868687868685848383828181
80808181818080807F7C7A79797D81848A9AA8B1B2A18C7A
6340200500000007236BB1EDFFF7D5C1AAA198887B736E68
676B707578777575747372707073757777726E6C6C747C82
878A8C8E8D867F7975787A7C7D7C7B7C
68696A6A6B6B6B6C6D70737577777778787777777673706E
6F777F8588847F7C79787776777A7E8184848484837E7A76
75797E7E7F82807F6B23000000005EA3E3FFFFFFFF9C1B00
00000005272829394754606A7275787A7D82878A8F959A9F
A2A3A3A39F948980797B7D7D7F81838688868482817F7E7C
7B7B7B7B7C808385878482807E7E7F7F7E7E7E7E7E818385
868686868687888888888888888889898989888786848281
80808080807F7E7D7D7C7C7D7E828689909FACB4B5A28B78
5D361100000000001868B7F9FFFFEBD7BFAC9A82706D6C69
696D71767977747372706F6E6E71747778736F6D6D747B80
858A8D919189817A76797C7D7E7D7C7C
707071727373737374777A7C7D7D7C7B7A7A7A7A79777574
747A7F8385837F7E7C7A7A797A7F84888A888684827E7A77
7780898E92918C897B4D2303002E668FB7D5EAFFF8A85715
000A2F4152483F4143464B4E56677886918F8D8D8E969EA2
A6A7A6A5A1968B81797A7C7C7D7D7D7E80808181817F7D7B
7A7A79797A7D80838482807E7D7E808080807F7F7F808081
81828383848383838384858687898A8C8C8A888785838280
7F8080807F7A76737174787B818A939BA0A2A19F998B7C6D
5A3D220E020816223D7CB8EBFFE8C2A98F857B6C646B757C
8386888C8C847D767171727173797F8587827C7876797D7F
83878A8E8E88817C787A7C7D7D7D7C7C
7879797A7A7B7B7B7C7F81838482807E7D7D7D7D7D7B7A7A
7A7D80828382807F7E7D7C7B7C83898E908B8683807C7977
7986949DA39E979289776658525F707B8BA1B4C5CAAF927C
6C757E807E6C5B4F453E3B383F5B7891A29A908D8B949DA1
A5A6A5A5A1968A8079797B7A7A797777787B7E80817F7D7B
7A797878787B7E8082807E7D7C7E8081828181807F7E7E7D
7D7E7F8081807E7E7E80828385888A8C8D8B88868382817F
7E7F80817F776F6A686E757B83919EA8ACA193887C756D64
5A493B312E374450658FB6D6E3BE96785F5C5C57596B7E8E
9C9E9FA19E92857A7172747477818A92968F87827E7F807F
8084878A8B86817D7A7B7C7D7D7C7C7C
7E7F7F808080808181848687878582807F7F807F7F7F7E7E
7E7F80818181828282807E7D7F868E9396908A87837F7C79
7C8D9EABB3ABA39D989A9C9B9684756A677E95A7B7BABCBF
BFBCB6AEA0876D5844362D252C537B9CB3A5958E89949EA2
A5A6A5A5A1968A7F78787A797976737272777C80827F7C7B
7978787777797C7E807E7D7C7C7E8182838281817F7D7C7A
797B7D7F7F7D7B7A7A7D7F8184878B8D8F8C88868382817F
7E7F80817F756B65626A73798396A6B3B7A28A786865635E
59514C4A4C586671819CB4C7C9A2795B424247464F69849C
AFB0AFB0AB9B8B7C717275767A86929CA29A908A8583817E
7E8184878985817F7D7D7D7D7D7D7D7D
858585858585858686878989898784818080818282828283
838281808082838485827F7E7E868E9396918B88847F7C79
7C8FA2B1BBB1A7A1A0B1C0C8C59F7A5F4F6279889DB8D1E8
F5EAD9CCB9A189725C493B2F325980A1B5A490867F899396
9A9B9B9C998F857D767779797975727070767B8082807D7B
7A797978787A7C7D7E7D7B7B7B7E8082838381807F7C7A78
77797B7D7E7B7978787A7C7D8084878A8B888582807F7F7E
7E7F80817F756C66646D777F8896A1ABAB947B685A5D6263
666B70777E858C9298A2A8ACA5825F4430323A3E4B6987A2
B7B9B7B8B2A08E7D717275757B8895A0A79E948E8784817D
7B7E8183858381807F7E7E7D7C7C7C7C
8B8A89898888878686868585858381807F80818283848485
858483828183858686817C78777C818587858382807A7571
738697A6AEA59B95929DA7ACA99078675C68767F8B97A2AF
B7B4B1AFADB3B7B8B5A5958880868D8F8E7E6F645D62686B
6F73777B7E7A777574777A7C7D7B7A79797B7E8081807E7E
7D7F808080807F7E7E7C7B7A7A7C7F8182817F7E7D7C7B7A
7A7A7B7B7C7B7A7A7978777676787A7B7C7A787676797C7E
80807F807F7C79777986929B9C8A776A5F5D5D5D616E7C8A
99AEC0D0D6C6B3A3938D867B7164584F4847494C55697E90
9FA4A6AAA79787786D6D6F6E727D8892989189847F7D7C79
787A7B7D7E7F8081817F7D7B7A7A7B7B
8F8E8D8B8A898886858482817F7E7E7D7D7F818283858687
8786848382858687867F787370727576787A7C7E7E766F6A
6B7C8C98A0978D8883878A8A887F77706D7176797B767271
747C8791A1C1DEF6FFF9E9DDCAB29980695C51453E3E3F42
474D545C6266696D71767B7E818282828282818180808181
81848688888582807D7C7B79797B7E7F807F7C7B7A7B7C7C
7D7C7B7A7A7B7C7C7C7773706D6D6D6D6D6C6B6B6D73797E
82807F7F8084888A8F9EA9B1AA7D502E192C44556B7F95AD
C8EBFFFFFFFFD3AF8C77644E424A545D645F5C5D606A757D
868E949A9A8D7F746B6A6A696A737C8488837D7A77777776
76767677787B7F81827F7C7A78797A79
9592908E8C8B89888683807E7D7C7C7C7D7F818385868789
8987868483868888877E76706B6B6B6B6C71767B7C726A64
6474848F968D847E797B7D7C7C7A787674706C68645B5552
556171819CD0FFFFFFFFFFFFFFD1A2734E423A2E27222123
283039434D565F6971777C8184868788878583817F808283
84888B8D8E8984807C7B7A79797B7D7F7F7D7B79797B7D7E
7E7C7A78787A7D7E7D766F6A6664636262616263676F777E
83807E7E808A9398A0AFB9C0B37132020008304E708BA7C7
EAFFFFFFFFFFF3C08D694927162E4A61736D6769696C7071
757F888F91867A7169686765666D747A7D79757271727474
7573727172787D8184807B7976777878
95928F8D8A89898785827F7C7A7A7A7A7B7E808385868788
8887858383858787867D756E68666563656D757C7F746962
606F7D878D857C777271706E6E74797D7D746A645B4C4039
3A4F6980A1D5FFFFFFFFFFFFFFE0AB784E41372920191516
192028323D4955626C747A8186898B8D8D8B888584848686
878B8E90918C86817E7D7C7B7A7A7B7B7B7A7978787B7D7F
7F7D7A78777B7E807F766D66605F5E5C5C5D5E61656D757D
83817F808494A3ADB4B8B6B4A1622600000633557A93ADCC
F0FFFFFFFFFFFAC1885F3C1605274D6B837C737473706E69
69747D84887F756F6A696967676B6F7375726F6D6D707375
7673716F70777D8284807B7876777878
888582807E80828383817E7D7B797775757A7E8284838180
7F7E7E7D7D7F8182827C77736F6C6A686A78848E9384756B
667381898E877F7B7674737171767A7E807E7B7A74604F44
466D96B6CDC5BAB7B5BDC4C5C4C1BAB3A68B705844413F3B
39363436394149525B656E7880878C919598999A9996928E
8C8C8D8D8C8B898887858482807A7672707276787A7A7B7B
7C7C7C7B7B7E818280766D656061646668696A6C6F72767A
7E82878B94ADC2D1D1A87D5D454B54565D66707E898B8F94
A3CEF6FFFFF1C29F7C6756413A516A7E8D867D7B77777774
74797D80817B75716F7376787A7978787875737271767A7D
7F7C7977777B808384817D7A78797A7A
7C79767373777B7F81807E7E7C78757171777D81837F7B78
76777777777A7B7D7E7B79787672706E7182939FA5938174
6D78848B8F89827F7B79777474777B7E82888C908E776252
548CC0E6F2B16E4121334C576F9BC4E8F8D1A7876C6C6D65
5E5146403C3E43474E5965717C848B939AA1A7ABABA49B94
8E8C8A8786898B8D8E8D8B89857B726A666C74797D7B7979
797B7D7E7F81838482786E6661666D707476777A7B797777
7A828D94A1C1DBEFE8954509003682B5DAC7AEA79883705B
547290A5B19D887B71717270727D8891968E86807C7E8080
807F7D7D7C797674757D848A8D88827E7B797876767C8186
8885817F7E80828384817E7C7B7B7C7C
726F6C6A6A70767B7E7E7D7E7C77726E6D747B80827C7672
6F717273747577797A7A7A7B7B76737174899CABB19E897B
717B85898C8882807D77736F6F757C8288929AA2A1846A55
569AD9FFFF9F34000000000D3682CAFFFFFFCDA9888B8D83
786552453C3B3D3F46525F6C79838C969FA9B1B7B8AEA299
908C888482878D909392908F8A7C6E635D6772797E7B7878
787B7E808284858784796F66626A72787D7F8184847E7875
76829099A9CFEEFFFA881B000024A2F7FFFFDDC8A7805C33
1C2E4453615D5A5F667686929C9FA0A2A098908882848686
85807A777575757679848E979B9188817B797977787F868C
8F8B87848283848383817F7D7C7D7D7D
6E6A6765656C73787D7E7E7F7E7974706E747A7F807A7470
6D6F717274757577787B7D7F807B7876798EA1B0B6A28D7E
747B84878A8683827F78726D6C737C828B98A4AFAF91755E
5C9ED9FFFF8B150000000000015FB9FFFFFFDFBFA2A7ABA2
96816C5D514E4E4D515A65707B81878F96A1ABB2B4A99E94
8B86837E7C82888D919291918D7E70655E68737A807D7A7A
7A7C7E7F80848688877D746D6A727B81878A8D908F857B75
737F8C94A4CAE9FFF4760000001DB6FFFFFFFCE0B47F4D17
000008101E2A384B617C95ABBAB6AFAAA39C958D86888989
88807974717376787E8A969FA3988B827B79797779818990
948F8A878484848281807E7D7D7D7D7D
7B7672706E73777A7E80828485827F7D7B7C7E7E7E7C7A79
787A7D7E7F7E7E7D7E80828384817E7D7F8B979FA1918074
6C737C7F83828182807A736F6D73797E86939EA7A994806F
677A8B939275553F260900000026699FC7BDAFADAAB0B6B5
B2ADA7A29D9B999693908C89857C746E6A6F75787B7A7878
7775737170727476797F858A8C86807C797C7F8182838485
847F7975747B83898C8884838285898B8F969B9F9F918378
707173727892A8BAB25F120000349FEAFFFFE7D8B9865321
00020D111D2D40556B7E8FA0AAA59F999492918D89868481
7F7B787575777B7E828B92999B91878079767573747D868D
918B85807D7E7F7F7F7D7B7A79797A79
88837E7B787A7B7D7F8286898B8B8A8A8884817D7C7E8082
8486888A8A888583828486878886858484888B8D8B7F736B
666C74797D7F8082817B75716F72777A808C969EA1978A81
72573F2A296095BAC4792D0000001C324D647B97ADB6BDC5
CCD5DDE1E4E3E0DBD2C4B3A39079634F41404142454C545C
636464666663615F616D79828A8D8F92938F8A8684898E90
8F81756C687380899192949799979694959FA8ADAC9C8A7C
6E635A504C59646E6D4A2A15144C86B0D1D2CCCDBD8D5D32
1213191922364C637781899397938D8783878B8C8B847E79
76767778797C7F82858A8E91918A837D7773716E6F788289
8D867E7976787B7B7C7A777675767676
908B86827F7E7E7E7F84898D90929293928A827D797E8488
8C8E9092928E8A8785878A8B8B8B8B8A898683807B736B65
62686F74797D7F82837D7874717375777B87929A9E9C9692
7E400900004DBCFFFFBF4C000000000000285A8DB6C0C7D6
E3F7FFFFFFFFFFFFFFE9CFB497755537211C1B191E2B3948
5457595E5F58534F5060707D8A939BA3A69D938A858D9598
968371645E6D7D89949AA0A7AAA6A19D9CA8B2B7B6A4907F
6D5A49392E3034383B39393D4760798EA1B2BEC7C092613A
1A14140E15314E6A80868A91928B827A767E868B8C847B75
7174787A7D808285888B8C8D8D87817C77726F6C6C768088
8C847B76727578797A78767473747474
948F8A878482807F80858A8E92949699978D837C787F878C
9092939695908B8785888B8C8E8E8E8D8A827A736D6A6865
666A7074797C7E80817E7A787675757578828C92979C9D9E
8A3A00000040CAFFFFEC73250000000000003E7BB0BECAE0
F2FFFFFFFFFFFFFFFFFEE0C3A27A543217100D0A0E1B2B3B
494F535A5C534A4545576B7988959FA9ADA2968B86909A9F
9D8771635C6B7D8A979FA7B0B4ADA6A09EAAB5B9B8A89484
6F553C26140D0B09112C476174706B6B7190ABBCBE976E4F
32251C11133457758C8C898D8A81786E6A7580888B817772
6E73797C808182848587878886827D7974706C696A737C84
877F76716D7074767774727170707171
888684828181818182848687898C8F919088817B787D8387
8A8A8A8B89847F7B7980868A8D8A87858179726B686D7478
7D7E8082827F7B78777A7D80807D7A79797E83868A93999E
956538160B4580A8C2AD9183693B1100000A3A6088A6C2E1
F4EDE3DCD6E0E8E8E7DFD5CBBB9C7E634E4A494544424244
48515A62665C544E4E5D6D7883888B90928E8985848F99A0
A1907F746E79868E979CA1A7A9A29C96949DA6AAAAA2968B
7A59391E08000000002346667B6E5F5A5B7A97A9B19F8979
664B34201B4066849A948C8B867C7369646E787F837C7571
6E73787B7C79757372777C7E7F79736E6A696866676D7378
7A736D6966696C6E6E6C6A6968686969
7D7D7D7D7D7F8183848281808083868888837E7A787C8082
8382807F7D78736F6E7781878B86807D78716A656572808B
93928F8F8C8279716D7680878B857F7C7A7A7B7B7E8A949B
9D908177674D3725296CADDDF0A95F2F0C213D49628CB4DA
EDCAA58C7B8B9DA5AFBAC3CCCDBAA594868686837D6C5D52
4C58646D7369605B5A6571797F7B787776787B7D828D979F
A2978B837E858D919697989A9A948F8B888E949697989692
85613D20070000000023496A7F6C574E4C688495A3A5A2A3
98724F32264D7693A89D8F8B83796F65606871787C787371
7074787A7A716963616972777A736B666263656566696C6E
6E6A6663616467686967646362636363
7577797A7C7F828485817D7B797C8082837F7B79787B7D7F
7F7D7A78756F6A6666717C8489837B777169635D5F738897
A3A09A999284776B6574838D938B827E7975726F7281909B
A5ADB1B5A3530900004CCFFFFFFD9555202838344377A7D3
E6AF78533A4F697689A1B7CEDBCFC1B6ACAFB0ADA3886E5A
4E5D6D777D736863616A73797C736B66646A72777F8B959F
A49D958F8B8F9394959492918F8A86828082858588909698
8E673F2005000000002351788E6E4D3B32506F8296AAB9C8
C6986A46355E88A2B5A490877C726A5F5A626B7176747171
7176797C7A6D6158535E6A71756D65605D60646566666667
666461605F616364656361605F5F605F
72737577797D8184857F7A7573767A7C7D7A787776787A7B
7B797673706B6662636E7982878079756F67605A5D748C9E
ABA7A09D958575676172838F978E85807A726C6768788994
A3BDCFDFCE5F0000003FE4FFFFFFC5814542453437648FB4
C184461D031A3748607E9BB8CDCBC7C5C2C8CCCAC0A2846C
5D6D7F898F83766F6B737B7F7F71635A565F6A727B868F99
9E98928D8A8E9293938C85807C7B7B7A7874706D6F808F99
9877563D27201D171F456A899874513B2F4763748AAAC6DF
E4B17F59456E97B0C0AB94887A726A615C62696F74747475
777B7E807E6F6055505D6B757A7168636064696B6D6B6A69
686766656567696A6B69676665656665
7A787675757A7E80817C76726F737678797572706F74787B
7D7C7A7A7875726F6F767C818483807F7C71696161728390
9A9792918C81766C687481898F8A84817D756D6766707B83
8D9CA9B5AF77441F1B7DDEFFFFFFD0A7827E7D6D63605C59
50341907000D2130414C586775808A949DA7AFB6B6A99C91
8C9AA8B1B3A08D7F77838E94958270635B636C71767A7C81
80756A615F6F7F8A8E7C6A5E57626E7576625045435E798F
A0A09FA3A8B6C3CACCC3B7AD9F8A77665D646E76839EB6CB
D0A77F62547BA1BAC9B6A09488817A726D7075787D7F8185
878B8D8E8C80756C69798893998F847D797C808183848586
87868584838587888887858483848484
827D787471767A7C7D78736F6D70737575716C69696F767A
7E7F7F81817F7D7C7B7D7F8081858789887C726A66707A81
87868484837C777270767D82858483827F776F6965696D71
767A7F868C8E9195A0BAD3E6F1E4D4C6B9B7B2A7915E2D04
000000000008121F27201B1A20364E6275838F9DA8ADB0B3
B8C5CFD5D4BBA28E8292A1A9AA947D6E63686E6F706E6B6A
6555463A38536D81896D513E354C6472765333201B3D6484
A7C6E5FFFFFFFFFFFFFFFBCAA19D9D938C837C797D90A3B3
B89A7D696386A9C0CFBEABA0948F8B837F7F8183868A8F93
97999B9C9B928A848494A5B1B8ACA09892949697989CA0A4
A7A5A3A2A2A3A5A5A5A4A3A3A2A2A2A2
877F78726E73777A7B75706C6A6D7072726D6865656C7479
7E818385868685858482807E7E858C9091857A716C707578
7A7B7B7D7D7A787675787B7D7F8182838179716A65636262
64666B717FA2C5E1F2DFCABDB7CDE2EAEFEADDD1B05A0700
00000000000000090C000000000225425E6F7F93A5B5C4D0
DAE5EDF2EDD1B49C8D9EAFB7B89E857365696F6E6D655D58
4F3B2B1D1C3E607984613D251A3B5B6F74461A010022537C
ADE5FFFFFFFFFFFFFFFFFFDD9FAABAB7B49B8479758697A4
A99480737191B0C5D3C3B2A89D9A97918D8A89898B91989E
A3A4A4A6A59E989495A7B9C6CDC0B3AAA3A4A6A6A8ADB3B8
BCBAB8B8B7B8B9BABAB9B8B8B7B7B8B8
8A80766F6A6F757879736D6A686B6E70706B676464697075
7A7F83878A8A888885807C7877818B9194897E76706F6F6E
6E7073767878777777777777787B7E808079736D68625D5A
5855575A6DA8E0FFFFEEB99682ADD8EDFEFDF2EBC7600000
00000000000000040300000000000D2E4E5F6F859BB3C9DB
EAF5FBFFFADCBEA495A6B8C0C1A98F7D6F6D6D69655F5955
4D3A291C1B3E5F78825B351A0E3458707742110000174C77
AEF2FFFFFFFFFFFFFFFFFFD38FA9C8CFD1AE8C7A6F7C8C95
9A8B7D777894AFC3CFC2B3AAA1A09F9B9894918F9098A0A7
ACADACAEADA7A3A0A2B5C7D5DDD0C2BAB2B3B4B3B5BCC4CA
CFCECCCCCBCBCCCBCBCBCBCBCBCBCBCB
80776E67636A717577716A6663686D70726F6B6A68666564
666F787F837E78746F6B6865656F7980847D75706B686765
646A6F747673706E6D6D6D6D6D6E6F7070717272716C6663
5F5956545C81A4C1D0B79C8C808B989BA3B6C3CCC17E3B06
0000070F1919181E1E0E000000112D4459626B788698AAB8
C6D5E1EAE9D0B6A195A5B5BDC0B1A196877362524B5E7281
8A8075706E7B868C89694B332947657A8057301911356080
A6D1F9FFFFFFFFFFFFF1B17B5A7FA7BECAA989766B7B8B95
9886756B6A849FB2BEB1A39B95989C9D9D999593949CA4AA
B0B1B1B3B2ABA49FA0B3C5D3DBD3C9C4BFBFC0BFC1C9D1D8
DDDDDCDDDCDAD8D5D4D6D8D9DAD9D9D9
786F67615E666F757870686361686F73767472716E655D56
556370797E7469625C595754555F687075716D6B6864615E
5E666E7477716B676465656565636261636B73797C77726E
696058514F5B68727A7E7F83806C594B496E91AAB69B7D69
564F4A403A3C3E40423C38363946535E6868696D737D8992
9DB0C0CDD1BEAA9B929FAEB4B9B5AEAA9E7A5A4038608BAA
C3C2BEC0BCB4AA9E8F7964524A6075858B6E52413B577488
9DACB7C2C1A281664D3C3024285684A9BFA38573687A8B94
96816C5F5B748D9EA99D918B878F979B9E9A9695959CA4A9
AEB0B2B4B3A9A19B9AABBDCAD3CEC8C6C4C3C3C3C4CDD5DC
E1E3E3E4E4DFDBD7D5D8DBDDDFDEDDDE
746B635D5B656E757870686361697175797978787465584D
495A6B777D6F61584F4C4B4849535E666D6C6A6A68625D58
57616B73767069646060605F5E5B58575B68768086827B76
6E615448404245464B58646F6D48270F0A3C7196B4B4AEB0
A995806B5C5D5F5E5F5F606265686A6D6D68636161687077
8295A7B7BFB0A197919DA9AFB4B8B9BBAF8156362D649EC8
EBF1F2F9F5DDC4AB9485786A6473828E937F6C605B6F838E
959289826C3000000000000000376D9FBDA385726576868C
8C77635550667C8C968C827E7D88939A9F9B9796969DA3A8
ACAFB1B3B2A89F9998A7B7C3CDCBC8C9C8C7C6C5C7D0D9E0
E6E8E9EBEAE4DEDAD7DBDFE2E4E3E2E3
766E6761606A747B7F776E6A686F777B7F8182837E6D5D50
4A5D707C8374645A504D4B4849535D666E6F70727169625D
5B6671787C756D6964646462615D5A595D6D7E8A928E8782
796B5C4D4139342D2E40516060350D00001E557DA5BED3EA
F1D5B59B86898E8B8C92979C9D948A82796F665D57565859
607182919B938B87858C93969CA8B2BAB4885F41396EA6CF
F2FCFFFFFFE8C7A9918F8F89898F959C9D90837873808B8E
8B79614D280000000000000000265E96B8A0847264748286
85715E524C5C6D79817A7371727D899197938F8E8D929699
9C9FA1A3A399918A8995A1ABB2B2B0B1B1B0AEADAEB7BFC5
CBCCCCCDCCC7C1BDBABEC2C4C6C5C4C5
8B837D787780898F938C85817F8286878A8E919594887C73
707F8D979C92878079726D6767717C858C8D8E8F8E87817B
7880888D8F8B85827F7F7F7F7E7C7B7B7E88939BA09D9894
8E857D746C67635E5A59585754493F393943515E749FC8EC
FFEFDBCEC5CDD7D8DBE1E4E6E1CBB4A08D847A6F6453453A
353C454C5355565A5B554F4C4F657B8C9790888482878D90
949A9FA4A3938378768DA4B4C0BDB6B4AB9987756A737C7E
7C6F5E513909000000000000134574A0BAA2867466737F82
83776B645F6267696B6A696A6B6F7376787572706E6C6A68
676A6D6F6F68625D5A5F636566625D5A5753514E4E52575B
5D595552504F4F4F4E4D4C4C4C4C4C4C
9F9994908E969EA3A6A19C9996959594959BA1A6A9A29C98
97A1ABB1B5B1ABA7A2988F8885909BA4ABACABADACA59F99
969A9EA1A3A09D9C9B9B9B9B9B9C9C9D9FA3A8ABADAAA7A4
A1A09E9A979694928A7562524B6075858B6E54464980B9E4
FFFFF8FAFCFFFFFFFFFFFFFFFFFCD9BAA098908373563923
120F0E0C101B2732372413090A26455C7796B1C8CDA27552
36383E3D3F3F424B5E8BB8DCF3E6D3C7B59F897161676E6F
7068605A503D2B1D151B252D3F6589A8B8A1867568727C7E
7F7C77747068615A575B5F6264615D5B585755524E463F38
34373A3B3C3935322F2C28231E160D060000000000000000
00000000000000000000000000000000
ACA7A3A09FA6ACB1B3B0ACAAA7A39F9C9CA4ACB3B8B5B2B1
B1B8BFC3C6C5C3C1BDB1A69D99A4AFB8BFC0C0C1C0BAB4AF
ABACAEAFB0AFAEAEAEAEAFAFB0B1B3B4B5B6B6B6B6B4B3B1
B1B4B7B8B7B5B1ADA282644C456E96B3BD844E2D256BB5EB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAD1AFA8A0917D532B0B
00000000000000121A00000000001C385F9BCFFBFFB76526
00000000000414294B8CCBFFFFFFEBD6BDA68F7461626665
655D5653504E4E4F504F51545E7A94A9B49E87786C737A7C
7E8081827E6D5C4E464F585D5F564D464141403E392C2016
0F111414151513120E050000000000000000000000000000
00000000000000000000000000000000
BAB6B3B1B1B6BBBEC1BFBCBBB8B2ACA8A7B0B9C0C6C5C4C5
C6CBD0D3D5D7D6D7D3C6BAB1ACB7C2CAD1D2D2D4D3CDC7C1
BDBCBDBCBCBDBEC0C1C1C1C1C2C4C7C8C9C6C2C0BDBCBCBB
BDC4CBD0D2D1CCC9BB926D4E467FB8E1EFA760342163AADD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDBB8B5B1A490643815
000000000000000F1A0000000000021B459BE8FFFFD06311
00000000000002204C94D8FFFFFFF1D6B8A4917865646564
645D57565866737E857E77737484949FA29180736A6D7171
73787D807D67514035404B5153473A312A2B2C2A25160800
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
CDCAC6C4C3C8CCD0D2D0CFCECCC7C3BFBFC6CDD3D6D1CCCA
CAD2DBE0E4E2DEDCD7CEC5BEBBC5D0D8DFE0E0E2E1D9D1CA
C5C6C7C8C9CDD1D5D7D3D0CDCCCFD2D3D3D0CCC9C6C4C3C1
C2CAD2D7DBDCDAD9CEA47E605996D2FDFFE1AD8E78889EA8
B9CDE1F7FFFFFFFFFFFFFFFFFFFBDEC4B2BAC1C1BCA58C79
6241250B022447606F563C30241A17132C90EDFFFFF48E47
0D111D192032496384B2DCFFFFF1CCB0979390867F7F7F7F
7D746B65636B73787A72696360656A6C6C655E58534F4C47
45494D4F4C3E2F241D232A2D2E261D1712141515120A0100
0000000000000A1214050000000000000000000000000000
00000000000000000000000000000000
D8D5D2CFCED2D6D8DAD9D8D8D7D4D2D0CFD4D9DDDDD4CCC6
C5D1DDE5EAE4DCD8D2CCC7C1C1CAD5DDE4E5E6E7E5DCD3CB
C6C8CACBCED5DBE1E4DDD6D1CED1D4D5D5D1CDCAC7C4C2C0
C1C9D1D6DBDFE0E2D8B08B6F6AA5E2FFFFFFF4E4CDAC8F72
6683A3BACECCC8CBCBCBCAC8C3B8AFA7A6B9CBD8E2E1DCD9
CBA179594A6F96B0C1B3A19A875933131883EBFFFFFFB67D
4F5867666D7E91A5B9CBD9E7E6C5A286737E8C9196979799
978C81776F7172716E655C554E48443E3C3E414341372D26
20222424231C16110E101213130F0A0705080A0B0C090706
03000000000F202D3426170D030000000000050B0F0F0E10
111214161D2F404F58524B4744464847
E1DEDCDAD9DBDDDFE0E1E1E1E1DFDDDCDBDFE2E4E3D8CDC6
C4D2E0EAEFE7DDD8D2CDCAC7C7D1DBE3E9EBEBECEAE0D6CE
C8CACDCED2DBE4EBEEE6DCD6D1D5D8D9D9D3CECAC6C3C0BE
BFC8D1D8DEE5E9EEE6BD987D78B6F4FFFFFFFFFFFFC37E42
1F456F8AA0968B8C8A87858282858B919EB9D5ECFFFFFFFF
FFE9B9917EA6D0EAFDF7EBE8D186440E0478EBFFFFFFD1A0
798596959EB0C1D3DFDDD7D4C7A48367586E8797A6A8A7AC
AAA0958A818384817C6F615648382A1D16212C333526170D
040507060605040404030100000000000000000306080A0C
0C04000000152D404A3E3028201E1D1B1C26303941424246
494F555B65798D9DA8A49E9B989B9D9C
C8C7C6C5C5C4C4C4C5C7C8CACBC9C8C7C6C8CACAC8BCB2AA
A7B6C4CED4CAC0BBB5B1AEABACB6C0C8CFD0D0D1CFC5BBB3
ADAFB2B4B8C2CBD3D6CDC3BCB7BBBEBFBEB8B2AFABA8A6A5
A7AFB9C0C7D1D7DED8B28F7670A5DCFFFFFFFFFFFFCA6B1C
000E395062544544413D3B3A3E4C5D6E85A4C3E0FBFFFFFF
FFFFDFBAA6CBF1FFFFFFFFFFFFAF5C1B056DD6FFFFFFD2AF
94A2B3B6BECDD9E5E8D7C2B29C7C60463C597990A5A9ACB2
B4ACA39A939494918A7C6D60513D2C1C1423323D42322218
0F10121213171C20221E1A18161617181A1E23282D34393F
4032271F203B566B7A736B6965625F5C5E6B78848D8F9195
9AA0A8AFB8CADBE9F3F0ECEBE9EBECEC
54585B5E5E58534E4D53595D605D59575658595958514B47
454E575E615D58555148403A3844505A61626263615B544F
4A4949494B52595F625D58555255575858534E4B494A4D4F
535B636A727B818682644732283C54637BA6CAE8EAA2571D
0000070708000000000000010813202D3E53697E92A6B7C6
CDBDADA19CACBEC7D4E5F2FDF4B97F51396593B1C2A48676
6C7B8B939A9C9C9C998D7F73634C382822374F63767F8893
9C9FA1A2A3A7AAABA9A198918A847F7A79818A9196908B89
888D92969BA0A5AAACAAA8A7A7A8ABADB0B8C0C7CED6DCE1
DFC9B5A59EB1C5D4E3EEF8FFFFFEF2EAE6F2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
040B12181F272D312E19040000000000001B5B8CA5794622
00000000000000000000000000000000000915202C37434F
5B6A79868E8A868489A7C3D5DCBF9F866E5F514137383C3F
46556370766B5E544A454039312419110F1C2B3948566575
84909CA7B1B7BDC1C4C2C0BFC0C7D0D6DBDDDEE1E5EAF0F6
FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000C4F7C5E3822
030000000000000000000000000000000000000000000000
10375C7C8F7A65595983ABC5D6CEBEB398571A000000071E
36455061654F3724120F0C060200000000050E1926394C60
74889BAEBDC3C9CFD4D7DBDEE5F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000002358493129
100000000000000000000000000000000000000000000000
00194A748B6A4936326496B5CED3CECDB051000000000017
3D484F606245260C000000000000000308090C121C304558
6D8499AFBFC6CBD2D8DEE4EAF5FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000B0F00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000C39584B3831
24140400000000000000000409121920241E1916161C242A
364F677C84684E3C3B6D9EBED5CAB7AD904B0A0000003967
8E908C94917A634D3E444C4E5254565A5D5A59595C68747F
8A949DA7AEB2B5B9BBBDBFC1C6D1DCE6ECEAE8E8E9EFF5FA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF0CAB2C8E4F7FFFFFFFFFFFFFFFFE0F6FFFFFFFFFFFF
FFFFFFFFF7EFE8DED8D8D9DADBD9D8D9
556676828778685D54575B5B5C5D5E5F5E57504A47494C4E
5052535454514D4A453A3129283747525A56504E49413A33
2F34393C3E38322E2A2B2B2B2B2B2B2B2A27232120272E33
34281E17141E29313940464D4D3D2D221E3348575F53463F
3D4A58626B6E707476726E6B6B757E8589827B77757C8387
898885847D6856484978A6C7D9BE9E8A6E472508044385B7
DDD5C7C6BDAE9F8E85919DA5ADADADAFAFA9A49F9C9FA2A4
A4A19E9C9A9B9C9B9B989694929190909092949595908B87
8587898A8A8A898886817B777473747579838D949BA2A6A8
995F280000113E5D86BEEEFFFFC66A24001135455A6A798D
95826D5E545D676B6F6E6C6D6D6E6E6E
A7B9C9D5DBCDBEB4ABAAAAA7A6A9ADAFAFA69C9590939697
999C9FA1A19B948F89817B757584939EA6A099958F857B72
6E778085887F76706B6A69676566676767625E5A595F6568
6756473C36404C545F6B77838A87827E787067605A53504F
58799CB8CFD3D3D8D7CFC6BDB9C3CCD1D4CAC0B9B4B9BEBE
BAA79384746153464976A1C2D3B18C745B4535252D71B6EE
FFFFEEE6D9CEC4B7B2C4D7E5F0F1F1F2F0E6DBD1C7C4C1BC
B5A89C928A888785827D78746E665E5753575B5D5B4F4339
31302F2C2925211E19120B050100000000060F141A202122
12000000000000001C5684B0B04300000000000000000003
100000000000000F1A18151515161717
ECFCFFFFFFFFFFFDF5F1EDE8E7EDF2F6F7EDE3DDD7D9DBDC
DEE3E8EBECE4DCD6D0CAC5C1C2D0DEE9F0EAE2DDD6CBC0B6
B3BFCCD5D9CFC3BCB5B3B1ADACAFB1B3B3ADA6A19FA5AAAD
AA9784776F76808893A3B3C2CED5D8DAD2B4967D6B686B6C
7CA9D7FFFFFFFFFFFFFFFFFDF5FDFFFFFFFDF2E9E2E6E7E4
DABC9D846E60574D51779DBBC8A47D65504A4A475999D8FF
FFFFFEF0E0D9D3C8C7DCF2FFFFFFFFFFFFFFF6E8DBD3CBC1
B5A3918175716F6B676059544C3F322720262C2E2C1B0A00
000000000000000000000000000000000000000000000000
0000000000000000000D3B67630000000000000000000000
00000000000000000000000000000000
ECF7FFFFFFFFFFFFFDFAF7F4F4FBFFFFFFFFFFFFFDFCFBFA
FCFFFFFFFFFFFFFFFFFDF6F0EFFDFFFFFFFFFFFFFFFFF8F1
F1FFFFFFFFFFFFFFFFFEFDFBFBFFFFFFFFFFFFF7F3FDFFFF
FFF9E9DDD4D4D5D5DBEDFFFFFFFFFFFFFFEDD6C3B3AFB0AF
B7D2EEFFFFFFFFFFFFFFFFF6EDEFF1EFECE3DAD3CCC9C5C0
B7A49283756C6660627B93A6AF9982746762615E6891BADB
EFDBC3B5A69C94898695A6B3BFC3C5C9C8BEB3A99E99928A
8175695E5654524F4D4944413C342C2521262C2E2D21140A
010000000000000000000000000000000000000000000000
0000000000000000023F709D9C2600000000000000000000
050000000000000C1F1D191B1B1D1E1E
E4E9EEF2F6F7F8F9FAF8F6F5F7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F0EDEA
EBF3FCFFFFFFFFFFFFF7EEE5DDD9D4CFC9C3BCB6AFA69E96
8F8A85817D787572747E8991968F88837E797672748798A5
AA9A877A6B5F554A454F59626B71767C7E776F68615E5A55
504A443F3C3A3A3938363433322F2C2A292E3335362E2620
1B18161312131516161411100E0906030615242E373E3F41
310000000000000A3B79AEDDE07000000000000000112D4F
5D361000000D334B5F5D5A5D5E606161
EEEEEEEFF2F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDF6EEE6DDD4CBC2BAB6B2AEA79A8E84
7D7E80808282838586848281818487898B8D8E8F8E8C8884
7C6D5E5042362C231E232A30363D444A4D49433F3A373430
2D2A282625242423232322222222212123272C2F302B2622
1E1B191716191D2023232323221D181518293B4751585A5D
4E120000000000245493C8F9FD90210000000000193B597C
8A5D30110229536D84837F8485878888
E3DEDBD9DAE4EEF6FDFBFAFCFEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFBF5EFE9E3DED9D3CCC2B7ADA6A3A19E988A7C72
6D737B8085898C9090867C74717B868D93989B9E9A8A7969
594E43372C2118110D0E1114181F252B2F2D29272523221F
1E202122232222222223242526282B2D3033373A3B3A3735
33312E2D2C31363A3E414346463F3935374A5D6A767E8285
773C04000000234674B5ECFFFFBB4F0000001428476B8CB0
BC8956322048738EA6A5A4A9ACADAEAE
B2ACA7A3A2A9B0B6BAB9B8B9B9BBBDBFC1C4C6C9CAC7C5C4
C6D3DFE8EEE8E2DEDADBDCDCDCDEE0E2E2DAD3CFCDCED2D5
DEF7FFFFFFFFFFF5E8E5E4E0E5FFFFFFFFFFFFEEE2F0FEFF
FFFFFFFFFFFFEBD9CEDAE7EEF4F1EEECE8DDD3C9C3C4C6C5
C6C6C5C5C3BAB1AAA4A4A5A3A29E9B9894928F8C88807973
70757B7F83838384827D7874737A81868A8B8A8A88807871
69645F59544F4A474547494B4D515457595653514F4F504F
50525557585755545353535455595C606263646565656564
63605D5B5A5C5E6063696E7373675D5655667985919DA3AA
9D5C1E000005395C8CD0FFFFFFDB6D1A00022C3E5C82A4C9
D59E663E284D768EA5A7A8B1B5B6B6B6
817A736E6B6F72757676767674706C686563636262626364
6870787F81766C6460687176797773716C6258504C4F5459
637D95A8AF967A66544F4C464B68839AA3856652444E5B61
6A7A8794967E6552454D565A60666B7273685D5551586066
6D7780888B7F736B656A7073777B7E8284817E7B79777675
75797D80817D797674757676777A7C7F7F7C78757476797B
7C7D7D7E7F7F7F7F808283858586858584827F7D7C7E8081
84878A8D8E8B89878584848384898E929492908F8E909192
918E8B8987868685878F979D9E8E7F757282939EAAB9C3CC
BF7A370600184D70A1E8FFFFFFF98935001A42526E96BADF
EAAF73482F51768CA1A7ABB5BCBCBBBB
534A423B36383A3A3B3C3C3C3930261E1713110E0D101316
1A202428271A0D02000C1B2329221A150D00000000000000
021D35494E2F0E0000000000000010283311000000000000
00061B2F361C0000000000000000030F160D0400000A161F
2A3845515648392F29333E454D565F686D6B686766696D6F
72777C80817A746F6C70747678797A7C7B736C67656B7379
80868C93999DA0A3A5A6A6A6A5A29F9D9A989796969A9EA2
A6ACB1B5B7B4B1AEACABAAA9ABB2B8BDC0BCB7B4B3B7BBBD
BEBBB8B6B4B1AFADAFBAC4CCCDBBA89C96A6B7C1CDE0ECF7
ECA35C280C376B8EBFFFFFFFFFFFB25F2441677590B9DEFF
FFCE8E6043618497ACB3BAC7CFCECCCD
362C221B1515161516171818150800000000000000000000
000000000000000000000000000000000000000000000000
0000000A0E00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
0112212F35251509040F1D26323E4A575F5D5B5A5B62686D
72787D81827A726B686D73777A7A7A7B786E655E5C66717A
848E98A2ABB2B7BCBFBFBEBDBAB6B1ADAAA8A7A7A8ADB3B8
BEC4CACFD2CECAC7C4C3C2C1C3CAD1D7DAD4CDC9C7CDD3D6
D8D5D2D0CECAC7C5C6D3DEE7E9D4C0B3ACBBCCD5E2F6FFFF
FFB9703A1C467A9BCCFFFFFFFFFFC9763B567A86A0CAF0FF
FFDE9B6B4C688A9CAFB9C1CFD8D7D5D6
4C4238312C2F333537393A3B393128201A17151211121416
181B1E201E10020000011019201D18161002000000000000
00142B3E43220000000000000000001A2502000000000000
0000162A321A000000000000000007131A12090505111E27
313D4750524232271F283238404A545E6564636465696D70
747B818587817B77737578797A7C7E807F78726D6B70767A
80878E969CA1A6AAACAAA7A5A29F9D9A97969696979BA0A4
A8AEB3B8BAB6B1ADAAAAAAA9AAAFB4B8BAB5B0AEACB1B5B8
BAB7B4B3B1AFAEADAFBAC5CDCFBDAB9F99A9BAC3D0E2EFFA
EDA25A24062F6283B4FFFFFFFFFFB25F243F636F89B4DAFF
FFCA88593B5B8094AAB3BBC9D2D0CFD0
655B524B474D54585C5E5F61615D5854515151504F4E4C4B
4B50535654483B322E38434A5053545653473A30292A2D2F
375066787D5F3E26110A06000324445E6947240E000F222C
3A4D5E6F745E4634282E36393F49515B5F554C46434D585F
666C7074726354483F44494C52585F666C6D6E6F70727374
777E848A8C8985827F7E7D7B7B7F828586837F7D7B7A7B7A
7C8084888C8F929495928E8B888786858483838384878A8D
91969A9E9F9A95918E8E8F8E8F9193969694918F8F929698
9996949291919292959FA8B0B2A293888494A5AFBBCCD7E1
D389410C0017486899E5FFFFFFFF98460B2649556F9BC2E9
F5B574462A4D758CA4ACB3C1C9C8C7C8
71685F58555D656B707274777876747270717273726F6B69
676B6F71706458504C535C62686E7479796D6057504F504F
556D8394997B5C453129261E2344637D8967452F22344955
6474829094806A5A4F5761656C737A82857A7069656F787E
838687888576665A51525556595F646B7072747678787878
7A81888D908E8B898684817E7D8286898B89868583817F7D
7D7F828486888A8C8C8883807D7C7C7C7B7B7B7B7C7E8183
868A8E91928C86827E7F808080808081817F7E7D7C7F8284
8482807E7E7F8081858E969E9F91837A778798A2AEBEC8D0
C27730000004355585D2FFFFFFF58634001336425C88B0D7
E4A465371D426C849DA5ACB9C2C1C0C1
7C736A64626A747B818385888A8A8A8A8A8C8E8F8F8A8581
7F838788877C7169656B72767D868E96988C8077706D6D6B
6F879CACB19576614D45423B3F607F99A583624D40546B78
8795A0ACB09C897A707A848A91979CA2A4998E86828A9397
9B9B9A9994857669605F605F61656A6F7476797C7E7C7B7B
7C848B9093928F8E8C8884817F84888B8E8D8C8B8A86837F
7D7E7F7F80828384837F7A7673737474747474747577797B
7D80848686807A757172737373727170706F6E6E6E707273
74726F6E6E7072747880888E9083776F6C7C8D97A3B2BBC2
B36922000000264676C3FFFFFFE77826000528334D79A1C9
D698582C1239647E98A0A6B4BCBBBABB
756C635D5A626B72787A7C7F80807E7D7D7E8081807C7774
7276797B7A6E625A565D656A71798086887C6F665E5D5D5B
60788E9EA38566503C3430292E4F6E899472503B2E415764
74828F9DA18D78695F6772777D848A9193897F77737C858B
8F9090908B7C6D60575759595B60666B717375787A7A7A7A
7B838A8F92908E8C8A8683807F83878A8D8B89898784817F
7D7F81828486888989847F7B7878787878777778797B7D7F
82868A8C8D87817C78797A7A7A7979787877767575777A7B
7C7A78767677797B7F889097988B7E757282939DA9B8C2CA
BB71290000002D4D7DCAFFFFFFEE802E000C2F3A5480A9D1
DD9E5E31173D68819AA3A9B7BFBFBEBE
6F655C55525A62686E707275767472706F707171716D6966
65696C6E6C60544B474F585E656B7176776B5E544D4C4C4B
51697F90947656402B231F181C3D5D7883613F291B2E4450
5F707E8C917D67584D555E636971788083796F67646E787D
83858687837364574E4F5253565C62686E70727577777878
7A82898E918F8C8A8784827F7E8286898B8987868482807E
7D808385878A8C8E8E8A85817E7D7D7C7C7B7B7C7D808285
888C9093938E87837F80818181818181817F7D7C7C7F8284
8582807F7E7F8182868F979FA092857B788899A3AFBFC9D1
C37830000003345484D1FFFFFFF68735001436425B88B0D8
E4A464361C416B849DA5ACBAC2C2C1C1
71675E58555C656B717375787A7876747375767676726E6B
696D7072706458504C535C616870767B7C70635A52515250
566E8494997B5B453028241D2243637D8867442E21344A56
6676839196826D5D535B646970777E86887E746D69727C82
8789898A8576675A50515455585D63696F71737678787879
7B82898E92908D8B8885827F7E82878A8C8A88878582807E
7D80828486898B8D8D88837F7C7B7B7B7A7A7A7B7C7E8183
868A8E91918B85807D7D7F7E7E7E7E7E7E7C7B7A7A7C7F81
82807D7C7B7D7F80838D959C9E908279768697A1ADBDC7CF
C0762E000001315181CFFFFFFFF385330011343F5985ADD5
E2A262351A406A839CA4ABB9C1C1C0C1
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell[TextData[{
  "The sum of the trend ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_5\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " plotted earlier and the details at the same level plotted above gives the \
trend at the next finer level ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_6\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " shown here. In spite of the fact that details at levels 6 and 7 are \
discarded, the reproduction is reasonable. We can also obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_6\) \((x, y)\)\)], "InlineFormula",
    CellTags->"S2.2.1"],
  " directly using the inverse transform on ",
  StyleBox["wtdata", "MR"],
  " with all the detail coefficients above level 5 set to zero."
}], "MathCaption",
  CellTags->{"S2.2.1", "1.22"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[temp1+%%, Mesh -> False]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -6 -9 ]
[.20703 -0.0125 6 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -12 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(50)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(100)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(150)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(200)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(250)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(50)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(100)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(150)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(200)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(250)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
232425262624222120202122242C343A3C3229221D1F2223
23201D1C1A161310111B262D312B231E191614100E0E0E0F
0F0E0E0E0E0F0F0F100F0F0F0F111314161718191A191817
161413121110101113181D22252728292A2A2A2927231E1A
17151412111112121212121212121212121212121110100F
0E0E0E0E0E0D0D0C0C0C0C0C0B0B0B0B0B0B0B0C0D101315
192025292A20150D0606070707090B0D101113141412100E
0D0D0E0E0E0E0E0F0F0F0E0E0E0E0F0F0F0F0F0F0F0F0E0E
0F10111212110F0E0E111415161412100F0F0F0F0F0F0F0F
0F0F0E0E0E0F10101111111110100F0F0F0F0F1010101010
10101112121212121314161718181818
36373737352D25201C1D1F20242C343B3E352B251F212222
22211F1F1D181411111B242B2F29221E191614100E0E0E0F
0F0E0E0E0E0E0E0F0F0F0F0F101113151618191A1B1A1918
161513121110101012181E232728292A2A282623201D1B18
15141312121212121212121212121212121212111111100F
0F0F0F0E0E0E0D0D0D0C0C0C0C0C0C0C0D0D0D0E0E0F1012
1316191B1C1C1B1A191816151415161616151312110F0E0D
0C0D0D0E0E0E0E0E0E0E0E0E0E0E0F0F0F0F0F0F0F0F0F0F
0F0F1010100F0F0E0F1113141513110F0E0F0F0F0F0F0F0F
0F0F0F0F0F0F10101010101010100F0F0F0F101010101010
10111112121212121213141516161616
494A494844372A20191A1D1F232C343C40372E2822222322
21212222211B1612111A23292D27221E1A1714100E0E0F0F
0F0E0D0D0D0E0E0E0F0F0F0F1012141517191A1B1C1B1918
161514131211101012191F25292A2A2A2925211E1A181715
131313131312121212121212121212121212111111111010
0F0F0F0F0E0E0E0E0E0D0D0D0D0E0E0E0F0F0F10100F0F0E
0E0E0E0F111921282C2926242121211F1D1915110E0D0C0C
0C0C0D0E0E0E0E0E0E0E0F0F0F0F0E0E0E0E0F0F0F0F0F10
100F0F0E0E0E0E0E0F1012131412100F0E0E0F0F0F0F1010
10100F0F0F0F0F1010101010101010101010101010101011
11111212121212121213141414141414
5859585751402F2118191D1F232C353D4139312B25242422
21222425241E1814121A22272A26211D1A1714110E0E0F0F
0F0E0D0D0D0D0E0E0E0F0F0F1012141517191B1C1D1B1A18
1715141312111111131920262A2A2A2A28231E1915151413
121212131312121211121212121212121111111111111010
10100F0F0F0F0F0F0E0E0E0E0E0F10101112121212100E0D
0C0907060A1827333B37322F2C2B2A27231C16100C0B0B0B
0B0C0C0D0E0E0D0D0D0E0F0F0F0F0E0E0E0E0F0F0F101010
100F0E0D0D0D0E0F0F1011121211100E0E0E0E0E0F0F1010
1110100F0F0F0F0F100F0F0F0F1010101010101010101111
11121212121313131313141414141414
656666655E4B37271C1C1F1F222B343C403A332E2A272522
2123252727201A16141B212528241F1D191614110E0E0F0F
0F0E0D0D0D0D0D0E0E0F0F1011121416181A1B1D1D1C1A18
1715141312111112141B22272B2B292926211B1612121211
121212131413121211121212121212111111111111111110
1010100F0F0F0F0F0F0F0F0F0F1010111112121312100E0D
0C0908080D1E303E48433C393434332F2A2119110C0B0B0A
0A0B0C0D0E0E0D0D0D0E0F0F0F0F0E0E0E0E0F0F0F101010
100F0E0D0D0E0E0F1010111111100F0E0E0E0E0E0F0F1010
1110100F0F0F0F0F0F0F0F0F0F1010101010101010111111
12121213131313131314141515151515
676B6D6D685846382C27231F1F272F363B393534312D2824
2123252626221D1A191D212325211E1B181513100F0F0F0F
0F0E0D0D0D0D0E0E0F0F0F0F10121416181A1C1D1D1C1A18
1715131211121415181E24292C2A2725221E1A1613131313
131313141413131212121212121212121111111111111110
10101010101010101010100F0F0E0D0C0B0B0B0B0B0C0E10
13181F242C37414A4E48413B3637383733291F17110E0D0B
0A0B0C0D0E0D0D0D0D0D0E0E0E0E0E0D0D0E0E0E0E0F0F10
10101010101011111111111111100F0E0E0E0E0E0F0F0F10
1010100F0F0F0F0F0F0F0F0F0F0F0F101010101011111111
1212131414131212121517191B1A1A1A
686E72747264564A3D3329201C232B313737383938322C26
222425262523201F1E202122221F1C19171412100F0F0F0F
0F0E0E0D0D0E0E0F0F0F0F0F10121517191A1C1D1D1C1A18
17141311111316181C21262B2D2925221E1C191715151514
151414151514131312131313121212121211111111111110
1010101010101111111110100F0D0A0907060505070A0F14
1C2936424B4F5154534B433C363A3D3D3B30261E16120F0C
0A0A0C0D0E0D0D0D0D0D0D0E0E0D0D0D0D0D0D0D0E0E0E0F
10111213131313131212111110100F0F0E0E0F0F0F0F0F0F
0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F10101011111111
121314151514131213171B1F21212020
6C73797C7B7063594C3D2F231B21282D33373A3E3F372F28
2325262626252423222221201F1C1A18151412100F0F0F0F
0F0E0E0E0E0E0F0F0F0F0F0F10121517191B1C1D1E1C1A19
171412111114181B1F24282C2D28231F1B1A181715151515
151515151515141313131313131212121211111111111111
111111111112121213131312110E0A0806040303050A1119
2336485762615E5D5850473E383D414342372B221A15110C
090A0C0D0E0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0D0E0E0F
0F1113151615151413121110100F0F0F0F0F0F0F0F0F0F0F
0F0F0F1010100F0F0F0F0F0F0F0F0F0F0F10101111111212
1314151617151413141A1F2427262525
6E767C8081796E665A4938292023282B30363B41433B322B
26262827272726262624211F1D1B1816141312100F0F0F0F
0F0E0E0E0E0E0F0F100F0F0F101215171A1B1D1E1E1C1A19
1714121111151A1E2226292C2D27211C1818181717161616
161616161515141413131313131212121212121111111111
111111111112131313131313120F0D0B0A0808090C121B23
2F435667716C6560594F473D373D4245453A2F261E18120D
090A0C0D0E0D0C0D0D0D0D0D0D0D0D0E0E0E0E0E0E0E0E0F
1012151718171615141312100F0F0F0F0F0F0F0F0F0F0F0E
0F0F0F0F1010100F0F0F0F0F0F0F0F0F0F10101111111212
13141618191818181A20252A2D2C2B2B
72777C7E7E79736D6456483B312F2E2C2D33393F423B332E
2A2B2C2C2B2A28272523201E1C19171514131111100F0F0F
0F0E0E0E0E0E0F0F100F0F0F101316181A1C1E1F201D1B19
1715131212181D21252728292925201C1919191818171717
17161515141414141313121212121212121212121110100F
0E0E0D0D0D0E0E0F0F0E0E0E0F1215181C1F22262B30363C
434F596266615B554E463E3631363C3E3F372E272019120C
08090B0D0E0D0C0C0D0D0E0E0F0F10111111111111111111
1214151717161514131211111010100F0F0F0F0F0F0F0F0F
0F0F0F0F0F1010101011111212121111111212121211100F
101214161A1F24292D2F303232333333
76787A7B7A7875726C62564C433B342E2B31383D403B3532
2F303131302D2A282523201D1B1917151312121110100F0F
0F0E0E0E0E0E0F0F0F0F0F10111316181A1D1F21211E1B19
17151413141A20242828272725221F1C1A1A1A1A19191817
171615141413131313131212111212121212121212100F0D
0C0C0B0B0A0B0C0D0D0C0B0C0F171F272F363D444A4E5154
56585A5A59544E49433C352F2B30343738322C272119120B
07090B0D0E0D0C0C0D0E0E0F101113141514141414141414
141516161615141312121111111010100F0F0F0F0F0F0F0F
0F0F0F0F0F0F101011121314141413131313131413110F0E
0E1013161C26313A403E3B3938393A3A
7878787878797978756D635B51453A302A30373C403C3735
3434353433302C292623201D1B1816141312121111100F0F
0F0E0E0E0E0F0F0F0F0F1010111416181B1D2022221F1B19
17161514161C22272A28262422201E1C1A1B1B1B1B1A1918
181615141414141414131212111212121313131313110F0E
0C0B0B0A0A0A0B0C0D0B0B0C101C28343F49525B62656667
65615C56504B453F39332D28262A2E31322F2B28231A120B
06080B0D0E0D0C0D0D0E0F10111315161817171616161616
16161617161513121111121211111010100F0F0F0F0F0F0F
0F0F0F0F0F10101011131416171615151415151514120F0E
0E1014181E2D3B474F4A44403D3F4140
7978777676797B7C7B746D665D4F41362E33393C3F3C3938
3838383735322E2B2825211E1B1916141212121111100F0F
0F0F0F0F0F0F0F0F0F0F1010111416181B1E202223201C19
17161616181E23282B282522201F1E1C1B1C1C1C1C1A1918
17161514131414141514131212121212121313131312100F
0F0E0E0E0E101215171615171C293744505A636C72737270
6B62584E45403C37322D28242326292B2D2B2927231B130C
07090C0D0F0E0D0D0E0F1011131516181919181818171717
17171717161413121111121212111110100F0F0F0F0F0F0F
0F0F0F0F0F10101112141517181716151515151515131111
1215191D2535445159524B4642444646
78787878787A7B7B79736C655E554D453F3F3F3E3D3C3A3A
39373635333332312E2925201C191613111111121211100F
0F0F0F0F0F0F0F0F0F101010111316181A1D202223201C1A
181818181A1E22262826232220201F1E1E1D1D1C1B181512
111111111112121314141515151312100F0F0E0E0F101214
17181A1C20272E353B3C3E41454D555B616467696967635F
5A5148403A39383735312D2A292A2B2B2B292725211A130E
0A0C0E101110101011121314151516161717171717171616
16161717171514121112121212111010100F0F0F0F0F0F0F
0F0F1010101112121314141515141313121111101114181B
1F24292E343E474F534F4B4745464847
78797A7A7A7B7A79777069635D5B5854504B45403D3C3C3B
3A37353332343536352F28231E1A1713111112121211100F
0F0F0F0F0F0F0F0F10101010111315171A1D202223201D1B
19191A1B1C1F21242524222120212121201F1D1C1A16110E
0C0D0F1011111213141617181815110F0D0C0B0B0D11161B
2023272C333E4A545D62666A6D6F70706F6C67625D58524C
463F38322E313537383532302E2E2D2B2A2725221F191410
0D0E11121313121313141516171615141415161717161615
151617171716141312121212111110100F0F0F0F0F0F0F0F
0F101010111213131414131313121111100E0D0D0F171F27
2E34393F4447494B4C4B4A4848484848
77787A7B7B7A7977756F69635F6162615F554B433D3D3E3D
3C3835323135383A3A332C26201C18141111121213111010
0F0F0F0F0F0F0F0F1010101011131517191D202223201D1B
1A1B1C1D1E1F2122232221202021222323211F1D1A15100B
090B0D0F1112121415181A1B1B17120F0C0B0A0A0C121A21
282D32394251606C787F84898C8A86827B736A60564E463F
372F292321282E3438363433312F2C29262422201D191511
0F1112141515151516171818181615131314151617161515
151516171716151413131212111110100F0F0F0F0F0F0F0F
0F101111121314141514131312111110100D0C0B0F1A2631
3A41474D504E4C4A48494A4A4A4A4A4A
7577797A7B797775726D67626064686A695C50463F3F4140
3F3A363332373B3D3D372F29231F1A151212121213111010
1010100F0F0F0F101010101011131516191C202224211E1C
1A1C1E1F20202021212121202022232323211F1D1A15100C
0A0E1214171818191B1C1D1E1D1814100E0E0F10131B232C
34393F4650606F7C8890969B9C9790887E7366594D443B33
2B231D181720293036353434332F2B2724211F1D1A171512
111214151616161617181819191614121113151616151514
141516171716151514141312121110100F0F0F0F0F0F0F0F
10101112121314141414131212111010100E0D0E12202F3B
464C515658534D4945474A4A4B4A4A4A
7375777878777574716C66615E626566655C534C47464645
433F3B3837393B3C3B37322F2A241F1A1614131211101010
10101010100F0F0F1010101111131416181C202324211E1B
1A1C1F2021212222222222222221201E1D1B191817161616
181E24282C2D2D2D2C27221E1A171514151B21282F353C43
494D51565B646C73797D8083837E78726B625A5047403932
2B231D17161C23282D2D2D2E2D2A2724211F1C1A18161412
111213141414141515151616161514131213141515151515
151616171717161615151414131211100F0F0F0F0F0F0F0F
101112121312111110111212131111111214181C222E3943
4C4E4F5252504D4A48494A4A4A4A4A4A
7072747576757472706A65605D5F6061605C57534F4E4C4A
4844413E3C3B3B3A39383634312B241F1A1714110F0F1010
1010101010100F0F0F10101111121415171B1F2324211E1B
1A1D1F21222323232424242423201D1B1817161516191D21
262E363C414241403D32281F181819191D2934404A4E5358
5C5F6062636465666667676765625E5A55504B46413C3732
2C241D1815191D2124252527272522201E1C1A1715141312
111212131313131313131313141313131313131414141515
161616161717171717161615141311100F0F0F0F0F0F0F10
1011121313110F0D0D0F121415131213151C232A323B444B
514F4D4C4B4C4C4B4B4A4A4949494949
6E707273747372706E68635E5B5C5E5F5F5D5B595754514E
4B484543403E3C3A393A3A39373029241E1915110F0F1011
1110101010100F0F0F10101112121314171B1F2325211E1C
1A1D2022232424242526272726211C1915141313151B2229
313B444C515251504B3C2E22191A1D1F263544535F63666A
6C6D6D6C6A66625D5A585654514D494643403D3A3734302D
29221B161315191B1D1F202222211F1D1B19171513121212
111112121212121212121111121212131313131313141515
161616161617181818171716151312100F0F0F0F0F0F0F10
1112131414110E0C0B0F13161816151619232D363F474D54
57524E4A47494B4B4B4A494847484848
6D6F71737372706F6C67625D5A5C5D5E5F5E5E5E5D595652
4F4D4B4845423F3C3B3C3D3E3C362E28221D18120F101011
121110101010100F1010101112121314161B1F2324211E1C
1B1E2123252525252527272827221E1B181717181B222B33
3B454D555A5A5957514234271F21262A314151606B6E6F71
7272706D696159514A4743403C3936343231302F2E2C2A28
251F19151213151617191B1D1D1C1B1A1816141211111111
111111111111111111101010101112131313121212131515
161616161617181818181717161412100F0F0F0F0F0F1010
1112131414100E0C0C11171C201E1D1E212D39424B505459
5A544D4844474A4B4C4A484747474747
6F7173757573706D6A6763605E606264656361605E5C5956
5352504E4C4A4744424242413E38322C26201B1512111211
11111010101010101010101111131415171B1F2224211E1D
1C2024262827252524232322232527292B2B2C2D30353B40
44464849494745423F3A353230343A3E444A51575B5C5C5C
5C5A5855514C46413C3A383533302E2C2A29282625232120
1D19161210111314151618191A1918171514131110111111
111111111111111111111111111212131313131313141415
161616161616161616171717161411100E0F0F10100F0F0F
0F0E0E0E0E0D0D0D101B252E34333233363D454A4F535558
5854504C494A4C4C4D4B4A4948484949
7274767777736F6C696765636265686A6A686462605D5B59
5756565553514E4C49484643403B35302A241E1915141312
12111010101010101110101111131516191C1F2123211F1D
1D2226292B2926252321201F202830373D3F40424447494A
4A45403C3834312E2E33383D43494E535653504D4A4A4947
45423F3C393634312F2E2D2B2A2927252422201E1D1B1918
161412101010111213141516171614141312111010101111
111111111111121212121212121212131313131314141415
1515151615151514141516161614110F0E0F101011100F0E
0E0C0A0A0A0B0E111725333F48484748494D505153545656
565452504E4E4E4D4D4C4B4A4A4A4A4A
7376787979746F6B6867666565686A6D6E6A676462605E5C
5A5B5B5A595754524F4D4A46433E39342F28221D18171514
131111101010111111111010111315171A1C1E2122211F1F
1F24292D2E2B282623201E1D1F2B38424B4E4F5253555554
50473E362E29262324313E49535A6066675D5349413E3C38
34302C28252422201F1F1E1E1D1D1C1B1A19181615141312
11111010101010101011121313121111101010100F101010
111111111111121212121212121212131313131414141415
1515151515151414131516161614110F0E0F11121211100F
0E0B0908090B10141D2E3F4E595A595A5A5B5A5958575755
54535251504F4F4E4D4C4B4B4A4A4B4A
7577797A7A756F6B68676767676A6C6F6F6C69666462605E
5D5E5E5E5E5B595754514E4A46423E39342E27211C1A1816
141211111111111112111111111316181A1C1E212221201F
2025292D2F2C2927252323232633414C5558595B5C5B5854
4F4439302924232126364857646B7075736556483C38342E
29231E1A17161514141414151515151515131211100F0F0E
0E0E0F10100F0F0F0F0F101010100F0F0F0F0F0F0F101010
101011111111121212121212121212121313131414141414
1515151616151414141516161613110F0E0F111112111010
100D0C0B0D11171D27394A59656665666564625E5B595755
5353525151504F4E4D4D4C4B4B4B4B4B
7678797A7A75716D6A696968686A6B6C6D6C6A6967646260
5E5E5E5D5C5A58565453514F4D4A46423D352D251F1C1A17
15141212111110111111111112141517191C1F2123201E1D
1C1E2123252525272A31383E44484B4E50525252504A443F
3A36333030353A4048545F6A7275767673695D5248433E37
312A231E1A171614131314141515151514131211100F0F0F
0E0F0F0F100F0F0E0E0F0F10100F0F0F0F0F0F0F0F0F1010
101111111111121212121212121212121212121212131314
1415161617171718181717161512100D0C0C0C0D0D0E0F11
1315181B20252C323A455059606160616060605E5D5B5957
5553514F4D4D4D4D4D4C4A4A49494949
7678797A7A76726F6C6B6A696869696A6A6B6A6A69666361
5E5D5D5C5A5957555455555453514E4B463C322A221F1D1A
18161413121110101010111213141516181C1F2223201D1B
1A1A1A1B1D202428303E4D58605A544F4A4A494642382F29
25292E333B4754606B72777D807E7B78736C655D564F4942
3B332B241F1B181614141516161616161514131211101010
101010100F0F0E0E0E0F0F0F100F0F0F0F0F0F0F0F0F1010
101111111111111212111111111112121211111111121213
1415161718191B1C1C1A181714120F0D0B0A09090A0D1014
191F262C333A40474C5054575A5A5A5A5A5C5D5E5E5D5B5A
5854504C4A4B4C4D4D4B494847484848
77787A7A7A7774716F6D6C6B69696968696A6B6C6B686461
5F5D5C5B5A58575655575858585755524E43392F2724211E
1B191715141311111011111213141516181C202324211E1C
1A181817191E242A34495D6D766A5C514846443F392C2019
161F2B3543556778868A8C8E8E89837C75716C665F575048
40372E26201C181614141516171717171615141211111111
10101010100F0F0E0E0F0F0F0F0F0F0F0F0F0F0F0F101010
101011111111111111111111111111121211101010111213
14151617191C1E1F201D1A1714120F0D0B090808090D1217
1E28313B444B52585C5B59585757575757595B5D5E5D5C5B
59544F4B48494B4C4C4A484746474747
77797A7A7A787573706F6D6B6A69686767696B6C6C686461
5E5D5C5A5958575757585A5A5B5A5958534A40372F2B2824
201D1B191714131111111212141516181A1D202224222120
1F1E1D1E20252B313C5266777F705F5245413D362E20150E
0E1D2F3F51667B8E9C9E9D9D99938B827A7875706A625951
483E342B231F1B1816161718191818181716151413121211
11111010100F0F0F0F0F0F0F0F0F0F0F0F0F0F1010101010
101011111111111111111110101111121211101010111314
151617191A1E2123231F1A161311100F0E0C0B0C0E131A21
29333E4852595F6467625C585454555455575A5C5D5D5C5C
5A544F4A47494B4C4C4A484746464646
7678797A7A787573716F6D6B6968676666696B6C6C67625E
5B5B5C5B5B5A5959595959595858585654504B46403B352F
2925211D19161311100F10101216191D1F1F1E1F2024272B
2F353A40454647494C545B5F615B554F473E352D251D1714
192E455A6E7C88959FA2A3A3A19C97908987837E776E645A
50453A302723201D1B191817171717171716151514131211
10101010100F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F10
101010111111111212111111111112121212131314151618
191A1A1B1C202326251E16100C0E10121416181B20283038
3F464B51565B5E61625E5A575556575758595A5C5C5D5C5C
5A56524E4B4B4C4B4B4A484847474747
7577797A7A787674716F6D6A6968676666686B6C6C665F5B
57595B5C5D5D5C5C5B5A58575656565554555554514A413A
332D28231E191512100F0F0F11171C2225211D1C1D262F37
414D58626966625F5B544E4843474A4B483B2E251D1B1C1E
27425D758A90949BA0A4A7A8A7A5A19D9995918B847A6F64
594D41352C282622201C1918171616161616161616141211
101010101010101010100F0F0E0F0F0F0F0F0F0F0F0F0F0F
101010101011111212121212121212121314151617181A1C
1D1D1D1D1E222629281D130B070C12171D21262C333D464E
555758595A5B5C5C5C5A58565657595A5C5B5B5B5B5C5C5C
5B5855524F4E4D4B4A49494949494949
757778797978767573706D6A6867666565686A6C6C655E58
55585B5D5E5E5D5D5D5A585655555554555A5E6060574D44
3C362F28221D181512100F0F111820262A231C1A1B293743
5161707D857F7771665647382F3842474837261D16191F24
3251718DA2A3A2A5A6AAADADACACAAA7A4A19D9891867B6F
6356493D332F2C2925211C1A181717171718181818161311
101010101010101111100F0F0F0F0F1010100F0F0F0F0F0F
0F0F101010111112121212121212121313151618191B1D1F
20201F1F2025292C2B1E1209040C151C242B323A434E5861
676663615F5E5D5A585756555457595B5C5B5A5A5A5B5C5C
5B59575552504D4B49494A4A4A4A4949
757778797978777674716E6B6867666565686A6C6B645D57
54575B5E605F5F5F5E5C595755555554565E64696A61574F
464039312B251F1B17141211131A22292D241D1A1C2F4454
65758390968D81776855423026313C4345322117121B2732
4363839FB3B1ACACABAEB1B1B0B1B1B0AEACA8A39C918579
6C5E51443A35322E2A251F1C191818181819191A1A171412
11101010101111121211100F0F0F101010100F0F0F0F0F0F
0F0F0F0F101011121212121212131313141618191B1D1E20
2121212022272C2F2E22150D09121E262F373E47505B656E
736F6B67625F5C58555554545457595B5C5B5959585A5B5C
5C5A585754514E4B494A4A4B4B4B4A4A
78797A7A7A7A79787773706D6A69686666686A6C6B655F5A
575A5E6061616060605E5D5C5A595958595E636768635D59
534E48423C36302B26201B17161A1F2528221F1F263F5A6E
8085878B887A6A5C504E4C48454442413C2C1E1514263B4C
61768BA0B0B1B1B3B3B4B5B4B4B5B6B5B4B0ACA79F95897E
716356493E3935302C27221E1C1A1A191919191A1A171513
1212111111111111111110100F0F101010100F0F0F0F0F0F
0F0F0F1010101111121212121213131415161718191A1B1C
1C1D1D1E20252A2F312B2522212A333B42464A4F545C6267
6B6A686664615E5B595858575758595A5B5A595858595A5B
5B5A585655524F4D4B4B4C4C4C4C4C4C
7B7B7B7B7B7B7B7B797672706D6B696867696B6C6B66615D
5B5D60616362626262616160605E5D5C5C5F616364646361
5F5B57524D47413B352C251E1A1C1E21242121242F4F6F88
9992888277645241384756606456483F34281E1719334F67
7D8893A0AAB0B4B7B9B9B8B6B5B8B9B9B8B4AFAAA3998E83
76685B4E433D38322E2924211F1D1C1A1A1A1A1A1A181615
1413131211111111111110101010101010100F0F0F0F0F0F
0F0F0F101010111112121212121314141516171718171717
18191A1C1F242A30343435373A41494F53545556575A5D5F
6162646464625F5D5B5B5B5A59595959595857575758595A
5A5957565452504F4D4D4D4D4D4D4D4D
7D7D7C7C7C7C7D7C7B7874716F6C6B6968696B6C6B67625F
5D5F626364646363636364646362605E5E5F61626366686A
6A6764605B56504942382E251F1F20222423252A375D829E
B0A08C7F6D57422E26405B6E78624B3D3026201A1F40627F
979A9CA2A8AFB6BABCBBB9B7B6B9BCBCBCB8B2ADA69C9287
7B6E605347413B35302B2724211F1D1C1B1B1B1A1A191716
1514141312121212121111111010101010100F0F0F0F0F0F
0F0F0F101010111111111112121314151616161717161515
1517191C1F252B31373D42484E545A6063615F5E5C5C5C5B
5B5E616364615F5D5C5C5C5C5B5A59585857575656575859
59585756545351504F4E4E4E4E4E4E4E
7E7D7D7C7C7D7E7E7D7A7673706E6C6A696A6B6C6C686461
606163646565646464656667676462605F5F5F5F61666B6E
716F6C6966615B554D43382F282625262725272B3A648DAD
BEA78B78624B38231C3C5D7581674C3C2D2828252E507391
A8A5A1A3A4ADB5B9BBB9B6B5B4B8BCBDBDBAB6B2ABA2988D
817466594D453F38322D2A272422201E1D1D1C1C1B1A1918
1616151413131313121212121111111010101010100F0F0F
0F0F0F101010111111111112121315161616161616151313
14171B1F242A30373E464E565D62676A6C6965625E5C5A57
575A5E6163605E5C5B5C5D5D5C5B59585656555555565758
58575655545352504F4F4F4E4E4E4E4E
7B7B7B7B7B7C7E7F7E7B7774716F6D6B6A6C6D6E6E6A6663
61636465656564646465666767656361605F5F5F6064686B
6D6B696663605C58534C463F3A3836353227201C265583A6
BA9F806D584B41332F415260675441362F363F4652687E92
A1A1A0A2A3A8ADAFB1B0AFAEAFB3B8BABDBFBFBEBBB0A599
8C7F7163564D443B35302D2A28262423222121201F1D1B19
171616151414141313131313131211111010111111100F0F
0E0F0F0F1010101011111212131415161717161616141313
151C242B323940474D5155585B5F62656563615F5D5C5B5A
5A5D5F61615E5B5957595A5A5B5958575655545353545555
565554535251504F4E4E4E4D4D4D4D4D
79797979797C7E7F7F7B7774716F6E6C6C6D6F71716C6865
6364656565646463636466666665636261605F5E5E626567
68666462605E5D5A5855524F4C4A4746402C1C111647789D
B2967662504E4D464245484B4C42393435465866757E8791
989C9EA1A2A4A5A6A6A6A7A7A9AEB2B6BAC1C6C8C7BCAFA3
95887A6C5F53493F3733302D2B2928272626252423201D1A
18171716151515151515151514131211111111121211100F
0E0F0F0F0F0F0F1010111213141516171817161716151414
18222D3741484F565B5A5959585A5C5D5D5C5B5B5A5B5C5D
5E5F6060605C585553555758595857575654535150515353
54535251504F4E4D4C4C4C4C4C4C4C4C
77777777787B7E7F807C787572706F6D6D6F7172726E6A67
64656665656463636364666767666463615F5E5C5C5F6264
666462605F5F5F5E5D5E5D5C5B5956544C331D0D0E407398
AD8F6D58464C52514F49423F3C3735343B536D8293929092
93989C9E9F9F9E9E9E9EA0A1A4A8ADB1B7C0C9CECFC3B5A9
9B8E817264584C413834322F2D2C2B2A2A29282826221F1B
19181817171717171717161616141312111212131311100F
0E0F0F0F0F0F0F0F10111213141617181817171716151516
1B2836424D555C6366635F5C59595A5959585857585A5C5D
5E5F5F5F5D5A56535153555758575656555351504F505151
5251504F4F4E4D4C4B4B4B4B4B4B4B4B
75767676777A7D7F7F7C78757271706E6E707274746F6B68
65656665656463636364666768666463625F5D5B5A5D6062
6362605F5E5F606061636465656766665F442B1917457394
A7896955464F595A594B3E363133383D48637E95A49D9490
8D949A9D9E9C999897989A9C9EA2A6AAAFBAC4CACCC1B4A8
9B8F827467594D42393532302E2D2C2C2C2B2B2A2824211D
1A1919181818191919191818171514121212131313121010
0F0F0F0F0F0F0F0F1011121415161719191817161716181A
202F3F4D5960666C6E69625D585757555454545556595B5E
5F5F5E5D5B5854514F525455575655555553514F4E4F5050
51504E4E4D4C4B4B4A4A4A4A4A4A4A4A
7676767676797B7D7D7B78767472706E6E707273736E6A67
64646564646363626365676869676563615F5D5C5B5E6264
666463626161616161606060626D777E806E5E52506B8597
A08C76675B5B5C5954493F393843515C6874808B93918E8C
8D949CA0A3A09D9B99999999999A9B9C9EA5AAAEAEA89F98
8E83776B5F54493F3733302D2B2B2B2B2C2B2B2A29262320
1D1B191717191A1C1D1B1A18171615141313131212111110
100F0F0E0E0F0F0F101112131416181A1B18161516191E22
2B3A4A586366686A6A65605A5656575757565757585B5D5F
605E5D5C5A57555251525455565555545453525050515152
52504E4D4C4B4B4A4A49494949494949
767675757577797B7B7A78777573716F6E6F7172726D6966
63636463636362626366686A6A686563605F5D5C5C606366
6867656564636262615D5A595E7185959F98908C8A91989B
9A90847B71685F575048423F42566A7C888580807F828688
8C949DA3A8A5A19F9C9A99979593918F8E8F90908F8D8985
7F756B61574D453C35302C292728292A2B2B2A2A29272522
201D1A17161A1D20211E1B19181716151413121211111111
10100F0E0E0F0F10111112131417191C1D191514151C252C
364654616B6A686865615C5854565758595959595A5C5E5F
605E5C5A5957565453545455555454545353525252525353
53514E4C4B4A4A4A4949484848484848
7676757575767879797978777673716F6E6F7172716D6865
62626363636262626366686A6B686462605F5E5D5D606467
6867666665646362615B57555C7792A8B9BBB9BBB8B0A79C
93918E898274655A514A464248647F96A394847B74797F81
87919BA4AAA7A3A09D9B9894918C8884807E7C7977777776
726A605850484139332E2A26242527292A2A2A2A29282624
221E1B18171C212426221E1B181818171514121111111111
11100F0F0E0F10101111121214171A1D1E1A161516202C35
41505E6B736F6A67625E5954515356575959595A5B5D5F60
615E5B595757565555545454545453535353535353545454
53514E4C4A4A4A494948474747474747
7776767575767778787878777674716F6E6F7172716D6865
62636363636262626366696B6B686462605F5E5D5E616467
6968676665646363615A54525A7999B3C9D3D8DFDDC9B39F
90959997927E6A5C514E4F4F587592A9B59F86776B707779
808D99A5ADABA7A4A19E9A948F89837D78716C6663646666
645D554E47413B352F2A2622202224262828282928272625
23201D1A1A20272C2E28211D191919171614131211111212
1211100F0F0F10111111121214171A1D1F1A171619263541
4D5A657076716A655F5B5753505255585A5A5A5B5C5E6061
615E5B585657575757565554545353535353545455555555
54514E4B494949494847474646464646
797979797979797A7A797877767472706F707272726E6B68
66666666666564646466686A6A67656361605F5E5F626568
6A69676766666667655D57545A7593AAC0CDD7E1E2CDB7A4
959BA09F9A826B5B515A666E798A9AA8AE9D8B7E73727270
748596A4AFAFACACA9A49F98918E89847E756C655E5C5B58
554F48433E38332E2925211F1D1E20212323242525242323
22201F1E202A33393C3228211B1A1A181615141413131313
121111101010101011111213141516181A1818191F304250
5D63676C6E6C6865615D59565456585A5C5C5C5C5D5E6061
605D5A585658595A5A595757565554545454555555555454
53504D4A484848474746464645454545
7B7B7C7C7C7C7C7C7B7A7877757472717071727373706D6B
6A6969696867666565666869696765636261605F5F636668
6A6968676768696A696059565A718A9EB2C3D1DEE2CFBBA9
9CA1A6A59F856D5C54687E8D9B9EA0A5A59B8F867C746D67
697D92A2B0B1B1B3B1ABA49C9593918C867B70665D57524C
47423D3935302B2723201D1B1A1A1B1C1D1E1F2021212021
2121232428343F474A3D2F251C1B1A181616151616151413
1312121111101010101113141514131415171A1D263A4E5F
6C6A686766666664625E5B5957595B5D5E5E5D5D5D5F6060
605D5A5857595B5C5D5B5A59585756555455555656555453
514F4C4A484747474646454545454545
7C7D7E7E7F7E7D7D7C7A7876757372717072737373716F6D
6C6C6C6B6A69676665666768686765646261616061646769
6B69686767696B6D6C625A56596D8394A8BED1E2E9D6C1AF
A2A8ADADA68A705D577492A8B8B2A9A6A09991897F72675F
5F768DA0B0B3B5B9B8B1A89F979795918B7D6F6358504840
3936322F2C2824211E1B191716161717181A1B1D1E1E1E1F
202326292E3D4953564736291E1C1C181616161718161514
1313131212111010101113151614121214171D222D445A6C
787168635F616362615E5C5A5A5B5E5F60605F5F5E5F6060
5F5C5A58575A5C5E5F5E5C5A595857555555565656555452
514E4C49474746464645454545454545
7D7E7F7F807F7E7D7C7A787674727270707173737472706F
6E6D6D6C6B69686665666767676665646362626162646769
6A696867676A6C6E6E645C58596879889AB5CDE2EDDBC7B8
ABAEB0AEA68D75656182A3BCCBBEAEA59B97938C83726359
586E8699AAB1B6BDBEB6ADA39C9C9C98918375685B50463B
33302E2B2925211E1C191715141414141516181A1B1B1B1C
1F242A303846545E604F3C2E211E1D191616171819171514
13131313131211101012131516141313161C242B374D6274
7E7468605A5D6161615F5D5C5C5D5F616261605F5F5F5F5F
5E5B5958575A5D60615F5D5B5A5857565555565756555352
504E4B49474746464645454545454545
7B7B7C7D7D7D7D7D7C79767472706F6D6D6F72737472706E
6D6C6B6A6967666564656666666563626161626263646567
68686767686A6C6E6D67615E5F666F7889ABCBE6F6E6D3C6
B8B0A99E948A827B7D92A8B8C3B8ABA39B97938D84736459
56677A8A9AA7B2BDC3BCB3ACA5A5A4A09A90847A6F625549
403C3835312C2825211D1A17151515161617181A1B191819
1D27323B45515B636454413325221F191616171819171515
1414141413131212121213141516191C212B353F4A56626C
726C66615D5F6161605F5D5C5B5D5F6061605F5E5D5D5D5C
5B5A5958585A5C5E5F5D5B5A595756555454555655545351
504E4C4A484848484747474747474747
787979797A7B7C7C7C7875726F6D6C6A6A6D71737572706E
6C6A69676665646363646565666462616061626363646465
66666767686A6B6C6D6965656463666977A0C7E7FBEFDED4
C5B3A18E82878E9299A2AAB3B7B0A8A19A97938E8574655A
55606F7A899BACBCC6C0B8B2ACACABA7A19B938C82736558
4D48443F3A342F2B27221D19161617171818191A1A181616
1B2A3A46525B6268675846382A25211B1717171818171615
151514141413131414121212141920262E3A47525B5F6164
6564636160616161605E5D5B5B5D5E5F605F5E5D5C5B5A59
59585858585A5B5C5C5B5958575655535353545454535251
504E4C4B4A4A4A494949494949494949
7677777777797B7C7B7874716D6B6A68686C707375726F6D
6B6968666564636262636465656361606061626464646363
6465666768696B6C6C6B696A68605C5A6592BEE1F9F2E6E0
D2B69C83758699A5B0B1B0B2B2ABA59D9795938F8876665A
545B656D7A91A6BAC8C2BBB7B2B2B1ACA8A5A09B92827163
56504C46403A34302B251F1A171718181919191A1A161414
192C40505E65696D6B5C4B3C2F28231C1717171818171616
161515141414141515131112141C262E394856636B66615E
5B5E606061616161605F5D5C5B5D5E5F605E5D5C5B595857
57575858595A5A5B5B5A5857565554535253535454535251
504E4D4C4B4B4B4B4B4B4A4A4A4A4A4A
757474747577797B7B77726F6C6A6867676B707375726F6D
6A6967656463636262636465656361606061636565646363
6364656667686A6B6C6C6C6E6C5F56505986B3D6F1F0EAEA
DEBC9B7E6E88A3B4C2BBB2B0ABA7A19B9594928F8978695D
56585D616B849CB1BFBBB5B2AEAEAEAAA7A7A5A19A897768
5B555049433D37332D27201B181818191919181919151312
182E4456656A6D706D5F4F41332C251D1817171818171616
16161515141515161613111115212E3A4655626E746B615A
54595E5F61616061605F5D5B5B5C5E5F5F5E5D5C5A595756
555657585859595959585655545453525252525353525251
504F4E4D4C4C4C4C4C4B4B4B4B4B4B4B
73737373737577797975716E6B6A6968696C707374716E6C
6A6A69686766656464656666666564636264656667666665
656464646466686A6B6C6C6D6C6159555C7FA3C0D8E3E8F0
EBC9A88C7B91A9B7C1BBB3B0ACA7A29B9593918D877A6D63
5B5858585D6F81919C9893908E919393929392908A7A695A
4E4A47423D38332F2B241F1A171617171716151616121112
182C415261686C716F615244372F281F1918181818171717
17161515141516171713111116283A49575F656C6E69625D
595B5E5E5F606061615F5C5A595B5D5E5F5E5E5D5D5B5957
565656565656565656555352525253535353525252525353
52514F4E4D4C4C4B4B4B4B4B4B4B4B4B
727271717173757777736F6C6A6A6A6A6B6D707273706E6C
6A6A6B6A6A68676665666768686766656566676869686868
67656362616467696B6B6B6C6B635D5B607893A8BED2E3F3
F5D6B59B8B9CAEB7BEB9B3B0ACA7A29C96938F8B857B726A
625B5651525D6A747B7772717075797B7D7E7E7D7869594C
403E3D3936322E2B27221D19161515151413121313111112
182B3E4E5C646A70706355473B322B221B1A191818171717
171615151415161718141212182E46586767666867666460
5E5E5E5D5D5F6061625F5C59585A5C5D5F5F5F5F5F5C5A58
5656555453545454545251504F5153545453525251535454
5453514F4E4D4B4A494A4A4B4B4B4B4B
7170706F6F72737575716E6B696A6B6B6C6E707272706D6B
6A6B6C6C6C6A6867676869696A696867676869696A6A6A6A
696562605F6266686A6B6B6C6C65605E62718392A6C4DEF5
FDDFBEA796A5B4BBBFB9B2AEAAA6A19C97938E89847D7670
695E544C484F575D625E5A595A60666A6D7071716D5F5043
39383835332F2B2926211D19161615141413121212111214
1A2B3D4C5962696F6F64574A3E352D241D1B1A1918181718
181715151415161819141212193550667670696663636461
5F5E5D5C5C5E6062625F5B5957595B5D5E5F5F60605E5B59
575554525152525252504F4E4D5052545554525151535455
565452514F4D4B4A49494A4B4B4B4B4B
706F6F6E6E70727474706D6B696B6C6D6E6F7071726F6D6B
6A6B6D6D6D6C6A6868696A6B6B6A6969686969696A6A6B6B
6A66625F5E616567696A6A6B6B676463656B757E8EB3D5F2
FFE5C8B3A4AFB9BCBEB8B1ADA9A6A29D98938D88837F7B76
7063584E484C51545753504F4F54595C606263636054483D
343332302E2B282623201C19171616151514131414141618
1F2E3E4B5760676E6E64574C41382F261F1D1B1918181818
1817161515151618191514141D3B58707F766A645F616462
615F5D5C5B5E6062625E5B5856595B5C5E5F6061615E5C59
5755535250515151514F4E4D4D4F52545554525150535556
565452514F4D4B4948494A4A4B4A4A4A
717070707072737474726F6D6B6D6E6F7071727372706D6B
696B6D6D6E6C6A6867696A6A6B6A68686767676767696A6B
6B67646160626466676868696967656566666A6F7DA3C8E7
F8E4CEC0B4B9BEBCBBB8B4B1ADA9A49F99948E8984807D7A
766E686361676E7376736F6C6965615D5A595957544C453E
38322C2723222221201D1B1A1919191A1A1A1A1C1D1E2124
2A37444F5961676C6C62564C41393129221F1D1A19181818
18171616161615171817191C253F596E7C746B6661636463
615F5D5C5B5E6061625E5B5957595C5D5E5F6060605D5A58
56555452525353545452514F4F5052535453525151525455
555351504E4C4B494848494A4A4A4A4A
72717171717374757573706E6D6F70717273737473706D6B
696B6D6D6E6C69686768696A6A696867666565646467696A
6B686664626364646565666767666667676261616D93BAD8
EDE1D3CBC3C2C1BCB9B8B7B5B2ACA6A19B958F8A85827F7D
7C7A79787B848D949895908C867A6D615854524E4A484542
3D3329211B1C1D1D1D1C1A1A1B1C1D1F2121222427292D30
36404B535B62666A6A60554B413A332B25211E1B1A181818
181717171716151517191E232D43596B77726B6764656563
62605E5C5C5E5F61615E5B59585A5C5E5F5F5F5F5E5C5957
555454535455565757565453525252525252515151525353
5352504E4D4B4A484848494949494949
72727272727475767673716F6E7072737474747473706D6B
696B6D6E6E6C69686768696A6A696766656463626265686A
6C69676564646463636364646566686A6A6058545C83ABCB
E2DFD8D7D2CCC5BCB5B7B8B8B6B0A9A39D97908B86848281
8284878B909AA4ABB0ADA8A39A88756455504B4542424343
4134271D1617191A1B1A1A1B1D1F212426282A2C2F33373C
414950575C626568675E544B413B342D2723201D1A191817
1717181818161414161B222933465969746F6A6764656564
63605E5D5C5E5F60615E5B5A595B5D5E5F5F5E5E5D5B5856
54545454555658595A585655545352515151515151525252
52504F4D4C4A49484747484848484848
73737373737576767674716F6F7173747575757574716D6B
696B6D6E6E6C69686768696A6A696766656361606064686A
6C6A686665646362616162626366696C6C5E534D52769BB8
D0D5D7DDDCD2C7BCB4B8BBBBBAB3ACA6A099938D88868585
878C9399A1ACB7BFC4C2BDB8AE99836F5E57514945464849
473A2D241C1B1B1A1A1A1B1D202326292C2E3134383D4247
4D52585C60646667655C534A423C362F2A25211E1B191817
1717181919161413151C242C37485967716D696663646564
63615F5D5C5D5F60605D5B5A595A5C5D5E5E5D5D5C5A5856
545555555657595B5B5A5957565453515051515151515151
514F4D4C4A4948474647474747474747
747473737375767776736F6D6B6E70727374747474716E6B
6A6B6D6D6E6C6A6868696A6B6B696766656362606064686A
6C6A6766646362605F6060616265676B6A605753566D869A
AEBCC8D5DBD2C9C0BABDBFBEBCB6B0AAA49E98928D8A8887
898E949AA2ACB6BEC4C3C1BEB8AB9C8F827A736A645F5B57
534F4B4741362C231E1F222326282B2F3235373B3F454B50
565C6266696A6967635C544B433D37312B27231F1C1A1918
1717181919161414161B222933475969736E686460626463
63615F5D5C5D5E5E5E5C5A58575859595A59595959595858
57575656565758595A5A5959585654535151515050505050
504E4C4A494847464546464646464646
747473737375767776726D6A686B6E6F7172737373716E6C
6A6B6D6D6D6B6A6868696B6B6B6A6866656362616164686A
6C6967656362605F5E5E5F606163666869625D5A5B66737F
8EA4B9CCD8D2CAC5C0C2C3C1BEB9B3AEA9A29C97928E8C8A
8A8E9499A0AAB3BBC1C3C3C3C0BBB5AEA69E968D84796E64
5E63686A66513D2D222428292C2E3034383B3E41464C5359
5F666C7073706C68625C544C453F39322D2824201D1B1918
1717181818161515171A1F252F44596A756F67625E616363
62605F5D5D5D5D5D5C5A585756565656565656565758595A
5A5958575657585858595A5A5A585654525151504F4F4F4F
4F4D4B49474746454445454545454545
757474737375767776716C6866686C6D6F71727373716E6C
6B6C6C6D6C6B6968686A6B6C6C6A6766646362606164676A
6B69666563615F5E5D5D5E5E60626567686461605F606367
7290ADC6D7D2CBC8C5C6C7C4C1BCB7B2ADA7A19B97928E8C
8C90969BA2ACB5BEC5C8CACCCCCDCCC9C4BCB3AA9F8E7F71
69757F858366493425282D2E3133353A3E4144484D545C62
696F75797B756F68615B544D46403A342E2A25211E1C1A18
181718181816151617191D222B415769746E65615D5F6262
62605F5E5D5D5C5C5B59585655545453535353535457595B
5D5B59585757575758595B5C5C5957555352504F4E4E4E4E
4E4C4948464545444444444444444444
757474737375767776706B666466696B6E6F707272706E6D
6C6C6C6C6B6A696867696B6C6C6967656362616060646769
6B68656461605F5D5C5D5D5E5F62646667666464635D5A59
6184A6C2D6D3CDCCC9CACAC7C3BFBAB5B0AAA49F9A95918E
8D91969BA2ABB5BEC6CACDD0D3D8DBDCDAD3CAC1B49F8C79
708190999876533A272B31323537393F4346494D525B636A
71777C8080797169615B554D47403A352F2B26221F1C1A19
181717181817161718181B1E263E5467736C64605C5F6161
61605F5E5D5D5C5B5A595857555453525151515253565A5D
5E5C59585657575757595B5D5D5B58555352504E4D4E4E4E
4D4B4947454544434243434343434343
7473737273747677767069656265686A6C6D6D6F6F6F6E6D
6C6C6B6B6A6866646466696A6B6865636160605F60636668
696663615F5F5F5E5E5E5E5F606366686966626161606265
708FAEC8DAD6D0CFCCCCCCC9C5C1BBB6B0ABA5A09B979390
8F9194979DA8B3BDC5C8CACDCFD3D5D5D3CFC8C1B69F8875
6A7C8C9695735138262A313337393D43484A4C50555F6870
777B7E808079716A625C554E47413B35302B2723201D1B19
17171718181717181917181921395063716C65625F616261
60605F5F5E5E5D5C5B5B5A5A595756555454545455575A5C
5D5A575654555657585A5C5E5E5B58555251504E4D4D4E4E
4D4B4948464443414141414141414141
7272727272747576756F6964616366686A6B6B6C6D6D6D6D
6C6C6B6A69666361606467696A6663615F5F5F5F5F626466
6764605E5C5D5F6061605F5F6064676A6B65605E5F656D75
829DB7CEDEDAD4D1CECECECBC7C2BCB7B1ABA6A09C989593
9191919398A4B0BAC3C5C7C9CACCCDCCCAC8C4C0B59D8570
6575858E8D6D4C3524293033373B3F464C4D4F5256616C75
7B7E7F807E78726A635C564E47413B35302B2724201D1B19
1717171818181819191615151C344C5F6D6A666462626260
5F5F60605F5E5D5D5C5C5D5D5C5B59585757575757595A5B
5B58555352545657585B5D5E5E5B575451504F4E4D4D4E4E
4D4C4A48474442403F3F3F4040403F3F
7171717172747576756E6863606265676869696A6A6B6C6D
6C6C6A696764615F5E6265686965615F5D5D5E5E5F616365
66625E5B5A5C5F61626160606164686B6B65605E5F697580
8FA6BDD1DFDCD7D4D0D1D0CDC9C4BEB8B2ACA7A29D999794
92908E8E929EABB6BFC1C2C4C6C8C9C8C6C7C6C3B99E846E
6172828B8A6A4A3424283033383C41494E4F505358647079
808180807E79726B645D564F48413B35302B2824211E1B19
171717171818191A1A151211172F475B696865656463625F
5D5F6060605F5E5D5D5E5E5F5F5D5B5A5959595959595A5B
5A57545251535556585B5D5E5F5B575451504F4D4D4D4E4E
4E4C4A494744423F3D3E3E3E3F3E3E3E
7070707071737576756F68646163666769686868696B6C6D
6D6C6A696764615E5D6165686965615E5D5E5F5F60626365
64605D5A585C5F62646261606064686B6C655F5D5F6D7D8B
9BB0C3D5E2DFDAD7D3D3D2CFCBC5BFB9B3ADA8A39E9B9895
938E8B8A8C99A6B1BABDBFC2C4C5C6C5C4C7C7C6BDA28770
626F7C828063463122272F32373C41494F4F50535865717B
8282807F7D78726C655E574F48423B35302C2825211E1B19
171717171818191B1A14100E132A4255646565676765625E
5C5E606161605E5D5D5E6060615F5D5C5B5B5B5A5A5A5A5B
5A57545150525557595B5C5E5E5B575451504F4D4D4D4E4E
4E4D4B4A4945423F3D3D3E3E3E3E3E3E
70706F6F7072747676716C6865686B6C6D6C6B6A6A6C6D6E
6F6E6D6C6B6865626165686A6B6764626061626363646565
65615E5B5A5D5F6162605E5D5E62666A6B645F5D5F6E7F8E
9FB3C7D9E4E1DCD9D5D5D4D0CCC6C0BBB5AFAAA5A09C9895
928D89878995A1ACB6BCC1C7CCCFD0D1D1D3D2D0C7B09883
737678756E553D2C20252C30363A3E444A4B4D505663707A
82817F7E7B77726C655E575049423C36312C2925221F1C19
181717171818191A1A14100E13273B4C5B61666C6E6A6460
5C5E6060615F5E5E5D5E5F5F5F5E5D5D5C5B5A5A595A5B5B
5B58555453545758595B5C5C5C5A575452504F4E4D4E4E4E
4E4E4D4D4B4744413E3F404040404040
6F6F6E6E6E71747677736F6C6A6D707172706D6C6C6D6F70
70706F6F6E6B696766686B6C6D6A67656365666667666666
65625F5D5C5D5F61615E5C5B5B6065696B645E5C60708291
A3B7CADBE7E4DFDBD7D7D5D2CDC8C2BCB7B1ACA7A29D9895
918B878486909CA7B1BAC3CCD3D6D9DADADBDAD7CFBBA794
837A71665A4635271E22292E3436393F44464A4E54616E79
80807D7C7975716B655E58514A433D37312D2926221F1C1A
181717171818191A1A15110F13243544525C656F736D6660
5B5E6060605F5E5E5D5E5E5E5E5E5D5D5C5B5A59595A5B5C
5C5A5756555658595A5A5A5B5A5856555351504F4E4E4E4F
4F4F4F4F4E4A46434041424242424242
6F6E6D6D6D717476777472706F71737575726F6D6C6E7071
71717171706E6B69686A6C6E6E6B69676667686969686766
6562605E5D5E5F60605D5B59595E64686A635D5C5F728799
ABBECFDFE9E6E1DDD9D8D7D3CFC9C4BEB8B3AEA9A49E9995
908A8581828C97A1ACB7C3CED6D9DBDCDDDEDDD9D2C2B09F
8C7A685646372C211C20262B3133353A3E42464B525F6D77
7F7E7B797674706B655F58514A443D37322D2A26231F1C1A
181818171818191A1915111013202F3C49576470766E655F
5A5C5F5F605F5E5E5E5E5E5D5D5E5D5D5D5C5B5A595A5B5C
5C5A58575758595A5A5A5959585756555352504F4E4E4F4F
4F505051504C47444242434444444343
6E6D6D6C6D70747678767372717375767673706E6D6E7071
72717171706E6C6A696B6D6D6E6C6A6867696A6A6B696867
6563615F5E5E5F60605D5A59595E636769625C5B5F758C9F
B3C3D2E1EAE7E2DEDADAD9D5D1CBC5C0BAB5B0AAA59F9A95
9089837F7F87929BA6B2BECAD3D5D5D5D5D7D8D5CEC0AF9F
8B735B45332A231D1A1D22282D2E2F33373C42484F5D6A75
7D7B797774726F6A655F58524B443E38322E2A26221F1C1A
181818171818181919151211131E29333F4F5D6A7169615B
575A5E5F605F5E5E5D5D5D5D5D5E5E5E5E5D5B5A595A5B5C
5C5B59585758595A5A595857565555545452514F4F4F4F4F
4F505152514D49454344454545454545
6F6E6D6D6D717577797673717071727271706E6D6C6D6F6F
6F6E6C6B6A686765656668696A6866666566686869696868
6764615F5E5E5F5F605E5D5C5D60636768605B595F7690A5
B9C8D4E1E9E7E3E0DCDCDBD8D4CEC8C2BCB6B1ACA6A19C98
928A827D7C838D949DA7AFB8BDB9B4B0AEB6BCBDB9A79281
6D5A473526211E1B1A1C1F232627282B2F363E454E5C6873
7B7A777572706D68635D58524C453F38332E2925211E1C1A
181817171818181919161313141C242C353F485157555352
52585E6265625E5C5B5C5E5E5F5F5F5F5F5E5D5B5B5B5B5B
5A595857565757585856555453535353525151504F4F4F4E
4E4F4F504F4C48464445464646464646
6F6E6D6D6E727578797673706E6E6E6D6C6C6B6B6B6C6D6E
6D6B68656362616060616365666463636364656667686868
6865625F5D5E5F5F5F5F606061626466665F5A585E7894AB
C0CBD5E0E7E6E3E0DDDEDEDBD8D1CAC4BDB8B3ADA7A39E9A
958B827C7980888F959CA1A7A89E948C8895A0A6A48D7562
4E4034261C1A1A1A1A1A1B1E201F202227303A434D5A6671
79787573706E6A66615C57524C463F39332D2824201D1B19
181717181818181818161514151A20252B2F34393D404447
4C555D6468645F5B595C5F6061616060605F5E5D5C5B5A59
5857565554555556565453515151515151515050504F4F4E
4D4D4D4D4C4A48464545464647464646
6F6E6E6D6E727678797673706D6C6B696969696A6A6B6C6C
6C6864615F5E5D5C5C5E6062636261616162646465676869
696662605E5E5E5F5F60616364646466655E59575E7A98B0
C6CFD6E0E6E5E4E1DFE0E0DEDBD4CDC6BFBAB4AEA9A5A19D
978D837C787E858A8F93969A998A7C706B7B8A9292795F4A
372C2317111215181A1918191A19191B1F2A36404C58646E
767573716E6C68645F5B57524D464039332D28231F1C1A19
18171718181818181817161617191C1F21222225282F373E
46515B6469645E5A575B5F616262616161605F5D5C5B5A58
57565554535454545452504F4E4F4F4F5050505151504E4D
4C4C4C4B4B4947464546474747474747
6F6E6E6D6E7275777875716F6C6A696766676768696A6B6B
6B67635F5D5B5B59595B5E606160605F6061626364666869
6965625F5D5E5E5E5F61636567666666655E59575E7C9BB5
CBD2D8E0E4E5E4E2E0E1E2E0DDD6CFC8C1BBB6B0ABA8A4A0
9B90867E797D83868A8E9093917F6E605A6B7B84846A4E3A
271F180F0A0E13171B181616161414151A26333F4B57626C
7373716F6D6A67635E5B57524D47403A332D27221E1C1A19
1817171818181718181717171818191A1A17151517202A33
3D4A566167635D5A585C60626363626161605F5E5C5B5957
565453525252525252504F4D4C4D4E4E4F4F5051514F4E4D
4C4B4B4A494847464546464747474747
6E6E6D6D6D70727374716E6C6A6969686766666566686A6C
6C696764625E5B59585B5E61636160606061626364656666
6663605E5C5D5E5F606264666868686A68605A575E7D9DB8
CFD5D9E0E4E5E4E2E0E1E2E1DED7D0C9C3BEB9B4AFACA8A5
A0958A827D7F82848891989F9F8F7E716A768287856D5542
30251D130D1115191B191718181615151A2734414D57616A
7171706F6C6A67635F5B57534E47403A332D27221E1C1A19
1818171818181718181817171718181919171615171B2126
2E3C49545D5E5D5E5F616364646362605F5E5D5C5B595856
5553525150515151514F4E4D4C4D4D4D4E4E4F4F4F4E4D4C
4B4B4A49474645444343444445444444
6D6D6D6C6D6E6E6F6F6D6B69686869696866646363666A6C
6E6C6A6967625D59575B6063656361606061636464646464
63605E5C5B5D5E5F61636567696A6B6D6C625B585E7FA0BB
D2D7DAE1E4E5E4E2E0E2E2E1DED8D1CBC5C0BCB7B2B0ADAA
A59A9088828183838895A2ACB0A292867E858B8C87725D4B
3A2E24191214171A1C1A191A1A1716171B2836424E586068
6E6F6E6E6C6A6864605C58534E47403A332D27221E1C1B1A
19181817171717181818171717181818181817181818191B
202D3B4752575C62656666666563625F5E5D5C5B59585655
545251504F4F5050504F4E4D4C4C4D4D4D4E4E4E4E4D4D4C
4B4A4948464543424141424242424242
6C6C6C6C6C6C6C6C6B69686666676869696563616065696C
6E6E6D6C6A645E58565B6064666461605F61636364636262
615F5D5B5B5C5E5F616466686B6C6D6F6E645D595F81A3BF
D5D9DBE1E4E5E4E2E0E2E2E1DFD9D2CDC7C3BFBAB6B4B2AF
AAA0958E878585848899A9B6BCAE9F948B8E8F8C85725F4F
3F33281E17181A1B1D1B1A1B1B1817171C2937444F585F66
6C6D6D6D6B6A6764605C58534E47403A332D27221E1C1B1A
191818171717171818181717171818181817161616121010
14212F3B48515A63696968676563615E5C5B5A5958575554
5351504E4E4E4F4F504E4D4C4C4C4D4D4D4D4D4C4C4C4C4C
4B494846454342403F3F404040404040
6B6B6B6B6B6A6A6969676665656768696966625F5F64696D
6F706F6F6D665F5A575D6266686562616061636364636161
5F5E5D5C5B5C5E5F616366686B6C6E7070665E5A6183A6C2
D9DCDCE1E3E4E4E2E0E2E2E1DFD9D3CEC8C4C1BCB9B7B6B4
AFA69D958F8B88868A9DB0BFC8BDB0A69D9A958D83736252
44382D231C1B1C1C1D1B1A1B1C1918191D2B394550575D64
696B6B6B6A696764605C58534E474039332D28221F1D1C1B
1A1918171717171818181717171818181717161615100C0A
0B17242F3C495561696968676563615D5A5A595857565554
53514F4D4D4D4E4F4F4E4D4D4C4D4D4D4D4C4C4C4B4B4B4B
4B4947464443413F3E3E3F3F3F3F3F3F
6A6A6969696A6A6B6B6A696868696A6B6B67646261666B6E
71706E6E6C6864605F63676A6C6965636263646464646363
6261605F5E5E5E5E5E616365686A6C6F6F665F5B6286AAC8
DFDFDEE1E2E3E3E1E0E1E1E0DED8D3CEC9C5C2BEBBBAB9B7
B4ADA6A09A938E8A8DA2B6C5CFC9C1BAB1A6998B7D6E5F50
43382F26201D1C1B1A1918191A191A1B202D3A454F565C62
67686969686765625F5B57524D463F39322D28231F1E1D1C
1C1A18171717171818181717171717171716161514110F0E
0F151D242D3C4B58626464666563605C5958585756555454
53514F4E4D4E4F5051504F4F4E4F4F4F4F4E4D4C4C4B4B4B
4A494847464543424040404040404040
6968686768696B6D6D6D6C6B6B6C6C6C6C69666463686C70
72706D6C6B69686666696C6E6F6C68666464656565656565
65646362615F5D5C5C5E606265686A6E6F665F5D658AAFCD
E4E3DFE1E0E2E3E0DFE0E0DFDDD8D2CDC9C6C3BFBDBDBCBB
B9B4AFABA69D969192A7BBCAD6D5D0CDC5B29E8A76695C4E
4239312A241F1C1A1817161718191B1E242F3A454E555A60
64656666656463605D5A55514C453E38322D2823201F1E1E
1D1B19171617171818181717171717171716151514131313
141516192030404E595D606465625E5B5757575655555454
54514F4E4D4F50515251515050515151514F4E4D4C4B4B4A
4A4A4949484745444242424242424242
6767666666696B6D6F6E6D6D6D6D6E6E6D6A676565696E71
73706D6C6A6B6B6B6C6E7072726E6A686565666565666667
6766656563605E5B5A5C5E606366696D6E676160698EB3D1
E8E5E0E0DFE1E2E0DEDEDEDDDBD7D2CDC9C6C4C1BFBFBFBF
BEBBB8B6B2A79E9798ADC2D2DFE2E1E1D9BFA48A73685D50
453C352E29221D1916151516181A1D2127313B454D53585E
616363636362615F5C5954504B443E38322D28242120201F
1E1B19171617171818181717171718181817171616161617
1712100F1324364551575C6164615D595656565554545454
5452504E4D4F5152535352525252525252504F4D4C4B4B4A
4A4A4A4A4A4846454443434343434343
6665646465676A6D6F6E6E6E6E6E6E6E6E6B6866666A6E71
726F6C6A696B6D6F70727374736F6B686565656565666768
6868676665615E5B5A5B5E5F6164676B6D6764646E93B8D6
ECE8E1E0DEE0E1DFDEDEDDDCDAD6D1CDC9C7C4C2C0C1C2C2
C2C1C0C0BCB1A7A1A1B4C7D5E2E9ECEEE6C8A78B71675E52
473F38322C241E1915141516181B1F242A333C444C51565B
5F60616160605F5D5B57534F4A443D37322D292522212020
1F1C19171617171818181717171718181818171717181919
19120C090B1B2C3A474F575F63605B585555555453545455
5452504F4E505253545453525253535352504F4D4C4B4B4A
4A4A4A4A4A4846454444434343434343
65646363636568696B6B6A6A6A6C6D6D6D6A676464676B6E
706C696766686B6C6E707173726D68646162636363646566
666665646361605E5E5F6062636465686A67676A7599BDDA
EFEAE2E0DDDFE2E0DFDEDDDCD9D5D1CDC9C7C5C3C2C2C3C4
C4C5C6C7C5BCB5AFAEBBC8D1DAE1E6E9E2C4A58971686155
4B4138322B241D1915151517191C21262C333B42494F5458
5C5D5E5E5E5D5D5B5956524F4A443E38322E2A262322201F
1E1B19171617171818181717171718181817171716161616
15110E0D0F18232C3744515C635F59565354555454545455
5452514F4F515354555352515050504F4F4E4D4C4B4B4B4B
4A4A4A49484643414041414242424141
64636262626365666767666767696A6C6C6865626165696B
6D696664636568696B6E7071716B65605D5E606061626364
6463636261616161626363656564636566686B717EA0C2DE
F1EBE3DFDCDFE2E1E0DEDDDBD9D5D0CDC9C7C5C4C3C3C4C5
C6C9CBCDCDC7C2BEBCC2C9CCD1D9DEE1DBBFA289736B6459
4F4439312A231D19161616181A1E22272C333A40474C5155
585A5B5B5B5B5A595755524E4A443E39332F2C282522201E
1C1A19181717171818181818181717171717171616151413
1211111214171B2028394A59625D57545153555454545454
54535150505253555553504F4D4D4D4C4C4B4B4A4A4B4B4B
4B4A49474643403E3C3E3F4041404040
6262616161626363646464646467696A6B67646160646769
6A676361616366686A6C6E706F69635E5A5C5E5F60616263
636261616062636465656667676462626469707887A7C6E1
F3ECE3DFDBDFE2E1E0DFDCDBD8D4D0CCC9C7C6C4C4C4C5C6
C8CCD0D3D4D1CDCBC9CACACACBD3DADDD7BDA189746D675D
53463B3129221D19161617191B1F23282D33393E44494E52
55575858585958575553514E4A443F3934302D2A2623201E
1C1A19181717181818181818181717171717171716141312
11121416171413141A2F4455605B55535052555455555455
54535251515254555552504E4C4B4A4A4949494A4A4B4B4C
4C4A484644413E3C3A3C3E3F403F3F3F
626160606060616162616161626567696A6663615F626567
686562605F626567696B6D6E6D67615C585A5D5E5F606162
6362616060626466676768696864605F626C788393B0CBE3
F3ECE4DFDBDFE2E1E0DFDCDAD7D3CFCCC9C7C6C4C4C5C6C7
C9CED3D7DAD9D7D6D4D1CECAC9D0D5D7D2BAA18C79726B61
57493C3128221E1A1817181A1D2024292D32373C41464A4E
52535556565756565453514E4A45403A35322F2B2824211E
1B1A19181717181818181818181717171617171716141211
1013161819120D0B0F263D4F5C5954525153555454545454
545352515152545555524F4D4A49494847474848494A4B4C
4C4A474543403D3A393A3C3E3F3E3E3E
626261606060616162616060616366686966646261636566
6765636262646667696A6A6B6A65615D5A5C5E5F60616263
64636261616365666768696A6A64605E62728595A7BCD0E3
EFEAE4E0DDDFE1E0DFDEDBD9D7D3CFCBC8C6C5C4C4C5C6C8
CACFD3D8DBDBDBDCDBDAD9D6D4D6D6D4CDBAA593827A7267
5C4D3E322823201C1A1A1A1C1E2124282C3034383D414549
4C4F515354555656555452504D48433E3935312D2A26221F
1C1B19181717171818181818181717171617171717151312
1112131515100C0A0E223748555554565655545251525454
545351504F51525353514E4D4B4A49484747474747494B4C
4C4A474442403E3C3B3C3D3E3E3E3E3E
63626161606161626261605F5F6265676866656463646565
6565656465666768696968686764615E5D5E5F6061626364
656463636364656667686A6B6B65605E637A92A7BAC8D5E2
EAE8E4E1DFE0E1E0DEDDDBD9D6D2CECAC7C6C5C4C4C5C6C8
CACFD3D7DBDDDEDFE0E2E2E2E0DDD8D2C9BAAA9B8D83796D
615141342925221F1D1D1D1E20212326292D3135393D4044
474B4E5053545656565554524F4B46413C38342F2B272421
1E1B19181717171818181818181717171717181818161413
12111112110D0B0A0F20313F4C5154595B5854514E515354
5452504E4D4F515152504E4D4B4A49484847464646484B4C
4D49464341403F3E3D3D3E3E3E3E3E3E
636261616061616161605E5E5E6163666766656464646464
6465656667676868686766656362605F5E5F606162636465
656564646465666768696B6D6D65605E64809EB6CBD3D9E1
E6E6E5E2E0E1E1DFDEDCDBD9D6D2CECAC7C5C4C3C3C4C5C7
CACED2D6DADEE1E3E6E8EAEAE7E0D7CEC4B9AEA2968B7F73
6654433429252421201F1F2021222325272B2E3235393C40
43474B4E5153555656565453504C48443F3A36312C292521
1E1C19181617171818181818181717171717181818161513
12111111100C0A0A0E1C2B38444C545B5F5A544F4C4F5354
54524F4D4C4E4F50504F4E4D4C4B4A484746454545484A4C
4D4945424040403F3F3E3E3E3E3E3E3E
636261605F606161615F5D5C5C5F62646666656564646463
636567686968686767656462616160606061626263646566
666665656565666667696B6D6D66615F6787A8C2D8DBDCE1
E3E4E5E3E1E1E1DFDDDCDBD9D6D2CDCAC6C5C4C3C3C3C5C6
C9CCD0D4D8DDE1E5E8ECEEEFEDE3D7CDC2BBB4AAA0938578
6A57453529272523232120212221222325282B2F3236393D
4145494D5052545555555452504C4844403B37322D292622
1F1C1A171617171818181818181717171718181918171514
1211100F0F0C0B0B0E19242F3A46515B615B544F4C4F5354
54514E4C4B4D4E4F4F4E4E4D4C4B4A494846454445474A4C
4C4945424040414141403F3E3E3E3E3E
605F5E5D5D5E5F60605E5C5A5A5E61646665656464646363
636567696A68676665646463626161616162636466666667
67676666656565656667686B6C6764646D8CACC6DBDDDDE1
E2E4E5E3E2E2E2E0DFDDDBD9D6D2CECAC7C5C4C3C3C3C4C5
C7CACED2D7DBE0E3E7EAEBECEAE3DCD3CBC3BBB1A597887A
6A5846372B28272625222020202020212326292C3035393D
4246494D4F51525252514F4D4B4844413D3936322E2A2622
1F1C1A181617171818181818181717171718181818171514
121110100F0D0C0C0F151C232D3C4B58605C565350525454
53514E4C4B4D4E4F504F4E4E4D4B4A49484747474748494A
4A484645434343424241414040404040
5D5C5B5B5B5D5E60605D5A59585C60636665646463636363
6366686A6B69666563636463636262616263656668686868
6867676666656464646566686A6767697391AFC8DCDEDDE1
E2E4E5E4E3E3E3E2E0DEDCDAD7D3CECBC7C6C5C4C3C2C2C3
C4C8CCCFD4D8DDE1E4E6E7E8E7E4DFDAD3CBC2B7AB9B8B7B
6A5848382C2A29282623201F1F1E1E1F2023272A2F343A3F
43474A4D4F50504F4E4C4A484542403D393734312E2A2522
1E1C1A181617171818181818181817171718181818161514
121111100F0E0E0E0F111519213344535E5B575654555554
53514F4D4C4D4E4F50504F4F4E4C4B494848494949494848
48484747464645444343434242424242
5B5A5959595B5E5F605C5957575B60636564636363636363
6466696B6C69666462636363636362626365676869696969
68686867666564636363646668686A6E7996B3CBDEDFDEE0
E1E3E5E4E3E4E3E3E1DFDDDAD7D3CFCBC8C6C4C3C2C1C0C0
C1C4C8CBCFD4D8DDE0E2E4E5E5E5E2DFDAD2C9BEB2A18F7E
6C5A493A2E2C2B292824201F1D1D1C1D1E2125292D33393F
44484A4D4E4E4D4C4B494643413E3C39373533302E292522
1E1C1A181617171818181818181818181818181817161514
131210100F0F1011110F0E0F162A3E4F5B5A575857575654
52504F4D4C4D4F4F5050504F4F4D4B4A49494A4A4A494847
46474849494846454544444444444443
5A585757575A5D5F605C5957565A5F626463626262626363
6467696B6C6965636162636363636363646667696A6A6969
68686767666563636262626467696E74809AB4CBDCDEDEE0
E1E4E5E4E4E4E4E3E2E0DEDBD8D4D0CCC9C7C5C3C1BFBEBD
BEC0C3C6CACED3D7DBDEE0E2E3E4E4E3DFD8CFC5B8A69381
6F5D4C3C302D2C2A2924201E1C1B1B1B1C2024282D343A41
46494B4D4E4D4B4A4745423F3C3A38353332302F2C282421
1D1B19181617171818181718181818181818181817161514
131211100F101112130E0A090E2236475456565959585654
51504E4D4C4D4F5051515050504E4C4A494A4B4C4B494745
4547494A4B4947464545454545454545
5A58575656595D5F605D5A58575A5D5F61605F5E5F606263
6467686A6A6764615F606060616262636466676868686766
666564646364646565636263656B727A869DB3C7D7DBDDE1
E3E4E5E4E3E4E4E4E3E1DFDDDAD7D3CFCCC9C6C4C1BFBEBD
BDBDBEC0C2C7CCD0D5D9DCDFE1E3E3E2DFDAD4CCC0AE9B88
7562503F322F2D2A28231E1C1A19191A1C20252A30373E44
494C4D4E4E4D4B494643403D3A373532302E2D2B2925211E
1B1A19181717171818181717171818181818181817161514
1312110F0F0F1011120E0C0B0F1D2C39444B51585B595552
4F4F4E4D4C4E4F505152525252504D4B4A4A4B4B4B484645
4446484A4A4846444344444545454444
5B58565555595C5F615E5B59585A5C5D5E5C5B5B5B5E6163
65666768686563605E5E5E5E5F6062646565666666666564
636261616163656768646261636C76808D9FB1C2D1D7DCE2
E5E5E5E4E3E4E4E4E3E2E0DEDCD9D6D2CFCBC7C3C0BEBDBB
BAB9B9B9BABFC4C8CDD3D8DCDFE1E1E0DEDCD8D2C8B6A290
7C68554234302D2926211C1A191818191B20262C323A4047
4C4D4E4F4E4C4A4744413E3B3734312F2C2A292725221E1C
191918181717171818181717171717171718181818171514
1312110F0F0F0F10110F0E0F1119222A34404C565D595450
4D4D4E4D4C4E50515253535453514E4C4A4A4B4A4A484644
44464849494744424142434444444444
5B58565454585C5F615E5C5A595A5B5B5B5A5958595C6063
656666676764625F5E5D5D5D5E6062646565656565646362
61605F5E5F6266696A656160626E7B8693A2B0BECAD3DBE2
E7E6E5E3E2E3E4E3E3E2E0DFDDDAD7D4D0CBC6C1BDBBB9B7
B5B3B2B1B2B6BBBFC5CBD2D7DCDEDFDFDEDEDCD7CEBCA996
826D594536312D28251F1B19171616181A20272D343B4249
4E4E4E4E4D4B4845413E3B3835312E2B28272524221F1C19
181818181818171818181717171717171718181818171614
131211100F0F0F10101010111315191D253647545D59524F
4C4D4E4D4D4E50525354545555524F4D4B4B4A4A49474544
44464749494643414041434444444444
5B58555453585C5F615F5C5B5A5A5B5B5A595857585C6063
666666666563615F5E5D5D5D5D5F62646565646463626161
605F5E5E5F63676A6B65605F616F7F8C9AA4AFBAC5D1DBE3
E9E8E6E4E2E4E5E4E4E3E2E0DEDBD8D4D0C9C3BDB8B5B3B0
AEACAAA9AAAEB2B7BDC4CCD3D9DBDCDDDDDFDFDCD4C3B09D
89735D4838312D27231E1918161516171A20272E353C4248
4C4C4B4A484643403D3B3835322F2B28252422211F1C1A18
161717181818181818181818181717171718181818171614
131211100F0F0F0F1011111314121213192D41515B57504E
4B4C4E4D4D4F51525354555555524F4D4B4A4A4948474544
44454748484542403F40424344434343
5A58565555585C5F615F5D5C5B5C5D5E5E5C5B5A5A5D6063
656565656564626160605F5F5F6062636363626261616060
606162636466686A6A645F5D60708292A1A9B2BCC6D1DCE5
EBEAE9E8E7E9EAEAE9E8E6E4E1DED9D4CEC6BEB6B0ABA8A4
A2A1A1A2A4A8ACB1B7C1CAD2D8D9DADADADFE1DFD9C9B6A4
9077604937302C26221D1917171617181B21272C32383D42
44423F3D3A39393736353433322E2B282623211F1C1B1918
171717181818181818181818181818171718181818161514
131211100F0F1010111112141411101015273A4954514D4C
4B4D4E4E4E5051525353545453504E4B4949494847464545
44454545454341403F40414242424242
5958575656595C5E605F5D5D5D5E606161605E5D5D5F6163
64646465656463636262626262626262616160605F5F5F60
616366686A6A696968625E5C5F728697A6ADB4BDC6D2DDE6
ECECEBEAEAECEEEEEDECE9E7E3DED8D2CAC0B6ADA49F9A96
9495979A9EA1A5AAB1BBC6CFD6D7D6D6D7DEE2E2DDCEBCAB
967C634B37302B24201B1817171718191C21262A2F33373A
3B37322F2C2D2E2E2E2F3031312E2B292623201D1A191918
181717171718181818181818181818171718181818161413
12111110101010111112131414110F0E122233414B4B4A4B
4C4D4F4F4F51515252525252514E4C4A4847474747464646
45444443424241404040404041404040
59585857585A5C5E5F5F5E5E5E606263646261605F606262
63636464646464646464646463626161605F5E5E5E5E5E5F
6165696C6E6C6A6967625D5B6073889AAAB0B5BEC6D3DEE7
EEEEEDECECEEEFEFEEECE9E6E2DCD5CEC5B9ADA299928D88
86898D9196999DA2A8B4C0CBD2D3D2D2D3DCE2E4E1D3C1B1
9D81664C37302A231E1A18171717181A1D2125282C2F3234
332E282320222426272A2D2F302D2B2825221E1B18181818
181817171717181818181818181818171718181817161413
11111010101010111113141616110D0B0E1D2C394346474A
4C4E4F5050515252525151504F4C4A484746464646464646
464442414040404040403F3F3F3F3F3F
58585858595A5C5D5E5E5E5E5F6163646564626161616262
636363646465656566666666656362605F5E5D5C5C5D5E5F
61666B6F726E6B6966625F5E63778B9EADB2B7BFC7D3DFE8
EEEEECEBEAEBECEBE9E7E5E1DCD5CDC5BBAC9E91857E7974
737980888E8F91969CAAB8C3CCCDCDCDD0DAE2E5E4D7C7B8
A4876B5039312A221D1917171818191A1D1F222527292B2C
2B251E1916191C1E2125292D2F2C292623201C1916171717
181717171717181818181818181818171718181817161412
11111010101010111113151616110C0A0C1826313C41454A
4E5050505051525151504F4E4D4B49474646454545464647
464442403F3F404141403F3F3E3E3E3E
59595A5A5A5A5A5A5A5B5C5D5E5F61626362616060616162
62636464656566666667676767656462615F5E5D5C5D5F60
63686C70726E6A68666465666C7E91A2B0B6BAC1C9D5E0E8
EDEAE6E3DFDEDCD9D6D7D6D4CFC7BEB4A7937F6E605A5753
55626F7C868280818697A8B6C1C3C5C9CDD8E1E6E6DCCEC1
AD9072573F352D231C191717171718191B1B1B1C1D1F2123
221E1A17151618191B21272B2D2924201D1B191615151515
161616171718181818181818181818171718181818161412
11101010101010101112141515110D0B0C16222B353E464E
535351504F5051504F4E4D4C4B4A49484746464646464646
46444342414141414141404040404040
595A5A5B5B59585756585A5C5D5E5F606160605F5F606162
6263646566666666666768696867656462605F5D5D5E6061
64696D71726E696765676B6F768595A4B1B7BCC3CBD6E0E7
EBE6DFDAD4D0CBC5C2C3C4C3BFB6ABA19279614C3C373533
384B5E707C756E6C708397A7B4B9BDC3CAD6E0E5E7DFD3C8
B6987A5E45392F241C18171617171718191715141316181A
1B18161514141414161D24292B261F1A1616161514131313
141516171818181818181818181818171718181918161412
1110100F0F0F0F101011131414100D0C0D151E262F3B4751
585552504E4F4F4F4E4D4C4B4A4949484847474746464645
45454545444343424141414141414141
595A5B5C5C5956545356595A5C5D5E5F5F5F5F5F5F606161
62636465666666676768696A6A68676563615F5D5D5E6062
656A6E72736E6966656A70767E8A97A3AEB6BDC4CCD7E0E6
E9E2DAD3CCC5BEB6B1B3B5B4B1A79A8F7E62472F1D191918
20374F6574695E5B5D728899A8AFB5BDC6D3DDE4E6E1D7CD
BC9F80634A3D31241B181716171616181714100D0C0E1012
1313121212111110121A22272A231B161213141313121212
121415171818181818181818181818171718181918161412
1110100F0F0F0F0F1011121313110F0E0F141A2029384754
5C5853504D4E4E4D4C4B4A49484848484848474747464545
44454646464543434242424241414141
585A5B5C5C5855535254575A5C5C5D5E5F5F5F5F5F606061
6263646666666666666769696968666564615F5D5D5E6162
656A6E72736D6865656C757D858C939CA5B0BCC5CFD8E0E5
E7DFD6CDC4BAB0A59D9E9F9D988E8378684B301907040505
0D264058675B504B4D62798A9AA4ACB7C1CED9E0E3DFD8CF
BFA284684F4033251C1817161616161717120D0A08090C0D
0E0F0F11110F0E0E0F171F24272018130F10121313121111
121315171818171818181818181818171718181918161412
1110100F0F0F0F0F0F10111212110F101113171B24354655
5E5A53504C4D4E4C4B4A4948474848494948484747464544
44454647474543424141414141414141
5658595A5A5755545356585A5C5D5E5F6060606060606161
61636465656464636363646464636362615F5D5C5B5D5F60
63686D72746D686465707C858C8884858AA0B6C8D6DCE0E4
E4DED5CBBFB1A293867F786F67615A534935231409050505
0B1E3245514A4341445668778794A0ADBAC7D1D9DDD9D1C8
B99F8369514234261C191716161616181814110F0D0D0E0E
0E0E0E0F0F0D0D0C0D13181C1E1A15120F11131414141314
141516161717171717181818181817171717181817151311
1010100F0F0F0F0F0F10101111100F0F101114171F314353
5D5953514E4E4E4D4B4A494948494A4A4A49474645454544
444546464643413F3E3E3F3F3F3F3E3F
55565657575655555557595A5C5D5F606161616161616160
61626364646361605F5F5F5F5F5F5F5F5F5D5C5B5B5B5D5E
60666C71736D68646573818C9181746C6F8EAFC7DCDFDFE3
E2DCD4CABCAB9885736354463B3735322D231A140E0B0A09
0C1A27343D3B383A3F4C5A66748595A4B2BFC9D1D4D0C9C0
B19A8169534335271D191716161617181918161514131210
0F0F0F0E0E0D0C0C0D101316171513121113141516161616
161616161617171717171718171717171717171716141211
0F0F100F0F0F0F0F0F101010100F0F0F101011141B2E4150
5B5853514F4F4F4D4B4B4A49494A4B4C4B49474543444444
4445454544413F3C3B3B3C3C3C3C3C3C
53545455555555565657595A5B5D5F616262626262616160
6061636363615F5E5C5C5B5B5B5B5C5D5D5C5B5A5A5B5B5C
5F656A70726D686466768591947B6557567EA7C5DEDFDEE0
DFDAD3C8B9A48E78624C38241716171717141212110E0C0B
0D151E262D2E2F3339424D5764778A9BABB7C1C9CCC8C1B8
AB96806A554637291E1A1817161617191A1A191919161412
1110100F0E0E0D0D0D0E0F10111111111214151617171717
171717161616171717171717171717171617161616141210
0F0F0F0F100F0F0F0F0F0F0F0F0F0F10110F1011182B3E4E
5A5753514F4F4F4D4B4B4A4A4A4B4C4D4C49464442434444
4444444443403D3A38393A3A3A3A3A3A
5151525253535455565758595B5D5F616262626262616060
6061626262605E5C5B5A595858595A5B5C5B5B5B5B5B5B5B
5D63686D706C68666877859091725643406D9BBDD8DBDADE
DEDAD3C7B8A38C765E442D1707070A0A0D1012171A171413
13171C2125292D33393F464E5A6F8395A5B0B8C0C3BFB8B0
A3917D6A5747392B201C1A17171717191B1C1D1F1F1C1A17
15151413121211111110100F101112131516171718191919
191817161616171717171717171717171616161515131110
0E0F0F0F10100F10100F0F0F0F0F0F10110F0F11172A3E4D
595652514F4F4E4C4B4B4A4A4A4B4C4D4D49464341424344
44444444423F3C393737383939393838
4E4E4F505051525354555657595C5E606161616060606060
6060616161605E5D5C5C5C5B5B5B5C5D5D5D5D5D5D5D5C5C
5D6164686A6A6A6A6C757D8380644937355C87A7C3CDD3DE
E2DDD5CBBEB0A08E7B65513D2F2A28242323242527242221
22262A2F33373A4045494F5660728493A1AAB0B6B8B4AEA7
9B8B796756483B2E241F1C19181717181A1D212426252322
2121201F1E1F1F1F1F1D1B1A191A1A1A1A19191918181818
181817171616161616171717171717171716151514121110
0F0F0F0F0F0F0F10100F0F0F0F0F0F10111214171E2F414F
5956514E4C4C4C4B4A494948484A4C4D4D49454341424343
44434343423F3C3A383839393A393939
4B4C4D4D4E4F4F5051525456575A5D5F61605F5E5E5F5F5F
5F606060605F5F5F5F5E5E5E5E5E5E5E5E5F5F60605F5E5D
5D5F616265696C6F717374746E543D2D2B4D728FABBDCBDC
E6E0D7CEC4BDB4A89A8978685A524A433D3A383635333131
32363A3F4346494E52555A5F677685929EA4A8ACADAAA49E
9485746455493D3229231F1B191717181A1F24292C2D2C2D
2D2C2C2B2A2B2C2C2C2A2725232322211F1D1B1A18181818
181817171717161616161616171717181716151413121110
0F0F0F0F0F0F0F1010100F10100F0F101114181C24344451
5A554F4C494A4B494948474646494B4D4D49454240414243
43434342423F3D3B39393A3A3A3A3A3A
48494A4B4C4C4D4E4F51525456595C5E605F5E5D5D5D5E5F
5F5F5F5E5E5F5F6060606060605F5F5F5F60616262605F5E
5D5D5E5E60676E7375716B675E4631221F3D5F7A96AEC3DA
E7E1D9D2CAC8C4BDB3A596887B70655A524E4A4846434242
4245484B4F52565A5E5F62656C7986919A9EA0A2A29F9A94
8C7E7062554A40362D27221D1B1818181A21282E33343536
37363534343537373734302D2B29282624211D1B19181818
181818181817161616161616161718181816141312111010
0F0F0F0F0F0F0F1010101010100F0F1012161C2129374551
58534D4A464849484847464545484A4C4C4844423F414242
43424242413F3D3B3A3A3A3A3A3A3A3A
4748494A4B4B4C4D4E50515355585B5D5F5E5D5C5C5D5E5E
5E5E5E5E5E5F6061616161616160605F5F6162636462605F
5E5D5C5B5E687177796E62584C38271A18304C637F9CB9D4
E6E1D9D3CED0D1CCC6BCB0A5998C7F7368635E5A56545251
52535456595C5F626567686B6F7A858E9597999A9996928D
85796D61554C433A322B25201D1A19191B2229303537393B
3C3C3B3A393B3D3E3E3A3733302E2C2A27231F1B19181818
181818181817161616161616161718181816141211111010
0F0F0F0F0F0F0F1010101010100F0F0F12171D232B384550
56514C4845464847474645444446494B4B4743413F404142
42424141403F3D3C3A3B3B3B3B3B3B3B
4748494B4C4C4D4E4F50525355575A5D5E5E5E5E5E5E5D5D
5D5D5D5E5E606162636261605F6060606061626363636262
62605F5E606C767D7D6B58493A2D231A1A293C4D6588A9C8
DDDAD4D1CDCECEC9C3BCB3ABA2978D837B756F6A66625F5D
5B5A5959595A5C5E606164676C757E868C90929494928E89
82786C61574E463D362F2924201D1B1A1B1F24282C2E2F31
3333333333353738383633312E2C292724201D1A18171817
171717171717171616161616161717181715141211101010
100F0F0F0F0F101010101010100F0F101115191E2533404C
54504B484647484847464443434546474744413F3E3F4141
42424141403F3D3C3B3B3B3B3C3B3B3B
48494A4C4D4E4E4F5051525354575A5C5E5E5F60605E5D5B
5B5C5D5E5F6062636462605E5E5F60606161626263636465
6563626164707B8281684E3A2923201C1C232D394E749ABB
D3D2CECFCCCBC9C4BEBAB4AEA8A199928B857F7974706B68
64605D5B595858595A5D60636870787F85898C8F908E8A86
80776D63595149413A332D2824201E1D1C1D1F2122242527
29292A2B2C2E2F3031302F2E2C292623201D1B1917171717
171717171717171717171717171717171715131211101010
100F0F0F0F0F10101010101010100F10111215181E2D3B47
504D4A4847484948474644434243434443413F3E3D3E4041
42414141403F3D3C3B3B3C3C3C3C3C3C
48494B4C4E4E4F50515152535456595A5C5E5F61615E5C5A
595B5C5D5F6163646562605E5D5E60616262626263646667
6866656366737F868364452C19191D1D1F1D1F2637618BAF
CACCCACDCDCCCAC4C0BFBDBAB6B0AAA49E979089827D7873
6E6964605D5A5958595C6064696E747A7F84888B8C8A8783
7E766D645B544D453F38322C2824221F1E1D1C1C1C1E1F21
2223252627292B2C2D2D2D2C2B2824211E1C1A1816161617
171716171717171818171717171717171614131110101010
10100F0F0F0F10101010101010101010111112141A283642
4B4A4747464748484745444241414141403F3D3C3C3E3F41
42414140403F3E3D3C3C3C3D3D3D3D3D
484A4B4D4E4F4F5051515252535557585A5C5E60615E5B59
585A5C5D5E61626465625F5D5C5E5F616261616162646668
696866656775808682603D220E131B1E211A161927537FA4
C1C5C6CCCDCBC8C3BFC0C1BFBCB8B2ADA7A0989089837E78
736D6864605C5A58595C61656A6F73787D8286898A898582
7D766E655D57514A443D37312D292724221F1C1B1A1A1B1C
1E1F2022232426272829292A2925221E1B1A191716161616
171616161717181818181717171717161614121110101010
10100F0F0F1010101010101010101010111010111522303B
43444345454748484746444241403F3F3E3D3C3B3C3D3F41
42414040403F3E3D3C3C3D3D3D3D3D3D
48494B4C4D4D4D4E4E4F50515252535455585B5D5E5C5B59
59595B5B5C5E5F6161605E5D5C5D5F5F605F5F5E5F616365
676665646570787D785A3B2311141A1C1E19161A28517A9D
BAC0C4CBCDCBC8C2BDBEBEBBB7B0A8A199918A827C77726E
6A676462605E5D5D5E62666B6F757A7F84878A8C8C8A8683
7E777069625C564F49433D3834312F2D2B28262423222121
21212121222223232424252524221F1D1B1A191817171717
171717171717181818181818171717171614121110101010
10100F0F0F101010101010101010101011101010131B242B
32373B3F434546484847454341403F3E3D3C3C3B3C3D3F41
42414140403E3D3C3B3C3D3D3E3E3D3E
48494A4B4C4B4B4B4C4D4F5051504F4F505357595B5B5A5A
595959595A5B5C5D5E5D5D5C5C5D5D5E5E5D5C5C5C5E6162
64646463646B70736E543A251516191A1C19191E2C517697
B2BBC1CACECCC7C1BCBCBAB7B1A79D948B837C756F6A6764
626161626262626364686D71767C82878B8E8F908F8C8884
7F79736C66605B554F49443F3B3938373533302F2D2A2826
242323222121212121212120201E1D1C1B1A1A1919181818
17171717171818181818181818181717161412110F101010
10100F0F0F1010101010101010101010111010101115191D
222A32393F424547484746444241403E3D3C3C3B3C3E4041
42424141403E3D3B3B3C3D3E3E3E3E3E
48494A4A4B4A4A4A4A4C4E4F504E4C4B4B4F535659595959
5959585858595A5B5B5B5B5B5C5C5C5D5D5B5A5A5A5C5E60
6263636363686A6B654F392719191A1B1C1A1B202D4F718F
A9B5BEC9CFCBC6C0BAB9B7B2ACA1958B817A736C6663605E
5D5E606264656567696D72767B81888D91939393928E8A85
807B75706A645F5A554F4A454241403F3E3B393634302C29
262422211F1E1E1D1D1C1C1C1C1B1A1A1A1A1A1A19191818
18181818181818181818181818181717161412100F0F1010
10100F0F10101010101010101010101110100F0F0F0E0F10
141F2A333C404347494847454341403E3C3C3C3B3C3E4042
43424141403E3C3B3A3B3D3E3F3E3E3E
4848494A4A494848484A4C4E4F4C4A48484C515457585859
5A595857565758595A5A5A5A5B5B5B5B5B5A5958585A5C5E
60616263636566655F4C3A2A1E1C1C1B1C1B1D23304D6C87
A0AFBCC9D0CDC7C1BBBAB7B2AB9F93887E77716B66636160
606265686B6B6C6E7074797D81888E939797969694908C87
827D78726D68635F5A55504B484848484744423F3C37322E
2A272522201E1D1C1B1B1A1A1A1A1A1A1A1A1A1A1A191918
18181818181818181818181818181717161412100F0F0F0F
100F0F0F101010101010101010101010100F0F0E0D0A0807
0A16222C363C41464A4947454342403E3D3C3C3C3C3E4042
424241403F3D3C3B3A3B3D3E3E3E3E3E
464748494948484747494B4D4E4C4A49494C505255565759
595857565658595A5B5A59595858595959595859595A5C5D
5E616263646666655F4E3C2D211E1D1B1C1B1D222E49657E
96A9BACAD5D3CFCCC7C5C3BDB7ADA49B938D88837F7D7C7B
7A7A7A7B7B7B7A7A7C7F83868A8F93979998979593908C88
837E79746F6B67625E5954504E4E4F4F4E4C4A47443F3A35
312D2A272523222120201F1F1E1E1D1C1C1B1B1A1A191918
1818181818181818181817171716151414121110100F0F0F
0F0F0F0F0F0F0F0F0F0F101010101010100F0F0F0E0C0B0A
0C131B222A343D464B4A4745444342413F3F3E3E3E3F4041
41403E3D3C3C3C3C3C3C3C3C3D3D3C3D
454647484847474747494A4C4D4B4A4A4A4C4F5153555658
5958575656585B5C5D5B585756565757575858595A5A5B5C
5D6063646567676761503F3024211F1D1C1B1D232E455D74
8CA3B8CCD9DAD8D6D3D1CEC9C3BCB5AEA8A4A09C99989796
9592908E8C8A8887878A8D909395989A9B99979592908D89
85807B76716D6966625D5855525355555553514F4C47423D
3834302D2A292827262524242322211F1E1D1C1B1A191918
18181818181818181817171616141312121111101010100F
0F0F0F0F0F0F0F0F0F0F0F0F100F0F0F0F0F0F0F0F0E0E0E
0F1215191F2C39454C4A4745444444434241403F3F3F4040
3F3E3C3A3A3B3C3C3D3C3C3B3B3B3B3B
44454647474646464648494B4C4B4A4A4A4C4E4F51535658
5958575656595B5D5D5A575554545555565758595A5A5A5A
5C5F626466676766615243362B26221F1E1D20252F43586D
849EB6CDDDDFDEDEDCD9D6D1CBC6C1BBB6B3B1AEACACABAB
AAA5A19D9A979492919396989A9C9D9E9E9B999693908E8A
86817C77736F6C6965615D5957595A5B5B5A5857544E4944
3E3A36322E2D2C2B2A29282726252322201E1C1B19191918
18181717171818181817161615131211101010101010100F
0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F1010100F10
100F0F10152536434D4A464544454645444342414040403F
3E3C3A3838393C3D3E3C3B3A3A3A3A3A
43444546464645454647494A4B4A4A4A4A4C4D4E50525557
5958565656595B5D5E5A5754525354555557585A5B5B5A5A
5B5F6365676868676255483D332D28232121232831415466
7C99B4CDDFE2E1E3E1DFDCD7D2CECBC6C3C1BFBDBBBCBCBB
BAB4AEA9A5A19E9B999B9D9FA0A0A0A0A09D9A9693918F8C
88837E7974716E6B6864605C5B5C5E5F5F5E5D5B59534E48
433E3A3531302F2E2D2C2B2A29272523211F1D1B19191818
181817171718181818171615141211100F0F10101010100F
0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F0F101010111112
120E0B0A0E2032414B49454544454746454443424140403F
3E3C393837393C3D3E3D3B3A39393A3A
43444445454545464647484A4A4A4A4A4A4C4D4E50535557
5958575656595B5D5D5A57555454555657585A5C5D5C5B5B
5C60646668696968655B51484038322C2827282B323F5060
7593B1CBDEDFDEDEDDDCDBD7D3D0CDC9C6C3C1BEBDBCBCBB
B9B4AFAAA6A29F9C9B9C9E9FA0A1A0A1A09D9B989593908D
8A847F7A75726F6C6965615E5C5C5D5D5D5C5A5956514C47
423D3834302F2E2D2C2A292826242321201E1C1A19191818
181717171718181818171615141211100F0F101010100F0F
0F0F0F0F0F0F0F0F0F0F0F0F100F0F0F0F10101010101111
110D0B0A0E1E2F3C46454343434445454443424241414242
413F3D3B3A3B3D3D3E3D3C3B3B3B3B3B
4344444444454546474748494A4A494A4A4B4D4E50535557
5958575757595B5C5C5A585655565758595A5C5D5E5D5D5C
5D616567696A6A6967615A544C443C36312D2D2E333F4D5C
708FAEC9DDDCD9D9D8D9D9D6D3D0CDCAC7C4C1BFBCBBBAB9
B7B2AEAAA6A3A09D9C9D9E9FA0A0A0A09F9E9B999794928F
8B85807A7673706C6965625F5D5C5C5B5B595755534E4A46
413C37322E2D2D2C2B2927252422211F1E1C1B1A19181818
171717181818181817161515131211100F0F0F10100F0F0F
0F0F0F0F0F0F0F0F0F0F0F0F101010101010101010101011
110D0B0B0E1D2B3741414042424343434242424141424344
4442403E3D3D3D3D3D3D3C3C3C3C3C3C
434343434444454647474849494949494A4B4D4F50535557
5858575757595A5B5C5A5856565758595A5C5D5F605F5E5D
5E6265686A6B6B6B6966625D574E463E38333131343E4B59
6C8DACC8DCDBD7D6D5D7D9D7D5D3D0CECBC8C5C2C0BEBDBB
B9B4AFACA8A5A29F9E9E9F9FA0A0A09F9F9D9C9A98959390
8C86807B7673706D6A6663605E5C5B5A58575553504D4945
413C36322E2D2C2B2A2826242321201E1D1C1A1919181817
171717181818181717161514131211100F0F0F0F0F0F0F0F
0F0F0F0F0F0F0F0F0F0F0F10101010101010101010101112
110E0C0B0E1B28333C3D3E40414242424141414141434445
464442403F3E3E3D3D3D3D3D3D3D3D3D
434343424344454647474849494949494A4B4D4E50525456
575757575758595A5A5857565658595B5C5D5E60605F5E5E
5F6266686B6B6B6B6B6A686561584F4840393532343E4C59
6D8CABC7DBD9D4D4D2D5D8D7D5D4D2CFCDCAC7C4C1BFBEBC
B9B5B0ADA9A6A3A19F9F9F9F9F9F9F9E9E9D9B9A98969390
8C87817B7673706D6A6764615F5D5B58575553514F4B4845
413B36312D2D2C2B2A28252322201F1E1C1B1A1918181817
171718181818171717161514131211100F0F0F0F0F0F0F0F
0F0F0F0F0F0F0F0F0F0F0F10101010111110101010101112
120F0D0C0E19252E36393C3F414141404040404041434546
47454341403E3D3C3C3C3D3D3D3D3D3D
4443424242434445464748494A494948484A4C4E4F515253
54555555555555555554545455585A5D5E5E5E5F5F5E5E5E
5E626567696A6A6A6A6A6B6A676059534B3F352E2E3D4F60
7591ACC6D8D8D5D4D3D5D7D6D4D3D0CECCC9C6C4C1C0BFBD
BBB7B3AFABA8A5A2A09F9F9F9E9E9D9D9C9B9A989795928F
8C86817C7774716E6B686663615E5C5957565452504D4946
413C37322E2D2C2B2A2826242321201E1D1B1A1918181817
171818181817171716151413131211100F0F0F0F0F0F0F0F
0F0F0F0F0F0F0F0F0F0F0F10101010101010101010101111
110F0D0C0E18222A3236393E40403F3E3D3E3F3F3F424345
4543403D3B3B3B3A3A3A3A3A3B3B3A3B
44434241404243444547484A4B49484747494B4D4E4F5051
51525354545351515050515253575B5E61605E5E5D5D5D5D
5E61646668686767686A6C6C6B67615D5544352B293D5467
7E97AEC6D6D7D5D5D4D6D7D5D3D1CFCCCAC8C6C3C2C1C0BF
BDB9B4B1ADAAA6A3A09F9F9E9D9C9B9B9A9998969593918E
8B86817C7774716E6C69676563605D5A58575654524E4A46
423D38332F2E2D2C2A2827252422201F1D1B1A1918181818
181818181817171615151413121111100F0F0F1010100F0F
0F0F0F0F0F0F0F1010100F0F0F1010101010101010101011
110F0D0D0F161F262D32373C403F3D3C3B3C3D3D3E404243
43403C3A373838383838383838383838
444341403F4142434547484A4B49474646484A4C4D4E4E4E
4F50515252504E4D4C4D4F5053575C6062615E5D5C5C5D5D
5E6063656666656566696D6E6E6C68655D49372A273E596F
879CB0C5D4D5D4D4D3D5D5D4D1CFCDCAC8C6C4C2C0C0BFBE
BCB9B5B1AEAAA7A3A09F9E9C9B9A9999989796959492908D
8A85807B7774716F6C6A686664615D5A58575654524E4A47
423D3833302E2D2B2A2927262423211F1D1B1A1817171818
181818181817161615141313121111101010101010101010
0F0F0F0F0F0F10101010100F0F0F10101010100F0F101010
100F0E0E10161C22282F353B3F3E3B3A393B3C3C3D3F4142
423E3A37353536363636363636363636
4442403F3F404142434547494A4846444447494B4D4C4C4C
4D4E4F50504E4B4A494B4D4F52575C6164615E5D5B5C5C5C
5D5F61636463626263676B6D6E6C6967604B382A28436078
91A3B3C6D2D4D4D4D3D4D4D3D1CECCC9C6C5C3C1C0BFBFBE
BCB9B5B2AEAAA7A3A09E9D9B9A9897969695949392908E8C
89847F7B7774726F6C6B696765615E5A58575654524E4B47
433E3935312F2E2C2A292827252321201E1C1A1817171818
181818181817161515141312121111101010101010101010
100F0F0F0F0F10101010100F0F0F101010100F0F0F101010
100F0F0F11151A1F252D343A3F3D3B39383A3B3C3D3E3F40
403C3835333334353535353535353535
41403F3E3E3E3F4041424344454342424245474A4B4B4B4B
4C4C4D4D4D4C4A4A494B4D4E51575C6063615F5E5C5B5A59
595C5E6061605F5E5E61646666625D5A54453931334D6B83
9BAAB8C8D3D4D3D3D2D3D4D3D2CFCDCAC8C6C4C2C1C0BFBE
BCB9B5B2AFABA7A4A09E9C9A9997969493939291908E8C89
87827E7A7674716F6D6B696765625E5B59575654524F4B48
45403C383432302D2C2A2928272523211F1C1A1817171818
181818181717161615141312111110101010101010100F0F
0F0F0F0F0F0F10101010100F0F1010101010100F0F101010
100F0E0F10151A1F242C343A3F3D3B3A393C3E3E3F3E3E3E
3C3A3835343434343434343535353535
3E3E3D3D3D3D3E3E3E3F3F3F3F3F3F3F404346484A4A4A4B
4B4B4B4B4A4A4A4A4A4B4D4E51565B5F62615F5E5D5B5957
56585B5D5E5D5B5A595B5D5D5C56504C473F3A383F59768E
A5B2BDCAD3D4D3D2D1D3D4D4D3D0CECBC9C7C6C3C2C0BFBE
BCB9B6B3B0ACA8A4A19E9C9A98969492919190908F8C8A87
84817D797674716F6D6B696765625F5C5A585654524F4C49
46423E3A3734312F2D2C2B2A29262422201D1A1817171818
181817171717171616151312111110101010101010100F0F
0F0F0F0F0F0F0F1010100F0F0F1010101010100F0F0F1010
100F0E0E10141A1F242C333A3F3E3C3B3B3E4041413F3D3B
39383736353434333334343535353535
3C3C3C3C3C3C3C3C3C3C3C3B3B3B3C3C3E41444749494949
49494848484849494A4B4C4E50555A5E61605F5F5D5A5754
5356595A5B59575554555555534C45403D3B3C3F49648098
AEB9C2CCD3D4D3D2D0D3D4D4D3D1CECCCAC8C6C4C2C1BFBD
BBB9B6B3B0ACA8A4A19E9C99979593918F8F8F8E8D8A8885
827F7C787573716F6D6B696765625F5D5A585654524F4D4A
4844403D393633302E2D2C2B2A282523211E1B1816171818
181817171717171716151312111010101010101010100F0F
0F0F0F0F0F0F0F0F0F0F0F0F101010101010100F0F0F1010
100F0E0E10141A1E242C333A3F3E3D3C3C3F4142423F3B39
36363736363533333333343535353535
3A3B3B3B3C3B3B3B3A3A393939393A3B3C40434648494949
49484746464748494A4B4C4D4F54585C5F5F5E5E5D595552
505457595A5753504E4E4D4D4A423C38363A4047546E89A1
B6BFC5CED3D4D3D2D0D2D4D4D3D1CFCDCBC9C7C5C3C1BFBE
BBB9B6B4B1ADA9A5A19E9C99969492908E8E8E8D8C898683
817E7B787573716E6C6A68666462605D5B59565452504E4B
4945423E3B3734312E2E2D2C2B292624221F1B1917171818
181817171717171717151312111010101010101010100F0F
0F0F0F0F100F0F0F0F0F0F0F10101010101010100F0F1010
100F0E0F1014191E232B333A3F3F3E3E3E414344433F3A37
34353636363534333334353536363535
3A3B3B3C3C3B3A3A3A3A3B3B3C3B3B3B3C4043464949494A
4A49484747474849494A4B4C4E5255585A5B5C5C5B585552
5054585A5B56514D4A494847443F3A3839404A53617890A5
B8C0C7CFD4D4D4D2D1D3D4D4D3D1CFCECCCAC8C6C4C2C1BF
BDBAB7B4B1AEAAA6A3A09C99969492908F8E8E8D8B898684
817E7A7774726F6D6B69686664615F5C5A58575553514E4C
4945413D3A3734312F2E2D2C2B2A282624201D1A18181818
181717171717181817151412111111101010101010100F0F
0F0F10101010101010100F0F0F10101010101010100F1010
100F0F101114181B212A333B4141414141434444423F3B37
35353636363635353535363637373636
3B3B3B3C3C3B3A39393B3D3E3F3D3C3C3C404447494A4A4B
4B4A49484848484848494A4B4D5052545658595A5A575451
51555A5C5D564F49444342413F3C3A3A3E48535F6E8296A8
B8C1C8CFD4D5D4D3D2D3D4D3D2D1D0CECDCBC9C7C5C3C2C0
BEBBB8B5B1AEABA8A5A19D9A97959391908F8E8D8B898784
827E7A7673716E6C6A68676563615E5B5958575553514F4C
4945403C393633302E2E2D2C2B2A292725221F1C19191818
171717171718181817161413121111111010101010101010
0F1010101010101010100F0F0F1010101010101010101010
10101011131417191E28333B4243434444454443413E3B38
36363636363637373737373737373737
3A3B3B3C3C3A3939393B3D3F403E3D3C3C404447494A4A4B
4B4B4A494848484848494A4B4C4E4F515254565858555351
50565A5D5D554C453F3D3B3A3937373A3F4C5B69798A9BAB
B9C2C9D0D4D5D5D4D3D4D4D3D2D2D1CFCECCCAC8C6C5C3C2
C0BCB9B5B2AFACA9A6A29E9A97959492918F8E8D8B898785
827E7A7672706E6B6968666563605D5B5958575654524F4D
4A45403C383533302E2D2D2C2B2A29282723201D1B191918
171717171818181817161413121211111110101010101010
101010101010101010100F0F0F1010101110101010101010
10101112131416181D28323C4344454647464543413E3B38
36363636373738393939383838383838
3A3B3B3B3B3A3938383B3E4142403D3C3C3F434648494A4B
4B4B4A49484848484849494A4B4C4D4E4F51535556545250
50565B5E5E534840393735343435373C4452627281909EAC
B9C2C9D0D4D5D5D5D4D5D5D4D3D2D2D1CFCDCBC9C7C6C5C3
C1BDBAB6B3B0AEABA8A39F9B9796959392908F8D8C8A8785
827E7A76726F6D6B6867666463605D5B595857565552504D
4A45403B373532302E2D2C2B2A2A29292724211E1B1A1918
171717171818181817161413121211111111111110101010
101010101010101010100F0F0F0F10101110101010101010
10111113141416181C27323B4344454747464543403E3B39
373737363738393A3A3A393938383939
39393A3A3A393837383B3E40423F3D3C3B3E414345464748
49484847474747474748494A4B4C4D4E4F5051515251504F
50565B5E5D5043393130303032373D444D596674818F9DAA
B6C0C8CFD4D6D6D6D5D6D6D5D5D4D3D3D1CFCCCAC8C7C6C4
C2BEBBB7B4B1AEACA8A49F9B989796959392908F8D8A8885
827E7A7673706E6B6968666463605E5B595858565552504D
4A45403C3834322F2D2B2A29292828282723201E1B1A1918
171717181818171716151312111111111111111110101010
101010101010101010100F0F0F1010101111101010101010
10101112141516191D2730393F40404242424241403D3B38
37373736363738393939383737373737
3838383838383737373B3E40413F3D3B3A3C3F4042434446
46464545454546464648494A4B4D4E4F4F4F4E4E4E4E4E4E
50565B5E5C4D3D3229292C2D3139424C565F6974808E9BA8
B3BDC6CED4D5D6D6D6D7D7D7D6D6D5D4D3D0CECBC9C8C7C5
C3BFBCB8B5B2AFACA9A4A09C99989796959492908E8B8885
817E7A7773716F6C6A68666563605E5C5A5958565552504D
4A45413C3834312E2B2A2928272727262523201D1B1A1918
171718181817171616141211101010111111101010101010
101010101010101010100F0F0F1010101111101010101010
101011121315171A1E262F363B3C3C3C3D3E3F403F3D3A38
37363736363737383837363635363636
3737373737373636373A3E40423F3D3B3A3B3D3E3F414244
44444444444445454647494A4B4D4E4F4F4D4C4B4A4B4D4E
50565B5E5B4A382B212327292F3A45525D646C757F8C98A4
AFBAC4CDD4D5D6D6D6D8D8D8D8D7D7D6D4D2CFCCCAC9C8C6
C4C1BDB9B6B3B0ADAAA5A09C99999898979593928F8C8885
817E7B7774716F6D6B69676563615F5C5B5A58575553504D
4A45413C3834302D2A2827262525252524221F1D1B1A1918
1717181818171616151311100F0F10111111101010101010
10100F0F0F0F0F0F0F0F0F0F101010111111111111101010
101011121315181B1F262E3439393838393B3D3E3E3C3A38
37373736363637373736353534343535
3636363636363636373A3D40413F3C3B3A3A3C3C3D3F4042
43434343434444454547494A4C4D4E4F4F4D4B49494B4D4E
51565A5C594634251B1E22252C39465461666C747D8996A1
ACB7C2CBD2D4D5D6D7D8D9D9D9D8D8D7D5D3D0CECCCBC9C8
C6C2BEBAB7B4B1ADAAA5A19D9A9A9A9998969493918D8985
827E7B7774726F6D6B69676563615F5D5C5A59575553504E
4A46413D3934302C292726242323232323211E1D1B1A1918
17171818181716151412100F0E0F10111111101010101010
10100F0F0F0F0F0F0F0F0F0F101010101111111111101010
101011121315181B1F262D333737363636393C3D3D3C3A38
37373636363636363635343433333433
343434353535353536393C3E3F3D3C3B3A3A3B3B3C3F4143
44444343434444454648494B4C4D4E4F4F4E4D4D4D4F5152
5356585954422F2117181C1F2632404E5B6269737D8A96A2
ADB7C0C9D0D3D4D6D7D8D9D9D8D8D7D6D5D3D1CFCDCCCBC9
C7C3C0BCB8B5B1AEAAA6A29F9C9B9A9997969593918E8A86
827F7B7774716F6D6A6967666462615F5D5C5A585654514E
4B47423E3A35312D2927252322212121211F1D1C1B1A1918
1717181818161514131211100F1010111111101010101011
1110100F0F0F0F0F0F0F0F0F0F1010101111111111111010
101111121315181B1F262D333839393A3A3C3D3D3C3B3938
36363635353434343333333333333333
323333343434343435383A3C3D3C3B3B3A3A3B3B3C3F4244
464544434344454546484A4C4D4D4E4E4F4F505051535555
565756554F3D2B1D131417191F2B3845525C65707B8896A1
ADB6BEC6CDD0D3D6D7D8D8D8D8D7D6D5D4D3D2D1CFCECDCB
C8C5C1BDB9B6B2AEAAA7A3A09E9C9A9897969594928E8B87
837F7B7773706E6C6A696766656462605F5D5B595654524F
4C48443F3B36312D2926242220201F1F1E1D1C1C1B1A1817
171718181716141312111110101011111111101010101111
111110100F101010100F0F0F0F1010101011111111111110
111111121415181A1E262E343A3B3C3E3E3E3E3D3B3A3937
36353534343332323132323232323232
31313233333334343537393A3B3B3B3B3A3A3A3A3B3E4244
464544434344454647484A4C4D4E4E4F4F50525253565758
585754514A39281A101013151B26323F4C56606B7785929F
AAB3BBC3C9CED2D5D7D8D8D8D7D6D6D4D3D3D3D2D1D0CECC
C9C6C2BEBAB6B2AEAAA7A5A29F9D9B9897969594928F8B88
847F7B7773706E6C6A69686766646362605E5C5957555350
4D4945403C37322D292623211F1E1D1D1C1C1B1B1B191817
171717171715141211111110101011111111101010101111
1211101010101010100F0F0F0F0F10101011111212111111
111112131416181B1F262E353B3D3E4041403E3C3A393837
35353434333231302F30313132313131
3030313233333334343638393A3A3A3A3A3A39393A3E4144
464543434243454546484A4C4D4E4E4F4F5152545557595A
5956524D453525180E0E111217202B36424D5864707E8C99
A5AEB7BFC6CBCFD3D5D6D7D7D6D6D5D4D3D4D4D4D3D1CFCD
CBC7C3BFBBB7B2AEAAA8A6A3A19E9B9896969594938F8C88
85807B7773706E6B6A69686766656463615F5C5A57555351
4E4A45413D38332E292623201E1D1C1B1B1A1A1A1A191817
17171717161513121111111111111111111110100F101112
1211101010101010100F0F0F0F0F10101011111212111111
111112131516181B1F272F363B3E404242403E3C3A393837
363534343331302F2E2F303131313131
3030313132323333343638393A3A393938383838393C3F42
44434241414243444547494B4C4D4D4E4F50505152545757
57534E49413224170F0F1213171C222A333E4A5764727F8D
9AA5B0BAC2C7CBCED0D3D5D6D6D6D6D5D5D5D6D6D5D3D1CF
CCC8C4C0BBB7B3AEABA8A6A4A29F9C9997969594938F8C88
85807C7874716E6C6A6867666565646362605D5B58565451
4E4A46423E39342F2B2724211F1D1C1B1A1A1A1A19191818
17171616151412111010101011111111111110100F101111
111110100F101010100F0F0F0F0F10101010111111111010
1011121416171A1C20282F363B3D3E3F403F3E3D3B3B3A3A
39373635343231302F30313232323232
30303031313233333537393A3B3A383736363636373A3D40
4241404040414243444648494B4C4D4E4E4E4E4E4E515455
54504A453D302318101114151818191E24303C495664717F
8D9BA8B4BEC2C5C9CBCFD2D4D6D6D6D6D6D7D8D8D7D5D2D0
CDC9C4C0BBB7B3AFABA9A7A5A3A09C9997969594928F8B88
85817D7975726F6C6A6867656464646362605E5B59565451
4E4A47433F3A35312C292622201E1C1B1A19191919181818
18171615141312111010101011111112121110100F101010
1110100F0F0F0F0F0F0F0F0F0F0F0F101010101111101010
1011131516191B1E222930363A3B3C3D3D3D3D3D3C3D3C3C
3B393836343332313031323233323232
2F303030303132333537393A3B3937363535353637393C3E
403F3F3E3E404142434547484A4B4C4D4E4D4D4C4C4F5253
534D4741392E221811131617181512131722303C4A576573
8292A1AFB9BEC1C4C7CCD0D3D5D6D6D6D7D8D9D9D8D6D3D1
CDC9C4C0BBB7B3AFACAAA8A6A4A09D9A97969594928F8B88
85817D7976726F6C6A6866656464646363605E5C59575451
4E4B47433F3B36322D2A2623201E1C1A1918181818181818
18171514121211101010101011111112121110100F101010
10100F0F0F0F0F0F0F0F0F0F0F0F0F0F1010101111101010
10121315181A1D20242A31363A3B3B3B3B3C3D3D3D3E3E3E
3D3B3937353433323132323333333333
2F2F2F30303132333537393B3B3937353435353637393B3D
3E3E3D3D3D3F404142444647494A4C4D4D4C4B4A4A4D5052
514B443D362C231A1416181A1A140F0D0F1925313D4A5765
748798A8B5B9BCC0C4C9CED1D3D5D5D6D7D8D9D9D9D6D4D1
CDC9C4BFBAB7B3AFACAAA8A6A4A19D9A98969594928E8B88
85817D7A76736F6C6A6866646363636362605E5C59575451
4E4A47433F3A36322E2A2724211E1C1A1818171717171818
18161413121110101010101111111212121110100F0F1010
100F0F0F0F0F0F0F0F0F0F0F100F0F0F0F10101011101010
10121416181B1F22262C32373A3A3A3A3A3B3D3D3D3E3E3E
3D3B3937353433323132323333333333
2F2F2F2F303132343537393A3B39373635363737383A3B3C
3D3C3C3C3C3E40414344454647494A4C4C4B4A48484C5051
5049413B332B241D18191B1C1C181413141A2129323C4854
63798FA2B2B7BBC0C3C8CCCED0D2D3D4D5D7D8D8D7D5D3D0
CCC8C3BEB9B6B3B0ADABA8A6A4A19E9B98979594928F8B88
85817D7975726F6C6A6866646363626261605E5C5A585552
4F4A46413D3935312D2926221F1D1B191817171616171718
181614131111111010101011111111111111101010101010
10100F0F0F0F0F0F0F0F0F0F0F0F0F0F0F10101111101010
11121415181D21262A2F3336393A3B3B3B3B3C3B3B3B3B3B
3A3837353332312F2F30313132323232
2E2E2F2F303133343637393A3B393736353738393A3A3B3B
3B3B3B3B3B3D3F41434344444547494B4B4A4847474B4F51
50483F38312B25201C1D1E1F1F1D1A1A1A1C1F2329303944
536C859CAEB4B9BFC3C7C9CBCCCFD1D2D3D5D6D6D5D4D1CF
CBC6C1BCB8B5B3B0ADABA8A6A4A19E9B99979694928F8C89
85807C7773716F6C6A68666463626161605F5E5C5B585552
4F4A45403B3734302C2824211E1C1A181716161616161717
171514121111111010101011111111111111101010101010
10100F0F0F0F0F10100F0F0F0F0F0F0F1010101111111011
11121415181E242A2E313436383A3B3C3C3B3A3939383837
3735343332302E2D2C2E2F3031313030
2E2E2F2F303133343638393A3B39373636383A3B3C3B3A3A
3A3A3A3A3B3D3F41434343434446484A4A494746464A4E50
4F473E362F2B27232020212223211F1F1E1C1B1C1F242C35
44607C95A9B0B5BDC2C5C7C8C9CCCED0D1D3D4D4D3D2D0CD
CAC5BFBAB6B4B2B0ADAAA8A5A3A09D9B98979593918E8B88
84807B7672706E6C6A6866646261605F5E5D5D5C5A585552
4E49433E3935322F2B2723201D1B19181616161515161616
161513121111111010101011111111111110101010101010
10100F0F0F0F0F1010100F0F0F0F0F0F1010101111111111
121314161920272D32343536383A3B3C3C3B393837363635
34333332312F2D2C2B2C2E2F30302F2F
2E2E2E2F303133343638393B3B3A383736383B3C3D3C3A39
39393A3A3B3D3F4142424242434648494A48464444494D4F
4F463D362F2C28252224262728272625241F1A19191D242B
3956738DA3ABB2BAC0C3C4C5C6C9CCCECFD0D1D2D1D0CDCB
C8C3BEB9B5B3B2B0ADAAA7A5A2A09E9B99989694918F8B88
857F7A7571706E6C6A68666462605F5D5C5C5C5B5A575451
4E48413C3633302C2925211E1B1A18171615151414151516
151412111111111111111011111010101010101010101010
100F0F0F0F0F0F1010100F0F0F0F10101010111111111112
121315171A222A313636363737393B3B3B3A383736353433
32323131302E2C2B2A2C2D2E2F2F2F2F
2E2E2F2F3031323435383A3B3C3B393837393A3B3C3B3A3A
393A3B3C3D3E3F40414243444547494A4B48454343484D50
50483F39322D282422262C2F32302E2D2A231D19181E262E
3B546D8599A3ACB7BEC1C3C4C5C8CBCCCDCFD0D0D0CECBC9
C6C2BDB9B6B4B3B1AFACAAA7A5A4A2A09E9D9B9997938F8B
87817B7672706F6D6C6967656462605E5C5C5B5958565350
4C46403A342F2B2623201E1C1A1817161514131313131415
151312111010101010101010101010101010101111101010
100F0F0F0F0F0F0F0F0F0F0F101010101111111111111112
131417191D252D3439393839383939393838383737353433
32323232312F2D2C2B2C2E2F2F2F2F2F
2F2F2F2F2F31323335373A3C3E3C3A3938393A3B3B3A3A3A
3A3B3D3E3F3E3E3F3F42444647494A4B4B48454242484D50
514A423C352E2823212931373B3935333028201B1A202932
3F53687C8E9BA6B2BBBEC1C2C4C7C9C9CACCCDCECECBC9C6
C3C0BDB9B6B4B3B1AFADABA9A7A6A4A3A1A09F9D9A96918D
88827C7772716F6E6C6A68666462605E5C5A59575553514E
4B443E38312B26211D1B1B1A191716151413121111121314
141311100F0F101010101010101010101010101111101010
0F0F0F0F0F0F0F0F0F0F0F10101011111111111111111112
1316191C212931383C3C3B3A393837363536373838363433
3232323232302F2D2D2D2E2F2F2F2F2F
302F2F2F2F30313234373A3D3E3D3B3A39393A3A3A3A3A3A
3B3C3E3F403F3E3E3E414447494A4B4C4C48444141474D51
524B443F38302922202B353D43403C3A362C241D1B222B33
3F5062738493A0ADB7BBBDC0C1C3C5C5C6C8C9CACAC7C5C2
BFBDBAB7B4B3B1AFADABA9A8A6A5A4A3A2A19F9E9B96918C
87817B75716F6E6D6B69676664615E5C5A58565452514F4C
48423B352F28211C17171717171615141412111010111213
1312100F0F0F101010101010101010101010101111101010
0F0F0F0F0F0F0F0F0F0F0F10101111121211111111111212
14171B1F242C343A3F3E3C3B3A3836343234363838363433
3232333332312F2E2E2E2F2F2F2F2F2F
30302F2F2F30313234373B3D3F3D3C3B3A3A3A3A3A3A3A3B
3C3D3F4141403E3D3D414447494A4B4C4C48454241474D50
514C46413B312922202B374046433E3C382F27211E242D35
3F4D5C6B7A8A99A8B3B7BABDBFC0C1C1C1C3C5C6C6C4C2BF
BDBBB8B5B3B1AEACAAA8A6A4A2A19F9E9C9B9A9997928D89
847E79736F6E6D6B69676563615E5A575553514F4D4C4A48
443E38322B241E1814141516161514141312100F0F101112
1311100F0F0F0F1010101010101010101010101111101010
0F0F0F0F0F0F0F0F0F0F1010101111121212111111111213
15191D22272F363C403F3D3C3A3735323133363738363432
31323333333230302F2F2F2F2F2F2F2F
303030303032333436383B3D3E3E3D3C3B3B3B3B3A3B3B3C
3D3E3F4041403F3E3E4042444647494B4B49464444474B4D
4D4944403A3129221F29333A3F3B3633302C292625282C31
39475665748493A2AEB3B8BCBFBEBEBDBCC1C4C7C8C6C4C2
C0BDBAB6B2AFACA8A5A29F9C9994908C898888878684827F
7D7975716E6C6A686563605D5A55504B4847474645434140
3D37322D27221D181414151515141414131211100F101112
121110101010101010101010101010101010101111101010
100F0F0F0F0F0F0F0F101010111111121211111111111213
151A20252B30363B3E3D3B3A383735333234363737353332
31323232323232323131313130303030
303030303133343637393B3C3E3D3D3D3D3C3C3B3B3B3C3D
3D3E3F4040403F3F3F3F4041424447494A49484746484A4A
4946423F3A3129221F262E3337312C2927282A2B2C2B2B2E
3441505E6D7D8C9AA7AEB4B9BCBBB8B6B6BBC1C4C6C5C4C3
C1BDB9B4AFABA6A19D9996928D867E787474747474747474
73716F6D6B686663605D5956514B453F3B3C3C3C3C3A3937
35302C28231F1C1815151514141413131312111110111111
111111111010101010101010101010111111111010101010
100F0F0F0F0F0F1010101011111111121211111112121213
161C23292E3236393B3A3938373635343334353636353332
31313232323233333433323231313232
2F30303132333537383A3B3C3D3D3D3E3D3D3C3B3B3C3D3D
3E3F3F4040403F3F3F3E3E3E3F4245474949494949494948
464542403B322A221F242A2E302B252221262C30332F2C2C
303C4B57657584929FA7AEB5B8B5B1AEADB4BABEC1C1C1C0
BEBAB5B0ABA5A09A94908C8882786F676161626364656769
6A6A69686664615E5A57534F49423B34303133333432302F
2D2A2623201D1A1715151413131313131312121111111111
111111111111111010101010101011111111111010101010
10100F0F0F0F101010101111111111111111111212121314
171E262C3234363839383837363535343435353635343332
31313131323334353534333332323332
2F2F30313233353738393A3B3C3D3D3D3D3C3B3A3A3B3C3D
3E3E3E3F3F3F3F3F3E3D3D3D3D40434648494A4A4A4A4947
454543413D342A231E22272A2B251F1C1B232B3135302B2A
2C37444F5B6A7886939DA4ACAFAAA5A09EA5ACB0B3B4B4B4
B3AFAAA59F99928B85817C7771665C544E4E4F505154575A
5C5D5D5D5D5A5854514D49454038302A26272A2B2B2A2828
2624211F1D1B191715141413131313131312121211111110
101111111211111010101010101011111111111010101010
10100F0F0F10101010111111111111111111121213131416
192129303536353636363635353535353535353535343332
31313131313334363635343333333333
2E2E2E2F303133343637393A3B3B3B3A3A39383838393A3B
3C3C3C3C3C3C3C3C3C3C3C3C3D4042444647494A4B4B4B4B
4A4A494743372C231D2126292A231D1A191E24282B292828
2B3139414A5866737F89929A9D948B847F83888A8D8F9193
93908C88837C756E67635E59544D46403C3B3C3C3D3F4043
44454546464543413F3C3936322D27232021232324232222
21201E1D1B19181615141313121212121212111111101010
101011111111111010101010101011111111101010101010
101010101010101010111111121111111212121314151719
1D252E353938353433343536363535343434343534343332
31313131313233343434333332323333
2D2D2D2D2E2F313233353738393938373736363535363738
393939393A39393A3A3B3B3C3D3F4142444647494B4C4E4E
4F4F4E4D483B2E231C21252829231D19171A1D1F22222426
292C2F333A47545F6A757E86887D70665F616464666A6D70
72706D6B675F58504945413C3834302D2B2A2A292A2A2B2C
2D2E2E2E2F2F2F2E2E2C292725221F1D1B1C1C1D1D1D1D1D
1C1C1B1B1A18161514131312121212121111111010101010
101011111111101010101010101011111110101010101010
101010101010101010111111121111121212131416181A1D
212A32393D39353230333536363534343334343434333232
31313131313132323232323232323232
2C2B2B2C2C2D2F3031333537383736353434333333343536
373737373737373838393B3C3D3E3F41424447494B4D5051
525353524D3F30251C20252627211B18151618191B1E2124
272627282D38434D57626C747668594D43444544464A4F53
565553514E463E37302B2723201E1C1B1A19181817181818
19191A1A1B1C1D1E1E1D1B1A191817161616161617171717
181818181817151413131312121211111110101010101010
101010111111101010101010101010101010101010101010
1010101010101010111111111212111212131416181A1D21
252E363D403B35302E313435363534333333343434333232
31313131313131313131313131313131
2B2B2A2B2B2C2D2E2F323435363534333232323131323435
35353536363636363638393B3C3D3F40424446484B4E5153
54565655514233261E21252627211C1916161616171A1E21
24212020222B353D4550585F605243372D2C2C2A2B303539
3D3D3B3B383129221C1815110E0F0F0F100E0C0C0B0B0B0B
0B0B0B0C0D0F101213121110101111121212121212131314
141516171716151413131312121111111010101010101010
101010111110101010101010101010101010101010101010
1010101010101011111111111212121213131516191C2125
2A32393F413B342F2C303335363534333333333333333232
313131313030302F2F30303131313131
2B2B2B2B2C2C2D2D2E303233343434333333323232333334
3535363637363535353637383A3C3F41444647494B4E5052
53565656524435292124282A2A26211F1C1C1C1B1B1B1C1C
1D1D1D1E20262D32383E4347473E342C2525252425292C2F
3231302F2C28241F1B1816131112121212110F0E0D0D0E0E
0E0E0E0E0E0F111212121111101111111111111111121213
131414151514131312121212121111101010101010101010
101010101110101010101010101010101010101010101010
1010101010101011111111111112121314131415171D2429
2F35393E3F3A34302D303234353433333333333333323232
3131302F2F2F2F2F2F30303030303030
2B2C2C2C2C2C2C2D2D2F3031323333343434333332333334
343536373836353535353536383C3F434647484A4B4E5051
525556565345382D25282C2E2E2B272523232322211D1A18
17191B1E202326292C2E2F302F2B26232020212122242628
292726252322201E1D1B1918161717171615131212121212
121211111112131313131212121212121111121212121212
121313141413121211111212121111101010101010101010
101010101010101010101010101010101010101010101010
1010101010101011111111111112131414131314161E272E
3437393C3C3935312E303232333333333333333332323232
31302F2E2E2E2F2F2F2F2F2F30303030
2B2C2C2C2C2C2C2C2C2D2E2F303233343434333333333333
333536383837353434343435363B40444748494A4B4D4F50
5154565754483B312A2D303132302D2B2A292726231E1914
12161A1C1F1F1F20201E1C1B1919191818191A1A1B1C1C1D
1D1C1A1918191A1A1A1A1918181819191917161514141414
141312121112121212121212121212121212121212121212
121213131312111111111112121110101010101010101010
101010101010101010101010101010101010101010101010
101010101010101111111111111213151614131316202A32
393A3A3B3A37353230303131323232333333323232323232
31302E2D2D2D2E2E2F2F2F2F2F2F2F2F
2B2B2C2C2C2C2B2B2B2C2D2E2F3132343434343333333333
333537383837353433333434363B404448484848494B4D4E
4F525556554A3F362F32343535343231302E2D2B27201913
10151A1D201E1B1A1814100D0B0D10121415151717171716
1614131211141618191919191A1A1A1B1A19181716161616
161514131212121212121212121212121212121212121211
111212121211111010111111111110101010101010101010
101010101010101010101010101010101010101010101010
101010101010101111111111111314151615151518232E36
3C3B3A393836353331313131323232333333323232323232
31302E2D2C2D2D2E2E2E2E2E2E2E2E2E
2A2A2A2B2B2B2B2B2B2C2D2E2F3032333433333333333434
3436373738363433333537383A3D40434545444445464748
4A4E5255544C443D37363635343433333332302F2C241C16
13181E2123211D1C1916120F0D0F11121313141415151515
151312111112131415151515161616161615141413131313
131212111111111111111111111111111111111111111111
111111111111101010101111111110101010101011101010
101010101010101010101010101010101010101010101010
101010101010111111121212121213141517191B20293138
3D3C39383736353433333333333333333333333333333333
33312F2D2C2C2D2D2D2D2D2D2D2D2D2D
282929292A2A2A2B2B2C2D2D2E3031323333333333343435
36363737373534333336393C3E3F40414241404040414243
454A4F53544F49443F3C393533343535363533322F27201A
171C22252724201E1B191614121213131313131314141515
151413121111111112121212121212121111111111111010
101010101010101010101111111010101010101010101010
101010101010101010101010101010101010111111111010
101010101010101010101010101010101010101010101010
1010101010111111121212131313121314191E22282E343A
3D3C39383636363535353535353534343434343333343435
34322F2D2C2C2D2D2D2C2C2C2D2D2C2C
2728282829292A2A2B2C2C2D2E2F30323232323233343536
373737373735343333383C3F41414040403F3E3D3C3C3D3E
40464C5153514D4B47423D38343638393A393736332B231D
1A1F25292B2723201D1B1916141415151515151515151616
161514131212111111111112121111101010111111111010
101111111111111111111111111110100F10101011101010
101010101010101010101010101010101011111112111010
0F1010101010101010101010111010101010101010101010
11111010111111121213131415131313151B22282E33373C
3E3C39363536363637373737373635343434343434353536
3532302E2C2C2C2C2C2C2C2C2C2C2C2C
272727272828292A2B2B2C2D2D2F30313232323233343637
373737373735343334383D404341403F3E3C3B3A39393A3B
3D434A4F535352524F48413B37393B3C3C3B3938352D2721
1E23282B2D2924211E1C1A18171716161616151515161717
17161514131211111010111111100F0F0F0F101011101010
101111121212111111111212111110100F10101011101010
101010101010101010101010101010101011111212111010
0F1010101010100F10101010111010101010101010101011
11111111111112121313141515141415171F272E34383A3D
3E3C39363435373738383838373635343333343434353536
3533302E2C2C2C2C2B2B2B2B2B2B2B2B
26262627272828292A2A2B2C2D2E2F313132323333343536
373737373736353435383C3E403F3E3D3C3B3A3939393A3B
3D434A4F53565859585149433D3E3E3D3C3834312D2A2724
232527282824201D1A181715141413131313131313131414
14131312121110100F10101111100F0F0F0F101111111010
101011111111111111111111111010101010101111101010
101010100F10101010101010101010101011111111111010
1010101010100F0F0F0F101010101010101010100F101010
1111111212121212121213141517191B1F262D32383A3C3E
3E3C39373536373838373737363433313031313232333434
34312F2D2B2B2C2B2B2B2B2B2B2B2B2B
262626262627272828292A2B2C2E2F303132323334343536
363637373736363536383A3C3D3C3C3C3B3A393939393A3C
3E44494E53595D60615A524B4543423F3B352F2A27272828
28262524221F1C1916151413121111111010111111111112
1211111110100F0F0F1010101010100F0F10101111111110
101010101010101010101010101010101111111111101010
10101010100F0F10100F0F0F0F1010101010101010101010
1010101010100F0F0F0F0F0F101010111110100F0F0F1010
11111213131212111112121315191E23272D32363A3C3D3F
3E3C3A3836373838373736353432302F2E2E2F3030313232
32302E2C2B2B2B2B2B2B2B2B2B2B2B2B
262626262626272728292A2B2C2D2E2F3132323334343535
36363737373736363638393A3B3A3A3A3A39383838393A3B
3E43494E535B6166686159524B4946423D342C2622262A2C
2D2925221F1C1A1715141413131110100F10101010111111
1111111010100F0F0F0F101010100F0F0F10101111111111
10101010101010101010100F0F1010111111111111101010
10101010100F0F0F0F0F0F0F0F1010101110101010101010
1010101010100F0F0F0F0F0F0F1010111110100F0F0F1010
111213131413121211121314161D23292F33373B3E3F3F3F
3E3D3B39373838383736353533312F2D2B2C2D2E2F303031
312F2D2C2B2B2B2B2B2B2B2B2B2B2B2B
26252525252626272728292A2C2D2E2F3031323334343435
353637373837373737373839393939393939383839393A3C
3E43484D535C646A6D67605A53504C4741372D2521262B2F
302A24201C1A1815141313131311100F0F0F101011101010
1010101010100F0F0F0F101010100F0F0F10101111111111
101010100F10101010100F0F0F1011111111111110101010
1010101010100F0F0F0F0F0F0F101010111010100F101010
1010101010100F0F0F0F0F0F0F1010111110100F0F101011
1112131414141313131315161921293036393C3F40414040
3F3D3B3A383838373736353432302E2C2B2B2D2D2E2E2F2F
2F2E2D2C2B2B2B2B2B2B2B2B2B2B2B2B
26262525252627272829292A2B2C2D2E3031323334343434
3536373838383737373839393A3B3B3C3C3C3B3B3B3B3C3D
3F44494D535C636A6E6B6764605C58534C433A322C2D2E2E
2D2823201D1A181614131212111111111111121213121110
0F10101010100F0F0F0F0F1010100F0F0F10101011111111
11111010101010101010100F101011111111111010101010
101010101010100F0F0F0F0F0F1010111111101010101010
1010101010100F0F0F0F0F0F101010111110101010111212
131313131414151618191B1D212930373C3E3F4041424242
413F3C3A38383837363534333231302F2E2E2E2E2E2F2F2F
2F2E2D2C2B2B2B2B2B2B2B2B2B2B2B2B
26262525252627282929292A2A2C2D2E2F30313233333434
35363738383837373738393A3B3C3D3E3F3E3E3E3D3D3D3E
3F44494D535B62686D6E6E6D6C69645F5950473E3734312E
2B2723201D1B191715141211101111121213141515131110
0F0F101010100F0F0F0F0F10100F0F0F0F0F101010101011
111111111111101010101010101010111111101010101010
101010101010100F0F0F0F0F0F1010111111111010101010
101010101010101010101010101010101010101010121314
151413131315181A1C1F22252930383E4242424242434444
43403D3A3838373636343332313131323131302F2F2F2F2F
2E2E2D2D2C2C2C2B2B2B2B2B2B2B2B2B
26262525252628292A2929292A2B2C2D2F30313232333333
34363738393837373738393A3B3D3E40414140403F3F3E3F
4044494D535960666C70737575726E6A635A51473F39342E
292623201E1B191816141211101112131415161616141210
0F0F101010100F0F0F0F0F1010100F0F0F0F0F0F10101011
111111111111111010101010101011111110101010101010
10101011111010100F0F0F0F101011111111111111111010
101010100F10101010101011111110101110111111131415
1615131313161A1D2124282C31383F444847454342444545
44413E3B383737363533323130313334343231302F2F2E2E
2E2D2D2D2D2C2C2B2B2B2B2B2C2B2B2B
26262525252728292A2A29292A2B2C2D2E2F303132323233
3335373839383736363738393A3D3F40424140403F3F3E3E
3F43474B50565C62686E74797C7A77746E63584D433C3730
2B2723201E1C1A1817141211101112131416171717151210
0E0F101010100F0F0F0F0F1010101010100F0F0F0F101011
111111121111111010101010101011111010101010101010
10101111111010100F0F1010101011111111111111111110
101010100F10101010101111111111111111111112141517
1715141314181C2024292E32383E444A4D4A474544454646
45423E3B393736353432313030323435363431302F2E2E2E
2D2D2D2D2D2C2C2B2B2B2B2B2C2B2B2B
26262625262728292A2A2A2A2B2C2C2D2E2F303132313131
323435363736353434353637393A3C3D3E3D3C3B3A3A3A3A
3B3F42464A4F53585E666E757A7D7E7E7967544437383937
342D26211D1B1A1816151413121212131315161717151211
0F0F1010100F0F0F0F0F1010101010100F0F0F0F0F101011
111111111111101010101010101111111110101010101010
101010101010101010101010101010111110101010101011
111010101010101010101010101111121212121212141516
17161616171A1D20242A30363C41464B4D4D4B4A49484746
44413E3C3A38363432313130303233343533312F2E2E2E2E
2E2D2D2C2C2B2B2A2A2A2A2B2B2B2B2B
26262626262728292A2A2B2B2C2C2D2D2E2F303131313030
303234353634323231333435373839393A38373635353636
373A3D4145474B4F545D676E757D83868269503C2D343B3D
3D3329221D1B1A1816161515151413121214151617151211
1010100F0F0F0F0F10101010101010100F0F0F0F10101111
111111101010101010101010101111111111101010111111
111010101010101010101010101010101010100F0F101011
111111101010101010100F0F101112131313131313141516
171718191A1C1E20242C333A4044484B4E4F4F4E4D4B4845
42403F3C3A38353331313130313232333332302E2D2E2E2E
2E2D2C2B2B2A2A2A29292A2A2A2A2A2A
2626262626272829292A2B2C2D2D2D2D2D2E2F3031302F2F
2F313334343331302F313334353636373735343232323233
3437393D404143464B556069727E878D8A6D503828323E43
45382C241E1C1B1817171717171513121113151616151311
1010100F0F0F0F1010101010101010100F0F0F0F10101111
111110101010101010101010111111111111111111111111
111010100F1010101010101010101010100F0F0F0F101011
1111111111101010100F0F0F101113141514141414151616
17181A1C1D1E2022262F373F46484A4C4E505151504C4844
41403E3D3B373432303030303132323333312F2E2D2E2F2F
2F2D2C2B2A2A29292929292929292929
2525252626272728292A2B2C2D2D2D2D2D2E2F30302F2F2E
2E3032333432302F2E30323334343435353331302F303031
323437393C3C3D3F434D58606A7A868F8E70523A2A354247
483C2F27201D1C1918181819191614121113141516141312
111010100F0F101010101010101010101010101010101111
111110100F0F101010101010111111111111111111111111
1110100F0F10101010101010101010100F0F0F0F0F101011
1111111111111010100F0F0F101113151616151616161617
181A1C1E2021222429333D454C4D4D4F4F515353514C4742
3F3E3E3C3B3734312F3030303131313232302E2D2C2D2F2F
2F2E2C2B2A2A29292829292929292929
23242424242526262728292B2B2C2C2C2D2E2E2F2F2F2E2E
2E3032333432313030313233343434353534323231313232
333537393B3B3C3E42474D535B6C7A8588745F4F42434543
40372F2924201D1A1919191A191714121112131414131211
111111101010101010101010101010101010101010111111
111110101010101010101010101010101011111111111111
11111010101010111111101010101010100F0F0F0F101011
111111111111111010101010101213151617171819181818
181A1B1D202225292F3A454F56565555555453514E49443F
3C3B3B3A393633312F2F2F2F2F303030302F2D2C2C2D2E2F
2F2E2D2C2B2B2A292929292A2A2A2A2A
2222222223232425252728292A2B2B2C2C2D2E2E2E2E2E2E
2E3032333433323231323333333434353535343434343434
353638393B3C3D3F414143464C5D6D7A80776C645A524A40
3834302C2824201C1A1A1A1A1A1714131112121313121111
11111111111010100F0F1010101011111111111111111111
111010101010101011101010101010101010101011111111
111111111111111111111111101010101010101010101111
1111111111111111111111111112141516181A1B1C1B1A19
191A1C1E21252A2F36424E585F5F5D5B5956524E4945403C
3938383837353231302F2F2E2E2E2F2F2F2E2D2C2B2C2E2E
2F2E2E2E2D2C2B2A292A2A2A2B2A2A2A
202021212222232324252728292A2B2B2C2C2D2D2E2D2D2D
2E3032333434333332333333333434343535353535353535
363738393A3B3C3E3F3C3A3A3E5062707A7975736C5D4E3F
343333302D28231F1D1C1C1C1B1816141212121211111111
11111212121110100F0F1010101111111212111111111111
111010101010101111111010101010101010101010111111
121111111111111111111111101010101010101010111111
11111111111111121212121212131516171A1C1E201E1C1C
1B1C1E2023282E343C49555F6665625F5B57524C46413D39
3636363635343231302F2E2E2D2D2D2D2D2C2C2B2B2C2D2E
2F2F2F2E2E2D2C2B2A2A2B2B2B2B2B2B
1F202020212122222324262728292A2B2C2C2C2D2D2D2D2E
2E3032333434343434333333333334343535353636363636
363738393A3B3C3D3D3834323646576570767A7D7A685645
38393A38352E2823201F1E1D1C1917151312121110101111
11111212121110100F0F1010101111121212121111111111
111010101010111111111010101010101010101010111111
121111111112121212111111111010101011111111111111
11111111111212121212131314151618191C1E2122201E1E
1E1F2224282F363C45515C656B6863605B554F48423E3B37
3434353535333231302F2E2D2D2D2D2D2D2C2B2B2B2C2D2E
2E2F2F2F2F2E2C2B2A2B2B2C2C2C2B2B
202021212222222324252628292A2B2B2C2C2D2D2D2E2E2E
2F3032333434343434343333333334343535353636363637
3738393A3B3B3B3C3C3A39383B46525B646C72787971665D
55514E484239302923211F1C1B1918171614121110101010
10111112121110100F0F1010101010111111111212111111
111010101010101011101010101011111111111110111111
111111111111111111111111101011111111111111111111
1111121212121212121213141517191B1D1D1E1F1F1E1E1E
2024292E343C444C535B626769645E58524D49433F3C3A38
3636363737353332302F2E2D2D2D2E2E2E2E2D2C2C2D2D2E
2E2E2F2F2F2E2D2C2B2B2C2C2C2C2C2C
2121222222232324242627282A2A2B2C2C2D2D2D2E2E2E2F
2F3032333434343535343433333334353535353636373737
38393A3B3C3B3B3B3B3C3E4042474D5258616A7176777675
716961584E443A302824201D1A1A1A1A191613110F0F1010
101011121211111010101010101010101011111212121111
111010101010101010101010101011111111111111101010
101011111111111110101010101111111111111111111111
111212131312121212131415171A1D1F211F1E1E1E1E1F20
232A3239414A525A60646667665F574F4845423E3B3A3938
383838393836343231302F2E2D2E2F30302F2E2E2D2D2E2E
2E2E2E2F2E2E2D2C2C2C2C2C2C2C2C2C
2222222223232424252627292A2A2B2C2C2D2D2D2E2E2F2F
303132333334353536353433333434353536363737373838
393A3C3D3D3C3B3B3B3E4144464646484C58646D767D8286
867C71665A4E43372D27231E1B1B1C1D1D19151210101010
10111112121211101010101010100F0F1010111212121111
111010101010101010101010101111111111111111101010
101010111111111010101010101111111211111111111112
121213141413121212141617191D20242523201F1F202123
28303A434C555E666B6B6967635A5148413E3C3938383838
39393A3A3A37353331302F2E2E2F303131302F2F2E2E2E2E
2E2E2E2E2E2E2D2D2C2D2D2D2D2D2D2D
2223232323242424252628292A2A2B2B2C2C2D2D2E2E2F2F
303132323334353636353433333434353636363738383839
393B3D3E3E3D3C3B3C4044474945424244515E68737F8890
92877A6F62574C40362F292420202121211C171411111110
10111112121211111010101010100F0F0F10111212121111
111110101010101010101010101111111211111111101010
101010111111111111111111111111121212111111111212
12131314141413131416191B1E212528292725242426292C
313B464F5860676E716D68635D544B423B39383635363738
393A3A3A3A38353331302F2E2E2F30313231302F2E2E2E2D
2D2D2E2E2E2E2D2D2D2D2D2D2D2D2D2D
23232424242424252526272829292A2A2B2B2C2D2D2E2E2F
2F3031313233343535343333323334343536363738383838
393A3C3E3F3D3C3C3C3F42454644434346505B646D757C82
847C736B625D575049433D37322E2A26221E1A1714131211
111111121211111111111111101010101010101111111111
111111101010101010101010101011111211111111101010
101111111212121212121111111112121211111010111112
1212131314141415171B2024272828292A2C2E3134383D41
4851596167696A6B69645E58514C46413C3A383635353536
3637383838363432302F2E2D2D2E2F3030302F2E2D2D2D2D
2C2C2C2C2C2D2D2D2D2C2C2C2C2C2C2C
242424242424252525262627272829292A2A2B2C2C2D2E2E
2F3030313132333434333332323233333435363738383737
383A3C3E3F3E3D3C3D3E40424343444548505960666B6F73
746F6A666261605E5B55504A443B332C25211E1A18161413
131212121211111111111111111111101010101010101010
101111111111101010101010101011111211111111111111
111112121213131313131212121212121211111010111212
13121213131416171A21272D302E2C2C2D33393F454B5157
5E656C7174706A666059534C4644423F3D3B383735353433
33343536363432302F2E2D2C2C2D2E2F2F2E2D2D2C2C2C2C
2C2C2B2B2B2B2C2C2C2C2B2B2B2B2B2B
25252525252525252525262626272828292A2A2B2C2D2D2E
2F2F2F303031323334333232323233333435373839383737
383A3C3E3F3E3E3D3E3F404143434446494F555A5F626568
6A6865636266696A6A655F5952473C312925221F1C191716
141313121212121212121212121211111110100F0F0F1010
101111121211111010101010101111121211111111111112
121212121313141415141313121212121211111010111213
131312131315181A1E262E3539353130313A434B545B6269
70777C7F7E766B62595149413C3C3D3D3D3A383735343332
323334343433312F2E2D2D2C2C2D2D2E2E2D2D2C2C2C2C2B
2B2B2A2A2A2B2B2C2C2B2B2A2A2A2A2A
2525252525252525252525252626272728292A2A2B2C2D2D
2E2E2F2F303031323332323232323333343638393A393837
383A3D3F40403F3F3F404041424345474A4E5256595B5D5F
6061626264696E70716D68635B504439302C2925221F1D1B
19171514131312121212121212121212111110100F101010
101111121212111110101110111111111211111111111212
121313131314151616151514131414141413121111121314
1413131315171B1E232A32393E3B39393C46515A636A7278
7E8285868376695C5149423A3537393B3C3A383735343331
313132333331302F2E2D2D2D2D2D2D2E2E2D2C2C2B2B2B2B
2B2B2A29292A2B2B2B2B2A2A292A2A2A
242323232324242525252525252626262728292A2B2B2B2C
2C2D2D2E2E2F3031323232333334353536393B3D3D3C3A39
393C3F40424242424241414142434446484D5256595A5B5C
5E63676A6C6A676562605D5A56524D48443E38332E2C2926
231F1C191614131111111112121212121212121212111111
111111111112121212121212121111101011111112121212
121314141516161718171616151617181817161514141414
15151516181B2024282B2E32373F474F575E656B71767A7D
7F7F7E7C776B5F544A45413C3939393A3A38363534343333
3232323232312F2F2E2F2F2F302F2F2F2F2E2D2C2C2C2C2C
2C2B2B2A2A2A2B2B2B2A2A2A29292A29
22222121222223242525252525252525262728292A2A2A2A
2B2B2C2C2D2E2F303132333435353637383B3E40413F3D3B
3B3E4042444444444444434242424344474C51565A5A5A5B
5D656D72736A60595252525050525556554E46403A383532
2E28221E1916141110101111121212121314141414131212
111111111112121313131313131211100F10111212121212
13141515161718191918181718191B1C1C1B1A1918171616
161617191B20252A2E2C2A2B314356657275787B7E808180
7E7A7570695F544B4342403E3D3B3A393837353433343434
3433323131302F2F2F30313233323130302F2E2D2D2D2D2D
2D2D2C2B2B2B2B2B2B2A2A2A29292929
20202020202123232425252525252524252628292A292929
292A2B2B2C2D2E2F30313335363738393A3D404243413F3D
3C3F4244454646474745444242424344474C515659585757
59646F7677695B5048494B4B4D555C62645B524B4442403C
373028221C18151210101112131313131415161717151413
1211111111121314151515151412110F0F10111213131313
131415161718191A1B1A1A191A1C1E1F201E1D1C1B191817
17181A1C1F252B31342E2A282E4863788889888A8A898884
7E776F675E544B423C3D3E3F3F3C3A393736353433343535
35343231302F2F2F2F31333435343231302F2F2E2D2D2E2E
2E2D2C2C2B2B2B2A2A2A2A2929292929
201F1F1F1F21222324242525252524242426272829292929
292A2A2B2C2D2E2E303234363738393A3B3E41444542403E
3D404345464748494946444342424344464B505558575555
57636D757768594E454647474A545E666A6259524B494743
3E362E27211D191513131314141414141516171818171514
131212121213141516161616161412111011121314141313
1415161718191B1C1C1C1C1B1C1E20212221201F1E1C1B19
191B1D1F232A30373A332D2B314F6E8597969393918E8A83
7B71675D534B433C383A3D40413D3A383635343333343536
363432312F2F302F303234363635333231302F2E2D2E2E2F
2F2E2D2C2B2B2B2A2A2A2A2929292929
2020201F202021222324242526262626262728282929292A
2A2B2C2D2E2F2F30313335363838393A3B3E404142403E3D
3D404244464748494947444341424243454A4F5457575657
585E6366686663615D56504A474D53575955514E4A484542
3E39342F2B2723201D1C1B19181614131213141415151515
151514141414141415161717181716161515151515141414
1515161617191B1D1E1E1E1E1E20212122222222211F1D1C
1C1E2023272D33393E3C3B3D445B7284929290908D88827A
726960574F49433D3A3B3D3E3F3B38363434343434343535
35343231313131313233343536343331302F2E2D2D2E2E2F
2F2E2D2C2B2B2B2B2A2A2A2A2A2A2A2A
212120202020212222232425262727282828282828292A2B
2C2D2E2F303131323334353738393A3A3B3D3E3F3F3E3D3D
3D3F424445474849494745434141414243484D5256575859
5A5959585A646D737567594E454648474848484848454340
3D3B393734312D2A2725221F1D1916131111121213141617
1818171716161514141618191A1A1A1B1A19171615151616
1615151516191C1F2020202121212121212223242422201F
202224272B30363D43464B50586776828B8C8B8A87807970
68615A524C47433F3D3D3D3D3C3936343334343535343434
34333333323333333434353535333231302F2E2D2C2D2E2F
2F2E2C2B2B2B2B2B2B2B2A2A2A2A2A2A
212120202020212122232426272828292A292928282A2B2C
2E2F3031323333333435363738393A3B3C3C3D3D3D3D3D3D
3D3F42434547484A4A4745434241414142474D515557595B
5C56514D4F62738084725E504341413D3C3F424648454240
3E3E3E3D3B3836332F2C2824201B17131010101112141719
1B1A1A1A191716151416191A1C1D1E1F1F1C1A1716161717
1716151516191D2022232323232323222224252727262424
2426292C31363B424850585F67717A8287888786827A7067
5E57514B464342403F3E3D3D3C3836333233343536353434
33333434343435353535353534333231302E2D2C2C2D2E2F
2F2D2C2B2B2B2B2B2B2B2B2A2A2A2A2A
2121202020202021212324252728292A2B2A2928282A2C2D
2F3031323434343435363738393A3A3B3B3B3B3B3B3C3D3D
3E4042444647494A4A4846444241414042464B5054575A5D
5D554E484A6076858B79645548423E3734393E424543403F
3E3F3F3E3D3C393734312D29251F1A16131313131417191C
1E1E1D1D1C1A181615181A1C1E1F2021211E1B1817171818
18171615161A1E222424242525242322232527292A292828
292C2F33373C42484F5A646D757A7E81838483817C72685F
56504B4541414142413F3D3C3B3835323133343536353433
333434353535363636353534343331302F2E2D2C2C2D2E2E
2E2D2C2B2A2B2B2B2C2B2B2B2B2B2B2B
1F1F1F1F1F20202021222324262728292A292929292A2C2D
2E2F303233333334343637383939393A3A3A3A3B3B3D3F41
4244454748494949494847464443424142454A4D5154575B
5D59565556616B73777169645C534A403A3C3E3E3F3F3E3E
3D3A3734323131302F2F2E2D2B2824211F1F202020212222
23232222211F1C1A191B1D1E202020201F1D1B1917181819
191919191A1E21242626252424232221212326282A2A2A2C
2E3135393E444A5058636E777E8183858583817D776F665E
554E48423F40414243403D3C3A3734323132343536353434
3435353636353535343434343332312F2E2E2D2C2C2D2D2D
2D2C2C2B2A2B2B2C2C2B2B2B2B2B2B2B
1D1D1E1E1E1F2020212223242526272829292929292A2C2D
2E2F303132323233343537383939393939393A3A3B3E4144
464848494A4A4A4949484847464543424245484B4E515559
5C5E60626362616061686E727164564C42403F3C3A3B3C3D
3C352F2A262728292A2C2E30312F2D2C2B2B2C2C2C2B2928
272727272623211E1D1E202121201F1E1D1B1A1918181919
1A1B1B1D1E2124262827252423222221212325282A2C2E31
34383C41464D535A626D777F8687878785827D78726B645C
554D47403D3F414344403D3B393634323132343535353535
3535363636353433333334343332302E2D2D2D2D2C2C2C2C
2C2C2B2B2B2B2B2C2C2B2B2B2B2B2B2B
1C1C1D1D1E1F20212122222324252728292929292A2B2C2D
2E2F30313232323334353738393938383838393A3B3F4347
494A4B4C4C4B4A494848494948464443434447494B4F5457
5C61656A6A625A545464737E817160534743403A37393B3D
3C3229231F202324272B2F33363534343335363635322F2D
2B2B2C2B2A2724222021222322211F1D1C1B1A1919191A1A
1B1D1E1F212426282928262524232322232527292C2F3337
3B3F44494F555C636B757F888D8C8986827E78726B655F59
534B443E3B3E424446413D3B383634323132333435353535
35363737373634333232333333312F2E2D2D2D2D2D2C2C2C
2B2B2B2B2B2B2B2C2C2B2B2B2B2B2B2B
1B1C1D1D1E1F2021222222232425272829292A2A2B2C2D2D
2E2F303132333333343638393A3939393939393A3C404549
4C4C4C4D4D4C4A4948494A4A4A474544444446474A4D5255
5A62686E6F63574E4C6277858C7C6A5D514B463E3A3B3C3D
3B3027201B1C1F2124292D323636363738393A3B3A373330
2E2E2F2F2E2A27252323242423211E1C1A1A1A191A1A1A1B
1C1D1F20222527292A2927262525262728292B2D30353A40
454B50565C636A717880878D908D89847F79726B65605B56
514A433D3A3E434547423D3A373634333232333435353535
36363738373533323132333333312F2D2C2C2D2D2D2C2B2B
2B2B2B2B2B2B2B2C2C2C2B2B2B2B2B2B
1D1D1E1E1E1F212223232324242628292A2A2A2B2B2D2E2F
303233343536363738393A3B3C3C3C3C3D3C3D3D3E414548
4A4B4B4C4C4C4B4A494A4A4A4A48474645464748494C4F52
565C616669645F5C5D6B7881857D726B635E59524C47423D
38312B262222222223242527292A2B2C2E3031333332302F
2E2F30302F2B28252324242524211D1B19191A1A1A1A1A1B
1B1B1A1B1C1F232629282727282C3034363636373A40484E
565E676F777F878D9291908E8B8885807B746D665F5B5753
4E48423D3B3F434647423E3B383635333232333334343435
3536363636353332313234343432302E2D2D2D2C2C2C2C2B
2B2B2B2B2B2B2B2C2C2B2B2B2B2B2B2B
1F1F1F1F1F202122232424252527292A2B2B2B2B2C2E2F31
333435373839393A3B3C3C3D3D3E3F404140404040434547
494A4A4B4C4C4B4B4B4B4A4A4949484747474848494B4D4F
52565A5E6264676A6E73787B7D7C7A7874706C665F54493F
3734312E2C29272524211E1D1C1E2022242527292B2C2C2D
2E2F30302F2C28252223252524201D1A18191A1A1B1B1B1B
1B191716161B2024282828292C343B4146444242454D565E
67727C869099A1A7A9A0958C8482807B766E66605A56534F
4B46423E3C40434546423E3B383635333232323233333434
3535353535343331313334353533302F2D2D2D2C2C2C2C2C
2C2B2B2B2B2B2B2C2C2B2B2B2B2B2B2B
21202020202122242525252627282A2B2C2C2C2C2D2F3133
343637393A3B3C3D3E3E3E3E3F4042434443434343444647
48494A4B4B4C4C4C4C4B4B4A4A49494949484849494A4B4D
4F5255595D656C7377787778797E828484817C766E5F5042
37373735332F2A28241F1A161416191B1D1F212426282A2C
2E2F3031302C28252324252524201C1917181A1B1C1C1C1C
1B18151313181E232728292C313B454D53504D4C4E57626B
75828E9AA4AEB6BBBAAA998A7E7C7B767169615A55524F4D
4A45423F3D40434646423E3B383736343332323232333334
3535353434333231313335363634312F2D2D2C2C2B2C2C2C
2C2C2C2B2B2B2C2C2C2B2B2B2B2B2B2B
23222121212224252626262728292B2C2E2E2E2E2F313234
3638393B3D3E3E3F40404040404244464746454545464647
47494A4B4B4C4C4D4D4C4B4A4A4A4A4A4A4A4A4A4A4A4A4B
4D4E515459636D767C797674757E868B8F8C88847C6B5A4B
3F3F403E3C37312D2820191410121416181A1C1E21242629
2B2D2E302F2C28252324252524201C1917191B1C1D1E1E1F
1F1B171413181E23272A2D313844505A615D5A595B646F78
83909CA7B1B9BFC3BFAB96847574736F6B625A54504E4C4A
4845413F3E41434545423E3B383736353333323131323334
353434343332323131333536363432302E2D2D2C2B2B2C2C
2C2C2C2C2C2C2C2C2C2C2B2B2B2B2B2B
232222212223252728282829292B2D2F3030313132333434
36383A3C3E3E3E3F3F3F3F3F404244454746464646474747
48494A4C4C4C4C4C4C4C4B4A4A4A4A4A4A4A4B4C4C4C4C4D
4E4E5051555C63696F717275787E8386898A8A89857A6E63
5955524D48423B363029231D191919181919191A1B1D1F21
2326292B2C2927252324252524211E1C1B1A1A1A1C212529
2C282422202224262A2F353B43505C676F6D6B6C6E778088
8F979EA5A9AAAAA8A293837469686765615A534E4B4A4948
47433F3D3B3E414344403C3A373736353433323232323334
34343434333231302F313335353331302E2D2D2C2B2B2C2C
2C2C2C2C2C2C2C2B2B2B2B2B2C2C2B2B
24232323232527292A2A2A2A2B2D30313333343535353535
36393C3E403F3F3E3E3F3F3F404244454747474748484848
484A4B4D4D4D4C4C4C4B4B4B4A4A4A494A4B4C4E4E4E4E4F
4F4F4F505154585C61686F757A7C7E8082868A8C8B86807A
736C645C544D47403A342F2A25221F1D1B1918181818191A
1C2023262827252524242424232221201F1D1B1A1C242D33
383531302E2C2B2A2C343D46505C68747C7C7C7D7F878F94
999C9E9F9E98928B83796F655E5D5C5A58524D4946464747
46413E3B393C3F41423F3B39373636363534333332333434
343434343432302F2F303233343331302F2E2D2C2B2B2C2C
2C2C2D2D2D2C2C2B2B2B2C2C2C2C2C2C
252524242527292B2C2C2C2D2D3032343536373838373636
363A3D4042413F3F3F3F3F3F404244464748484949494948
494A4C4D4E4D4C4C4B4B4B4B4A4A4A4A4A4C4E4F51505050
504E4D4D4D4F515358616A73797A7A7C7E858C9093928F8D
887E746A6059524A443E39342F2925201D1A181615151515
171B1F23262625252525252424242323231F1D1B1D28333C
423F3C3B3834312E303A454F5B67737F88898A8C8E959B9F
A1A09E9B958B7F756B645E5753525251504C484543444546
45413D3A393B3E40413E3A38373737373736353434343434
353534343432312F2F30323334333231302F2E2D2C2C2D2D
2D2E2E2E2E2E2D2C2C2C2D2D2D2D2D2D
2727262627292B2D2F2F2F2F3032343638393A3B3B3A3938
383B3F424342414040404040414345464849494A4A4A4949
494B4C4D4E4D4C4C4B4B4B4B4B4A4A4A4A4D4F5152525151
504E4D4C4B4B4B4D515B666F777777787B838A8F9397999A
978C81766C655F57504B47423D362F2924201D1A17151414
15191D2023242425262524232324252626232120232E3841
474542423F3A353234404E5966717C878F919294959B9FA1
A19D98928A7D6F625854514D4B4B4B4B4B47454241434445
45413D3B393B3E3F403D3B39383839393837363535353535
35353535343231302F30313233323131302F2E2D2C2C2D2D
2D2E2E2E2E2E2D2D2C2D2D2D2E2D2D2D
2A2929292A2C2E303131313232343637383A3B3D3D3D3C3B
3C3F4244464544444343434242444648494A4A4B4B4B4A4A
494B4C4D4D4D4C4C4B4B4B4B4B4B4B4B4C4D4F5051515151
504F4E4D4D4D4D4E515860676D72767A7E808183858B9194
948D857D76726E68635F5B57524A423B35312D2925201C19
181A1C1E202123242523201F1E212426292A2C2E3135383B
3C3B393938353333374655626F777F878C8C8B8A898C8F90
8F8C88847E756B625A56524E4C4C4C4C4C49464442444546
4644413F3E3E3F3F3F3D3C3B3B3A3A3A3938373636353433
333333333231302F2E2F2F2F2F2F2E2D2C2B2A292929292A
2A2929292929292A2A29292929292929
2D2D2D2D2D2F31323434343535363738393B3D3E403F3F40
404345464848484847464544444648494A4B4B4C4C4C4B4A
4A4B4C4C4C4C4C4C4C4C4C4C4C4C4C4D4D4E4F5050505051
50504F4F4F4F505153565B5F646D747C807C7977777F878C
8F8B8683807E7C7875726F6C675F564F48433F3A342D2722
1E1D1E1E1F21232526221E1C1B1F23272B32383D403C3835
32313130313132353C4C5C6A777C81868885827E7B7C7D7D
7C7A7875726D68635E5955504E4E4E4E4E4B484645464748
484745444342413F3E3F3F3E3E3D3C3B3B3A393837363433
32323232323130302F2F2E2E2D2C2C2B2A29282827282828
28272626262728292928272726272727
30303030313234353637373839393A3A3B3D3F4142424343
444648494A4A4B4B4B4948464647494A4C4C4C4D4D4D4C4B
4B4B4C4C4C4C4C4C4C4C4D4D4D4D4E4E4E4F4F5050505151
5151515150505051525356585D68727B7F78716C6B768188
8E8C8A89888888878584827F7B72696058544F4942393029
2321201F1F22242728231E1C1B20252A303A424A4D443A33
2D2D2D2D2F313539425364737F82838585817B767171706E
6D6B69676563615F5C5855514F505050504D4B4948494A4B
4B4B4A4A48464341404142434342403F3E3D3D3C3B383635
33333333333333323231302F2E2D2C2B2A29292928282829
282726262527292A2B2A282727272727
34343434353637393A3A3B3C3C3C3C3D3D3F424345454647
48494A4B4C4D4D4E4E4C4A4848494B4C4D4D4D4E4E4E4D4C
4C4C4C4C4C4C4D4D4D4D4D4D4E4E4F4F4F4F4F5050505151
5252525252515151525152535764707A7F766C66646F7A81
8889898B8D8F909090908F8D8981797069645F5952483E36
2F2B282625282B2E2F29242221252A2E34414C565A4C3E34
2C2C2F2F32353B414B5B6B7983848383807B756E68666461
5F5D5C5B5A5B5B5B5A57545150505151514F4D4C4B4B4C4D
4D4D4D4D4C4946434243454647454443424141403F3C3A38
3636373637373738383635343231302F2E2E2E2E2E2E2E2F
2E2D2C2C2C2E31333432312F2F2F2F2F
39393939393A3C3D3E3E3F40404141414244464748484849
494B4D4E4F4F4F4F4E4D4B4A494B4C4D4E4E4F4F4F4E4D4C
4C4C4C4C4D4D4E4F4F4F4E4E4E4E4F4F5050505050515152
52515151515150515150505155626E797F79736F6D717577
7B7F8286898B8B8C8D8D8D8B89847F7974716D68635C544D
47413C3735393C3F403C3837353433333745535E6256483F
393B3E4043474C525A66717A81807E7D7A75706A65615E5A
57555352515050504F4D4B4A4949494A4A4A4949494A4A4A
4A4A4A4A4947444342434546474645444443434242403E3D
3C3C3C3C3C3E3F4141403E3D3D3C3C3C3C3D3E3F3F404041
4242424344474A4C4E4C4B4A494A4A4A
3E3E3E3E3E3F4041424343444545464647494A4B4C4B4B4A
4B4D4F51525150504F4E4D4C4B4C4D4E4F4F5050504F4E4D
4C4C4D4D4D4E4F5051504F4F4E4F50505050515151515252
52525151505050515150505054616D777E7C79787674716F
6E757B808585868788898988878684817F7D7A77736E6965
5F58514B474B4F5153514E4D4A443F3B3C4B59656A5F534C
474B5052565A5F646A70767C7F7D7A7874716D68645F5B57
53514E4C4B49484847464545454545454647494A4B4A4A4A
4A4949494847464544464748494949494948484847464645
4544444444474A4C4D4C4B4A4A4A4B4B4C4E4F5152535455
5658595B5D6064676968666665666666
4444444444454546474849494A4B4B4C4D4E4F50504F4E4E
4E5053545554535352514F4E4E4F5051515252525251504F
4E4E4E4F4F51525354525150505151525252525252535353
53535252525252525251505054606C767E7F7E7F7D756D66
646C757C8283838586878889898A8B8B8B8A888684817E7A
756C645D585C6062646361615E534A434252616D73695E57
53585E61656A6F74797B7D7E7E7B7774706D6966615C5753
4F4C4A4847464545444444444545454546484B4D4F4E4D4D
4C4C4B4B4A4A4949494A4C4D4E4E4E4F4F4F4F4E4E4E4E4E
4E4D4D4D4D5155585A595858575859595A5C5F6163646566
686A6D6F72767A7D7F7F7E7D7C7D7D7D
4A49494A4A4A4A4A4B4C4D4E4F4F50505152525353525150
5053555757565554535251504F5051525353535454525150
4F4F50505052535455545252515252535353535353545454
545453535253535454525151545F6A727A7E818483776C64
5F6872787E7F7F8183858687898C8F91929291908E8E8C8A
867D756E6A6C707173737374716459504D5B697379706763
60666C70757A7E82858483817F7B7873706D6B68645F5A56
52504F4D4C4B4B4B4B4B4C4D4D4D4E4E4F5356585A5A5958
57575756565657575758595A5B5C5D5E5F5E5E5E5E5E5F5F
5F5E5E5D5E63686B6E6D6C6C6C6C6C6C6D6F717375767779
7A7D8083868A8E929493929291929292
4B4C4C4C4C4B4A4A4A4B4C4E4F4F4F4F4F50505151505050
5051525354535352514F4E4C4C4D4E4F505051515151504F
4F4E4E4E4E4F4F505150504F4F5050515151515151515253
53525252515252535352515153595F646B737B81847C746F
6B6F7476797A7B7D7F818385888A8D8F908F8D8C8A898886
84807D7A787879797A7C7E7F7E766E6864696F7274706C6A
6A70767B7F8285888989888684827F7C7A787573716E6B68
66666666666666666768696A6B6C6E7071747678797A7A7A
7B7B7B7B7B7C7C7C7D7E7F80818283848584848484848485
8583838283878B8F91929292918F8D8B898B8C8D8D8D8D8D
8E919395989A9C9FA09F9E9E9D9D9E9E
4F505051504E4D4B4A4C4E4F50504F4F4F50505151515151
5151525252525252514F4D4B4A4B4D4E4F50505151515151
504F4E4E4D4E4E4E4E4F4F4F505050515150505050515253
535352525252535354535354555557595E6A767F86827E7C
797878777677797A7C7F8285878A8B8D8D8C8A8886858483
82838586868482818185898B8C88837F7C79767371717172
757A80868A8B8C8D8E8E8E8D8C8A8987868482817F7E7D7D
7D7E808182828384858687888A8D909294959697989A9C9D
9E9F9FA0A0A1A1A1A2A3A4A5A6A7A8A9AAA9A9A9A9A9A9A9
A9A7A7A6A7AAAEB1B3B5B6B7B6B1ACA7A4A3A3A3A2A1A09F
9FA1A3A4A6A7A8A9AAA9A8A7A6A7A7A7
555656575754514F4E505253545453535353535353545454
545454545454545453514E4C4B4D4F505152525353545454
54535150504F4F4F4F505151525252535352525252535455
56555555555556565757585959555352556575818B8A8787
85807C77747577787A7D818487898B8C8D8B898786858484
858A8F9395918E8B8B9095989A99969590867D757074797C
81878C92969695959494939292919190908F8E8D8D8E8E8F
919396989A9B9B9C9D9FA0A2A4A8ABAEB1B1B1B1B2B5B7B9
BBBCBDBEBFBFC0C0C1C2C3C3C4C6C7C8C8C8C8C8C7C7C7C7
C7C6C5C4C5C8CCCFD1D4D5D6D5CEC6BFBAB9B8B6B4B2B0AF
AFB0B1B2B4B4B4B4B4B3B2B2B1B1B1B1
6263636463605D5A585A5D5E5F5E5D5D5D5D5C5C5C5D5E5E
5E5D5D5C5C5C5C5C5C595654535557585A5A5B5B5C5D5D5D
5D5C5B5958585757565759595A5A5A5A5A5A5959595A5C5D
5D5D5C5C5C5D5D5E5F606162615B56535667788590929193
918B857E7A7B7D7D7F8286898C8E909292908E8C8B8A8A8A
8C939AA0A49F9A97959CA2A6A9A9A8A7A294867B757C848A
90959AA0A4A2A1A09E9E9E9D9C9D9D9E9E9D9D9D9E9FA2A3
A6A9ACAFB1B2B3B4B5B6B8B9BBBFC3C6C8C8C7C7C8CACDCF
D1D2D3D4D5D5D6D6D6D7D8D8D9DADBDCDDDCDCDCDBDBDADA
DAD8D8D7D8DCE1E4E7EAEBECE9DFD4CBC3C1C0BDBBB8B5B4
B3B4B6B7B8B8B9B9B9B8B7B6B5B5B6B5
81828383827F7B787778797A7A7A79797978777776777778
787776767575757473716E6D6C6E70717373747475757575
7474737271706F6E6E6E6F6F707070706F6F6E6D6D6E6F70
706E6D6C6C6D6E6F7072737475716E6C6E7A8690989A9A9C
9C9A97949293949596999B9EA0A3A5A7A8A6A5A4A3A3A3A4
A5A9ADB0B1ADA9A7A6ACB2B6B8B6B3B1ACA1978F8B939CA2
A9ADB0B5B8B8B7B7B6B6B5B5B4B4B4B4B3B3B3B4B4B6B7B9
BBBCBEBFC0C1C2C2C3C4C5C5C7C9CBCCCECDCDCDCDCECFCF
D0D0D1D1D1D1D1D1D1D1D1D1D2D2D3D4D4D3D1D0CFCFCECD
CDCCCBCBCDD4DBE1E5E6E6E6E1D2C3B6ABA9A9A6A4A19E9D
9D9FA2A4A7AAADB0B2B0AEADACADADAD
A0A1A1A1A19D9A9795959696969696969594939291929292
92929191908F8E8D8C8A888786888A8B8D8D8D8E8E8E8D8D
8C8C8C8C8B8A888786868787878686868685848382838484
8482807F7E7F81828485878889888787898F969CA1A3A4A6
A8A9AAABACACACADAEAFB1B3B5B7BABCBEBDBBBBBABBBCBD
BDBEBEBEBDBBB8B6B6BCC1C5C6C1BCB9B4ADA7A2A1A9B2BA
C0C3C5C8CACBCCCCCCCCCBCBCAC9C9C8C7C8C8C9C9CACBCC
CDCDCDCDCDCDCECECFCFCFCFCFD0D0D0D0D0D0D0D0CFCECD
CCCCCCCBCBCAC9C9C8C8C8C7C7C8C8C8C7C6C4C3C1C0BFBE
BDBCBCBCBFC9D3DBE0E0DEDCD5C2AF9E918F8F8D8B888585
86898C90949AA0A6A9A7A5A3A2A3A4A4
B9BABABBBAB6B3B0AEAEAEADADADADADADACAAA9A8A8A9A9
A9A8A8A7A7A5A4A2A19F9E9D9C9EA0A1A2A3A3A3A3A3A2A2
A1A2A2A2A2A09E9C9B9B9B9A9A9A9A999998979595959696
9593918F8E9092939597999B9C9C9C9D9EA1A4A7AAACAFB2
B5B8BCBFC1C1C1C1C1C2C3C4C5C8CBCDCECECDCCCCCECFD0
D0CECCCAC8C6C5C3C3C8CDD0D2CCC6C1BDB8B5B2B3BBC5CD
D3D4D5D7D9DADBDCDCDDDDDDDCDBDAD9D9DADBDBDCDDDEDF
DFDEDCDBDBDBDCDCDCDBDBDADAD9D8D7D6D6D6D6D5D3D0CE
CDCCCBCACAC8C7C6C5C5C4C3C3C3C3C2C1BFBDBBB9B7B6B5
B4B3B3B3B7C4D0D9DFDFDBD8CFB8A28D7D7C7C7978747272
73767B7F858E969DA2A09D9B9A9B9C9B
CCCDCDCDCCCAC7C4C2C2C1C0C0C1C1C2C2C0BFBEBDBDBEBE
BDBDBDBDBCBAB9B7B5B4B2B1B0B2B3B4B6B6B6B7B7B6B6B5
B5B6B7B8B8B6B4B2B1B0AFAEADADADADACABA9A8A8A8A9A9
A9A6A4A2A2A3A5A7A9ABADAFB1B2B3B4B4B4B4B4B5B8BBBE
C2C7CBD0D3D3D2D2D2D2D2D2D3D5D8D9DBDADADADADCDDDD
DDDAD6D3D1CFCECDCDD1D5D8D8D2CBC7C3C1C0BFC0C9D1D8
DEDEDEDFE0E2E3E4E5E5E6E6E6E4E3E2E2E3E4E5E5E6E7E7
E7E5E3E2E0E1E1E1E1E0DFDFDEDCDAD8D7D7D7D6D5D2CFCC
CAC9C8C7C6C5C3C2C1C0BFBEBEBDBDBCBBB9B6B4B2B0AEAD
ACABABACB0BECCD6DDDCD7D3C9B096806E6D6D6A69656363
65686D7279848E979D9B979694959696
CCCCCCCCCCCAC9C7C6C6C6C6C6C7C9CACBCACACACACACACA
CACBCBCCCBCAC9C7C5C3C0BEBDBDBEBFC0C0C1C2C3C3C3C3
C3C6C8C9CAC9C7C6C4C3C1BFBEBEBEBEBEBCBBBABABBBDBE
BEBDBBBBBABBBDBEBFC1C3C5C7C6C6C6C6C6C6C6C7C9CBCD
CFD2D5D7D9D9D8D8D7D7D7D6D6D7D8D9DADADADADADBDBDB
DBD9D6D5D3D2D1D0D0D2D3D5D4D0CBC8C5C3C2C1C2C7CCD1
D4D4D3D4D4D5D6D6D6D6D6D6D6D5D4D4D4D5D6D6D7D8D9D9
D9D8D7D6D5D6D6D6D6D6D6D5D5D3D2D1D0D0D0D0CFCDCAC8
C6C6C5C4C4C3C2C2C1C1C0BFBFBEBEBDBCBAB8B7B5B3B1B0
AFAEAFB0B4C1CED8DEDDD9D5CBB39A847371716E6C696767
696C71757C88939DA3A19D9B9A9B9C9C
C8C8C8C8C8C8C8C8C8C8C9C9CACCCECFD1D2D3D4D4D5D5D5
D5D6D7D8D8D7D6D5D3CFCCC9C7C6C7C7C7C8C9CBCCCCCDCE
CFD3D6D8DAD9D8D7D6D3D1CECCCCCDCDCCCBCAC9C9CCCED0
D1D1D1D1D1D2D2D3D4D6D8DADAD9D8D7D6D6D7D7D8D9DADB
DCDCDDDDDDDDDCDCDBDADAD9D8D8D7D7D7D7D8D8D8D8D8D7
D7D6D6D5D4D3D2D1D1D1D0D0CFCCCAC7C6C4C3C2C1C3C5C7
C8C8C7C7C7C7C7C7C6C6C5C5C4C4C4C4C4C5C6C6C7C8C9C9
CAC9C9C8C8C9C9CACACACACACACACAC9C9C9C9C9C8C6C4C3
C2C1C1C1C1C1C1C1C1C1C1C0C0BFBFBEBDBCBAB9B8B6B4B3
B2B2B2B3B7C4D0D9DFDEDBD7CDB69E8979767672716E6C6D
6E717579808C98A2A9A7A3A1A0A1A2A2
C9C8C8C8C8C9CACBCCCDCECFD0D2D5D7D9DBDDDFE0E0E0E1
E1E3E4E5E6E5E4E3E1DDD8D5D2D1D0D0D0D1D3D4D6D7D8D9
DCE0E4E7E9E9E9E8E6E3E0DDDADADBDBDAD9D8D8D8DBDEE1
E3E4E4E5E6E6E6E6E7E9EBECEDEBE9E8E7E7E7E6E6E6E7E7
E7E6E5E5E4E4E3E2E1E0DEDDDCDAD9D8D7D8D9D9D9D9D8D7
D7D6D6D6D5D5D4D4D3D1CECCCAC9C8C7C6C5C5C4C4C3C2C1
C0BFBEBEBDBCBCBBBBBAB9B9B8B8B8B8B9B9BABBBCBCBDBD
BEBEBEBEBEBEBFBFC0C0C0C1C1C1C1C1C1C1C1C1C0BFBDBC
BBBBBCBCBCBDBDBEBEBEBEBEBEBDBCBBBAB9B8B7B6B4B2B1
B1B0B1B2B6C2CED6DCDCD8D5CCB59D89787675716F6D6B6C
6E7174797F8D99A4ACA9A6A4A2A4A5A5
C5C5C5C5C5C7C9CBCCCDCFD0D2D4D7D9DCDFE1E4E6E6E6E7
E7E9EBECEDECEBEAE7E3DEDAD7D5D4D2D2D3D5D7D9DADCDE
E1E6EBEFF2F2F1F1EFEBE6E2DFDFE0E0E0DEDDDDDEE1E5E8
EBEDEFF2F3F3F2F2F2F4F6F7F7F6F4F2F1F0F0EFEEEEEEED
ECEBEAE9E7E7E6E5E4E2E0DFDDDBD8D7D6D7D8D9D9D8D7D6
D6D6D6D6D6D6D5D5D3D0CCC9C7C6C6C5C4C5C5C4C4C1BEBB
B9B8B7B6B5B4B4B3B2B1B0AFAFAFAFB0B0B1B1B2B3B3B3B4
B4B5B5B6B6B7B7B7B8B9B9BABABBBCBCBCBCBBBBBAB9B9B8
B7B8B8B8B9BABBBCBDBDBDBDBDBCBBBAB9B8B7B6B5B4B2B1
B1B1B1B2B6C1CCD4DADAD7D4CBB49E89797675716F6D6B6D
6E7174787F8D9AA6AEABA8A6A4A6A7A7
C0BFBFBFC0C1C3C5C7C8CACBCDCFD1D3D5D8DADCDEE0E1E2
E3E4E6E6E6E5E3E1DFDBD7D3CFCCCAC7C6C7C9CACCCED0D2
D6DCE1E6E9E8E7E6E4DED9D4D0D0D0D0D0CECDCDCED2D5D9
DDE1E5E8EBEBEBEBEBECEDEEEEEDEDECEBEAE8E7E6E6E6E6
E6E6E6E6E6E4E3E2E0DFDDDCDAD8D7D5D5D6D8D9DADAD9D9
D9D9D9D8D7D6D5D4D2CFCCCAC7C6C5C4C3C2C2C2C1C0BEBD
BBBBBAB9B8B8B7B7B6B6B5B4B4B4B3B3B4B4B5B5B6B7B8B8
B9BABABBBBBBBCBCBCBCBDBDBEBFBFC0C0BFBEBDBCBCBBBA
BABABBBCBDBDBEBFBFC0C0C1C0BFBDBBBAB9B8B7B6B5B4B3
B3B2B2B2B5C1CCD4DADAD7D4CBB59D897875736E6C6A686A
6C6E71757C8A98A3ABA9A6A4A3A4A5A5
B9B9B9B9BABCBDBFC0C2C4C6C8C9CACCCDD0D2D4D6D8DADC
DDDEDFDFDEDDDAD8D5D1CECAC7C3BFBBBABABCBDBFC1C3C6
CAD0D6DBDFDEDCDAD7D0CAC4BFBFC0BFBFBDBCBCBDC1C5C8
CDD3D8DEE2E2E2E2E3E3E3E3E3E4E4E4E4E2E0DEDDDDDEDE
DEE0E1E3E3E1E0DEDCDBDAD8D7D5D5D4D4D5D7D8DADBDBDC
DCDCDBDAD8D7D5D3D1CFCCCAC8C6C4C2C1C0BFBFBEBEBEBE
BEBDBDBDBCBCBCBBBBBABABAB9B9B8B8B8B8B9B9BABBBCBD
BEBFBFC0C0C0C0C0C0C1C1C1C2C2C3C4C4C2C1C0BFBEBDBD
BDBEBEBFC0C1C1C2C2C3C4C4C3C1BFBDBBB9B8B7B6B5B5B5
B4B3B2B2B5C0CCD4DADAD7D5CCB59D887773716C69676667
696B6E737A8795A0A8A6A3A2A1A2A4A3
B2B2B2B3B3B5B6B8BABCBEC1C2C3C4C5C7C9CBCDD0D2D5D7
D8D9D9D9D8D6D3D0CDCAC7C3C0BAB6B2AFAFB1B2B4B6B9BC
C0C7CED3D7D5D3D1CDC6BFB8B3B2B3B2B2B0AFAFB1B4B8BC
C1C9D0D7DCDCDCDDDDDDDDDCDCDDDEDFDFDCDAD9D8D8D8D8
D9DBDEDFE0DEDCDAD8D7D6D4D3D2D2D1D1D3D5D7D8DADBDD
DDDCDBDAD8D6D4D2CFCDCBC9C7C5C2C0BFBDBCBBBBBCBCBD
BDBDBDBDBCBCBCBCBCBBBBBABAB9B9B8B8B8B9B9BABBBCBD
BFC0C0C1C2C2C1C1C1C1C2C2C2C3C4C5C5C3C1C0BFBEBEBE
BEBFC0C1C2C2C3C3C4C5C6C6C6C3C0BEBBBAB9B8B7B7B6B6
B6B4B3B2B5C0CBD3D9DAD7D5CCB59E897873706B68666566
686A6D717986949FA7A5A3A2A1A2A3A3
AEAEAEAFAFB1B3B4B6B9BBBDBFC0C0C1C3C5C7CACCCFD1D4
D5D6D6D5D4D2CFCBC8C5C2BFBBB5B0ACA9A9AAABADAFB2B6
BAC2C8CED2D0CDCBC7BFB7B0AAAAAAAAA9A8A6A7A8ABB0B4
B9C2CBD2D8D9D9DADAD9D9D7D7D9DADBDCD9D7D5D4D4D5D5
D6D9DBDEDFDCDAD8D6D5D3D2D1D0D0D0D0D2D4D6D8DADCDD
DEDDDCDBD9D7D4D1CFCDCBC9C7C4C2C0BEBCBBBAB9BABCBD
BDBDBDBDBDBDBDBDBDBCBCBBBBBAB9B9B8B9B9BABBBCBDBE
C0C1C2C3C3C3C3C3C2C2C3C3C3C4C5C6C6C4C2C0BFBFBFBF
BFC0C1C2C3C4C4C5C5C7C8C8C8C5C1BFBCBBBAB8B8B7B7B8
B7B5B3B2B5C0CBD3D9D9D7D5CCB69E897873706A67656465
67696C707785939EA6A5A2A1A0A2A3A2
B3B3B3B3B4B6B8BABCBEC1C3C5C6C7C8CACCCFD1D4D6D8DA
DCDCDCDCDBD8D5D2CFCCC8C5C1BCB8B4B2B2B3B4B6B8BBBE
C2C9D0D5D9D7D5D3CEC7BFB8B3B2B3B3B2B0AFAFB1B5B9BE
C3CBD3DADFE0E1E2E2E2E1E0E0E1E3E3E3E1DFDDDCDCDCDC
DCDEE0E2E2E0DEDCD9D8D6D4D3D2D1D1D2D4D6D8DADCDDDF
E0DFDEDDDBD9D7D4D2CFCDCBC8C6C4C2C0BFBEBDBDBDBEBE
BEBEBEBDBDBDBDBDBCBCBBBAB9B9B8B8B7B8B9B9BABBBDBE
BFC0C1C2C3C2C2C1C1C2C2C2C2C3C4C4C4C2C1BFBEBDBDBD
BDBEC0C1C2C2C3C4C4C6C6C7C6C4C1BEBCBBBAB8B7B7B7B7
B6B4B2B2B4BFCAD2D8D9D7D4CCB59D8877726F6966636364
66686B6F7785939EA7A5A3A2A1A2A3A3
B8B7B7B8B9BBBDBFC1C4C6C9CBCCCECFD1D4D7D9DCDEDFE1
E2E2E2E2E1DFDCD9D6D3CFCBC7C3C0BDBBBCBDBEC0C2C4C6
CAD1D7DCE0DFDCDAD6CFC8C1BCBCBCBCBCBAB9B9BABFC4C8
CED5DCE2E7E8E8E9EAEAEAE9E9EAEBEBEBE8E6E4E3E3E3E3
E3E4E5E6E6E4E1DFDDDBD9D7D5D4D3D3D3D5D8DADCDEDFE0
E1E0DFDEDDDBD9D7D5D2CFCDCAC8C6C5C3C2C2C1C1C0C0C0
BFBFBEBEBDBDBDBCBCBBBAB9B8B7B7B7B6B7B8B9BABBBCBD
BFC0C0C1C2C1C1C0C0C1C1C1C2C2C2C3C2C1BFBEBDBCBCBC
BCBDBEBFC0C1C2C2C3C4C5C5C5C2C0BEBCBAB9B8B7B6B6B6
B5B3B2B1B4BFCAD1D7D8D6D4CBB49C8776716D6864626263
65676A6F7685939FA8A6A3A2A1A3A4A3
BBBABABABBBDC0C2C5C7C9CCCED0D2D3D6D8DBDEE0E2E3E4
E5E5E5E5E4E2DFDDD9D6D2CECAC7C4C2C0C1C2C4C5C7C8CB
CED5DBE0E3E2E0DEDAD3CCC5C0C0C1C0C0BEBDBDBFC3C8CD
D3D9E0E5EAEBECEDEEEEEEEEEEEEEFEFEEECEAE8E7E7E7E7
E7E7E8E8E8E5E3E1DFDCDAD8D6D5D4D4D4D6D9DBDDDFE0E1
E2E1E1E0DEDDDBD9D7D4D1CECCCAC8C6C5C4C4C4C3C2C2C1
C0C0BFBFBEBEBEBDBDBBBAB9B8B7B7B7B7B8B9B9BBBCBDBE
BFC0C1C2C2C1C1C1C0C1C1C1C2C2C2C2C2C0BFBEBCBCBBBB
BBBCBDBEBFC0C1C2C3C4C4C5C4C2C0BEBCBBB9B8B7B6B5B5
B5B3B1B1B3BEC9D1D7D7D5D3CAB39C8775706D6764616162
64666A6E7684939FA8A6A3A2A1A3A4A4
BDBDBDBDBEC0C2C5C7CACCCED1D3D5D7D9DCDFE1E3E5E6E7
E7E8E8E7E6E4E2DFDCD8D4D0CDCAC8C6C5C5C6C8C9CBCCCE
D1D8DEE2E6E4E2E1DDD6CFC8C3C4C4C4C4C2C1C1C3C7CDD2
D7DDE3E8EDEEEFF0F1F1F2F2F2F2F2F2F1EFEDEBEAEAEAEA
EAEAEAEAE9E7E5E2E0DEDBD9D7D6D5D4D5D7DADCDFE0E1E2
E2E2E1E1DFDEDDDBD9D6D3D0CDCBC9C8C6C6C6C5C5C4C3C2
C1C1C0BFBFBEBEBEBDBCBAB9B8B7B7B7B7B8B9BABBBCBDBF
C0C0C1C2C2C2C1C1C0C1C1C2C2C2C2C2C1C0BEBDBCBBBBBA
BABBBDBEBFC0C1C2C3C3C4C4C4C2C0BEBCBBB9B8B7B6B5B5
B4B2B1B0B3BEC9D1D6D7D5D3CAB39B8675706C6663616062
6466696E7584939FA8A6A3A2A1A3A4A4
BCBBBBBCBCBFC1C4C6C8CBCDD0D1D3D5D7DADDE0E2E4E5E6
E6E7E7E6E5E3E1DEDBD7D3CFCCC9C6C4C3C3C4C6C7C9CACD
D0D6DCE1E4E3E1DFDBD4CDC6C1C2C2C2C2C0BFBFC1C5CBCF
D5DBE1E7ECEDEEEFF0F0F1F0F0F1F1F1F0EEECEAE9E9E9E9
E9E9E9E9E9E6E4E2DFDDDBD8D6D5D4D4D4D7D9DCDEDFE0E2
E2E2E1E0DFDEDCDAD8D5D2CFCDCBC9C7C6C5C5C5C4C3C2C2
C1C0C0BFBEBEBEBEBDBBBAB9B8B7B7B7B7B8B9BABBBCBDBE
BFC0C1C2C2C2C1C1C0C1C1C2C2C2C2C2C1C0BFBDBCBCBBBB
BBBCBDBEBFC0C1C2C3C4C4C4C4C2C0BEBCBBB9B8B7B6B5B5
B4B2B1B1B3BEC9D1D6D7D5D3CAB39B8675706C6663616062
6466696E7584929FA8A6A3A2A1A3A4A4
BBBABABABBBDC0C2C5C7C9CCCED0D2D4D6D9DCDEE0E2E3E4
E5E6E6E5E4E2DFDDDAD6D2CECBC7C4C2C1C1C2C4C5C7C9CB
CED5DBE0E3E2E0DEDAD3CBC5BFC0C0C0C0BEBDBDBEC3C8CD
D3D9E0E6EAECEDEEEEEFEFEFEEEFEFEFEFEDEAE9E7E7E7E7
E7E8E8E8E8E6E3E1DFDCDAD8D6D5D4D3D4D6D9DBDEDFE0E1
E2E2E1E0DFDDDCDAD7D5D2CFCCCAC8C7C5C5C4C4C3C3C2C1
C1C0BFBFBEBEBEBEBDBBBAB9B8B7B7B7B7B8B9BABBBCBDBE
BFC0C1C2C2C2C1C1C0C1C1C2C2C2C2C2C2C0BFBDBCBCBBBB
BBBCBDBEBFC0C1C2C3C4C4C5C4C2C0BEBCBBBAB8B7B6B6B5
B5B3B1B1B3BEC9D1D7D7D5D3CAB39C8775706C6763616062
6466696E7584929FA8A6A3A2A1A3A4A4
BBBBBBBBBCBEC0C3C5C8CACCCFD1D2D4D6D9DCDFE1E3E4E5
E6E6E6E6E5E2E0DDDAD6D2CFCBC8C5C3C1C2C3C4C6C7C9CB
CFD5DBE0E3E2E0DEDAD3CCC5C0C0C1C1C1BFBDBEBFC4C9CE
D4DAE0E6EBECEDEEEFEFEFEFEFF0F0F0EFEDEBE9E8E8E8E8
E8E8E9E9E8E6E4E1DFDDDAD8D6D5D4D4D4D6D9DCDEDFE0E2
E2E2E1E0DFDEDCDAD8D5D2CFCCCAC9C7C5C5C5C4C4C3C2C1
C1C0C0BFBEBEBEBEBDBBBAB9B8B7B7B7B7B8B9BABBBCBDBE
BFC0C1C2C2C2C1C1C0C1C1C2C2C2C2C2C2C0BFBDBCBCBBBB
BBBCBDBEBFC0C1C2C3C4C4C5C4C2C0BEBCBBBAB8B7B6B5B5
B5B2B1B1B3BEC9D1D6D7D5D3CAB39C8775706C6663616062
6466696E7584929FA8A6A3A2A1A3A4A4
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["Here we do the wavelet packet decomposition of the picture.", 
  "MathCaption",
  CellTags->{"S2.2.1", "1.23"}],

Cell["\<\
wpdata = WaveletPacketTransform[data, s4, 3,
BoundaryCondition -> Fixed];\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
Compared to the wavelet transform, the wavelet packet transform \
decomposes some subspaces further.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.24"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition2D[wpdata, AspectRatio -> 1]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.02381 .2619 L
s
.2619 .5 m
.2619 .02381 L
s
.97619 .2619 m
.5 .2619 L
s
.7381 .5 m
.7381 .02381 L
s
.5 .7381 m
.02381 .7381 L
s
.2619 .97619 m
.2619 .5 L
s
.2619 .14286 m
.02381 .14286 L
s
.14286 .2619 m
.14286 .02381 L
s
.5 .14286 m
.2619 .14286 L
s
.38095 .2619 m
.38095 .02381 L
s
.2619 .38095 m
.02381 .38095 L
s
.14286 .5 m
.14286 .2619 L
s
.02381 .02381 m
.02381 .97619 L
s
.5 .02381 m
.5 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
This is the density plot of the wavelet packet coefficients. Note \
that unlike the case of the output from wavelet transform, the residual trend \
is not normalized separately. The white area at the lower\[Hyphen]left corner \
shows that the trend has much larger coefficients than the details.\
\>", 
  "MathCaption",
  CellTags->{"S2.2.1", "1.25"}],

Cell[CellGroupData[{

Cell["PlotCoefficients2D[wpdata]", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00372024 0.0238095 0.00372024 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.20982 -0.0125 -6 -9 ]
[.20982 -0.0125 6 0 ]
[.39583 -0.0125 -9 -9 ]
[.39583 -0.0125 9 0 ]
[.58185 -0.0125 -9 -9 ]
[.58185 -0.0125 9 0 ]
[.76786 -0.0125 -9 -9 ]
[.76786 -0.0125 9 0 ]
[.95387 -0.0125 -9 -9 ]
[.95387 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .20982 -12 -4.5 ]
[-0.0125 .20982 0 4.5 ]
[-0.0125 .39583 -18 -4.5 ]
[-0.0125 .39583 0 4.5 ]
[-0.0125 .58185 -18 -4.5 ]
[-0.0125 .58185 0 4.5 ]
[-0.0125 .76786 -18 -4.5 ]
[-0.0125 .76786 0 4.5 ]
[-0.0125 .95387 -18 -4.5 ]
[-0.0125 .95387 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.20982 0 m
.20982 .00625 L
s
[(50)] .20982 -0.0125 0 1 Mshowa
.39583 0 m
.39583 .00625 L
s
[(100)] .39583 -0.0125 0 1 Mshowa
.58185 0 m
.58185 .00625 L
s
[(150)] .58185 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(200)] .76786 -0.0125 0 1 Mshowa
.95387 0 m
.95387 .00625 L
s
[(250)] .95387 -0.0125 0 1 Mshowa
.125 Mabswid
.06101 0 m
.06101 .00375 L
s
.09821 0 m
.09821 .00375 L
s
.13542 0 m
.13542 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.24702 0 m
.24702 .00375 L
s
.28423 0 m
.28423 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.35863 0 m
.35863 .00375 L
s
.43304 0 m
.43304 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.50744 0 m
.50744 .00375 L
s
.54464 0 m
.54464 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.65625 0 m
.65625 .00375 L
s
.69345 0 m
.69345 .00375 L
s
.73065 0 m
.73065 .00375 L
s
.80506 0 m
.80506 .00375 L
s
.84226 0 m
.84226 .00375 L
s
.87946 0 m
.87946 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.99107 0 m
.99107 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .20982 m
.00625 .20982 L
s
[(50)] -0.0125 .20982 1 0 Mshowa
0 .39583 m
.00625 .39583 L
s
[(100)] -0.0125 .39583 1 0 Mshowa
0 .58185 m
.00625 .58185 L
s
[(150)] -0.0125 .58185 1 0 Mshowa
0 .76786 m
.00625 .76786 L
s
[(200)] -0.0125 .76786 1 0 Mshowa
0 .95387 m
.00625 .95387 L
s
[(250)] -0.0125 .95387 1 0 Mshowa
.125 Mabswid
0 .06101 m
.00375 .06101 L
s
0 .09821 m
.00375 .09821 L
s
0 .13542 m
.00375 .13542 L
s
0 .17262 m
.00375 .17262 L
s
0 .24702 m
.00375 .24702 L
s
0 .28423 m
.00375 .28423 L
s
0 .32143 m
.00375 .32143 L
s
0 .35863 m
.00375 .35863 L
s
0 .43304 m
.00375 .43304 L
s
0 .47024 m
.00375 .47024 L
s
0 .50744 m
.00375 .50744 L
s
0 .54464 m
.00375 .54464 L
s
0 .61905 m
.00375 .61905 L
s
0 .65625 m
.00375 .65625 L
s
0 .69345 m
.00375 .69345 L
s
0 .73065 m
.00375 .73065 L
s
0 .80506 m
.00375 .80506 L
s
0 .84226 m
.00375 .84226 L
s
0 .87946 m
.00375 .87946 L
s
0 .91667 m
.00375 .91667 L
s
0 .99107 m
.00375 .99107 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.20982 .99375 m
.20982 1 L
s
.39583 .99375 m
.39583 1 L
s
.58185 .99375 m
.58185 1 L
s
.76786 .99375 m
.76786 1 L
s
.95387 .99375 m
.95387 1 L
s
.125 Mabswid
.06101 .99625 m
.06101 1 L
s
.09821 .99625 m
.09821 1 L
s
.13542 .99625 m
.13542 1 L
s
.17262 .99625 m
.17262 1 L
s
.24702 .99625 m
.24702 1 L
s
.28423 .99625 m
.28423 1 L
s
.32143 .99625 m
.32143 1 L
s
.35863 .99625 m
.35863 1 L
s
.43304 .99625 m
.43304 1 L
s
.47024 .99625 m
.47024 1 L
s
.50744 .99625 m
.50744 1 L
s
.54464 .99625 m
.54464 1 L
s
.61905 .99625 m
.61905 1 L
s
.65625 .99625 m
.65625 1 L
s
.69345 .99625 m
.69345 1 L
s
.73065 .99625 m
.73065 1 L
s
.80506 .99625 m
.80506 1 L
s
.84226 .99625 m
.84226 1 L
s
.87946 .99625 m
.87946 1 L
s
.91667 .99625 m
.91667 1 L
s
.99107 .99625 m
.99107 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .20982 m
1 .20982 L
s
.99375 .39583 m
1 .39583 L
s
.99375 .58185 m
1 .58185 L
s
.99375 .76786 m
1 .76786 L
s
.99375 .95387 m
1 .95387 L
s
.125 Mabswid
.99625 .06101 m
1 .06101 L
s
.99625 .09821 m
1 .09821 L
s
.99625 .13542 m
1 .13542 L
s
.99625 .17262 m
1 .17262 L
s
.99625 .24702 m
1 .24702 L
s
.99625 .28423 m
1 .28423 L
s
.99625 .32143 m
1 .32143 L
s
.99625 .35863 m
1 .35863 L
s
.99625 .43304 m
1 .43304 L
s
.99625 .47024 m
1 .47024 L
s
.99625 .50744 m
1 .50744 L
s
.99625 .54464 m
1 .54464 L
s
.99625 .61905 m
1 .61905 L
s
.99625 .65625 m
1 .65625 L
s
.99625 .69345 m
1 .69345 L
s
.99625 .73065 m
1 .73065 L
s
.99625 .80506 m
1 .80506 L
s
.99625 .84226 m
1 .84226 L
s
.99625 .87946 m
1 .87946 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .99107 m
1 .99107 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FF00FB94108CA1782DFF1DFF5D7F00
0000FFFF00FF245C9FFF974B808200FFFFFF5F91A837CFD1
4C779267A1839A77D80069FFFF36648C908862879B57725B
FF32EE8FDC7DADC092A658CE047B7E9300FF00FFFF12E4FF
75418F749781A56E0026A96DA55C9B5267B480927E895E71
8955DF7D8FB57A9C737F797B6A9C5650847C7885546C886C
AF5B457C7574637E7B608A6A88845985778475776B2F7820
D81E682E8E9A7B93488AB75F9A6261887B94A191548787AE
5B918E7E8177708A7784846C63CA000000802357506B5773
5E47876A5C6E77867C837E8191805CE1
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FF009AB7607C22AF005F00FF00FF
FFFF00FFFF56FF0000C952981C00FF00571DB79977728475
8D6A91C2002C53F900FF6D00009B87FF7CAC828E5965CE77
6EAAF600A5B0716B8FA05866FFC5AC00FFFF00ECFF48C2CD
5671985D92FF00FF4558B3C079AA8B91758F78976E8D8993
9F32DB8AA57DC8C0767491717B7E7C86A493834F8D82A600
0067AC6C598285685D916EA585809686918795758D986DD2
624951C987B244AD4FA5A17C807F7E858786828D667869A9
578590B7776B978149645EFF00F81021C3A3A4A8ACA9749B
6724D5938B868978827E8492867B96CA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF53FF4D2441B10000FF9200FF00
00FFFFFF79A9D0E66E000400FFFF00FF3EC985C183C0757C
5E417FB3FF730000FF00F5AB439EAE9FB6AB7948E8807F49
002D30C500C06564803AFF00FF00FFFFFF0000C325AA94A5
9DBF8EFF00FF5E97516841847092AE7D7887378292CF6A81
5B5A6DC4C75DC4A4BD9086817E7C6C60142CA5AE00BFFFC6
56215AC9DCD24283717B626F9B897A8884967CA475676C56
9BA843A26ABB353E875148908C9D88834C8B988080649D99
AE595AA180598BFFFFFF00FFFF8FD1700051927C9A82A17E
B696828B98827477A781868A93776B71
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00054F007600FF7E00FFFF00FFFFFFFF
FFC934498C6495E6FF00FFFF0074FFFF00468F401F94A876
ABFFFF000FFFFF0000FFE7969A7085921213E7E8AA005D9D
0024875100C000EBC0000000FFFFFFFF3FFF847086717156
FFFF00FF200887742D769A7F93A29A4F8765AB907C76686D
82A22B6468A28FA46C795C7F8B7E67ADFFFF9A570E880093
91FF857A79AEF89D918B6C8E63816DA2967F9879868C7DAF
828FAA69CE93807A73785C88817C986E8C8CBE816A81946D
6B80FFC85E8F01FFFFFF00CB37AB598D876F75B4B04C9D4F
68669271777D7B7F7999AB7321E77791
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000DBC600550000FF00FFFF000000FF
4AFFBE0098866782FFFF00002B860400B9C5C79B8E8B00CA
00FFFF6AFF0081FFD593687F70896ABB8FFF0027768B4C5F
DAE6B2999BF323FFFF000800FFB6EE00006062FF8C778354
FFFF0365125F307D436C7D9C3A2BA3D45C8A7B7F808B7781
82A35A37A1915E65AA79FF718799306B0F4FC5DAA1779C61
782C7A4851AD7F5EBE8D9C55887B7D9E6BFB75872A716EA8
CAAF47986ED560D46D734C75956B6C69A6759C9BD04D92C1
0000FFF8208A1D00367200FFEA56B3965B7955546A686E96
7F9B9C85748C897F64001B0C6289568B
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF3DFFE28AFFFF0000FF0014FFFFFF
000000FF4BC3A400FF00FFC1FFFF22BAB5854A819A79E700
005593B40CFFFF002E896C7E8F8A8C50A400FC8C81A4B086
4833B61954FFFF75FF0000FF70EA00000000D58BA4C89CFF
FF5C6FAB2E3DB02C5C75724AC46E7B7ACB9B98BD74986A86
8540B15E9058A9BBA3002DFF62458E5020A5CE47797BA49C
657C8C817897608946647E89848A817CCE0000568BA27D7A
8A64356E7E8368D575947928845F7A727B739C8563FF00FF
6D0B437EFFFF000000008FC12C69D8526A938A71949A8D86
667E4376788297CC21003949CE758477
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF7600FF78FFFFFF00FF330000FF000000
00240000FF6C83D200FF4CFF006BFF0B187DAF62914A4EA6
9FFF0061B7AB00FF739E7B3EBD999FFF22B3335A9166A599
0000002700CA97ABA400000C0000FFFFFFFFE4F4968C55FF
00C139AD9C0046CA8689B29E827CA83964839A8F637C8280
5B828F9D9ED27D62F5BCD610FF8EFFFED88594763182926F
7E869486849772609D5E85947A6298B1B62FA064646B80B5
B47E8C865C62896354FF848688CA667DBE5C43B038FF003A
BF50E70EFFF971C0BE9EB365406C86707B808F7875A26F8C
E67B846884CB0663E578CF7A5C4C6D9D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF7D2C008C217D3950FF0000FF0000FFFF
FFCDFFFF329200009A3500C711DF203395A37A65AAB09252
840059EB64006E7962EDA7836F7EA400A1836C9DCA98893E
00007A47DAFFFF965B0056476E10FFFF22FFD97B606BA1E6
8FB35582FF05B1FF7D785C968B745B6CA85668DD9E817183
CA597B996E00FFFAA25569934B6064365E73615A7F9A6E7E
778E8C936BA2559CD9868346BAAB5F706AB0828181676289
D0B18A909189829FCB7A7A90B0BE59CF2F760000FF9F1DEA
564272787F9D6B5A87677E6887777A7F9C7D996E8B89715D
F09813FF00DF7C3085B89A9D625CAB9A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF54FFFFFFFFFFFF3B0098C63D00500000
00000000C47CE56AFF3500F6E856FAFF2197BBA1FFAF886A
27FF9E4A3393623B0053889C585681FAF1899A7791C9B67E
00009B5938CBD0AD5BD7913B230F0041FFC6B28362727F00
00FFD260E46B6FE79C769067AC558D5287D05D5579799949
6A57FDFF319F2A437D72657D8AB479498B9A7B8580938D8D
7D79739D7C6592AF6F527CE92F6276558443246E839D607C
CDB16D99506A626CABB3827B6AFF00CD657CDCFF1676C480
9053707CB1D0658F85627A818D62747B6F7B7D87775F9C1E
6CCB00FF2FA526B1788D7BB2A63888AE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA00083FFFFFF0028FF00539AFFFFFFFF
FFFFFFFF53CB1CFF0044501BB4E934007F637AC47763826B
AA76735F6E3B00D2FFBE9A71839B7C0000F6A777519E6979
00A45800003277FFFFA57B3A47000000FF7F91854F2F8324
00C5F991682957558A94A76E6C8F7C7FA1715C6E977A00FF
42C67FFFFF002A9A4B66778165B292BA7B985BA687886C8A
57778770A9975FA282A1A2348555A4928E79B9557A785C8A
8A75805E9D74C96FC3829B74A39F0CFFFFFF20D8F05C4BFF
799F869D872D66C03862834863817AA4A5A874A1964985AF
FC5A7255885E8596BA93798F5A804A95
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FF99FFB47700FF0021
0024006CFF329C00FFCE91AC3F008800FF98988B90BC7777
76A7888099CCFF062D85598865009D75F932CA837C4F566C
00F9B3108AB06D65FFAF821C6A007A00C9864ACF58008F62
9600B05BC6903F8E7A8263786F7E785E876C9B8F887C6B9E
8780356900E780569873926A705C5E756A6892898E7D6D85
8776799A689C7396675E9F817E488B899A6F83655C8D8184
9B8B8371A994988F73646D94555BB24BFFFFFF7FDC00C57E
9CB06F6C5758FFFFA8DE8FC4A05BC074917C9C7D8677FFDA
2B566C73B58EB0AB6B9779A2739F9B81
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00646FB8BCFFD2000900FFFFFF00FF00
A200FF2F0061867C08F900FFDBFFB9FF449BA89D358B9277
98114A3C6D3B3BF377549B6E8AC86B8D72A56960569D3A7C
54DCF308FFFFE8B4918FDF5E80805A8C54A979E0EAA67889
63913A4D6E4249E06D6B786ABBA48F437D76425B8B538296
00D9525F5AB46F9D5867815882A38A85CAA070AFB6667BAC
7D898A7482BA754F9D9DAFBF6878596A535A898D8E8D7329
6F596880AD8E7C706C824A94B18DB46F95328DEF4C9A5B81
899C7A62152400514E967975669768986F94A179698A8DFF
6A646B6FBB7A88BE7A5C6F4D71977E59
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF83FFCFFF63FFEFFFFFFF8900FF00FF
08EC0000FFC67E8B6D4FFF004A009157FF8A97857E794881
7196FFFFFCE7806A8A82001B7E897E7AA47B9787608D8578
4FBF81169A4DA2FF53B50000FF00389F54B3FFFF4A327D7B
696E513FF3337BD0B28E81737C848E958BA68CBD7CC5778A
A858EB31D05F8183A775B4AB894E8C8DA17A778E8AA0608D
7F97A4766D81A36F56926E748F5AD88C906B418D66858E50
83617B8680A96C5F788A5D757B9395B04D86880057A0519F
786300001B007E8A7782838681C44274699E6186568900FF
559181666D7756393B4A88551E7B407A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00E2E378000000D800FF0000FF000000
60FFFFFFBDFF4C5B4B83506DFFFF2900717D44C356589484
C3A50000FF0C645B64F54E17D4556B74507257A5A58B5A94
8FEC4600875AFFCE2A0000F0FF0000FF7000FFFF008C9379
5E699691CA1F7250798AA295889CA4CF7981794E82687A81
A14F60FF68886D57548858005132787BA35C8A85837E5757
778A9EB08D7F006E8E3D8092897D8284A1A663A1748B618E
394F7A5B74777C989D6A836C4B4F8E577B370C5B6272386C
5F0000B1FFB6FFFFB7A4AD86404C746A6D7884417A70007F
5F71706D7B6E7E865C66755F4A93706D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFB4B3B833FFA1FF000000000000FF
B2000000003FB986A0880000FF008FCB6D90B74DBE8D7A5C
0000FFFFFF00A36450240046B34D95618188588770A7ADC4
986C1772B263FB000032FFFFFFFF7D685CC1FFFFFF36A67F
9780C9FF008871FDBAA9656061777BBA3783C471848A759F
7AAFE9999266986D8F8BFFB5CE93866E8F628AAA5E8C7168
888E80839468AB7C87836E91747A9C897A8C9D7695AA7984
677C916E8C61917F5E8776B0727B6479A66AF746774D7285
82AE98FD40FF86FFB0199D9D696495B2C58875808E0028A8
A77575A98C5A48904E6D756D85527391
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF007AFF97FF4EAEFF946EFFFFFFFF1800
0F76FFFFFF2A64008A7B7EFF00FF4C640D7BAEAB6B3B6942
94A84F2578FAB24B73B3F9FBDA756979A49E87A89CC4A284
CC0013F89FF4F200B2C8FFFFFFFFFFBCEEFFFFFFB8AF6786
7E76977031704D688B85B8789E8C956E8E7B945C507E688F
787A584E8B8B9AA378854425458E74CE6B843D6B57937685
968B7C767E7F7A60A49E75A97C9C856F65B99184719D8262
B699719391AE664F7D7CA68D9C81675D807C3E1B86A46E68
876B635891FFCAFF77469386718C6A8283866A7C835F88B4
75667C695B727B61828931708C6B8CC3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFAB5121000095000000FF540000000000
B6FF583296866C9E86875400CA0000003B4B4D8D9EA2645A
798000001F3146538819116053767B7073818D67826D9F6A
002B8CC4A3FFFFFEFF4274008E978DDF9D545F755F7195BA
70966D7864DD71BF68565C4D8B74659B664D727E69707278
7C946CA3686183567C6791A972577A285985408667756868
6E657F807A967B5A69625D828D7590844C645E4983B78C5E
D49F8D8F7F6550947B617393415C7EA88C8E4E7753918A7D
5CB1A16DAD80A67569B297918987695D857E7A7F7C8E7785
A1696C5A994B727D56864D70614C3C72
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00FCFFFFFFFFFF
474D5B00D2A58F948F8C7D974DDCFFFF75A6A6649270CA68
61E9A8F7BFBCAB8B839078C25C6B6580928596877F8561D6
610581F05AFEFF3300FF604285939C7E718C9496646E8465
70757585A6FF7EFF766894844F827A788F71947E9E853877
82A3957C82907080907A8E61ABBC837B8EB775808C596A3C
95467E7E7F73717E836185778B889C7567795A82A067887E
746E6B448E878A92614E9576716B4FAF62908D5482A07E7E
577DAE78001C66C2925A6D754DA09A646C568D7C7E766709
977B7C7A71797C5A65318B8066971F72
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF442823FFAEFFFF1300FF2417D07F0F76
62F9D7FF2C6F7FA58F94679649FF5012858BBD7A1D8A8388
876F75C16F6F5F62ACBF5873A27EB480775B806331BF9078
D1171F0DEE9EA153FF36B4A4D4E591434F89534959937181
81859492DB38477A8D825570747A7B6850794B73758BAD69
45994B87895A978F836C792F002D3370967C626A77567A8B
5A636E807D816F7671918D93A56C6C4775A4468088697656
1C5C8A587CA26E6A89575E727C56496A6B5168618B95907C
9A697DFFFF170092964642544F7F7E8F7A75767F7C7F4200
FF3A779CC3994D5C9EB3717E888C786A
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF8D95FFB0942CB3FFFF00FF2C00FFFFFF
C9EED8006D66B0559E7C9275DD77000008617BA8A7B9C986
D80C624C3EA3C4845F664A99979B6D914D806E7A99755A98
001C5C4A6D70F3836900A2FFFFD3808398C173FDC7797EC4
AC84B56B8A0E62FF606790A34D978C4957718B617F7A69B5
B5876D8F87839589747797FBFFBCBF8756688BA27EA69978
7CB1797D7E839EFF87A36A5EB8639B828D7E75A381A59F8B
7A84807576687A3A7E5A747C818A6498818C707A8C939388
656B79BEFF708B67D9967A5072627F98AD60827F807187D2
A8A039749CA75E558464916771687299
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF3FE35A813713210000FF5466FF000000
000000FFD2D5A0A1709850A500CB9DE56F8E81514E7EA898
FFE98FC0FD8900003577478D9C4C744A7A669F8F3A3897A1
FF5521A885A8FF3DFFFF00AF00FFFFFFFFFFFF93797D7B78
868563C900A9BD7B8A7C5AA26C74882C707B8D8C9BB29F70
736B8180698085897B7C9436035E4982625D8A774B356B8C
75537D817F6A796C7B8271916A5F807F8B854F869AB655DD
BDD74B8567897F606D6862A69497AD6D7C784F697C7A8C77
907A77555A976C977276457DB295809E75C9AE688183715C
7BA24C7B7B917E709C858781949B9DC7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA7FFFFBEFF00FFFFFFFFFFFFFFFFFF
FFFFFF287F866D7876621700A18D70683646525089873CFF
A9471700008AFFFFFFFBCE94B17F86926F7B51D797867890
2200005FD500FF00230000000000FFFFFFA7B1886D548774
6B57DF0940B3394919578467973D615B6C6B777B676D8470
46A2647A8A9A87528E8F67748F769F8782766A79958EAA88
738756748378776C6D79AC6DA7747B5C7A6A866E86609147
C4AD84838A908E71928485786437939D8B4E748257354C6A
5D7586738172A478A28279685B534B66A7898875727F7D86
886E795A987899C277888FA57AA26B73
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFB053734D6B29FFFF0000000000000000
000028896B6C76617E12FF55600000BC43878B78763657F6
5682B7FF8C845C273879807A70978F966A6AC64F5F7FBC70
A7DDB980FF953B0000FF63FFA9727FB189848995A1A977CB
CEFF41E1FFD6D276E6BD6F986F877D62A981535C736E7F4F
8AA4898A88A18A7F7D6F85AA645E8182C87BAB8E8C99A996
A177AE86697CA88897AA92CB825774947B5E6896A78A5AAA
FFB6616C3EB47EA78E879D8C8E937D7C61D0A18181828FB3
63648293B79493897A3FA9697A656282C0D1887A72826F73
8F807480897C718362A16D8995C89089
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF756FAB2300000000000035000D4E8E73
4F85806E4E7C51662700008C74109D13E6A6C59CB46F82F8
003F8668747883927693918F839C9296AFB4007448565C6D
A1D9AEC4EFCA8EFFD3FF0082B67B9BB98B95888B7E948495
58FF71FF7698AD777B6C586AAF5D5C99A383925699785072
85718271A090868E7D947D687477815E876D6C6F84528C5E
85A17D77817B8D68AD7B74677EAF789079997C876D63A93A
794A58796BB7926B6364BD635983789392B19580906A6382
7F809264859E43148070CC7B9F87AD7F93A8877F7E7E7E93
6AA58F45426D628D6D954F989232794E
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC2D69AB19BFF00FFFF3700662B72
4D8A4A2342636700FFFF00FFFFFF6D6E003A68A4A6817145
4CFFB0293BA4795C4D64714A7C755F240070AF6165778463
83738892F08A80C4A7FF00FFE841857B9B8591AF755E97FF
FFB7FF874114706A838964747E55B665A4844F83768B806A
879C7D867D789569998F71947168A5796B6D6BB78359C79B
60736C7E7E7D8090A28A7E65726F6682627265607C55555A
5A5E637B719A686F5F6A78796B7A6D5960558E7F71721C00
46BF726A89696C776979A0B26C3DB3A38CAB70807E817B8F
428F8C8C7C7E65A064A66580798B8C6D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF002C881D62FFFC72CCFF0080FFE11B78
769887A9FFF600FF0000FFA4E8FFFFA9988E5B63638676B1
9D6011FCEE0064674E6A546B3D9E74FFED00009CC38D6774
6E746C834B166A2376AE00FF00FF903E6CBF87FFC900FF00
FF182E7F886A1B6638669E6E6B8B9E868391E485B4705190
889E64907F846E225772AB976D975E9BB5807F8CAE405649
73778C7B7A7E7E76B29E8AC2598A9B6B67538075A9877157
1043868C71835B60768B8E7C7B606A607F4E8A9E8E5D0000
005A005796806E7D8D819BFDFF7C7B656D7C7B888776838C
9B8F80848B5B80BC9D7C5F3D6B995FBD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF006500270014FFA050FF00FF0000FFFF
FF002E46008EFF00FFFF008B005542676C5F509740000963
39FFA8FF00FF00612ADC5500AF009A00214F5C734D0E5B74
4B6D7A07000063747FFF00FF00FFFF000000ED7958350000
00FF2B84A545558E937371795E997C6A44957F91909F756E
A56870756178782EB087497D8387A66D527F9F767EA5AC72
56957D6F6E638A6B91978A8D7363958986738B85677DB79C
B9AC7B4A9C918E894D9A939F6571739D4B5A6294FFDF0000
005100E5A1949FAE877DA47E736B6D6D985B6E777C688172
72796C4A83608972577485824FA78893
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF148FE9580000895412FF0000FFFFFF00
0083FFFFFF0000008E000C0000000000B8824A445BF95E54
92ED5200FFD98BBC00889CA6FF00002A31329C678A787264
E0BE6B454A44BCB9F9E5DCFFFF0098FFFF00000000FF0000
8EC81F757DA3C2A38C8B5F787F5F8A657D837B746D7D8D61
56888D80C3363EA48E7CC0A968787B9B77988B855558773C
A98DA2B3798192959385929D869982AD66689CC68F775BA0
7689A6AB6D735D63458A6D5D776F789838678FA272C02A49
45FF31A88F5D7A8F507660736CAAC34CAAA78833828F4167
7F8D858582A585907E6E69A198C79D97
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000000000FF000000FF
FFFFFFFF00FFFF0000FFFFFFFFFFFFFF355869774D355163
34866D4629003BEFFF00FFFFFF00AEFFD8767B7C95FFFFFF
FFFFFAFFFFFFFFFF8AFFFF121FECFF0000000000FFFFFFFF
FFFF570000000000315F6D9776486D787FA4988854648E56
9B7287955ECB8BB13FB279968B7F828D887F7361B1D0BB84
C3778599707CA6A77C7D828F84C38A8D8E8E926D78809970
9C8B8D9A2D894E827C8891576A765FCB485E855F8CFF5600
00FAA2799F879C5A9773A578C339ACEBA9BF80907E8A6142
928273719C77778FAF4F65859A626784
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
5719FFFFFFFF00000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFA3FFFFAF001FFFE642FFC1FFFFB9630000000000
00000000000000000000000000000000000000FFFFFFFFFF
FFFFFF9900000000837BAB6F62A495939D708EAB644CB468
90808A8E6321385948315E37718E99B77C93A68D4D116D91
5962718F6D927EA3907A7099772A7497683C74C3AB919B66
A7A78B9C6777B38F7F48777B2B8E587A72938764AA386099
CCB2E2B0729E72B076CA686BC662989FC58E857E5F898870
7783596763487E45779B6FBF948D6E85
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000000000000000005A
5906E7FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000005100BC9CA468578321370000372989E5FFFFFF
00000000000000000000000000000014000000DDF4ADE8C9
D9C67EFBCDCF866B6B6169838669A99488A4817B558D758A
8A838A92A9875594A494B08E71C19C8D779C94A281ECE7CB
9977696E88785AA96F64779376BF678B708B5B7A777B9C83
40665859A7696F5A6F58A1900A548DA871717D152B00236E
784080705747718184382A3CA4C34A999C597A809464927E
6079746D9194419466805B5C8A9E9FCB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFA8FFFFFFFFFFFFFFE09E2FFFFF62
00115F17D83A42BBA5140000EF1B8371FFFFFFFFFFFFFFFF
FFFFFFFFFFC4FF5E898E709386B691B66D7F9E9081666A78
B189C1F1ACB0978C98BB9995AA9A99648E847693A6A69295
838C999667775280555A958DAA8155957683A3999623C76B
A97C787A7E929B848C80783477817577678E7E766E81B551
9574827C7676606B868E9289825C828B757F6B554151805E
A5853A65AF829D97A16AB3888F2CEF67567669509175B199
949E6E7C845D64A06281817A6082BC5E7D6170807A635E93
6780866C7D89827C80897B88832C67AC
00FFFF0000FF3CFF008A0016FF4B69827F18FF0AA6646B7C
9700C7B150C72664FFCB00FF9E6379A77AFF5A00D6935E61
2DFF00FF00D49D8A00B15E807027E200005E809775954186
769468D345AA71B316FFFF00FF8D7E953BB8899A678E9CAA
00774C2F7C8C448D827E6CA7BE38A221FF00FFFFFF358B94
C5986D807FD628F6276774A5867F6D4BA49E844EA85E7DA4
74C06C69716B8B4E749D8D7D858C913495768076935F7C85
827A877E876B556867877C7689757A857F9A6EB4A78E8452
B9A27979718162573959A28EA6AFBB842E5E99827D6D6557
508E63A471854285634A8A624E6B8F8392A879796D5D6F8B
6771857D8B697395A08F77A861726BC6
00FF002600FF69FF00FF00FF42943F8BEAFF00FF95165AA1
178F88876000FF0000FF9EFF06B57B65B50000DC0000FFFF
00FFC600FF5B1A7484A37F3AB8FF0030A36C6F0080718971
8FA0A02F8E2EF700FF0000874B5591526E758D6F92FFC68A
7C6AFF00A59271849700A3FF16FF00FFC5DB00FFFF96837A
6C717BD7000000FB5D53717B6C86349B798B8A676C5A6750
7C8E7B8C7B7465A88E708382738669805F6678867388777A
79807882826575887A69829285826D8499AB93957C6B7494
555F7D6E78A759516A518C9D8D94BC8D87859A557B4D8284
6879926C5E7F78859C61917BA398767E418685774B5E4F62
7D6D847459656E737B4E5C56464766A2
C1FFFFFF139E2CFF00FF5BB100867BFF1900FF05006A1665
247EAA2800FF00FF8B00FF5FFF00AF9B5284FF00FF00FFFF
00CC04FF0095424F343F1AFF00FF00C48C66C2EF40806F77
7C4AE0FF00FF947300B78F0020628FADB1737FFF0050E373
81B5FF00FFD65D8183E5008400FF00FF00FF009576908936
8DA8D200FF0FA36DA8808946998C5D6D5089668B9262598E
8D97749578818E865B63928F7C858E824E8E8A758D60887A
A361917E644E8B747F7B76626F927D828589858FA7875E72
AB7488B5B0618A94708E7C7D7DA1C47E93737E935E826978
8173755FAC6A858D6779AC9190A48BA9948F768B98D18C8F
918196859574739FD4926A7CA3688552
00FF00A400FF31EF00432200FF6957BB2D82FF00FF6B95BD
99009AFF0071FFFF5AED691FD6009DFFFF00FFFF00FF00AD
DC1DBF5AAD96714894FF00FF00FF008E59A65C0064969E9E
FA00FF000013A94CAA1FAE848B65866590E4230000AE5B79
5EFF5710FF00007600FF000000FF009B701B7379839E78FF
7C00FF00A861A894B17D85A6BA6A9F8D8C475F8B7782AA8B
9F669298607E717A836D678C6B82707F66689C6C9C80AD7F
998A826B6C6F7A787799775C60769097908592698D644F5E
2545726980777199A195515588B079AB796B834C68666C66
6C6F7A62966A73786E9075C5A2B7888DA2827E66A2847172
926C7F7E8482729AAC7154A47974B19C
00FF0075E9006BFFFF0000FF007D00FF8B0095BD6A838C66
FFFFFF00FF9496FF6E8C1DA6DE00FF00FFFFFF003F000050
D11F8D546E9653F800FFE67BFF70A95F7778A768010000ED
00FFFFDCFFA95AB66BB17D8D7087785CFF0000C397B16B6D
7696C26AC90AFF0000FF0000E6FFFF325EA17E97829694FF
FF0000FF668C7E89623E5C7B8D6B7D7E907F9AB69C7C5999
6BA66D8384888A9D7C6E7E9873749590708E704F718D9684
4329886AB38B5E68737D7D8085636F83A881973E67949D78
63547268A296C8A9979C776479B22EAE94736E987F86684C
615A8E7F8D5F8F5D85876F64896177867E7782797BA49389
8D7B868A7B7E997A8E51807D6E8D7267
FFBE009E00FF00FFFF3091FF00FF00FFFF00FF166687C0FF
00FFFF0020FF31FF44E7AD41FF4DFF00FFFF0000FFFF00FF
00850AFF00630000FF00B1543C863F6A625E8D649D921086
FF68F4FF04FFFF998B8F86A55B772FA4CB5475AE8284A27D
517BA09C7A6F9CDAB30000FF48B4000A86556C81797CFFFF
FFA46792A4C56E7C9173787B876148658272790B699DBB60
737E7B7789856F76898F58647F55649F6A7F8990A39F8D7E
7D6C7D70727F8B86919C8470897588766EA0722F74678082
64805570B14D79899CC981FFA6939654D8669E9F8786785C
88587C6F78608955888178714F7D6470286E818E5483827B
70747A7B677C637A947F906976706075
958B00C300FF00FF0058000000FFFF00FF00FFFF514002FF
00FF52FF520BFF965584E7078AF89BFFFF00FFFF00FFFFD8
0BCDFF00C57171FF28FF28FFCCB85A8B7C72847A787684AF
FCC9F048E47300C664AD914A9B10FF774A5E6352969E9481
7DA164B59A69A91100A2FF25FF000092BE2604808282FFFF
18E58D23F7AD565BC691898993518795797E8F3EB35DA378
A7819D756B81A98A7A81847A7892669A869D79926F5D81B6
A4AB79D56F9B948876988786786B7676A59B3D986EA25260
7B9967647B456B7F93C1B2A3736F789A5CD5AA9581A26959
72A6726B7A7B796F57657C479B99A9698C806B5A608B7370
7A94967F5C7F67857265749ECA99A5D8
FFFF0042004DFF00FFFF0000FF0000FFBC4F00FFFF00FF00
FFFF00FFFFDE538097CA44CD6519E54400FF2100FFFF0000
FF5800C044B0FF087C1AFF5457C6916B7B9E9577B9818380
00AB51800063FF98924D5EA98A6400176469755054575B68
9BB848B532E584F3000015940AB1FFFF0078548E8F63004D
9DB37BA6CB797278A49587529A698FBDB6B87F5E65718A71
9C90676E9F8C7F6E71726F647C6A7974848C789D66409472
9A62777A8999A482AE8B71A0659F86837B50746C4C85609F
619B919483905F6A7F666462854690537E655EA73D9F9774
359588AB6A5D537D598D8C6B57BB838E679883555E7E784B
987073716488907AA35B3866A5837284
C1FF000F00FF6475FF00D4FFFF002300FFFF00FFFF00FF99
FF74C2FF00FF56A1BC1B6798FF8600B4FF00BC680500FFFF
005CB259AE79005158FA9300FF4181627D77647F5B755555
FFA05FA48D2500C5887E935BBF74AE4D97596C7D705F6991
A3AD7972349D5FC1AD7D80A980514B005792CE5783835EFF
00BB0650CFB4589294759854918A82CB8C8497767F789C45
8379BD8D9D6F77A3A77C969B848289728A978F837B7E6395
4A956B767B7B9D886D789A6CA28F90A8E190728A9B93855C
667754686AA36937968D7E815358A9FF1C3A94A177888D9B
997D778A3A6979576F7848648A71439B65713A58696D6967
736B6C714D665C7DC9A963673966807E
FFFFFF360054FF58FF00DC00FF00004300FF00F2BE00FF00
0032DAFF00FF00FF0ADFFF004C247AFF4E13C7670071FF00
E15F75A1607BFF00FF00E4B20EFF1AEF767CA26D6E808E55
6680649A5ACEEB00744F787C8E965CFF108D529877787177
A3AA41D34EC45B9279C84C569EFF000054A490CE51577C1C
0063191EFF646C5BC1A4778E8258998796578AB957A88F71
686F5588717A6583765F8A66434472987870615A7D9C856D
697C896995816A8C7F6B6379BA635E8149705B53643C99B7
9760846B217CB67F9DB660651890906D6CCC3E57945ABA64
57775CE5FFFFFF9AAA8F35487D9173B07C839572AC887574
878982899A738C95AB8E956760859581
FF8CFF00005FD900FF0000FFFF0000FF000B0000FF7800E3
E100D7FFE64C3FC41CC9534A5422FF0000C86441FFC200FF
00C57468455825F0008A554AB26EC6007494666B84A8847B
658A763340CDA8B474477E7F5A3A65C25128A2408E778D6B
C6A585AF4B4852F3A69F7C6707FFFF3B95803F618C3871B3
006F5F87A15C927370759B4D7981667D757F8654B24F7066
9B80884F4E5D3B673269607CA855DDB1A283686ABCA4585F
94835F7E866C6A87807B7D838AA68782718196AB71D08123
A592A095AE8E5F8194787FB000E68C5BA583B63ADCFF6D00
553B3986A27D8A2E517FCF9C7B979BA36C6C87926C918E88
997C8F778D869799BE858FB8A49A897E
E2EBFFFF00FF5300FF7818FF00FFFFFFFF009300FFFF5500
FF00FFFF83FF208AC273FF6E056048FFFF6DC16400FFFF00
E3BB16F51C738983FFFF00C3760000658B96BE64B2AE6999
C66EC25FAF6D6D8F619D947197A77E5BABD69E6A68608FAA
7A831FAF3C502CFF3D9660878900A1E445A000D19D7D8580
8BB7DD64967EE0A29185A05E95AB609E4F745BC500319074
7D727AC38DC88F807997B88A71607C9364B66E865E8C6C66
8189746A7159615C767A724F625D87548F745B8F81724E66
568AA3697B876CAC9CCB6FDA00971333C473A9348B5C8C8C
6E74686C768AA99157745F5E5A6E967C827DA19863698053
7C85AB5B9A6D3981B5CA7AAE60657924
FFFFAE00FF009DFA00FF0F93FF0000FF00FF00E500FF5600
00FF00FF00A800ED00FF00E700FF00EA00DD00FF0000C4EA
535AFF00FFA8717531F1FF06DF7CFFD35E747087609B5F7E
6D80CC32DB6C728B815C538F5C85738F8209717D4671D978
C211586ACAC0510D495300DA2A3C46CE6CFB3AEBC1629558
62501E8168C2B3768D81A388766594886C9B7691814B6850
89759D985F5C69582B8F4F69BC7981635E8379688A8E7F80
928478697DA388705B8BA58DAD6929446F6C8D8FBA7B6B7F
5D737E6876749293976C865D8A848A00D172868C91967054
7F817D958C968696836E8298936F8C959C95869295709F90
71C19463997940A9A0A08734D59386B8
FF98FF0E69FF00FFFFFF00FF000000FF3B75FF00FF2F8500
FF0000FF13972C95FFB8B338FF00FF000000FF00FFFF0021
CB00FFFF5CCC779672BD006745EC6C7082AB8D6A97767005
245F0085FF9A498FC200FF4EA188917573AE9B90A8947880
8944BF0090EC00FFFF00FFC000FF11B322FF3CB483B49255
6CA217006D97569492A58F8878609166928B9D9B639056C1
6BA684773B66916A73738F886D8B8A8082728D846F766B83
806C6E8C7A91796777A67668B93871DBACA07C817F92789B
53817B7E856B666A7E697A9B7BD32C0000976C7372886964
995F7B8F6C876C88866B8A6E5A696C70787F7389746F7A91
7D8378B638934435765A4B5A8D81799F
00B678126AF700000000FFFF00FF00FFFF00D800A9689600
A500FF00FFFF00FF4F770052BBFF00FFFF00FF5E000000BC
57FF040034B96364775DFF005D5F626B6B73B3818E5CA1FF
FF94202C4633AF79607F524491929C86778DBA845B757888
4532FF7B856E00FFFF44CB3C0C047F9640C55991B07D8381
847300FFA884FFA03C6B76AA77998EA499C2A1657965956F
7DD2448647856E6F86879980769F68658F91A09267798279
4E876C7B81787A8E6FA56FAB66B77C78829C7F5586787D6D
9865826A676E9D89747E594F77699600BC6CB693597D5FA4
7376796F797C8B77709683856F8983729D8C736D8883A963
8A8F878F5E83BC3C82A09182A1597A82
50CA00FFEB48FFFFFF00C8F9D9FF00EBFF00F501FF5688FD
8500FF00FFFF009B80FFB8A6F200FF0000DEFF02FF39D878
8969C44FEC75874B8647FFFFB657EFDD82608E5E927A7144
2D456EB14BC6835ACBDAA3476685755C8383FFFF8D6B6AA0
6F00D587BAC7289CB87B00D5248A9639D4477B6E66895E57
847A6BFF7F9DD2736A836E797C3374757E637F7C6A4D75B7
8D2196905A915B5053626E968A94658478858C6D995A9A6F
A26EA3618F7D9D6D767E5E748EB77BA473BC60CE777D7C7D
7E8C839578688B4A5490605D47708EFFFFC5E045C45E56AD
767E91A5926E7C7496A05981AB939B79877C88838A9187A8
792DB465BD74A0BA8E685B92638A6090
49009DFFFD8A00FFFF00FFFF18AC13DDFF00FF1198983AA0
688100FF00FFFF747F2A4D34A4F85EFFFFFF4DB62F8C7E61
8F53594B9B75827F92864F006241F5577F8279925A9BFFA0
DC9AE47693A08C86737456C06F6875866A7D5F5561B24051
768079C43BFF6DFF33786FB83F71BE93BE6C9BAC78946184
6E72582152FF19A50B6F8994767D968384788693BC928554
51F8846D9B4B807C88816F8896955D87857562A777787094
7A6C68878D6C46765E8C9F948E8A79655470837E796C7885
81738182698E61686A8C85687FE97887F41D3BDC7B718CA8
95618B9E709E9362728B8A837C9478A0A59E778D977988A0
3EAB597A00499D86786C937B78918A85
FF005F00FF084B00FF00FFFF42C006FF3500FF00FF359067
868B17FF00FFFF25AB00D32139DE00FF002DBF8DCAA3B695
6632F3AC3E786E82838A816C62FFD6C18E65997D5C9AB395
188378889168B48681886962758880827A9572975C9D5A97
449D34EA62686A160086648C995C8B7CAA965F917B6E9578
9688648291ED81A25A47AD8F8D86A77E5978969F2D74B980
A313CCD44685728E6F8D647898767F736F7078777E6B868E
6F86A9637B988051679159740071EA728790A4939F719783
2E5D868F7F8879A76D6F65857094768FBC13FF3756E21F76
815259829967907D887270695B73888893875B99857794CD
74D2B5580047C0755B527F5E927F8C7C
3B0000A9FF3500EFFF00FFF75CFF00F52C4BB867FF5AEB56
73AC3BFF0000EE3B58F97B9E9200FF00BEFE6C42640C927F
6DA76063798242A3778C7B3287CD6718967D837282758140
E88F9B60649D7263A27F6C7A717B4B67837F8B6488436B44
6EFB008F9166D6F5FF77BE688A6F90A07C315D705D5F928C
7E746FBB79BE9D8E1C647367818D85996BA0D5A49BA56E52
A4A96A45B8D05F6B8B766E746978836770927F9D7274AE71
9A8A7E908B8688964097AB62CC827990958B8099857E9172
8BC355A4616E87907B82848B79818B8172B76B8F7B008046
27907483A48466808B6D9C8F887B51796F808371659D4C3E
FF6D9E5780858F65337E876B93808A8D
9800FF9E17FF00FF2A00AF9163E500EC9B7309FF3509DCA8
949A08FF0093A6626C9F149871B21EFFB46CFF9598E848FF
2F76B0A25A6F8A67858F6AFFE37838678178728B756FACA3
A6659287947091A77B7C6D71626393947F8A86984B527B81
5AC450F1977E94FFFF001884638CC4716125BA2C599E7E8E
80A6A380368E49B8908E51AFA27E75A18678A0A48B8E7D78
94A06D912648B0976B79A2C6B5A48383B2A07696857A9B95
62995C955A7DD67C0078B3897F6C63967A6AB39C93907294
B19496775A88796F604C777675635A8E6E7CABF3006EFF00
95FF9372B8BF3F4B4E657066A58B63B9DF5A4675B90A00B5
D8210F9F8572756A4E85826D67708664
FB0069B679FF7B00FF00FF00FF7600FFC226A2AEC0C2667A
8E8206FF00B43E0085CB77FEFF00D1FF006400DD4500FF00
A324CAC13E5B8B9A8D627100D7CAC05E8D5EA35C92590024
A0903A6A6B8E65509B41A0C9715E667E80A48D00F566B19A
628BB9383DFFAEFF536FEA7FAD9048FF267D7C86549B888F
6D76B47E9AACA877386DA76E5E7475AA956AAC8966725A96
3686973E9BB7193A8E90936B7B76565E56B88A4E95769F8B
896C8F50DEAE9D95FDB613B8406F676E8E72588961897830
7E644D81ADA09799858EB96660636B6BA44DC75BE6008800
F2FF0002FFC37464A79C4E7CA9BB83A6ACED96C9FFD04154
7ABB5A749275B7979E936E7F85AD7F92
FB00FF00F0FF000037FF00FF0002D473008A1697A868956C
8759BF007700A5B24AEF5218FF59FFC10000FF00FF00D159
2A60A26884918B7A8F6CEDFFBB6EB6A35D4DA885CDA25208
5676D151A400A7A14F7F494A7D92AC8C857F9793AAA45A66
827649690000AC8D21FFFF00CC5BA48F38824064837F7F7C
608B43460C919B69B27D90807D8F8068815F7B95898D625E
339E7C7E6E37C149BA338C96A876DD883B41AA6E5F7A6B70
7BBEAB9F5E4E9978A75D589B9A5A7D9C6178747167696E63
8A858375844669868AA73A94E893A6ADB986F4894DBF00D4
A53B428AFFA0004DCE051BCE67ABBC59B72454FF004CD100
F15CFF28567D686CA07E678D71927F82
8060DA00FFFF00FF00E600FF00FFA89C7F8B38676E678689
9D00FF00CF74FF287774556FFF2BFF00FFFF00B74CC3939A
B38D597DAC6F998D3AFFFF00A7516776A4646DC775682755
57C322BD298B786E71768E7E826E608E8A5F8F9940898466
817014FF007D000000FF533A50A07081796F4F79626B807D
6E00004A3A6C7F815E467C804F8B7786B8AD806047606986
62726737779E4DCF3D95BB9F59A98D548ABE4E4889AF9898
7A9100346E76424E7964577B8B6692A875725C7A8C897A88
D0949566877D987482C7767282639239AC6F925789FF6F4F
00FF0074FFA084007C5A6A8954ADC600FF0911FFD0FF0044
C96378718E6E8E768E59726366628180
A4B76E2800A6FFC3FF00FF009B335D72946E7BA56A7977C4
27FF00FF36B0D27761527B7F00FA00FFFF5900C8986B68A2
7567B060965AC84C000000A100AEA9794E866D849BA30080
003EAD958B5F935D8C728B81847375836A2A718584526482
846E6E9E6EA0680000FFF21C6A9C8A7C7B6F6684737869CE
FFFF077FFF367B7DB5B462598178865E579F6A8E6C78AA62
9A5972452695D54ACCB1396C5153AC818F85BD6475A89097
777EFF136387D9C864A0B58293AC95947C57998487797A85
16586F777453867C794D8082BAA79060A8FF8BAB42E70C00
FFA5009170FA5789ED2F988BD640045EFFFFFFFF1767A100
FFC03D875C8679AB9C5B716766847288
C46B3600BA5F92FFFFFF11009967A48875918F7FA967FF00
FF003B64DDFB50848D7C788E8A98CE00FF52FF429C598B67
92717579A56400FF00FF3F2FE54ABE6C7E9FAF79924EC500
3F5BFF656393865A8B90617A898044CE92F48E157E858273
8E545265995AA70000FF009D7B738C78558F8E8545A7BB00
FFBBFF81A26F4881727A6E795EAF8BABAEA06F86797E8C80
747C65848F7C3A5F4B945CFD8050399D94AC528F84709100
BC8623FFE58DA8525F4770959E95747B71774E887F7D5787
AA7FA667BE5A59584100448F5B4F876F9A9F855C758D5C57
6F2120FF00FFFF819227A1FFDA543700009155240078CC01
00A5806F64944A77719F819EB3807783
76638063DB6C00FF00A696FF00895384A2827590A86600C5
5300FF00FF9241B4974D6E6A714C9DFF0000FF008DAA1EF2
406169A51400FF00FF00FFAE23B341817C7B92746F8A60FF
FF88006FFF62878355737D935A746656D10D0F1555886C76
3CA74F6C7D704EB2FF6C00FF00DB9C65E8CE5531FFFFC100
006DC64270726482F9BCA06C5B5FAE726E86A65A89845F5A
88627B7E7CA2AFAB66657D302672FF5C5094B588B8CE977E
FF7AAA5A19AC458FB082477369726084739BC5B0BDEB7FB3
6C67C378A28979B090B97299A7957291817C8D619B7E9F1D
2DFF847BFF3EFF156ECC52000000060032FFFF004BCD7C7C
96AA91B79CCBCDCE9C9C60000000001E
C4575F8696003AAB0000FF72CD3867922891C8CE00FFFF00
00FF4E8F00FEA8B9859934BE39AF3E1FFF0000FFFF7600EA
151C16F6FF83FFFF00FFB3435E3C768566BF79928C525388
0000FF0000DE1D6E91BB419B6CFF40622D8087A1C0687A66
7DA3BF9669376E00FF370000FF00FF00FD7C0000FF000039
F7E88E6D86697077685957484D629673619159576E7AA161
687C927A8C666955A73EFF43CE7D009CF0A2A1724457504D
46AFA3C6EECAB19A6CA6A0C4A99EC5B0C3AB7660043F2A34
4C6B70549AAE4A6AB976ADE38E5A8D78B97A98868F8A7AA9
36FF0900FF72C0FFFFFFAA00362B3500197139001E004635
669BBDFDFFE6FFFFDED05F99A8EFD6E8
A19AF73F1CFF0824F9FF00CAFF0059000090FF99FFFF0000
FF00822A00C3A198789A304D527D4957950000FFFF00A08A
FFFF0000007D0011F95E4354D56F757A7F82789C84606D66
610B320021FF00A500CD004200CCA100DDB3BD3B8C888688
7375B718A775648C4FC900FFFF00B4005400FF000000FFFF
76D38842589D5A949E948BC99FBFA88A919763B23679D7BF
E0D189B46E6DDF9949C0BF5565E6FFB2CB67A4F5ABBCE1B1
9D4C5F2723745F4B4D48381B4A2F815D5C45528B9C88AEA3
150F00000000000000000000000000000000000000000000
00FF0800462DC4FFED880000E2A7ABA199919D83949BBDB4
C18135422E00023B73360E5C83979391
FFDC2900FF35239800FFB200F2928500CBFF3BDAFF00FFFF
FFB0C53000FF6B9177A567386C7E898C55D34000B6FFF568
00FF00FF1900DD17FFC7DB7BA36F174175668C95C267B696
6B3CC7FF0000FFCF2900BFFF520600FF4D5DA356A55A4D92
75139C5276C66A564B76FFFF00FF00FFFF00FF00FF2D0063
B14C76AE00DAD68C5D537B4B60546A7655422A1329232C2A
26003315354C2E6272009A4156517E696C979344091D082C
7E98A9CCB2888E5F7CA5929AA0BBA2A78FA26A8D707D6966
F2D386C5CE90C1BCACCBF8E0E8BEC2BFA7E4D7C3C7AEBAC2
E07460CA840068DA410443000000005D817FA69C798D7D8A
66A28A8D7B918B9D9B888B937B83A9BF
70372D00FF00E6A2B000FF00C30000FF0000FF00CEAC944B
155825FF0063FFA1C2DF592D704564B05289FFFF00E70CFF
0300FF0041FF0000896747FF0377FF007F6A9AACA7AD7657
69649300FFFF647020FF88A500D4ADA96467828D8F8A9E6B
9B40FF466AFF2B559D702CFF00F4C20000FF3D5314895795
83EE77B700ABBA696E8D9C7495A07D9DA986CAC7BF80BEC2
C6D287A1C6A19497848388E66AA55A7DA2DD8DBBADAC7E96
82687A80748C7D738C66705D7A518D7A66796F9E708775AF
84ABAC8380A3A891A5A9BA8C9084A5B0B8AD7876A6A5B993
A58D9DEAB78266787CB0993B815FB1A9826983698A6FB279
64606A926478767CA48C7AA1788F8393
00BFA70EFF2A00B9FFFF000086E1E70000FF00F1A387942B
97AB00FF00FFFF002C2CFE7533B6508E5C61D2330FD8EA19
00FF0080B35292B25163C1916F9D0C9292946B9C448D5E6D
6E788F0300897FDD8382B17DAE6C6D816D686E54D1665EA3
88808C7E34DC39A4D163709800FF307535CD7F5DCF818C64
6287BB92748274779C6A6F747294676D5E5A6F6F7997647F
8D7790787779797AA068685F8E8062A16B68667946826D71
837C62538192787A6B648164697F7F7F8B7A8458858D798B
7C8D83717F86958C8979656845666F5E62647C95928173B1
A4807381839087638672976D85977E6980865B82A596B0C5
8B8E839C799F636E915B607F6F97677A
FF3A9B0046FF00FFFF00F4FF00D15D41F22DA374AC23B78B
BA0025FF00FFFF006F7CA96118BF5C7B4B528BA55756949D
8B52945C8297A46F816677A3655C79B75F77616397869E65
7E927194A2369B4B778776719B888874966EAE937E779771
787D6C7F8B858C6E8E7E7583897B7F6371807B7A8E8A866C
7D8C98877C84917173788184717C818A937668A15F64908B
7F746E64777F917B7A757C7C8274936D76828767748C8B74
8E84897F958E7A8368779B7783685D79716D9FA2AB6A7D4A
787E798185868485847D83977C6D7D7B6E746F7F7F7F8481
837A82897E75867585838C78898E85858689808693837981
7D7E888587847778757185868E7E8072
00AEFF4FAFA56789D5A4FF71407E8D708572946573859180
37FF9D9B778CA29AFF0000B41857AC795690B14C4C898695
74A419CE2FEE597EAAAD636D76AC928EA2FF4AC84571318B
683F727AA6AF8F678AB19E86699374707489786A897E7575
837B846F5EFF1D83D47C79805183898B8BA3694F7F8D9182
727D68875E9A5A87B6C982A237437868E391619C2A6C548A
854B908069A04D8D667F818D6E996B6A7E7A85775378A667
631D9765977C6E9D5C764C74776E6476726F8060757C9E83
04515B939D7E744FC4B68A7C57AD7F868F825C6D6B8D629C
7A7A797A7A98698783887185FF50189E6BD28EA9977D887E
775F5E619D76728564836A81615DB172
9AF218CD67587FA7C8C7B4A9699D6F869756205437937F85
61528D9B7C8179FFA89A05BF637B7787A5658234CA6B9D7F
3BCC83FB659B4DA459928E984DC1009100F39A6462D8A361
8284907C7B7E85815E7A61919E9A788B649F997F7573736E
5D7172FF00FF003968BC681C92665571B54D7D838F93767A
5F90875CA48200CA85917A87B1B298A6BA798483926687B8
6C665C9B44BB64658B697579807D827F899369B0BDFF5B5C
7F726789557DA968AC787094709397919377AA806856AE6E
5300B1A2AA5B5B7F758383825F76828A8BC9B850787B5EA8
947F789679869096843DEB00FFB649A591B19B92A79B6F6C
A078A29068887D788E688EA19D97FF70
B488803C3ED85FA26ACB3760AC5AB6114800FF40FFA56B9E
8A895E8497997BFF68A3981D550A8979586EF46C7B723F4E
2C361BFF4D89627C9C746AB11767CE67A207FF1EC000CABF
95BF82756584756880A8853DAA71C4CA6D8EB36F8D80A77E
7FFF00FFBE1BABCB9A345C6BC96FA3C59C608D9E717F696E
B15DAB41FD00FF578C642B4979767C716ABA7274519B7D5A
839A6774AA5EA6959D6959836F7B68998069AA003E278DAE
A938369EB78AA66F8FAC63916B7D7E657E5D8690BAAD9E7D
865A9BFA4474504B918286735F98808D7092948223837BB1
8A757B7974637A1C5C3DF71F69619329A46C82D87CAD4764
7A706D62737C759C48C8368900FDD16C
8E9920B685715E7B4ED263283FBE439DA782BB00AE774794
BE5ACA58D73498C9979B2C60B6885B95B5BE09FF00FC4FA5
8481846D828B8DA74AFFB56B758074477B8385FF00FF0066
DE8D6469898685789968B2A46D958AB1AC78618A808999FF
00FF52769DDFBCFB4EAA8AAA525B5283987E8A6B7D8486A3
785347F7009E4886A16571B36D82A894958785807F7F8E8B
BC8A8A638479545B597B825B8B72710000FF2AAC79379699
5A716352894145859C9A8096797D927555A38B481C746F84
7C587AE0FF77D43A2F5D6F798960948F6F67869B8159625E
68B467B77A91664C1CFF5F6038523C0B8A5CA067847E6E80
8F9D8B797B7C5C691F6AACFF0096478D
5F5F2CFF33356AB7FFFF0091B45072ADA1697EA17899659B
63DF80831F912DCABA828D6B68835785552D00FFA240E850
BA7435AE588889A999D55287658CAF908058AAA06C1DFF00
63B4A975708C868A457AB6356B6A7BC7B100CE1500C5412D
7649F100CB2EF7259B7663996574A368865FA7948089827D
FF0080FF0097828C8E586463D366917A56948482A5807F86
6E28DD8351965252B2DE0F99827069BD00FF598A996DAD3F
CA7F37A97B8284836C7C966E7F81917DC26A6FC0AF8C9E7D
787E7D8BF80091F036A46599928A7A797C7B5B61767235B3
2A00FF70A06B6C97535FD7469BAA5E6F66757B8C7E839493
92937B71817884B900FFF66966918C7B
5D5E6EFF3E4FA400FFFFFFBB42DBB93BCA7B94764496941E
915DADC95F44A740A2788BA6B6549F2700FF84DF78621776
7067614C618C0B7DA51D732864784DB09B675F918A15FF9D
03519A656670887D5A8891B191AA10FFC3A400FF98635E7E
75A663A996D45984897F98778A72587F4E687553698444FE
00FFFF332E67B86D8A705E70867B3D8DAC9186A17A8C6E85
5C57C25E41A202D530FF5E53AE7C57759CB49E71AF42578B
678480819A6C738655948E898C7C6EA300FFB757549B6D89
6B6F6A915C6DBBFF229BA06C8A70777B9CD1827FE0A50076
993AE17309876E737A6B7065775B78A98D8E7C6F6466A7A9
556D4A757B96AE00FFF3A281AB72797D
7A6D74E27E6C4FFF00FF3B00FFA835A88B07FF00A99916BD
00FA7AC200C2C6437B587554178A72FF000053E922804085
59B417C8789800DB5AA1A8AE7A86606DBC4C846957689713
FF7C239478908075B2007BFF00FF0001FF00FF303E879FA7
79CF99A15C638C7C8A6B89806B6C8493918258847A941612
D300988A94946F88797BA39942756027304C657D89908281
907A7AB4ABB79F5CE7248259CD74756F827C968B718D8776
748A647DA88B74C3465F92837BB64E141B4E797E81648978
5D777488B12A946980A2285767B9778B3968BA00FFFF1500
A4339D7369518388709D7D8D8D8380806A6674818D767B9F
4DA7AB808C00FF009B56AD9A74799375
624C6CEC1C3F9100FF001E41CF589CE06C51FF00BE79006E
B5B0A36600FF6D647CA29C8455C7AA23FF00689410BA00B4
849279444EA800FF8E44744793B127B46D80355FAB9B525F
B706FF31C717AE9C22FF0000FF00FFEB4A1C687ECF63AD7F
708C6C5189898A868B7579677D7B766CA5004AFF5C61D148
64D49892A97674807B6C5E811D919C8B9790867375878773
A2656D49328B888A3FAE93718989667F67778072997D7C7E
73A28183905B708671C266AD5A0027798D898A576D999C7B
6F6B4D71908C7B9C8C3800FF077762609000FFCE00FF004E
0FB47C747B6393507B6876846480697DA4847A9D5D6C9B6E
676CFF00FF00A2C68F8B7A857179807A
5C9C95E80B8B6667D400F46FBB37B079FF90647464520000
9A98B07C0091546A586C8CA17C7A77D19A97CB789A774EB7
07A13F749B6FFB009E5E85546E75837A904459C86264A076
A79F5ABFD310FF4ED000B0FF00FF850077888BA04F863671
8672D4C67786A192768B6E7B689EB4535FFF00ED2A7C58A7
737AA5728270907B699487958F907E60517B9FFF5D6539A6
34D8008AFF40E26F9F45B97A985F6E7D5A6F7C7E98767D69
7C7C8363685CAF606DCDD64810C280818A847FB59592808B
747C784492768AB47B5671E86AC5832E9C00F7FF85E9009B
B47C746B6E74C07672854B639A867A986F7292887385689C
B300567085854BA6777D946B893EA577
7B97BB6500606B7FFFFF425FE52C8B2FD49B503C367DFFE7
28A06C517DFF8D0685A270897B5233A58D516B61695D533D
9955568D5C58A1FFFF00D7AC55B86C7379675C5B5A997E3A
5A5971678D78B900FF0000FF0BFF00BD51806FA6907BFFA7
7F7D676DB189723868799665A3688067FF003784B9365782
61977D8E8F40B8787D65667E7862936E8059AC888900EB62
FF5CC36C000063A97894897D6D8BA064A472685DA4848C7F
7173797B9B6C757CA5BE6C8686979D73899181759786817E
6F7E9A5081A888B5717ABE7B856B892300E67396000000DB
7E886C7492908FAA977887918588705F7296618E6B8B63C3
043F757183797B68777E897294728F79
D448FF004D85458000FF8377930000FF00B3484B0000A600
F711D355995AB7557EB130A26C54A205FF7C5E8FADBC4061
405F7683FFFF7D464A3AB69451757A6D8D7D987F9CC072A8
79DDA09A6537B7FF0018CD30FF00007F888191A808DA5689
538E5F8E4D836AB4708D54AF8F737CFFA5318E857D75717A
7BCC5675889D84797C54A7667B4C647D8D9F5F67A07883E7
00FF0000FF7EA88D777C9272926F92815A7E81A382845190
81803E6B856B8C71AD5D85C17398A27068908E8F83709578
726F898B705D9EBC564D85627A857DFF00FF00FF06003298
7478A36EC032A8689D63805A915E91858775837D8285712C
004157827F938390525C897E97816F84
B084AA3144EE375B7100EC8D5EFF00FBAB6B6F786A7F6799
2100959A4B943CA6A5598A8B595674FF000E9D6E73BC419C
609253993D717F8FB900FF8A6F4F7BC1839F617892717056
B57E2952677F7A0000D300BB006F722DD947747A9830A398
7499BDA4F413944DA376543C2C73DF0300AA7A757C5A53D1
529B925385A5C87680937C767E678CAC8B94B7A489418D05
FF31F5FF00E3667578977DA55B82846978808680C2736487
60738B67957F787B75AB7870A0937C54B86C5A6D72886C8B
6F809695738F725666AF61917D6D9CB1D11E000000A05B44
7877548C6F61A597967C7F8560A9849E78608CA07568FF64
8C7881BF986B67917F75907977AB817C
58948500676C49DE009E6F8FBF882EFF558C006693837E4F
2BFF1AA159FE4F319A5A6EA3818C4A00FFF25D60808855D3
4D9F88719D6F707C7757FF177050A27294649652AB987C53
8287B283A46914FFFF4700F0FF3B4CAB158A8BD3C4C64949
8F72786000E74169954579AD6BFF009A559E956F7D508A5E
678C5E9C846CAD7A6C877E72959B736F86949476948B873F
74FF00ACEC599B95776E879F64897176827A8171648B747C
8A4A49CC4D9A5BD36E7184629A797FAA796E549469558287
6A898B898E63927E6178B9765A9390584D5647FF9E7C8C43
5C8C8000E543A4866784919F86A2618A6946AD56BF0000BD
44785D72AAB44C8C896EA34B6F938686
75B28F67977888FFFF0086CDAD8F00FFB5167C2CAC6B697C
7384FF4974933A144D847F9CA34ED20000945C00436C6C63
D001A8CF55778E8B81579DEF36A9B37484826FA853820E8C
85B573976780993C0000FFFF188A9348C9FF00B99A00A6A6
7E86598DDC6B956D8871974EAB000081626E5DA28E964B8E
7D8A839B87C22A8E805F72B8639694BA8F6B9166978AA79E
4B6500595D829C7857525953B3627D568D7E96B685439C98
539F7469BA5865559A9953837F6BBC5A898971894F946E7A
8164849DA19593815883815DB37F97818791D26C6BA57886
67B97B00AA5552AC8E9E95A2748386A19A8B866B7D407F60
A4989979808980958BA18C7056A38F6D
C5B849937789D600FF00D3FFFF2A6FFFCE82261CA6878997
627F0000F2AC11A2CD989D7081BE08FFFF6A7F99F16A8C89
A6811F6D6790A3A68879C0FFD27F7A74818361BD846B9C79
6B9570869F8E6577FFFF001DDC7B93715A00FF00FF7457B6
4E63919C498B8B9467759A87D9D87A96AD608685735FD063
A1A4629991535E8B81A58B798E83BB627A7D738674659771
91B1007C7565A16587637D8770B2935B92779E5C72947685
837F67748AA0718C91869685627AA67CA48762828965A573
8874776F759D9DADAB63605B6B927B5161EEFF6083758288
8A8F70BA2378926F9AA2B15A7AA17280387B8087489F6A73
BE8B6679936775466275798D7970AA7F
F67720589D46FF830000EF144860388D9D69963BC5A36A99
9360926F99972DC579A379849747F99E479043AE5355A482
69B57A84819C77738579A42E7E9FD0948E6C80949A9696B8
A58822906279467025FFF29168836B928B895087897FF100
A868B082A19EA39D7D687E851152729F9B65BA7EB98B6FA0
7E897CAE755AA96E7DA285669E5E8985918664959BAB7465
9640FF6982808AA640886F73618F4091795C7F64666A8988
90887A7B75747186826C89A466726F7962808483848E6F79
6D6B8373495D8E608374A58B739199728676FF6163805D79
777B5AB629796FA375A48F766BA86D5B6EA67A825C48846F
B38E6E907D8C857594906A8F5B98867E
D64452A08D6F9DBE0000C0B634784FFF9468836D8C89468D
7E7C816549BB48CB85867861B2607AAA6800A296749D6486
85575281857DAE81807B6A3D3F88D677867E6D86466E9460
6076A182B47E8050A088A55F55816D859873AAA8169235C2
90A68850724A915993747F77C299458A756673726BA0B56A
41555D81988F1B9977988D5B7B8D6E947E7B6773A0C48A98
66965B858091509D686871958D74659F867970697863879E
917E807D937B4489A18C6B967F96698A937F7AA8814B8F74
6FBF6A648F67668070966C7062773E9677515080956B7296
A06A6D9E6B5E6D8F99897D868F7F787192897E7E86627794
686D8452625C618980973980A1AF7B80
3F4A6CAB7C5D80FF0046A79894828E96A5C37F90B67A7C8D
748093BC10D7009B885D734A90A06F00FFB2558D7A8869C0
AD9475797E9E5E7E87AD758FEE64385BA08C7190938CA16F
78C974BE64853D995A89A779B1297E6C688C8925B32AF412
8B8E49BD747D76697276887F6A18418D987891547358B1CE
61896191847A8B82718292B67879878779718DA83C955687
6D719896867159767C7A98798C7D6C89857661935B9C7E84
826D7E7F798378ADA1A18277846D6E9A8A8A626E873C6787
7E8B5B788BA85F6D4D6C8FB17B803389746E6C6F7B666F7A
5D6A9C768E8043A054C78B888C7C90699059817D7E8E6F79
78965B8A7886618687906C889376A77E
8C7F7E96787500FF0025DA6961AF6778796A7B80696E7650
8C75C509FF33C9A79C8143776091C3C0FF00BB68D8789391
8C7A8A346A9A887270879094178872727A8A6680998B99A5
A7673055B561875A93528C7F64936C91898200FF00FF00F5
226C698B6F915B787F78817D819BFFF500D198A9A96C4F85
749399716E938A8A7B777F944E85898B75668F8D779E726E
94908787797C77927093858774564D8F459C74576B98988B
687D777F7F6B75433B544CA47790899F798D838669594387
9C7489848A6365AF896F9F85909F92697A746D798163877A
75809E7BAA546E6F5D816F806D6981655E7A7A7E836C4CFF
FF5F7A8C8A2A5C897D7D656EA26D6080
9160BFA65AB2B2FF8F00AF4A71818687B4169B81AD758E5B
A9798B28B12AA04C8BAB81A9695ED3B02D642B727F92986E
736631B53F9D8960897F863A5F3D798D54637F4180949C87
9BA8B89E72B5A48282965D8294709C629D82E400FF08D15D
71A78D816A8A8595866C7F7D817D10FF0000B14B8C5768AB
6D948A6F397B80827B78A5B8968D7F7162716CA56B776E73
819477826F7D6480646F78659095705973717D726D897574
6F907D7D817D4A9F8766AC906BBA7CAF9189758F8C58A670
82799A8481836E83767F895AAC7B9B898DAD7E778A959570
72797D6FA67973A4807757958B9865798F737D7F72758498
FFBC7184518E706898732E887269797A
9464A79A85E900FF9BAD3EA86AA639FF749D8E6267687784
9192A76FDC7425D99D68674C6989FF8D6F00B945C67BA27E
87968C6C7551815997536C51FF9A95739190409972A064EA
4F948BA9BD5A8C6C861B7A857B8A7A766A5F5CFF3587156C
5F63798E857C858688FF548B9887891FFFFF00C06E9B6F73
7C986F6F84700F99787D8D80754E4E5A7A8378A696769179
607769697291748169666DA568A2505EA267616D6C548065
6D7E79806C75866C7F8D4AAA5793757A846A8A777E75826C
9261984966749D9A87906987777B3963608C867A6D7C956D
5C968B773E99B689907A7A6175956958760D9B77847A7C8E
9DFF998D656A949088759F58626CC970
7E38BF60898DFFFF8100ADB4879778A352C3588664A27F88
8B7B2E7C00869EAB9560768276B252FFCE11FF407685468D
8870809C5B8481707A7583C3196455B16158D434D2728E82
A520A4829B836E85B5D188667F80745499B54900B3D9B173
80BCBB4873645E8A930096777D7D838854E8FF6C8E80A56C
7F95848B6D5E69749B68566B7A7458587C90957A6F79666A
8A9B6B7C756AA08198828B758E937598798F8E77779F4192
8F9B8D7D7C776C49B7878B5883878E62968EA765946F9573
73738491846B74585E9B75638B76838E629D718864866F91
8A91AE61AA8D8F899E8487905B768979838D917C7784A592
6F767B62826F7B7185B29783AA7D737D
8A658032AF49FF0040FF4F7E329E9777578487A766808D67
88B9CD44FF2849B64C5FAA9C537AF77F295CBD8C859F7680
85968A788E6B90686D95008C7A755774A07F56998E97605A
5D7A8C70865BAC6E006872987F77AC8BA06BBC82FC687599
287E76A5AE6D837974A49B7C798793916574000A786D7363
738878659A8E3E93729998838987796299A8619F7A4CB48B
628B837E658D84697F8A7787848F696C9B2D7B9F8AA97AB1
6EA1767E71A08C83818F785A6DBD75629464846F9F947C88
556E70876EA4525E7F7A5097A4B27748AD9583806E777275
7C8599885FC0746C5BA1857458695E7B66647F7C7B716E81
818DAFA696AA68A06FA89562AF4E767B
9487809138B03CFFFF9A844EA1697B8070A64D816F568179
81CA60AF5C567F9E9B78857E4D9100FFFF00A5535E717754
948180578275725E5A4C00C089B17E7B5C8BA969A816756A
5E7E766474AA6C77D47A768E6B8175788983508A2E7244A9
A4758E3B55935D6A914E947C80738F968661FFFF36798687
9B9D4E6564A990737D94467D658387B05F7E7C4A869266B0
A470788E77716E6CA36A9F80869466A961856084BA83803A
9453837C7E8A7172726646B15FA74B88625D83A19FD39F82
617E97939E88549E6560995A625A6AA9D4848B80936A8293
71858B9D6C77A55E8C9395AD947EA7B3957B787D7E7D8389
9463709F4F6E6C8F8776848A959E8876
82849EAA924DB5FF2E00D350829067787877AF8491777A83
765E8BBEA956697F6A4E9894944D8E27FF2EB475404E868A
789082687D8697FF00FF4F39B3873F877B96AC9F8E71A395
79696A78748AA5E7FFB895797756537F749468AF9658D96D
938686BA6A9F9F5D6A74737F7F7E7B977E616900F0948687
6271976BA2C6A182836C5F6C4BB68B4C5D81816A928E6865
7294768481748D9E99837C9271A4838898723C47A17B7D66
74867C7F7F7A778D6A8D71657673AA657B939491817F6088
7E7B8CA83F667F847A80B053936389A09664888784777979
7275866F857F897B7F9576328B8D698FBD7D777E7B7E8266
5E85613865618797527B916593738B82
9C505B84A284755CB40D948BAB84707ABB72968F677FCC63
59EBD6C1754CBC77A895A47661A3847D00FF3648A79A8A87
7A6399957FCF7AFF7E0B9C5F5C6E9C998B719897576E9084
6B5B64906C9F46000078974E62A77D7E528F397163916E7B
5F89854A874B84698E6F7A73768376B08F8140A30754887E
765D7D60847F7D81947D736A6F5D63A18F9C59A88367608B
896B71A389A56F865495738E7085A9A5817C73996B85A258
696C81797E817AA18360A4BB8193799DA67A8A7C835B5D80
8F64A0797988956392766C758984A9D7A17A888581957154
9C5B935C8674A6737485AE5A94985FA98B857C8D846F815F
90759052B7825184959477C050658381
7D275D844C3E617CA78C25FF654FBB758094BFD083FF0000
A4FF8AAF72A06D9E956689637E7E796E31AAE800FFE83E77
AC5D5E3EC700E22E4AFF7550999A88737B91A3946C5CB465
9D5D7DB14E76FFFF89A1656AC355FF1EFF00FFB971705C64
7F706D7D6AB9538A979CA97E7E877E807E9C5D4251C88E86
9467AF6A957A33856F90728182A277905279995090625B90
9F6BA3857C6C8E458E6C887E946D666474934D5F704C5C8D
5D9D7575A5687A9C74697D6B40757A8F8B946D657D7D4C8F
7A7AA593707E938759796C887E708F5D6E7972924CC42E60
8D8A145C78827B8170868F6F8B66AF7C9E7E847C8B797EAD
876F777447767C978A6F7B9342459972
7D90705B7F594A9475739CFF9566D3D49EA39BF3A7643347
5D3A6F4D80595A71A988798E6F9B68649A436A00346421D7
B519006E93A4C26F1BCDC285747A8A94776BA8A965936672
C18789769162000041678CF20CFF435200FF007D64728E6E
8E6E7716FF3D957F71866980A27D77798C836D81745F5976
62938F8F8DA46E6E794E737F8C9A758680B05E8677774D68
6C83807E7070409A788E5B72968AAE6BA38555729A8E6C5D
8E74478A7E7D6F557C7D8772717B489A6E7D757567749F74
887F4A6F79966094468A84987F998B91704A9D60E2C13C66
A661555972B0789C6E92858AAC8B795E717E796B677AA86E
7A84755B5FAA895A896F623A84727A77
7E63A861A0427A704E97A3007278C23C3F3D00FF00E9323A
FFB657596F4F867D7F84912EC87D706B7F3BFF00B6993F8A
E0D6F4F4778A4780FF896163A29C62A89968808CCA41C28F
976B4C8C85D2FFFF763EA040FF56CE47E382C683A45E5187
A58F96AE3F958B849F98815C5D6F8F837E6DA5A1E049838D
797B8156828163799362505E84589773737068B371958D9B
808F8C5DDD31C6346D70AE71868B697A936960A36E6A5993
7D6B879B7F855182816B7E6A9A966FA27F7679AB3D68A87D
7792809A8C81838E68757098746E949F9D826F8FD32F847F
B057765DAD8EAFB4806D7C77AD908A6C907B5F7C8C75A780
8C6D76754B4EAB61715B658884BE8889
96819C704078BD967644A7FFC3624AFF00FFBD00A5724C8E
56C264B0467FB073764D71A3449471ACC99B82C1978E9F61
31FF0045A27569916A7EA58592489496758F5B85397C7D69
8B7860849B4B6453BE880991BE9959A774AA50874599905A
777C646A7435B18D827DA0817589476B7B718B8B00FF577F
8E7C678B7A53CB76747C725C69A56580729D517D794F9E39
849A54907EB681A25A795B7A96766C8F7771AF53B781608B
717B518877855D8088746587637B847D8A5862773CAF8A7E
7D70905099A792646D689C6A641F894788836648C4746B7A
905361807768789D7C388457B5A3858F9C877E7398789276
757884595D005A55798FB05D8A8E898A
6FD0757449B099677B61AE6C38AD8B5F56009F8A948D7A79
9D7E74835B00E2959D67A2538AACA1716177935E5B7F7E95
5B0C98879595B056727E817F93469A7C877E8C63C55A6743
95BB98705670FF878433FF53C0875679958EA97D8245CBC0
66705BA86681795698829C76896671826D828365AB00FF13
8378668288A84E88787D7982BA83AE7A805A7289525C7C90
6B77A5629376915FA2789E93836F8A66BB477F9B629A6E92
966E938A7380857D6B868D8667534577726C4A845F778B7C
8F6285AA856883A69EA785749C214BAF9DA8998F78D86380
9477928B60647476945066B06B788060618B8A5F75A04D78
738C6F93774844927298795DDFAAB865
A34F7CAA6B85007F248E63B189909948929855A8A3458E54
AB91A9FF5500FFB97B6970858595787F8E6F7C7D81768B65
768B6F847F8F7768A4817F8C8D73746CB074955A5D82B689
7069824462FF656188B14FA492923499638A8FA061A9BE34
77AB4A54859A758C608A6C7878957376758A9369639528FF
9D6B7FA66A6CC2777C85756A674C725063B16A598B2DC795
8E62768984908B6D647D646F9E83836C8F68855F518C6A9C
98AC828D6D746F83707D7B83749F687E8A798776777A7B75
717EA16165598592853B75A4A071BEB064844B9E54A48C7F
906886417A687C8C98506C7B708F77A2708C7982988D7E8F
797D7777A59D576A2D97A2766D979984
00FF0000FFAA904269FFFFEB7C7D7E6A808A3A76E895815A
FF957944648C787CFFC200A36399A9809C1F7FAF7E8B627E
7F37FF1900A287CFC6AB9C59776D3C74729A87728081649D
637C7D974BB263AD00BB9A8B73835C7573877C538258765C
807053A3707592A26F84806A8C77828F7F7D85858F4E9C0C
126AB28C3EC3B0789E6C8C82807D738AA492688BB0816956
606D9275826C89756C8C71857D676B78817482849984767F
5373807A7B8983788383717497727F7D86576E83788D757D
71697968B3569D6A7652788EA4757D7D858568856798805D
8479889C76A37F9B7A93698C808F9174978F7E8A4C517F96
7A85717575967D745457614BAF699B7A
FF00269EFD6FA3033E00777E607A92974FB6FF000085AA88
6B85868E8B7D73B2EF0000EEF398928CA170887F7F526700
FF00FF64C3A2828B9D5984466800BC9C74C8857890779766
9C5F9E6ABF78A639B2277A7E7D7D7A5388A0973F9EAB62A9
7270798949B25F4197828174837D8D7583719492957D7EAA
D09C578F8F869B8C778865996B6A813B687E6E67758E896F
81678995739A6198838E827D7B86A59073918E849A9487AF
487A7C66487663847C7F857E6B6E5E949AA0987687949484
889C5673A9708B954D7764ACB4B4BA58777B806A5E8B815D
818386828890789BA173747D476FA4765C7F8A8D3A8A6991
6C9B70746B8E696F72756E7F7FA38E7A
FFFFB9D200BF95084CC56E7C7D00720CAE8C00003945ACA0
76C575A6FFAA00A75768CCFF75499365254FED95D6FF25EF
8081FFFF5860BB6D4573AB000000356C90629DCAB6996C99
858B84A3968E39FFACC381739E81848E847450D775456D7B
94B59F898E66A37A897A629A828C76798A886E7F84667E90
818275A3634E857A6686825C8E8B7B78877E914AA366C65A
5F948E92A67D84618D8B9684629585566679997E64747067
B778855E7794747D8D8B7977717B98757C868298646B6887
5B7888B3B26057718F907B58AD94FF70947881718CA77F7A
8378868281897DA29B8384788A7B8A597582868C6A9BA769
7A87658D6E7C989D8A9F64A065895D7A
FFFF9A0AE79756244B6CFFBE74577C1AA06B4330B9709C9A
000057FFFF80008EA77A24BE00BEC40000FF000000FF8A7B
5D897162AC8D859EFFB3BD0FF069DC755C5E6E717DB69FA3
9E407984439CFF76111B908776837F88789A8284A68F6E6D
76816C99987E6D5EAC84796F5E858E6AA4A47E7F77667E89
9BA5955D77199E6B63895C94A64B66786344705EA06F7E9A
9E728C7970A27C748772557796877A88738B835481867A62
7E847172916F8D7F7A8B9F967F767C7AB1B0857A94786D81
7C23857156558C73A7666D9489537079C77A7F49608C888D
8691A95EC073776F7483AB82965C7B693F7E69866EA76B69
89758C96856A9343A0A57AA17C716E83
FFFFFF5A00893E000000FF0018EDDF0069867A7A736A8277
FFAD6BFF4F00009899A9FF8F82BC61FFFFFF000009367888
BDBB6B9C848A5E495F327E002373A98B74AAB2DA8187824B
6F776A5F5DEA001EFFC2956D6B995EA381887D8AA5978377
639CA7907386C8D3A3A496856872578A66817B8E85848284
567D9DAA6CA5A7716A8C73398E799D7474967C696C716F48
80738E617D8A735B8E93729773809C7945998E63A4A28280
966B6F936E855A567B797E91765B637B72926C98628E8086
738FA38B99806F67747EA98B88399B6A8B783F97947E747C
718E996F8A4F61A97252788C7E776685937483905E748277
697D7593997771848989997D6F5D5978
EDFFFF1D000026FF00FF79130043342A99D434468C9A7600
76195DBBFFE50057C043005E4730B4FF000000FF8E000017
9FF5FF507139FFFFF6FF7DB1FF4B12889E9168919437533D
6A9554BE3D7FDDDB00107C7D7F757C8C767B96868A659989
A0448CB488A978428275776D8883628F9A898E889E5C9167
7D8B92818B56927D7296537A8B9E717B457281916C815E99
6971829984649E74746E6A957F9A8B9A6B867466AC80549E
8F7F7D8A877AA67F797A8D77727E92724CBA9F86766E608E
90758476A69E7451A476B685C63976AFB15A60898E6E7370
7C6185747A9469788F816471978CA94662777F9769767F92
7E837A8388676D819C4CA252814F8485
FAF2FFD24A007A00006FFF92FF0000FF5FFFFF00A33DFFFF
3E64376CFFF9665C4C8620648C8E9100FFFFFF0000DF14B4
71000E6E6F02FFFF14005E6F5C41A17C886EB6899F5B7C72
A45EB965EF3249DEEBB2107EC0526E727F6A72705D96766E
9A7AAA997B7D91B3609388865C99658C6B7A7C74898E45C7
D6566E7C768E9C6C6290A1858499929298965C959A789E62
B07E7079988F84896F787C8070798D618A5F8BBDA7724560
86878871778C8A64967F8384A05D79536EA48C8F577A8675
958872A652A0456D8B5A7F9AB475716AD382B44B6A888E5D
7F904C7C5C7E7A838D9975997B76A2AC797FBE877E807C76
7B8C868294729052629BA47BAD689B7C
BBFFFFFFFF3B00FFFF6518FFFF3E33FF68FFC400924FFF00
00001FA8FFE5226A66D0FF16568D91FFFFFF49F1FFC3008A
BD7E898AB90000F3E7C8FE4BFF397C935B848BBA7B5C6275
86A86D42828B82639800F4268F5A7675617B5A6982B9A961
89595D6770615660968E68848AA681699171757A8279862A
4D97924D7492AE6A76808985AB53976482A1537B696A9A65
77998876757075799368796567677B61979F8E87B4779B55
75788270918E8E7C6F8C777584879B5D47C6864375628569
A4916E5D939551C25681AD78878174516847826F76847781
6B6A818898624E6F83A77891A598627B7E5C7A937E948A89
91788980847E777244A36982759C8575
8805FFFFFFAA00000000E9FF6A1A00009600004759C5FF33
30006553FF2FC98A8B9C8AFF938D8D0A004ED75DA1FFFFDF
9B94728760FFE8007A9266A453673A758DA79E7689838549
75959D840047DAF18ED6005A4F7C8B6A726F898176877D86
7A867C81808D5EA1A0436A8065876D7782758ABB857A7760
FF57917F4F6674806C8759507F7D929A9B73929A629270A9
418D8A6082878A77798A738171576B7A6B7E8A7AAE90696D
91807C8A7C778A92749299818697A76E2F83AD9274767C79
866D8BA68463B576795F952EFF9D3200496E50A27D7EA099
92909D82805B647D94756A5280B57885696E706C99557C79
6B7A8A8AA37A7A65A9909D9A46857B7F
8059FFFFED9F3800000071FF0000F900FFC000546D4D0000
51C20000FFD4394A6B984278776DCBB1A179008382E70000
4A432E6ADD5600FFFF705349B647BF809C837085348D4B58
7A8CC51F58DA0100FF00CAFA317C8B82875C6B2FA375516D
7A6082A32B449E33859289857E81676A7C817FA696537F7D
7A51797F648B4C8E68499D72A05A6654A695742E8E8F7E3F
61968376976D6A8A9E7580867C8D928F9565665881955E77
577C627C7F72A67B597F7B9C70A964A3827952979E9C6B83
5A70316FAB6F7A71897B5828F1856F7D3A9E4D79815B6F8E
868781853F627B8271B74184637D845B8175838B8E807F98
8278569575A28D625974996BAB67B075
00B4FFFFEC600000001C924D0000007F1EF3164CFF7B4BD5
F72F9A91FC5B015B71A9D1A1BECD58FFEF3CB2B61B00FFFF
FFFF98CE00A17CFFFFEFC1C7A5783C6E828B985B9F4A7C98
8B667DBC2A477DCE00FF6600AE6132D44E5E773BAF839F77
B18862A87382695B847B9570A87C6A7A65898291937D5888
748DA2529173777C7F80407E6BB4733B746481AFCB6E7E82
918B987C8A856D826B74A06F99657F916BDD6E77B05F6768
82776F8491597D9A859170876F8C7A7E7E98A56859904D95
6E6649663F7A90988D94AF7AE13DCA78585F9B98496CCF87
6D557AA17D4C848F71AE7D788C6A92877A7E96587B8B8F7A
9697566875C0AD5D7D7A759B747C7086
00D6FFFFFF0000FFFF38F479FF1E008951AD5775FF9AB918
00DA4F5638AAFFAA58793E504FADE2001B5657C1FE000000
24376D946E76857E00003C48551836978567886D91A881BA
A0AC4484A985FF5FEC00E4B5734898619870787B79616888
717B897A5A43888878768A6D7E77958BA57D7576566AFDBB
69AD3C1F8B6B947479905F987A62A965688DD89B815E6146
8E7BAE9250698B9E6AB87065733E9A79918B83677B687E74
7F707E99748F8C746F626F7A608B663D9A809B888A998374
956F8A8E7BA1907290140087A8CF009B257E38768961705E
59B8739F5D858A7F7582817C787485867F8A6E896E908482
5D816C8684B57D675EA4A2767785448F
0033B3FFFF9000006F87FFC327ACFFDD51745A6FFFA379FF
FF3820A1FFE0FF73F6944C5B34628AFFDF82920063FFFFF0
3B8E6EA8BB7B746C5EFFFFAE8EA6A77F70817C4B9267796E
9CFF008DC8D400FF53A078A49C7F7C1B92808F817B7E7896
6A607986709C755B7D6F87778179646C883C7D8979E33D72
8ACC74444B8390787EAD6C80718B81867C5CB1805B8E4E70
9C6E4F73509996768D866E777D6F889C908C8C769CAA818C
75546E7C899C5F77718F7EA289618650828C7D2C6A7E8A7F
86657085A57E67BA8A51919395BBCD8252A0954D77727E78
8A6F5C8A5A86877C81835C758B7AA4628D6797778B7B8E9E
A69A6399AC5B9C508290743C68905B83
3D002EFFFF6E0000FF00FFBAFFA5FFE39EFF0052846B78C5
89FFFF54B8FFFF6A6B4C98852FBB000098FF00000000006D
2CCC77DD51888572826D007549A9A17879837375A3498E6E
E468689A0075FF00C554B14488627A848B82895E88BA766B
77A4936485766A74687E827A8277849C639D4165073BEE40
958688704571727B8A80939575D076855F6391998A62D55D
B099ADB68A88BA7E997C705E845F7C81836C7DA960786E7A
72868679787D87778BA39A99756684758B487F768F80717C
9A83928E6D8D7B469F578B5A9A0074DB437E78844F7F9276
847D8E7A757480697476847C86707B696069718972897391
7A9570A0938D8E775A82629491737B7E
CC0018FFFFB7002EFFFFFFFFFF00FF2AB200063AA68FA5A1
908AFF01F618AC9523849478BD00FFFF00C1FFFFB20480BC
CF03655D7EBF8C76A840006EB387877DA3AF678E5ABFBB5F
79459423FF004FFFF3B796AB5E7C915D7B7C817FA16F8799
817B859C6C8392696E6D88557A7579846AA211FFFFA97D7A
49927633837A737791578B9E6793A48C656B578C777E8AB1
4B942E6964629083747A59888B778F8089818A7766738786
9468A16D7C768F7C6E849559CB768F84A66B8385A3796980
64A18D6350A877557662587E37FF28BB0070707880686AA6
80787581928E898C6CA46A8F5A6B736F8D5B8D767E869298
444581F17F6E887E96678C587D817A80
FF008DCAF6B700000000763967F6FFE6B6FF5E84C78D8D86
7891FF109F610087D33D1C83208B3233FF6E006B2E8A5610
547F8A78906548798B9288004D9DFB917F7A6E438A8E4778
966D8C8F97FF004B00F200C2DA465FA1907C6E7560856F7F
71978C8C628E766C84747C7A6EA58C66991848FFAA3DBE6E
67624B5C735F9B76939C868780C98962915EA06863BA874E
9B52928679676AA16D6D7B8D807E998A72737C96878E8D94
88877C826B7D69728E88A86E825C8899857953AD8D818478
8EA5996E97A27C8A4878739380D6365F8EFFFF8989868A9D
6B8C6F799B906A9684947B76746A6861946E807D938D7784
867CDD6B8F2E8ACB84AD70747D8A5C7F
7B48DF73FFAA2F9A0000B890245494FF8E9860756C60767F
77835EFABDFFA49A3F8390B9867474FFFF4F6E82815696A4
406165868B8A8C77756875FFD8D61F6C8CA267886FAA6FA6
A46E8E4E8166F800FFD575003DB4759B9E92746A7A96A88C
A1906E7C717C959D7971756C886F1CBF5AFFFF00657C6280
64A772916A776E7FB37284B68E8A5E8265A0978E866EA6F9
9AA883537D946196757582A2755F878073717C838376AD71
899A817F9687524D7DCB84B88C9E9C7A816D7F9263796B80
727EA37C8C8F8E72799F43B56D6E8FFF008CA97E9C8D7063
7F6E937C7C7E8F94869A979D7A7D7598848F798F85829099
7855B9007773AD82756D817583807780
1A080000CFFFFFFF005AA266D984AA1F77BE1526966B6591
8088820053FF939114D75E189295FF000E9C7C9A7C91617F
275B6E787652537B70977A63BA8E85768F58385D6B6D838D
819081A87EB469F500FFFF00F500CE806055676E767C7E64
6887758A747D80605677834C8C56FFDC627360FF00B43AC9
725588788A517C7A6F965C76777E499B857F5F7E6A88825E
472B5F6D7C8B7D5F957F7B88589C936C7F607E848D818287
5D8A687DAD887A7FC1598A854F34BE58967C8A7581808180
927594727A6981B646987E81AF7A92DD5B00B6FF1F3C2CB4
6D9169906A8489867451806888788ABA7FA090AD80724E60
98CB873B4C914B7A8DA9A16A8176777D
9A417D299CEBFFFFC08DFE30D8B98393D0E9A3A14E9D669E
7F9B5DFFFFC20D7C90674B906863001BFF1459BC869B8B4F
7CB1956172407C957E9565618688977A889B77AE5C89799F
7A6382A4565DA2A78D0000FF00E18F43A07E6E84868A8593
626AA08273A2736A5EA354CA58FF005F0000FF30B5766EB5
9358A2837B5C737B9E5676886F766D896D435E8175A05D87
CD7C7B8DFFBB009662AE948E9C70758998847F927770718D
88B68C457E85465990D18052A38962846A6C7F94A97B7F82
A4606A758A9367917881846698AF8A88D2443659009EE865
7C9D9D71728E6B78546D568E6A4F766FAA8F75345513FF1C
66DC965B9F8E5895778887738D8B8A82
E5FF3300E7E8005D00003F86364D95A7D8AD1700429C9B7A
7D6BAEFFA37E4B6697CCE25CB8EFFF2019FD875859C48574
78AC936E636B716A71677AE00029C0905C6C7759A358678E
9195707E946D8876FFE20F0062CF1625BD768270A1467B6F
64994D8174A15FA1709DFF0FF500FFB1850031B770964BA0
66696E7B7685C0717D6998757B4B8B7096936D8037645F67
827C8BA7FFFFE93D839856789D756D9F7089758B67805580
775E347B826B93AA9B1F80B35C87559045914B877792727B
6F8E899372707F8E9478709975976E560C5AB0FFC09A00FF
227C68A7638394907E9990947B7A877788AE303931BE558C
00E36490856B5E5F6CA3A875706A8A78
EDFF0000700000FFB2FF54AD6033E71A386A0034686BBB70
6A999B8E786072A4AC76A4D433FFA3FFFF009B708D998974
5C80EE346D7C915973AD9B51FF955275AD848A5B7180558F
897F9A717C937E1DB049FFFF00FF8D05BF5C7EA3797B5D67
759D659F7A00B5D247FF00EC00FF234F8200798C67B76C72
B56790AE7E7A6B7D987C54A18169825E799D908783887E7A
63905FD23C486EEC135E4F828377939F5D8878A594796D87
7A738B975C5A949550665F7B716C7F67837182858B856282
7BB3AC7E828D616B826B94827B828E673B704BFF990002FF
00FCA21C8C7C6B8E788F4B9855B415847B5EA07732F01F92
EEE58994927A9566707766655785737C
FDFFB9803C000000000000549754F57354AB5CFF8360717A
9A5FCDEC2BFFE19F6DB7638F7600FF1E00AA0073519B976D
98745DAA749E6B865484FFFF2A4B82927C8C374478489393
8E716070495C95B778607E4E5400FFFF00F582BE2B33676B
698AC88627C0000AFF00FF003300FF00B0F085AA8D762093
699E877B717B9C7A5C725E5E5D69887E58A09D6D7379B54C
8DA4D90B7E256663DEFFBF559F8A77916C418B6BA3507A4A
BD00F443AA807E987D9D5077977D997D68828F8F9E75867F
7B82808975856A588A5F876777C368739FC82AFFFF0000B9
A8A69D58ED6CAF6920CB449FA53571BC00FF958300C900CB
C950D740B75375547065578F735E7E7A
ADFFFAC00DAAFF0E6268BF466A3128626E6AA8A8769D9593
9F7F000073FFC6A496405194009FFFFFFF13E2F5C070639A
559F827D716D756E410000367F736C787684633B999D7975
886DA98D6E962CA96265003CE98DAEFFFF00CC2319FF0087
51886E69B900FFA0FFFF005C21F41545001FFB7A75859C62
7D6C8A7671555F8069756C6F579584706653898E898CCC72
725857A674AA4163AC2F819770988C9D46AC628382628F8D
4BFF6BB4A667A65C78A848BA70B15969778B7E78818A8879
5C7F64689499A590765D72959BA1736C6B9F00C3002D00FF
6AA6948050AAEF5B2B585FA6914442E200FF5DA324A200EA
7B596998748E6F73936F8A658F887B81
5A9DE5725442FF00B2922B2357916C467088768CA385B173
6E001D022ECB8C8D7093702F9EA6FF85FF36967A63807990
908C89747B6943D8FF5607A3DCABE5827A5A689C79A4708F
96A45A778092599E707261114900C3DFBED2F046C79EA280
39D28E6F009065B100FFFD4E00FF00EC6A5C97807F9C9F71
98A0677D9B77887C879084596C8B829D747E74737E5C1792
7C8E9559571B99E50999EB5591A34B818040A37E6E9D8114
FF0096399E6DBECFB98F8E4E9781858577A4747988797E83
99529A7E9B835CAF9E8497849F7C9C8E7B81836164006CFF
00FF00A57375AA7D725040ABCF7D762A64BE756CFFA344FF
636F5FB7626B65667E4883A575828B77
97A9E5B01100390000006979504E6E548E81966373B83EA6
8CFF9D9ECD9AB286623C4B6B165946FFFFCC9D84868B9F82
A596867790B1C5D1FFFFFF6C471764818D6D9B556385726A
5F6A98983FA475917EB380AB92FF6DA1D490E20092A18A36
0061DAFFFF00A54BFF63640DFF7AFF4A77E438667C89A482
8757898078685A897D62979590A24C9379A0779C69878570
9382B5898BB1DC17B65117FF57C38F907684736592974CA3
7A4B2CE75CD84050916872647C737583776D4D669888767E
658C64637D6A608D6B7A9C4E5F6D706F905395758A466210
DA4E3CCEFF00D46E8C98714E3FFFA6AC002639E51B3DCF93
97454F997182716EA1537A9A878E9D7A
9E96E0F524000245FF00FF8F65758D857E878F677B87C59E
A77895FF8AB4B58063AC60B37076C500FFFFFF936E5FA292
6764AE9795FF15B50009AD755B7C9B8B6F8282678977A2B4
846B997B849232AC4DA477947425FF0B9A3DD8BB10D57B4E
FF6E001E4B96FF420F64D1669B4ACE64AB36A85277965A7F
7B6F577BC767727C5E7F6D81886A766C59789198837673A0
6E86AB626E9136EC6DB90000E400C763784F797E83CF73BD
7E9658818562B14B62898C8A4FB6845A8170A896655D7682
76968EA9628895AC54749688608B70799F7F8784876021F4
DB00BD064F21BD6700FFB01900B79E553D00CA439068B589
97AA53876D8B937F8D945E8279B76686
3B94C78200001F9FFFFFC7A61045A75C7FB1644FC4000000
C4AA6B33888C9493A97399583498CAA2FFFFFF3E20B7934D
240094FFFFFF000021E85AA471817D7A928CA493BF706B5D
99846E63536AAAA67C9E869E969C22FFDF3CD87D5095CD5F
4D00FD00FF9F66FF6DA2576B81758F68B071775EB174A38A
81567A59877F827E757878687E8E4C4D90818E66649E4D4F
96A051858CC2D1EB6EB1FF3F00D22F3303325D957B52BD61
A24F7A7D7F6C616E9E85764678677A7B648A8B7C4E758177
8A6B9A74A77D8A9E918C68558E85717151828195886AAD00
00C9CD1D009700A100FFC160BB71DB5EC954875690718D8B
84967C5C7C9492857389468E72666E82
BF6694CEBE49008A8C001B0038718801C532B800FF004D72
5B0012007FC08D7B846B8FE3A89B4738463BFF000075FFFF
C4A2008D57FFFF0039BA94B1607B75876F844C8155927DA9
7CC4488A9F61516F5249B182767FF700FF8C83DD06E632C7
4BFFD531BB55C05EA4786E4E8CC7626A7F7F49AF7D789988
7A78935475A57C7F7F98868F8B99599E98817E9387A88B8A
A67EA1577B838979DB613DD630A4CD25AD6B923054638D83
55736284726B81716396A36B75C2A7908D616E8A827B887C
8491939A915F7B699A7C7592837E84707681897E94398378
036363A325C2228070D4D00C9E5D81708592818B726A7191
8269678863BD635E878489946C849B7B
623F8BFFEE700051FBC6CAFF9A9E8F004C0000FF004C3800
FFB88872DE53657A564A4DA89D50837C58E100002BFA6CAC
78B9FD6100612300141989506AA99F938A76907879648859
6C79938A698478828B6C9F935A6DA18B1897709B48A26B9D
9100AC4E93876A8C5E7A5F68756CB37E8A8BC46482A37556
83927F7B6D8D7F7E747A7C81828A6D6A83708199647F7A8A
8380687379758A642C74559766798789941F65947C818AA0
879BA3919E728B6E6F86795A7B595D58746A8F598A927B7E
758894898A7E98718094917D5A708E9174A6787F90747286
26AE53867CAA6C91837AB37C81835D6984897C6C59857E7E
6377C566886C6C7795748E8B8E6A817C
8B6C9DD5E6C21C1B6F9E000066532B00BE00354EFFA5842F
9DABC39490EE607553351794588CB66EA05900004CEBFD00
00FF6C227E4D6AA97D748780BFDEB1876F777B79577C8282
77645B6C8D6D967D65638573838463678FA3696272A97D87
97DBC86A895F60898A657E805DAD69AE8A774FBB89978A87
6F9DDE6264A4678B8B6662606F5B82959E9B7E938F566B96
80897971768172749E5D947BAA887F768560905C835B927B
8F727E816F4D6C909F83926272997A939168788273777D7F
9175928DA1807B73757C8F8B84858F7B79A37A6D6F794F9A
5372888C7974908C618975727AA37C9676739F7E9E51617B
97776C7E858076669064856F78619D73
9CB260A8849283854239A3EFAFD934F2FF0055C16C757EBB
8EBC3D00FFAB4E746AEBCDA3A265849779A26886B16D9AB3
FF068CA159729C6D898BA77D5B6C7F7E7F9D597686618D73
8D687EA565AA5F947F9F877B7A87966F845A90758E919963
78717F9C8A8A9E7E3AA9B7629B6A79614F73955F96AD805F
6F6F465B7F9B6B7A6392977A86737785798C77997D76836F
82927E897A7A6CA27974887CA78280867A8395666385709C
794B6C7A785C6F819990988E60977E7D6E8D9DB06182747B
83619B8371A0794A767996707480806688545E7B83788087
A690569B87837D8A7377777C8590607C6D8066A8986FA073
A98685688B6B4265886694565C907D76
8182A18D7E63417C8EE68D2F777C9E722CBE84BD7B987C79
48AC3700FFFF00727D947574846D778E87817671988D839A
6B8A8FAB6A817F6C7A909AB5836CAC7B8C79868B79897D81
7D7372908B848179727195757E748D906E7A767D70818184
8385777C717B8C827B5E878785818A59688A817C8CA97078
7B75646D7B77937389AA726F7F826D7C937398686F889068
8173616587867385777B866F72896E8372816A8179A17E77
618176AE875C806C747A8E6A876B6D799666678E70868C6D
84887A787B877079897B887A79857C7D7C77727281807885
847B787B7A7E77827B7D757F7B88807372807E9183748A75
7B7C82728179767D8276787B7A828578
7326BCBEF7468CB6B7E4AF73B58C818189A4938A658F616F
4A847B7E766A4E857E7E7E837A8C5E639766DF728A818485
8371A2C2757A7A86886571547D7B6959879769A1677C6186
B3816F66396F687E915F6E859E734B5C5069858086747775
787A79677B48FFFF17AE81A7596E628166AE78638080A96C
86859D697E596F807C8A49A9507DB38A6668A8AF55C1698A
59A35E565E627AAD344F69AA7B63748A96A48D2B98857D85
7182648082517C9865847D7E7E7F748589968F928A867281
7E7E7E807E7E7CAB7881807F6C6D7F848C607064BB6D8574
AF787EAE78826F7585606C7D8F49627F807D80845F818173
74926E8B8676857B826864855F5F807D
7A0059B261CAB75C94D5BB88A34C81875E95CF9288A4878C
40657D7D84A26273767B8177A744FFFF007450AFC394907C
4A5B7B989D8199629A5C60797B7681925EA93F6185214E86
628C7D7D7F69809081769258646C9444DB5786807E8B8B74
6D745FBA0ED000CDFF4C00D2D56DCF878837947D94818682
7C7E8B8E7C7296506CF09D687493789A8A535682889D6EA1
758746BB577E89977EB8B7B57B647A968D9D6E768B7A7C8D
4374808056836B87828C777D837E78847C72716F98907D6F
7F7C7E6F807D7D997D757C5DF0D398944872A040C5C331BB
47857E4F887E8080659F8D7F6B7F8C7F34877989977A6E8B
747369697F7A85797A85816178747E7D
9E37AF96C7D0974CA64196597EA17E753975685BDBB13D52
88D42E94835779885D7F678000FF4500FFD98E76D9638C82
6A51946E907C82866F5E73798C6F9A7A84605C59884E8C9E
736881668C80798BAE954D7F9F6EB8D1387D599388858093
7473F0B9F9378C634B7F325077A791405F4FA5805B7F7B61
B986766B82712B688640E19E3A7B8D465D9877884CB29939
B06B8CC69086837C7C7975797D7585B14A6478B09C928180
8B9393786F77A0968BA2998E5D837D7D7E8E777A6C878286
848784747F7E7F777C8D6F811B5B59C9AF467ACE63976688
7F7E7E8A5A6E7E7BE1618E698E72837F877D7B918487818C
8782666E608A5D8897858D70A3778080
814C6943FF1A64C75E588B557B7F88971E72E136ACD9AE7A
6F6658679F61A67A6200FF0000FF0000FFE0CD9874A09842
64957290987774883F86947D5B848F8C7E776B7924A27E87
9168657C7D838372BB8B99786CA516CF74689F7285A78763
FFE0715E8E5AEB34737C8EA2657B5B4E89C1727B8880958E
7E9C5BC354996D8B7B9E10A6769C547B755AA22A6B86984A
926B756D66796F807E378A7C7E73806C77767C655A935C91
6192A981A4617CA148758B949C5F6C7F805C7E7C6B767991
86827F997B6E85BF00B399B89C4784B6337C766BB6C46077
61827B7C9A6E7D7F804887886D70766E807D7E7C7D837582
9073777F7572897E97807AB498C9777F
8098599C8600A0BA318DBF768A8B6D615360817856679973
7B31776487D329DE0000FF0600FFF01FFF3EA59BA74A9592
4B9E9979817E7D97707F6AAE759046897A99899968AE3333
AE938E716A88808B70815F93743B007441E200D1538789CD
07360F57B48AA600987A739D84955DAD9E5E898A867B9A84
BA5094E9707D98667F768D57CC3C9362B67C52B09952917C
9F5D809E797C7678AE59857C7F817F637B9C7A9D7290556B
7A78656C656CAEA0507B5E9C876E837C7F73727D87836E77
83848C68808000A3B96B91515363805A57A1659A75E57566
78619C75A27A8B6E80817775418F677635877B7E7F777785
6A907C787389838A8D8B8E54BD53827E
87745A2E3583CC184F9BC76E8EA18875A974808B7CF69C3D
FEFF00906083A04680B9FF2C0094CA03C53D63768759A54D
9D577B709A786B6ECB06B8A38B5253907E997CA08E63A3D1
63617662937B71699F88C7865C0000FF00F9742B527E7B4F
7E8CD57D556D8AAB8178885F8B647CA3DBBA9D746C846E7A
1DDE489186B4727F7A90A95B74A700CA838F8D7175767D71
72968B92697F887D78818071667D8E9E7B847461707D6C5C
6B877A9F8BA6748B7E97755A90A5767E7470807E74926FA0
76707AD70FE07577668D6AEB75957F84A96D7A6B4374839E
7488A59C79906E6A7D70646F6793656B887D7E7D7D857A8D
934C7ABAA56298AD7EB92EFF405A827B
8572BF9E55C49F2CEA00944E7498784FDB858E56990066E5
3F007286A57B7D8E6F504F988EAF93587F9E54899E437D7F
8D886E8883986DA11D249D795B518F99829D695C9CA08F3B
C5AB82A36F88946039D443A627FF00FF93008F8D5479929A
AB98656A858277798A876F8D8A636869969656A18C677F82
896E9078999976777A977583805B565AB3607B886CAD71B9
3667B8806A8A67827F7B7E8172776A7A8C9877AD859CB469
6E824F826468A9C0617CA0A36C5794878A7C777A9E74DB00
A200DB50A349B18542B190DD9C757093A89C7F5383827592
96925C4E95698D98409BA87D7E648298787F7D9578776B7A
712BC78D7767B48CB776AD4D9E807E7E
815A72884E536B8E6D7CFF4648848005B9908471C4D25300
BA958E8D7B77DC8B68746F6282857D867C9A87728C728885
E848437A945B9885855F7B73659C4896799BC06E8B8F8186
8970D9B43297789093B60064007FFF003397578082826B84
528065A5775F6B7F60867DB0796893867A89626885509F83
A092B984929061827C8D617C83848043E09F84AA8EB7B23E
9E8676A1917D7A697E88718D7B7F817F818854896768587F
7D98AF929C86977D798D743584B87E89798D996EFBA45576
368D6AB36F8B14B3468291339DFF876B88699E669A6B7193
96A1B0BE8D8B5D5CB4884155727E7D7A7E7E7D8495718C91
926C88787C66B703DA48AEA482857D7F
7F7A1A779686A16293CB25E012D97D4267FF007AFF0000E1
FF605399A54DE8AA6E967367826C517876768B755A97BFB7
70BF4F8E5A707F91904C534B826C8A927E8E7D6CA93F809E
748C5D64BC00B46CF400FF1EFF006C88C760A28D8C667184
805C8D86718B6D7B8A718778723C878F977C0068955E5B48
6B6C71AC9380857E7D7F919C8A837B9B39D7609F6B6648B7
5F98A3797C837C82747F928C747B7D7A57708E7D7E636D8A
667F676F99484195766FA0D18E33B168863B65B5998287BD
7C69B7879B57AE62CB449C906836627B99928EAB9576A2B6
7380A7846341A08E49A93B68D9AF757F7D7E7D7F969683AD
967E7386779B00906280727EA165827D
73844D56AC426D915EA047964A9FE770FF00FCFF7912D238
838F37CD926AE69D67A1719C7D8C699E87747F8B898D7280
9C287D6579AA84A7BF806B5B854669857E6C77506F675A8C
B1618A676D8C843500919FFFC44A1A7463578F78705C94BF
893E719A639080699795737F9067878D8000C9496D5D965B
665B868494677C707C87656B6B8B9D7D8978AF0F7C5F176F
AB42875E6B748B718C938C73AB69819D82886B638DC8C0CD
B8B267236CA69D0092FF0000F18444866885A272715F6393
828277836AB27EAB499DAF5D77BBA1588F5C788484877678
71798B2A7681BE956E836C7A869BC48B857C7DA07F706C74
76EF7AB8CA00845E8484C2708E6B807D
78B86C8F837B506276AC804C5C789B0000FF55A64A610C97
A17842A87447E08C8B8B838E797C7C8B9B7B6A8274B2866E
A7E8603DA482A07C8D8E4E75808DC7857E98878B596760A5
61725658776589EEFF1CB5C86100A774777B75998AAE6B97
8D7791D867769C5D8B99AB81705256BD00BC6E4D8D75885B
956D8A6F809751877E7C80A98759797B86634846F65BA38A
7A517968633487915E6E706761927C637E8A6A7280676D52
B06E7A85D400E4FF0000EE9D65875D70879F6F828590A5A3
6F7D7470709A4A52A99D9E97947897A65C807C87C88E8E7E
7F8E8F526D74896B98755F6E815F8C7F7C8874827C828A6F
9F00FF1EA0BA7996549C5B5A8669817D
778C8B4968858060C175727A89777E98E7824E0056886878
A470703C89A6896C838BBD895766968163648A8E8FB26966
C483328F73818876888484AF7CC265767F879DA35B637562
7F76A8555B827A3600A6A6FFA2CD677375779779749B9D83
A08251AA9D969C8F90987D5F547C6883E2657C858E7A6B90
6788787F7BBF99717C896BAD72619D4C8A7FA0A2B05CAE7F
D25EAAC871894F718B7C8490876E7F907F65917276315913
4E86A800BFFF1218FFFF5185824C8B9860A2B0627B846785
9F4A6F386C65A17473875C648B5073887B7268927C738982
5E619AAE7B59965F3693AA908DB98E8584775F73956B939E
20E15B994774BE91918BA66CA77E7F7E
7D9C7070B489B889B38D627D706C94FFF1CC30CDD5225C8E
D99F6A758568628F8582A6A2C98331836F9C977897C31BFD
665D90B28A6EA162AD8B8A949288AC668180965497A07A68
6272886B7E6952C8001C4F970085989A67AB8568923B8E59
69787990A7717A758D6A835293A772DC7CA6917B91957B7A
926A86B2954C77778167726E857D80956D7F86609681919E
2B794F9676645F9C788E7B7B8080819A585B7381517F4F06
A071CFFF0032BF5E19C13FAFA883C36A8B927F796D4F986B
6A9C9D948B8B72756574883886887E786D898B87767F7764
837971798C85598A85B186838273817B7C7F89835AABA62C
9E488A8A898C5B8592A38D99668F7B7F
7A98687092739E83DCDD52665A789500FF12E4CD8587838A
8BE65ED0A03A7998A87E5C43CF6857579E83839358CC0086
B67F617B69A4A77DA9B6809B865C8D7C816A8B5F4B6C8166
5D7D64829360685AFF197D31B96D6D698D3D6A5865CA8080
629C96A2726C8FA872768E9BA39DB2619568B96C6F95857F
77488AA25680717E7B8F73B8707275695D9A7661779C618A
35EA209FAC585489717D85657D7D627A72A3678E5E8F63BE
00FF0000FF118C8DA75AA67E7B876E706D586F587C577A73
6C787083848D8091789070867C7D7E80708F7482895F8078
7D8485778279827D4CA4678285A7778A7A71A97E8C2DBE54
8385737C609190566D5C8287536D7F7D
759A9092854F7766A3756B7E60CC87696400B67088957472
20BF6189833ACE778998796EC4C5888A7B7F687B4AFF4E78
65A4605B60ABC0929EB86FAE5A5276787D91996982749A84
70769372508C9F4F8F00855F7997797C929EBC8D94A0786B
AA6CA279A87A6D6C8189788990706167778F6F7E887989AA
8D74848E7C8F9E6E816B885BA3C3657A6596756178728855
986D5DFC366B8E5A71AF8B817B7F5994778F836172B146BA
A300FF6D0C6776A444A18E49676E60746E847593678A757F
7B8C7E80717C85796A897E997B827D7C8A88808E828C7784
7B6E735F5E8787888F8FBA96685B897CA37E9B6AC87E9198
669F5973959773679D919D9C4E7C7C7F
779268DD5B9FC08DBB7FB1A152BC66894AFF95CD7192B071
74C0404B8C8468978D3E679BB68A55679E8179738F12A286
63AE98A56E778C4469876FBF8F874996808175878E6E6796
8EAFA9776950685C4DB46E729268919597A16B7676879D51
A674793D9EB26C8F688C84805D8E655E465AB879625B6272
865E6E78969BC08B7D818CC26D876C60538E577D9A616F67
9195959AAEC66597557A8374925AB25B9C7E5EB63DB0B100
62072DFB9A8C715B7A696F8B77988E7977677A7680719984
79727C7C7F7B849F7C767D61876C808867849671797B7779
A87B82519CC67E94908EA87877787994837D795B8872A86F
77838C55816A7E838176817D9053837C
72B167C7727B972382ABC74A8D93926C428000C3929D768A
7FA2607C891BE25D83935F9FAE6B7A787F50887C7E30AFA5
A9657780955DA6768159806E714A648F7E82818A4E6F6464
6269938D88736F567B94FF6C7F7A7B9B867182766181708A
5E5C8D6C7289856F5D7D7E799B00B27AA28D825F9AA37980
5E8F72A56E8D7F6A816A89698081A0929A549653938B8888
8777999795A373685ED5AD927653899B8EA6D29D80D39395
75A5FF00C975A942769D8E59A0847290797B829D856C6B65
846488869D827B5E7F5E825684798672907D7B807F72677A
795D828D8D685C929092966B519B4FD45A768A729D947575
78A099966F9C662F987D7F7A875B827D
7C865F8B5B7C9DA3AD8585689EF17F8477FF348981C47483
55AB45A48400BB71868F8E74B1807F858192918842FF4181
C282ABAB697E77567A90989B5AAC518383827977956C8F5C
B09B91965B80A464B8664991844F7F5A77948D8A6E8E765A
799979676E966080747A70836DD77A7A36A49C5B4EAE7D72
6D968A8B778766737E7B5573727E498A7B7C97768C559490
735A888A87736F724B9C649F9993A46E7A6B00E4A1566CDB
D100E0FF74F206A576846D7589809F7B716E7D6585917A76
6199967070B091735696749E7E74986E6D69837C7F6A9C6F
6A8852386A747F5E5B36B6CC25C6656B75765B708D82996D
75966A86846C7F9A9962808A7B717F7D
798B72A1337F486DB065897B79999AAAA4CCFA8A89A1837F
1C8F5C85724CE0906B6E697F58825788A6706E7B7FA89F86
CB8685806C698064B563913D8C85707E7C94A4958F888469
789D60805B5178848C74A37A85686595778A7B7E5C9A1095
94738886759887858E837A7E8658FF578283BA6E8DA28CD5
5C445D75746A86687F7473868C6C856358AE728F65537D57
74AF8F74786E8A7198933B6284907EAA9A7432752000FF00
FFFF007FFF009D6E7E677E696F886F788D9796AD81928850
9279A2677D7892976EA89A439DB1748D91956E807D7F7F7B
8C7F62727A3B739E80D160A5857E8B8C92787F84757C7C7D
685C84975D8779846D7BA780857B7F7E
7D948FA570905C7B8D81AE9F587E5A5977D56E9B729AA491
009766686339E6939A786E416EAA605C7A6F907B789E19A2
8E566B877D607251A15493595F72687F7A639C4B5D669A44
60BF6874615C9775637B81857E76936A576482797E51A979
828C8E79BB78928E63807E7D7D845C897ACB95787D6B6363
66958597928562787C85948A705D79857D566A537A9187AC
9E5F7A767C6E897C7E76787C8D7A59E6A07D2175B5DA00FF
00FF00B843CF91BE76887E917A7683766B79996A9B787A76
707887965F4782557F787B88816935796CAC57827E6D766A
836E7B85A9767F78A90F924D5799937E755A7F8291707B7E
8A7E3B7FA37E8E8485A073A085817D7E
846E32816D50627EAF7292708B6C83A44CFF009F698A4D8A
6D6787496E777B6D7A8ABD706A5B615C7ED2AA757E709A34
76235D9E897879597FB076675C76736985609C707E8F7F54
8146917AA4B59E868443986D857E7DB26EA7629C8B5B6389
696D5832674F6389C700498B819977CC960EA0836C967D73
6E5068754E6F7076807186657F75638958948677895A7872
938B648E7C82728077A1748458823AFC96A8D2000000FF00
E851FFFF587192987286898680727F5F8F9E6A8A9E87977D
B27E6988828451A9908181575D8A3C6E9B877B7BA8998785
9961B88C47615932A98159897B966095717F7E7F7F8B7647
36889C4C8078817D715164809E817E7E
837FA49A597AAF88B6A67786796C4C8F2AFF54A0607E8260
932CFF85C18A61698362B679A295476968FFF7707D7082AA
5EDF407FB1955A66588364748F838279797E876B786EAB92
53608295547683A067E37376867B79696C787D55785C818F
909D7B9F6C70609C7CEF7E7579805D98816BFF76C290917F
7481A885757E99917D866E787C786E777D5F7A7980784982
5DAA8B826F9A65477B72716F7878AD38CCFF4A67900C00FF
12FF6451839C77897B797BA19D5D787987668880739A4BAE
6F80767B918BA27C7F7280834E5987725665776C7F808381
6AA29E77AD768BC2597DAEC58F7A7D786B7391537A795DA3
9C778170606DB2906EB76A7C6C787E7E
8087756B283A435D8E95816A83878F7DC200B47C6F95734B
8E7D9EA69BD38ADA9066955C8BA2797A8D1CA67578799A70
996FFF626E6F5EA28B2A81817B7FB267865E80878E866BAA
8D658A977F9089679F008B6F7A746D7A628F808F7FAF9996
567E629E8E997D986799AD7E867C9E527588FF7F68799377
B278989AAB9C916F7E7A8B927B886B6C927CA78D787CAE86
B96669AC956F97968E905C7C94679B8068FFB0D500FF7679
85B07C9DB4747BA4707598705D7F79816B978E848366728E
5B7A6966A37E88706C8D796A34678878939D6FA089637F69
5B8F9A4A815AA3879B73968A97A26D7B79905934A5998E89
7183559D6492787E905E6E898761817C
769183928C607C4E7978AF815A6A7E60CB1BBD8E7B9AA09F
969961669662EA928D61A07D766584907D80B0717A7D5990
6B76A4809661739477808A96AC48937274AA8A9C8F464C8E
7D77717A6551668A00697B999670687C8783628880A25365
3E9B3B71758C576E7A83BB777D7E77A36E7AACA3889D6C7A
889B8C5F4A5C7A897E7D626180837A777E8E7CA075869177
7C7A758F5571826E7A5E41A0878967464680D7FFE8FFADA2
008E60847F7D7B5B9E767477A59B7F8F664F866D798FA47C
718A7E7F81946B7CA1657776599283887B6E44BA8C9C8384
8E82A56A6B8A4B7F928E7E718D656A6BAC748D7DACB78490
AC8C9E7B87896E8E4985A6629A53847C
74AA59938F8B918092BA88834BA19828FF6E9186838DA46C
8FA04178AB44F181698DA98E5F65895E92C396777E7E8871
839045528A888063828D84998D7AA08A7E87996C59857454
65A3AE618687939CFF308D687491856B6683837270514A6B
78843D898A61837A76345A817F7E797A7F86905DC368A17E
7A5B8B927868A87781688176989181849F7F646A487F7775
6B777C6D8CA4746DB8799AA4A795A0A7FF898AFB0001FF00
F95F91699598688C8D667982637E6889966A627F607F7AA1
857C7D7D7D869B6BBB82A297868885797D7D748463756776
8B898F637E14FF8F7966757B6E907B7663938C9687949B8E
857E8795679687546A705F7A935E827C
6DAF5699447E9F887659495B8A7D6FFF06C475687B83A0B6
4C736A7E906AF09A847E7B468F918A9DC23DA0787C7E8188
9E5D7670FF5E70BE8672998C868452728180B7708893A58E
4E7C676E723F46AE249E72827A7270A18E9B506C7B7A7B4F
5980766375636656696A8A8A7E7E7D835289739296CC8D7D
70717D69768C73747C878F835E6F7B6E8183728A59A76E5D
727B8E7EA6A1745563A291646EA4ACE400498EAE007E00E7
307A67917D9B8D615C758C7D8E827A67963F7A98696F425E
9A7B7F7D7A7E769F526A8D8A9A8E87A4857D79B1796B8864
A25B81A304FD6E8464985A9E89888D6E7270909A748E9495
7E9A627385825A6C9583969676A5797F
7D7976884F7D554DA76B8A73864A6CFF3600847C88919387
A8789C5F902AFF906A6F618046BC7F9E516277916D747DA0
835F69517B389C866A72417FBA507C857C93A07D7F639DC3
86779378305988727C9E8A797936BF581A3EC37C9375657F
7A78A087987E7F846D4C897F6F9D788782697E364D6B6BAF
907FA07891AB96847E7A8F707B6D5AA3948A7E9D8975A39C
8A985250838E608878A3876A897A9362BDFF43846CFF6E63
9A898969776A81B46A698363825E8F55918C79858674769E
5C8D7795BA9B9D7456A18A709D7D787C75897D7D37848B96
713B80C56970737C8F5D77816745A470AC5E7B7252AE7E4B
97895C5E7F827F6F6348667699937C7F
8E527058913F5A7884816E71985D9FCDFF00AE878D50B363
FF00FFDD8782FF555569797E4A79B5688B9663698D6D8469
897C95809000A98C5950913D9B79C4857A8C6F819E755F81
638388687E5CFFC50081718069A3B56A8E925DAD566D9D74
7A858581BF60AE7B6E8E6685687785AF767083837F5C6791
967B5FAB667A83A07E817D7A9163A47D71A68D4A7293706A
92568881B9B9757B6EB774AE7F71737E4E005C8EFFE86873
80886083858E82506F868999AE9D7F9B6D63738A869B9F76
5E6B6D9F54BA7F5E808D597F81749C557E8E7B7C9664C278
738D7F5A83806A796D797B687188937888797E48A8979FA2
559186986265836482B862837D59827C
89576366789A9998945A7D4EC62AAF00FF00E9B444668A8C
925D84ED6277D0A7B1907AA747925874997D7E787281BA92
70857F816F746869A8907DA491502D6F808B6D818B6B926B
7BA27F9888BD3154D48C659491546F918F4E86807F7C7F8C
876F698F55C1636B726C6A8B576E78937A777E72505F728C
5E3C974A8191A8907C888A7C7C7999823E6D888F74736C95
AD7679B09371A37170908996837D728625A7BA35685F7460
7B7F806491778F866B729883997B7C938D6B7E647C7D797A
627881595F8154AE5B6A8A78777F59C15AA1827F7C6E6C64
847D726A8575636FA16461805D626C9289B0664369766D87
89688588669C9C78BE76D29F5E8E7B80
818A73947060789C8D8A7D5D8ED40061984768A089AB7795
A15B61F98D919495687D7156C494568F70897E88B7599090
866D5F625300A1B15B8867BB7169AF7B7F7595A6648D9840
7D7E5FA2525700495ED486A17F7F8A99A1A95C848C86A186
896AC7789771796E976B8284919EAA95738A8387758B5037
978C806D6E7D656C7F777097829D7387927FA66E8863559D
98A9798D9355989FC47E5EB86F686388A16C44FF2A9F747D
649191688C9095698E6A8A91835E967D90A952905A8A878F
7D66857D7D62A96F40A9436488A87497AB89917D81727982
797C8A8A978D6280839F8E836087554686826D8B806D833F
7B6B88865A76535F84825E975EAA787F
9174897BA38C7397A1527FA17EFFFFB223A99785806E7574
648354B5848CC84BA58A8D876C6A71797778766B8E95CA56
7C91987D7E7D5F559D6972609E5A708F7DA2AD8A8D71847E
8344806A985DFF889EA3967D647AA258848DB1879B975F4D
9C888B847499559A6882797785878378838288866E5E9C42
A1866D7079A77A807C86C3898376858C8865948E69A07974
926C678480866F97979A6D885FA97F7D5B99A98CFF108C76
885E7E8F764E8C84A37B7A82726E849371727A9DA360809C
6A825162909D6B8C9D816F9C636F578A80728D797F7E7E7C
845D6D587592987CBB8D6FB7768BA54C966D7674AD97AD70
5F58947D7BA15E8987628CB6A6837E7E
89869E7FC488A493948388A45C9754F62FB027A25468A070
8D867C877BA15F867FA385815FB762429B8D848E80716C76
848667758983707576798E88C676666A838A7BA2907CA8B0
609595999B70632A7839637E778150788CA69F7A926F7A75
696D6A896DA26DA44576678A78AB78937A7B706E709474DC
6D336872B0509E777C8D8683A2547A796F98678E797E8C88
935D72C67B6F9C9CB581788B808364679166928B5DAD8567
7C68637C9588908E83836B888C788B74A0A187907C6E628B
7293598A887582927689748462617B84707587877D7E7E7E
7A9B6076778264696D929061868881A09C936F8F99549064
7789B97A76977F637D9F7095999A7B7F
886C865169815A9B5790959D4E5ADB0579D028AC5A8EA08D
75776C7C79A55A9285B592A85B9328A1AE698D7B88879E7D
6A77897F908F7E34709CA180697C836A79A181846F6D6160
5F4AAA86705591CE73A18879708B9673827F709591839174
6E7799968A738F686F7A7F7B61837F868572835F696B7183
6A7A79896D989B7A816E6E88909783ABA66D727E79907668
BC79876E6A7683548B88769F6BA46E70A25B9B5F856E8D82
837A7D8B6A82AF7C578689947C6E778C8E90808F7E7C857E
7697619C6E92727E6A836090848869715793AD78807E7E7E
7D8488619C859FA2A3718074886685905F7E718281837365
90906D996060899283727F918B8D7C7F
7E79B0804D7F82D94B7E8D5C52ABB71DC4FF2E5C84894C8F
549887648A89889B889770695D655688728C788680998B78
77708A699174976942747D7E6A638279834C6473947EC5A6
819188777C7E153D7D5C7E9E79978C6B7D79676587785B69
7951677B8C828A36797E7F7C907762897B866F8577787567
956A73563B6E50607E7A6F9686786A556E5F86694E78716A
5EA754A6628C9583995AA56C81897D338B719772826872A0
916A9F5F947E6D6690A9657C90817E7E726EAB8081997C99
8D8088C96C9D6E87667B84866F51718F707D6D807E7E7E7E
7E7C7D977E7E8A548C79856088858B7B88769C5E746B868E
A27C886C7F60858BA7577C4E76767F7D
777AA3757B68776A806E985C854D5D273CFF29498E9865AF
6A76897F8B6B9A84BA8EA36F668D5C6DBA807C83C7898767
72749C65978B72AB7890656A808A888581718662947F636C
7575798C7D6DEA955C6A656E6E7A77887D75738A96966770
7A80626E67916F67B2858C6DAF9573807975818484A14F7E
316D7995757E897F7F748EAC7680568690798382866A7F92
74997C75505CA179916F6E6499AC6A6D5A977EA05D7A8E6C
547C31A27A8475927F9A707D9476806D8A7B6992859F6D58
6C577A539E6A7A8692928E8B8192698C639C73827E7E7E7E
7E7E81847D718D637B717EB07B6868819B8B82728B4D9257
866D68775F958F588C81837F905E837C
79A9766D59793C9A83687FA3B274B200AA634A848B828886
5A756F507F6E73858B8F8460AE6A6784AE7C72678BAC8770
8B797F8A7F987AB2A7789F8F7C83946B79663C8360806E5F
4F969F5874BF9B777F76429F6582AF867F8C9E708D6E8D70
68589F839783955E54A0787289835D857773716E7B6D6F94
90897B95996D6A917E7B898C7781877889688B67799A3F7A
A47A82907B898CA75FA47D8D77816F6B8353997B7F6D6C75
8D8C896A7F87647A868E918D9B4D77767E6183856B859C67
45A4B795716A8C8290808771519D7D747C80A8877E7E7E7E
7E7D89728F83608566637373847A79607E8C796F8B80A05C
5C677E9E586E576A7D619457AA9D7C7D
8561502F837668947A867578733E4598ED53419C7E9881A4
727F7A796D54A0477B9D547148B6848190A578777E719571
9671A6618F76786DA06B8B64433983767A9D5B5F9D677E83
848565609634795B868A7C977C8861879F80778176747079
7676928A8098596E74BF7A9A5E7579898E869A60867F7177
959D733F6F98737F7D85859385A8656D697D88A7958BB189
7C7F75816B9B898550818A7D847D7679819A609B85947E78
786E72717C97C16C6C8955847D7E786D837984767C897B67
83A0827C90897B869CBCA0B77A8781926C906B957B7F7E7E
7E7E7D5EA0C8A1698363796F81826B8C8898777798547C48
515A718B855B6F7788878D7562717F7D
825980A5BF8B719D6E81B6AFD12AF84E06C4549D7F7FA892
6E8B68808093878D7B90AF915F9569727E6F7B66626A838A
996B6B70997E9C2C7F1A91555C518987856F659AA38DA364
9B5B6B876BC4A88857787A89914F837591A979908A674E68
657A5A683D7383BF8C947C7B8E768A7E7BA872827E7F8083
007CA574616C6B79826473A0624AA392B576959E7298818E
858B8A6A8A74739C7D74846A8EB68C8E767FAE7F7C867F80
77787D7986718D986D7D766C5C569D528C537536968E9C7E
8D8B7AAAAD8C7171957C86897D66948C504B85797E7E7E7E
7E7E7A9189645AF28D97986453A08C6A805A5C9B6F688EB0
629860708A6E94887798944D89807E7E
8289843789787B94815D728886E08AA3FD087C647D9F9675
6475766D6A677C66A78D756887BC6683477C84658F7580A1
79808C6D8C92786F6C5265C5B19EA17C7E7E6B81A5A57D7C
9680768642708A846D9B59CB8C6C716C7A7C6A7E8B567450
9F73806C64A26E82608A86AA74917A6D5C787F888D5E8874
E180978168B6908F7C896A6480806DA9718BA5756D6B8A8F
A2447D6C779D8C8658AB6E907C9C7394A3588C7B908E7A75
8984917497928484937F6B82718285759C7975916E85654F
58A87B6A4583987E867A9C68954379488160807D7E7E7E7E
7E7E7F71A9B734AC056047C994A295AB71765C4785787685
7E5D80687C72817194B15A787A977B7F
7CAAAB6E9F847A7C5376899710E397667FB010547E726F7F
7E6F6884878F7F8E68A7978EB19A4871A97986706EA06884
717B74887F64A96D5A4983657AB3B06A7A769B5879878480
A79C6F6E839A4E6C6FA44B977C955A837E78A2AA84956B8F
78947685A2455D85B0734F8C865967977C7D915B7A7B7F7E
7673A4A4797D8E8B7F776E82786730968B616A7B6F6D5370
6BA08599758F8E76966F757B90629F8079775E918979837D
7D6E64768A6D62748B877B806C8B74877D7663896EAC796A
6D927B87788963AC607F80716BA181A0797184807E7E7E7E
7D81807E8247676EBE851C9C6A7E5F7973969F6D73875F5E
847DAE928C80987C7D88864D52897B7F
819AA73AAC5B53926DAD9E8E0000417B498257007E785A90
65686E747C8A96864C758D4F6EA67B7D9E2A479B93988F88
7B798E849C52BE65F8822F625B8B8D7F7F9476773E8CB380
44AF775F7BBB82888A5B6D6D5E817D7D947B848571977B6E
708E4C7581A737627B6366868894937D7B8069A78C5D6572
93865882477D997C7F7A63726F898499759A7A8C8CA4AC8E
795067A79F28698865604F9C85799B8E5AC4746780696E78
7F78907C906D7E7B8C5F707663768F82618C7D6649AD6094
8F7183577C68604E897E7788798B9B96878BC38A7D7E7E7E
816B737E7C958D876BACE5359D5A7171777E918E997F8491
717E6A748B806A948555A76DA1B37981
7E70998777D96F9D779053721016537E3CD771287A7A8B8A
698A8C6672919D756671A38F35817B6E9C5E7F83855C789A
82787F929B85AB6B3B985A9365656C83884B7CA9655E7879
658B886AF79EFB41B86A5EA67762798178796D6B6697686C
9E4C9B7C795768617B826472807B886D6B808C7099677989
6C918E5C72637C767C81A8A995896F6D7F97915F99B77185
A67C916186A372907AB98D783989737B8A936B69617D8362
5F8C6F7A647685937B7B9E846F9961746D7C73954F7D6C8B
81808250717B866C958095806AA973675ACF638F85807E7E
8073777E797A8C64815291F157B18359A67D9C68869AA8B7
6E93A874887B998C9557787F8CA47A7E
8082915F80A38E7599B3657439FF296A79A100A65F6AAAB3
559B994A739D7F836DD18B9275AB8E8BA178739C8E6A7D80
87868165836CA6A7A0664A775D9F73927E8B888F78AB83A5
9374A8908486A1713CC85B705B85728570675E7C7F889F89
95826FA468A08A767B9D818170748F75686D988189B46198
7A756746C2548A847B936061514F717774A26171A5988486
8A654D795B95697873768271686D817B8574978B5E7F8481
83747F688B837976759B7988848C6E82765DAE79A54D765A
827E616A5E979771A65F6B8C98A67E8366848B9E636F7F7E
7E7E7E7DA1668D899E57AB7AEE787290BDA1665290638157
758A7F7D789C8D6FADA5916A638A7B7F
7A997D5F936A8382767DC555C1007B7F6047AB6F9969BD66
8577A6586D913D63977C7AA5A78A679B5A8666878C967581
7985788DB679716B4F6E60627E6C62977D8677688B7E8B71
8BA481846806A982B97F8F669EA2828C7B708B704F7C8064
848C71918364818379827E888C8C9C72718467606B83AB81
528942FB847D8B877C88858B8FAC5871937B7378705AA156
797868907F8D725A9B796B7B9180916A81C6658F6C719A7E
7C82896C82927181978A77897A6B987D6A6667787C7B9478
7E718C69A0966D5E6CA09C7D77907B77748F585769827D7C
7E7E7E7E60749B66B257877612686E7B718249BDA16AA87B
9693838572997B57847F94B7C276817E
7F777D258E7E5D753E657F8F4E32F16C8A946D8377549284
76968D73918248977C70836F7A8170708977727865727077
9761817BA0750BBC4B6A4CAFA587778D7D715F9163A79D62
A6707E8BA65E31EA60928B7E8782B26B8C75936A8975676D
779E689B7B7B6E8171537E80927E878096826C847B908E96
9C809DA0528B8E7E8267A883998457A2A488735773B69C90
A0A65B6F48936F7F9173B65778547A666B118864838C8089
6482827984A67A809184758780948A8B75759F649B83507E
9482738A758B69814E5DA09674867EBB71898F6360807BA7
797F799B958138946E759E88ABCE85A67F7794914F77847D
815371837986737A905791967765817D
80AB817E70A6748E86687C8479416CB53868926991658D8A
5E8E7574747E779F6D617F8F668A7F857F9B745C86759782
6A5B925566596C858E5296867B766A8B7E705F5D4EA77E7C
3488875D7BD7D6715D4EAF996A4CA2996364717C7E998A79
8372A9677F986B7389847CA38C838E8C938D96647F7E6664
7B7A727C697C6D857B9562A16573827F5C8E704E6F377377
8471677E705074368B878E9663857E9C90B77C7C86968199
90776785877960857D8C6B8079937B92837D88926F7C9178
8966806184B085477BA18B8169848F85A1BF7144717E7E79
7E7E7A998B808A5A65718B8A75043C8E6FA99191735E6B76
856EAA827AAB5D8B447C9653585C807D
7B9464759D838B86B78375513F6B9F88CF977E859A7E7266
828F648A9B637391548D939690726D75607A72848B75986C
7A595E529D767B989977766468827476876F7B9AC4A6A555
8F63BD5D706E6832C269878B4E916289746C9584647C659A
7696798E81888194738F73835F8D9144957684A6A6286B9F
5DA3527E8A7E7F8B81699A738676779855867E50816A6B8C
73A38C9179899585819293979A6C737B8C8080938286899C
806F81738C868E6C897899798B8A7E9882766C969D6C77A0
96A2748F7364628F5A66786B7F537B6A7B776F82827C7E7F
7E7E7E7B7F6B7252848285707CA4FF3A7A70A086B6A06494
7C779A7D5879826D958461A7707B7C7E
7D645467B273977DB84B696D9374CA792BA7717B7A7444A8
948178846E807068587C70897A79778892758C757683636B
986B6A75768CBAA28D8D2DAF918274947C9178748C7778C2
64416F5B5E9F4BB885767C7B627B899E747A889B6D8B866D
8D6884657F68937481A674716E84D44F7475B9636253887F
6A447B937C7180817B92856D7460654A897AAF606B917795
88509A74806194728D7A6D8E816D6F6F79777287767A828C
8D79AA81748A7A8E7F7A857F8D807D8A91A256794F468361
98948A64B67A87387EAB7D629772A45A73728390927C7F7E
7E7E7E7F80747A4880777E748EA0366B6F7A657A787E629A
848795B08A8D678E8A8B8AAE594E837C
81677180BC8AA78B77777A6A897239AA00CE91A04D5C9A6C
86766C83819778926C6264607D7778875F77787C8E676F3C
5163DC9FCB29B38C75767B7970637A7580877A8286A067B7
49738D98CBB4B9529E066AA3656D877F969A938D647D7A54
806456877C8770737A8376687E767CD468C46D99B13C7185
8A67937B5A69777F7F757C6C7D627B657496958073A86E86
78737898656273996872726C6C6795BA694E836E867F6386
767B86889A7A936661808179738580816F5DA077A0749F8E
869481808E918F84AB676D60778CAD6C8A9E8E91797F7E7E
7E7E7E7E804D847D82947470837A7F457280BE6B6A69678C
A29A657E829E9B9297879D598E7B7F7D
8473686D805B437F67807972737D9FC4ECBCC49E74868D97
6C926F854F799373696A9292718A9182677B7E92777B7D70
938F7C8DA3FDB29BB275845C8A667A7A7E8978748C767070
4EA5755F8FC720D57BD16B4369744A716A6664827F71826F
809668867F88988671A1946689BC924AA7A2915AA39F5AA3
8F8B7867866E8B837B8EAD8D8F6A7C8A747696A769709575
97804D5E88824C7B62B071B278727461B9588273836B8377
7C957F71809A9182898E695C7875868F8176857E6D5D935D
47787F6B8B79B46D6690959A70745C759B505B88867D7E7E
7E7E7E7E7E847A688D858B7983814CB8FF8146756B9C7C6C
654FB87597AD7F7B6983964372927C7E
7BB1747C6072956766805991815DA33F81349F904764B76D
8781677B7B82657D7B8E6A7B697F9A6A736096769C7E84A1
8964BC909D799729A08077758F7B6A847F9291766E829787
B1888E8E6B76D0BF6F7FFF15BE8A5F8884957C7F99819366
76717F7F7B6C7D674E73A2B44B653972C6B29AA195855B43
888B96A5A5B09B7E7A978970736C9173986785876E747F7D
6193AE8E88758995776C7C666F663D4F7989657E6F8C7371
776C789D82616A749C8966A269837186787A5B72797C8184
6B837A8E907E768A99929E788174614574885D827C797E7E
7C7E7E7E7E7C7B8786756F9C8371A26F1D6E8B9A8E81968A
7C7D5F56636B96896E77A97976747F7D
804D7A8F59867D478CC396B426655A8D9F6895853EAE89A3
77648F9381945F9E967B7F6F776097A6578072C1169600C7
44506AAA71717E799A8D525A64637D9075967E7E82895B65
866393A86597848B8518D45BC68F3B6E7F6B6347687A78A8
5F8A83864F8E63B27B82B989981B8A8056648A7C68AF756A
6BB4787C817575808070698A5B61697457818A568D86927F
869E71AC94859196AC8671657C74B6FC67756C765A7B6E90
7A728B64907E808B44827E927B68918D7A806C8C8B7D9077
7E7D7E8A89AF5F9A9A79B4A45C8F824D767F7B7A7E9C7A7D
A878837D7E80878D7E809E7D9255B17297AC808D8F95805C
9B5D7298935C5B5AB397699070877C7D
80736A758C808153988766866D9155819DFF389ED400BB7C
69688DABA1A377907A9D8F8FBD5D63A663348DAC44FF808F
61887EBAA04C6580A54AA386737B608C81A1777990698BA0
8D6D636F7B62898A6ECBFC7EFFECF83FD88A88B0867F85AD
6F84918B756E944A71AB8BAC469DBE678658A3487D928C99
74846F80797391837F786D66A37890939358A2517C7A4373
5D8C629F9380687D9B8B95438F9000655F79788C828E8287
7A987C9E2B887D61D85468897B7E828B8E6E8B81817F8F6A
70797D7567737E6CBF718086A98B8690806C9CA287927C83
5E9960837D7F86398F767B97759F888C965A44706E89798D
845BA355999A7098A44A8D5B6A5F827C
7C7C8A636F78716AA335593688BD7289A600B35D6D9C45B7
66AEAC67CA847D757C80776F739886A3777B458C00FF2038
2A68575486A26B6A9FAA7FA879806A8282608C729A9B6894
757D766E85708697684EAF5D1CB6FF94AF877F847F3B60A3
7C82838BA477807A8DA4ED9E3280746F9D72B28C72A37376
8C5A8D66938978797E797E8D6E976E766B82A8936B9369A3
78AD71B3A178729B8F6A8C81696DD9789D915F787A9C85AA
67799D63C8988282539774727763828C77839A6E7F7F8147
6BB98AA87660727F95717F8EA2886F5B6B7E907858897C7D
837B6F7F7D799F887375788D8A9A7D77639C905B75908787
956874857E6D8F9C889065A2A076807D
81808C6884578F729074906C926396836DA5406FE198EC4B
15B182A3705F6BA698785B9B396BA540A4572800A375956A
3F84C59B9B64A7985888897393996E7F7B99ABAB68796E7E
8C9EB0898A766B6C669A71837000C8FB459B7D8277669B26
856A7C6D976C9F48604781855D9581B99C83A73D606264A8
7D96717E667A87837E799C876096837DA5A7908B6D796A4A
776A638079957E9BA77B829C7C638A7995857A676F877562
96918AA752718F998771997D8E87A471927C7462877A88A1
77AC8E7870857E8078667D8867908F86738EAF695B8C7B7E
80817E807E7982857F7289878690648771737F864C5E7F6B
85917C83599571844170783B63987A80
769A7F606251855667A1729FA0A5666272336A6558EE598B
708774866B6F597D4FBC689C417C5FFE412F346DADF34686
34BE129B8CA48C738E6482816E8875767E6E9C7B9D76806A
7D6C465772748854A3A18F8842FFA7B1B72CB4857398D492
24B7748C723F2F7B5EAC69839ABC8947A95B6E788E8D8F99
8F8C867A8184707D7E7D8A80497E82745E769A51509C41A0
6878917DA1507F7D85879355A1C8879F5F6D9887887B667B
60968BA9BB8A914954A577A6846F4D8D825D958775929D7D
8C784C837674777E82A98F69497194885F8F727C9C7B997D
6672804A727FB0747F976B817C82788E998F696C7383838F
6C778C75A79C5BB59D8A698DC864837D
807F9A9B6F41BF60A65F54987A9484767DA49D628F84B36A
165F768C6B997378519C61CF2533A3AE767D95828C705551
1F65C64D8687A2B3AA4E79677D8C6981835B6CA3953CDE7B
9051A3796D4368938F708388B600BF2D4E00C6676AA8558D
267BBC4DAC9E596D6C6EAA79738979A261779E6E838D729C
647A8797977C76787C8A518E92839DB58460709891818270
99936B94695A8D9D928B6D74456F4F3FA4807D8779728E86
9E8A8B869E96757A98566C67599E857C606E7D8B818C9282
958189718B786182877F71698764987B946D938679826959
B289808483574B727E7A7C8390847D6C7761539E797E8988
8E94916C7CA3996F5F9283827663807D
7D8A6F5A5E5F6D7E7D829A9BA85584898F57856677B07586
FF9A6E37A47CA6AA8DCDDA124400A0FF6EC1B44A6DAF92A6
AC947568A25A7083947B847D7D8F818A7E6168676F568A89
66836A7D5F7F5D8C75B18E819865C3B17E7CAD64588B6A53
5A77DF4C52D390A146AB93A7AD907B8E71568E598B9C9E6F
76AF7A8CA04D69867D83877672658E5F6C7B7A5887826F79
8668729D81876276879E79BEE659BCA9587A6C77889B6B9A
75568378819A5F767A96938D657E9E79829151896C6D3A69
87906B838E8A764C6F68895A70797F65588A59727F7F737C
91357977688752817B7F7D8676775E797B7C61654F59A386
7859957A9E8F3C655F69C0AA91957B7F
7D95754B649D958C768884645F7AA29C775D936C55334D7E
9766655C8C79B578619790A795717F88A7A18B67777A6449
9984788687947E6786589A8A709D7E83846C96879C9989A5
74897B708D6E799A7D585E8D6459519D0E605848A17AAE70
79064A42D781AE8574BDA05C9468898D794F5C7181637071
88667863958079818070727E8C717493987E8C6A8B8B7F7C
658F7D7F784669925580A661718B4B655A746B755E929C6C
8A9E6974757D99796D908386896A7258887A7A519975A080
49805BA9757A826D9E7062837A448E89335F839896937D93
7A998477A77D877F857C7F787C84767FA25A509B85898E42
63937841B18F3897886366978E56827C
8369688B8B7B60714B7C759F82A093737E917A7185A28C8C
C79864AF567886887F00B6A383855267846F477B86988177
927B5C857F7C5C7A736D8E77747B78857B7B64908D706F6F
736A7E818892499C79618F8F5D7D837DB2428B786B538562
75CA5F67806E6376857E73919E804C797F769A4C818A8E6F
748868657A63797A7E7B777682707A6174616C6670795036
8A836C7664428780958872805779908E8178D07988739289
78847E897F8B76618D675B7B847E708496A185879360B887
7565747AA14AE7888C3C9B63A491879C79AC768FA27F7F7D
4E7D9796879C865B7A977482947978596F8E6D887D877B9D
8C8588814B6B647386848D8D7AAA7880
7F72956A6887968780857E7E9F8B8A68799A84978E5F8F74
A7A982AE7797776D600E927A99699C938D707B7B8997797A
655E9E9EA380637D873AD87358A578798170778E865D8F8D
617083A18798986C88769A7482866B66A460618D709D837C
687D717C7D78665D917E6D5D6C7D7D7C9B996D75754B6B72
805F74A264A17A7F7D8196694E889C6C7B8A8955777B957A
946B6D6B81917D63874F9F0DA07D417F8A8C5D4E84927285
7E9581485AA38E5962697098927988A1ACA06F9054937783
909B7698B885797D886A5571AC64937593787D7E8273807E
847E909080697C7F736F6A97748285878174610588947394
A97E7BB784924A75B100C06F6F737E7E
7C7D796E5D819A937B76556C5AA8716472804D8276A68488
8098498C8D706D9278818073B18291867C64868764848B88
8A7983A867A66E608056B68372A96F807B81855069688884
899A7BA0737A888588778391899279867D7A6A7979947E97
686E81809F977F877F679D626C869276806D90778178736B
738B6A67889D6E7180718671737390576D8C6CA26755976A
91659B9C92827D877195749E9E909A929C9FA77E68696683
66987674714B6A868F566E9E7884868A7F4C8B687A4F8490
7153ACAB969E678397817D92A3D383925A658D7A7D83646F
7C8184689B7876858D8E878A8E626F58958076964C786C44
8AAA6F6C936E728E7DBCA1A4C066837C
809D8D6D88727D956A5D747F688273A27D51744F738A8A81
738275919075708C755F817E83516A737A977E7D95638A7D
819369906D6763599755A5613B8E88897F82887EA895807E
757D7B7F71617B758A77996D7C6F7D6A996E738596658790
6B8975858A9085837A6FAC807191A2BFB785929481608D8D
7D8A98467C67908C7E7C5E8A5CAD77AD9268609C78815964
9D746A6873746F8E6085827E813A76758E7D5B9B7C826F72
986F897A7E906F5D8B6C738073837987678D6C83927C52A5
685DBB639678AA7A617F789C9A975B895A9C6D7E887D8180
80725C909787859A847783867D976B7D827F846A8F6DA46D
8E71A3767270827F8A6C6579B4B87881
818D806784746EAC66676E939382A88867A7645D86938C8B
64856F86927771B57CA8737D617386A27087668588779390
C1868C7FA95E7A6B8B62B78673A1B3917E8C807A797E8389
7D7E79787B808379878284827D7D87807F757B7D77767697
82917D7F747D827A7C66797B807B927891818881817A7E89
787F7488887F878579969AB98776716D7089706D8E969B93
A357B37DB5677767905A45EB4072737C6264897493648762
7C7C7A7E847D8B74706C5AA3906D60A180988288A1699F95
628AC07395778F8173856A5387577C9E6597718C837E7D7D
842C70697276757B7E707F7C85806F83836B958578889664
A768975669864EAD675C676242AB777F
FFFC7EFFFF00B5D0BAAEA18E61756F1E63CB91469057FF50
5C817C787E576F7E7D7C7F6F886F827B86C1BA8C85728580
8B76007D79867D66A5854C815E8FD67A587CC5777C976E2F
52B0939FB0C1749C829A846A887A876B96788A935D80768E
7E8B7AC35BCA6C8F1F8A5D3260B5796A518439677A76846B
7E849C7087977C7F7C8A89707A36A77984797B946C897A95
755568737983A2826680757DAA79A2879E8EA07289837984
72A28C8A6B77967A588F8B7F8A8283738B61707378957087
8B74507C6D7B4577678C7793959B75673C997A7D7E7E7D83
7EA38E86667A618F9373807D806D749171837B6087816997
936C879E5C9898687298A1837B68807D
FF00DC7800FCAD18A77695746456860DAFF88164D500948E
C7727772748C819D799075793F686FDB008F6490A329855E
776D9AA58D5C6A6F6E876C8A6ABD6381FFFF9BD1F699B666
5E6E6F716C756F62498974B32FAF987788B8897C7B709866
837F9A0EFFFFBF19FF874398918F8892B76592A58C6D9292
8F8D6E6B8A8BF77A7B927787827E898C4C899DB29D7A6769
809B836A7AB1717D679F6E94777B729473A66F667E5E758F
6C758771867D7A895B8E856A81797C6E747F73867C836B4F
80767D6D7AA59C4A876F676B74A662869C9A6A807E7E8335
795E7B6F81716C7E7B7E7D7D7A8795897C8C7D8F7B829C69
668D4D9390AA876F7B788B8393787F7D
0098AD005EFF00E9D94CAD693F865D7DB9FF327B5A6098BF
36C3608C607E728C77AA8610FF007DD9ACB385C49192A491
CF58A0968B7F6C6D85AB71A16E6EA97B609A9D2561FFCC7F
6C577280857F988580AC7A4DB08F648C95964F8B7B81796C
3F2E7277A85453C06365006FA88D6241758C8E7F6E8784A9
957664788CFFB77D8073616B6977637E836E58A43A7B7F82
9C86645E8E61AA81748FA16E716F6A5B898787AA87616B84
7E8A6F847D6F73767882677C9B7F665D769479867C8C7F9E
729D8E9C75787788724E8D697EA457418E8C7F7E7E7E7D8F
94AC5E917F79977C7E9694838C897F6A84667B65806F7564
C450566F9075AD4F789D734AA165827E
64740087BBEE5EE58F468765777DA35228FF16B349625D5D
3DA3B891828393D600D1005B31FFF0E55417C69B9290909F
AD6E7D708887825448A272905E895B807F8F7D00583C7EAA
8A717387798275A9B95A8285467D8F8373C051858AB02000
E96282D229D900DFD39E809757725842AA8E98717F716B77
A49AAF9F2CA863818262536E687A996DAB877E5E7D776C88
8B7CA1718F786C779981818C28A262817468A0948A957A81
9269887F6470678380745767908CA26E8273778384767E6D
7C7C5B684D98829C728E9C82975E807F77757D827D799C95
54717B819065867398786E7E9B7F727993918C759C908773
5C9B816CA98A6DA4A1777E755060807C
59294E7A15EB34B613358E7583A190AE2ED83A4584837A7E
A441E5758CB6FFB940D300FF4D00BAA09A6B299D9979A3A7
7A70946A7D776C8B9B8248535E8B4C808A9F8565698C582A
BD85928E6C658A3F838E7E8AA6305CB54AC700638580C4C4
AE7A8FB386AD00487B516E5C5393B43ECB60777B7F807F5F
0048F7886D72B67A81695D8F85657BA9775E9081787D878B
82825B6B6A708C5CA9514B46A09A778E918981668E717781
7786986C6A728A5FA078829B7B7F7D88798D7F897459717D
758C8177C1797C706D776D7F76695E915C707F6481807E7F
767C7F6E858B9E767D80667D816D907E7A849E70696F8F92
8C6C8B8570AD8E4B4E6882C3817D7E7D
3E6B50319C63A3C300B0C6586B936A9223BE8E85A0785ACD
E600D28A3B8E455F5E9F00898E4FFFBBFF85779CA47A6699
8C878C5F807782A3002E08796D874881706649AA80BC5E3E
5E61925E808786B86D6E9751AEB14FFFFF0E82B185924253
5C8C79A17A6D9F6FAD8B957A7179767D907168798D868E36
FFC7086C83566B7D7C86858C7B7E337172796577897B6679
7172EA8E6299556D52858B706799948F86618A8D9065847B
75738967838D697B69677084858C9D806A8B5E966F6E877F
694495737DA756979451A617A86B8465687C7E6F836A7674
9340806966706E747D86917C878F6C858F82898A85627D58
4E9E7F776C818C9C799460538D58837D
648C695781727C8C457FD936939852FF005EBB5B4EFFA2FF
00A52C7B4C794C93D36A826F94559C777E696889407C6F50
644CE08E7D636A2C004EEC9EB3A04782569C7B7D76973673
816282A6886F728557D3422276B468FF5DA07D804B6B6B8C
AD8E67587196738D8B7B6D8575735E88A76839856C8CC47B
90B4BB8492AD937E835A826DB6588C729E908091A2886F78
7A585F975D7E7D7278778089928D829D97A6637493977C6D
7C9F6A8C8E848680776C79987577778F816E80769E845F94
808E637591885E827D838C7F798069557A6B7E7D7F737780
5B9D768B8E7B6881868C5C887274709D81968387A56D82BA
A67AAEA36786B645878B5D758C947C7E
744E67C49D87A97DAE51FF008C8F56FF0596342000009246
FF8C8ED48F186A8A715D65945E787676757084538D74837E
9D00448A755547B1638F796FA67C2B819A7B3D8A6765659E
82A1256A02897A889100FF59FFD47C0019A18B687971AA6E
726A9B83727F8466767E607B78AC747993A99377562F6F83
68A57F959FCE7E80817251887DA07990B28298588093B072
90807B8D8D6F638C6D81538DA68F9B5678A067826A767B7B
74768D769258687B7488887A4F65807E7A90866B86AD9E7F
6B5C7794A6ABA7716D7BC570837580AA6081837E7D81807E
764B8E7D7D7E796C7A789E8280818781808D669D78996C97
2E6670845296615C7D478983A7827E7E
656A63C4CBB0B29CC734CC00A7C934FF9100FF0007AC8797
CA6F78BB5643A58E677F585B61977C83686E857D659A6B26
B79D3E94AAF07BA445A16A60989352807A93A7B75ECCA295
A56D935966ACC53D37CA190000860027A98D8674609B6096
72938C5D7E94947B8B7B7C8059998E8381C37146B2C45B7B
519077BD9C8D827E7F72B5A44C929C9B66984885838B9096
8FA49379698E97A0807F64A36D939F7C8B56A5857E856C84
877D7F77728C838D90696B789077816762747B928E7289A2
81879F6481767E9D8478889F909C846084C4807F816B6E9D
8E507E789B8A916A768D83667A6E6A9D6765826D949A7378
59A374AC9F8A6A648C87517BB277807D
AE59526AC25DCE67975857B32DFD7100BDFFFF279A0000B4
A77F95CA903B7C95AF6E877C74618F89907F767F8F7B4182
97FFC05D869368829C9762A39460638080805EC4B57B5B85
677C4980A46D92FFC4FC0000DE9D60A39580838D7E554D80
7FB36BC06AA56F8A917B7C7D7C677BA81600A08674516E76
908191857F56987B7E7F8C617A674A626B6B6C95997CA663
62867F698F75B1887B8A57436C2D6768548572675CAA7081
9373777BA35995698C797996897F5FAA776BB46484737F81
76876C8B6B7681647C778E88747C918E607C8D7C80727986
7C8C7A60809AA0727C847A78968887878179729B707772CA
7F888B6864654C5F7D8F908D993B867B
7D6347BB7C89B59DC350927D948EF4FFFFFF00DF2C832B6E
B26FA198961C2AD9844D819D83659D93996B8379A792718D
FF5D91918152856549948F9F863F6E7D7A808F57917E8C57
5B6F84955B84B500D2FF31FF00007987947A5C9172AAA378
6F8798498284A8568584667D86648C00009468A7846C5D88
7C8CCF7CB29E62807F785F718CC167619E9795536C5E9871
4B6F7E817452794B8E929B8533667D9B928261BE5A7D8B83
7490989586767B986F6E77676174896D9B718D746A849170
9991608A908E76A4655EAF797B878C7ED14D777E7E816E8F
7A7C6C8678866F6D79776F6E747787748A8060946C8A7362
936C868DAE82797C7A916F8F5E65817C
9B6B79B9A5C23E269C547565799F57003EAFFF008BFFCAA3
E0AF5885765B36B26E976FAE848791837D827F6C86908E64
9856602A7F96605E9896709F8083847E767B879388848EAA
A4497B4B687689FF5984008700F7796599AE6F7D729A7380
7C5A6F59765E337157B392AE98955C008C566D5A82A4B061
72A696899258927A82646F6E86897AA07D4E29358C6A786C
7F93528D6797867B80975A747A86987E7E92786D797C6887
776A907C767F8092676594795FB2797A688D7C95725C8F7C
967191567F709B9390716A62915A3A61727F8B7C7E83527F
6B768666787E8B86916E8582A58273736B8680689478874D
709078958057707B7A9283A064937B7F
79B58469A5A5847A9D63A066ABE1310063FF0000FF1BAAB0
F98C9CA69D4C1DB5709C8B44005D5A67A16FB553ABFD69FC
5E3D7B918A9374708AD83864A927AB796CA96E938781612F
7C8D7B8469486600DA43FFFF99647B874771726E6D155772
7E89847EF5787D7A8BC8897A9071B8B7908E70747784517B
808586A5468B927D7F79707E6E9286697C879B5486916644
955A9F7E604276818785707F809E9476747495A2B2799573
7482869C96807C7F5D8168856A6D69905F89798A72918584
71667E805F71B87A99BB9A73874D68A08B7B857D7D595AC1
7B9584719B7A6A8E92818D877E717E948B8D6584846D77A0
836158635E94997C767D8678D081807E
88E5969E9FBB4EBAA189703A6A6110FFFFBF00134675924B
57E6967B5C2C78B77B8681D91518B56485759177E7FF8550
718F837292834EB15FA0337FA0938C7E6F826357728AA882
AD765B7B8E8777FFFF3AD45A9F7C5D958540D36B008F7C69
5C494B3C41807B818084385983006761878D8791A269AAB5
985A61967C6F767E81687C587249835B7C67829494555F7D
6F925A7F6C937A806D5E8372907996AE586C6E7D92838A8F
7B6D748481898A84746F6F775B7F68699275615F7BA19770
8D6F8F436A556A6C889966898E7A73C074837F799B817988
7F61766A7385817A71859B697963897D7B6F8675B29E7C68
6B5883987856C06B527E8083A0B97880
A28F4DB37EA27480AEBF792980439379007800696687A233
32716BB3FF6781678B449A9550806F6878768C05FFFF6552
B6649C815B60888B879934679893927E7F66A2D46465716C
956164817661A4660000006C71637C7E7DB5657D9D928EB6
87938662C257D47B59796A7E1A9E8B7B3C7A6D8E7980A589
856C66589361A67B7C8B5D7894906B768D7F809CB9728F99
7F8474558393A09266927969A4BB776D8F6CA88C72823A84
8F66727C83738B648E826B6A987F8F85A26E7D6E71909E78
89A56E97A96E898D5C6249889764838A846E777F8A64848C
A199714C7E796870787679A1708184918E748F7E596E6698
877288707E8499845F84C0845FB07781
9BCA93956C96935C948EBC43A3A18C49FF5C00804E63A381
8D655B867A4B618D86728836898A53297284867300004C3D
B9AA84755065666776AF605D5A973F826F508891B291A0AB
7474768990636768A97FAF87738A9F65A8769A8184649346
AA9A8A5F71AF5C56947E7E79FFA18DA08E6F92AB7C88AC59
61868C7D7DB0777F835B6F57545C749F69A9768368B27199
8F7290807A8C73949D5F867B70768E5F8B6158768676988F
8278836660806D8C6178626E8E91636796717B6D80755B72
999378606084A9614F6F94818477697F9F74649D9088947D
73527F86838F808473797E887D838B747C71C87177846271
8D958DC0AA45757854877F7278827D7E
B378958041C467547C77AC4D9857807D42005655566C5A4B
7DCCA3C9DF5F7B087D788120A372884C7C56807E33817287
6CC7D3B67E3D93628873864998AD5D81766F785D666E6784
B5757583538B937C5575A668A76F868FDB6D666D709A6B81
9A7F7E93946BA29D6F7D7D8B00663E717C516D839DA69172
7A549785441D997A7D837A8D8F51A83D8A8C5F7596915E49
655E8E8470978E7C4E74709B5AA48878716860773F8D877E
707A9677A17B6A678989728C7B868F76799E886679789679
867845638C4B8C6AA2936FA6757B8683556C748190708875
9B7DA57AA3896E7381967991778F5D6083607990858C6462
7B867777B045929287A17E7182977B7F
7857528B8BB4685A967B80598353619E730000B2C94E757D
A8AC9EE46D0099265F4F942E82976E7BB65C815EFFFF5D48
59B0A08F3D48BE9E7976182E928C647F5C719568B3585B84
683B5080906B7376748B79725B5E56855D798C8CA99D8B66
B3926D8E7BA49C6C6A9B7C78C2456E8F7989A4858F8C786B
919891928691947D806BA8728C6FB1734171567F7C637781
A871577476979063CC9B858161669C909B70A264AA76A18A
6B736269758A816E64728769748E6F8F8F679AA262BBA168
8581926492875E8E859C6F8D8D6F738F6C68937C717A7A8C
7F6A9684838E75816C7D7C8282746A9B747B6D94B2548C81
8C947E837C99A4535582AE9D87887D7E
8B759094778535A1AAAFD54C5D736876660072439D9CAE83
7FB3669D632B337D525D854F8E92D968BBA17E885900282C
6493698E6362935E9D6B556A7371777F88846D5375578A6C
87808D837F539DA342719B729A71857F956EC681881676A9
8D9359607699849168837D7F67E46336AA99546F6561297F
5A698A7D9D86B57B8165A6785B80808F7C8373A498975CBD
7579788C818D6A4CFF46AA9BB280AC738B5787B076744F67
6E886F6D5E7E80725C9E878A808F8187737D7086887A697A
66576C688C7FBE81A77B8F5DBAAF5D3F6D77708E968A7A92
73788682825A735C79748D909A857BA47B9A557A82947179
7D7F95979F628C79958061AB867D7E7E
7487B4628D6A17C3BAA9AA4581696E90BDD7625D813F8C53
3B9CFF598948B89F84867951BB9E7C4CBE5E827E880037C3
FFA67E295762B3BA6D769371924F717F9E6D7A9FB699A2A0
8B9C7669777D8F8E8D7271727980879F91733AFA9D9F835E
6C5975927692747468787E7E7E6AB32400796B6F6D5870A1
895D8B8B7583867D7A95A36FA59D8D62666973AA99888265
8C826F7391966D346C7D688277497A9B7492A0709A7DB76F
714874A7848C78666F838396867C76969F608B83A1797C60
87817D399772494063587D36B658787D6A7E84729F876B96
9288968F7C6B89587D9C667D998A82765E775A75A69F6625
976B9F6CB6835C9A987B79758863827B
5E9BA0696783695FA88C6F4FB6508968FFFF6E88683C7070
23DAFF0F8779567D5961C84A8E78A45CD237857B819A4B8D
7B79B54665939C9F8C8C6B93A570A77C5B9F777480527D66
636E368856629A9D8427917981857B6E8BA9C7642A6E588D
81C0535576837E9700C1767F6F859D8F0000547B83597E5C
B6A053866787937E816663936B925A66967A8562B683897B
539B76609485C39E99894A656A80A948709C5EA3387D7576
9394807683698B6F9272896388B9A18B7284627B766A7E99
8D8F8789C7745880836787686494748C7A576A8E857A7A93
7D8271728A8C7467898380868082758A9E547F819281916A
8E897E957A9A8280896C6C9F8A4B847B
5F79E14C4385478CB558A94BAB6F9B58FFFF8C6E5357758E
52AFFF7788452E6B6675E96E9D7B8735FF339577847DAE76
C2002E658C7691BAAF8A6C6B8FA98E7D9E5074965461488F
7C6C928E7860A17B29BE5F75879872628A7880B1C0A57E53
7C7F9DAC7E5AC7A292557B8483695D77947FFF6F9BAEB456
9E763367AE7454807C8B6F5374737B6F75816A3079A28779
7C7752B9867B635B7086DD81695529707D7085A78C6BAF6C
938C93757A8A62638055A473AA7B86718E7F7A8853624F7E
7D71776F4C9291AB82827AA8B3646F5B618D776879948475
84788E919280697C6675948C7B7686827E6F7F698E816494
43785188889A8D5F7A907385858F7C7E
76599E6A1F6665798298B075CB58A0770000946E6E6E6774
C29E8C6B28866C734D6ABF7D66B84186B06A8B8E79A78A76
90FFFFA8625C997C918E6F9DA467BC79495D7B6E5F7EAE96
998E63847BBFAABBFF7788858D72717E857EA5916185849F
77A479997CAFA1628C86916D7B83728C63CA002A7659766A
8D8D8EA26050977B7E7A78767B9A8899737E668E705F794C
9F70745C82747E766F64BB6FC48E9884CA7A7B4EBE516E67
84587496B35B60A17B8A775C68787F6279856D41976A6382
4A5179686F898FA54675788F6A7D7F92719187877292716E
945F84797A88A3829C735DAAA9786F785AA2788C6DB95477
6E90908AB56F886582719167A4947C7E
AE567AA046263F6BC09551488F6339E8FF6A898269517192
826D5AB53695A98F85A983767685A07885408D8281878683
927A0032794150A0A2A5259341FFBB7FB2957D7986768C94
6C4C885C6E79A532277C629477AC899D8578A057577286A3
4F84688F8B9A7C7F726C967D7F7F63778189007071518488
669AA4A37D69627F8070875F768E8B737584826D6F99815F
658767A56FA66CA4839F009C916A5335646E6B3B7B8569BB
807198956952499C8C6C886A6D7D999E83B05DA3A8706595
8B8E6F9086629267857A7E75907A80698A88768082617264
7E7097A58986645D6A85888283698382838582666E509591
6B66B37B9A859C878678787D7B917B80
A78D655F515D741D8992BE766F8C23FFFF8BBB7A55609A8D
CA8A84BA697280798050C13B7DBA986F87457F797E7D74B0
715A95DF775F83A49089418E5662627E81828872829DA67A
768F9E755C814F2CFF899190548483817E6D77717078825E
93586042798290928B82767F7D7D9257846DD4FFFF7DB67C
6A738B92789F9D7D7B8E79818A72AF7B85609485588A7279
8B72839F2CA68D305A75E5BD691ACE44588F9D7470A37769
756B7E27789E86857C8E567E654F9B73817E9E8E837E9792
6F897884828177A488638C7D93718382756E826D6679A180
7E6D6E6B80747874687A667A7781777F5AC45E8F507B7586
826E7B9BB07E85788B995EA28165817C
D1837B7D41909E717250958F735E5C00002F7F707368D779
6AAC958E822D309B6B7C9050B68672A1C4438E7A7C7D7388
757B5D6AFC3D5FB85D8B305F54999A7E70708E6D95689D91
76657F938B7CF6FF4A7E8B9D80917C7E6A645A5D7D6D886E
679066CB7F5582776B766282857E839172798E3100D0997C
6F87794E6A59887C7E81617E76A5996D516D657F6970917E
7C90E347BD8273A46B156D1CBCD537B2796D915F779E7AA1
AF91AB7FA887868B4A9097872666829F848576707A878D5F
777A848D8D5E7B8C927C778A5C797D9479838F9676667157
807490627A8A7B957072718E8D73B18C8BB88C82A0707792
8698807E836A8E6881848569967E7E7E
7DBA8E18559D509A99898978A05DFF0FFF256C4F3108C5A5
BCB05543607482EA9092A5B55A6F813CB68E59797C78895A
9C7AA0A6A71EB7A37B605B9F34AC7B8086945E826E989659
5162816F5439009E618584A086FFC508298DA382A2887B9C
61A5939286826590755883707D8E8361A395A177FF7EA47B
888460779C4D687E7A929C797092876C9E7E8B8795567F6B
ABAD939F639A4F587BB5D83B007E8E418B5686C066827074
68C37D70A4827B805169858179807A6D87846B917D757266
77676A6D747372737D6E806C6FA07FAA907A84799A636883
8297806E5E6586A29087574E8B7D7290A370759C684C82C3
8D928F509265769074708C7593927D7E
2E4184769A5E6AA6843E69AA61610000FF4282B92DF59FFF
FFD4FF69797267DA788284453BB8BD83803790847C776E58
8A707EBC000093A04E807E84718F7E7E8B4D817C738D5285
909D7A5B7EEF517A2B6B7E7A320021C29F794A94A9928B8F
69999FC8E2A6CC999A797A6B827972A17771888E96926F7F
938D777F6A8E3383806F7A687C77829F5B765D926D789978
7968679581847B7C9547CFCF5F913887378DD2738F749E69
856B91A06B68928783A37E846E6698856A6D6F9A78756176
817C8F8DA46F6D7A838893846E846C867B6F8581738C8383
7C7C647B816A91849A917674886C8C749DAF6D7B5F5B8E60
7B557A9F9884478A8E737F8D78837D7E
3A3C88008E90776F8D6A54C275FFFFFFFF5E91B531FF935A
AA31E566544E4090A17AA33F4381A287806E754A886D1D72
94696D66ECB2C196819D5C843ABD9B7E69356C969D3C8193
9C8B767C7928FFFFC1918490BFB585489951B1639B6E648A
B387937477767E7C677A8A8178649D8B83919E4B3A71838B
E7705E68C9955F807A92AA8497859BAD8375737D87AD9294
796EA1714FA0906E9DBE33A9CE68A79D69975A869C888381
53807C747A8284AA79766E80675A6A7A7A6D7B72797A8A6F
8688716E8C7B948677967D828C7A9782927C6D7874778979
7D7E9587807A8177A472884C6785736C7A64498B7A56777C
6CA05B8865854E918271667E82807E7E
5A9AA8268489B26D9B989763CB0000FFFFE1C18200038970
72BA969D7676A67F6581C1597A848692D56A7A3582774B6D
7B9E9373000D748C8797636B6EAC967E7FA3A585768667A8
9AAA86886F2618CFFF3059884F759164816478B1738A76B5
5E4B6DA1AF717C74B1AE8A607F867D837C856F83DAD2C561
B36E80733E6D9F7B799E92877E9995B47C7780844F5B7FA2
6782993E9C71965F49E14D1D70C65B62B577687E72729A69
6069996A877A7E6C7C61787B7D88886F84658A99755B7168
7E926C81869A867D87959777848592828274767779808EA1
7089618476846C587B8A70B0B44F9E5E965CD17C7FA5876C
95A399774E6B908D8F757979778C7C7E
007978279490BCA97E8385A3BA000000F80000547A529CBB
8A7597834D711AB49C9B7E86AD9B717D875C9792A0878883
9B8FA7815C42A199A67A626B92C06382816D8B88935A497D
6887628B73DEFF4D76B58A73979F988AC4A67EB0897FB27A
91B465929E8457688A7788868D93547A9C5E807282FF905D
4C9E7089A684737E7D8662667E9F7F736997642583976675
5C9F566A6A5E84608A7C9E5A31C6629B2C74FC189C62819A
7461958065837386777C73978275816BA77E8D846F687373
8C8E848D899C5C6E8296997075977D7D669A846D5C697084
7C5D81446FB858827E9180627A996AAA39A433A0717E648A
979DAA8E8C89A36C628C6C828B927C7F
3A58765E5B7B95916FA24594FF000053FF0B81856B66D2CA
C58A9F6D67595FC7957F489180519C83837B8878758D6685
A06AA0798046375854553B5D624A9E7B5385403376778D78
935D4D95B8465474638B73909199A57F76A7888372866B79
A4727BAF9753A1A3B09C7C79A0836378996B717F8175CCC6
7D81D7757DB6A47D7C8A7186849387668478B65E8380739C
5F87C78F5B658DA0837E738296567D78E7B9629D6488917D
5B5456586B8A8A8E83977E6D7895708A7C8F879077618A62
888F7880669F787597978D6F7E6F8B8279807C6C838A7E86
86717C55A7AB9C628E9D5B5ECE4A537D8F649E8B93617A95
753A73937D90908C8C77738C68767E7E
46AE95968E84946E8A7454696EC8004BFF00516150909688
A38C94B1A96A60A4A6A63B819873A3829F6E807C8C879784
848376777A7EA4FF66631B9EA9A2AF7B9562876F7876AC76
85B15F6374D6AC5093C09C6F7983727370807D5A76A78283
9CA1945076676D46767B81896E7384838B81677E8B5F7E4A
7A5C568A26A1937D77AC8A7C6259797B75A09C6DA966687D
888B62838970AC7B5A7E97668563409D595D907C7D9C6E8C
8A4B917F926C7B86A2897981818088757271727078757978
97718D77666E91806D8594707C818178986F7182765B627E
657287A8A3A853A2637A9A9B205A7281647C76A261B17C84
AB5783938175869E6D768A8175887D7E
8079B14785B8D079765667593C761C34FF00A3456DA577A3
904FA7A06971748A86866E7581747293788780634F7F6D75
7F7B5D77997D928F566605BBB3B5967D6C927F747B5A5561
7B5E54642D47B5A49B5E7C79995E6885718EA58C945F666B
81617F80878C68728F7E7C8F7984828D77747E97918E7888
9571A7927A73B77A7A919FB0AA777B7C7F77685B777849A2
8ECA7D6F75799E7875728F667B62D662D22EC4407947A62D
67907891847F8586799AA968846898956E737B7F696B7960
8D806A8F7D6B7A996F808A668964998A756C736184778B7A
769B5F878D8971727490697EFF778873677E69628B756166
5D9D6A7F87968166845A7D7F757F7D7E
B18AC168602B883437656A44654FD6FF6F7DA18F65757E70
658CA8726E634F6C92806E95806D8C8C7C876D538D86A87B
76606A8C727BAD192F8312B15C6D6D7E697E666B825F7094
5260828948498D846389798E6B9FA26789648E717E6A6E9A
85A18A7D6EB254B2936181528D8179826774877B8B8A9161
75A56B826D747B7E806C66A562606C808057845B827C9CA0
6585806D8F6675796A58637663736BBD00957472979780A2
1084727294887B6B827781937796785378857B7289628B78
937B846D87909B857173897F72996487799492916D7B818C
7FB277716C7C6E915171468C5CB87979906391756B944998
6F5D6F7F7565848BAB7B6B7073767E7D
914DEA5A74906B8D7987928629FFCCBBEE367A767789915F
687E947D7A4547748D5F808A9BB2827671908A908A6B6071
6B708A7B8473BB85946477777931A27A9A7999AEC472B68B
B67390A09D419D0026A87D8F8E838B925E8B867F9375659C
8D5B759BB586855C4B8A7F918A757A6D80827785746E735C
A28B7F4F4FAA5A817F795E5875A9628D9060788699AE6E78
687A77856394709E7A9195848E9E8D4BA40D71846AC72D93
717FB03282796C957E739F757F67A3697F5B84766AA09567
8F7F96889E76A57D6C8E7B63A28583767680867B935C5E86
BD546933A06DA58B63BE375C7500A12460AB5F85AE475788
88A05B616E7D706372937F687E67807D
5A7DC1BD7D9F786E52B8A7764DFF0000A6009C684B80996B
6C668F8082A8588991A856ADA4888A5E41847D8585676466
7E638188767B63299C9769A0A90E7E7C917F8741797DB086
4F88836F689860FBDC82678D9A70627B70B15F5F5B72859E
8376C06D66827A568E9873806C5F616592735490938D82DB
90B49C988A2D667C78A4617F52757D8A537B89AC91888E6B
B28C7487475E798B64D45866829A7588416A432C00F54DF5
4961B37A6F819D8C9A8DBF8978A05E6D5F88797C9482708F
827E758F8499895B76978B766F688597937165777E9FA58E
AB899172854E72907C5A76E55A9066C38995565E862F8698
988D8982757D8477725F766A82707F7D
6C6BA35E9657B9A355A09DAAA95800000E33567877709277
966976815C61458471A3BACE934E916F657587A4766D6D72
7A85897F728946FFFF62A59CC7395E7E5377948244686260
8B9DA04BA2AD6E008E7F8EB68178928D8574609A71838A7A
8BA1A178766476693E7E7EA58E7889818F5E97AF727F7251
79619696769A8D7E81666DA87575695DAD926B727CA28D99
B6945D756666497F78876D396E6396B5731BCD9CBE007628
9D7085947A75A26A5562628E8DA77E6B97828C7A7B7F777F
6C7E61807F83897A6F657F5789757387749180B08E725B9D
8C9F44698D3399798975716664A09E9D8A727AB57C61905D
85697C4760716C80776D918377967B7F
598DB5C1C879587A7FA7BA8EA487A04F5D00CD6A8E75B77F
8D90A37D7076507E507089839B7ED1729D886494895A687F
8B7D6A7D868B7BBF8A5AB982713E807C764B4A75576B967C
735488770021B37C188B459D9D8C7B757976B4A071836684
8DA1487771C3598882837388798F8695827D7A778095AA7C
89827A738268507F7D838F9C6E996A758C7E607A8B7D864D
9D9381857581758893A662B86D66D293B9BD657894FF8786
B729D751A5A98FA3A468979086A57F836399A99576817F74
B2917778776A7D88A47E74896E8A66827F655A63679FBB72
A777AC9E86848EAFAD65BB9768846C796A4CDC8892667958
5C6E7A818A5B7D738584807975847D7E
787A907D793B612E586161A7FFFF8089FF6F728E8880864F
6C528599AA6A8E62378073799672C565897B616CB2A37780
6A77A57A5F8B891DBE8F93847043AA79965099879B3A7FA7
73AE5063A2695F8CE899A18C78817A7E7A8AA37A9A7D8270
8B64A57B8AAE85958A58595F719F79816F80979177A66476
5B999A9E7255597E7A978B7240A7549BAF937976447D5B79
828050A454A6609D73867C92998C646B403FA64ED118FF02
B57DFF4CBAAB63936F878F8C804E89627F6D9E9B9A727776
8084817B8E8D7D914871A0776D60705F974A9F8B819C83A5
67A65796C42E8A7C839045AAF959917D852B767D8579895A
7E9B95886C6D818B766B7D81817D7E7D
5B8CAD9A9F86A6858C9F8FB0FFFF299513009656AE82835B
8177845E946E5A5AB16E7775B78D6AAAA75A8171B56A7F91
9375898F6B7491FFA4686F7D8DA88A7D747C7E6B92A25382
88895A7B7697EB5A61765B5A73818A998A75CD639376676D
5D94A25E69738D90A5496E8F74806B6F6E7C6B40736A822E
876770527362817D7B8F92799C738B67797D856A7088A06E
7584827D629E765483B04C7A40457F4F89204DBE3DB40EFF
0093489ED20586B72882808E81676471A06C808868467B6A
877E857CC78579828570757B928160BB7C7687725D5F9699
686AC77D3F91419F5190B79962B05DAB8E9F58788980708E
8B617F9A6177C48B45736B64798B7C7E
78A0518C9D9B434C9D5D597CFFF259009E0020387785946D
9782686870695A7D9B4B746C90AB9EA29176886F9977A76D
737E5F5668862FB3906E8DA3BAAD787F4BB15A7B8B6F5095
A25E5D8AEB662BFFC9C18981637D8C6B44AD9C67887775B0
76706F88A2886F886AAB74775D54956589799B59764F7BAF
9371799A8B97977E80706399918E76956E7C907D9F708E73
84A36B49979B6B7A8D767F9A939D6F9D4FF6454177519045
FF00FF33CE89686F64AB62896971CC76668E7678747E7E83
896E9B9E74737F849072A260BC7770956093909D9690656B
6F8D28CB94798C3DB07F1FC0D38B88938686896E6E8F9749
69A6819489825792AF6F886C84717F7D
5EA85287AE8A9B5768678530E5C00000080000DA6D599345
2C7988667B56706D86707E65666C6B5B8A8B9179A8678E9B
948E878F60BA6F005F5A419C697D47807E787F8B81705371
86773FA9286FB35E980090927F4F946A9B917B9A9681B37F
656C7A98803F8376957D80775B816D6D745B8772938B954C
806A705F3B78787F8167937684AD6197908887827B71689E
8D84906A638A4C976B7E8183656BA068A56DB4709CF87CC1
326100A0C4DF25775C9F256963746676B19DB2526EBD6E72
8457775886897E8975A4749183AC7F7B82867B3D8A697E8B
597C84B9797A77D6378F007D74B25974B7A67E7B82727E90
8695BABB7980887686779F787B7D7E7E
88709E567E77A47E8240AE7300002E83B4FFAA6765004A64
935BAE84775985977F466D6E9D736476A660808F995E9B75
617E7496A696FF849A7D81C67C8043817D8D8C8C95756490
6C848E4A5AA7BC7C9EDD92847B8D83808E8F88996F668B68
4579796A5472708A86786A807F7A788A7B7EB287C499A590
4F73BA7F9E9A737F81687F7B937E7486A0757A99819AA582
62A0817D72878354A78A638087798B7D7A6D6E00C872B4B8
7F7B532820FF93B45E4D94868F7E5E737971576F7B8EA39F
89949077897E68A4A97D92C698C570847CD828BC62998062
7775B17080A84C9AF86D943C71826F817A875F6A88729367
86A4526B8E6D9C8D8E76727B7D7A7E7E
77783FA2B3A0BD6D652F6F9B74DDFFFFEB728C9C7E56686D
5B7449788CA8778292835F818D6C79848E86A79C886B6187
5A718D5D781D6F637D657ED7919D5E80879B90B45C95407B
8D497CB3FFCB4FC76A8A74945F6CA163AA81AA76717B8C9F
818A87875794AF96A68AA06E71607F7F8199A244CDA45877
82BEB06D8C647C7D82666C7C6F93537693769375AB9F8686
8B857380756A76656DA2596D68976C7950869AC186A800DB
748C574DD700FF00B27B6F837966526F86846072A3756C9F
8678767A96925D557176705F94458E84635AE20079568DB0
9BAF7CCD73E339C459E04FA35582655D9679846786695970
735777946E7D8F7E8075797F7C8B7C7F
67976D6B687494A4A14E8AEA5394FF7C37A3B85B82736B8C
4A916472577B66748E60777864636F828E746E78986C916E
9F748C64C0EA8475A075916E98905F807D69856D70807757
679B906FB76F0083936B73978F71626F4D789385AC699B76
54708378AE7C69A7817E6F8478777BAFA06564AE46BA767E
65A68D7A7C70687F7A9A7F716E7A51726873A17C5A80946C
8C81869A7DA1747992778C619C68838F697A9959D803F11D
A35337C81BFF00FFBAB076D26F836E72A07ACA8D8A688363
844E5D7B609A8A818A7066918EA56A92B36F2DFB55A96EAD
68996AA7CD703F697B6DA54A77966A898F68AE8389745A82
A57B78807E727C857790947C757F7E7E
8970A7A36E6FB077B250518800FF8A000071799D6C74C06C
81698080526E4E5F698D8E7F775E7683704E7F7780597E89
CA834C4884B57F749A55738880788D7D4D7B78827BA04D9C
5B4F47781996FFFFED4295AC6EB3916D8C8C6F7C7469AB87
8A6B748A5F838F98797A7E7779755D836B46DEFFFF6C5F40
BCA68B81938060807E7D757D817C9E83BD9B8F697987969A
7A3A84BD70868D96849696808B749D886D7D8F7C695F81C2
669171CA3E57C3A5FFD29D979B67688A81808B666A51AE9A
49779A96AD7F6B9F9F917D898034C160B8AD229A98918355
7CA81A6D7E5EE87D6EA24C795A9B7A4DA86F928D66777C8A
8A81A66D7D8379896E718589736B807D
806E8C6C3D8E852B6664916F6600348A3C312598649A747B
8D8D8496996BA89A5E5584827A8378865B6C66618977A17B
35291D36594D887785A5737D86904B81877978A1796B88A7
5B60AB74AC104E77165BB4878183848F84715C7D997D916C
88688F8274778E7F7D7988887C925C7554D8A5455F79626A
6B7D7A8E6887797E826957897B8A915A5B89A18C5A7E6B91
5B5595847C759696A06C935CA169A3798290AB73849C859D
52A50572F50082DD63DA45FF9D57A2AB8084815C55AC564A
A48270AB5775AB359C9D4E44628E78635AE0778367854DB6
64ABC24D22EF3C3FED7E80958B805E7D88538C5487659682
83AC9189698B8C8B62838A84756B807D
677C619B7C92B15D88669389643B5D0000724ECB8B81598E
966B7C9B75728F7464986B8182676D9E7856855F955F717D
A5FF542D804CBB996CBF87837793977D708065558BAA8F7E
6A8D848B20776EDEFF2B00347DB68976689690626B9B8582
636D7A74A28AA69E786E977E8D8EFF826D25005F9153A187
988C9F818C787A7E7C83926F879D88A87AEB648F558B7192
6DB17EA3B76E4D8A716F688C8C766A7C9996598A8C7BA3B0
BB8EE30E7D503A28FF4054A16B19C5BA6E819876795483CE
93619544B1A65D9754BEB4674A888F5CA7199FD83C807B9C
5F698ABB6858D7748E5766869B61508A7DB16B937E8D8973
606C587C4B6F68788379615884897D7F
558B6B9D70A18C5BB94F999F8B73003C94B9AD666CA68F6C
6C6E8474797E72778177797181757D7B9D918D847175AB6E
D93ED4AC80B2716E837978A141507E7D76496D7259896F64
8BAA6A64A731C67B81C3672743787C55A4755A778499A072
7983646F6B816E779063876D939945902207B088757BB781
8D865A7B7569737E7D808C968D795EB8444D8B976790A888
75209B798D758577758A627660AB748C9F82988D907E7E6C
957373FFED4E94F940CF68DF006DAA3C7783AA5E708A704B
73C361875E964395A15672CD8183A0893AAF8B068DCF30B1
6A89675D4F449786807E92717D5F7CA3A256A3878B7A779A
816D727F9C986E9CA3667F82987E7F7D
8086776279807C8EAE6DA165397B8264FFCDFE4F5A878D7B
64797A7273837F807580885C696F7C927D617B24EF2421B3
F4FFA0B39B7774857F9C6B9C7FA2727F74458F8E508E597B
7A7291AD7B556E0085FFFFB8A44F996A5BA0847A917D7556
89927C8BAB91787565836C983C60A19FA9CF9182858AA848
7D5A7F62714C777C835C88715E85588E3C77847E7673409F
6B4674619E64919A65797F8D82848F5A8795996B8D796F54
826E7213144C82273B18BD975F3C337F8ED062A885857C91
000DE27A75AE1DC56E52AC73706FB949C2A08483555F906F
7D757E35996B7B9284657F625F5E758E477A78975E4C95AE
7793587E8E88777D71437C9FB66B827D
7C6F947D5D965F7A6B508345827F9A513A16A8A7418EAA6A
59847A8369788A926F848B7B9C8A79587BA5B08BFFFFFF81
5E81565A9B74966C7B8758C27CA45C81AFA15F7A708695AF
A45A7B708E9A74BBA66E0076D3A97AA28CBC965C8C7B8560
7B76884E75606095669207162AB4FFB493D965899681726E
8F7D717D8E927B7E7F748A857C756B9A75896A5892514981
7C7B767D8C67936E74767B6C5F68AF8268896872867E7593
6079A3EB33AF5ACBFFB65AE01BB2883F762A406F3B5D983B
A10A4DA2985EDF916D978CAB5A327A00FF42656078847E7B
7464769D83926C8B7C6FA660757889856687876E675F7134
57BAB885795C959081864E78848A7C7E
6EA38D98708F7361B451784981958CB5F3DD0091517AFFA2
75567694305D5D9A8866784877472F4885962460FF21065A
255568A3767D5AAB58867D9B836C507F63B36C8AAF79779D
D192877AB8549F9ACA6946005FDD82A0A87B81494F87B865
5DAB6377C9ADA782A749CE630000007B909C997B5E66896B
927299858070757E7E7C7B74616D79879A767A9092A2955F
8C7F92AAA4A5886A6F9F8195748588B9A5588FAF808D93AA
77727245BA004BC317FF0B2649DE3C8DAD61C26266B37190
7577A12C746453766A6E92A265C75DCB379A4EA488739E8D
74A1AA796FA4857B8B838692867B97A16F69796E6C7C8F5C
845A6668824E987F849289837C8A7D7E
888A78498B54855651758761D29C7EB2000AAAB752FF4277
A36DA1918C86A470429A8C9D9193FF20CBB0B6389FFFE578
B0DBFF80B993768662A2886D7890717F728B9D75745BA998
89825E78597D8EB274FC5E0000FFFA009B4B8D187143405A
808C993D9C786CFF2F00321C2FB822BCC500927556AE6298
6E886B6F6F74847D7F7A8F696C649A93958587855D676C65
998C92A5886C8266A75F79689E62787C80CDA1817C6F747E
688C8077524E2CA44EFF2B53407BB074903390AF899C5E91
7E9911D664796C9C41B0939D8C566688897188AC7E6E8D67
8F876E877958857765979B76828266A0777A9F835C706D6C
7B7085708C727594817C807B79887C7F
5D844C9584503959C88A6F928049A791A46A8A4C80139000
4B8B5492514185598A76836E15FFFFE90050FFAF60946232
275BBF8D70808F8E7197717E8080767E8F878C6C548A74E6
985E68725B51904A954D780E3492FFEB0C9E5B7FA6895575
826A7DB5A7D2465320F0FF00B1424F0D5C96ABAF9984964D
7643826E6C82767F7C8A91866D858399659E4F794C8C8280
7F7CAB77919F687D73778E6B856E98677D9F3E848FA4807D
8477A97995C0FF4EFF48DA8FDD4EA59A7099688973817A57
89A6CC4463B7167752899C81725F8A6E7E677D8573886365
7D938D836B62738E8E8976656CB09D968089879682798979
886B655C797D7D84939D858475747F7E
9F46906765B023359883BF919B6F8DA04F5D6A30FFC05722
3173856DA39E435B7474DA87A4B5003B0037FFEA007654D6
8C183D726668B69651756F7785878E7D7D60568C7C65407B
8E808B726640579F6594AE70FFFFCE6A8B5ACCAB998928EA
A6AB7EA75270EB3DC3E5019DA700EAAC9F7F6651977A8A5D
616E75918A73797E7F7385A3758F70899886897374747786
5CA788626E9C837C6C817F65A17A928D6D8D55856A6B9A79
56838E5249A07C1D4D8571945A84537D6F9D7381817CAB6F
6C89328D6E5A9C787D87736A7F66777B776D97A87F877E76
8C7377687F706E65727D87856D81867E7D7C7E5959987A80
6E899C725B9B656C7A82797B75877D7E
6C7B9A89EC919B406071949B91548A704D7A394C966CBA04
B05AB9C7B9989577B06E67902A6847C3649AA03769BCC513
6C66739766498B6E68A8756D7586737E638F888A61449A5D
7751B757757B7CAD837D72770076B65FDE90918A69727D8C
0FB2FF3E00DFFF731C69FF92EAEBA333772E73779D526B84
91779994528C8C7E7F788F7B8385768D6A8A787980727B7F
7E706C817E8186938E6A887480817C86898271727F8E747F
769080B98A706B7EB9A5928A6B9B7285897F8260926C8D82
9276849D7E9A758C8D7176849674969D768E74798A797A63
887F7C80836D918E5972988686786F807A6F7493857D6482
7E667D6EA086748A84887D7A997F7E7E
724F6E58C8D5764F4A5C946D81577E7057647F97D1FF94FF
5A703D2CAE5A753F2FEF67D4B3FFFF525BC47E2C6A889072
56B1749DB55948864F72B5BF88805F8081856592646DA884
6C697B6687305E9089A67FA243FFCFFF7B98A59E827388AA
006C6EFC509C94009D355D4A8B85805592A5935C984A8576
889C7C6D748C70807B8B9893839D846384858C77738C7E84
798480587F966B718A88739696896F6B9B86AEAC6779829A
75939DA37E77737D55B1666D9E77849F627977878D8C5B71
9B8F6C776F6EA3869A518E8198778F69A37F886C63837294
5A77977C6B8C8A7265707D6D7D6E7E797C7152937D707E5C
8285885F8F779A5E61807A7C81797E7E
7E7983837381D35F7969C1867D6788B9753C4C72679AFF96
4FB534735BD2215CCDFCC4411E7F504ABC9465AA6962C03A
7A52786D818A82958F735083C154677E5C717964716D4751
877E705777836E34A381B79661C459D169BE9E5C60829D6A
EF8AD0A9D16C4C36674A9E9D795F4C40736383577A866782
5F60746C8886777E7C887C6D9C8B7278767A7D937D86886E
94806778A2766E7A798D967E8E8D788A866A7B7A898E9279
90829A966572797578786E808A78827CA86483896F979586
877692815A8461A774618D9A708B72946D787C9E8A60968D
8B9F6564617B867B687B7E7B597E7D9F8BAC6B648C6D7487
8071728291866052947B89726A7C7E7E
6B4DB65F71AE83448D98946C542F5CA68C76A97D448C0588
95859BA39ABE959CC20060006893548B50738F9A9A988088
73855B8C798D9F7F7A0075928F5C607F90AB7A928677649A
71936C8A9484887D4963506B86764DFFFFA9A1577F735880
75B4348487998C967E76867C686F85AD9193DB82849F7C7A
98A76E72766E837D82667886A272909A975292608B857374
677A8093777E6B6B75839B84719A6862917B7881867D7672
75747A7E748E6C95907A7F747A92888F947F82699668767C
82946E8A906EAC637D877377818C7B5C896E9B8288797E7B
AB9D9183839B94858C828D8A7D7B7C8F81968F88536E7F78
70848EA25895807B9890828E77777F7D
876D7367408090A783757C385F78723B5F8692755C334270
83988062566D606DA54E9F5597A45C6761AA8F948E81734F
55817970796B73FB2700A99D8A4E7E7C6C9482827BA98857
6B7B746265747C4D89AB7C77C7B76F78D56C77798097838C
A6B39C8494836096828D7A868384927F7D6561748A978165
7F5B8687948D7A7E7F7377877C756B7E85907C8C788B9775
7E6382747F5B71937D877B7B8B6466769C947A8B738D91A9
7D857947888E68708A777288866B91647C8F588276876967
5E737F83787F8E82777C688A8A874D63666E884E686B6E5E
7C7E899A96527A88688366618277718D8868898B80917C8F
647C82666E50AA599896787D73987A7F
80766E674D7A925B939E5E746B88558C57577B4E814B917A
7C647558826953985CB88F869389747F7773AC8397698967
95889D7662598FD65F00A583CA60767E918A607C776C8C6E
7077749D6B786B88A1898A6A56758F8D75873E4077858690
716F765463838F7C7E77AF758D696A807876756D92676A86
6B7B8E9C7C7D947C7F7C649D6E7382677A89867C848F83A7
996F8D6B977F8586818D75767D69767C6FA7778E7F8B827C
7E8C8B85898C7355A494757B7B82697884838C7783838977
957684817674736C878084657A8970526A7789756D74707D
83818A6A64A157BD6D7F90A281768397797C74798BA27877
5E7585687D6D827A8B83667E81897C7E
6067869179978C70C68272A3536E396F85506E8D90827F6B
9F65879087AA649786936855939344988685A24C80746E84
C8629782818A80994747B289E477727F7A50678068988B66
9B5D8C708378947B6D69806D9799879A7F83808D83638496
68856E7A8F7E727E8162818397AC6D5392614F85A2929A78
5C808569958A66807C8E7C619478697E816878887D936168
81837F63866B4E956773828A926D8F748F647B69838A7573
7E8C897B6D76788176958576838495827691639A83907B95
7B74758A9B7A97727F87937469807E5E7474728F736D8989
957E896D7CA8727F658665737B9454728080628D8F9C837D
6B8589797A8657819C81697460BA7581
5567965B7D86536C7D81599393551386C76B67646D837F67
988B9F7E7E9096887685597D7251507993969390556C6D3C
9C6D8D866D8688717BAECA9BD94B667F78897E747C7E8483
8280746C856F7B82818E7A767B84856F777A85736E7C857F
72827A7C8170717A9780788D728E6B867781808A7D8B8787
7D73888FA6696A7E7E7C7B6D838879837483787B7B78807A
867E877E83827D87818574798D74826F7B767A8B7778757B
7D8C827D717C7F7288838E817B85887B8289867D7B847A7C
7F78757D877D8775817F86797D74817F85908678817B7C80
7E7D8280828174887A858B7E7B7378827B7F798A77786A80
7D747C838689767E6E8B6B7780807E7E
pop
P
% End of image
.5 Mabswid
.5 .2619 m
.02381 .2619 L
s
.2619 .5 m
.2619 .02381 L
s
.97619 .2619 m
.5 .2619 L
s
.7381 .5 m
.7381 .02381 L
s
.5 .7381 m
.02381 .7381 L
s
.2619 .97619 m
.2619 .5 L
s
.2619 .14286 m
.02381 .14286 L
s
.14286 .2619 m
.14286 .02381 L
s
.5 .14286 m
.2619 .14286 L
s
.38095 .2619 m
.38095 .02381 L
s
.2619 .38095 m
.02381 .38095 L
s
.14286 .5 m
.14286 .2619 L
s
.02381 .02381 m
.02381 .97619 L
s
.5 .02381 m
.5 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
We calculate the cumulative energy from both the wavelet and \
wavelet packet coefficients.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.26"}],

Cell["\<\
(wtE=CumulativeEnergy[wtdata, 3500]/
(Flatten[wtdata].Flatten[wtdata]);
 wpE=CumulativeEnergy[wpdata, 3500]/
(Flatten[wpdata].Flatten[wpdata]));\
\>", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
Here the relative error versus compression ratio curves are \
plotted. The curve from wavelet packet coefficients (solid line) lies \
slightly below that from wavelet coefficients (dashed line). So we will use \
wavelet packet decomposition to do compression.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.27"}],

Cell[CellGroupData[{

Cell["\<\
Show[
{ListPlot[Transpose[{Table[256 256/i, {i, 1000, 3500}],
Sqrt[1-Take[wtE,{1000, 3500}]]}], PlotJoined -> True,
DisplayFunction -> Identity, PlotStyle -> Dashing[{0.02}],
PlotLabel -> \"relative error vs. compression ratio\"],
ListPlot[Transpose[{Table[256 256/i, {i, 1000, 3500}],
Sqrt[1-Take[wpE, {1000, 3500}]]}], PlotJoined -> True,
DisplayFunction -> Identity]},
DisplayFunction -> $DisplayFunction]\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.357143 0.0203451 -0.26789 8.226 [
[.25321 .54221 -6 -9 ]
[.25321 .54221 6 0 ]
[.45666 .54221 -6 -9 ]
[.45666 .54221 6 0 ]
[.66011 .54221 -6 -9 ]
[.66011 .54221 6 0 ]
[.86356 .54221 -6 -9 ]
[.86356 .54221 6 0 ]
[.03726 .06115 -24 -4.5 ]
[.03726 .06115 0 4.5 ]
[.03726 .14341 -24 -4.5 ]
[.03726 .14341 0 4.5 ]
[.03726 .22567 -24 -4.5 ]
[.03726 .22567 0 4.5 ]
[.03726 .30793 -24 -4.5 ]
[.03726 .30793 0 4.5 ]
[.03726 .39019 -24 -4.5 ]
[.03726 .39019 0 4.5 ]
[.03726 .47245 -24 -4.5 ]
[.03726 .47245 0 4.5 ]
[.5 .63053 -108 0 ]
[.5 .63053 108 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25321 .55471 m
.25321 .56096 L
s
[(30)] .25321 .54221 0 1 Mshowa
.45666 .55471 m
.45666 .56096 L
s
[(40)] .45666 .54221 0 1 Mshowa
.66011 .55471 m
.66011 .56096 L
s
[(50)] .66011 .54221 0 1 Mshowa
.86356 .55471 m
.86356 .56096 L
s
[(60)] .86356 .54221 0 1 Mshowa
.125 Mabswid
.09045 .55471 m
.09045 .55846 L
s
.13114 .55471 m
.13114 .55846 L
s
.17183 .55471 m
.17183 .55846 L
s
.21252 .55471 m
.21252 .55846 L
s
.2939 .55471 m
.2939 .55846 L
s
.33459 .55471 m
.33459 .55846 L
s
.37528 .55471 m
.37528 .55846 L
s
.41597 .55471 m
.41597 .55846 L
s
.49735 .55471 m
.49735 .55846 L
s
.53804 .55471 m
.53804 .55846 L
s
.57873 .55471 m
.57873 .55846 L
s
.61942 .55471 m
.61942 .55846 L
s
.7008 .55471 m
.7008 .55846 L
s
.74149 .55471 m
.74149 .55846 L
s
.78218 .55471 m
.78218 .55846 L
s
.82287 .55471 m
.82287 .55846 L
s
.00907 .55471 m
.00907 .55846 L
s
.90425 .55471 m
.90425 .55846 L
s
.94494 .55471 m
.94494 .55846 L
s
.98563 .55471 m
.98563 .55846 L
s
.25 Mabswid
0 .55471 m
1 .55471 L
s
.04976 .06115 m
.05601 .06115 L
s
[(0.04)] .03726 .06115 1 0 Mshowa
.04976 .14341 m
.05601 .14341 L
s
[(0.05)] .03726 .14341 1 0 Mshowa
.04976 .22567 m
.05601 .22567 L
s
[(0.06)] .03726 .22567 1 0 Mshowa
.04976 .30793 m
.05601 .30793 L
s
[(0.07)] .03726 .30793 1 0 Mshowa
.04976 .39019 m
.05601 .39019 L
s
[(0.08)] .03726 .39019 1 0 Mshowa
.04976 .47245 m
.05601 .47245 L
s
[(0.09)] .03726 .47245 1 0 Mshowa
.125 Mabswid
.04976 .0776 m
.05351 .0776 L
s
.04976 .09405 m
.05351 .09405 L
s
.04976 .11051 m
.05351 .11051 L
s
.04976 .12696 m
.05351 .12696 L
s
.04976 .15986 m
.05351 .15986 L
s
.04976 .17631 m
.05351 .17631 L
s
.04976 .19277 m
.05351 .19277 L
s
.04976 .20922 m
.05351 .20922 L
s
.04976 .24212 m
.05351 .24212 L
s
.04976 .25857 m
.05351 .25857 L
s
.04976 .27503 m
.05351 .27503 L
s
.04976 .29148 m
.05351 .29148 L
s
.04976 .32438 m
.05351 .32438 L
s
.04976 .34083 m
.05351 .34083 L
s
.04976 .35729 m
.05351 .35729 L
s
.04976 .37374 m
.05351 .37374 L
s
.04976 .40664 m
.05351 .40664 L
s
.04976 .42309 m
.05351 .42309 L
s
.04976 .43955 m
.05351 .43955 L
s
.04976 .456 m
.05351 .456 L
s
.04976 .4889 m
.05351 .4889 L
s
.04976 .50535 m
.05351 .50535 L
s
.04976 .52181 m
.05351 .52181 L
s
.04976 .53826 m
.05351 .53826 L
s
.04976 .0447 m
.05351 .0447 L
s
.04976 .02825 m
.05351 .02825 L
s
.04976 .01179 m
.05351 .01179 L
s
.04976 .57116 m
.05351 .57116 L
s
.04976 .58761 m
.05351 .58761 L
s
.04976 .60407 m
.05351 .60407 L
s
.25 Mabswid
.04976 0 m
.04976 .61803 L
s
[(relative error vs. compression ratio)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 ] 0 setdash
.97619 .60332 m
.97486 .60209 L
.97353 .60086 L
.9722 .59962 L
.97088 .59839 L
.96956 .59716 L
.96824 .59593 L
.96692 .5947 L
.96561 .59346 L
.9643 .59224 L
.96299 .59101 L
.96168 .58978 L
.96038 .58856 L
.95908 .58733 L
.95778 .58611 L
.95649 .58489 L
.95519 .58367 L
.9539 .58245 L
.95261 .58123 L
.95133 .58002 L
.95005 .57881 L
.94877 .5776 L
.94749 .5764 L
.94621 .57518 L
.94494 .57397 L
.94367 .57276 L
.9424 .57156 L
.94114 .57035 L
.93987 .56914 L
.93861 .56794 L
.93736 .56673 L
.9361 .56553 L
.93485 .56432 L
.9336 .56312 L
.93235 .56191 L
.9311 .5607 L
.92986 .55949 L
.92862 .55829 L
.92738 .55708 L
.92614 .55587 L
.92491 .55467 L
.92368 .55346 L
.92245 .55225 L
.92122 .55104 L
.92 .54983 L
.91877 .54862 L
.91755 .54741 L
.91634 .5462 L
.91512 .54499 L
.91391 .54378 L
Mistroke
.9127 .54257 L
.91149 .54136 L
.91028 .54014 L
.90908 .53893 L
.90788 .53772 L
.90668 .53651 L
.90548 .5353 L
.90429 .53408 L
.9031 .53287 L
.90191 .53167 L
.90072 .53046 L
.89953 .52926 L
.89835 .52807 L
.89717 .52687 L
.89599 .52567 L
.89481 .52447 L
.89364 .52327 L
.89247 .52208 L
.8913 .5209 L
.89013 .51972 L
.88896 .51854 L
.8878 .51737 L
.88664 .51619 L
.88548 .51502 L
.88432 .51385 L
.88317 .51268 L
.88201 .51151 L
.88086 .51035 L
.87972 .50918 L
.87857 .50801 L
.87743 .50684 L
.87628 .50567 L
.87514 .5045 L
.87401 .50334 L
.87287 .50218 L
.87174 .50102 L
.8706 .49986 L
.86947 .4987 L
.86835 .49753 L
.86722 .49637 L
.8661 .49522 L
.86498 .49407 L
.86386 .49292 L
.86274 .49178 L
.86163 .49063 L
.86051 .48949 L
.8594 .48835 L
.85829 .48721 L
.85719 .48608 L
.85608 .48495 L
Mistroke
.85498 .48381 L
.85388 .48268 L
.85278 .48157 L
.85168 .48044 L
.85059 .47933 L
.84949 .47821 L
.8484 .47709 L
.84731 .47597 L
.84623 .47485 L
.84514 .47373 L
.84406 .47261 L
.84298 .4715 L
.8419 .47038 L
.84082 .46927 L
.83975 .46816 L
.83867 .46706 L
.8376 .46595 L
.83653 .46486 L
.83546 .46377 L
.8344 .4627 L
.83333 .46163 L
.83227 .46057 L
.83121 .45952 L
.83015 .45847 L
.8291 .45744 L
.82804 .4564 L
.82699 .45536 L
.82594 .45433 L
.82489 .4533 L
.82384 .45229 L
.8228 .45129 L
.82175 .4503 L
.82071 .44931 L
.81967 .44833 L
.81864 .44735 L
.8176 .44637 L
.81657 .4454 L
.81553 .44444 L
.8145 .44347 L
.81347 .44252 L
.81245 .44159 L
.81142 .44066 L
.8104 .43973 L
.80938 .43881 L
.80836 .43789 L
.80734 .43697 L
.80632 .43606 L
.80531 .43516 L
.8043 .43426 L
.80329 .43337 L
Mistroke
.80228 .43249 L
.80127 .4316 L
.80026 .43072 L
.79926 .42984 L
.79826 .42896 L
.79726 .42808 L
.79626 .42721 L
.79526 .42633 L
.79427 .42547 L
.79327 .42462 L
.79228 .42376 L
.79129 .42291 L
.7903 .42206 L
.78932 .42121 L
.78833 .42037 L
.78735 .41953 L
.78637 .41869 L
.78539 .41786 L
.78441 .41703 L
.78343 .41622 L
.78246 .41542 L
.78149 .41463 L
.78051 .41384 L
.77954 .41305 L
.77858 .41226 L
.77761 .41148 L
.77664 .4107 L
.77568 .40994 L
.77472 .40919 L
.77376 .40844 L
.7728 .40769 L
.77184 .40695 L
.77089 .4062 L
.76994 .40546 L
.76898 .40472 L
.76803 .40399 L
.76708 .40327 L
.76614 .40254 L
.76519 .40181 L
.76425 .40108 L
.76331 .40036 L
.76236 .39964 L
.76143 .39893 L
.76049 .39822 L
.75955 .39752 L
.75862 .39683 L
.75768 .39614 L
.75675 .39545 L
.75582 .39476 L
.75489 .39407 L
Mistroke
.75397 .39339 L
.75304 .39271 L
.75212 .39203 L
.7512 .39136 L
.75028 .39069 L
.74936 .39002 L
.74844 .38936 L
.74752 .38869 L
.74661 .38803 L
.7457 .38737 L
.74479 .38672 L
.74388 .38606 L
.74297 .38542 L
.74206 .38477 L
.74115 .38413 L
.74025 .38349 L
.73935 .38285 L
.73845 .38221 L
.73755 .38158 L
.73665 .38094 L
.73575 .38031 L
.73486 .37968 L
.73396 .37906 L
.73307 .37845 L
.73218 .37783 L
.73129 .37722 L
.7304 .37661 L
.72952 .37601 L
.72863 .37541 L
.72775 .37481 L
.72687 .37424 L
.72599 .37366 L
.72511 .37309 L
.72423 .37251 L
.72335 .37194 L
.72248 .37137 L
.72161 .3708 L
.72073 .37023 L
.71986 .36966 L
.71899 .3691 L
.71813 .36854 L
.71726 .36798 L
.71639 .36743 L
.71553 .36687 L
.71467 .36632 L
.71381 .36578 L
.71295 .36523 L
.71209 .36469 L
.71123 .36414 L
.71038 .3636 L
Mistroke
.70952 .36306 L
.70867 .36252 L
.70782 .36198 L
.70697 .36144 L
.70612 .36089 L
.70527 .36036 L
.70443 .35982 L
.70358 .35928 L
.70274 .35875 L
.7019 .35822 L
.70106 .35769 L
.70022 .35717 L
.69938 .35664 L
.69854 .35612 L
.69771 .3556 L
.69688 .35508 L
.69604 .35456 L
.69521 .35403 L
.69438 .35351 L
.69355 .35299 L
.69273 .35248 L
.6919 .35196 L
.69108 .35145 L
.69025 .35093 L
.68943 .35042 L
.68861 .3499 L
.68779 .34939 L
.68697 .34887 L
.68615 .34836 L
.68534 .34785 L
.68452 .34734 L
.68371 .34683 L
.6829 .34632 L
.68209 .34581 L
.68128 .3453 L
.68047 .3448 L
.67966 .3443 L
.67886 .3438 L
.67805 .3433 L
.67725 .3428 L
.67645 .3423 L
.67565 .34181 L
.67485 .34132 L
.67405 .34082 L
.67325 .34033 L
.67246 .33984 L
.67166 .33935 L
.67087 .33886 L
.67008 .33837 L
.66929 .33788 L
Mistroke
.6685 .33739 L
.66771 .33691 L
.66692 .33642 L
.66614 .33593 L
.66535 .33545 L
.66457 .33497 L
.66379 .33449 L
.66301 .33401 L
.66223 .33354 L
.66145 .33306 L
.66067 .33258 L
.65989 .3321 L
.65912 .33162 L
.65834 .33115 L
.65757 .33067 L
.6568 .3302 L
.65603 .32973 L
.65526 .32925 L
.65449 .32878 L
.65372 .32831 L
.65296 .32784 L
.65219 .32737 L
.65143 .3269 L
.65067 .32642 L
.64991 .32595 L
.64915 .32548 L
.64839 .32501 L
.64763 .32454 L
.64687 .32407 L
.64612 .32361 L
.64536 .32315 L
.64461 .32269 L
.64386 .32222 L
.64311 .32176 L
.64236 .3213 L
.64161 .32085 L
.64086 .32039 L
.64011 .31993 L
.63937 .31948 L
.63863 .31902 L
.63788 .31857 L
.63714 .31811 L
.6364 .31766 L
.63566 .3172 L
.63492 .31675 L
.63418 .3163 L
.63345 .31584 L
.63271 .31539 L
.63198 .31494 L
.63124 .31449 L
Mistroke
.63051 .31405 L
.62978 .3136 L
.62905 .31316 L
.62832 .31272 L
.62759 .31228 L
.62687 .31184 L
.62614 .3114 L
.62542 .31096 L
.62469 .31053 L
.62397 .31009 L
.62325 .30966 L
.62253 .30924 L
.62181 .30882 L
.62109 .30841 L
.62037 .30799 L
.61966 .30757 L
.61894 .30716 L
.61823 .30676 L
.61752 .30635 L
.6168 .30594 L
.61609 .30554 L
.61538 .30513 L
.61467 .30473 L
.61397 .30433 L
.61326 .30393 L
.61255 .30352 L
.61185 .30312 L
.61115 .30272 L
.61044 .30232 L
.60974 .30192 L
.60904 .30152 L
.60834 .30112 L
.60764 .30072 L
.60694 .30032 L
.60625 .29992 L
.60555 .29952 L
.60486 .29912 L
.60416 .29873 L
.60347 .29833 L
.60278 .29793 L
.60209 .29754 L
.6014 .29714 L
.60071 .29675 L
.60002 .29636 L
.59934 .29596 L
.59865 .29557 L
.59797 .29518 L
.59728 .29479 L
.5966 .29441 L
.59592 .29402 L
Mistroke
.59524 .29363 L
.59456 .29324 L
.59388 .29286 L
.5932 .29247 L
.59252 .29209 L
.59185 .2917 L
.59117 .29132 L
.5905 .29094 L
.58983 .29056 L
.58915 .29018 L
.58848 .2898 L
.58781 .28942 L
.58714 .28904 L
.58648 .28866 L
.58581 .28829 L
.58514 .28791 L
.58448 .28754 L
.58381 .28716 L
.58315 .28678 L
.58249 .28641 L
.58182 .28604 L
.58116 .28566 L
.5805 .28529 L
.57984 .28492 L
.57919 .28455 L
.57853 .28418 L
.57787 .28381 L
.57722 .28344 L
.57656 .28308 L
.57591 .28271 L
.57526 .28234 L
.57461 .28198 L
.57396 .28161 L
.57331 .28124 L
.57266 .28088 L
.57201 .28051 L
.57136 .28015 L
.57072 .27979 L
.57007 .27943 L
.56943 .27908 L
.56878 .27872 L
.56814 .27836 L
.5675 .27801 L
.56686 .27765 L
.56622 .27729 L
.56558 .27694 L
.56494 .27658 L
.5643 .27622 L
.56367 .27587 L
.56303 .27551 L
Mistroke
.5624 .27516 L
.56176 .2748 L
.56113 .27445 L
.5605 .2741 L
.55987 .27376 L
.55924 .27341 L
.55861 .27306 L
.55798 .27272 L
.55735 .27238 L
.55673 .27203 L
.5561 .27169 L
.55547 .27134 L
.55485 .271 L
.55423 .27066 L
.5536 .27032 L
.55298 .26998 L
.55236 .26964 L
.55174 .2693 L
.55112 .26897 L
.5505 .26863 L
.54989 .2683 L
.54927 .26796 L
.54865 .26763 L
.54804 .26729 L
.54743 .26696 L
.54681 .26663 L
.5462 .26629 L
.54559 .26596 L
.54498 .26563 L
.54437 .2653 L
.54376 .26497 L
.54315 .26464 L
.54254 .26431 L
.54194 .26399 L
.54133 .26366 L
.54072 .26333 L
.54012 .263 L
.53952 .26268 L
.53891 .26235 L
.53831 .26203 L
.53771 .26171 L
.53711 .26139 L
.53651 .26107 L
.53591 .26074 L
.53532 .26042 L
.53472 .2601 L
.53412 .25978 L
.53353 .25946 L
.53293 .25914 L
.53234 .25882 L
Mistroke
.53175 .2585 L
.53115 .25818 L
.53056 .25786 L
.52997 .25754 L
.52938 .25723 L
.52879 .25691 L
.5282 .2566 L
.52762 .25629 L
.52703 .25597 L
.52644 .25566 L
.52586 .25535 L
.52527 .25505 L
.52469 .25474 L
.52411 .25444 L
.52353 .25413 L
.52295 .25383 L
.52236 .25352 L
.52178 .25322 L
.52121 .25292 L
.52063 .25262 L
.52005 .25231 L
.51947 .25201 L
.5189 .25171 L
.51832 .25141 L
.51775 .2511 L
.51717 .2508 L
.5166 .2505 L
.51603 .2502 L
.51546 .2499 L
.51489 .2496 L
.51432 .2493 L
.51375 .249 L
.51318 .2487 L
.51261 .2484 L
.51204 .2481 L
.51148 .2478 L
.51091 .2475 L
.51035 .24721 L
.50978 .24691 L
.50922 .24662 L
.50866 .24633 L
.5081 .24604 L
.50754 .24575 L
.50697 .24546 L
.50642 .24517 L
.50586 .24488 L
.5053 .24459 L
.50474 .24431 L
.50418 .24402 L
.50363 .24374 L
Mistroke
.50307 .24345 L
.50252 .24317 L
.50196 .24289 L
.50141 .2426 L
.50086 .24232 L
.50031 .24204 L
.49976 .24176 L
.4992 .24148 L
.49866 .2412 L
.49811 .24092 L
.49756 .24064 L
.49701 .24036 L
.49646 .24008 L
.49592 .2398 L
.49537 .23952 L
.49483 .23924 L
.49428 .23897 L
.49374 .23869 L
.4932 .23841 L
.49266 .23814 L
.49211 .23786 L
.49157 .23758 L
.49103 .23731 L
.49049 .23703 L
.48996 .23676 L
.48942 .23649 L
.48888 .23621 L
.48834 .23594 L
.48781 .23567 L
.48727 .2354 L
.48674 .23513 L
.48621 .23486 L
.48567 .23458 L
.48514 .23431 L
.48461 .23404 L
.48408 .23377 L
.48355 .2335 L
.48302 .23323 L
.48249 .23296 L
.48196 .2327 L
.48143 .23243 L
.4809 .23217 L
.48038 .2319 L
.47985 .23164 L
.47933 .23137 L
.4788 .23111 L
.47828 .23084 L
.47776 .23058 L
.47723 .23032 L
.47671 .23006 L
Mistroke
.47619 .2298 L
.47567 .22954 L
.47515 .22928 L
.47463 .22902 L
.47411 .22876 L
.47359 .22851 L
.47308 .22825 L
.47256 .22799 L
.47204 .22773 L
.47153 .22748 L
.47101 .22722 L
.4705 .22696 L
.46999 .22671 L
.46947 .22645 L
.46896 .22619 L
.46845 .22594 L
.46794 .22568 L
.46743 .22542 L
.46692 .22517 L
.46641 .22491 L
.4659 .22466 L
.46539 .2244 L
.46489 .22415 L
.46438 .22389 L
.46388 .22364 L
.46337 .22339 L
.46287 .22313 L
.46236 .22288 L
.46186 .22263 L
.46136 .22238 L
.46085 .22213 L
.46035 .22188 L
.45985 .22162 L
.45935 .22137 L
.45885 .22112 L
.45835 .22087 L
.45785 .22063 L
.45736 .22038 L
.45686 .22013 L
.45636 .21988 L
.45587 .21963 L
.45537 .21939 L
.45488 .21914 L
.45438 .21889 L
.45389 .21865 L
.45339 .2184 L
.4529 .21816 L
.45241 .21791 L
.45192 .21767 L
.45143 .21743 L
Mistroke
.45094 .21718 L
.45045 .21694 L
.44996 .2167 L
.44947 .21646 L
.44898 .21622 L
.4485 .21598 L
.44801 .21574 L
.44752 .21549 L
.44704 .21525 L
.44655 .21501 L
.44607 .21477 L
.44559 .21454 L
.4451 .2143 L
.44462 .21406 L
.44414 .21382 L
.44366 .21359 L
.44318 .21335 L
.4427 .21311 L
.44222 .21288 L
.44174 .21264 L
.44126 .21241 L
.44078 .21217 L
.44031 .21194 L
.43983 .21171 L
.43935 .21147 L
.43888 .21124 L
.4384 .21101 L
.43793 .21077 L
.43745 .21054 L
.43698 .21031 L
.43651 .21008 L
.43604 .20984 L
.43556 .20961 L
.43509 .20938 L
.43462 .20915 L
.43415 .20891 L
.43368 .20868 L
.43321 .20845 L
.43275 .20822 L
.43228 .20799 L
.43181 .20776 L
.43135 .20753 L
.43088 .2073 L
.43041 .20707 L
.42995 .20684 L
.42948 .20661 L
.42902 .20638 L
.42856 .20615 L
.42809 .20592 L
.42763 .2057 L
Mistroke
.42717 .20547 L
.42671 .20524 L
.42625 .20501 L
.42579 .20478 L
.42533 .20456 L
.42487 .20433 L
.42441 .2041 L
.42395 .20388 L
.4235 .20365 L
.42304 .20343 L
.42258 .2032 L
.42213 .20298 L
.42167 .20276 L
.42122 .20253 L
.42076 .20231 L
.42031 .20209 L
.41986 .20187 L
.41941 .20165 L
.41895 .20143 L
.4185 .20121 L
.41805 .20099 L
.4176 .20077 L
.41715 .20055 L
.4167 .20033 L
.41625 .20011 L
.4158 .19989 L
.41536 .19967 L
.41491 .19946 L
.41446 .19924 L
.41402 .19902 L
.41357 .19881 L
.41312 .1986 L
.41268 .19838 L
.41224 .19817 L
.41179 .19796 L
.41135 .19774 L
.41091 .19753 L
.41046 .19732 L
.41002 .19711 L
.40958 .1969 L
.40914 .19668 L
.4087 .19647 L
.40826 .19626 L
.40782 .19605 L
.40738 .19584 L
.40695 .19563 L
.40651 .19543 L
.40607 .19522 L
.40563 .19501 L
.4052 .1948 L
Mistroke
.40476 .1946 L
.40433 .19439 L
.40389 .19418 L
.40346 .19398 L
.40302 .19377 L
.40259 .19357 L
.40216 .19336 L
.40173 .19315 L
.40129 .19295 L
.40086 .19274 L
.40043 .19254 L
.4 .19233 L
.39957 .19213 L
.39914 .19193 L
.39872 .19172 L
.39829 .19152 L
.39786 .19132 L
.39743 .19112 L
.397 .19092 L
.39658 .19071 L
.39615 .19051 L
.39573 .19031 L
.3953 .19011 L
.39488 .18991 L
.39445 .18971 L
.39403 .18951 L
.39361 .18931 L
.39319 .18911 L
.39276 .18891 L
.39234 .18871 L
.39192 .1885 L
.3915 .1883 L
.39108 .1881 L
.39066 .1879 L
.39024 .18771 L
.38982 .18751 L
.3894 .18731 L
.38899 .18711 L
.38857 .18691 L
.38815 .18671 L
.38774 .18652 L
.38732 .18632 L
.3869 .18612 L
.38649 .18593 L
.38608 .18573 L
.38566 .18553 L
.38525 .18534 L
.38483 .18514 L
.38442 .18494 L
.38401 .18475 L
Mistroke
.3836 .18455 L
.38319 .18435 L
.38278 .18416 L
.38237 .18396 L
.38196 .18377 L
.38155 .18357 L
.38114 .18338 L
.38073 .18318 L
.38032 .18299 L
.37991 .18279 L
.37951 .1826 L
.3791 .1824 L
.37869 .18221 L
.37829 .18202 L
.37788 .18182 L
.37748 .18163 L
.37707 .18144 L
.37667 .18125 L
.37626 .18105 L
.37586 .18086 L
.37546 .18067 L
.37506 .18048 L
.37465 .18028 L
.37425 .18009 L
.37385 .1799 L
.37345 .17971 L
.37305 .17951 L
.37265 .17932 L
.37225 .17913 L
.37185 .17894 L
.37145 .17875 L
.37106 .17856 L
.37066 .17837 L
.37026 .17818 L
.36987 .17799 L
.36947 .1778 L
.36907 .17761 L
.36868 .17742 L
.36828 .17723 L
.36789 .17704 L
.36749 .17685 L
.3671 .17666 L
.36671 .17647 L
.36632 .17628 L
.36592 .1761 L
.36553 .17591 L
.36514 .17572 L
.36475 .17554 L
.36436 .17535 L
.36397 .17517 L
Mistroke
.36358 .17498 L
.36319 .1748 L
.3628 .17462 L
.36241 .17443 L
.36202 .17425 L
.36164 .17407 L
.36125 .17389 L
.36086 .17371 L
.36047 .17352 L
.36009 .17334 L
.3597 .17316 L
.35932 .17298 L
.35893 .1728 L
.35855 .17262 L
.35816 .17243 L
.35778 .17225 L
.3574 .17207 L
.35702 .17189 L
.35663 .17171 L
.35625 .17153 L
.35587 .17135 L
.35549 .17117 L
.35511 .17099 L
.35473 .17081 L
.35435 .17063 L
.35397 .17045 L
.35359 .17027 L
.35321 .17009 L
.35283 .16991 L
.35245 .16973 L
.35208 .16955 L
.3517 .16938 L
.35132 .1692 L
.35095 .16902 L
.35057 .16884 L
.3502 .16867 L
.34982 .16849 L
.34945 .16831 L
.34907 .16814 L
.3487 .16796 L
.34832 .16779 L
.34795 .16761 L
.34758 .16743 L
.34721 .16726 L
.34683 .16709 L
.34646 .16691 L
.34609 .16674 L
.34572 .16656 L
.34535 .16639 L
.34498 .16621 L
Mistroke
.34461 .16604 L
.34424 .16587 L
.34387 .16569 L
.34351 .16552 L
.34314 .16535 L
.34277 .16518 L
.3424 .16501 L
.34204 .16484 L
.34167 .16466 L
.3413 .1645 L
.34094 .16433 L
.34057 .16416 L
.34021 .16399 L
.33984 .16382 L
.33948 .16365 L
.33911 .16349 L
.33875 .16332 L
.33839 .16315 L
.33803 .16298 L
.33766 .16282 L
.3373 .16265 L
.33694 .16248 L
.33658 .16232 L
.33622 .16215 L
.33586 .16198 L
.3355 .16182 L
.33514 .16165 L
.33478 .16149 L
.33442 .16132 L
.33406 .16116 L
.3337 .161 L
.33335 .16083 L
.33299 .16067 L
.33263 .1605 L
.33227 .16034 L
.33192 .16018 L
.33156 .16002 L
.33121 .15985 L
.33085 .15969 L
.3305 .15953 L
.33014 .15937 L
.32979 .1592 L
.32943 .15904 L
.32908 .15888 L
.32873 .15872 L
.32838 .15856 L
.32802 .1584 L
.32767 .15824 L
.32732 .15808 L
.32697 .15792 L
Mistroke
.32662 .15776 L
.32627 .1576 L
.32592 .15744 L
.32557 .15728 L
.32522 .15712 L
.32487 .15696 L
.32452 .1568 L
.32417 .15664 L
.32382 .15648 L
.32348 .15632 L
.32313 .15616 L
.32278 .15601 L
.32244 .15585 L
.32209 .15569 L
.32174 .15553 L
.3214 .15538 L
.32105 .15522 L
.32071 .15506 L
.32036 .15491 L
.32002 .15475 L
.31968 .15459 L
.31933 .15444 L
.31899 .15428 L
.31865 .15413 L
.3183 .15397 L
.31796 .15381 L
.31762 .15366 L
.31728 .1535 L
.31694 .15335 L
.3166 .1532 L
.31626 .15304 L
.31592 .15289 L
.31558 .15273 L
.31524 .15258 L
.3149 .15242 L
.31456 .15227 L
.31422 .15211 L
.31389 .15196 L
.31355 .15181 L
.31321 .15165 L
.31287 .1515 L
.31254 .15135 L
.3122 .1512 L
.31187 .15104 L
.31153 .15089 L
.31119 .15074 L
.31086 .15059 L
.31053 .15043 L
.31019 .15028 L
.30986 .15013 L
Mistroke
.30952 .14998 L
.30919 .14983 L
.30886 .14967 L
.30853 .14952 L
.30819 .14937 L
.30786 .14922 L
.30753 .14907 L
.3072 .14892 L
.30687 .14876 L
.30654 .14861 L
.30621 .14846 L
.30588 .14831 L
.30555 .14816 L
.30522 .14801 L
.30489 .14786 L
.30456 .14771 L
.30423 .14756 L
.3039 .14741 L
.30358 .14726 L
.30325 .14711 L
.30292 .14696 L
.3026 .14681 L
.30227 .14666 L
.30194 .14651 L
.30162 .14636 L
.30129 .14621 L
.30097 .14607 L
.30064 .14592 L
.30032 .14577 L
.3 .14562 L
.29967 .14547 L
.29935 .14532 L
.29903 .14517 L
.2987 .14503 L
.29838 .14488 L
.29806 .14473 L
.29774 .14458 L
.29741 .14444 L
.29709 .14429 L
.29677 .14414 L
.29645 .14399 L
.29613 .14385 L
.29581 .1437 L
.29549 .14355 L
.29517 .14341 L
.29485 .14326 L
.29454 .14311 L
.29422 .14297 L
.2939 .14282 L
.29358 .14268 L
Mistroke
.29326 .14253 L
.29295 .14238 L
.29263 .14224 L
.29231 .14209 L
.292 .14195 L
.29168 .1418 L
.29137 .14166 L
.29105 .14151 L
.29074 .14137 L
.29042 .14122 L
.29011 .14108 L
.28979 .14094 L
.28948 .14079 L
.28917 .14065 L
.28885 .14051 L
.28854 .14036 L
.28823 .14022 L
.28791 .14008 L
.2876 .13994 L
.28729 .13979 L
.28698 .13965 L
.28667 .13951 L
.28636 .13937 L
.28605 .13923 L
.28574 .13909 L
.28543 .13895 L
.28512 .13881 L
.28481 .13867 L
.2845 .13853 L
.28419 .13839 L
.28388 .13825 L
.28357 .13811 L
.28327 .13797 L
.28296 .13783 L
.28265 .13769 L
.28235 .13755 L
.28204 .13741 L
.28173 .13727 L
.28143 .13713 L
.28112 .13699 L
.28082 .13685 L
.28051 .13671 L
.28021 .13658 L
.2799 .13644 L
.2796 .1363 L
.27929 .13616 L
.27899 .13603 L
.27869 .13589 L
.27838 .13575 L
.27808 .13561 L
Mistroke
.27778 .13548 L
.27748 .13534 L
.27717 .1352 L
.27687 .13507 L
.27657 .13493 L
.27627 .13479 L
.27597 .13466 L
.27567 .13452 L
.27537 .13439 L
.27507 .13425 L
.27477 .13412 L
.27447 .13398 L
.27417 .13385 L
.27387 .13371 L
.27357 .13358 L
.27327 .13344 L
.27298 .13331 L
.27268 .13318 L
.27238 .13304 L
.27208 .13291 L
.27179 .13278 L
.27149 .13265 L
.2712 .13251 L
.2709 .13238 L
.2706 .13225 L
.27031 .13211 L
.27001 .13198 L
.26972 .13185 L
.26942 .13172 L
.26913 .13158 L
.26884 .13145 L
.26854 .13132 L
.26825 .13119 L
.26795 .13106 L
.26766 .13093 L
.26737 .1308 L
.26708 .13066 L
.26678 .13053 L
.26649 .1304 L
.2662 .13027 L
.26591 .13014 L
.26562 .13001 L
.26533 .12988 L
.26504 .12975 L
.26475 .12962 L
.26446 .12949 L
.26417 .12936 L
.26388 .12923 L
.26359 .1291 L
.2633 .12897 L
Mistroke
.26301 .12884 L
.26272 .12872 L
.26244 .12859 L
.26215 .12846 L
.26186 .12833 L
.26157 .1282 L
.26129 .12808 L
.261 .12795 L
.26071 .12782 L
.26043 .12769 L
.26014 .12757 L
.25986 .12744 L
.25957 .12731 L
.25928 .12719 L
.259 .12706 L
.25872 .12693 L
.25843 .1268 L
.25815 .12668 L
.25786 .12655 L
.25758 .12642 L
.2573 .1263 L
.25701 .12617 L
.25673 .12605 L
.25645 .12592 L
.25617 .12579 L
.25588 .12567 L
.2556 .12554 L
.25532 .12541 L
.25504 .12529 L
.25476 .12516 L
.25448 .12504 L
.2542 .12491 L
.25392 .12479 L
.25364 .12466 L
.25336 .12454 L
.25308 .12441 L
.2528 .12428 L
.25252 .12416 L
.25224 .12403 L
.25196 .12391 L
.25169 .12378 L
.25141 .12366 L
.25113 .12354 L
.25085 .12341 L
.25058 .12329 L
.2503 .12317 L
.25002 .12304 L
.24975 .12292 L
.24947 .1228 L
.24919 .12267 L
Mistroke
.24892 .12255 L
.24864 .12243 L
.24837 .1223 L
.24809 .12218 L
.24782 .12206 L
.24754 .12194 L
.24727 .12181 L
.247 .12169 L
.24672 .12157 L
.24645 .12145 L
.24618 .12132 L
.2459 .1212 L
.24563 .12108 L
.24536 .12096 L
.24509 .12084 L
.24481 .12071 L
.24454 .12059 L
.24427 .12047 L
.244 .12035 L
.24373 .12023 L
.24346 .12011 L
.24319 .11999 L
.24292 .11987 L
.24265 .11975 L
.24238 .11963 L
.24211 .11951 L
.24184 .11939 L
.24157 .11927 L
.2413 .11915 L
.24103 .11903 L
.24076 .11891 L
.2405 .11879 L
.24023 .11867 L
.23996 .11855 L
.23969 .11843 L
.23943 .11832 L
.23916 .1182 L
.23889 .11808 L
.23863 .11796 L
.23836 .11784 L
.2381 .11772 L
.23783 .11761 L
.23756 .11749 L
.2373 .11737 L
.23703 .11725 L
.23677 .11714 L
.23651 .11702 L
.23624 .1169 L
.23598 .11678 L
.23571 .11666 L
Mistroke
.23545 .11655 L
.23519 .11643 L
.23492 .11631 L
.23466 .1162 L
.2344 .11608 L
.23414 .11596 L
.23387 .11585 L
.23361 .11573 L
.23335 .11561 L
.23309 .1155 L
.23283 .11538 L
.23257 .11527 L
.23231 .11515 L
.23205 .11503 L
.23179 .11492 L
.23153 .1148 L
.23127 .11469 L
.23101 .11457 L
.23075 .11446 L
.23049 .11434 L
.23023 .11423 L
.22997 .11412 L
.22971 .114 L
.22945 .11389 L
.2292 .11377 L
.22894 .11366 L
.22868 .11354 L
.22842 .11343 L
.22817 .11331 L
.22791 .1132 L
.22765 .11309 L
.2274 .11297 L
.22714 .11286 L
.22688 .11275 L
.22663 .11263 L
.22637 .11252 L
.22612 .11241 L
.22586 .11229 L
.22561 .11218 L
.22535 .11207 L
.2251 .11196 L
.22484 .11185 L
.22459 .11173 L
.22434 .11162 L
.22408 .11151 L
.22383 .1114 L
.22358 .11129 L
.22332 .11118 L
.22307 .11107 L
.22282 .11096 L
Mistroke
.22257 .11084 L
.22232 .11073 L
.22206 .11062 L
.22181 .11051 L
.22156 .1104 L
.22131 .11029 L
.22106 .11018 L
.22081 .11007 L
.22056 .10996 L
.22031 .10985 L
.22006 .10974 L
.21981 .10963 L
.21956 .10952 L
.21931 .10941 L
.21906 .1093 L
.21881 .10919 L
.21856 .10909 L
.21831 .10898 L
.21807 .10887 L
.21782 .10876 L
.21757 .10865 L
.21732 .10854 L
.21707 .10843 L
.21683 .10832 L
.21658 .10822 L
.21633 .10811 L
.21609 .108 L
.21584 .10789 L
.21559 .10779 L
.21535 .10768 L
.2151 .10757 L
.21486 .10747 L
.21461 .10736 L
.21437 .10725 L
.21412 .10715 L
.21388 .10704 L
.21363 .10693 L
.21339 .10683 L
.21315 .10672 L
.2129 .10661 L
.21266 .10651 L
.21241 .1064 L
.21217 .1063 L
.21193 .10619 L
.21169 .10608 L
.21144 .10598 L
.2112 .10587 L
.21096 .10577 L
.21072 .10566 L
.21047 .10556 L
Mistroke
.21023 .10545 L
.20999 .10535 L
.20975 .10524 L
.20951 .10514 L
.20927 .10503 L
.20903 .10493 L
.20879 .10482 L
.20855 .10472 L
.20831 .10461 L
.20807 .10451 L
.20783 .10441 L
.20759 .1043 L
.20735 .1042 L
.20711 .10409 L
.20687 .10399 L
.20663 .10389 L
.2064 .10378 L
.20616 .10368 L
.20592 .10357 L
.20568 .10347 L
.20545 .10337 L
.20521 .10326 L
.20497 .10316 L
.20473 .10306 L
.2045 .10295 L
.20426 .10285 L
.20402 .10275 L
.20379 .10264 L
.20355 .10254 L
.20332 .10244 L
.20308 .10233 L
.20285 .10223 L
.20261 .10213 L
.20238 .10202 L
.20214 .10192 L
.20191 .10182 L
.20167 .10172 L
.20144 .10162 L
.2012 .10151 L
.20097 .10141 L
.20074 .10131 L
.2005 .10121 L
.20027 .10111 L
.20004 .101 L
.19981 .1009 L
.19957 .1008 L
.19934 .1007 L
.19911 .1006 L
.19888 .1005 L
.19864 .1004 L
Mistroke
.19841 .1003 L
.19818 .10019 L
.19795 .10009 L
.19772 .09999 L
.19749 .09989 L
.19726 .09979 L
.19703 .09969 L
.1968 .09959 L
.19657 .09949 L
.19634 .09939 L
.19611 .09929 L
.19588 .09919 L
.19565 .09909 L
.19542 .09899 L
.19519 .09889 L
.19496 .09879 L
.19473 .09869 L
.19451 .09859 L
.19428 .09849 L
.19405 .09839 L
.19382 .09829 L
.19359 .09819 L
.19337 .09809 L
.19314 .09799 L
.19291 .09789 L
.19269 .09779 L
.19246 .0977 L
.19223 .0976 L
.19201 .0975 L
.19178 .0974 L
.19155 .0973 L
.19133 .0972 L
.1911 .09711 L
.19088 .09701 L
.19065 .09691 L
.19043 .09681 L
.1902 .09672 L
.18998 .09662 L
.18975 .09652 L
.18953 .09642 L
.18931 .09633 L
.18908 .09623 L
.18886 .09613 L
.18863 .09604 L
.18841 .09594 L
.18819 .09584 L
.18796 .09575 L
.18774 .09565 L
.18752 .09555 L
.1873 .09546 L
Mistroke
.18707 .09536 L
.18685 .09527 L
.18663 .09517 L
.18641 .09508 L
.18619 .09498 L
.18597 .09488 L
.18575 .09479 L
.18552 .09469 L
.1853 .0946 L
.18508 .0945 L
.18486 .09441 L
.18464 .09431 L
.18442 .09422 L
.1842 .09412 L
.18398 .09403 L
.18376 .09393 L
.18354 .09384 L
.18332 .09374 L
.18311 .09365 L
.18289 .09355 L
.18267 .09346 L
.18245 .09337 L
.18223 .09327 L
.18201 .09318 L
.1818 .09308 L
.18158 .09299 L
.18136 .0929 L
.18114 .0928 L
.18093 .09271 L
.18071 .09261 L
.18049 .09252 L
.18027 .09243 L
.18006 .09233 L
.17984 .09224 L
.17963 .09214 L
.17941 .09205 L
.17919 .09196 L
.17898 .09186 L
.17876 .09177 L
.17855 .09168 L
.17833 .09158 L
.17812 .09149 L
.1779 .0914 L
.17769 .0913 L
.17747 .09121 L
.17726 .09112 L
.17705 .09102 L
.17683 .09093 L
.17662 .09084 L
.1764 .09075 L
Mistroke
.17619 .09065 L
.17598 .09056 L
.17576 .09047 L
.17555 .09038 L
.17534 .09029 L
.17513 .09019 L
.17491 .0901 L
.1747 .09001 L
.17449 .08992 L
.17428 .08983 L
.17407 .08974 L
.17385 .08965 L
.17364 .08955 L
.17343 .08946 L
.17322 .08937 L
.17301 .08928 L
.1728 .08919 L
.17259 .0891 L
.17238 .08901 L
.17217 .08892 L
.17196 .08883 L
.17175 .08874 L
.17154 .08865 L
.17133 .08856 L
.17112 .08847 L
.17091 .08838 L
.1707 .08829 L
.17049 .0882 L
.17028 .08811 L
.17007 .08802 L
.16987 .08793 L
.16966 .08784 L
.16945 .08775 L
.16924 .08766 L
.16903 .08757 L
.16883 .08748 L
.16862 .08739 L
.16841 .0873 L
.16821 .08721 L
.168 .08712 L
.16779 .08703 L
.16758 .08694 L
.16738 .08685 L
.16717 .08676 L
.16697 .08667 L
.16676 .08658 L
.16655 .08649 L
.16635 .0864 L
.16614 .08631 L
.16594 .08623 L
Mistroke
.16573 .08614 L
.16553 .08605 L
.16532 .08596 L
.16512 .08587 L
.16491 .08578 L
.16471 .08569 L
.16451 .0856 L
.1643 .08551 L
.1641 .08543 L
.16389 .08534 L
.16369 .08525 L
.16349 .08516 L
.16328 .08507 L
.16308 .08498 L
.16288 .0849 L
.16268 .08481 L
.16247 .08472 L
.16227 .08463 L
.16207 .08454 L
.16187 .08445 L
.16166 .08437 L
.16146 .08428 L
.16126 .08419 L
.16106 .0841 L
.16086 .08401 L
.16066 .08393 L
.16046 .08384 L
.16025 .08375 L
.16005 .08366 L
.15985 .08357 L
.15965 .08349 L
.15945 .0834 L
.15925 .08331 L
.15905 .08322 L
.15885 .08314 L
.15865 .08305 L
.15845 .08296 L
.15825 .08287 L
.15806 .08279 L
.15786 .0827 L
.15766 .08261 L
.15746 .08252 L
.15726 .08244 L
.15706 .08235 L
.15686 .08226 L
.15667 .08218 L
.15647 .08209 L
.15627 .082 L
.15607 .08192 L
.15587 .08183 L
Mistroke
.15568 .08174 L
.15548 .08166 L
.15528 .08157 L
.15509 .08148 L
.15489 .0814 L
.15469 .08131 L
.1545 .08122 L
.1543 .08114 L
.1541 .08105 L
.15391 .08096 L
.15371 .08088 L
.15352 .08079 L
.15332 .0807 L
.15313 .08062 L
.15293 .08053 L
.15274 .08045 L
.15254 .08036 L
.15235 .08027 L
.15215 .08019 L
.15196 .0801 L
.15176 .08002 L
.15157 .07993 L
.15137 .07984 L
.15118 .07976 L
.15099 .07967 L
.15079 .07959 L
.1506 .0795 L
.15041 .07942 L
.15021 .07933 L
.15002 .07924 L
.14983 .07916 L
.14964 .07907 L
.14944 .07899 L
.14925 .0789 L
.14906 .07882 L
.14887 .07873 L
.14867 .07865 L
.14848 .07856 L
.14829 .07848 L
.1481 .07839 L
.14791 .07831 L
.14772 .07822 L
.14753 .07813 L
.14733 .07805 L
.14714 .07796 L
.14695 .07788 L
.14676 .07779 L
.14657 .07771 L
.14638 .07763 L
.14619 .07754 L
Mistroke
.146 .07746 L
.14581 .07737 L
.14562 .07729 L
.14543 .0772 L
.14524 .07712 L
.14505 .07703 L
.14487 .07695 L
.14468 .07686 L
.14449 .07678 L
.1443 .0767 L
.14411 .07661 L
.14392 .07653 L
.14373 .07644 L
.14355 .07636 L
.14336 .07628 L
.14317 .07619 L
.14298 .07611 L
.14279 .07603 L
.14261 .07594 L
.14242 .07586 L
.14223 .07577 L
.14205 .07569 L
.14186 .07561 L
.14167 .07552 L
.14149 .07544 L
.1413 .07536 L
.14111 .07527 L
.14093 .07519 L
.14074 .07511 L
.14056 .07502 L
.14037 .07494 L
.14018 .07486 L
.14 .07477 L
.13981 .07469 L
.13963 .07461 L
.13944 .07453 L
.13926 .07444 L
.13907 .07436 L
.13889 .07428 L
.1387 .0742 L
.13852 .07411 L
.13834 .07403 L
.13815 .07395 L
.13797 .07387 L
.13778 .07379 L
.1376 .0737 L
.13742 .07362 L
.13723 .07354 L
.13705 .07346 L
.13687 .07338 L
Mistroke
.13668 .0733 L
.1365 .07321 L
.13632 .07313 L
.13614 .07305 L
.13595 .07297 L
.13577 .07289 L
.13559 .07281 L
.13541 .07273 L
.13523 .07265 L
.13504 .07257 L
.13486 .07249 L
.13468 .0724 L
.1345 .07232 L
.13432 .07224 L
.13414 .07216 L
.13396 .07208 L
.13378 .072 L
.13359 .07192 L
.13341 .07184 L
.13323 .07176 L
.13305 .07168 L
.13287 .0716 L
.13269 .07152 L
.13251 .07144 L
.13233 .07136 L
.13215 .07128 L
.13197 .0712 L
.13179 .07112 L
.13162 .07104 L
.13144 .07096 L
.13126 .07089 L
.13108 .07081 L
.1309 .07073 L
.13072 .07065 L
.13054 .07057 L
.13036 .07049 L
.13019 .07041 L
.13001 .07033 L
.12983 .07025 L
.12965 .07017 L
.12948 .07009 L
.1293 .07002 L
.12912 .06994 L
.12894 .06986 L
.12877 .06978 L
.12859 .0697 L
.12841 .06962 L
.12824 .06954 L
.12806 .06947 L
.12788 .06939 L
Mistroke
.12771 .06931 L
.12753 .06923 L
.12735 .06915 L
.12718 .06907 L
.127 .069 L
.12683 .06892 L
.12665 .06884 L
.12647 .06876 L
.1263 .06869 L
.12612 .06861 L
.12595 .06853 L
.12577 .06845 L
.1256 .06838 L
.12542 .0683 L
.12525 .06822 L
.12508 .06814 L
.1249 .06807 L
.12473 .06799 L
.12455 .06791 L
.12438 .06784 L
.1242 .06776 L
.12403 .06768 L
.12386 .0676 L
.12368 .06753 L
.12351 .06745 L
.12334 .06737 L
.12316 .0673 L
.12299 .06722 L
.12282 .06714 L
.12265 .06707 L
.12247 .06699 L
.1223 .06691 L
.12213 .06684 L
.12196 .06676 L
.12178 .06668 L
.12161 .06661 L
.12144 .06653 L
.12127 .06645 L
.1211 .06638 L
.12093 .0663 L
.12075 .06622 L
.12058 .06615 L
.12041 .06607 L
.12024 .066 L
.12007 .06592 L
.1199 .06585 L
.11973 .06577 L
.11956 .06569 L
.11939 .06562 L
.11922 .06554 L
Mistroke
.11905 .06547 L
.11888 .06539 L
.11871 .06532 L
.11854 .06524 L
.11837 .06517 L
.1182 .06509 L
.11803 .06502 L
.11786 .06494 L
.11769 .06487 L
.11752 .06479 L
.11735 .06472 L
.11718 .06464 L
.11702 .06457 L
.11685 .06449 L
.11668 .06442 L
.11651 .06434 L
.11634 .06427 L
.11617 .06419 L
.11601 .06412 L
.11584 .06405 L
.11567 .06397 L
.1155 .0639 L
.11534 .06382 L
.11517 .06375 L
.115 .06367 L
.11483 .0636 L
.11467 .06353 L
.1145 .06345 L
.11433 .06338 L
.11417 .06331 L
.114 .06323 L
.11383 .06316 L
.11367 .06308 L
.1135 .06301 L
.11333 .06294 L
.11317 .06286 L
.113 .06279 L
.11284 .06272 L
.11267 .06264 L
.11251 .06257 L
.11234 .0625 L
.11218 .06242 L
.11201 .06235 L
.11185 .06227 L
.11168 .0622 L
.11152 .06213 L
.11135 .06205 L
.11119 .06198 L
.11102 .06191 L
.11086 .06184 L
Mistroke
.11069 .06176 L
.11053 .06169 L
.11037 .06162 L
.1102 .06154 L
.11004 .06147 L
.10987 .0614 L
.10971 .06132 L
.10955 .06125 L
.10938 .06118 L
.10922 .06111 L
.10906 .06103 L
.10889 .06096 L
.10873 .06089 L
.10857 .06081 L
.10841 .06074 L
.10824 .06067 L
.10808 .0606 L
.10792 .06052 L
.10776 .06045 L
.1076 .06038 L
.10743 .06031 L
.10727 .06023 L
.10711 .06016 L
.10695 .06009 L
.10679 .06002 L
.10663 .05994 L
.10646 .05987 L
.1063 .0598 L
.10614 .05973 L
.10598 .05966 L
.10582 .05958 L
.10566 .05951 L
.1055 .05944 L
.10534 .05937 L
.10518 .0593 L
.10502 .05923 L
.10486 .05915 L
.1047 .05908 L
.10454 .05901 L
.10438 .05894 L
.10422 .05887 L
.10406 .0588 L
.1039 .05873 L
.10374 .05865 L
.10358 .05858 L
.10342 .05851 L
.10326 .05844 L
.1031 .05837 L
.10294 .0583 L
.10279 .05823 L
Mistroke
.10263 .05816 L
.10247 .05809 L
.10231 .05801 L
.10215 .05794 L
.10199 .05787 L
.10184 .0578 L
.10168 .05773 L
.10152 .05766 L
.10136 .05759 L
.1012 .05752 L
.10105 .05745 L
.10089 .05738 L
.10073 .05731 L
.10058 .05724 L
.10042 .05716 L
.10026 .05709 L
.1001 .05702 L
.09995 .05695 L
.09979 .05688 L
.09963 .05681 L
.09948 .05674 L
.09932 .05667 L
.09917 .0566 L
.09901 .05653 L
.09885 .05646 L
.0987 .05639 L
.09854 .05632 L
.09839 .05625 L
.09823 .05618 L
.09808 .05611 L
.09792 .05604 L
.09776 .05597 L
.09761 .05591 L
.09745 .05584 L
.0973 .05577 L
.09714 .0557 L
.09699 .05563 L
.09684 .05556 L
.09668 .05549 L
.09653 .05542 L
.09637 .05535 L
.09622 .05528 L
.09606 .05521 L
.09591 .05514 L
.09576 .05508 L
.0956 .05501 L
.09545 .05494 L
.09529 .05487 L
.09514 .0548 L
.09499 .05473 L
Mistroke
.09483 .05466 L
.09468 .0546 L
.09453 .05453 L
.09438 .05446 L
.09422 .05439 L
.09407 .05432 L
.09392 .05425 L
.09376 .05418 L
.09361 .05412 L
.09346 .05405 L
.09331 .05398 L
.09316 .05391 L
.093 .05384 L
.09285 .05377 L
.0927 .05371 L
.09255 .05364 L
.0924 .05357 L
.09224 .0535 L
.09209 .05343 L
.09194 .05337 L
.09179 .0533 L
.09164 .05323 L
.09149 .05316 L
.09134 .05309 L
.09119 .05303 L
.09104 .05296 L
.09089 .05289 L
.09074 .05282 L
.09058 .05276 L
.09043 .05269 L
.09028 .05262 L
.09013 .05256 L
.08998 .05249 L
.08983 .05242 L
.08968 .05236 L
.08953 .05229 L
.08939 .05222 L
.08924 .05215 L
.08909 .05209 L
.08894 .05202 L
.08879 .05195 L
.08864 .05189 L
.08849 .05182 L
.08834 .05175 L
.08819 .05169 L
.08804 .05162 L
.08789 .05155 L
.08775 .05149 L
.0876 .05142 L
.08745 .05135 L
Mistroke
.0873 .05129 L
.08715 .05122 L
.08701 .05115 L
.08686 .05109 L
.08671 .05102 L
.08656 .05096 L
.08641 .05089 L
.08627 .05082 L
.08612 .05076 L
.08597 .05069 L
.08583 .05062 L
.08568 .05056 L
.08553 .05049 L
.08538 .05043 L
.08524 .05036 L
.08509 .05029 L
.08494 .05023 L
.0848 .05016 L
.08465 .05009 L
.0845 .05003 L
.08436 .04996 L
.08421 .0499 L
.08407 .04983 L
.08392 .04977 L
.08377 .0497 L
.08363 .04963 L
.08348 .04957 L
.08334 .0495 L
.08319 .04944 L
.08305 .04937 L
.0829 .04931 L
.08276 .04924 L
.08261 .04918 L
.08247 .04911 L
.08232 .04904 L
.08218 .04898 L
.08203 .04891 L
.08189 .04885 L
.08174 .04878 L
.0816 .04872 L
.08145 .04865 L
.08131 .04859 L
.08117 .04852 L
.08102 .04846 L
.08088 .04839 L
.08073 .04833 L
.08059 .04826 L
.08045 .0482 L
.0803 .04813 L
.08016 .04807 L
Mistroke
.08002 .048 L
.07987 .04794 L
.07973 .04787 L
.07959 .04781 L
.07944 .04774 L
.0793 .04768 L
.07916 .04761 L
.07901 .04755 L
.07887 .04748 L
.07873 .04742 L
.07859 .04735 L
.07844 .04729 L
.0783 .04722 L
.07816 .04716 L
.07802 .04709 L
.07788 .04703 L
.07773 .04697 L
.07759 .0469 L
.07745 .04684 L
.07731 .04677 L
.07717 .04671 L
.07703 .04664 L
.07688 .04658 L
.07674 .04652 L
.0766 .04645 L
.07646 .04639 L
.07632 .04632 L
.07618 .04626 L
.07604 .0462 L
.0759 .04613 L
.07576 .04607 L
.07562 .046 L
.07548 .04594 L
.07534 .04588 L
.0752 .04581 L
.07506 .04575 L
.07492 .04568 L
.07478 .04562 L
.07464 .04556 L
.0745 .04549 L
.07436 .04543 L
.07422 .04537 L
.07408 .0453 L
.07394 .04524 L
.0738 .04518 L
.07366 .04511 L
.07352 .04505 L
.07338 .04498 L
.07324 .04492 L
.0731 .04486 L
Mistroke
.07296 .0448 L
.07283 .04473 L
.07269 .04467 L
.07255 .04461 L
.07241 .04454 L
.07227 .04448 L
.07213 .04442 L
.072 .04436 L
.07186 .04429 L
.07172 .04423 L
.07158 .04417 L
.07144 .0441 L
.07131 .04404 L
.07117 .04398 L
.07103 .04392 L
.07089 .04385 L
.07076 .04379 L
.07062 .04373 L
.07048 .04367 L
.07034 .0436 L
.07021 .04354 L
.07007 .04348 L
.06993 .04342 L
.0698 .04336 L
.06966 .04329 L
.06952 .04323 L
.06939 .04317 L
.06925 .04311 L
.06911 .04305 L
.06898 .04298 L
.06884 .04292 L
.06871 .04286 L
.06857 .0428 L
.06843 .04274 L
.0683 .04268 L
.06816 .04261 L
.06803 .04255 L
.06789 .04249 L
.06776 .04243 L
.06762 .04237 L
.06749 .04231 L
.06735 .04224 L
.06722 .04218 L
.06708 .04212 L
.06695 .04206 L
.06681 .042 L
.06668 .04194 L
.06654 .04188 L
.06641 .04181 L
.06627 .04175 L
Mistroke
.06614 .04169 L
.066 .04163 L
.06587 .04157 L
.06573 .04151 L
.0656 .04145 L
.06547 .04139 L
.06533 .04133 L
.0652 .04127 L
.06507 .04121 L
.06493 .04114 L
.0648 .04108 L
.06466 .04102 L
.06453 .04096 L
.0644 .0409 L
.06426 .04084 L
.06413 .04078 L
.064 .04072 L
.06387 .04066 L
.06373 .0406 L
.0636 .04054 L
.06347 .04048 L
.06333 .04042 L
.0632 .04036 L
.06307 .0403 L
.06294 .04024 L
.0628 .04018 L
.06267 .04012 L
.06254 .04006 L
.06241 .04 L
.06228 .03994 L
.06214 .03988 L
.06201 .03982 L
.06188 .03976 L
.06175 .0397 L
.06162 .03964 L
.06149 .03958 L
.06135 .03952 L
.06122 .03946 L
.06109 .0394 L
.06096 .03934 L
.06083 .03928 L
.0607 .03922 L
.06057 .03916 L
.06044 .0391 L
.06031 .03904 L
.06018 .03898 L
.06005 .03892 L
.05991 .03887 L
.05978 .03881 L
.05965 .03875 L
Mistroke
.05952 .03869 L
.05939 .03863 L
.05926 .03857 L
.05913 .03851 L
.059 .03845 L
.05887 .03839 L
.05874 .03834 L
.05861 .03828 L
.05848 .03822 L
.05836 .03816 L
.05823 .0381 L
.0581 .03804 L
.05797 .03798 L
.05784 .03793 L
.05771 .03787 L
.05758 .03781 L
.05745 .03775 L
.05732 .03769 L
.05719 .03763 L
.05706 .03757 L
.05694 .03752 L
.05681 .03746 L
.05668 .0374 L
.05655 .03734 L
.05642 .03728 L
.05629 .03722 L
.05617 .03717 L
.05604 .03711 L
.05591 .03705 L
.05578 .03699 L
.05565 .03693 L
.05553 .03688 L
.0554 .03682 L
.05527 .03676 L
.05514 .0367 L
.05502 .03664 L
.05489 .03659 L
.05476 .03653 L
.05463 .03647 L
.05451 .03641 L
.05438 .03635 L
.05425 .0363 L
.05413 .03624 L
.054 .03618 L
.05387 .03612 L
.05375 .03607 L
.05362 .03601 L
.05349 .03595 L
.05337 .03589 L
.05324 .03584 L
Mistroke
.05311 .03578 L
.05299 .03572 L
.05286 .03566 L
.05274 .03561 L
.05261 .03555 L
.05248 .03549 L
.05236 .03543 L
.05223 .03538 L
.05211 .03532 L
.05198 .03526 L
.05186 .03521 L
.05173 .03515 L
.0516 .03509 L
.05148 .03504 L
.05135 .03498 L
.05123 .03492 L
.0511 .03487 L
.05098 .03481 L
.05085 .03475 L
.05073 .03469 L
.0506 .03464 L
.05048 .03458 L
.05036 .03452 L
.05023 .03447 L
.05011 .03441 L
.04998 .03436 L
.04986 .0343 L
.04973 .03424 L
.04961 .03419 L
.04949 .03413 L
.04936 .03407 L
.04924 .03402 L
.04911 .03396 L
.04899 .03391 L
.04887 .03385 L
.04874 .03379 L
.04862 .03374 L
.0485 .03368 L
.04837 .03362 L
.04825 .03357 L
.04813 .03351 L
.048 .03346 L
.04788 .0334 L
.04776 .03334 L
.04763 .03329 L
.04751 .03323 L
.04739 .03318 L
.04727 .03312 L
.04714 .03306 L
.04702 .03301 L
Mistroke
.0469 .03295 L
.04678 .0329 L
.04665 .03284 L
.04653 .03278 L
.04641 .03273 L
.04629 .03267 L
.04616 .03262 L
.04604 .03256 L
.04592 .03251 L
.0458 .03245 L
.04568 .03239 L
.04556 .03234 L
.04543 .03228 L
.04531 .03223 L
.04519 .03217 L
.04507 .03212 L
.04495 .03206 L
.04483 .03201 L
.04471 .03195 L
.04458 .0319 L
.04446 .03184 L
.04434 .03179 L
.04422 .03173 L
.0441 .03168 L
.04398 .03162 L
.04386 .03157 L
.04374 .03151 L
.04362 .03146 L
.0435 .0314 L
.04338 .03135 L
.04326 .03129 L
.04314 .03124 L
.04302 .03118 L
.0429 .03113 L
.04278 .03107 L
.04266 .03102 L
.04254 .03096 L
.04242 .03091 L
.0423 .03085 L
.04218 .0308 L
.04206 .03074 L
.04194 .03069 L
.04182 .03063 L
.0417 .03058 L
.04158 .03053 L
.04146 .03047 L
.04134 .03042 L
.04122 .03036 L
.0411 .03031 L
.04099 .03025 L
Mistroke
.04087 .0302 L
.04075 .03015 L
.04063 .03009 L
.04051 .03004 L
.04039 .02998 L
.04027 .02993 L
.04016 .02988 L
.04004 .02982 L
.03992 .02977 L
.0398 .02971 L
.03968 .02966 L
.03956 .02961 L
.03945 .02955 L
.03933 .0295 L
.03921 .02945 L
.03909 .02939 L
.03898 .02934 L
.03886 .02928 L
.03874 .02923 L
.03862 .02918 L
.03851 .02912 L
.03839 .02907 L
.03827 .02902 L
.03815 .02896 L
.03804 .02891 L
.03792 .02886 L
.0378 .0288 L
.03768 .02875 L
.03757 .0287 L
.03745 .02864 L
.03733 .02859 L
.03722 .02854 L
.0371 .02848 L
.03698 .02843 L
.03687 .02838 L
.03675 .02832 L
.03664 .02827 L
.03652 .02822 L
.0364 .02816 L
.03629 .02811 L
.03617 .02806 L
.03605 .02801 L
.03594 .02795 L
.03582 .0279 L
.03571 .02785 L
.03559 .02779 L
.03548 .02774 L
.03536 .02769 L
.03524 .02763 L
.03513 .02758 L
Mistroke
.03501 .02753 L
.0349 .02748 L
.03478 .02742 L
.03467 .02737 L
.03455 .02732 L
.03444 .02726 L
.03432 .02721 L
.03421 .02716 L
.03409 .02711 L
.03398 .02705 L
.03386 .027 L
.03375 .02695 L
.03363 .0269 L
.03352 .02684 L
.03341 .02679 L
.03329 .02674 L
.03318 .02669 L
.03306 .02663 L
.03295 .02658 L
.03283 .02653 L
.03272 .02648 L
.03261 .02642 L
.03249 .02637 L
.03238 .02632 L
.03227 .02627 L
.03215 .02622 L
.03204 .02616 L
.03192 .02611 L
.03181 .02606 L
.0317 .02601 L
.03158 .02595 L
.03147 .0259 L
.03136 .02585 L
.03124 .0258 L
.03113 .02575 L
.03102 .02569 L
.03091 .02564 L
.03079 .02559 L
.03068 .02554 L
.03057 .02549 L
.03045 .02543 L
.03034 .02538 L
.03023 .02533 L
.03012 .02528 L
.03 .02523 L
.02989 .02518 L
.02978 .02513 L
.02967 .02507 L
.02955 .02502 L
.02944 .02497 L
Mistroke
.02933 .02492 L
.02922 .02487 L
.02911 .02482 L
.02899 .02477 L
.02888 .02472 L
.02877 .02466 L
.02866 .02461 L
.02855 .02456 L
.02844 .02451 L
.02833 .02446 L
.02821 .02441 L
.0281 .02436 L
.02799 .02431 L
.02788 .02426 L
.02777 .02421 L
.02766 .02416 L
.02755 .02411 L
.02744 .02405 L
.02732 .024 L
.02721 .02395 L
.0271 .0239 L
.02699 .02385 L
.02688 .0238 L
.02677 .02375 L
.02666 .0237 L
.02655 .02365 L
.02644 .0236 L
.02633 .02355 L
.02622 .0235 L
.02611 .02345 L
.026 .0234 L
.02589 .02335 L
.02578 .0233 L
.02567 .02325 L
.02556 .0232 L
.02545 .02314 L
.02534 .02309 L
.02523 .02304 L
.02512 .02299 L
.02501 .02294 L
.0249 .02289 L
.02479 .02284 L
.02468 .02279 L
.02457 .02274 L
.02446 .02269 L
.02435 .02264 L
.02425 .02259 L
.02414 .02254 L
.02403 .02249 L
.02392 .02244 L
Mistroke
.02381 .02239 L
Mfstroke
[ ] 0 setdash
.97619 .60289 m
.97486 .60166 L
.97353 .60043 L
.9722 .59919 L
.97088 .59796 L
.96956 .59673 L
.96824 .5955 L
.96692 .59426 L
.96561 .59303 L
.9643 .5918 L
.96299 .59058 L
.96168 .58935 L
.96038 .58812 L
.95908 .5869 L
.95778 .58567 L
.95649 .58445 L
.95519 .58322 L
.9539 .582 L
.95261 .58077 L
.95133 .57955 L
.95005 .57833 L
.94877 .57712 L
.94749 .5759 L
.94621 .57469 L
.94494 .57347 L
.94367 .57226 L
.9424 .57105 L
.94114 .56983 L
.93987 .56862 L
.93861 .56741 L
.93736 .5662 L
.9361 .56499 L
.93485 .56378 L
.9336 .56257 L
.93235 .56136 L
.9311 .56015 L
.92986 .55893 L
.92862 .55772 L
.92738 .5565 L
.92614 .55529 L
.92491 .55408 L
.92368 .55287 L
.92245 .55166 L
.92122 .55044 L
.92 .54923 L
.91877 .54801 L
.91755 .5468 L
.91634 .54558 L
.91512 .54437 L
.91391 .54315 L
Mistroke
.9127 .54193 L
.91149 .54072 L
.91028 .5395 L
.90908 .53828 L
.90788 .53706 L
.90668 .53584 L
.90548 .53462 L
.90429 .53341 L
.9031 .53219 L
.90191 .53097 L
.90072 .52975 L
.89953 .52853 L
.89835 .52732 L
.89717 .52611 L
.89599 .5249 L
.89481 .5237 L
.89364 .52249 L
.89247 .52129 L
.8913 .52008 L
.89013 .51888 L
.88896 .51768 L
.8878 .5165 L
.88664 .51531 L
.88548 .51412 L
.88432 .51293 L
.88317 .51175 L
.88201 .51056 L
.88086 .50938 L
.87972 .50819 L
.87857 .50701 L
.87743 .50583 L
.87628 .50465 L
.87514 .50348 L
.87401 .5023 L
.87287 .50112 L
.87174 .49994 L
.8706 .49876 L
.86947 .49758 L
.86835 .49641 L
.86722 .49523 L
.8661 .49406 L
.86498 .49289 L
.86386 .49172 L
.86274 .49054 L
.86163 .48937 L
.86051 .4882 L
.8594 .48704 L
.85829 .48589 L
.85719 .48473 L
.85608 .48358 L
Mistroke
.85498 .48242 L
.85388 .48127 L
.85278 .48013 L
.85168 .47898 L
.85059 .47784 L
.84949 .47669 L
.8484 .47555 L
.84731 .47441 L
.84623 .47327 L
.84514 .47214 L
.84406 .47101 L
.84298 .46987 L
.8419 .46874 L
.84082 .46761 L
.83975 .46647 L
.83867 .46534 L
.8376 .46421 L
.83653 .46308 L
.83546 .46194 L
.8344 .46081 L
.83333 .45969 L
.83227 .45857 L
.83121 .45745 L
.83015 .45633 L
.8291 .45522 L
.82804 .45411 L
.82699 .45301 L
.82594 .45192 L
.82489 .45084 L
.82384 .44975 L
.8228 .44868 L
.82175 .44761 L
.82071 .44654 L
.81967 .44548 L
.81864 .44442 L
.8176 .44336 L
.81657 .44231 L
.81553 .44125 L
.8145 .4402 L
.81347 .43915 L
.81245 .43811 L
.81142 .43708 L
.8104 .43606 L
.80938 .43505 L
.80836 .43403 L
.80734 .43303 L
.80632 .43202 L
.80531 .43103 L
.8043 .43005 L
.80329 .42906 L
Mistroke
.80228 .42807 L
.80127 .42709 L
.80026 .42611 L
.79926 .42515 L
.79826 .42419 L
.79726 .42323 L
.79626 .42229 L
.79526 .42135 L
.79427 .42041 L
.79327 .41947 L
.79228 .41855 L
.79129 .41763 L
.7903 .41671 L
.78932 .41578 L
.78833 .41487 L
.78735 .41396 L
.78637 .41305 L
.78539 .41214 L
.78441 .41124 L
.78343 .41034 L
.78246 .40944 L
.78149 .40854 L
.78051 .40766 L
.77954 .40678 L
.77858 .4059 L
.77761 .40502 L
.77664 .40415 L
.77568 .40327 L
.77472 .4024 L
.77376 .40153 L
.7728 .40066 L
.77184 .3998 L
.77089 .39893 L
.76994 .39806 L
.76898 .39721 L
.76803 .39636 L
.76708 .39552 L
.76614 .39467 L
.76519 .39382 L
.76425 .39298 L
.76331 .39215 L
.76236 .39133 L
.76143 .3905 L
.76049 .38968 L
.75955 .38886 L
.75862 .38804 L
.75768 .38722 L
.75675 .38641 L
.75582 .3856 L
.75489 .38479 L
Mistroke
.75397 .38398 L
.75304 .38318 L
.75212 .38238 L
.7512 .38158 L
.75028 .3808 L
.74936 .38002 L
.74844 .37925 L
.74752 .37847 L
.74661 .3777 L
.7457 .37693 L
.74479 .37617 L
.74388 .3754 L
.74297 .37464 L
.74206 .37388 L
.74115 .37312 L
.74025 .37235 L
.73935 .3716 L
.73845 .37084 L
.73755 .37008 L
.73665 .36934 L
.73575 .36859 L
.73486 .36785 L
.73396 .36711 L
.73307 .36637 L
.73218 .36564 L
.73129 .36491 L
.7304 .36419 L
.72952 .36346 L
.72863 .36274 L
.72775 .36202 L
.72687 .3613 L
.72599 .36058 L
.72511 .35987 L
.72423 .35917 L
.72335 .35846 L
.72248 .35776 L
.72161 .35706 L
.72073 .35637 L
.71986 .35568 L
.71899 .35499 L
.71813 .35432 L
.71726 .35364 L
.71639 .35297 L
.71553 .35229 L
.71467 .35162 L
.71381 .35096 L
.71295 .35029 L
.71209 .34963 L
.71123 .34896 L
.71038 .3483 L
Mistroke
.70952 .34763 L
.70867 .34697 L
.70782 .34632 L
.70697 .34567 L
.70612 .34502 L
.70527 .34437 L
.70443 .34372 L
.70358 .34308 L
.70274 .34243 L
.7019 .34179 L
.70106 .34115 L
.70022 .34051 L
.69938 .33988 L
.69854 .33925 L
.69771 .33862 L
.69688 .33801 L
.69604 .3374 L
.69521 .33679 L
.69438 .33618 L
.69355 .33557 L
.69273 .33496 L
.6919 .33436 L
.69108 .33376 L
.69025 .33316 L
.68943 .33256 L
.68861 .33196 L
.68779 .33137 L
.68697 .33078 L
.68615 .33019 L
.68534 .3296 L
.68452 .32902 L
.68371 .32844 L
.6829 .32787 L
.68209 .32729 L
.68128 .32671 L
.68047 .32614 L
.67966 .32557 L
.67886 .325 L
.67805 .32444 L
.67725 .32388 L
.67645 .32333 L
.67565 .32277 L
.67485 .32222 L
.67405 .32167 L
.67325 .32112 L
.67246 .32057 L
.67166 .32003 L
.67087 .31948 L
.67008 .31894 L
.66929 .3184 L
Mistroke
.6685 .31786 L
.66771 .31732 L
.66692 .31678 L
.66614 .31624 L
.66535 .3157 L
.66457 .31516 L
.66379 .31463 L
.66301 .31409 L
.66223 .31356 L
.66145 .31302 L
.66067 .31249 L
.65989 .31197 L
.65912 .31144 L
.65834 .31092 L
.65757 .31039 L
.6568 .30987 L
.65603 .30934 L
.65526 .30882 L
.65449 .3083 L
.65372 .30777 L
.65296 .30725 L
.65219 .30673 L
.65143 .30621 L
.65067 .30569 L
.64991 .30518 L
.64915 .30466 L
.64839 .30415 L
.64763 .30363 L
.64687 .30312 L
.64612 .30261 L
.64536 .30211 L
.64461 .3016 L
.64386 .3011 L
.64311 .30059 L
.64236 .30009 L
.64161 .29959 L
.64086 .29909 L
.64011 .29859 L
.63937 .2981 L
.63863 .2976 L
.63788 .29711 L
.63714 .29662 L
.6364 .29613 L
.63566 .29565 L
.63492 .29516 L
.63418 .29468 L
.63345 .2942 L
.63271 .29372 L
.63198 .29324 L
.63124 .29276 L
Mistroke
.63051 .29228 L
.62978 .2918 L
.62905 .29133 L
.62832 .29085 L
.62759 .29038 L
.62687 .28991 L
.62614 .28945 L
.62542 .28899 L
.62469 .28853 L
.62397 .28807 L
.62325 .28762 L
.62253 .28716 L
.62181 .2867 L
.62109 .28625 L
.62037 .2858 L
.61966 .28535 L
.61894 .2849 L
.61823 .28446 L
.61752 .28402 L
.6168 .28358 L
.61609 .28314 L
.61538 .2827 L
.61467 .28227 L
.61397 .28183 L
.61326 .28139 L
.61255 .28097 L
.61185 .28054 L
.61115 .28011 L
.61044 .27969 L
.60974 .27927 L
.60904 .27885 L
.60834 .27843 L
.60764 .27802 L
.60694 .2776 L
.60625 .27718 L
.60555 .27677 L
.60486 .27635 L
.60416 .27593 L
.60347 .27552 L
.60278 .2751 L
.60209 .27468 L
.6014 .27427 L
.60071 .27385 L
.60002 .27344 L
.59934 .27302 L
.59865 .27261 L
.59797 .2722 L
.59728 .27179 L
.5966 .27138 L
.59592 .27097 L
Mistroke
.59524 .27056 L
.59456 .27015 L
.59388 .26975 L
.5932 .26934 L
.59252 .26894 L
.59185 .26853 L
.59117 .26813 L
.5905 .26772 L
.58983 .26732 L
.58915 .26691 L
.58848 .26651 L
.58781 .26611 L
.58714 .26571 L
.58648 .26531 L
.58581 .26491 L
.58514 .26451 L
.58448 .26411 L
.58381 .26371 L
.58315 .26332 L
.58249 .26292 L
.58182 .26252 L
.58116 .26213 L
.5805 .26174 L
.57984 .26134 L
.57919 .26095 L
.57853 .26056 L
.57787 .26016 L
.57722 .25977 L
.57656 .25938 L
.57591 .25899 L
.57526 .25861 L
.57461 .25822 L
.57396 .25784 L
.57331 .25746 L
.57266 .25707 L
.57201 .25669 L
.57136 .25631 L
.57072 .25593 L
.57007 .25555 L
.56943 .25517 L
.56878 .2548 L
.56814 .25442 L
.5675 .25405 L
.56686 .25367 L
.56622 .2533 L
.56558 .25293 L
.56494 .25256 L
.5643 .25219 L
.56367 .25182 L
.56303 .25146 L
Mistroke
.5624 .25109 L
.56176 .25073 L
.56113 .25037 L
.5605 .25001 L
.55987 .24965 L
.55924 .24929 L
.55861 .24893 L
.55798 .24857 L
.55735 .24821 L
.55673 .24786 L
.5561 .2475 L
.55547 .24714 L
.55485 .24679 L
.55423 .24643 L
.5536 .24608 L
.55298 .24573 L
.55236 .24537 L
.55174 .24502 L
.55112 .24468 L
.5505 .24433 L
.54989 .24398 L
.54927 .24363 L
.54865 .24329 L
.54804 .24295 L
.54743 .24261 L
.54681 .24227 L
.5462 .24193 L
.54559 .2416 L
.54498 .24126 L
.54437 .24092 L
.54376 .24059 L
.54315 .24025 L
.54254 .23992 L
.54194 .23959 L
.54133 .23925 L
.54072 .23892 L
.54012 .23859 L
.53952 .23826 L
.53891 .23793 L
.53831 .2376 L
.53771 .23728 L
.53711 .23696 L
.53651 .23663 L
.53591 .23631 L
.53532 .23599 L
.53472 .23568 L
.53412 .23536 L
.53353 .23505 L
.53293 .23473 L
.53234 .23442 L
Mistroke
.53175 .2341 L
.53115 .23379 L
.53056 .23347 L
.52997 .23316 L
.52938 .23285 L
.52879 .23253 L
.5282 .23222 L
.52762 .23191 L
.52703 .2316 L
.52644 .23129 L
.52586 .23098 L
.52527 .23067 L
.52469 .23036 L
.52411 .23005 L
.52353 .22974 L
.52295 .22943 L
.52236 .22912 L
.52178 .22881 L
.52121 .22851 L
.52063 .2282 L
.52005 .2279 L
.51947 .22759 L
.5189 .22729 L
.51832 .22699 L
.51775 .22669 L
.51717 .22639 L
.5166 .2261 L
.51603 .2258 L
.51546 .22551 L
.51489 .22521 L
.51432 .22492 L
.51375 .22462 L
.51318 .22433 L
.51261 .22404 L
.51204 .22375 L
.51148 .22345 L
.51091 .22316 L
.51035 .22287 L
.50978 .22258 L
.50922 .22229 L
.50866 .222 L
.5081 .22171 L
.50754 .22142 L
.50697 .22113 L
.50642 .22084 L
.50586 .22056 L
.5053 .22028 L
.50474 .21999 L
.50418 .21971 L
.50363 .21942 L
Mistroke
.50307 .21914 L
.50252 .21886 L
.50196 .21858 L
.50141 .2183 L
.50086 .21802 L
.50031 .21774 L
.49976 .21746 L
.4992 .21718 L
.49866 .2169 L
.49811 .21662 L
.49756 .21634 L
.49701 .21607 L
.49646 .21579 L
.49592 .21552 L
.49537 .21524 L
.49483 .21497 L
.49428 .21469 L
.49374 .21442 L
.4932 .21415 L
.49266 .21387 L
.49211 .2136 L
.49157 .21333 L
.49103 .21305 L
.49049 .21278 L
.48996 .21251 L
.48942 .21224 L
.48888 .21197 L
.48834 .2117 L
.48781 .21143 L
.48727 .21115 L
.48674 .21089 L
.48621 .21062 L
.48567 .21035 L
.48514 .21008 L
.48461 .20981 L
.48408 .20955 L
.48355 .20928 L
.48302 .20901 L
.48249 .20875 L
.48196 .20848 L
.48143 .20822 L
.4809 .20795 L
.48038 .20769 L
.47985 .20742 L
.47933 .20716 L
.4788 .2069 L
.47828 .20663 L
.47776 .20637 L
.47723 .20611 L
.47671 .20585 L
Mistroke
.47619 .20559 L
.47567 .20533 L
.47515 .20507 L
.47463 .20481 L
.47411 .20455 L
.47359 .20429 L
.47308 .20403 L
.47256 .20377 L
.47204 .20351 L
.47153 .20325 L
.47101 .20299 L
.4705 .20274 L
.46999 .20248 L
.46947 .20222 L
.46896 .20197 L
.46845 .20171 L
.46794 .20146 L
.46743 .20121 L
.46692 .20095 L
.46641 .2007 L
.4659 .20045 L
.46539 .2002 L
.46489 .19995 L
.46438 .1997 L
.46388 .19945 L
.46337 .1992 L
.46287 .19895 L
.46236 .1987 L
.46186 .19846 L
.46136 .19821 L
.46085 .19797 L
.46035 .19773 L
.45985 .19748 L
.45935 .19724 L
.45885 .197 L
.45835 .19676 L
.45785 .19652 L
.45736 .19628 L
.45686 .19604 L
.45636 .1958 L
.45587 .19556 L
.45537 .19532 L
.45488 .19508 L
.45438 .19484 L
.45389 .1946 L
.45339 .19437 L
.4529 .19413 L
.45241 .19389 L
.45192 .19366 L
.45143 .19342 L
Mistroke
.45094 .19319 L
.45045 .19295 L
.44996 .19272 L
.44947 .19249 L
.44898 .19225 L
.4485 .19202 L
.44801 .19179 L
.44752 .19156 L
.44704 .19133 L
.44655 .19109 L
.44607 .19086 L
.44559 .19063 L
.4451 .1904 L
.44462 .19018 L
.44414 .18995 L
.44366 .18973 L
.44318 .1895 L
.4427 .18928 L
.44222 .18905 L
.44174 .18883 L
.44126 .1886 L
.44078 .18838 L
.44031 .18815 L
.43983 .18793 L
.43935 .18771 L
.43888 .18749 L
.4384 .18727 L
.43793 .18705 L
.43745 .18683 L
.43698 .18661 L
.43651 .18639 L
.43604 .18617 L
.43556 .18595 L
.43509 .18573 L
.43462 .18551 L
.43415 .1853 L
.43368 .18508 L
.43321 .18487 L
.43275 .18465 L
.43228 .18444 L
.43181 .18422 L
.43135 .18401 L
.43088 .18379 L
.43041 .18358 L
.42995 .18337 L
.42948 .18316 L
.42902 .18294 L
.42856 .18273 L
.42809 .18252 L
.42763 .18231 L
Mistroke
.42717 .1821 L
.42671 .18188 L
.42625 .18167 L
.42579 .18146 L
.42533 .18125 L
.42487 .18104 L
.42441 .18083 L
.42395 .18062 L
.4235 .18041 L
.42304 .1802 L
.42258 .18 L
.42213 .17979 L
.42167 .17958 L
.42122 .17938 L
.42076 .17917 L
.42031 .17897 L
.41986 .17876 L
.41941 .17856 L
.41895 .17835 L
.4185 .17815 L
.41805 .17795 L
.4176 .17775 L
.41715 .17754 L
.4167 .17734 L
.41625 .17714 L
.4158 .17694 L
.41536 .17674 L
.41491 .17654 L
.41446 .17634 L
.41402 .17614 L
.41357 .17594 L
.41312 .17574 L
.41268 .17554 L
.41224 .17534 L
.41179 .17514 L
.41135 .17494 L
.41091 .17475 L
.41046 .17455 L
.41002 .17435 L
.40958 .17416 L
.40914 .17396 L
.4087 .17377 L
.40826 .17357 L
.40782 .17337 L
.40738 .17318 L
.40695 .17298 L
.40651 .17279 L
.40607 .17259 L
.40563 .1724 L
.4052 .1722 L
Mistroke
.40476 .17201 L
.40433 .17181 L
.40389 .17162 L
.40346 .17143 L
.40302 .17123 L
.40259 .17104 L
.40216 .17085 L
.40173 .17065 L
.40129 .17046 L
.40086 .17027 L
.40043 .17008 L
.4 .16988 L
.39957 .16969 L
.39914 .1695 L
.39872 .16931 L
.39829 .16912 L
.39786 .16893 L
.39743 .16874 L
.397 .16855 L
.39658 .16836 L
.39615 .16817 L
.39573 .16798 L
.3953 .1678 L
.39488 .16761 L
.39445 .16742 L
.39403 .16723 L
.39361 .16705 L
.39319 .16686 L
.39276 .16668 L
.39234 .16649 L
.39192 .16631 L
.3915 .16612 L
.39108 .16594 L
.39066 .16575 L
.39024 .16557 L
.38982 .16539 L
.3894 .1652 L
.38899 .16502 L
.38857 .16484 L
.38815 .16466 L
.38774 .16447 L
.38732 .16429 L
.3869 .16411 L
.38649 .16393 L
.38608 .16375 L
.38566 .16357 L
.38525 .16339 L
.38483 .1632 L
.38442 .16302 L
.38401 .16284 L
Mistroke
.3836 .16267 L
.38319 .16249 L
.38278 .16231 L
.38237 .16213 L
.38196 .16195 L
.38155 .16177 L
.38114 .16159 L
.38073 .16141 L
.38032 .16124 L
.37991 .16106 L
.37951 .16088 L
.3791 .1607 L
.37869 .16052 L
.37829 .16035 L
.37788 .16017 L
.37748 .15999 L
.37707 .15982 L
.37667 .15964 L
.37626 .15946 L
.37586 .15929 L
.37546 .15911 L
.37506 .15894 L
.37465 .15876 L
.37425 .15859 L
.37385 .15841 L
.37345 .15824 L
.37305 .15807 L
.37265 .15789 L
.37225 .15772 L
.37185 .15755 L
.37145 .15738 L
.37106 .15721 L
.37066 .15704 L
.37026 .15687 L
.36987 .1567 L
.36947 .15653 L
.36907 .15636 L
.36868 .15619 L
.36828 .15602 L
.36789 .15585 L
.36749 .15568 L
.3671 .15551 L
.36671 .15535 L
.36632 .15518 L
.36592 .15501 L
.36553 .15484 L
.36514 .15467 L
.36475 .15451 L
.36436 .15434 L
.36397 .15418 L
Mistroke
.36358 .15401 L
.36319 .15384 L
.3628 .15368 L
.36241 .15351 L
.36202 .15335 L
.36164 .15318 L
.36125 .15302 L
.36086 .15286 L
.36047 .15269 L
.36009 .15253 L
.3597 .15236 L
.35932 .1522 L
.35893 .15204 L
.35855 .15188 L
.35816 .15171 L
.35778 .15155 L
.3574 .15139 L
.35702 .15123 L
.35663 .15107 L
.35625 .15091 L
.35587 .15075 L
.35549 .15059 L
.35511 .15042 L
.35473 .15026 L
.35435 .1501 L
.35397 .14994 L
.35359 .14978 L
.35321 .14962 L
.35283 .14946 L
.35245 .1493 L
.35208 .14914 L
.3517 .14898 L
.35132 .14882 L
.35095 .14867 L
.35057 .14851 L
.3502 .14835 L
.34982 .14819 L
.34945 .14804 L
.34907 .14788 L
.3487 .14772 L
.34832 .14757 L
.34795 .14741 L
.34758 .14725 L
.34721 .1471 L
.34683 .14694 L
.34646 .14678 L
.34609 .14663 L
.34572 .14647 L
.34535 .14632 L
.34498 .14616 L
Mistroke
.34461 .14601 L
.34424 .14585 L
.34387 .1457 L
.34351 .14555 L
.34314 .14539 L
.34277 .14524 L
.3424 .14508 L
.34204 .14493 L
.34167 .14478 L
.3413 .14462 L
.34094 .14447 L
.34057 .14432 L
.34021 .14417 L
.33984 .14401 L
.33948 .14386 L
.33911 .14371 L
.33875 .14356 L
.33839 .14341 L
.33803 .14326 L
.33766 .14311 L
.3373 .14295 L
.33694 .1428 L
.33658 .14265 L
.33622 .1425 L
.33586 .14235 L
.3355 .1422 L
.33514 .14205 L
.33478 .1419 L
.33442 .14175 L
.33406 .1416 L
.3337 .14145 L
.33335 .1413 L
.33299 .14116 L
.33263 .14101 L
.33227 .14086 L
.33192 .14071 L
.33156 .14056 L
.33121 .14042 L
.33085 .14027 L
.3305 .14012 L
.33014 .13997 L
.32979 .13983 L
.32943 .13968 L
.32908 .13953 L
.32873 .13939 L
.32838 .13924 L
.32802 .1391 L
.32767 .13895 L
.32732 .1388 L
.32697 .13866 L
Mistroke
.32662 .13851 L
.32627 .13837 L
.32592 .13823 L
.32557 .13808 L
.32522 .13794 L
.32487 .13779 L
.32452 .13765 L
.32417 .1375 L
.32382 .13736 L
.32348 .13722 L
.32313 .13707 L
.32278 .13693 L
.32244 .13678 L
.32209 .13664 L
.32174 .1365 L
.3214 .13635 L
.32105 .13621 L
.32071 .13607 L
.32036 .13592 L
.32002 .13578 L
.31968 .13564 L
.31933 .1355 L
.31899 .13535 L
.31865 .13521 L
.3183 .13507 L
.31796 .13493 L
.31762 .13479 L
.31728 .13465 L
.31694 .1345 L
.3166 .13436 L
.31626 .13422 L
.31592 .13408 L
.31558 .13394 L
.31524 .1338 L
.3149 .13366 L
.31456 .13352 L
.31422 .13338 L
.31389 .13324 L
.31355 .1331 L
.31321 .13296 L
.31287 .13282 L
.31254 .13268 L
.3122 .13255 L
.31187 .13241 L
.31153 .13227 L
.31119 .13213 L
.31086 .13199 L
.31053 .13185 L
.31019 .13171 L
.30986 .13157 L
Mistroke
.30952 .13144 L
.30919 .1313 L
.30886 .13116 L
.30853 .13102 L
.30819 .13089 L
.30786 .13075 L
.30753 .13061 L
.3072 .13048 L
.30687 .13034 L
.30654 .1302 L
.30621 .13007 L
.30588 .12993 L
.30555 .12979 L
.30522 .12966 L
.30489 .12952 L
.30456 .12939 L
.30423 .12925 L
.3039 .12911 L
.30358 .12898 L
.30325 .12884 L
.30292 .12871 L
.3026 .12857 L
.30227 .12844 L
.30194 .1283 L
.30162 .12817 L
.30129 .12804 L
.30097 .1279 L
.30064 .12777 L
.30032 .12763 L
.3 .1275 L
.29967 .12737 L
.29935 .12723 L
.29903 .1271 L
.2987 .12697 L
.29838 .12683 L
.29806 .1267 L
.29774 .12657 L
.29741 .12643 L
.29709 .1263 L
.29677 .12617 L
.29645 .12604 L
.29613 .1259 L
.29581 .12577 L
.29549 .12564 L
.29517 .12551 L
.29485 .12538 L
.29454 .12524 L
.29422 .12511 L
.2939 .12498 L
.29358 .12485 L
Mistroke
.29326 .12472 L
.29295 .12459 L
.29263 .12446 L
.29231 .12433 L
.292 .1242 L
.29168 .12408 L
.29137 .12395 L
.29105 .12382 L
.29074 .12369 L
.29042 .12356 L
.29011 .12343 L
.28979 .1233 L
.28948 .12317 L
.28917 .12304 L
.28885 .12292 L
.28854 .12279 L
.28823 .12266 L
.28791 .12253 L
.2876 .1224 L
.28729 .12228 L
.28698 .12215 L
.28667 .12202 L
.28636 .12189 L
.28605 .12177 L
.28574 .12164 L
.28543 .12151 L
.28512 .12139 L
.28481 .12126 L
.2845 .12113 L
.28419 .121 L
.28388 .12088 L
.28357 .12075 L
.28327 .12063 L
.28296 .1205 L
.28265 .12037 L
.28235 .12025 L
.28204 .12012 L
.28173 .11999 L
.28143 .11987 L
.28112 .11974 L
.28082 .11962 L
.28051 .11949 L
.28021 .11936 L
.2799 .11924 L
.2796 .11911 L
.27929 .11899 L
.27899 .11886 L
.27869 .11874 L
.27838 .11861 L
.27808 .11849 L
Mistroke
.27778 .11836 L
.27748 .11824 L
.27717 .11811 L
.27687 .11799 L
.27657 .11786 L
.27627 .11774 L
.27597 .11762 L
.27567 .11749 L
.27537 .11737 L
.27507 .11725 L
.27477 .11712 L
.27447 .117 L
.27417 .11688 L
.27387 .11676 L
.27357 .11663 L
.27327 .11651 L
.27298 .11639 L
.27268 .11627 L
.27238 .11615 L
.27208 .11603 L
.27179 .11591 L
.27149 .11579 L
.2712 .11567 L
.2709 .11555 L
.2706 .11543 L
.27031 .11531 L
.27001 .11519 L
.26972 .11507 L
.26942 .11495 L
.26913 .11483 L
.26884 .11471 L
.26854 .11459 L
.26825 .11447 L
.26795 .11435 L
.26766 .11423 L
.26737 .11412 L
.26708 .114 L
.26678 .11388 L
.26649 .11376 L
.2662 .11364 L
.26591 .11352 L
.26562 .11341 L
.26533 .11329 L
.26504 .11317 L
.26475 .11305 L
.26446 .11294 L
.26417 .11282 L
.26388 .1127 L
.26359 .11259 L
.2633 .11247 L
Mistroke
.26301 .11235 L
.26272 .11224 L
.26244 .11212 L
.26215 .112 L
.26186 .11189 L
.26157 .11177 L
.26129 .11166 L
.261 .11154 L
.26071 .11142 L
.26043 .11131 L
.26014 .11119 L
.25986 .11108 L
.25957 .11096 L
.25928 .11084 L
.259 .11073 L
.25872 .11061 L
.25843 .1105 L
.25815 .11038 L
.25786 .11027 L
.25758 .11015 L
.2573 .11004 L
.25701 .10992 L
.25673 .10981 L
.25645 .1097 L
.25617 .10958 L
.25588 .10947 L
.2556 .10935 L
.25532 .10924 L
.25504 .10913 L
.25476 .10901 L
.25448 .1089 L
.2542 .10879 L
.25392 .10867 L
.25364 .10856 L
.25336 .10845 L
.25308 .10833 L
.2528 .10822 L
.25252 .10811 L
.25224 .108 L
.25196 .10789 L
.25169 .10778 L
.25141 .10767 L
.25113 .10756 L
.25085 .10745 L
.25058 .10734 L
.2503 .10723 L
.25002 .10712 L
.24975 .10701 L
.24947 .1069 L
.24919 .10679 L
Mistroke
.24892 .10668 L
.24864 .10658 L
.24837 .10647 L
.24809 .10636 L
.24782 .10625 L
.24754 .10615 L
.24727 .10604 L
.247 .10593 L
.24672 .10582 L
.24645 .10571 L
.24618 .10561 L
.2459 .1055 L
.24563 .10539 L
.24536 .10528 L
.24509 .10518 L
.24481 .10507 L
.24454 .10496 L
.24427 .10486 L
.244 .10475 L
.24373 .10464 L
.24346 .10454 L
.24319 .10443 L
.24292 .10432 L
.24265 .10421 L
.24238 .10411 L
.24211 .104 L
.24184 .10389 L
.24157 .10379 L
.2413 .10368 L
.24103 .10358 L
.24076 .10347 L
.2405 .10336 L
.24023 .10326 L
.23996 .10315 L
.23969 .10305 L
.23943 .10294 L
.23916 .10283 L
.23889 .10273 L
.23863 .10262 L
.23836 .10252 L
.2381 .10241 L
.23783 .10231 L
.23756 .1022 L
.2373 .1021 L
.23703 .10199 L
.23677 .10189 L
.23651 .10179 L
.23624 .10168 L
.23598 .10158 L
.23571 .10147 L
Mistroke
.23545 .10137 L
.23519 .10126 L
.23492 .10116 L
.23466 .10106 L
.2344 .10095 L
.23414 .10085 L
.23387 .10074 L
.23361 .10064 L
.23335 .10054 L
.23309 .10043 L
.23283 .10033 L
.23257 .10023 L
.23231 .10012 L
.23205 .10002 L
.23179 .09992 L
.23153 .09981 L
.23127 .09971 L
.23101 .09961 L
.23075 .0995 L
.23049 .0994 L
.23023 .0993 L
.22997 .09919 L
.22971 .09909 L
.22945 .09899 L
.2292 .09889 L
.22894 .09878 L
.22868 .09868 L
.22842 .09858 L
.22817 .09848 L
.22791 .09838 L
.22765 .09827 L
.2274 .09817 L
.22714 .09807 L
.22688 .09797 L
.22663 .09787 L
.22637 .09777 L
.22612 .09767 L
.22586 .09756 L
.22561 .09746 L
.22535 .09736 L
.2251 .09726 L
.22484 .09716 L
.22459 .09706 L
.22434 .09696 L
.22408 .09686 L
.22383 .09676 L
.22358 .09666 L
.22332 .09656 L
.22307 .09646 L
.22282 .09636 L
Mistroke
.22257 .09627 L
.22232 .09617 L
.22206 .09607 L
.22181 .09597 L
.22156 .09587 L
.22131 .09577 L
.22106 .09567 L
.22081 .09557 L
.22056 .09547 L
.22031 .09537 L
.22006 .09527 L
.21981 .09518 L
.21956 .09508 L
.21931 .09498 L
.21906 .09488 L
.21881 .09478 L
.21856 .09468 L
.21831 .09458 L
.21807 .09449 L
.21782 .09439 L
.21757 .09429 L
.21732 .09419 L
.21707 .09409 L
.21683 .094 L
.21658 .0939 L
.21633 .0938 L
.21609 .09371 L
.21584 .09361 L
.21559 .09351 L
.21535 .09341 L
.2151 .09332 L
.21486 .09322 L
.21461 .09312 L
.21437 .09303 L
.21412 .09293 L
.21388 .09283 L
.21363 .09274 L
.21339 .09264 L
.21315 .09255 L
.2129 .09245 L
.21266 .09235 L
.21241 .09226 L
.21217 .09216 L
.21193 .09207 L
.21169 .09197 L
.21144 .09187 L
.2112 .09178 L
.21096 .09168 L
.21072 .09159 L
.21047 .09149 L
Mistroke
.21023 .0914 L
.20999 .0913 L
.20975 .09121 L
.20951 .09111 L
.20927 .09102 L
.20903 .09092 L
.20879 .09083 L
.20855 .09073 L
.20831 .09064 L
.20807 .09054 L
.20783 .09045 L
.20759 .09035 L
.20735 .09026 L
.20711 .09017 L
.20687 .09007 L
.20663 .08998 L
.2064 .08988 L
.20616 .08979 L
.20592 .0897 L
.20568 .0896 L
.20545 .08951 L
.20521 .08942 L
.20497 .08932 L
.20473 .08923 L
.2045 .08914 L
.20426 .08904 L
.20402 .08895 L
.20379 .08886 L
.20355 .08876 L
.20332 .08867 L
.20308 .08858 L
.20285 .08849 L
.20261 .08839 L
.20238 .0883 L
.20214 .08821 L
.20191 .08812 L
.20167 .08802 L
.20144 .08793 L
.2012 .08784 L
.20097 .08774 L
.20074 .08765 L
.2005 .08756 L
.20027 .08747 L
.20004 .08738 L
.19981 .08728 L
.19957 .08719 L
.19934 .0871 L
.19911 .08701 L
.19888 .08692 L
.19864 .08682 L
Mistroke
.19841 .08673 L
.19818 .08664 L
.19795 .08655 L
.19772 .08646 L
.19749 .08637 L
.19726 .08627 L
.19703 .08618 L
.1968 .08609 L
.19657 .086 L
.19634 .08591 L
.19611 .08582 L
.19588 .08573 L
.19565 .08564 L
.19542 .08555 L
.19519 .08545 L
.19496 .08536 L
.19473 .08527 L
.19451 .08518 L
.19428 .08509 L
.19405 .085 L
.19382 .08491 L
.19359 .08482 L
.19337 .08473 L
.19314 .08464 L
.19291 .08455 L
.19269 .08446 L
.19246 .08437 L
.19223 .08428 L
.19201 .08419 L
.19178 .0841 L
.19155 .08401 L
.19133 .08392 L
.1911 .08383 L
.19088 .08375 L
.19065 .08366 L
.19043 .08357 L
.1902 .08348 L
.18998 .08339 L
.18975 .0833 L
.18953 .08321 L
.18931 .08312 L
.18908 .08303 L
.18886 .08295 L
.18863 .08286 L
.18841 .08277 L
.18819 .08268 L
.18796 .08259 L
.18774 .0825 L
.18752 .08241 L
.1873 .08233 L
Mistroke
.18707 .08224 L
.18685 .08215 L
.18663 .08206 L
.18641 .08197 L
.18619 .08188 L
.18597 .0818 L
.18575 .08171 L
.18552 .08162 L
.1853 .08153 L
.18508 .08144 L
.18486 .08135 L
.18464 .08127 L
.18442 .08118 L
.1842 .08109 L
.18398 .081 L
.18376 .08092 L
.18354 .08083 L
.18332 .08074 L
.18311 .08066 L
.18289 .08057 L
.18267 .08048 L
.18245 .0804 L
.18223 .08031 L
.18201 .08022 L
.1818 .08013 L
.18158 .08005 L
.18136 .07996 L
.18114 .07988 L
.18093 .07979 L
.18071 .0797 L
.18049 .07962 L
.18027 .07953 L
.18006 .07944 L
.17984 .07936 L
.17963 .07927 L
.17941 .07918 L
.17919 .0791 L
.17898 .07901 L
.17876 .07892 L
.17855 .07884 L
.17833 .07875 L
.17812 .07867 L
.1779 .07858 L
.17769 .07849 L
.17747 .07841 L
.17726 .07832 L
.17705 .07824 L
.17683 .07815 L
.17662 .07807 L
.1764 .07798 L
Mistroke
.17619 .07789 L
.17598 .07781 L
.17576 .07772 L
.17555 .07764 L
.17534 .07755 L
.17513 .07747 L
.17491 .07738 L
.1747 .0773 L
.17449 .07721 L
.17428 .07713 L
.17407 .07704 L
.17385 .07696 L
.17364 .07687 L
.17343 .07679 L
.17322 .0767 L
.17301 .07662 L
.1728 .07653 L
.17259 .07645 L
.17238 .07636 L
.17217 .07628 L
.17196 .07619 L
.17175 .07611 L
.17154 .07603 L
.17133 .07594 L
.17112 .07586 L
.17091 .07577 L
.1707 .07569 L
.17049 .0756 L
.17028 .07552 L
.17007 .07544 L
.16987 .07535 L
.16966 .07527 L
.16945 .07518 L
.16924 .0751 L
.16903 .07502 L
.16883 .07493 L
.16862 .07485 L
.16841 .07477 L
.16821 .07468 L
.168 .0746 L
.16779 .07452 L
.16758 .07443 L
.16738 .07435 L
.16717 .07427 L
.16697 .07418 L
.16676 .0741 L
.16655 .07402 L
.16635 .07393 L
.16614 .07385 L
.16594 .07377 L
Mistroke
.16573 .07368 L
.16553 .0736 L
.16532 .07352 L
.16512 .07344 L
.16491 .07335 L
.16471 .07327 L
.16451 .07319 L
.1643 .07311 L
.1641 .07303 L
.16389 .07294 L
.16369 .07286 L
.16349 .07278 L
.16328 .0727 L
.16308 .07262 L
.16288 .07253 L
.16268 .07245 L
.16247 .07237 L
.16227 .07229 L
.16207 .07221 L
.16187 .07213 L
.16166 .07205 L
.16146 .07197 L
.16126 .07189 L
.16106 .0718 L
.16086 .07172 L
.16066 .07164 L
.16046 .07156 L
.16025 .07148 L
.16005 .0714 L
.15985 .07132 L
.15965 .07124 L
.15945 .07116 L
.15925 .07108 L
.15905 .071 L
.15885 .07092 L
.15865 .07084 L
.15845 .07076 L
.15825 .07068 L
.15806 .0706 L
.15786 .07052 L
.15766 .07044 L
.15746 .07036 L
.15726 .07028 L
.15706 .0702 L
.15686 .07012 L
.15667 .07004 L
.15647 .06996 L
.15627 .06988 L
.15607 .0698 L
.15587 .06972 L
Mistroke
.15568 .06964 L
.15548 .06956 L
.15528 .06948 L
.15509 .0694 L
.15489 .06932 L
.15469 .06924 L
.1545 .06916 L
.1543 .06908 L
.1541 .06901 L
.15391 .06893 L
.15371 .06885 L
.15352 .06877 L
.15332 .06869 L
.15313 .06861 L
.15293 .06854 L
.15274 .06846 L
.15254 .06838 L
.15235 .0683 L
.15215 .06822 L
.15196 .06814 L
.15176 .06807 L
.15157 .06799 L
.15137 .06791 L
.15118 .06783 L
.15099 .06776 L
.15079 .06768 L
.1506 .0676 L
.15041 .06752 L
.15021 .06745 L
.15002 .06737 L
.14983 .06729 L
.14964 .06721 L
.14944 .06714 L
.14925 .06706 L
.14906 .06698 L
.14887 .0669 L
.14867 .06683 L
.14848 .06675 L
.14829 .06667 L
.1481 .06659 L
.14791 .06652 L
.14772 .06644 L
.14753 .06636 L
.14733 .06628 L
.14714 .06621 L
.14695 .06613 L
.14676 .06605 L
.14657 .06598 L
.14638 .0659 L
.14619 .06582 L
Mistroke
.146 .06575 L
.14581 .06567 L
.14562 .06559 L
.14543 .06552 L
.14524 .06544 L
.14505 .06537 L
.14487 .06529 L
.14468 .06521 L
.14449 .06514 L
.1443 .06506 L
.14411 .06499 L
.14392 .06491 L
.14373 .06483 L
.14355 .06476 L
.14336 .06468 L
.14317 .06461 L
.14298 .06453 L
.14279 .06446 L
.14261 .06438 L
.14242 .06431 L
.14223 .06423 L
.14205 .06416 L
.14186 .06408 L
.14167 .064 L
.14149 .06393 L
.1413 .06385 L
.14111 .06378 L
.14093 .0637 L
.14074 .06363 L
.14056 .06355 L
.14037 .06348 L
.14018 .0634 L
.14 .06333 L
.13981 .06325 L
.13963 .06318 L
.13944 .06311 L
.13926 .06303 L
.13907 .06296 L
.13889 .06288 L
.1387 .06281 L
.13852 .06273 L
.13834 .06266 L
.13815 .06258 L
.13797 .06251 L
.13778 .06243 L
.1376 .06236 L
.13742 .06228 L
.13723 .06221 L
.13705 .06214 L
.13687 .06206 L
Mistroke
.13668 .06199 L
.1365 .06191 L
.13632 .06184 L
.13614 .06176 L
.13595 .06169 L
.13577 .06162 L
.13559 .06154 L
.13541 .06147 L
.13523 .0614 L
.13504 .06132 L
.13486 .06125 L
.13468 .06118 L
.1345 .0611 L
.13432 .06103 L
.13414 .06096 L
.13396 .06088 L
.13378 .06081 L
.13359 .06074 L
.13341 .06066 L
.13323 .06059 L
.13305 .06052 L
.13287 .06044 L
.13269 .06037 L
.13251 .0603 L
.13233 .06023 L
.13215 .06015 L
.13197 .06008 L
.13179 .06001 L
.13162 .05993 L
.13144 .05986 L
.13126 .05979 L
.13108 .05972 L
.1309 .05964 L
.13072 .05957 L
.13054 .0595 L
.13036 .05942 L
.13019 .05935 L
.13001 .05928 L
.12983 .05921 L
.12965 .05914 L
.12948 .05906 L
.1293 .05899 L
.12912 .05892 L
.12894 .05885 L
.12877 .05877 L
.12859 .0587 L
.12841 .05863 L
.12824 .05856 L
.12806 .05849 L
.12788 .05841 L
Mistroke
.12771 .05834 L
.12753 .05827 L
.12735 .0582 L
.12718 .05813 L
.127 .05805 L
.12683 .05798 L
.12665 .05791 L
.12647 .05784 L
.1263 .05777 L
.12612 .0577 L
.12595 .05763 L
.12577 .05755 L
.1256 .05748 L
.12542 .05741 L
.12525 .05734 L
.12508 .05727 L
.1249 .0572 L
.12473 .05713 L
.12455 .05706 L
.12438 .05699 L
.1242 .05692 L
.12403 .05684 L
.12386 .05677 L
.12368 .0567 L
.12351 .05663 L
.12334 .05656 L
.12316 .05649 L
.12299 .05642 L
.12282 .05635 L
.12265 .05628 L
.12247 .05621 L
.1223 .05614 L
.12213 .05607 L
.12196 .056 L
.12178 .05593 L
.12161 .05586 L
.12144 .05579 L
.12127 .05572 L
.1211 .05565 L
.12093 .05558 L
.12075 .05551 L
.12058 .05544 L
.12041 .05537 L
.12024 .0553 L
.12007 .05523 L
.1199 .05516 L
.11973 .05509 L
.11956 .05502 L
.11939 .05495 L
.11922 .05488 L
Mistroke
.11905 .05481 L
.11888 .05474 L
.11871 .05468 L
.11854 .05461 L
.11837 .05454 L
.1182 .05447 L
.11803 .0544 L
.11786 .05433 L
.11769 .05426 L
.11752 .05419 L
.11735 .05412 L
.11718 .05405 L
.11702 .05398 L
.11685 .05392 L
.11668 .05385 L
.11651 .05378 L
.11634 .05371 L
.11617 .05364 L
.11601 .05357 L
.11584 .0535 L
.11567 .05343 L
.1155 .05337 L
.11534 .0533 L
.11517 .05323 L
.115 .05316 L
.11483 .05309 L
.11467 .05302 L
.1145 .05295 L
.11433 .05289 L
.11417 .05282 L
.114 .05275 L
.11383 .05268 L
.11367 .05261 L
.1135 .05255 L
.11333 .05248 L
.11317 .05241 L
.113 .05234 L
.11284 .05227 L
.11267 .05221 L
.11251 .05214 L
.11234 .05207 L
.11218 .052 L
.11201 .05193 L
.11185 .05187 L
.11168 .0518 L
.11152 .05173 L
.11135 .05166 L
.11119 .0516 L
.11102 .05153 L
.11086 .05146 L
Mistroke
.11069 .05139 L
.11053 .05133 L
.11037 .05126 L
.1102 .05119 L
.11004 .05112 L
.10987 .05106 L
.10971 .05099 L
.10955 .05092 L
.10938 .05086 L
.10922 .05079 L
.10906 .05072 L
.10889 .05066 L
.10873 .05059 L
.10857 .05052 L
.10841 .05046 L
.10824 .05039 L
.10808 .05032 L
.10792 .05026 L
.10776 .05019 L
.1076 .05012 L
.10743 .05006 L
.10727 .04999 L
.10711 .04992 L
.10695 .04986 L
.10679 .04979 L
.10663 .04972 L
.10646 .04966 L
.1063 .04959 L
.10614 .04952 L
.10598 .04946 L
.10582 .04939 L
.10566 .04932 L
.1055 .04926 L
.10534 .04919 L
.10518 .04913 L
.10502 .04906 L
.10486 .04899 L
.1047 .04893 L
.10454 .04886 L
.10438 .0488 L
.10422 .04873 L
.10406 .04867 L
.1039 .0486 L
.10374 .04853 L
.10358 .04847 L
.10342 .0484 L
.10326 .04834 L
.1031 .04827 L
.10294 .04821 L
.10279 .04814 L
Mistroke
.10263 .04807 L
.10247 .04801 L
.10231 .04794 L
.10215 .04788 L
.10199 .04781 L
.10184 .04775 L
.10168 .04768 L
.10152 .04762 L
.10136 .04755 L
.1012 .04749 L
.10105 .04742 L
.10089 .04736 L
.10073 .04729 L
.10058 .04723 L
.10042 .04716 L
.10026 .0471 L
.1001 .04703 L
.09995 .04697 L
.09979 .0469 L
.09963 .04684 L
.09948 .04677 L
.09932 .04671 L
.09917 .04664 L
.09901 .04658 L
.09885 .04651 L
.0987 .04645 L
.09854 .04638 L
.09839 .04632 L
.09823 .04626 L
.09808 .04619 L
.09792 .04613 L
.09776 .04606 L
.09761 .046 L
.09745 .04593 L
.0973 .04587 L
.09714 .04581 L
.09699 .04574 L
.09684 .04568 L
.09668 .04561 L
.09653 .04555 L
.09637 .04548 L
.09622 .04542 L
.09606 .04536 L
.09591 .04529 L
.09576 .04523 L
.0956 .04516 L
.09545 .0451 L
.09529 .04504 L
.09514 .04497 L
.09499 .04491 L
Mistroke
.09483 .04484 L
.09468 .04478 L
.09453 .04472 L
.09438 .04465 L
.09422 .04459 L
.09407 .04453 L
.09392 .04446 L
.09376 .0444 L
.09361 .04434 L
.09346 .04427 L
.09331 .04421 L
.09316 .04415 L
.093 .04408 L
.09285 .04402 L
.0927 .04396 L
.09255 .04389 L
.0924 .04383 L
.09224 .04377 L
.09209 .0437 L
.09194 .04364 L
.09179 .04358 L
.09164 .04351 L
.09149 .04345 L
.09134 .04339 L
.09119 .04333 L
.09104 .04326 L
.09089 .0432 L
.09074 .04314 L
.09058 .04307 L
.09043 .04301 L
.09028 .04295 L
.09013 .04289 L
.08998 .04282 L
.08983 .04276 L
.08968 .0427 L
.08953 .04264 L
.08939 .04257 L
.08924 .04251 L
.08909 .04245 L
.08894 .04239 L
.08879 .04232 L
.08864 .04226 L
.08849 .0422 L
.08834 .04214 L
.08819 .04207 L
.08804 .04201 L
.08789 .04195 L
.08775 .04189 L
.0876 .04183 L
.08745 .04177 L
Mistroke
.0873 .0417 L
.08715 .04164 L
.08701 .04158 L
.08686 .04152 L
.08671 .04146 L
.08656 .04139 L
.08641 .04133 L
.08627 .04127 L
.08612 .04121 L
.08597 .04115 L
.08583 .04109 L
.08568 .04103 L
.08553 .04097 L
.08538 .0409 L
.08524 .04084 L
.08509 .04078 L
.08494 .04072 L
.0848 .04066 L
.08465 .0406 L
.0845 .04054 L
.08436 .04048 L
.08421 .04042 L
.08407 .04036 L
.08392 .0403 L
.08377 .04024 L
.08363 .04018 L
.08348 .04012 L
.08334 .04006 L
.08319 .03999 L
.08305 .03993 L
.0829 .03987 L
.08276 .03981 L
.08261 .03975 L
.08247 .03969 L
.08232 .03963 L
.08218 .03957 L
.08203 .03951 L
.08189 .03945 L
.08174 .03939 L
.0816 .03933 L
.08145 .03927 L
.08131 .03921 L
.08117 .03915 L
.08102 .03909 L
.08088 .03903 L
.08073 .03897 L
.08059 .03891 L
.08045 .03885 L
.0803 .03879 L
.08016 .03873 L
Mistroke
.08002 .03867 L
.07987 .03861 L
.07973 .03855 L
.07959 .03849 L
.07944 .03843 L
.0793 .03837 L
.07916 .03831 L
.07901 .03825 L
.07887 .03819 L
.07873 .03813 L
.07859 .03808 L
.07844 .03802 L
.0783 .03796 L
.07816 .0379 L
.07802 .03784 L
.07788 .03778 L
.07773 .03772 L
.07759 .03766 L
.07745 .0376 L
.07731 .03754 L
.07717 .03748 L
.07703 .03742 L
.07688 .03737 L
.07674 .03731 L
.0766 .03725 L
.07646 .03719 L
.07632 .03713 L
.07618 .03707 L
.07604 .03701 L
.0759 .03695 L
.07576 .0369 L
.07562 .03684 L
.07548 .03678 L
.07534 .03672 L
.0752 .03666 L
.07506 .0366 L
.07492 .03655 L
.07478 .03649 L
.07464 .03643 L
.0745 .03637 L
.07436 .03631 L
.07422 .03625 L
.07408 .0362 L
.07394 .03614 L
.0738 .03608 L
.07366 .03602 L
.07352 .03596 L
.07338 .03591 L
.07324 .03585 L
.0731 .03579 L
Mistroke
.07296 .03573 L
.07283 .03567 L
.07269 .03562 L
.07255 .03556 L
.07241 .0355 L
.07227 .03544 L
.07213 .03539 L
.072 .03533 L
.07186 .03527 L
.07172 .03521 L
.07158 .03516 L
.07144 .0351 L
.07131 .03504 L
.07117 .03498 L
.07103 .03493 L
.07089 .03487 L
.07076 .03481 L
.07062 .03475 L
.07048 .0347 L
.07034 .03464 L
.07021 .03458 L
.07007 .03452 L
.06993 .03447 L
.0698 .03441 L
.06966 .03435 L
.06952 .0343 L
.06939 .03424 L
.06925 .03418 L
.06911 .03412 L
.06898 .03407 L
.06884 .03401 L
.06871 .03395 L
.06857 .0339 L
.06843 .03384 L
.0683 .03378 L
.06816 .03373 L
.06803 .03367 L
.06789 .03361 L
.06776 .03355 L
.06762 .0335 L
.06749 .03344 L
.06735 .03338 L
.06722 .03333 L
.06708 .03327 L
.06695 .03321 L
.06681 .03316 L
.06668 .0331 L
.06654 .03304 L
.06641 .03299 L
.06627 .03293 L
Mistroke
.06614 .03287 L
.066 .03282 L
.06587 .03276 L
.06573 .0327 L
.0656 .03265 L
.06547 .03259 L
.06533 .03253 L
.0652 .03248 L
.06507 .03242 L
.06493 .03237 L
.0648 .03231 L
.06466 .03225 L
.06453 .0322 L
.0644 .03214 L
.06426 .03208 L
.06413 .03203 L
.064 .03197 L
.06387 .03191 L
.06373 .03186 L
.0636 .0318 L
.06347 .03175 L
.06333 .03169 L
.0632 .03163 L
.06307 .03158 L
.06294 .03152 L
.0628 .03147 L
.06267 .03141 L
.06254 .03135 L
.06241 .0313 L
.06228 .03124 L
.06214 .03118 L
.06201 .03113 L
.06188 .03107 L
.06175 .03102 L
.06162 .03096 L
.06149 .03091 L
.06135 .03085 L
.06122 .03079 L
.06109 .03074 L
.06096 .03068 L
.06083 .03063 L
.0607 .03057 L
.06057 .03052 L
.06044 .03046 L
.06031 .03041 L
.06018 .03035 L
.06005 .03029 L
.05991 .03024 L
.05978 .03018 L
.05965 .03013 L
Mistroke
.05952 .03007 L
.05939 .03002 L
.05926 .02996 L
.05913 .02991 L
.059 .02985 L
.05887 .0298 L
.05874 .02974 L
.05861 .02969 L
.05848 .02963 L
.05836 .02958 L
.05823 .02952 L
.0581 .02947 L
.05797 .02941 L
.05784 .02936 L
.05771 .0293 L
.05758 .02925 L
.05745 .02919 L
.05732 .02914 L
.05719 .02908 L
.05706 .02903 L
.05694 .02897 L
.05681 .02892 L
.05668 .02886 L
.05655 .02881 L
.05642 .02875 L
.05629 .0287 L
.05617 .02865 L
.05604 .02859 L
.05591 .02854 L
.05578 .02848 L
.05565 .02843 L
.05553 .02837 L
.0554 .02832 L
.05527 .02827 L
.05514 .02821 L
.05502 .02816 L
.05489 .0281 L
.05476 .02805 L
.05463 .02799 L
.05451 .02794 L
.05438 .02789 L
.05425 .02783 L
.05413 .02778 L
.054 .02772 L
.05387 .02767 L
.05375 .02762 L
.05362 .02756 L
.05349 .02751 L
.05337 .02746 L
.05324 .0274 L
Mistroke
.05311 .02735 L
.05299 .02729 L
.05286 .02724 L
.05274 .02719 L
.05261 .02713 L
.05248 .02708 L
.05236 .02703 L
.05223 .02697 L
.05211 .02692 L
.05198 .02686 L
.05186 .02681 L
.05173 .02676 L
.0516 .0267 L
.05148 .02665 L
.05135 .0266 L
.05123 .02654 L
.0511 .02649 L
.05098 .02644 L
.05085 .02638 L
.05073 .02633 L
.0506 .02628 L
.05048 .02622 L
.05036 .02617 L
.05023 .02612 L
.05011 .02606 L
.04998 .02601 L
.04986 .02596 L
.04973 .0259 L
.04961 .02585 L
.04949 .0258 L
.04936 .02574 L
.04924 .02569 L
.04911 .02564 L
.04899 .02558 L
.04887 .02553 L
.04874 .02548 L
.04862 .02542 L
.0485 .02537 L
.04837 .02532 L
.04825 .02526 L
.04813 .02521 L
.048 .02516 L
.04788 .0251 L
.04776 .02505 L
.04763 .025 L
.04751 .02495 L
.04739 .02489 L
.04727 .02484 L
.04714 .02479 L
.04702 .02474 L
Mistroke
.0469 .02468 L
.04678 .02463 L
.04665 .02458 L
.04653 .02453 L
.04641 .02447 L
.04629 .02442 L
.04616 .02437 L
.04604 .02432 L
.04592 .02426 L
.0458 .02421 L
.04568 .02416 L
.04556 .02411 L
.04543 .02405 L
.04531 .024 L
.04519 .02395 L
.04507 .0239 L
.04495 .02384 L
.04483 .02379 L
.04471 .02374 L
.04458 .02369 L
.04446 .02364 L
.04434 .02358 L
.04422 .02353 L
.0441 .02348 L
.04398 .02343 L
.04386 .02338 L
.04374 .02332 L
.04362 .02327 L
.0435 .02322 L
.04338 .02317 L
.04326 .02312 L
.04314 .02307 L
.04302 .02301 L
.0429 .02296 L
.04278 .02291 L
.04266 .02286 L
.04254 .02281 L
.04242 .02276 L
.0423 .0227 L
.04218 .02265 L
.04206 .0226 L
.04194 .02255 L
.04182 .0225 L
.0417 .02245 L
.04158 .0224 L
.04146 .02235 L
.04134 .02229 L
.04122 .02224 L
.0411 .02219 L
.04099 .02214 L
Mistroke
.04087 .02209 L
.04075 .02204 L
.04063 .02199 L
.04051 .02194 L
.04039 .02188 L
.04027 .02183 L
.04016 .02178 L
.04004 .02173 L
.03992 .02168 L
.0398 .02163 L
.03968 .02158 L
.03956 .02153 L
.03945 .02148 L
.03933 .02143 L
.03921 .02137 L
.03909 .02132 L
.03898 .02127 L
.03886 .02122 L
.03874 .02117 L
.03862 .02112 L
.03851 .02107 L
.03839 .02102 L
.03827 .02097 L
.03815 .02092 L
.03804 .02087 L
.03792 .02082 L
.0378 .02077 L
.03768 .02072 L
.03757 .02067 L
.03745 .02062 L
.03733 .02057 L
.03722 .02052 L
.0371 .02046 L
.03698 .02041 L
.03687 .02036 L
.03675 .02031 L
.03664 .02026 L
.03652 .02021 L
.0364 .02016 L
.03629 .02011 L
.03617 .02006 L
.03605 .02001 L
.03594 .01996 L
.03582 .01991 L
.03571 .01986 L
.03559 .01981 L
.03548 .01976 L
.03536 .01971 L
.03524 .01966 L
.03513 .01961 L
Mistroke
.03501 .01956 L
.0349 .01951 L
.03478 .01946 L
.03467 .01941 L
.03455 .01936 L
.03444 .01931 L
.03432 .01926 L
.03421 .01922 L
.03409 .01917 L
.03398 .01912 L
.03386 .01907 L
.03375 .01902 L
.03363 .01897 L
.03352 .01892 L
.03341 .01887 L
.03329 .01882 L
.03318 .01877 L
.03306 .01872 L
.03295 .01867 L
.03283 .01862 L
.03272 .01857 L
.03261 .01852 L
.03249 .01847 L
.03238 .01842 L
.03227 .01837 L
.03215 .01832 L
.03204 .01828 L
.03192 .01823 L
.03181 .01818 L
.0317 .01813 L
.03158 .01808 L
.03147 .01803 L
.03136 .01798 L
.03124 .01793 L
.03113 .01788 L
.03102 .01783 L
.03091 .01778 L
.03079 .01773 L
.03068 .01769 L
.03057 .01764 L
.03045 .01759 L
.03034 .01754 L
.03023 .01749 L
.03012 .01744 L
.03 .01739 L
.02989 .01734 L
.02978 .01729 L
.02967 .01725 L
.02955 .0172 L
.02944 .01715 L
Mistroke
.02933 .0171 L
.02922 .01705 L
.02911 .017 L
.02899 .01695 L
.02888 .01691 L
.02877 .01686 L
.02866 .01681 L
.02855 .01676 L
.02844 .01671 L
.02833 .01666 L
.02821 .01662 L
.0281 .01657 L
.02799 .01652 L
.02788 .01647 L
.02777 .01642 L
.02766 .01638 L
.02755 .01633 L
.02744 .01628 L
.02732 .01623 L
.02721 .01618 L
.0271 .01614 L
.02699 .01609 L
.02688 .01604 L
.02677 .01599 L
.02666 .01594 L
.02655 .0159 L
.02644 .01585 L
.02633 .0158 L
.02622 .01575 L
.02611 .01571 L
.026 .01566 L
.02589 .01561 L
.02578 .01556 L
.02567 .01552 L
.02556 .01547 L
.02545 .01542 L
.02534 .01538 L
.02523 .01533 L
.02512 .01528 L
.02501 .01523 L
.0249 .01519 L
.02479 .01514 L
.02468 .01509 L
.02457 .01504 L
.02446 .015 L
.02435 .01495 L
.02425 .0149 L
.02414 .01486 L
.02403 .01481 L
.02392 .01476 L
Mistroke
.02381 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
From the above curve we see that if we want to keep the error below \
5%, the compression ratio should be below about 35. We choose to keep the \
1985 largest coefficients. This corresponds to 3% of the total coefficients \
and to a compression ratio of roughly 33.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.28"}],

Cell["\<\
InverseWaveletPacketTransform[
Compress[wpdata, 1985], s4,
BoundaryCondition -> Fixed];\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S2.2.1"],

Cell["\<\
We see that the original is rather faithfully reproduced although \
we have less contrast than the original.\
\>", "MathCaption",
  CellTags->{"S2.2.1", "1.29"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[%, Mesh -> False]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S2.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00375601 0.0192308 0.00375601 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.20703 -0.0125 -6 -9 ]
[.20703 -0.0125 6 0 ]
[.39483 -0.0125 -9 -9 ]
[.39483 -0.0125 9 0 ]
[.58263 -0.0125 -9 -9 ]
[.58263 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.95823 -0.0125 -9 -9 ]
[.95823 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .20703 -12 -4.5 ]
[-0.0125 .20703 0 4.5 ]
[-0.0125 .39483 -18 -4.5 ]
[-0.0125 .39483 0 4.5 ]
[-0.0125 .58263 -18 -4.5 ]
[-0.0125 .58263 0 4.5 ]
[-0.0125 .77043 -18 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .95823 -18 -4.5 ]
[-0.0125 .95823 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.20703 0 m
.20703 .00625 L
s
[(50)] .20703 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(100)] .39483 -0.0125 0 1 Mshowa
.58263 0 m
.58263 .00625 L
s
[(150)] .58263 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(200)] .77043 -0.0125 0 1 Mshowa
.95823 0 m
.95823 .00625 L
s
[(250)] .95823 -0.0125 0 1 Mshowa
.125 Mabswid
.05679 0 m
.05679 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.13191 0 m
.13191 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.28215 0 m
.28215 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.35727 0 m
.35727 .00375 L
s
.43239 0 m
.43239 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.50751 0 m
.50751 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.65775 0 m
.65775 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.73287 0 m
.73287 .00375 L
s
.80799 0 m
.80799 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.88311 0 m
.88311 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .20703 m
.00625 .20703 L
s
[(50)] -0.0125 .20703 1 0 Mshowa
0 .39483 m
.00625 .39483 L
s
[(100)] -0.0125 .39483 1 0 Mshowa
0 .58263 m
.00625 .58263 L
s
[(150)] -0.0125 .58263 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(200)] -0.0125 .77043 1 0 Mshowa
0 .95823 m
.00625 .95823 L
s
[(250)] -0.0125 .95823 1 0 Mshowa
.125 Mabswid
0 .05679 m
.00375 .05679 L
s
0 .09435 m
.00375 .09435 L
s
0 .13191 m
.00375 .13191 L
s
0 .16947 m
.00375 .16947 L
s
0 .24459 m
.00375 .24459 L
s
0 .28215 m
.00375 .28215 L
s
0 .31971 m
.00375 .31971 L
s
0 .35727 m
.00375 .35727 L
s
0 .43239 m
.00375 .43239 L
s
0 .46995 m
.00375 .46995 L
s
0 .50751 m
.00375 .50751 L
s
0 .54507 m
.00375 .54507 L
s
0 .62019 m
.00375 .62019 L
s
0 .65775 m
.00375 .65775 L
s
0 .69531 m
.00375 .69531 L
s
0 .73287 m
.00375 .73287 L
s
0 .80799 m
.00375 .80799 L
s
0 .84555 m
.00375 .84555 L
s
0 .88311 m
.00375 .88311 L
s
0 .92067 m
.00375 .92067 L
s
0 .99579 m
.00375 .99579 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.20703 .99375 m
.20703 1 L
s
.39483 .99375 m
.39483 1 L
s
.58263 .99375 m
.58263 1 L
s
.77043 .99375 m
.77043 1 L
s
.95823 .99375 m
.95823 1 L
s
.125 Mabswid
.05679 .99625 m
.05679 1 L
s
.09435 .99625 m
.09435 1 L
s
.13191 .99625 m
.13191 1 L
s
.16947 .99625 m
.16947 1 L
s
.24459 .99625 m
.24459 1 L
s
.28215 .99625 m
.28215 1 L
s
.31971 .99625 m
.31971 1 L
s
.35727 .99625 m
.35727 1 L
s
.43239 .99625 m
.43239 1 L
s
.46995 .99625 m
.46995 1 L
s
.50751 .99625 m
.50751 1 L
s
.54507 .99625 m
.54507 1 L
s
.62019 .99625 m
.62019 1 L
s
.65775 .99625 m
.65775 1 L
s
.69531 .99625 m
.69531 1 L
s
.73287 .99625 m
.73287 1 L
s
.80799 .99625 m
.80799 1 L
s
.84555 .99625 m
.84555 1 L
s
.88311 .99625 m
.88311 1 L
s
.92067 .99625 m
.92067 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .20703 m
1 .20703 L
s
.99375 .39483 m
1 .39483 L
s
.99375 .58263 m
1 .58263 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .95823 m
1 .95823 L
s
.125 Mabswid
.99625 .05679 m
1 .05679 L
s
.99625 .09435 m
1 .09435 L
s
.99625 .13191 m
1 .13191 L
s
.99625 .16947 m
1 .16947 L
s
.99625 .24459 m
1 .24459 L
s
.99625 .28215 m
1 .28215 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .35727 m
1 .35727 L
s
.99625 .43239 m
1 .43239 L
s
.99625 .46995 m
1 .46995 L
s
.99625 .50751 m
1 .50751 L
s
.99625 .54507 m
1 .54507 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .65775 m
1 .65775 L
s
.99625 .69531 m
1 .69531 L
s
.99625 .73287 m
1 .73287 L
s
.99625 .80799 m
1 .80799 L
s
.99625 .84555 m
1 .84555 L
s
.99625 .88311 m
1 .88311 L
s
.99625 .92067 m
1 .92067 L
s
.99625 .99579 m
1 .99579 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
256 string
256 256 8 [256 0 0 256 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3532323A3E372F21171C232A33393E45473B30251E232829
2A2622201E1B181618222C3438312A25201D1B1715151616
16151413131414151616171819191A1B1C1C1D1D1D1E1F1F
1F1D1B1A19171615161B2025292D313435312D292522201D
1B1B1B1A1A19181817181818181819191918181817171717
17181818191A1A1B1A1714121114171A1C1C1C1C1C181512
121920252A2826262424242323272A2C2C28221E1A181513
111213151616161717171616161616161616161616161616
161616161616161616161717171818181818171716161615
151516161617171717171616161616161616171718181919
19191918181919191919191818181818
3836353636312C27232325272B333A41433A312A24272929
29262422201D1B191A222A31342E2824201D1B1715151516
161514131314141515161718191A1A1B1C1D1E1E1E1F1F1F
1F1D1B1918171717181D22272B2D2F31322F2B2724221F1D
1B1A1A1A1A19181818181818181818191919181818171717
16161616151514141414141514131111100F0F0E1013171B
1F2326292926221F1C191612121216171917151413131414
141414141515151515151515151515151515161616161616
161616161616161616171717171717181717171616161615
151516161616161717171616161616161616171717171717
171818181919191919191A1A1A1A1A1A
40413F3A35302C2C2B292724242D363D403A332E2B2B2B2A
2927252423201E1C1C23292D302B26231F1D1B1816151515
151414131314141515161718191A1B1B1C1D1E1F20201F1F
1E1C1A18171818191B2025292C2D2E2F2E2B292623201E1C
1A1A1A1A1A19181818181818181818191919181818171716
1515141313110F0E0E11141617120E0B090707070911191F
25292B2C281A0D050004090B0F0B0D0B0D0D0E0F10111314
151514141414141414141415151515151515161616161616
161616171717171717171717171717171717161616161615
151616161616161617161616161617161616161617161616
1617181919191919191A1B1C1D1D1D1D
5B5F5F554A3B2F2B29272621202B353C403A35322F2E2C2A
282827262522201E1E23282B2C2925221F1D1A1816161515
151414131314141415161718191A1B1C1D1E1F202120201F
1E1C191817181A1B1E22272B2D2D2D2C2B29272422201D1B
1A1A1A1A1A19181818181818181818191918181817171616
15131211100F0E0E0E101213141413131314151516161615
151A1D1A181719242C2B292A2C2626211F1E1C1B19171513
121213131314141414141414141515151516161616161616
161717171717171818171717171717171616161616161616
161616161616161616161616171717171616161616151514
141618191A1A1919191B1D1F20201F1F
6F76786D5F49362F292726201E29333A3F3C373634312E2B
282829282825232121242628292623211E1C1B1817161515
151414141414141415161718191A1B1C1D1F20212221201F
1E1B191717191B1D2025292C2F2D2B2A28272523211F1D1B
191919191919191818181818181819191919181817171615
14131211100F0E0E0E0F10121316181A1C1E1F201E19130E
0B0D100C10263F5C6E5F4F463E3C3D37332E2925211C1712
101011121313141415151414141415151616161616161616
171717171818181818181717171716161616161616161616
161616161616161616161617171717171616161616151514
1416181A1B1A1919191C1F2122222222
68727877705B473B312C2922202932393E3C3A3A3934302C
29292A2A2A27252423242526262422201E1D1B1917161615
1414141414141414151617191A1A1B1C1D1F21222322201F
1D1B191716191C1F22272B2E302D2A2725242322201E1C1A
19191A1A1A1919181818181818191A1A1A1A191818171616
1516161717171616161718191918171616191B1C1C16110F
100C111C2C495F65685E544C3E48424540373028211C1712
0F1011121313131415141414141415151616161616161617
171718181818191919181817171616161516161616161616
161616161616161616161616161717171716151515161616
17191B1D1E1B1917171B1F2224232323
646E787E7E6C594A3B342D26232A31373D3D3D3E3D38322D
292B2C2C2C2A282625252524242221201E1D1B1918171615
1414141414141414151617191A1B1B1C1D1F22232422201F
1D1B1917171A1E2124282C2F312D292522222221201E1B1A
19191A1A1A1A191918181818191A1A1B1B1B1A1918181716
16181A1B1C1C1C1C1D1D1D1D1D191614131517191A151212
17141E3449626D5F5552524E3D5245504A3E352A211C1712
0F0F10111313131414141414141415151616161616161717
171718181919191919191817171616151515151516161616
161616161716161616161616161717171716151515161718
191B1D1F201D1917161B202426252425
6C71767E8076695A4B3F342A252A30363B3E3F42413B342E
2A2C2E2E2E2C2A29272624232121201F1E1C1B1918171615
1414141414141414151618191A1B1B1C1D2022242523211F
1D1B1917171B1F23262A2E31322D2925212121201F1C1A18
1718181919191A1A1A19181817191A1B1B1B1B1B1A191817
1717171718191A1B1B1A1918171615141312121313131516
203148586367626262534B4832503F514A3C33271E1B1713
101011111212131314141313141415151616161616171717
1718181919191A1A1A191817171616151515151516161616
161616161616161717171616161717161615151515151616
171C2024251F1A17151B222629282727
7272747B807C75695B4B3D322C2E3134393D4044443D3630
2C2E3030302E2C2B29272422201F1F1E1D1C1B1918171615
1414141414141414151618191A1B1B1C1D2023252623211F
1D1B1918181C2024282B2E31312D28242121201F1E1C1918
1717181819191A1B1B1A19181718191A1A1B1B1B1A1A1918
171616151517191B1B1917161412100F0F101215181C2124
304E6B757666555B5F4C3F40294A384D463930241C1A1713
111111121212131314141414141515161616171717171718
18181919191A1A1A1A191818171616151515151516161616
161616161616171717171717171717161616151516151515
171C212628231E1B1A20262A2D2C2B2C
7776767A7C7B777066594C423A37353334393E42443E3733
2F30323231302E2D2B282522201F1E1D1C1B1A1918171615
1414141414141414151618191A1B1B1C1D2023252624211F
1D1C1B1A1A1E2225282B2D2F2F2A26221F202020201E1C1A
1919191A1A1A1A1A1A1B1C1C1C1A19181716161515161617
1718191A1915120F0E1115171A1A1A1C1B1B191B202F3E4E
54686A6E705A544C4443343B2A3F35423D342D251F1B1713
111112131414141415151515151616171718181818181819
1919191A1A1A1A1A1A191818171616151515151516161616
1616161616161617171717171818191A1A1917161517191A
1B1D1E2022262A2D3032333435353535
7B797879797978756F655A5249413A3330363C41433E3935
333334333231302E2C292623211F1D1C1A1A191818171615
1514141414141415151618191A1B1B1C1D2123262724211F
1D1D1C1C1D202325282A2B2C2C2824211F1F212121201E1D
1B1B1B1B1B1A1A191A1C1E1F1F1C18161313121111131516
18191A1B1B1814121114181A1D1B1A1D1E262C333E4D5B70
6B796462664C544333402B372B34323836312B27221D1713
10111314151515161616161616171818191919191919191A
1A1A1A1A1A1A1A1A1A191918171716161515161616161616
161616161616161617171818191A1B1D1E1C191716191B1D
1E1D1C1C1F2A353E44423F3E3D3E3F3F
7C7C7C7C7C7C7B78746E665F564A3E342F353C40433F3A38
36363635343331302E2B2825221F1D1B1919181818171616
1515151414141415151718191A1B1B1C1D2124262725221F
1D1E1E1F2022242628292A2A2A2623201E2021212221201F
1D1D1D1D1D1C1C1C1C1D1D1E1D1A17151312131213151618
1916141313171B1E1F19120F0E11161C2540546878736D76
5E7359565D3E514434472B393032363635322E2B261F1812
0F1113151716161717171717171819191A1A1A1A1A1A1A1A
1B1B1B1B1B1B1A1A1A191918171716161616161616161616
1616161616161616171819191A1B1C1E1F1E1C1A18191A1B
1C1B1B1C21303F4B534F494744464847
7C7E7F7E7E7D7B7A78736E696052453932373D4143403C3B
3938383635343332302D292623201D1A1818181818171616
1615151515151515161718191A1B1B1C1D21242728252220
1E1F20212224252728282828282523211F2021222322201F
1D1D1D1D1D1D1E1E1E1D1C1C1A181614131314141517181A
1A181513131517191A140F0E13273D505F696F757B746C73
546A48464E324E44364C2D3A3430393434332F2D29211913
0F111416181818181919191919191A1A1B1B1B1B1B1B1B1B
1B1B1B1B1B1B1B1B1A1A1918181717161616161616161616
16161616161717171718191A1A1A1B1E201F1E1C1A19191A
1B1C1F21283747535C57504D4A4C4E4E
7B7C7D7C7C7B7B7A78736D6760574E464142444444413E3C
3A39393837363534322E2A2723201D1A1818181818171716
1616151515151515161718191B1B1B1C1D21242728252220
1E1F2122242628292A2A29282726252423232323221F1C19
17151616171A1D20211D1A17151515151515151617171819
1A1D1F22242324252A343F495465757E8A7A7768645F5960
4558393B3F2E443F37462F3633303532312F2B28241F1A16
1314161718181819191919191A1A1B1B1C1C1C1C1C1C1C1C
1C1C1C1C1C1C1B1B1B1A1A19181817171616161615151516
1616171718191919191A1A19181615181A1C1D1B19171518
1C242D343B42484E52514F4E4D4E4F4F
787A7A7A7A7A7A7977716B655F5B5854504D4B4846433F3D
3B3B3A3A3939383735302C2824201D1A1818181819181717
16161615151515151617181A1B1B1B1C1D21252829262220
1E2022242628292B2C2A29272626262626252424221D1914
1210121214191D21231E191512141616171718191A191A1B
1E22282E374553606C737A81858B8F8991787C6762574B4D
33462C32312C3B3B3A3F323331323231302C2724201D1B19
17171818191919191A1A1A1A1A1B1C1C1C1C1C1D1D1D1D1D
1D1D1D1D1C1C1C1C1B1B1A19191817171616151515151515
16171718191A1B1B1B1A191816131114171A1C1B1A17161C
24303B444B4B4A49494B4D4F4F4F4F4F
76787A7A7A797776746F6A646060605F5D57514C4744423F
3D3C3C3C3C3B3A3937332E2A26221E1A1818191919191818
17171616151515161617181A1B1B1C1C1E21252829262321
202326282A2A2B2B2B292826252525252425252524201C17
1514151516181A1C1D1C1B1B1A1B1C1C1C1B1A1A1B1D2023
29313B4553697E8F9C9993918B8D8D7F88677056544D444A
3340242B242834373A3A343233343232302A26211E1D1C1B
1A19191919191A1A1A1B1B1B1B1C1C1D1D1D1D1D1D1D1D1D
1D1D1D1D1C1C1C1C1B1B1A19191818181717161616151414
1517191A1C1D1D1C1C1A1916141313181C1D1D1A191C2233
4145474B4C4D4D4C4C4D4F5051515050
7376797A7A787674726D696461646768665E564F49474442
403F3F3F3F3E3D3C3A35312C2824201C1A191A1A1A191818
18171616161516161617181A1B1B1C1C1E2225282A262321
2124282B2D2C2B2B2A292726252525242425252524211E1A
19191A1A1C1D1F20222222232321201F1E1D1C1D1F23282E
374554616B6C6C6D717E8A93938A7F6B7353644B4B473F45
333A20261B262E3339353532323331312F29241F1C1C1C1C
1C1B1A1A191A1A1A1B1B1B1B1C1C1C1D1D1D1D1D1E1E1E1E
1E1D1D1D1C1C1C1C1B1B1A19191918181817171616151414
1416191B1C1D1D1D1C1A18151414151B1F1E1D1A1C253248
585551504E4F504E4D4E505152515151
7175787A7A787675736E6A6663656666655E58524E4B4947
454544434342413F3D3934302C2825211E1C1B1918181717
17161515151515161617181A1B1B1B1C1D2125282A262320
1F2225282A29292A2A28272626282A2A2A25221F1D1C1B1B
1A1E20242627292A2B2D2E2E2D251D17141920252B323941
4851585F635E595656616C74777672697059624F4E484042
333723261E252C2F342E2F322C2C302D2B28231F1C1B1B1A
1A19191919191A1A1A1A1B1B1B1B1C1C1C1C1C1D1D1D1D1D
1D1D1D1D1C1C1C1C1B1B1A19191817171616161617171717
171616151517191B1C1A1817171818181717191C233A4E52
555553514F4F504F4F50515152525152
707477797A797775736F6C6865656565635E595652504F4D
4B4A494847464543413D3834302D2A26231F1C1917161616
16151414141415151617181A1A1A1A1B1D2125282926231F
1D202325272727292A282727272B2E2E2D25201A18191B1F
2028293034383D3F403E3A3732271D15121C28313B434B54
5A5A595A5A5E6163635F5B58565D64646A5B594D48443F3E
333426262124292B2E28283226242E292826211F1D1B1A19
181818191919191A1A1A1A1A1A1A1B1B1B1B1B1C1C1C1C1C
1C1C1C1C1C1C1C1C1C1B1A1A191716151515161617181A1A
1A161311101215181B1A191A1B1D1E18141519212F4C6159
52545351505050505151525151525252
6F7275777978767573706C686666666563605C5956555351
504F4E4C4B4A484744403C3835322F2C28231E1A17161615
1514141414141515161718191A1A1A1B1D2125282A26221F
1C1F21242625252728282829292A2B2927201C17181B202B
293C384549525B5F5E4F3E312622201D202E3D4A565C6066
696968666463615F5D5C5B5956524E494642413D3B393635
312D262420222525282022301F1D2A2423231F1D1C1A1918
1717181819191919191919191A1A1A1A1A1A1B1B1B1B1B1B
1B1C1C1C1D1D1C1C1C1B1B1A19171615141515161718191A
1917151412121315171A1C1D1E21221C191A2032424D5657
5654535556524F4E4D4F515151515151
6F72747678777574726F6C686666666564615F5C5A595856
555452514F4E4C4A4844403D393734312D26201B17161615
1514131314141515161718191A1A1A1B1D2125282A26231F
1D1F2224262525262728292A2A292825231F1E1B1E232A39
394F4B5A5B5B5A575143352A22252B2F374656646F707071
706F6D6A6765625F5C5A585550463C352D302E2F2E2E2E2D
2D272521201F211F22191C2D191726201F201C1C1B191817
16171718181819191919191919191919191A1A1A1A1A1A1A
1B1B1C1C1D1D1D1D1C1C1B1A191716151414151516171818
1818171716131213151A1F22252B2D2723252C42534F4D54
5754525759534E4C4A4D505050505050
71747678787673716F6C696765676869696663605E5D5C5B
5958565553514F4D4B4744403D3A3835312A231E19181817
17161515151516161718191A1B1B1B1C1E22252829272422
2125292C2D2A2726252627272624232221282D33373E464A
60556A606157483F352D292525313E4A555C636A6E6E6D6B
696764605C58544F4B4744403D3A373531302D2C29282725
2521201E1C1C1D1C1E181A251817211D1D1D1B1A1A181817
16171718181818191919191918191919191919191A1A1A1A
1A1B1B1C1C1C1C1D1D1C1C1B1A1918161616161616151413
131517191A1715191B171929394852453B3F455059565456
5655535454514F4D4C4E4F4F4F4F4F4F
747678797975716E6B69676565686B6D6D6A66636160605E
5D5B5A58565553504E4B4844413F3C39352D27211C1B1A19
19171616161616171718191A1B1B1C1D1F22252728272524
252A2E31332E2A28262728262423232628353D494D535A56
7857765C5C5140372E2929282E43586A777571706D69645E
595755524E463D373230302F2E303132322E2A272422201E
1C1B1A1A191919191A17181D18181D1B1B1B191918181717
161717181818181819181818181818181818191919191A1A
1A1A1B1B1C1C1D1D1D1D1D1C1C1A1918171716161513110F
0F13181C1E1B191D201A1C334B5F6C5E51565A5C5D5A5857
56555552504F4F4F4E4E4E4E4F4E4E4E
7678797A7975706C6967666565686C6E706C696664646362
615F5D5C5A585653514E4B484543403D39312A231E1C1B1A
19171616161617171818191A1B1B1C1C1E2226292A272424
24282B2C2E2E2D2D2D3030272329314146534E5756525157
5A5650463B332C24222D3A4653606C777C72665D534C453D
37363533312D2825232221212021222222201F1D1B1A1817
151617171716161515151617161718181818181817171616
161617171818181818181818181818181818181818181919
191B1C1D1F1F20202020201F1E1C19171514131211111213
1416191C1D1917181C2B3B4A575F636260616262615A5556
565655514D4E4F4E4E4D4D4D4E4E4D4D
78797A7B7A756F6B6866666465696C6F716E6B6967666564
6361605E5C5A585654514F4C4A4845423E362E27211F1E1C
1A191817171717171818191A1B1B1B1C1D2226292A272424
2527292A2B2E31323436362D2B37455A60675B5D584E4751
3D4D2D31221F2421273E546775726D6A6252423226262624
231F1C1B1A19181716161717171718181917171615141212
111314151614141312141412151615161716171716161616
161617171718181818181818171717171718181818181819
191B1D1F20212122222120201E1C19171513121010121416
18191A1C1E1C1B1B213D555C605E5B6267666565635A5455
575756504C4D4F4E4D4D4C4D4D4D4D4D
78797A7A7975716D6A69686767696C6E6F6D6B6A68666563
61605F5E5D5B5957565452504D4C4A48443B322B25232220
1F1C1A1918171717171718191A1B1C1D1E21252628252428
2A2D313132323133332E2E3D4C5D6A646A585D4C48443E3D
31322528272F3B4450606E7A81786D655A50463A33333434
322B241F1B19181716171718191A1A1B1B19181715141312
111314151514141313141413151615161616161616161616
1616171717181818181818181818181818181919191A1A1A
1B1B1C1C1D1D1E1E1E1C1917161718191919191918181919
19191A1B1F273038424E585E62605D5A595C5F62635D5759
595958534F4F4F4E4D4D4D4E4E4E4D4D
78797A7A797673706E6C6B69696A6B6C6D6C6B6A69666462
605F5F5E5D5C5A595756555351504F4D4940372F29282725
23201D1B1918171717171718191B1C1D1D2124252623242B
2D31363535343233342D3050697881686C4A583B383A362B
231D212834435365747D83898982797067625D56514D4945
40372D26201D1C1A19191A1B1C1D1D1E1D1C1A1816151413
131314151515141414141515151516161616161616161616
161617171818181818181818181818181819191A1B1B1B1C
1C1C1B1B1A1C1D1D1C1814111013171A1D1D1E1F1F1E1C1C
1C1D1F21273644525C5C5B5F61605D534D535A5F635F5B5C
5C5B59565351504E4C4D4E4E4F4E4E4E
78797A7A79777472706E6D6B6A6B6B6B6B6B6B6B6A676360
5E5E5F5E5E5C5B5A59585756555554524E453B332C2B2A27
25221F1D1B19181817171717181A1B1B1B20252729211E29
2D2D302D2B2D2F2E3343556B7A6F63625B4D403934383927
1D202B3D515E6B7C898D8E8E8C89857F79746F69625B544D
463C342C2622201D1C1B1B1B1C1D1E1F1F1D1B1918171615
151515151515151515151516151516161616161616161616
1617171718181818181818181818181818191A1B1B1B1C1D
1D1D1D1D1D1E1F201F1A15110F1216191B1C1C1E1E1A1817
1926333E484E545B5F5F5E5F6061605954575B5F62605F5F
5F5C5A575452504E4D4E4E4F4F4F4F4F
79797A7A7978767472716F6D6C6B6A6A696A6B6C6B67625F
5D5D5E5E5E5D5C5B5B5A5A5958585856534A413A33302E2B
2825221F1D1B191918171717181A1C1A1A21272A2B211C27
2D2C2C28252D33313858737C7F614855484B2D3630343823
1A273C556F7881909A9997938F9293928F8A857F776D6258
4E453C342D292522201E1D1C1D1E1F20211F1D1B1A191818
171716161616161616151616161616161616161616161616
16171717181818181918181818181818191A1A1B1B1C1C1D
1E1F1F2020222425241E17130F121517191A1B1D1E1C1B1C
2134465561615F6162605E5E5F61625D5A5B5C5F61626261
605D5A575452514F4E4E4F4F504F4F4F
7A7A7A7A797877757472706E6D6B6A68686A6B6C6C67625F
5C5D5F5F5F5E5D5D5C5C5C5C5B5B5A5855504B46403B3530
2B2825221F1C181817151516181C1F1B1A23292B292A261F
282D2B2726394B4C5167746C614F3E3E373B32342F29251A
1A324F6980868A939A9EA0A0A0A1A09E9A948C847C746B62
584C41362E2A272422201E1D1C1D1D1E1E1C1B1A19181818
181717161616161616161616161616161616161616161616
16171717171818181918181818181919191A1A1B1B1B1C1D
1F222527292C2E302F271F1914131312121316191F2B3641
4A4E5155585C5F6263615F5F5F5F5E5B58595B5E60606060
5F5D5A575552514F4E4E4F4F504F4F4F
7B7B7B7A79797877757371706E6B696766696B6D6D68625E
5C5D5F6060605F5E5E5E5E5E5D5C5B59575655534F473F37
312D2A27231E1918171514161920241D1C252B2B28312D1E
2F3B3634344C6464666F6E58443D362F2E3237312B211919
2143647D9092939699A1A7ABADACA9A6A19990867D78726B
62544639302D2A2725221F1E1D1C1C1C1B1A1A1918181818
181817171717171717171616161616161616161616161616
16171717171818181918181818181919191A1A1B1B1B1C1E
2024282B2E323538372E251E181513111214191E273C4F60
6B635B5652585D6061615F5F5F5D5B5958595B5D5F5F5F5F
5E5C59575452504F4D4E4F4F504F4F4F
7C7C7B7A7A797978777573716F6B686665686B6E6E68625E
5B5D5F60616160606060605F5F5D5B59595D606260584F47
3F3A36302B241D1B191716181C262D2725282A2A252B282E
5C6E6870707A83776A6053413335394047413A291C1B1F28
3859798C9BA0A2A4A5A8AAABACADACABA79F968D85807A73
6A5B4C403532312D2B2723211F1D1D1C1B1B1A1A1A1A1A1A
1A1919181818181818181717161616161616161616161616
16161717171818181818181818191919191A1B1C1D1E1F21
22232526272C303333291F181314181A202A36414B555E66
6B6864615E5F5F5E5D5D5D5D5C5B5B5A5A5B5C5C5D5E5F5F
5E5B58565452504F4E4E4F4F504F4F4F
7D7C7B7A7A7A7A7978767472706C686564686C6E6F68625E
5B5D60616262616161616160605D5C5A5B62686D6E665D56
4E48423B342B24201E1B1A1C202B332E2B2B2A2A25292A45
899D96A19E98927D664F3B322E36414F59493A21111A283B
53708A97A1A9ADAEAEADACACACADAEAEABA49C948D88827B
726353463B3836322F2A2623211F1E1D1C1B1B1B1B1B1B1C
1C1B1A191819191919181717171616161616161616161616
161617171717181818181818191919191A1B1C1D1E1F2022
2323222223282C2F2F261D17141A222932414F5D67686869
696A696866635F5C5A5A5B5B5B5A5A5B5C5C5C5C5C5D5E5E
5D5A58565452504F4E4E4F4F50504F4F
7B7B7B7B7A7A7A7A79777573716D6A6766696D6F706A645F
5C5E61626363626363626161605F5D5C5D63696D6F6A6560
5B544D463F37302B2825232222272926292E33312E384168
A9B7ACA695806D58473A344452525255513B291C161E2F54
76828D99A2AAB0B4B5B3B1AFAEB0B1B1AFABA6A09A948D85
7B6C5D4F433E39342F2B282624222121201F1E1D1C1C1C1C
1C1B1A191918171717171717171716161616161616161616
16161617171717181818191919191A1A1B1C1C1D1D1E1E1E
1F21242627292A2B2B29262628323C454D52565B5F626566
676868676663615E5C5C5C5C5C5B5B5C5D5D5C5C5C5D5D5D
5C5A57565452514F4F4F4F5050505050
7A7A7B7B7B7B7B7A7A787674726E6C69686B6E70706B6561
5E606263646464646463626261605F5E5F64686B6D6C6A69
665F58514A443E3834312E2A2623212026303A3737445588
C3C8B8A28666493A312E375871695F57472E1B1A1E2A406C
908F8F9BA3ABB2B7B9B8B5B2B0B2B4B3B2B1AEABA69E958C
817264574B433C35302D2A28272625242422201F1E1E1D1D
1C1C1B1A1917161616161717171717171716161616161616
1616161616171717171819191A1A1A1B1C1C1C1D1D1C1C1B
1C2025292D2B2A2A2B2E32363C48535D64615D5B5A5D6061
62636465656362605F5E5E5D5C5C5C5C5D5C5C5C5B5C5C5C
5B595756545251504F4F505050505050
797A7A7B7B7B7B7B7A78767472706D6B6A6D6F71716C6662
60616464656565656564636262616161616466686A6B6C6C
6B66605B56514D48423F3B342D211B1E222F433D3E485A95
C8C6AF886B52393D44485469766D604E3721131A29476679
8A9096A2AAAEB1B5B8B9BAB9B7B8B9B7B6B4B2AEA9A0958B
8073665A4F463E37312E2D2B2A282726252322201F1F1E1E
1D1C1C1B1917161515161717171717171717161616161616
16161616161617171718191A1A1A1A1B1C1C1C1C1C1C1B1A
1B21282F33333233363C43484F565D63676563615F5F5F5D
5D5E5F606161616161605F5E5D5C5B5B5A5B5B5B5B5B5B5B
5A585755545251504F50505051505050
79797A7B7B7C7C7B7B79777573716E6C6B6E7072716C6764
616365666666666666656463636363636363646566696B6E
6E6B66635F5D5A56514D473F36251D23222F433C3F4A5F9F
C7B79B6C4E403240505C6A75786D5C41281B17263E658584
85919AA6AFAEAEB1B3B8BBBBBBBCBCBAB9B8B6B2ADA2978B
80756A5E544A413933312F2E2D2B2928272524222120201F
1E1D1D1C1A18161515161718181818181817171616161616
16161616161616161718191A1A1A1B1C1D1D1C1C1C1B1B1A
1A222B333A3B3C3F434B52585D61646667666563615F5D5B
5A5A5B5C5D5E606162605F5E5D5B5A5958595A5A5A5A5959
59575655535251505050505151515051
78797A7B7C7C7C7C7C7A787674726F6D6C6E7172726D6865
62646566676767676766656464646565656463626266696C
6D6B6967656463605D58534D473E36352D31292E333650A5
CD9977623B3B464145525D6A6F63502F1B2C4154697C8B8E
90989FA6ABAAA9ABACAFB2B2B3B6B9BABBBCBBBAB5A99B8F
837A70665C52483F38363433312F2D2C2A28262523222220
201F1F1E1D1A181717181919191919181818171717161616
16151516161616161618191A1B1B1B1E201E1C1C1C1E1F1C
1B212730393F464E5457595B5D606365656462615F5F5F5F
5E5E5E5D5D5D5D5D5D5D5C5B5B5A59595858585959585858
58565554535251515050515151515151
77787A7B7C7C7D7D7D7B79777572706E6D6F7172726D6965
636466676867676767676666656667676664615F5F636769
6B6A69696868676765605C5857534E4F39321722292B4CA9
C97D5A5A353E5847424A4E5C625341241B44697D8D8E8E93
979CA1A5A7A5A4A4A5A6A8A9ABAFB4B7BABDBFBFBBAFA194
887F776E64584D433C3A38363532302F2D2B292725242322
212121201F1C1A1A191A1B1B1B1A1A191918181717161616
16151515151616161618191A1B1B1C20221E1C1C1C20231F
1D2128313C47515C63625F5D5B5E606060605F5F5F606162
62615F5E5D5C5B5A59595959595958585858575757575757
56555454535252515151515151515151
76787A7B7C7D7D7E7D7B79777573716F6E707273726E6A66
6465676868686868686767666667686968635F5C5B5F6467
696766656463636462605E5C64565C793A2C1C131B437CB7
A4705E5857524C5153473F4D513B282940647E8C94929093
969B9FA1A2A09E9D9D9E9FA0A2A7ACB0B5BCC1C5C4B9ABA0
938A81766A5C4F433B39393837353331302D2B2927262524
23232222211F1D1C1C1C1D1C1C1B1B1A1919181817171616
16151515151616161618191A1B1C1D21231F1C1C1D21231E
1C2632414F565C64696865625E5D5C59585A5D5F60616161
61605E5D5B5A595857575858585858575756565656565656
55555453525251515151515151515151
76787A7B7C7D7E7E7E7C7A78767472706F707273726E6A68
6667686869686868686867676768696968635E5B595E6366
676562605F5F5E605E5E5F5E6E58679D48332D202A548BBD
9A71645E776242596245353F402A1D3A667F8D9494918E91
94989C9D9D9C9A99989798989A9FA3A7ADB6BEC4C5BCB1A7
9B91867A6D5E4F423938393838363333312E2C2A28272625
242423232221201F1F1F1E1E1D1C1B1B1A19191818171716
16161515151616161618191A1B1C1D21221F1C1C1E21231E
1F2E3F505F62656A6C6B68645F5B585452565B5F62616161
615F5E5C5B59585756565757575757575656565656555555
54545353525151515050515151515151
77797A7C7D7D7E7E7E7C7A78767472706F717273726F6B69
676869696969686868686767676868696864615E5D616669
6A6662605E5F60615E5E5F5E6C596CB37B554E52628FACA5
92837371797060574D4A4639342D3A6C82828C888688888C
90959A9D9F9F9E9D9A98979798999C9EA2A9AFB4B5B1ABA4
9C908376695A4D4037373736363331302E2C2A2927272727
2624222121222322211F1E1D1C1C1C1B1B1A191918181717
16161616161616161718181A1B1D1E1E1E1D1D1E1F1E1E22
2A3C4D5B6668686969686663605C585453565A5D60616162
63615F5D5C5A5A5858585858585858575756565656565555
545453525150504F4F4F4F4F4F4F4F4F
797A7B7C7D7D7E7E7E7C7A787674737170717272726F6C6A
68696969696968686867676666676767676563616165696B
6D68635F5D6062615E5F615F695A6FBCAB807993A5AA9D92
A59D83857F746A574A515138303C5D969885877C787E8186
8B92989DA1A3A4A19E9B98969594949495999D9FA0A09D9B
94887A6D6054483D3534343332302D2C2B2A292727272728
282422202024272624211E1D1C1C1C1C1C1B1A1918181817
1717161616161617181718191B1D1F1C1A1D1F21221D1D29
384A5B646A6B6A68656463615F5C585655575A5C5F606263
6462605E5D5C5B5A5A5A5A59595958585757575756565555
54535251504F4F4E4D4E4E4E4E4E4E4E
7A7B7C7C7D7D7E7E7D7C7A787675737170717272726F6D6B
6A6A6A6A6969686868676766666666676665646464676A6D
6E6965615F65696664656664676777B0CFB7A7B2B7B7B39A
848F9489887158616451433B3F6588969D8F817F7D7D7F82
878F969CA2A6A8A5A19C9693908C8A878585848281828281
7D72675C524941393331302F2E2C2A292827272626272829
2925212020262B2A28231F1D1C1C1C1D1D1C1B1A19191818
1717171716161617191717181A1D201A171D232628222236
49586567686B6C696663605E5D5A585756585B5C5F606263
6463615F5E5D5C5B5B5B5A5A5A5959585858575757565655
54535251504F4E4D4C4C4D4D4D4D4D4D
7B7B7C7D7D7D7E7E7D7C7A78777573727171727272706E6C
6B6B6B6A6A69686867676666656565666666666667696B6E
6F6A666362696E6A686A6C696470799FE6E3CFD1CCB9B1A0
7A8CA0837C8075685B49414C5B8EAA969D967E81807A7B7D
828B949CA3AAAEABA59E97938E88837E7974706A66676766
635A524A433E3934302E2C2B2A282726252525252627282A
2B262221222B32312F28211F1E1D1D1D1D1C1B1A19191919
181817171716161819171517191D2019151D25292D2A2D45
5B656C69656A6C6966625D5C5A595959595A5B5D5E606263
646361605F5E5E5D5C5C5B5B5B5A59595858585757565655
555352504F4E4D4C4B4B4B4C4C4C4C4C
7B7C7D7D7D7E7E7E7D7C7A78777574727171727271706F6E
6D6C6B6A6A6968686767666665656565656565666768696C
6D69656362696E69686C6E68626B7297DAE1D3D4CCBDB1A0
8D86909B8E827F67555054738F9DA39D9E9688847E777374
7985919CA6AEB2AFAAA39C99948D867F7870675F57524E49
45403C3834312E2C2A28272625252524242424252527282B
2C28242427343E3F3C322824211F1E1D1D1C1C1B1A1A1A19
19181817171616191A161416171C1F19161B2228313A465B
6B6E6E6A66696A6865615E5C5A5B5C5C5D5D5D5E5F606161
626160605F5F5E5D5D5C5C5B5B5A5A595958585757565655
545351504E4D4C4A4A4A4A4B4B4B4A4B
7C7C7D7D7D7D7D7D7D7B7A78777574737272727171706F6F
6E6D6C6B6A6968686766666665656565656565666667676A
6B68656363696E69686D70685F656A8AC8DCD5D3C9C1B6A0
988E97B49C78716761616B96B7A89DA19E9792887E746D6C
707E8E9BA8B1B6B3AEA8A2A09C938B837B70665B50473E36
302E2D2C2B2927262624232221222323232323242526282C
2D2A27282D3D4A4C4A3D302A2421201E1D1C1C1B1A1B1B1A
1A191817171717191A161415171C201B181B202733485C6D
78736C696567686765625E5C5A5C5F606160605F5F5F6060
60605F5F5F5F5E5E5D5D5C5C5B5A5A595858585757565655
5452514F4D4C4B4A4949494A4A4A4A4A
7C7D7D7D7D7D7D7D7C7B7978767574737272717171707070
6F6E6C6B6A69686767666665656564646465656667666668
69676665656B706B6A6F71685A636377BDE1DFDED4C9BDAD
A4B2BAAC9F877668577399AAB8B0A6A9A6A0998C7F726764
68778999A8B2B8B6B2ADA9A8A59C938C847C73695F554A41
39373533312E2B292725242221212121212122222425282C
2F2C2A2C324555585646362F2824211E1C1C1C1B1B1B1C1B
1B191817171717191A171416191F241F1C1F23252F4D6875
7C7165625F62656667635E5B595D6164656361605F5F5F5E
5E5E5F5F5F5F5F5E5E5D5D5C5B5B5A595958585857575655
5452504F4D4B4A494848494949494949
7C7C7C7D7D7D7D7C7C7A7978767574737272717171717170
706E6D6C6A69686767666665656564646465666767666567
68676666676D706C6C70716759605E68AADAE2E3DBD2CBC8
C0BAAAA5B99A756A5987BAB6B5B1A9ADABA49D8F8071655F
60708294A4B1BABAB8B3AFAFACA49C968E877F766D62584E
46423F3C3934302C2A27252321212120202020212224262B
2E2D2E323A4E5E62604F3D342C26231F1C1C1C1C1C1C1C1C
1B1A19181717181A1A1715171A2227242224272932536F78
7A6C5F5C5A5E636668645F5B595E6366686562615F5E5E5D
5D5D5E5E5F5F5E5E5E5D5D5C5B5A5A595858585857575655
5452504F4D4B4A494848484949494949
7A7B7B7B7B7B7B7B7B7A7877767473727171717171717170
706F6D6C6B6A696867676666666665656566676768676768
68686868696C6F6D6D6E6D675F6261648CC2E4EDDFD9D9D3
CAB39D9EA3978073849DA8AEAFABA9AAA8A1998F83766A5F
5B66768698A8B5BBBDB8B2B0ACA7A19B96928E888073665A
4F4A45403B36322E2B2825232120201F1F1E1E1E1F1F2124
292E353D475764676454443A312A25201C1C1D1D1D1D1C1C
1C1B1A191919191B1B1714151820282C2D26253B505D686D
6D665F5D5C6064676965605C5A5E6264666461605E5E5E5D
5D5D5D5D5D5D5D5D5D5C5B5B5A5959585858575757575656
555351504E4C4B4A49494A4A4A4A4A4A
7879797A7A7A7A7A7A797776757372717070707171717171
706F6D6C6B6A696868676767676766666667676868686868
686869696A6B6D6E6E6B69676564656371A6DEF3E4DDE1D5
CBB9A6937D8E9083A8AE9BA6A7A5A7A6A49C938D867A6F60
575E6A788A9DAFBBC1BAB2AFAAA8A5A09C98938E867B6F64
59514A443E3935302C29262422201F1E1D1C1B1B1B1B1B1E
242F3B47535F686A67594A40362E28211C1D1D1D1E1D1C1C
1C1B1B1A1A1A1B1C1C17141417202A33382E2D4F69646162
6160605F5F6266686965615E5C5F61636362605F5E5E5E5E
5D5D5D5D5C5C5C5B5B5A5A59595858575757575757575656
555452504F4E4C4B4B4B4B4B4C4C4B4B
777778787979797979787776747371706F70707071717171
706F6E6C6B6A696968686868686767676768686869696968
6869696A6A696A6D6D6864666A6569665E81C1EFEDE1E4DB
CFB497877B8391A5B6B1ACA7A2A2A2A19E958E8B867D7261
5558606D7F95ABBCC5BCB2ABA5A4A4A09B938A8179726B63
5A5149423C3835312D29262421201F1E1C1B1A191917181A
203041505D676D6E6B5E50453B322A221D1D1E1E1F1D1C1C
1C1C1B1B1B1B1B1D1D19161619222D333B4855626B686360
5D5F6262636566686865625F5D5F61626261605F5E5E5E5D
5D5C5C5C5B5B5A5A59595858585757575656575757575756
56545351504F4D4C4C4C4C4D4D4D4D4D
7576767777787878787776757372706F6E6F707071717171
706F6E6D6B6B6A6968686868686868686868696969696A69
68696A6A6A68676C6D6560666D676D6B5263A1E3EFE3E7DF
D1B39481787C96C0C0B3B6A79FA19F9C98908A89877F7563
56555A6372889CAEBAB2A9A39E9F9F9C9A9896928C7E6F62
554E48413C3935322E2A262421201E1D1B1A181818151517
1D314456646B6F716D62554A3F352C231D1D1F1F1F1E1D1C
1C1C1B1B1B1C1C1D1D1A18181B273238446074716D6A645E
5A5F636466666667666462605F60606161605F5F5E5E5E5D
5C5C5B5B5A5A595858585757575656565656565657575757
5655535251504F4D4D4D4D4E4E4E4E4E
73747576767777777776757472716F6D6D6E6F7070717171
716F6E6D6C6B6A6969696969696969686969696969696968
68696A6A6A69696C6D6662676D6A6E6E5E5C81C3E0E8F5E9
D9BFA18F8590A4BBC0B7B3AAA3A3A09B97918C89857D7469
5F59575961768B9CA8A29C9A99A1A8ABACAAA6A29A877361
524E4B4744403B37322D2925221F1D1B1A18171717151618
1F30435260696E727065584C40362E241E1E1F20201E1D1D
1C1C1B1B1B1B1C1D1E1C1B1C223244525F6B72716E6A6560
5C5E61616263646565646261606061616160605F5E5E5D5C
5C5B5B5A5959585757575656565655555556565657575757
5755545351504F4E4E4E4E4F4F4F4F4F
727374757576767676757473716F6E6C6B6D6E6F70707171
716F6E6D6C6B6A6969696969696969696969696969696968
68696A6A6A6A6A6C6C6764686C6C6E6F695B67A2CBE8FFF1
E0C7AA9D97A4B1B6BCB8B1ADA9A5A19B95928E89847B746E
6860595454606D78818385898E9AA4ABAEA89F988D7D6C5B
4D4B4B4847423C38332E2A26221F1C1A191717171717181A
2130414F5C656C727267594D41382F251F1F2021211F1D1D
1C1B1B1B1B1B1C1D1E1D1D1F263C526676736F6E6C696662
605F5F5E5E60626364636261616162626261605F5E5D5D5C
5B5A5A595958575756565656555555555555565657575757
575654535251504F4E4F4F4F4F4F4F4F
717273747475757575747372706E6D6B6A6C6D6F70707071
71706E6D6C6B6A6A6969696A6A6A6969696A6A6969696968
68696A6A6A6A6A6C6C68666A6D6C6B6765616886A7DDFFEC
E0CBAEA6A1AFBCBABAB7B1B0ACA6A09992918F8A847C7574
71675D52494849494B51575E666D73797D7E7E7D77695B4D
41403F3C3B37332F2C282522201D1B1A1918181819191A1C
2231404D59636B7273685B4F4339312720202121221F1D1D
1C1C1C1C1C1D1D1F1F1D1C1C223A536A7B756E6A66666766
6462605E5C5E606162626161616262626160605F5E5D5C5B
5B5A59595857575656555555555554545455565657575758
57565553525150504F4F505050505050
717272737474757575747271706E6D6B6B6C6E6F70707071
71706E6D6C6B6B6A69696A6A6A6A6A6A6A6A696969696969
68696969696A6A6A6B69686B6D6D6A6365686A6F86CCF8E8
E0D1B8B1ACB8C3BBB7B6B1B2B1A9A1989292918B847D7779
796C6051474E555A5B534B4745494D5054585B5E5E544940
383634312F2C29272522201E1D1C1C1B1B1B1B1B1C1D1F21
2734424E5962697072685B50443B32292222222222201D1C
1C1C1C1D1D1E1E1F201C1B1A213A546C7C746A6662656868
6865615E5B5D5F5F606061616262616161605F5E5E5D5C5B
5A5A59585857565655555555555454545455565656575757
575654535251504F4F4F505050505050
727273737474757575747271707070707070707071717171
706F6E6D6C6C6B6A6A6A6A6A6A6A6A6A6A69686868686969
69696968686868686968686B6D6E6D6B6A66636479B2E5EE
DED8D5BEB0BCC1B9B5B5B4B5B5ADA49D9694928C867E7879
78736F6866737F878A7C6D61564F49413D42474A4A433B36
322F2C2824222121201F1E1D1C1D1F20222223242626282A
303D4A555E64686D6D645A4F453C342B2424242323201E1D
1C1C1D1D1D1D1C1E1F1C1C1E263F57697570696866676868
6764625F5D5E5F5F60606060606060605F5F5E5E5D5C5C5B
5A5A59595858575756565656565555555555565656565656
5655535251504F4E4D4E4E4E4E4E4E4E
737373747475757575747271707273747473727271717170
706F6E6D6D6C6B6A6A6A696969696969696867666668696A
6A696867676665666767686A6C6E70716D66615E6D97CAE9
DCDFEBCAB4BDBFB8B3B4B6B8B8B0A8A19A97938E89817B79
787B7F80848D959B9C93897F72614F3F34393E40413A3533
312E29231E1C1B1D1E1D1D1C1C202326292A2B2E30313235
3A46525C6467686A6861584F463D362D2726262524211E1D
1C1C1D1E1E1C1B1C1E1D1E222C445A666E6B67696A696766
656462605F5F605F605F5F5F5F5F5E5E5E5D5D5D5C5C5B5B
5B5A5A5A5959585858575757575656565656565656555555
545352514F4E4D4C4C4C4C4D4D4D4C4C
747474747475757675747271707375777776747372717170
6F6F6E6D6D6C6B6B6A6A696969696969696866656567696A
6B696867656464646567686A6B6D6F706F6B685F607D9EC7
E9F2F0D3BABFC1B6B1B4B7B9BAB3ABA59F9B96918C85807C
7B7E83878E99A4ADB2ADA69F9483716052504F4A46423F40
3F3830261F1D1D202321201E1E22272B2E313336393B3D3F
444F596268696767645D564E463E37302A28272624211F1D
1C1C1D1E1E1B191A1D1D2128344D636B6F6B676B6D6A6765
6363626160606060605F5E5E5E5D5D5D5D5C5C5C5C5B5B5B
5B5B5A5A5A5A595959585858585757575656565555555454
5352504F4E4D4C4B4A4B4B4B4B4B4B4B
757574747575767676747270707376787A77757372717170
6F6F6E6D6D6C6B6B6A6A696969696969696765646466696B
6C6A676665636363646668696A6C6E6F6F6E6D635A6878A3
E3F5EDD7BEC0C1B7B2B6B9BBBBB5AEA9A49E9994908A8480
7E83898F97A3AEB8BFC0BEBCB6A79686776F675C54504E50
50473E32282423262826242221262C3034373A3E42444649
4E5761686D6B6865615B554E474039322C2A282625221F1D
1C1C1D1E1E1A171A1C1E232C3A546A6E706B676C6E6A6663
61626261616060605F5F5E5D5C5C5C5C5B5B5B5B5B5B5B5B
5B5B5B5B5A5A5A5A5A5A5959595858575756565555545453
52514F4E4D4C4B4A4949494A4A4A4A4A
75757575757676777673706E6D7074777876747271717170
6F6F6E6D6D6C6B6B6A6A696969696969686664636366696B
6C6A6866656363636464656667696A69696B6B6560626981
A3C4D7CCBFC2C2BEBCBFC0BDBAB5B0AAA59F9A96928D8985
84898F969DA7B1BAC1C3C4C5C2BBB2A89D9185776B676667
6861594D41372F2E2D2B2A27262B3034383C3F44494B4E51
565F676D716F6B68635D575049423A332E2B29272522201D
1B1C1E1F1F1B191C1F1D1F2634536C70706963686B676462
606263626161605F5E5E5D5C5C5B5B5A5A5A5A5B5B5B5B5B
5B5B5B5B5B5B5B5B5A5A5A5A595958585757565554545352
51504E4D4C4B49494848484949494848
757575757576777776726E6B6A6E72747674727170707070
706F6E6E6D6C6B6B6A6A696968696969686664626265696C
6D6A68666463636363636263646667656468696765606065
6E9CC4C2C0C4C3C5C6C7C5BFB9B6B1ABA6A19C9995918D8B
8A8E9499A0AAB4BDC5C7C8C9CACAC8C4BDB0A293857E7A79
7978746A5E4C3C353130302D2C3034383C40444A4F525559
5E666D7376736E6A655F59524B443C352F2C2A282522201D
1B1D1E1F201D1B1F211C1B212F516D7171685F6467646261
606263636261605E5D5D5C5C5B5A5A5959595A5A5A5A5B5B
5B5B5B5B5B5B5B5B5B5B5A5A5A5959585857565554535251
504F4D4C4B4A49484747474848484848
767676767677777877726D6A686C7073757371706F707070
706F6E6E6D6C6C6B6A6A696968686969686563616165696C
6D6A67656463626363615F60626568676666666665616060
6595C1C3C5C7C5C8CACBC9C1B9B7B3AEA9A39F9B98959290
8F93989DA4ADB5BEC4C6C7C8C9CBCCCAC6BFB5AA9D8B7C75
737F89887F6246382F3235323235383C4044494F55595D62
666D73787A76716C66605A544D453E36312E2B282623201D
1C1D1E20201E1C21231C191E2C516F7271675D6265625F5F
5F6163626261605E5D5D5C5B5A5A5958585959595A5A5B5B
5B5B5C5C5C5C5C5C5C5B5B5B5A5A59595857565554535251
4F4E4D4B4A4948474646464747474747
767676767677787877726C68666A6E7072716F6F6F6F7070
706F6E6E6D6C6C6B6A6A696968686969686563616165696C
6D6A676563626263625F5D5E606569686765646465636460
6495C0C6C9CAC7CBCDCECBC3BAB8B6B0ABA6A19E9B989593
93969A9EA4ADB5BDC3C3C4C5C6C9CBCAC8C7C3BCB0957D6F
6B83979D98724D3A2D323937373A3C4044484D545A5F6469
6E74787C7D78736D67615B554E463F38322F2C292623201E
1C1D1F20211E1D22241C181C294E6C7171675D6264615F5E
5F6163626261605F5E5D5C5B5A595958585859595A5A5B5B
5C5C5C5C5C5C5C5C5C5C5C5B5B5A5A595857565554535150
4F4E4C4B4A4847464646464646464646
747575757677787877726D6966696B6D6E6E6E6E6E6F7070
706F6E6E6D6C6B6B6A6A696968696969686664626265696B
6C6966656362626262605E5E5F656A69686765625F636668
7DA9C8CDCDCDCCCDCDCDCCC5BFBCB8B2ADA7A29E9B989593
9294969A9FA8B1BAC1C3C4C6C7C9C9C6C3C5C3BFB4957A69
637B929A96714D392B3239393A3D4044484C51565C636A70
75787B7C7C78726D67615B554E473F38332F2C292724211E
1C1D1E1F1F1E1D21221D1A1E2846606A6E68646769666464
646667656362605F5E5D5D5C5B5B5A5A5A5A5A5A5B5B5B5C
5C5C5C5C5C5C5C5C5C5C5B5B5A5A59595857565554535251
504E4D4B4A4948474646464747474747
737475757677787877726D696768696A6B6B6C6D6E6F7070
71706F6E6D6C6B6B6A6A696969696969686665646366696A
6B6966646362616262605F5F60656A69696866605A636870
97BED0D3D0D1D1CECCCDCCC8C4BFB9B4AEA9A39F9B979592
9191929499A3ADB6BEC1C3C6C8C8C6C1BDC1C1BFB5967966
5D748A92906D4A372A31393A3D3F42474B4F53585E676F76
7B7C7C7C7B77726C66615B554E47403933302D2A2724211F
1D1D1D1D1E1D1D20211E1D1F273D53626A69696B6C6A6768
686969676463615F5E5E5D5D5D5C5C5B5B5B5B5B5B5C5C5C
5C5C5C5C5C5C5C5C5C5C5B5B5A5A59585857565554535251
504F4D4C4B4A48474747474748474747
727374757677787877726E6A6767676767696A6C6E6F7071
71706F6E6D6C6B6A6A696969696969686867666564666869
6A6866646362616262605F5F60646867676968635B63646B
9AC0CDD3D1D3D5D1CECECDCBC7C1BBB5AFAAA5A09B989593
918F8E8F939DA7B1BABEC2C7CACACAC5C1C3C3C1B89C826F
6576868B876849372B31393B3E4144494E5155595F69737A
807F7E7C7A76726C67615B554E47403934302D2A2824211F
1E1D1D1D1D1D1E1F201E1E1F2535475A65686B6B6A686667
67686866646261605F5E5E5E5E5D5D5D5C5C5C5C5C5C5C5C
5C5C5C5C5C5C5C5C5C5B5B5A5A5959585757565554545352
514F4E4D4B4A49484747484848484848
717273747577777877736F6B6867676666686A6C6E6F7071
71706F6E6D6C6B6A6A696969696968686867666666676869
69676564636261626261605F6064676566696B665D64626B
A1C4CCD3D1D5D9D4D1D0CFCDCAC4BDB7B1ABA6A19C989593
918D8B8A8C97A2ADB7BCC1C7CBCDCCC8C4C6C5C3BBA38B7A
6F7880807A6046362B30373A3E41444A4E5155595F6A757D
83817E7B7875716C67615B554F47403A34312E2B28252220
1E1D1C1C1C1D1E1F1F1F201F222D3B5060686D6C69676465
666667646262616160605F5F5F5F5E5E5E5D5D5D5D5D5D5C
5C5C5C5C5C5C5C5C5B5B5A5A595958585757565555545353
52504F4D4C4B49484848484849484848
70717273757676777774716F6D6C6B6B6B6C6D6F70707070
706F6F6E6D6C6C6B6B6A6A6A696968686867676767676868
686765646362616262605F5E5F646765666A6C675F686977
ADCBCFD5D3D7DCD6D2D2D0CFCDC6BFB9B2ADA8A29E9A9795
928D89878994A0ABB5BABEC4C9CCCDCAC7CACACAC3AE9887
7A7A7B766C564031272C32363A3E42484D4F52555B67737D
83807C7A7674726D68625C564F48413A34312E2B29252220
1F1D1C1B1B1D1F1E1E20211F1F293345606B6E6F6B666363
636363605F606263636260605F5F5F5F5E5E5E5E5D5D5D5D
5C5C5C5C5C5C5C5C5B5B5A5A595958585757565555545453
52504F4D4C4B4A494848484949494949
6F70727374757576767574727170706F6F70707171717070
6F6F6E6E6D6D6C6C6B6B6A6A696968686867676767676868
676665646362616262605E5E5E636866676B6D69636B6F82
B7D0D2D7D5D9DED9D4D3D1D1CFC8C1BBB4AFAAA49F9C9996
938D888586919DA8B3B7BCC3C8CCCFCCCBCECFCFCAB8A493
847C74695D4A3A2D25282D31363A3E454A4C4E515764717B
827F7B787473726E6A635D564F48413A34312E2C29252221
1F1D1B1A1A1D1F1E1E20221F1C252B3A5E6D6E6F6B656160
5F60605D5C5F6264656361616060605F5F5F5E5E5E5D5D5D
5D5C5C5C5C5C5C5C5B5B5A5A595958575756565555545453
52514F4E4C4B4A494848494949494949
6E6F7172737475757676757575747373727272727271706F
6E6E6E6E6D6D6D6C6C6B6B6A696968686768686868686767
676564646362616262605E5E5E636865666B6F6B666E738A
BFD3D3D8D6DBE0DBD6D5D3D3D1CAC2BCB6B1ACA6A19E9B98
948C8581828D99A4AFB6BCC4CBD1D4D3D3D5D6D6D1C1AF9E
8C7B6A594A3E33292325282C31363B4147484A4D53616F7A
817D78757272716F6B645D564F48413A35312F2C29262221
201D1B1A191D201E1E21221F1920222F5B6E6C6F6A625E5C
5C5D5F5D5D5F6263646362616161616060605F5F5E5E5D5D
5C5C5C5C5C5C5C5B5B5A5A59595858575756565555545453
52514F4E4C4B4A494849494949494949
6E6F7071727374757576767777767575747473737271706F
6E6E6E6D6D6C6C6B6B6A6A69696968686768686868686767
666564636362616262605F5E5E646866666C6F6C68707692
C6D6D4D8D7DCE2DDD8D6D4D5D3CCC4BEB8B3ADA8A39F9C99
958C847F7E88949FA9B2BAC3CBCFD2D2D3D5D6D5CFC1AF9E
8A735D4939322D26232224272C30363C4244474A505F6D78
7F7C77747171716F6B645D564F48413A35322F2C2A262221
201D1B19191D201E1E21221E171C1C275569676A655E5B5A
5A5D5F5E5E60626363626262626262616160605F5E5E5D5D
5C5C5C5C5C5B5B5B5A5A5959585857575656565555545453
52514F4E4D4B4A494849494949494949
6E6F70717273747475757575747373727171717070707070
706E6C6B6A68686766666767676768686868686868686767
66656463636161616261605F60656967666B6D6A666D7696
C7D5D5D9D8DDE2DDDAD8D6D6D5CEC6C0BAB5AFAAA5A19D9A
958B837D7B838D949EA9B3BCC2C0BDBEBFC3C4C0B9A89684
715D4A392C2927252321212326292E33393D4349515F6D78
7F7C77747071706D6A635C564F48423B35322F2C29262221
1F1D1B1A1A1E201F1E1F1F1B141818254857585A58595C5F
636464636263636262616162636363636261605F5E5D5C5C
5B5B5B5A5A5A5A5959585858575756565655555554545353
52504F4E4C4B4A494849494949494949
6E6F707172737474747473727170706F6E6E6E6D6E6F7071
716E6B696765646262626364656667686968686867676767
66656463626160616161616162676A68676A6B67646B769B
C9D4D5D9D9DDE1DEDBDAD8D8D6CFC8C3BCB7B2ACA7A29E9A
958C847D7A80878B929FABB2B6ACA3A4A6ACAEAAA08F7B68
5646372A2221232324211F1F2123262A2F374048525F6C77
7E7B777470706F6C68625C564F48423B36322F2C29252220
1E1D1C1B1C1E20201F1E1D18131517243B454747474D555D
646666666564646160606162636464636361605F5E5D5C5B
5A5A59595958585857575757565656555555545453535352
51504E4D4C4B4A494848494949494949
6E6F707172737374747371706F6F6E6D6D6C6C6B6C6E7072
726E6A676462615F5E5F6163646667686969686867676767
66656463626160606161626264696C6A68696964636B7AA4
CED6D8DBDADEE1DEDCDBD9D9D7D1CAC5BFB9B4AEA9A49F9B
968D867F7C8084868A959EA2A08D7D7C7F8B94938B796450
3E32271E181A1D20221F1C1C1C1D1F2227313C46515F6B76
7D7A7673706F6E6B67615B554F48423C36322F2C2925221F
1D1D1C1C1C1F20201F1E1C18151619253132312C2A313A43
4C545A60646462605E606163646464646361605F5D5C5B5A
595858585857575656565655555555555454545353525251
514F4E4D4C4A49494848484949494949
6E6F7071727273737372706F6D6D6C6C6B6A6A696A6D7073
736F6A6663615F5D5C5E6061636566686969686767676767
666564636260606061616264666A6D6B69686762626B7EAD
D3D7DADCDBDEE0DFDDDCDBDAD8D2CCC6C1BBB6B1ACA7A29D
989089837F818382848E969791765F5D617281817B68523F
2D241D1613161A1F221E1B1A19191A1C212D3A45525E6973
7A7875726F6E6D6A66615B554F48423C36332F2C2925211F
1D1D1D1D1D1F2020201E1C1817171C2629231F18141B222B
35424F5B6363615F5D5F6163646564646361605E5D5C5A59
585757575656555555555554545454545453535352525151
504F4E4C4B4A49484848484849484848
6E6F70707172727372716F6E6D6C6C6C6B6A6868686C7072
736F6A676362605E5E5F6062636566686968686767676767
6665646362605F6061626365676C6E6D6A686661636B81B7
D7D8DCDCDCDFE0DFDEDDDCDBD9D3CDC8C2BEB9B5B0ABA6A3
9E968E888384858283909A9B94745A595E7283837E6C5845
342A221A16191C2023201D1C1C1B1B1D212D3A46525D6770
767572706E6D6C6965605A554F48423C36332F2C2924211E
1D1D1D1D1D1E1F201F1E1D1B1A1B1D2324211E1A1717191D
263749596565635F5C5E6063656565646362605E5D5B5958
575656565555545454535353535353535353525252515150
504F4D4C4B4A49484848484849484848
6D6E6F707071717272706F6D6C6C6C6C6B696866676B6F72
736F6B686563626060606163646566686868676767676767
6665646362605F6060626467696D6F6D6A686661646C86C1
DCD9DEDDDCDFDFE0DFDEDCDBD9D4CEC9C3C0BCB8B5B0ACA8
A49B948D888787828394A1A49E7D6263697B8A8780715F4D
3D3128201B1C1F2224211F1F1F1E1D1E222E3B47525B646D
7272706E6C6C6B6865605A544E48423C37332F2C29241F1E
1D1D1D1D1E1E1F1F1F1F1E1D1D1E1F2021201E1D1B161314
192C4153626564615D5F6063666565646462605E5C5B5957
565555555454535352525253535353535352525251515150
4F4E4D4C4B4A49484848484848484848
6D6E6F6F70707171716F6E6C6B6B6C6B6B686665656A6F72
74706B686564636261626263646566676868676766676767
6765646362605F5F606365686A6E706E6B696660656E8BC9
E0D9E0DEDCDFDFE0E0DEDDDCD9D4CFC9C5C2BFBCB9B4B0AD
A9A097908A87857F829BB0B9B99B848B9197998B7B716353
44372D241F1F212325232122211F1E1F232F3C47525A6269
6E6E6D6C6B6B6A67645F59544E48423C3733302E2A221C1E
201E1D1D1E1E1E1F1F1F1E1E1F20211E1D1D1D1F201A1514
17243341505C656867656264656464636361605E5C5A5856
555554545353525251525252525252525252515151505050
4F4E4D4C4B4A49484748484848484848
6D6D6E6E6F6F7070706E6D6C6B6B6B6B6B68666464696E71
736F6C696766656463646465656666676767676666676767
6765646362605F60616366696B6E6F6F6C686660677393D0
E2DAE1DEDDE0DFE0E0DEDDDCD9D4CFCAC6C3C1BEBCB8B5B2
AEA49B948D89868083A2BFCCD2BAA7B2B8B2A88F78716859
4B3D322A24222223242322232321202024303C4752595F66
6B6B6B6A69696866635E59534E48423C3733302E2B221C1E
201E1D1D1E1E1E1F1F1E1E1F2021211C1A1C1E22241E1917
181F28313E51626A6E6A64646363636261605F5E5C5A5856
54545453535252515151515151515151515151515050504F
4F4E4C4B4A4948484747474848484848
6C6C6D6D6E6E6E6F6E6E6D6C6B6B6C6C6B69676565696D6F
716F6C6B6969696867686868686766666566666666666767
6665646362616160616467696B6C6D6D6B6866626A7E9FD1
E3DCDFDEDDDFDFDFDFDEDCDBD8D3CECAC6C4C2C0BDBAB7B5
B1A9A19B96928F888AA8C3D3DBCABCC7CBBCAA8D736C6456
4A3D332C272321201F1F20212221212226303C4650575E64
6969696867686765625D58534D48433D3834302A2729291F
181B1E1E1F1E1E1F1F1E1D1E1E1F1F1C1A1B1C1F211F1D1D
1D202428304050606B696664616262605F5F5E5D5C595755
54545454545352525252525151515151515151505050504F
4F4E4C4B4A4948474646474747474747
6A6B6B6C6C6D6D6D6D6D6C6C6B6C6C6C6B69686666696B6E
6F6E6D6C6C6C6C6B6B6C6C6C6B6967656464656666666666
6665646463626261626467696A6A6A6B6B6866646D8AACD1
E3DEDDDDDDDFDFDFDEDDDCDAD7D3CEC9C5C4C3C1BFBCB9B7
B5AEA7A39F9C999193ADC7D6E0D6CDD7D8C3AA8B6F686154
483D342E29231F1C1B1C1D202221222328313C454E555C62
6767676666666564615D58534D49443E39343029252E3120
131A1F1F1F1F1E1F1F1E1D1D1D1D1D1C1B1B1B1C1D1F2121
2121222124303F54656767636061615F5D5D5D5C5C595755
545454555554535353525252515151505050505050505050
4F4D4C4A494847464545464646464646
696A6A6A6B6B6B6C6C6C6C6B6B6C6C6C6C6A686767696A6C
6D6D6D6E6E6E6F6F6F6F6F6F6E6A67646263656666666666
6665646463636362636567696A69686A6B6867677195B8D1
E2E0DCDDDDDFE0DEDDDCDBD9D6D2CDC9C5C4C3C2C0BDBBBA
B8B3AEACAAA7A59D9DB2C7D5DED7D1D8D7C1A78A70686053
483F37322D251E1A17191C1F222223262A333C444C535960
6465656464646462605C57524D48433E3A36322F2B272421
1F1E1E1E1E1E1E1E1E1E1D1D1C1C1C1D1C1B1A19191C1E1E
1D1F211E1F252F475B6165625E5F605D5C5C5C5C5C595655
535455555555545454535252515150505050505050505050
4F4D4C4A494746454445454545454545
68696969696A6A6A6A6B6B6B6B6C6C6C6C6B696868696A6A
6B6C6D6E6F70707071717272706C67636162646566666666
666565646464646363666869696766696B696969749FC4D3
E2E0DADDDDDFE0DEDCDCDBD8D5D1CDC8C5C5C4C3C2BFBDBC
BBB8B6B6B5B3B1A9A7B6C6D1DAD6D2D7D3BDA48971686053
49413A3630271E1815181B1F222325282D343C434A51585E
62636262626262615F5B56524D48433E3A37343330231A22
27221E1E1E1E1E1E1E1E1D1D1C1C1C1E1E1C191716191C1B
1B1E201D1C1D23394D5961615E5F5D5C5A5B5B5B5B585654
5354555656565555545453525151504F4F4F505050505050
4F4D4B4A484745444344444445454444
6767686868686969696A6A6A6B6B6C6C6C6B6A696969696A
6A6B6C6D6E6E6D6D6E6F7172716C67636062646566666565
666565646464646464676969696664686B6B6C6974A6D0D9
E1E0DBDDDEDFDFDDDBDBDAD7D4D0CCC8C5C5C5C4C3C1BFBF
BFBDBCBEBFBDBBB2AEBAC6D0D9D9D8DCD8BFA48A736B6458
4E453D373028201B17191D202325272B2F363D434A50565C
606161616061615F5D5955514C47433E3A3633312D262122
23201F1F1E1E1E1E1E1E1D1D1D1D1D1E1F1D1B19181A1C1C
1C1C1C1A1A1C222D3B4C5A61645E58595A5B5D5A58575654
5354555657565655555453525150504F4E4F4F4F5050504F
4F4D4B49474645444343434444444444
66666767676767686869696A6A6B6B6C6C6B6B6A69696969
696A6A6B6C6B6B6A6B6D7071716C67636062646566656565
656565656465656464676A6A696563676B6D6F6A76ADD9DF
E1DFDBDDDEDFDFDCDADAD9D6D2CFCBC7C4C5C5C5C5C3C1C2
C2C2C3C6C8C7C4BBB6BEC6CFD7DADBDED8BFA48B756E685D
54493F383029221D1A1C1E212426292D32373D43494F555A
5E5F5F5F5F5F5F5E5C5854504B47423E3936332F2C292723
20201F1F1F1E1E1E1E1E1D1D1D1E1E1F1F1E1D1B1A1A1B1C
1C1A18191A1D2223293E5260685D5457595C5E5956565654
53545556575756565554535251504F4E4E4E4F4F4F4F4F4F
4F4D4B49474644434242434344434343
6565656666666666676868696A6B6B6C6C6C6B6B6A6A6968
6869696A6A696868686C6F71716C66626062646566656565
656565656566666564686B6A696462666B70736C79B5E3E3
E0DFDCDDDEDFDFDCD9DAD9D5D2CECBC7C4C5C6C6C6C4C2C3
C5C6C9CED1D1CFC6C0C2C5CBD1D6D8D9D2BAA28C79726B61
584C4239312A241F1C1D1F2225272B2F34383D42484D5358
5B5C5C5D5D5D5D5C5B57534F4A46423D3936332F2C2A2723
2120201F1F1E1E1D1D1E1E1E1E1F1F20211F1E1C1A19191A
1B1817191C1E1F171731495E6B5C5054585C5F5954555654
53545456585756565655535251504F4E4E4E4F4F4F4F4F4F
4E4C4A49474544424242424343434343
646464646565656566666768696A6A6B6B6B6B6B6B6A6968
6768686969686766676A6E70716C66626062646566656565
656565656566666565686B6A696462666C71777583BCE8E4
DEDEDCDDDEDFDEDBD9D9D8D5D1CECBC7C5C6C6C7C7C5C3C4
C6CACED4D8D9D8CFC8C7C7CACED3D5D3CCB7A18E7E766F65
5C50443A312B26211F1F202225282C3034383D41454B5054
58595A5A5B5C5C5B5A56524E4A46423E3A3734302D2A2824
2121201F1F1E1E1D1D1D1E1E1E1F202121201E1C1A181719
1A1716191C1E1D0F0C264058695B4E54575B5E5854555654
53545556575757575655545251504F4E4D4E4E4F4F4F4F4F
4E4C4A48474544424242424343434343
63636363646464646465666768686969696A6A6A6A696868
6768696969686867686B6D6F6F6A66626062646566666666
66666665656667676767676A6A6663686E6E788E9FC2E3DF
DBDEDEDEDEDFDFDCDAD9D8D5D2CECBC8C6C6C7C7C7C5C4C5
C7CBD0D6DBDDDCD5D0D0D0D4D6D6D4CFC7B5A393847B7269
5F52453B312C27232020212225272A2E3236393D41464B4F
52545657585A5B5B5A5754504D4946423E3A37332F2C2824
222120201F1E1E1D1D1D1E1E1E1F2020211F1D1C1A191819
19171517191919121224374B5B59565655575A5A5A585654
53545555555656565655535251504F4E4E4E4E4E4F4F4F4E
4E4C4A49474645434343434444444444
626262626363636363646565666667676868686868686868
686869696A696968696A6C6D6D6966636163656667676767
6767666565666768686664696B686669706C7AA7BAC8DDD9
D9DEDFDFDEDFE0DDDBD9D8D5D2CFCCC9C7C7C7C7C7C5C4C5
C7CCD1D8DDDEDEDAD6D8DADDDEDAD4CDC3B5A7988A80766C
6154473C322D2925222121222426292C2F3236393D414549
4D50525456585A5B5A5855524F4C4946423E3935312C2825
222120201F1E1E1D1D1D1D1D1E1E1F20201E1D1B1A1A1A19
19171516161516171A232E3E4C575E585354555B605A5654
53545554535455565654535250504F4E4E4E4E4E4E4E4E4E
4D4C4A49484645444444444545454545
616161616262626262636364646565666666676767676868
6868696969696969696A6B6B6B6865636263656667686868
6867676665666768696562696C69686A736C7DBBD1CDD8D6
D6DEE1DFDEE0E0DEDCDAD8D5D3CFCCC9C7C7C7C7C7C5C3C4
C6CCD2D8DDDFE0DDDBDFE3E6E6DFD6CDC3B7AB9E91867B71
6557493C322E2B27252322222425272A2D3033363A3D4145
484C4F515456585A5A585553504E4B4845403B37322D2925
222121201F1E1E1D1D1D1D1D1E1E1F1F1F1E1D1B1B1B1C1B
1A1715131313151A1F212632405462595150515C645C5655
53545553515355555654525150504F4F4E4E4E4E4E4E4E4D
4D4C4A49484746454545454546454545
606060606161616161626262636364646465656666676768
686869696969696969696969696765636264656667686969
69686766656667696A6461696D6B6A6B747085CBE0D1D5D4
D6DFE2E0DEE0E1DEDCDAD7D5D3D0CDCAC8C7C7C6C6C4C3C3
C5CAD1D7DCDEDFDFDFE4E8EBEBE2D8CFC5BCB1A5988C8075
68594A3D322F2C2927252322232426282B2D3034373B3E42
45494C4F5255575959575553504E4C4946413C37332E2A25
22212120201F1E1D1D1D1D1D1D1E1E1E1E1E1D1C1B1D1E1C
1B1815121111141D231F1F28344F62595150505D655D5655
54555552505254555554525150504F4F4E4E4E4E4E4E4D4D
4C4B4A49484847464646464646464646
5F5F5F5F6060606060616161626262636364656566676768
686868686868686868686868676664636364666768696A6A
6A686766656566686A6664696D6D6E6B6F7B99CBDAD3D8D7
D9E0E3E2E0E0E0DDDBD8D6D4D2CFCCCAC8C7C6C5C4C2C1C1
C2C8CED4D9DCDEDFE0E3E6E7E6E0DAD4CCC3B9AEA1938578
6A5A4B3D32302E2C2B27242222232526292C2F33363A3E41
45484B4E515356575755524F4C4A4845413D3935322E2A26
24222120201E1D1D1C1D1D1D1D1E1E1F1F1E1D1C1C1D1D1D
1B181513111214191E1C1D232D4456575756545B5F5B5857
565554514F5153555554525150504F4F4E4E4E4E4E4D4D4C
4C4B4A49494847474747474747474747
5E5E5E5F5F5F5F5F5F606060606161616263646565666768
686868686767676767666666656564646465666768696A6A
6A696766656565686A67666A6D6E716B6B88ADC9D2D4DBDB
DCE2E4E3E2E1DFDCDAD8D6D3D1CECCC9C7C6C4C3C2C0BFBE
C0C5CBD0D5D8DBDEE0E1E1E1E0DFDCD8D3CBC2B7AA9A8A7B
6B5B4C3D3331302F2D28242221222325272B2E32363A3E42
46494B4D5052545555524E4B484543403D3A3633302D2A27
25232221201E1D1D1C1C1D1D1D1E1E1F1F1E1D1D1C1D1D1D
1C19161312121416191A1C1F273848555D5B585958595A59
585553504F5153545553525150504F4F4F4E4E4E4D4D4C4C
4C4B4A4A494848474747474748474747
5D5D5E5E5E5E5E5E5F5F5F5F5F5F60606162636465666768
686867676767676666656564646464646465666768696A6B
6B696766666565676968686A6D70746C6A92BCC9CFD6DCDD
DFE3E5E5E4E2E0DDDBD8D6D3D0CDCAC7C5C3C1C0BFBDBCBB
BCC0C4C9CDD1D5D9DCDDDEDDDCDEDEDDDAD3CABFB2A18F7E
6E5D4D3E33323231302A24222020212325292E33383C4145
494B4C4E4F515253524F4B4844423F3C393634312F2C2A27
25242221201E1D1C1C1C1D1D1D1E1E1E1F1E1E1D1D1D1E1E
1D1A16141213141617191A1B1F2E3E52605E5B5753575B5A
595552504F515354555352515050504F4F4E4E4D4D4D4C4C
4B4B4A4A494948484848484848484848
5D5D5D5D5D5E5E5E5E5E5E5E5F5F5F5F6061626364656767
686867676666666666656463636364646566666768696A6B
6B6968676665656769696A6B6D71756D6F9EC5C6CCD7DCE0
E2E4E5E6E6E3E0DEDCD9D7D4D0CDCAC7C4C1BFBEBCBAB9B8
B8BCBFC2C6CACED4D8D9D9D9D9DDDFE0DFD9D0C7BAA89583
715F4F3F34333332312A24211F1F202123282E33393E4348
4B4C4D4E4E4F50504F4C4845423F3C383633322F2D2B2927
252322211F1E1D1C1C1C1D1D1D1E1E1E1F1E1E1E1D1D1E1E
1D1A17141314151516181A181A25334C5F5F5C5550565B5A
585551504F515254555352515050504F4F4E4E4D4D4C4C4B
4B4A4A4A494949484848484848484848
5C5D5D5D5D5E5E5E5E5E5F5F5F5F5F606061626364656667
676767676667676766656564646464646565666767686869
6A6968676767676666696C6C6A70706F85ACBDC0D1DADBE0
E2E2E3E5E5E2DFDDDBDBDAD9D7D4D1CECBC7C3BFBCBAB8B8
B8BBBFC2C5C8CBCFD3D6D8D9DADDDEDFDDD9D2CBC0B09E8B
78655342363332312F2923201E1E1F2123282D32373C4146
494B4B4C4D4E4E4E4D4B4845423E3B373432302E2C292725
232221201F1E1D1D1D1D1D1D1E1E1E1F1F1E1E1D1D1D1D1D
1C1A1715131415151517191819202B405257595754565856
54525150515253545554525150504F4F4E4E4D4D4D4C4B4B
4A4A4A49494948484848484848484848
5C5D5D5D5E5E5E5F5F5F5F5F5F5F60606061626364656666
676767676767676767666665656565656565666667676768
6968686868696A6564696E6C686F6C719CB8B3B9D5DDD9E0
E2E0E2E4E5E2DEDDDBDDDEDDDCDAD7D4D0CBC5C0BCB9B7B6
B7BABDC0C2C4C6C9CCD1D6D9DBDCDCDCDBD8D4CEC6B7A794
806A57453834322F2C27221F1D1D1F2023282D31373C4045
48494A4B4B4C4C4C4B494745423E3A3532302E2C2A272523
2120201F1F1E1E1D1D1D1D1E1E1E1E1F1F1E1E1D1D1C1C1C
1C1917151415161515171918191C2334434D555858575452
4F505151525354555554525150504F4F4E4E4D4D4C4C4B4B
4A4A4949494848484747474848484747
5C5C5D5D5E5E5E5F5F5F5F5F606060606162626364646566
666667676767676767676666656565656565656666666566
67686969696B6B64636A6F6D666E6A74AEC3ADB3D7DFD8E1
E2DFE0E3E5E1DEDCDBDDDEDFDEDBD7D4CFC9C3BCB7B5B3B3
B3B5B7B9BBBCBCBEC1C8CFD4D9DADADBDBD9D6D2CBBEAF9B
86705A483A35312D2A25201D1C1C1E2023282D33393F4449
4C4C4B4B4A4A494847464544423D38332F2E2C2A28262321
201F1F1E1E1E1E1E1E1E1E1E1E1E1F1F1F1E1D1D1C1C1C1C
1B1917161516161515181A1919181B29374652575956524E
4C4E5152545455555654535251504F4E4E4D4D4C4C4B4B4A
4A494949484847474747474747474747
5C5C5D5D5E5E5E5F5F5F5F60606060616162626364646565
666666676767676767676766666665656565656566656465
6668696A6A6D6D6462696F6C646E6A7ABCC7A5AED7E0D7E1
E3DEE0E3E5E2DFDDDCDEE0E0DEDBD7D2CDC6BFB8B2AFAEAD
ADAEB0B1B2B2B2B3B6BFC8D0D6D7D8DADADAD8D6D0C5B6A2
8C745E4B3C35312C28231F1C1B1B1D1F22282E343A41464B
4F4D4B494746454341424242403B36312D2C2A282624211F
1E1E1E1E1E1E1E1E1E1E1E1E1E1F1F1F1F1E1D1D1C1C1B1B
1A1918171617171515181A1A1916161F2C3D4C5559554F4C
4A4E5253555555565654535251504F4E4D4D4D4C4C4B4B4A
4A494948484747474747474747474747
5B5C5D5D5E5E5F5F5F5F6060606060616162626363646465
656666666767676868676767666665656565656565646364
6567696A6B6E6E6562676C67636D728BBBBA9DB0D6DCD7E0
E2E0E2E6E9E8E6E6E5E4E3E1DDD8D3CDC6C0B9B2ACA8A5A4
A4A3A3A2A3A4A7A9ADB7C2CBD2D5D7DADCDCDBD9D4CABCA6
8F775F4D3E36312C28221E1B1A1A1C1E21282F353C42484E
504D4945413E3C3837383A3B3B37332F2C2A282624221F1D
1C1C1D1D1E1E1E1E1F1F1F1E1E1F1F1F1F1E1D1D1C1B1B1A
1A19181817171817171718181816161B2333424C53514D4D
4E515454545555555554535251504F4E4D4D4C4C4B4B4A4A
49494848484747474646464747474646
5B5C5C5D5D5E5E5F5F606060606060616162626363636464
656566666767676868676767666666656565656565636363
64676A6B6C6F6E6762656863626D7A9BB9AC97B2D5D9D7DF
E2E2E4E8ECECEBEBEAE7E4E0DBD5CFC8C0B9B1AAA39E9A98
9796969596999DA1A7B1BCC6CFD2D5D9DCDDDDDCD8CFC1AB
9279614F3F37302B27221E1B1A1A1B1D21272D333A40464B
4D48433E3936322E2D30333536332F2D2A28262422201D1C
1B1B1C1D1D1E1E1F1F1F1F1F1F1F1F1F1F1E1D1C1C1B1B1A
1A1919181818181919171616161718171B2938444D4C4B4F
51545555545555555454535251504F4E4D4C4C4C4B4B4A49
49494848474747464646464646464646
5B5B5C5D5D5E5E5F5F606060606061616162626263636464
646566666767686868686767676666656564646464636262
63666A6C6D6F6F6862646662636C7CA6BBA18FB4D5D6D7DD
E0E1E3E8EBEAE8E7E5E3E0DCD7D4CFCAC3B8AEA49B948E8B
8A8C8F9295999EA2A8B2BCC6CDD0D3D7DADCDDDEDBD3C6AF
977D64514137302A25211E1C1B1C1D1F2124282B2E333639
3A3734312E2B292625292D2F312F2C2A28262422201E1C1A
191A1B1C1D1E1E1F1F1F1F1F1F1F1F1F1E1E1D1C1B1B1A1A
191919191919191A1A1715151618181313202E3C48494A50
54565755545555555453535251504F4E4D4C4C4B4B4A4A49
49484847474746464646464646464646
5B5B5C5C5D5D5E5F5F5F6060606061616162626263636364
646565666767676868686767676665656464646463626261
62666A6C6E706F6A65646362676F82ACBC998CB8D5D5D8DD
DFE1E2E7E9E6E3E1DEDDDBD7D3D0CCC7BFB1A3968B827C77
767C848B92969A9FA5AFB9C1C9CBCED2D6DADDDFDED7CAB5
9C8268554439302924211F1D1C1D1F202222222323252729
29282625242221202024282B2D2B2927252422211F1D1B19
18191B1C1D1E1E1F1F1F1F1F1F1F1F1F1E1E1D1C1B1B1A19
191919191919191B1B171414151819110E19263543464951
56575756545555545353535251504F4D4C4C4C4B4B4A4A49
49484847474646464545454545454545
5A5B5B5C5C5C5D5D5E5E5F5F606061616262626363636464
646565666667676767676666666565646463636363626261
6265696C6F6F6E6E6C6560656D8599A4BA9D94BFD9D7DDE0
E2E1E0E2E3DFDCD8D6D7D7D5D1C9C0B7AA968272645D5953
535F6C798587898E949EA9B2BABFC4CACFD6DBE0E1DBD0BD
A78B715B493C322822201E1E1E1E1F2122201E1D1D1D1E1F
1F1F1F20201F1F1F2024292C2E2A2623202020201F1D1B1A
191A1B1C1D1D1E1F1F1F1F1F1F1F1F1F1E1E1D1C1B1B1A19
181919191919191A1A16141414161612111A25313E454C52
56565555555454535252525251504F4E4D4C4C4B4B4A4A49
49484747464645454545454545454545
5A5A5A5B5B5B5C5C5C5D5E5F606061626263636363646464
646565666666666666666665656464646363626262626261
6165696C6F6D6C7173665F6C7596A699BAA19BC5DCD9E2E3
E3E1DDDDDCD6D1CBC8CCCECDC9BDB0A4947B624E3F3A3932
3444576A7978777A7F8B97A1AAB2B9C1C9D2D9E0E2DDD4C4
B09479624D3F3328211F1E1E1F1F2021211E1B1917171717
17191A1C1D1D1D1E2025292D2E29231F1C1D1F1F1F1D1C1B
1A1B1C1C1D1D1E1E1F1F1F1F1E1F1F1F1E1D1D1C1B1A1A19
18181818181818191916141414141414151B232D39444E53
56555355555453525152525251504F4E4D4C4C4C4B4A4A49
49484746464545444444444444444444
5A5A5A5A5A5A5A5B5B5C5D5E5F6061626363636363646464
646565656666666666656564646463636262626161626261
6165686C6F6C6A737968617884989B90C6A59EC9DCD9E5E5
E3E0DAD9D5CBC2B9B4B8BCBBB7AB9D91806348332322231C
1F334960716962616473838F9BA5AFBAC4CED7DFE2DED6C9
B69B7F6751423528201E1E1E1F1F1F20201E1B1917171717
17191A1B1C1C1C1C1E23282C2E28211D191B1D1E1E1D1C1C
1B1C1C1C1D1D1D1E1E1E1E1E1E1F1F1E1E1D1C1C1B1A1919
18181818181818181816141313131316191C212933435155
57545254555352515151525151504F4E4D4D4C4C4B4A4A49
49484746464544444344444444444444
59595959595959595A5B5D5E5F6061626363636364646464
646565656565656565646463636363626262616161626261
6264676C6F6B69737B6B658591968C84C7A5A1CDDCD9E7E4
E2DDD6D3CDBEB0A49B9EA09F9B8F8279694D321E1012150E
10263E57685B4F4B4C5E717E8C99A5B2BFCAD4DCDFDDD6CB
BA9F846B544436291F1E1E1E1F1F1F20201D1B1918181818
19191A1B1B1B1A1A1C21262A2B251F1B181A1C1D1E1D1C1C
1C1C1C1D1D1D1D1D1E1E1E1E1E1E1E1E1E1D1C1B1B1A1918
181817171718181817161413121213181C1C1F242E425256
57545053555351505051525150504F4E4D4D4C4C4B4A4A49
48484746454444434343434343434343
5959585858585858595A5C5D5F6061626363646464646464
646565656565656564646363626262616161616161616262
6264666B6E6C6C71746E708E998A7775AF93A3D1E1DAE4E0
DCD8D1CCC2AC9784746F6B645E5A56554F3A271C14171A12
12263A52615244404052657281909EADBAC5CED5D8D6CFC5
B69D836B55453729201E1F1F201F1F201F1D1A1816161717
1716161717161616171A1D20211F1C1B191A1C1C1D1C1C1C
1C1C1C1D1D1D1D1D1D1E1E1E1E1E1E1E1E1D1C1B1A1A1918
1817171717181818171614131213141A1D1A1A1E273F5356
57534E525452504F4F505151504F4F4E4D4D4C4C4B4B4A49
48474746454443434242424343434343
5858585757575757585A5B5D5F6061636464646464646464
646464656565646464636362626261616061616161616162
6364666A6E6E6F6E6D717B959C7E6566927FA1D2E2DAE1DB
D7D4CDC6B9A0866F594C41342D2F3237382C211E1C202319
1625364A56493D393A4A5C69778898A7B5BFC7CED0CEC7BF
B19A826B5646382A2120202021201F1F1F1C1A1817171717
17161515141414141415161718191A1B1C1C1C1B1B1C1C1C
1C1C1C1D1D1D1D1D1D1D1E1E1E1E1E1E1E1D1C1B1A191918
1717171717171818171514131314161B1E181519223C5357
58524D5154514F4E4E5051504F4F4E4E4D4D4C4C4B4A4A49
48474645444443424242424242424242
585757575656565657595B5D5E6061636464646464646464
646464646464646463636262616161606060616161616162
646465696D6F716D69748194987D65576E6A9ECEDED7DEDA
D7D3CAC1B4A08A76614F3E2E232224272A231F212427281C
141C25333E3936393E49565F6C7E90A0AEB8C0C7C9C6C0B8
AC97816B57483A2C2221212121201F1F1F1D1B1A191A1A1A
1A19181716161616151413121216191B1D1C1B1B1B1B1C1C
1C1C1D1D1D1D1D1D1D1D1D1E1E1E1E1E1E1D1C1B1A191818
1717171616171817171514131314171D201813141D3A5357
58514B5053504E4D4E4F51504F4F4E4D4D4C4C4B4B4A4A49
48474645444342424141414242424141
575656565555555556585A5C5E5F61626364636363646464
646464646464646363636262616161606060616161616163
646566686B70726A6677868F8E7661494F5796C3D5D3DBDA
D8D3C9C0B4A59583715B463224201F1F211F20262A2D2C1F
15161A242D30353D464C545B65778A99A7B1B8BEC0BDB7B0
A6937F6B57493C2E2523222222201E1E1E1D1D1D1D1E1F20
201E1D1B1A1A1A191916131111151A1D201E1C1C1B1B1C1C
1C1D1D1D1D1D1D1D1D1D1D1E1E1E1E1E1E1D1C1B1A191817
1717161616171817171514131315171E211811121B395257
58514A4F524F4D4D4D4F504F4E4E4D4D4C4C4B4B4B4A4949
48474645444342414141414141414141
555554545454555556585A5B5D5F60626363636363636363
636363636463636363636262626161616161616262626262
64676969696D6D65687F8B877A604B3D485082AAC1CADADB
DAD4CBC6BFB5A99C8C765F49372D251F1B19181C20222218
12151B2631353B454D52585E66768694A0A9AFB5B7B3ADA7
9D8C7A69584A3E3229262523221F1D1D1D1E202225272A2C
2D2A282523222221201E1C1B1B1E20222322201E1D1D1D1C
1C1C1C1D1D1D1D1D1D1D1E1E1E1E1E1E1E1D1B1A19191817
1616161616171818171514131214161C1F1814161F3A5258
5A544D51524F4D4D4D4E4F4E4D4D4C4B4A4A4A4A4A494948
47464544434342414141414141414141
53535353535454545557595B5D5E60616262626262626262
626363636363636363636362626261626262626263636362
63696C6A676B69606C858D7C644B3833414A6C8FA9C0D6DC
DCD6CDCDCAC4BCB4A7927C665244372C241F1D1F2122221B
181E25313B40454E55595E626977848F99A1A7ACADA9A39D
94857667584C41362D2A2725231F1D1C1C2024282C303337
393633302D2C2B2A2827272626262727272523211F1E1D1C
1B1C1C1D1D1D1D1D1E1E1E1E1E1E1E1E1E1C1B1A19181717
1616161616171818171614131213151A1D19171A233B5158
5B56505252504E4D4C4D4E4D4C4B4A494949494948484847
47464544434242414141414141414141
51515252535353545557585A5C5D5F606161616161616162
626262636363636363636363636261626362626363646462
636A6F6B6569655C6E8A8E70503B2C2B3541577492B4D1DB
DED6CDCFCFC8C0B9AF9F8F7E6F665D554E4844434242413C
393F465057555456595D63676E78838C959B9FA3A4A09A94
8B7F7265584D443A322D2A2724201D1C1C21262B31353A3E
413F3C3A38383735343332302F2E2C2B29272523211F1E1C
1B1C1C1D1D1D1D1E1E1E1E1E1E1E1E1E1D1C1B1A19181716
161616161617181818161413121315181B191A1E263C4F57
5C57515251504E4D4C4C4D4C4B4A49484747474747474747
46454544434242414141414141414141
4F50505152525353545658595B5D5E5F6060606060606161
616162626263636363636363636262636463636364646562
636B716C6368635B748C87623D2E25262C38435A79A4C7D7
DED6CDD1D2CBC4BDB6ADA3978D87817B766F696562615F5B
585E646A6E67605D5C61676B717A82899095989B9B98928C
847A6F64594F463D36312D2A27221E1C1D22282D33383C41
444342414040403F3E3C3A383633302D2A28262422201E1C
1B1C1C1C1D1D1D1E1E1E1E1E1E1E1E1E1D1C1B1A19181716
161616161717181818161413121315171A1A1C20283B4C55
5B565151504F4E4D4C4C4C4B4A4948464546464646464646
46454443434242414141414141414141
4E4E4F5051515253545657595A5C5D5F5F60606060606060
606161626262626363636363636262636463636363656662
636B706C646A646285886D51332A2826292D33445E8AB1CB
DCD6CFD1D0CDCAC5BFBAB3ACA49C958E88837F7B78767470
6D6D6D6E6E6864626163676A6F767E858B8F929596938F89
82796F655B5249403935312D2A25211F1E2125282C2F3236
393B3C3E3F41434343403C3935312E2A2726252322201E1D
1C1C1C1D1D1D1D1E1E1E1E1E1E1E1E1E1D1C1B1A19181716
151616161717181818161413131315171A1B1D2128384751
57534F4E4C4D4E4D4D4C4C4B494846454444454546464646
45454443424242414141414141414141
4C4D4E4F5050515253555658595B5C5E5F5F5F5F5F5F5F5F
606061616162626262636363636262646463636263666763
636A706D656C6669948254412A282C272523273449729BBE
D7D5CFD0CECDCCC7C3C1BFBBB6ADA49D9693908C8986827F
7B76716D6A676563636466696D737A81878B8E91918F8C87
817970675E554C443C3835312E292522202123242627292B
2E3135383B3E4143433F3A36322F2B272424232221201E1D
1C1C1D1D1D1D1D1E1E1E1E1E1D1E1E1D1D1C1A1918171716
151516161617181818161514131416171A1B1D212734414B
524F4B4A484B4D4E4E4D4B4A484645434243444445454545
45444343424241414141414141414141
4B4C4D4E4F50505153545657595A5B5D5D5E5E5E5E5E5F5F
5F6060616161626262626263636363646463636262666863
626A706E656E676EA17D3E321F212A231F1D202C406288AE
CBCDCCCCCACAC8C3BFC1C2C1BFB7AEA69E99948D87817C78
746F6A65625F5E5D5D5F62666A71787E84878A8C8D8B8884
7F78706860584F47403C3935322D29262323232324242526
27292B2E30323435363432302D2B292725242322211F1E1D
1C1C1D1D1D1D1D1E1E1E1E1D1D1D1D1D1D1C1A1918171616
15151616161717181816151414151617191B1E2126313C46
4D4B484645494C4E4F4D4B49474544424142434444444445
44444343424241414141414141414141
4A4B4C4D4E4F50515253555657595A5B5C5C5D5D5D5D5E5E
5E5F60606161616262626262626262636463626262666863
62696F6E666E6772A5773027191D291F1B191E293B57789F
BEC5C8C9C6C6C4BEBABEC1C2C1B8AFA79E9891888079726E
6A65615D595959595A5D60646971787E8486888A8B898783
7E78716A635B534B45413E3A37322E2B2826252424232222
2223242526272728292929282827262524232221201F1E1D
1C1C1D1D1D1D1E1E1E1E1E1D1D1D1D1D1C1B1A1918171615
15151616161717181817151514151617191B1E20242C343E
4544434241464B4E4F4D4A48464543424142434344444444
44444342424241414141414141414141
4A4B4C4D4E4E4F5051525355565758595A5B5B5C5C5D5D5E
5E5F5F606061616161616161616160616261616162656763
62686D6B6469646F936E382A1A1D241B181A202C3D567498
B6BFC3C5C4C3C0BAB5B6B7B6B3ABA199918A837B746D6662
5F5D5C5A5A5A5B5D5F62666A6F767D83888A8B8C8B8A8783
7E79736C665E57504A4643403C393633312F2D2B2A292827
26262524242423232324242525252424242321201F1E1E1D
1C1D1D1D1E1E1E1E1E1E1D1D1D1D1D1C1C1B1A1918171616
1515161616171717171716151516171819191A1B1E232A31
383A3C3E4045494C4D4B4948474544434243444444444444
44434342424241414141414141414141
4A4B4C4C4D4E4F4F50515253545556575859595A5B5C5C5D
5E5E5F5F6060616161616060605F5F5F6060606162646663
62676A686363606B7F66422F1D1D2019171C232F3F567092
AEB9BFC3C3C2BFB8B2B1AFACA79E958D857E78716B645E5A
58595A5B5D5E606265696D71767D83888D8E8E8E8D8B8884
7F7A746F68625B55504C484542403E3C3A373533312F2E2D
2B292726242221202020212222232323232221201F1E1E1D
1D1D1D1E1E1E1E1E1E1E1D1D1C1C1C1C1B1A191818171616
1515161616161717171716161617181919181716171B2025
2B3035393E43474A4B4A4848474645454444454545454444
44434343424242414141414141414141
4A4B4C4C4D4D4E4F4F50515252535455565758595A5B5C5D
5D5E5E5F5F60606060605F5F5E5D5D5D5E5E5F6061636463
6266686562605E6A715E47332121211B191D242D3B516A8C
AAB6BFC4C5C6C4BEB8B6B2AEA89F958C847E7A75706A6561
5F6061626466696C6F7276797D83898D919190908E8C8985
817C77716B655F5A55514E4A48474644433F3B383533312F
2D2C2A2927262423222222222221212121201F1F1E1E1E1D
1D1D1E1E1E1E1E1E1E1E1D1D1C1C1B1B1A1A191817171616
1515161616161617171717171718191A191614121114171B
1F262D343B4045484A494847474646464545464545454444
43434343424242414141414141414141
4B4B4C4C4C4D4D4E4F4F50505151525354555658595A5B5C
5D5D5E5E5F5F6060605F5E5E5D5C5B5B5C5D5E5F61626362
62656663625E5E6865584C372725231D1B1E242B384C6486
A4B3BFC6C9CBCAC6C1BDB8B3ACA2988E8783807C7974706D
6B6B6C6D6F7174777A7C7F82858A8F9295949392908E8B87
837E79746E69645E5A56534F4D4D4D4D4B47423F3B393634
31302E2D2B2A28272625242322212120201F1F1F1E1E1E1E
1E1E1E1E1E1E1E1E1E1E1D1C1C1B1B1A1A19181817171616
1516161616161616161717171718191A1915110F0E0F1113
171F272F363D42474A494747464747474747464646454444
43434343424242414141414141414141
4A4B4B4C4C4C4D4D4E4E4E4F4F5050515253555658595A5B
5C5D5D5E5E5F5F5F5F5E5D5D5C5B5A5A5A5B5D5E5F606161
6164666564636369665749382A28261F1B1F252C3745597A
9AAEC0CAD0D4D4D1CDC9C4BFB8AEA49A93918F8C8985827F
7D7C7C7C7D7D7E808184878A8D91949799989694928F8D89
85807B76716C68635F5B575452535354534E4A4643403E3B
393633312F2C2A282626252524242423232221201F1F1E1E
1E1E1E1E1E1E1E1F1E1E1D1C1B1B1A1A1919181817171616
161616161616161616161616171818191915121110111315
181C21262D3842494E4B4847464748474747474746454443
43434343424242414141414141414141
4A4B4B4B4C4C4C4D4D4D4D4D4E4E4E4F505253555758595B
5C5C5D5D5D5E5E5F5E5D5C5C5B5A5959595A5C5D5E5F6060
616366666768696A6757473A2F2D2B211C20262D373F4F70
91AAC0CDD5DADCDAD7D3CFCAC4BAB1A8A2A09F9E9C989593
918F8D8C8B8A89898A8C8F929597999B9C9A989693918E8B
87827D78746F6B67635F5C585658595A5955514D49474542
403C3936322F2C2A282828272727262625242321201F1F1E
1D1E1E1E1F1F1F1F1F1E1D1C1B1A1A191918181717171616
161616161616161616161616161718181816141212141618
1A1A1B1E2433414B514D4847454648484848474746454443
43434342424242414141414141414141
4A4A4B4B4B4B4C4C4C4C4C4C4C4C4D4D4E5052545657595A
5B5C5C5C5D5D5E5E5E5D5C5B5A59585858595B5C5D5E5E5F
61636567696C6C6A6557493E35322F251F23282E373C496A
8BA6BECBD4DADCDAD8D6D3D0CCC4BCB5B0AFAFAFAEACA9A7
A4A29F9D9B9895949395989A9C9E9FA0A09D9A989593908D
8A85807B76726F6B6763605C5B5D5F60605C5753504E4C49
46423F3B3834312E2C2B2B2A2A2929282725242221201F1E
1D1E1E1E1F1F1F1F1F1E1D1C1B1A19191818171717171616
16161616161616161616161616171717171614131315181A
1B1817171C2E3F4B534E4946444648484948484747454443
42424242424242414141414141414141
4A4A4A4A4B4B4B4B4B4B4B4B4B4B4C4C4D4F515355565859
5B5B5B5C5C5C5D5D5D5C5B5A5959585858595A5C5D5D5D5F
616365686A6E6F6A65594C443C38342A24272C30363A4565
85A2BBC9D3D8DAD9D7D7D6D5D2CCC5C0BCBCBDBDBCBBB9B7
B4B0ACA9A6A29E9B9A9C9EA0A1A2A2A2A19F9C999694928F
8B86817C7874716E6A6663605E60636464605B585452504D
4A47433F3B3834312F2E2D2D2C2B2A292826242321201F1E
1D1E1E1E1F1F1F1F1F1E1C1B1A1A19181817171717161616
16161616161616161616161616161717171615141417191B
1B17131317293C4A534E4846444648484848484747464443
42424242424241414141414141414141
4949494A4A4A4B4B4B4B4B4B4B4B4C4C4D4F515254565759
5A5A5A5A5A5B5B5B5B5B5B5A5A5A5A595A5B5C5D5E5E5E5F
61636567696C6C69655E554C443C362F2B303533353A4663
819EB7C6D1D5D6D5D4D5D5D5D4CEC8C4C0C0C0C0BFBDBBB8
B6B2AEAAA7A29F9C9A9C9E9FA0A0A0A0A09D9A989593918E
8B86817D7975726E6B67646160616363635F5A5753514E4B
4845413E3A3734312E2D2C2B2B2928272625232221201F1E
1D1E1E1E1E1E1E1F1E1D1C1B1A1919181717171717161616
161616161616161616161616161617171716141313151718
18161414172736444E4B4745434547464647474747464443
43424242414140404040404040404040
48484949494A4A4A4B4B4B4B4B4B4C4C4D4F505254555758
59595959595959595A5A5A5A5B5B5B5B5C5D5D5E5F5F5F60
6164666768696A6966635E554C42393533393D36333B4862
7F9AB3C4CFD3D3D2D0D3D4D5D4CFCAC6C2C2C2C1C0BDBBB8
B5B1ADA9A6A29E9B9A9B9C9D9E9E9E9E9E9B99969492908E
8A86817D7975726E6B68656361616262615D5855514F4C49
46433F3C393532302D2C2B2A2928272625232221201F1E1E
1D1D1E1E1E1E1E1E1E1D1C1B1A1918171717171716161616
161616161616161616161616161717181716141312141516
161515151924303D48474543424445454445464646464444
4342424141403F3F3E3F3F3F3F3F3F3F
474848484949494A4A4A4A4B4B4B4C4C4D4E505253555657
585858575758585858595A5B5B5C5C5D5E5E5F5F60606061
62646667686868686868655D53473C3A3A414539333C4A61
7C97B1C4D1D4D4D3D2D5D7D7D6D1CCC8C4C4C4C2C1BEBBB9
B5B1ADA9A5A19E9B999A9B9C9D9D9D9D9C9A989593918F8D
8A86827E7976726F6B696664626261615F5B5754504E4B48
45413E3A3734312E2C2A2A292827262524232221201F1E1E
1D1D1D1E1E1E1E1E1D1C1B1A191918171717161616161616
161616161616161616161616171717181816141312141515
1516161619212B3843444442414344434344454646454544
43424241403F3F3E3D3E3E3E3E3E3E3E
4747474848484949494A4A4A4B4B4B4C4D4E505153545556
57575656565656565758595B5C5D5E5F6060606060606161
6264666767676668696C6B645B4E434141474A3B323D4D62
7B97B0C4D2D4D4D4D3D6D7D8D7D2CDC8C5C4C4C2C0BDBAB8
B5B1ACA8A5A19E9B999A9A9B9B9B9B9B9A98969492918F8D
8A86827E7A76726F6B696765636261605E5A5653504D4A47
44403D393633302D2A29292827262524232221201F1F1E1D
1D1D1D1D1D1D1D1D1D1C1B1A191818171616161616161616
161616161616161616161616171717181816141313141515
15161717191E26333E414241404243424142444546454544
43424241403F3E3D3C3D3D3D3D3D3D3D
46464747474848494949494A4A4B4B4C4D4E4F5152535455
56565555555555555557595A5C5D5E606161606161616161
62646667676665686B6F706B655D554F4A4B49362C3C4F66
8099B1C3D0D2D2D1D0D3D5D6D5D0CCC7C4C4C4C2C1BFBCBA
B7B3AFACA8A5A29F9D9D9D9C9C9C9B9A9998969593918F8D
8B87827E7A77736F6C6A68666463615F5D5A5754514E4B49
46423E3B3835322F2C2B2A2927262524232221201F1E1E1D
1D1D1D1D1D1D1D1D1D1C1B1A191817171616161616161616
161616161616161616161616171717181816151413151616
16171816171B212E3A3E4141404142404041434546454544
434241403F3E3D3C3B3C3C3C3C3C3C3C
4546464647474748484949494A4A4B4B4C4D4F5051535455
55555454535353535456585A5C5E5F616261616161616161
61646667676564686D7173706D6A655B524E4732273B536C
869DB2C3CED0D0CFCED1D4D4D3CFCAC6C3C3C3C2C1BFBDBB
B8B5B1AEABA8A5A2A09F9E9E9D9C9B9A999796949391908E
8B87837F7B7773706D6B69676563615F5D5A5754524F4D4A
4744403D393633312E2C2B2A28272524232221201F1E1E1D
1D1D1D1D1D1D1D1D1D1B1A19181817161616161616161616
161616161616161616161616171717171816151514161817
1718181616181D2A373C40403F4141403F41434546454544
444241403F3D3C3B3B3B3B3B3C3C3B3B
454545464646474748484849494A4A4B4C4D4E4F51525354
54545352525252525255585A5C5E60626362626161616261
61646666666362686D727574737472655950462F253D5871
8CA1B3C3CED0D0CFCED1D2D3D1CDC8C4C1C1C1C1C0BEBCBA
B8B5B2AFACA9A6A4A2A09F9E9C9B9A99979695949391908E
8B87837F7B7773706D6B69686663615E5C595754524F4D4A
4844413D3A3734312F2D2C2A29272624232221201F1E1E1D
1D1D1D1D1D1D1D1D1C1B1A19181717161616161616161616
161616161616161616161616171717171817161515171918
1819191715151926333A3F3F3F40403F3E40424446454444
4342413F3E3D3C3A3A3A3A3B3B3B3B3B
44444545454646464747484849494A4A4B4C4E4F50515253
5353525151505050515457595C5E60626362616160616160
60636566666362676B6F7374757978695A50453028415E78
92A5B5C4CED0D0CFCDD0D2D2D0CCC7C3C0C0C1C0BFBDBBBA
B8B5B2AFACAAA8A5A3A19F9E9C9A99979695949392918F8D
8B87837F7B7773706D6B6A686663605E5B59575552504E4B
4845413E3B383532302E2C2B29282625232221201F1E1E1D
1D1D1D1D1D1D1D1D1C1B1A19181717161616161616161616
161616161616161616161616161717171817161516181919
181919171514172330373E3F3F40403F3E40424446454444
4342403F3E3C3B3A393A3A3A3B3A3A3A
434444444445454546464647474848494A4B4C4E4F505152
53525150504F4F4F505255585A5C5E60616060605F5F5F5F
5F60626466656565646464686B6F6D5C4D494438374D667F
98AAB9C6CFD1D0CFCED1D3D3D2CEC9C6C3C3C3C2C2C0BEBC
BAB7B4B1AEABA8A6A3A19F9E9C9A989795949392918F8E8C
8986827E7A7773706D6B6A686664615F5C5A585553514E4C
4946423F3C383533302F2D2C2A29282625242221201F1E1D
1D1D1D1D1D1D1D1D1D1B1A19181717161616161616161616
161616161616161616161616171717171717161515171818
18181917161518232E363D3F404142404041434445444343
4241403F3E3C3B3A3A3A3A3B3B3B3A3A
43434343434344444445454546464747484A4B4C4E4F5051
5251504F4F4E4E4E4F515456585A5C5D5E5E5E5E5E5D5C5D
5D5D5E62656768625D58555B6063614F40414341475A7087
9EAEBDC8D0D1D1D0CFD2D4D4D4D0CCC8C6C6C6C5C4C2C0BE
BBB8B5B2AFACA9A6A3A19F9E9C9A9896949392908F8E8C8A
8884817D7A7673706D6B6A686664615F5D5B585654524F4D
4A47433F3C393633312F2E2D2C2A292827252322201F1E1D
1C1D1D1D1D1D1D1D1D1C1B19181817161616161616161616
161616161616161616161616171717171717161515161717
17181817171719222C343B3F414343424243444445434241
40403F3E3D3C3B3B3A3A3B3B3B3B3B3B
4242424242424343434344444445454647484A4B4D4E4F51
51504F4F4E4D4D4D4E50525557595A5B5C5D5D5D5D5B5A5B
5C5B5B606469695F554D4850575A5845373C43495565798F
A4B3C0C9D0D1D1D0CFD2D4D5D4D1CDCAC8C8C7C6C5C3C1BF
BDB9B6B3AFACA9A6A4A29F9D9B9997959392918F8E8C8B89
8783807C797673706D6B6A68666462605D5B59575552504E
4B4744403D39363331302F2E2D2C2B2928262423211F1E1D
1C1D1D1D1D1D1D1D1D1C1B1A191817161616161616161616
161616161616161616161617171717171717161515161716
1617181717181A222A333A3F424444444344444544434140
3F3F3E3E3D3C3C3B3B3B3B3B3B3B3B3B
424141414141414242424243434344454547494A4C4D4F50
504F4E4E4D4D4C4C4D4F5153555759595A5B5B5C5B59585A
5B59585E63696B5C4E433D464F51503D3039445162718297
AAB8C3CBD0D1D1D0CFD2D4D5D4D1CECCC9C9C8C7C6C4C2C0
BDBAB7B3B0ADAAA7A4A29F9D9B99969492918F8E8C8B8988
85827F7B7875726F6D6B6968666462605E5C5A575553514F
4C4844413D3A37343231302F2E2D2C2B2A27252321201E1D
1C1D1D1D1D1E1E1E1D1C1B1A191817161616161616161616
161616161616161616161617171717171716161515161616
1617171818191C212831393F44454546454545454442403F
3E3E3E3D3D3C3C3B3B3B3B3B3B3B3B3B
41414140404040414141414242424343444648494B4C4E4F
4F4F4E4D4C4B4B4B4B4E50525456575858595A5B5A585658
5A56555B61696A57463D38444F4E4C3E353F4B596B7B8D9F
AFBBC4CCD1D2D1D0CFD1D3D4D3D1CECBC9C8C7C6C5C3C1BF
BCB9B6B3AFACA9A6A4A19F9C9A989593918F8E8D8B8A8886
84817E7B7774726F6C6B69676563615F5E5C5A575553514F
4C4945413E3A3734323130302F2E2D2C2B28262422201E1D
1C1C1D1D1E1E1E1E1D1C1B1A191817171616161616161616
161616161616161616161617171717171716161515151616
161718191A1A1C20262F394045464747474746454342403E
3C3D3D3D3D3C3C3B3B3B3B3B3B3B3B3B
404040403F3F3F404040404141414242434547484A4C4D4E
4F4E4D4C4B4B4A4A4A4D4F51535556575758595A59565457
595452595F6869533E3734424E4C48403C455261738596A6
B4BEC5CDD2D2D1D0CFD1D3D3D2D0CDCAC8C7C7C5C4C2C0BD
BBB8B5B2AFACA9A6A3A19E9C99979492908E8D8C8A898785
83807D7A7774716E6C6A68676563615F5D5B59575554524F
4D4945423E3B383532313130302F2E2D2B29262422201F1D
1C1C1D1D1E1E1E1E1E1C1B1A191817171616161617161617
171616161616161616161717171717171717161615151616
161718191B1B1D1F242E3840464848494948474543413F3D
3B3C3C3C3D3C3C3C3B3B3B3B3B3B3B3B
3F3F3F3F3F3F3F3F3F3F3F404040414142444647494B4C4D
4E4D4C4B4A4A49494A4C4E50515355555557585858555356
585350565C66684D36302E3E4C47433F3F4A58697B8E9FAD
B8C0C6CED2D2D1CFCFD1D3D2D2CFCDCAC8C7C6C5C3C1BFBD
BAB8B5B2AFACA9A6A3A19E9B999693918F8D8C8B89888684
827F7C797673716E6B6A68666463615F5D5B5A5856545250
4D4945423E3B383532323131302F2E2D2C29272422201F1D
1C1C1D1D1E1E1E1E1E1C1B1A191818171616161717171717
171616161616161616161717171717171717161615151516
1617181A1C1D1E1F232D37404749494A4B49484543413E3C
3A3B3C3C3C3C3C3C3C3B3B3B3B3B3B3B
3E3E3E3E3E3E3E3E3E3E3E3F3F40404142434547484A4B4C
4D4C4B4A4A494949494B4D4F515254545456575857545256
58524E555A636448302A2A3B49444141444F5E6F8293A3B0
BBC2C7CED2D2D1D0CFD1D3D2D2CFCDCBC9C8C7C5C4C2BFBD
BBB8B5B2AFACA9A6A3A19E9B999693918F8D8C8A89878684
827F7C787673706D6B6968666462615F5D5C5A5856545250
4E4A46423E3B383532323131302F2E2D2C29272522201F1D
1C1C1D1D1E1E1E1E1D1C1B1A191818171616171717171717
171716161616161616161717171717171717161615151516
1617191B1D1D1E1E212C363F4748494A4B49474542403E3B
3A3A3B3C3C3C3B3B3B3B3B3B3B3B3B3B
3D3D3D3D3D3D3D3D3D3E3E3E3F3F40404143444647494A4B
4C4B4A4A49494949494B4D4F505254545455565757555457
58534F55595D5B412B272838464546474B57647484919FAE
BBC2C8CCCFD1D1D1D0D2D3D3D3D1CECCCACAC9C8C6C4C2C0
BDBAB7B4B1AEABA8A5A29F9D9A979592908E8D8B8A888785
837F7C797673706D6B696866656362605E5C5B5957555351
4E4A46423F3B3835323131302F2E2D2C2A28262422201F1E
1D1D1D1D1D1D1D1D1D1C1B1A191817171616171717171717
171716161616161616161717171717171717161616151516
1617191B1D1D1E1E212B343D444545464646454341403E3C
3B3B3B3C3C3B3B3B3B3A3A3A3A3A3A3A
3C3C3C3C3C3C3D3D3D3D3E3E3F3F3F40414244454648494A
4B4A4A49494949494A4B4D4F505253545455565656555558
595451565857513A2725273442464B4D515D6A77858E99AB
BAC2C8CBCCD0D2D2D2D3D4D4D4D2D0CECCCCCBCAC9C7C5C3
C0BDB9B6B3AFACA9A6A3A19E9C99969491908E8D8B898886
83807D797673706D6B6A6867666462615F5D5C5A58565452
4F4B46433F3B38343231302F2E2C2B2A2927252322201F1E
1D1D1D1D1D1D1C1C1C1B1A19181817171616171717171717
171717161616161616161617171717171717161616161616
1718191B1D1D1D1E212A333B4141414242424241403F3E3D
3C3C3C3C3B3B3A3A3A3A3A3A3A3A3A3A
3B3B3B3B3C3C3C3C3D3D3D3E3E3F3F404142434445474849
49494949494949494A4C4D4F505253545455555556565658
5955525656514833232226323F474E5257636F7A858B95A8
B8C1C8C9CACFD2D2D3D3D4D5D5D3D1CFCECDCDCCCAC9C7C5
C2BFBBB8B4B1ADAAA7A4A29F9D9A979593918F8E8C8A8887
84817D7A7673706D6B6A696766656362605E5C5A58565452
4F4B47433F3B373431302F2E2C2B2A282726242321201F1F
1E1D1D1D1C1C1C1C1B1A1A19181817171617171717171717
171717161616161616161617171717171717161616161616
1718191B1D1D1D1E212932393E3E3E3E3F3F4040403F3E3D
3D3C3C3C3B3A3A393939393939393939
3A3A3A3B3B3B3C3C3D3D3D3E3E3E3F404041434445464748
484848484949494A4A4C4D4F505253545454545555565759
59565356554B3F2D2020242E3A444E545A66717A838991A4
B5BFC6C7C8CED2D2D3D4D5D6D6D4D2D0CFCFCECDCCCBC9C7
C4C1BDB9B6B2AEABA8A5A3A09E9B98969492908F8D8B8987
85817D7A7673706D6B6A696867656462615F5D5B59575553
504B47433F3B3734312F2E2C2B292827252423222120201F
1E1E1D1D1C1C1B1B1A1A1919181817171717171717171717
171717161616161616161616171717171717161616161616
17181A1B1D1C1D1E212931373C3C3C3C3D3E3F3F3F3F3E3E
3D3D3C3B3B3A39383838383939393939
3839393A3A3B3B3C3C3C3D3D3E3E3F3F4041424344454647
474848484849494A4A4C4D4E505152535454545455565859
59575556554838281B1B1F262F3B464F59636D77818A95A4
B2BBC2C6C9CDD0D2D3D4D5D6D6D4D3D1D0D0CFCFCECCCAC8
C5C2BEBAB6B2AFABA8A6A3A19F9C99979593918F8E8C8A88
85827E7A7673706D6A69696867656462615F5D5B59575553
504B47433E3B3733302E2D2B2A282725242322222120201F
1F1E1D1C1C1B1B1A1A191918181717171717171717171717
171717161616161616161616171717171717171616161617
17181A1B1D1C1D1E212932393E3E3E3F3F404141403F3F3E
3D3C3C3B3B3A39383838383838383838
373839393A3A3B3B3C3C3C3D3D3E3E3F4040414243444546
464747484849494A4B4C4D4E4F5052535453535354565859
595856555444322418181B1E26313D4A565F68727D8A97A3
ADB5BDC4CACDCFD1D2D4D5D6D6D5D3D2D0D0D0D0CFCDCBC9
C7C3BFBBB7B3AFABA8A6A4A29F9D9A98969492908E8C8A88
86827E7A7673706D6A69686867656463615F5D5B59575553
504B47433E3A3733302E2C2B29272524232222212120201F
1F1E1D1C1B1B1A1A19191818181717171717171717171717
171717161616161616161616171717171717171616161717
17191A1B1D1C1D1E212A333A3F4041424243434241403F3E
3D3C3C3B3A3938383737383838383838
36373838393A3A3B3C3C3C3D3D3E3E3F3F40414242434445
454646474848494A4B4C4D4E4F5051525353525253565959
5959575552402C20151518181D293745535A626C7888969F
A7B0B8C2C9CBCDCFD1D4D5D6D5D5D4D2D1D1D1D1D0CECCCA
C8C4C0BCB8B4B0ACA9A6A4A2A09D9A98969492908E8C8A88
85827E7A76736F6C6A6968686766646361605E5B59585553
504B47423E3A36322F2D2B2A282624232221212020202020
1F1E1D1C1B1A1A1919181818181717171717171717171717
171717171616161616161616171717171717171616171717
18191A1B1C1C1D1E222B333A404242444444444342403F3E
3C3C3B3B3A3938373737373737373737
3536373839393A3B3B3C3C3C3D3D3E3E3F40404142424344
444546464748494A4A4B4D4D4F5051525352525152555859
595958554F3C281D1514161518232F3E4C535A6470829198
9FA9B2BEC8CACBCED0D3D5D5D5D5D4D3D2D2D2D1D1CFCDCB
C9C5C1BCB8B4B0ADA9A7A5A2A09D9B98969492908E8C8A88
86827E7A7673706C6A6969686766656362605E5C5A585653
504C47433E3A36322F2D2B29272523212020202020202020
1F1E1D1C1B1A191918181818171717171717171717171717
171717161616161616161616171717171717171616171717
18191A1B1D1D1E20242C343B404243454545444342403F3D
3C3C3B3A3A3938373636373737373737
3536373738393A3A3B3B3C3C3D3D3E3E3F3F404041414243
43444546464748494A4B4C4D4E4F50515252515150545657
585757554735291D16181918192028323C434C576374828B
95A0ABB9C4C6C8CBCED1D3D4D5D4D4D3D2D3D3D2D1D0CECC
C9C6C1BDB9B5B1ADAAA8A6A5A3A09E9C99979593918F8C8A
87837F7B7774706D6B6A6A696867666563615F5D5B595755
524D48443F3B37332F2D2B2927242221201F1F1F1F1F1F1F
1F1E1C1B1A1A191818181717171717171717171717171717
171717161616161616161616171717171717161616161717
18191A1B1D1E2023272E343A3F4142434444434241403F3D
3C3B3B3A393837363636363636363636
343536373839393A3B3B3B3C3C3D3D3E3E3F3F4040414142
4243444545464748494A4B4C4D4F5051525151504E525455
585556563F2F2A1E191B1C1C1C1E21262C343E495664727E
8A97A4B3BFC3C6C9CBCFD1D3D4D4D4D3D3D3D3D2D1D0CECC
CAC6C2BEBAB6B2AEABA9A8A6A5A2A09E9C9A979593908E8C
8984807C7875716E6B6B6A6A696867666463615F5D5B5956
534E4944403B37332F2D2B29272422201F1F1F1F1F1F1F1F
1E1D1C1B1A19191817171717171717171717171717171717
171716161616161616161616161717171717161616161717
18191A1B1D2023262A30353A3D3F404242424241403F3E3D
3C3B3A39393736353535353536353535
343536373838393A3B3B3B3C3C3D3D3E3E3E3F3F40404041
424243444445464748494A4B4D4E4F505151514F4D505253
57535656382A2B1F1C1F1F1E1E1C1B1B1E27313D4A576471
7F8E9DADBBBFC2C6C8CCCFD2D3D3D3D3D3D3D3D2D1D0CECD
CAC6C2BFBBB7B3AFACAAA9A8A6A4A2A09E9C999794928F8D
8985817D7975726E6C6B6B6A6A6967666563615F5D5C5A57
544F4A45403C37332F2D2B28262422201F1E1E1E1E1E1E1E
1E1D1B1A1919181817171717171717171717171717171717
171716161616161616161616161717171717161616161717
18191A1B1D2125292D3236393D3E404142424140403F3E3D
3C3B3A39383736353434353535353535
333435363738393A3A3B3B3C3C3C3D3D3E3E3E3F3F3F4040
41414243444445464748494B4C4E4F505051504E4B4E5151
5752555531252C211F232222201C1815151D27323E4A5664
738495A7B6BBBFC3C6CACDD0D2D2D3D3D3D3D3D2D1D0CECC
CAC6C2BFBBB7B3AFACABAAA8A7A5A3A19F9C9A9794928F8D
8A85817D7976726F6C6C6B6A6A696766656462605E5C5A58
544F4A45403C38332F2D2A282623211F1E1E1E1D1D1D1D1D
1D1C1B1A1918181717171717171717171717171717171717
171616161616161616161616161717171717161615161717
18191A1B1E23282C313436393C3E3F40414140403F3E3D3C
3B3A3938383635343434343435343434
333435363738393A3A3B3B3B3C3C3D3D3D3E3E3E3E3F3F3F
40414142434344454648494A4C4D4F4F5050504D4A4D4F50
565155522B212B2222262523211F1D1A191D242D37404A56
64788CA1B2B7BBBFC2C7CACDCFD0D1D1D2D2D2D1D0CFCDCB
C9C5C2BEBAB6B2AEABA9A8A6A4A2A09D9B999694918F8D8A
8783807C7975726F6D6C6B6A696866656462615F5D5B5A57
544F4A45403C37332F2D2A282523201E1D1D1D1D1D1D1D1D
1D1C1A191818171717171717171717171717171717171717
161616161616161616161616161717171716161515161718
19191A1C1E242A2F333537393B3D3F40414140403F3E3D3C
3B3A3938373635343333343434343434
32333536373838393A3B3B3B3C3C3D3D3D3D3E3E3E3E3E3F
3F404141424343454647484A4B4D4E4F4F50504C484B4E4F
5551544F261E292425292725222323201F20222830363F49
566C839AAEB3B7BCBFC4C8CACCCECFD0D0D0D0D0CFCECCCA
C8C4C1BDB9B5B1ADAAA8A6A4A2A09D9B989694918F8D8A88
85827E7B7875726F6D6B6A696866656362615F5E5C5A5956
534F4945403B37332F2C292725221F1D1C1C1C1C1C1C1C1D
1C1B1A191818171716161717171717171817171717171716
161616161616161616161616161717171716161515161718
191A1A1C1F252C323637383A3B3D3F404141403F3F3E3D3C
3B3A3938373534333333333334333333
32333435363738393A3A3B3B3C3C3D3D3D3D3D3D3E3E3E3E
3E3F404142424244454648494B4C4E4E4F504F4B474A4D4E
5450544C221B2925292D2B282526272422202024292D343C
49627B94A8AEB3B8BCC1C5C8CACCCDCECFCFCFCFCECDCBC9
C7C3BFBCB8B3AFACA8A7A6A4A3A09E9C9A989593908E8C89
86837F7C7875726F6C6B696867656362605F5E5C5B595755
524E49443F3B36322E2B292624211F1D1B1B1B1B1C1C1C1C
1C1B1A191817171616161717171717181817171717171616
161616161616161616161616161717171716161515161719
1A1A1B1D20272E343939393A3A3D3F4040403F3F3E3D3D3B
3A393837363534333232333333333333
32333435363738393A3B3B3B3C3C3D3D3D3D3D3D3D3E3E3E
3E3F404041414243454647494A4C4D4E4E4F4F4B474A4C4D
534F544C211A28262C302F2B282B2D2A2823202124272C34
415A748DA1A8AEB5BABFC3C6C8CACBCCCCCDCECDCDCCCAC8
C6C2BEBBB7B2AFABA8A6A5A4A3A19F9D9B999694918F8C8A
87837F7B7874716E6B6A6867656462605F5E5C5B59585654
514C47423D3935312D2A282523201E1C1B1B1B1B1B1B1B1B
1B1A19181717171616161717171717181817171717161616
161616161616161616161616161717171717161616161819
1A1B1C1E212930373B3B3A3A3A3C3E3F403F3F3E3E3D3C3B
3A393837363534333233333333333333
323334363738393A3B3B3C3C3C3D3E3E3E3E3E3E3E3E3E3E
3F3F404141424243454647484A4B4C4D4E4F4E4B484A4C4C
514E5350261B27272E35363330323332302A252222262C35
435B7386969FA7B1B9BEC3C6C7C8C9C9C9CACCCCCCCBC9C8
C5C2BFBBB8B4B1ADAAA8A6A4A29F9D9A989693918E8C8A87
84807D7976726F6C6A69686765646261605E5D5B59575553
504B45403B36322D2A272523221F1D1C1B1A1A1A1A1A1B1B
1B1A19181717171616161717171717171817171717171616
161616161616161616161616161717171817161616171819
1A1C1E20242B32383D3C3B3B3A3C3E3E3E3E3E3D3D3C3B3A
3A393837363535343333343434343434
323335363738393A3B3C3C3D3D3E3E3F3F3F3F3F3F3F3F3F
3F4040414242434445464748494A4B4C4D4E4E4B494B4D4B
504D53542D1D26272F393D3A3638383937302A2421262D37
465C727E8A95A0ACB7BDC2C5C6C6C6C5C4C7C9CBCBCAC8C6
C4C2BEBBB8B5B2AEABA9A6A4A19E9C999694928F8D8B8886
837F7B7774706D6A6867676665646261605E5C5A58565451
4E48433D38332E2A26242321201E1C1B1A1A1A1A1A1A1A1A
1A1918181717171616161717171717171717171717171616
161616161616161616161616171717181817171717171819
1A1D2023272D343A3E3D3C3B3B3C3D3D3D3D3D3C3C3B3A3A
39383837373635353434353535353535
323435363738393A3B3C3C3D3E3E3F404040403F3F3F3F3F
3F4041414242434445464748494A4A4C4C4D4D4C4A4C4D4B
4E4C5356331F2527313D423F3C3D3D3F3F372E2520262E38
465C6F777F8C98A7B4BBC0C2C3C3C2C0BFC2C5C7C9C7C5C4
C2BFBCB9B6B3B0ADAAA8A7A5A3A19F9C9A989592908D8B88
84807B77736F6B6865646464636261605E5C5A585654524F
4B46403A35302B27232221201F1D1C1B1A1A191919191919
191918181717171616171717171717171717171717171716
161616161616161616161617171717181818171818181819
1B1E22252930363B3F3E3C3C3B3C3C3C3C3C3C3B3B3A3A39
38383837373636353535353535353535
323435363738393B3B3C3D3E3E3F40404140404040404040
40404142424243444445464849494A4B4C4C4D4C4B4D4E4A
4D4B535839222326313E46423E3F3F42423B332822262E38
465B6D6F748391A2B1B8BDBFC0BFBEBBBABEC2C5C7C5C3C2
BFBCB9B6B3B0ADAAA8A7A5A4A3A19F9D9B989693918E8B89
85807B77726E6A6663626161605E5D5C5A58565452504E4B
48423C37312D2824201F1F1E1D1C1B1A1A19191918191919
191818171717171717171717171717171717171717171716
16161616161616161616161717171718181818181919191A
1B1F24272C32373C403F3D3C3B3B3C3B3B3B3B3B3A3A3938
38383837373736363636363636363636
3334353638393A3B3C3C3D3E3F3F40414141414040404040
4041414242424343444546474848494A4B4C4C4D4C4E4E4A
4A4C52553C241E242F3C433E393735383938352D26262832
40576A696B7B8B9EAFB6BABCBCBCBCB9B8BDC2C6C9C7C4C2
C0BCB7B3AFACAAA7A5A3A2A09F9D9C9A98969492908E8C89
86827D7874706B6764615E5C595654514F4D4C4B49484644
413C36322D2925211E1D1D1C1C1B1A1A1919191818181818
181817171717171717171717171717171717171717171717
16161616161616161616171717171818181919191919191A
1C20252A2F34393E41403E3D3B3B3B3A3A3A3A3A3A393838
38373737373737373737373737373737
3334353638393A3B3C3D3D3E3F4041414141414141404040
404141424242434344454647484848494B4C4C4D4D4F4F4A
494D525140261A222D39403A332F2C2D303437312B25242D
3A53666262738499ABB1B5B7B6B7B7B4B4BAC0C5C8C5C2C0
BDB8B4AEAAA7A5A29F9D9A989693918F8D8C8B8A88878583
817D7A76726F6B67635F5A56524D494643424241403F3D3C
3A35312C2825221E1C1C1B1B1B1A1A191918181817171717
171717171717171717171717171717171717171717171717
161616161616161616171717171818181919191A1A1A1A1B
1D22272C31363B3F42413F3D3B3B3A393839393939383837
37373737373737373737373737373737
3334353638393A3B3C3D3D3E3F4041414242414141414140
414141424242434343444546474747494A4B4C4E4F504F4A
474E524F452A18212C373F372F2925262A3339352F26222A
364F625A58697B91A3A9ADAEADAEAEACABB2B9BEC2BFBCBA
B6B3AEAAA5A4A19E9A938B857E78736E6B6B6C6C6D6D6C6C
6C6C6B6A69696866635D57514A45403B3737383838373635
332F2B2724211F1C1A1A1A1A1A1919191918181717171717
171717171717171717171717171717171717171717171717
1716161616161616171717171718181919191A1B1B1B1B1C
1E24292E33383C4042413F3D3C3B3A383738383838383737
37373737373838383838383838383838
333435363738393A3B3C3D3E3F4040414141414141404040
40404141414242424344454646464648494B4C4E5051504B
474F524F492D18202A343C342B241F20242F383531272127
32495B524E5F7186989FA3A3A2A2A19E9DA4ABB1B5B2AFAD
AAA7A39F9B9997938E83786F655D554E4A4B4D4F51525254
5658595B5C5E60605E574F48423C36312D2E2F2F302F2F2E
2D2A2623201E1C1A19191919191918181818171717171717
171717171717171717171717171717171717171717171717
17171616161617171717171717181819191A1A1B1C1C1D1E
20262C31363A3D4042413F3D3C3A39383737373838373737
36373737373738383838383838383838
32333435363738393A3B3C3C3D3E3F404040403F3F3F3F3F
3F3F3F40404040414142434445454647494B4C4F5051504C
495054514B331F2329333B3128231E1E21282F2E2D282527
2D3F4E49485665788991979897928D8682878D9194939291
908D8A86827E7A756F665E554D463F39353638393B3B3C3E
3F41434546494A4B4A453F3A35312D29272728292A292929
282523211F1D1C1A19191919191818181817171717171717
171717171717171717171717171717171717171717171717
1616161617171717171717171717181819191A1B1C1D1F22
252A2F33373A3C3E403F3E3D3B3A39383737383838373737
37373737373737373737373737373737
323334343536373738393A3B3C3C3D3E3E3E3E3E3E3E3E3E
3E3E3E3E3E3E3E3F3F41424344454547484B4D4F5051514D
4C5256544D3827262932392F26221F1E1F22262728292A27
2836403F424C58687781888B8980766C66696E7073737374
74726F6C68625C56504A443E38322C27242425262828292A
2B2D2E303133353636332F2D2A2725232122232324242424
2322201F1D1C1B1A19191919181818181717171717171717
171717171717171717171717171717171717171717171616
161616171717171717171616161717181819191A1C1F2225
292E3236393A3B3C3D3D3C3C3B3A39383838383838373737
37373736363636363636363636363636
3132333334353536373839393A3B3C3C3D3D3C3C3C3C3C3C
3C3C3C3C3D3D3D3D3E3F414243444446484A4D4F5151514E
4E5458564F3D2E292831372D24211E1C1C1D1F22252B2D27
242D34363A414A57636E767A786C5E524A4C4F5052545658
595855534F48413B3533312E2B2723211F1E1F1F1F1F1F20
2021212222232424242322201F1E1D1C1C1C1D1E1E1E1E1E
1E1E1D1C1C1B1B1A1A191919181818171717171717171717
171717171717171717171717171717171717171717161616
161617171717171717171616161617181819191A1C212529
2D3135383A3B3B3B3B3B3B3B3B3A39383838383838383737
37373636363636353535353535353535
31313233333434353536373839393A3B3B3B3B3B3B3B3B3B
3B3B3B3B3B3B3B3C3C3E3F4142434445474A4D4F51515150
505559585142342B2731372C2422201E1C1B1B1F242B2E26
21252A2E32363C454F5961656356473B31333536373A3C3F
41403E3C39322C262122232323211F1E1D1C1B1B1A1A1A1A
191918181817171717171717181818181819191A1A1A1A1B
1B1B1B1B1A1A1A1A1A191919181817171717171717171717
171717171717171717171717171717171717171716161616
161617171717171818171616151617181819191A1D22282D
3235373A3C3B3A3938393A3B3B3A39393838383838383737
37373636353535353434353535353535
313131323233333434353637373839393A3A3A3A3A3A3A3A
3A3A3A3A3A3A3A3A3B3D3E4041424345474A4D5052525252
52575A585345372A24313B30292A29252122232628282621
1E212527292B2E33383E4345443B322A2527292A2C2D2E30
3131302F2E2B2825232221201F1D1C1B1919191918181818
181818181818181818181818181818181818191919191A1A
1A1A1A1A1A1A1A1A19191918181817171717171717171717
171717171717171717171717171717171717171716161616
161717171717181818171616151617181919191B1D242B30
35383A3D3E3C39373638393A3A3A39393838383838383737
37363636353534343434343434343434
303131313232323333343536363738383939393939393939
39393939393939393A3C3D3F40414244464A4D5053535353
54585A5954483A2A22323F352E32322C27292A2C2C251E1C
1B1F2323232424252628292A2A26221F1D20232426262525
2525252525262626262422201F1D1C1A1919191919191818
18191919191A1A1A1B1A1A19191919191919191919191919
191919191919191919191818181817171717171717171717
171717171717171717171717171717171717171716161616
1617171717181818181716161616171819191A1B1F262D33
393B3D3F3F3C3936343638393A3A39393838383838383737
37363635353434333333333434343334
303030303131313132333434353636373838383838383839
3938383838383838393B3C3E3F41424346494D5053535354
55595B5A554B3E2B203544372E3538302A2D2E2F2D211716
171C2223242423211F1E1D1D1D1D1D1D1E21232627252322
21201F1E1E202223242221201F1F1F1F1E1E1D1D1C1C1B1B
1A1A1A1A1A1A1A1A1A1A1919191919191919191919191919
191919191919191919191818181717171717171717171717
171717171717171717171717171717171717171716161616
161717171718181919181716161718191A1A1B1C20283037
3C3E3F41403C3835323537393A3939393838383838383737
37363635343433333333333333333333
2F2F2F303030303031323333343535363737373737383838
3838383837373838393A3C3D3F40424345494C4F51515153
55585959564F442F2337463931393D352F3132322E1F1314
161C2325262624211D19161516181A1D2023252728262321
1F1D1B1A191C1F2122212020202021212120201F1E1E1D1C
1C1C1B1B1B1A1A1A1A191919191919191919191919191919
191919191919191919181818181717171717171717171717
171717171717171717171717171717171717171717161617
1717171717181819191817171718191A1B1C1D1E222A333A
3F404142413D3834323437393A3938383838383838383737
37363535343333323232323232323232
2F2F2F2F2F2F303030313233343435363737373738383939
3939393838383839393B3C3E3F4142434547494B4D4C4C4D
4F52545656544E403536393D403F3E3A363634302C231C1D
1E22252728282624211E1C1B1A1A1B1B1C1F21232322201F
1D1B1A1817191A1B1C1C1B1B1B1C1C1D1D1C1C1B1B1A1A19
191818181817171717171717171717171817171717171717
171718181818181818181817171717171717171717171717
171717171717171717171717171717171717171717171717
17171717171718181818181818191B1C1E1F2023262E353B
40414142413D3935333537393A3938383838383737373737
37363534343333323232323232323232
2E2E2E2E2F2F2F2F3031323333343536373737383839393A
3A3A393939393A3A3A3C3D3F404142434445464748464547
494C4F535659584F453932404A433D3E3C39352F2A282626
262728292A2A292726242221201D1B1A191B1D1E1F1E1D1D
1C1B19181717171717171717171818181818181717171616
161615151515151515151515151516161616161616161616
161617171717171717171717171717171717171717171717
171717171717161616161616171717171717171717171717
171717171717171818181819191B1D1F212224272B31383D
41424142403D3A3735363839393938373737373737373737
36363534333332323131323232323232
2D2E2E2E2E2E2F2F30303132333435363637383839393A3A
3A3A3A3A3A3A3A3B3B3C3E3F404243434444444443414142
45484C52575D5F544B464242423E3C3E403C38322C2D2D2C
2B2A2929292827252422211F1D1A17141314161718181818
181817161616161616151515141414141414141313131313
131414141414141414141515151515151515151515151616
161616161617171717171717171717171717171717171717
171717171616161616161616161616161717171717171717
17171717171717181819191A1B1D1F212426282B2F343A3F
42424241403E3B3837373839393837373637373737373737
36353534333232313131313232323132
2D2D2D2D2E2E2E2F2F3031323334353636373838393A3A3B
3B3B3B3B3B3B3B3B3C3D3E3F4042434343424141403E3D3F
41454A5057606459505251453C3A393E413E3A332E313330
2E2C2929282625242322201F1C1815110F10111213141415
161616161616151515141413121211111111111111121212
121313131314141415151515151515151515151515151515
161616161616161616171717171717171717171717171717
171717161616161616161616161616161617171717171717
171717171617171818191A1C1D1F212427292C2F33383C40
43434241403E3C3A38383939393837363636363636363636
36353434333232313131313131313131
2C2C2D2D2D2D2D2E2E2F30313233343536373838393A3A3B
3C3C3C3C3C3C3C3C3D3D3E3F40414242424140403F3D3D3F
4345485058646A5C50585A48393533373B3B39343031322E
2B292828272523222121201F1D1A17151314151616171718
181817171716161615151515151414141414141414151515
151515151515161616161616161616161616161616161616
161616161616161616161617171717171717171717171717
171717161616161616161616161616171717171717171818
1817171717171718191A1B1D1F212326292C3033363B3F42
44434241403E3C3A39393939393837363636363636363636
36353433323231313031313131313131
2C2C2C2C2C2D2D2D2E2F30313233343536373738393A3B3B
3C3C3C3C3C3C3D3D3D3D3E3E3F404141404040403F3D3D41
4445484F57666E5E525C5F4D3D363134383A3A353031312D
2927262626242221201F1F1E1D1B19181718181919191A1A
1A1A19181817171616161717171717171717171717181818
181818171717171717171717171717171717171717171717
171716161616161616161616171717171717171717171717
171717161616161616161616161617171717171717181818
18181717171718191A1B1D1F212326292C2F33363A3E4144
454442413F3E3D3B3A393939383736363535363636363636
36353433323231303030303131313030
2B2B2B2C2C2C2C2D2D2E2F303232333435363738393A3B3C
3C3C3C3D3D3D3D3D3D3E3E3E3E3F403F3F3F3E3E3E3D3C41
4544454D566873685D59565A5B493B3F41403D332C313533
312C272523212120201F1E1D1C1B1A1A191919191A1A1A1B
1B1B1A1A1919181717171818181818181819191919191919
191919191919181818181818181818181818181818181717
171717161616161616161616171717171717171717171717
171717161616161616161616161617171717171718181818
19181818181819191A1C1F212426292C2F33373A3D404345
464442413F3E3D3C3B3A3939383736353535353636363636
36353433323131303030303030303030
2B2B2B2B2C2C2C2D2D2E2F303132333435363738393A3B3B
3C3C3C3D3D3D3D3D3D3E3E3E3E3F403F3F3F3E3E3E3D3D41
4543444C5567746E65585166735A484C4D48413329313737
362F282421201F1F1E1E1D1C1B1B1B1B1A1A1A1A1A1A1B1B
1B1B1B1A1A1919181818181919191919191A1A1A1A1A1A1B
1B1A1A1A1A19191919191919191919191919181818181818
181717171616161616161616171717171717171717171717
171717161616161616161616161717171717171818181819
191918181819191A1B1E2124272A2D3033373B3E41434546
464542403E3E3D3C3B3A3938383736353535353535363636
35343332323130303030303030303030
2B2B2B2B2C2C2C2D2D2E2F30313233343536373738393A3B
3B3B3B3B3B3C3C3C3C3D3E3E3F404141414140403F3F3F41
4446494F56616A686663626B70645B5F5F534635282D3233
332E2825221F1D1B1A1A1A1A1A1919191818181818191919
1A1919181818171717171718181818181818191919191919
191919191919181818181818181818181818181818181817
171717171616161616161616171717171717171717171717
171717161616161616161617171717171717171718181819
1919191919191A1A1C2025292D3033363A3C3F4143454647
474543413F3D3C3B3A393938373736353535353535353535
35343332313130302F2F303030303030
2A2B2B2B2C2C2C2D2D2E2F3031323334343536373738393A
3A3A3A3A3A3A3A3A3B3C3E3F404142434443424141404041
43484D52575C6063666C706F6E6D6C6F6D5D4C392B2C2E2F
302D2926221F1C1918181819191817171716171717171718
181817171716161616161616171717171717171718181818
181818181817171717171717171717171717171717171717
171717161616161616161616171717171717171717171717
171717161616161616161617171717171717171717181819
191919191A1A1A1B1E23292E33373A3D4042444546474748
474543413F3D3B3A38383838373736363535353535353535
34333332313130302F2F303030303030
2A2B2B2B2C2C2C2D2D2E2F30313232333435353637373839
39393939393939393A3C3D3F414243454644434241414241
434A52565A595A626A7177757272706F6A6054463A332E2D
2D2B2925211F1D1B19191919191817171717171717181818
181717161615151515151516161616171717171717171717
171717171717171717171717171717171717171717171717
171717171616161616161617171717171717171717171717
171717161616161616161717171717171717171717181919
1A1A1A1A1B1B1B1D1F262D33393D40434647484848484848
474543413F3D3B3937373737373736363635353535353434
343332323130302F2F2F2F3030302F30
2A2A2B2B2C2C2C2D2E2E2F30313132333434353536373738
3838383838383838393B3D3F404243454644434241414140
414B53585A56545F69737B797676746F69625B51473B312F
2D2C2A25201F1E1D1C1A1919191818181818181818181818
181717161515151515151515161616161616161617171717
171717171716161616161717171717171717171717171717
171717171716161616161717171717171717171717171717
17171716161616161616171718181717171717171818191A
1A1A1B1C1C1C1D1E222931393F4346494B4B4B4B4A4A4948
474543413F3C3A3836363737373636363635353534343434
333332313130302F2F2F2F2F302F2F2F
2A2A2B2B2C2C2D2D2E2E2F30313132333334343536363737
3837373738383838393A3B3D3E3F404142403F3E3D3D3D3D
3E454C515553535A626E797F82817D746A635C544D443D3D
3C352E241D1E2020201D1B1B1A1A1A191919191919191919
181817171716161515151616161616161617171717171717
171717171717171717171717171717171717171717171717
171717171717171717171717171717171717171717171717
171717171616161616161718181818181818181919191A1A
1B1C1D1E1F1F2021252D363D43474A4D4E4E4E4D4C4B4A49
474543413E3C393736363636373636363635353434343433
333232313130302F2F2F2F2F2F2F2F2F
2A2A2B2B2C2C2D2D2E2E2F30303132323334343535363637
373737373737383838393A3B3B3C3D3E3E3C3B3A3A39393A
3B3F44494E5052545A66727F8888847A6E655B544D484649
493E32251B1E222222201D1C1C1B1B1B1A1A1A1A1A1A1A19
191918181817161616161616161616171717171717171717
171717171717171717171717171717171717171717171717
171717171717171717171717171717171717171717171717
1717171716161616161717181919191919191A1A1A1A1B1B
1C1D1E202122232428313A41484B4D505151504F4D4C4B49
474543403E3B393635353636363636363635353434343333
333232313130302F2F2F2F2F2F2F2F2F
2A2A2B2B2C2C2D2D2E2E2F30303132323333343435353536
363637373737373838383939393A3B3B3B3A393838373738
3A3A3B3F43474B4B4E57616F7C888F8A806A54453B3D424A
4E4336291F1F201F1E1E1E1F1F1D1C1B1A1A1B1B1B1B1B1B
1B1A19181717171616161616161616171717171717171717
171717171717171717171717171717171717171717171717
171717171717171717171717171717171717171717171818
171717171716161616171819191A1A1A1B1A1A1A1A1B1B1C
1D1F2022242526282C353E464D4F5153545352504E4D4B49
474442403E3B383634353536363636363635353434333333
323231313030302F2F2F2F2F2F2F2F2F
292A2A2B2B2C2C2D2E2E2F2F303131323333333434353535
363636373737373738383838383839393838373736363638
393635373B4146444449515F6E8291948D70523C2D343D49
50463A2E2422211D1B1C1D20211F1C1B1A1B1B1B1B1B1B1B
1B1A19181717171616161616161617171717171717171717
171717171717171717171717171717171717171717171717
171717171717171717171717171717171717171717171818
1817171717171717171718191A1A1B1B1C1B1B1B1B1C1C1D
1F20232527282A2C303A434B52545557575654514F4D4A48
4543413F3D3A383634353535363636363635353433333332
323231313030302F2F2F2F2F2F2F2F2F
29292A2A2B2B2C2C2D2E2E2F303131323233333434343535
363636373737383838383838383939393938383838383839
3A3836373A3F434242464C535D6F7F8B8D7860483432353E
46433F372F2B26201B1B1B1B1C1C1C1E1E1C1B1A19191919
181818171717171616161616161617171717171717171717
171717171717171717171717171717171717171717171717
171717171717171717171717171717161617171717171717
1717171717171717171818191A1A1B1B1C1B1B1C1C1D1E1F
202225272A2B2D30343F4951585A5B5C5C5A57534F4C4945
42413F3E3D3A383635353535353535353535343433333333
32323131313030303030303030303030
2929292A2A2B2B2C2C2D2E2F2F3031323233333434343535
36363637373838383839393939393939393939393A3A3A3B
3C3A39393A3D4141414548494E5C6B7D887F715841373137
3E42433E37322C241D1B1919191B1C1F201D1A1816161716
161616161716161616161616161617171717171717171717
171717171717171717171717171717171717171717171717
171717171717171717171716161616161616171717171717
1717171717171717171819191A1A1B1B1C1C1C1D1E1F2021
2225272A2D2F313439444E575E5F6061605D59544F4B4742
3F3E3D3D3C3A383736363535353534343434343333333333
32323231313131303030303030303030
282929292A2A2B2B2C2D2D2E2F3031313233333334343535
35363737373838393939393939393939393A3A3A3A3A3B3C
3D3C3B3B3B3E414141464947474C5468798689745C4B3C3D
4043443C34322F29231F1C1B1B1B1C1E1F1C191715151615
151516161616161616161616161617171717171717171717
171717171717171616171717171717171717171717171717
171717171717171717171616161616161616171717171717
17171717171717181818191A1A1B1B1C1D1D1D1F20212324
25282A2E313336393E49535B62636364635E5A544F4A4540
3C3C3C3B3B3A383837363535343434343433333333333333
33323232313131313131313131313131
28282929292A2A2B2B2C2D2E2F3030313232333334343435
35363737383839393939393939393939393A3A3B3B3B3C3D
3E3D3D3D3D40424142464945424043566A85968977614D4A
4949483D3434322D2824201F1E1D1C1D1D1B181615151515
151515161616161717171717161717171717171717171717
171717171717171616171717171717171717171717171717
171717171717171717171616161616161616161717171717
171717171718181919191A1A1B1C1D1E1F1F1F2022232526
272B2E3236393C40464F596065656463615D58534E48433D
3A3A3A3A3A39383838373635343433333333333333333333
33323232323131313131313131313131
2828282929292A2A2B2C2D2E2F2F30313232333333343435
35363737383839393A3939393938383838393A3A3B3B3C3D
3E3D3D3D3D3F40414243434241434856646F79898F7C6B68
625950423836342D2826252727211B181617181717161616
161515151516161717171717171717171717171717181818
181717171717171616171717171717171717171717171717
171717171717171717171616161616161616161616161717
181818181819191A1A1A19191A1D1F222323222121232425
262B31373E43494F555C616567635E5A5553514E4A45403C
39393A3A3A39383838373535343333333232323233333333
33333232323232313131313131313131
282828282929292A2A2B2C2D2E2F30313232323333343434
353637373839393A3A393938383838383838393A3B3C3C3D
3D3D3D3D3D3E3F414240404143484E565D5B60829A8F8482
7A6A5A4C403C382F29292A2D2E251B171416181919181717
171616151516171718181717171717171717181818181818
181817171717171716171717171717171717171717171717
171717171717171717171716161616161616161616171718
18191919191A1B1C1C1B1A191A1E22262827262422242525
272E363E464E565D63676869676057504A4A4A4847423E3B
393939393938383838373534333333323232323232333333
33333232323232323232323232323232
27282828282929292A2B2C2D2E2F30313132323233333434
353636373839393A3A393938383838373838393A3B3C3D3D
3E3E3E3E3F3F3F4143424245494F534F4E56606F7D868C8B
86786A635B5045352A292A2C2E2822211F1D1C1917171717
171718191919181818181818181818181818181818181818
181818171717171717171717171717171717171717171717
171717171718181818171717161616161616171717171718
1819191A1A1C1D1F1F1D1B1A1A2025282B2F302B27282928
2A323B444E5860696F6F6E6C675D52474041444443403C3A
393838383838383838373534333332323132323232333333
33333232323232323232323232323232
27272828282829292A2B2C2D2E2F2F303131323232333334
343536373838393A3A3939383838383838393A3A3B3C3D3E
3E3F3F40403F3F42444344494E54564B44515D5D647B8D8E
8B81777670625341322F2F2D2D2B292A2924201B18181818
1819191A1B1A191818181818181818181818181818181818
181818171717171717171717171717171817171717171717
171718181818181818181817171717171717171818181818
19191A1A1B1D1F20211F1E1D1E23292C303537322E303130
323B454E5760697075726E6B64584C41393B3E3F403D3B39
383838373738383838363534333332323132323232323333
33333232323232323232323232323232
27282828282929292A2B2B2C2D2E2F303031313132323333
34343536373738393939393938383839393A3A3B3C3D3E3E
3E3F404040404042444444484B50534D4A4F565B63727D7E
7C7A7777746B625B52483D332B2C2E2E2D2823201E1D1C1B
1B1917161516171717171716161717171717171717171717
171717171717171717171717171718181818181717171717
171818181819191919191919191919191818181818181819
1919191A1A1B1D1D1F212325282C2F3436312E38403E3F43
4850585E64686B6D6D69645F585048413C3C3D3E3E3C3A39
393838373737373737363534343333323232323232323233
33323232323232323232323232323232
28282828282929292A2B2B2C2D2D2E2F2F30303131313232
3334343536363738383838393939393A3A3B3B3C3D3E3E3F
3F4040404141424344444446484C4E4F4F50535A62686D6D
6D71747372706E6F6D5E4E3C2F313432302B27252422201E
1C1916131214161718171616151616171717171717171717
171717171717171717171717171818181818181818181818
1818181919191A1A1A1A1A1A1A1A1A1B1A1A191919191919
1919191A1A1B1B1B1D22282E3334353A3B312D40504E4E57
5F666B6E6F6E6B68645E58524D4945413F3E3D3C3B3B3A39
393838373737373736363535343433333333333333323232
32323232313131313131313131313131
28282828292929292A2A2B2C2C2D2D2E2F2F2F3030313132
323334343536363737383839393A3A3B3B3C3C3D3E3E3F3F
4040404141424344454443444547494C4F53585F65696A69
686B6C65626A7174746E655445413D332C2A292A2A241F1C
1A181715151618191A191717161616161616161617171717
171717171717171717171717181818181818181818181818
181919191A1A1B1B1B1B1C1C1C1C1C1C1C1B1A1A1A1A1A1A
1A19191A1B1B1B1B1D252E363B3937373840484D5359606A
73787B7C79746D655D554E4843424140403D3B3A39393939
393838373736363636353535353434343433333333323232
32323131313131313131313131313131
282828282929292A2A2A2B2B2C2C2D2D2E2E2F2F30303131
3232333334353536373738393A3A3B3C3D3D3D3E3E3F3F40
4041414142434445454443424243454A4F565D6368686665
6364645C58626C72767773675A5146382E2D2E303028211D
1A191A19191A1B1B1C1A1918171717161616161617171717
171717171717171717171818181818181918181818181818
18191A1A1B1B1C1C1C1D1D1D1D1E1E1E1E1D1C1B1A1B1B1B
1A1A1A1B1C1C1D1D1F29323B413F3C393C51625E5D66707A
838686837D746A5F554D47403C3D3E40403D3A3938383939
3A3938373736363635353535353535353434343333333232
32313131313130303030303030303030
282828292929292A2A2A2B2B2C2C2D2D2D2E2E2F2F303031
3132323334343535363738393A3B3C3D3E3E3E3F3F404041
414242434445464747464545454547494D53585D61616061
626466686754495B6968696C6B645A4D413E3B39362F2926
2324262625221E1C1A1A1A1A191919181818181818181818
181818171717171717181818181819191919191919191919
191A1A1B1B1C1C1D1D1E1E1E1E1F1F20201E1C1C1C1D1D1B
1A1A1A1D21232527292C31363B42484D5567767A7D7C7B81
8484827A726A60564E494643413F3E3E3D3C3A3938393939
393837373636363535353535353535353534343333333232
31313131313030303030303030303030
282828292929292A2A2A2B2B2B2C2C2D2D2D2E2E2F2F3030
31313233333434353637383A3B3C3D3E3F3F3F4040404141
424344454647484849484847474748494B5055585B5B5C60
63646771724F374A59585C6A736F685E534D48433E38322F
2C2E2F2F2E27211C19191B1B1B1B1A1A1A1A191919191919
191918181818181818181818191919191919191919191919
1A1A1B1C1C1D1D1E1E1F1F1F20202021211F1D1C1C1E1F1D
1B1B1C2025292D3032302F31374555616E7B8790948B8384
837F7A6F645D564D4746464646423E3C3B3A3A3939393939
393837373636363535353536363636363535343433333232
31313131303030302F2F303030303030
282828292929292A2A2A2A2B2B2B2C2C2D2D2D2E2E2F3030
31313232333334353637393A3B3D3E3F4040404141414142
434445464748494A4A4A4948484748484A4E53555857585D
6263656C70706A53424A53565C6163605B5956544F463C34
2E2C2B2825211E1B1A1A1B1C1C1C1B1B1B1B1A1A1A1A1A1A
1A1A1919191918181818191919191A1A1A1A1A1A191A1A1A
1A1B1C1D1D1E1F1F202021212222232424201C1B1B1F221F
1D1E1F23282C303436312F2F354C6374838B8F93928B8486
847C716356514C444042444748433E3B39393A3A3A393939
393837373636363535363636363636363635353433333232
313131303030302F2F2F2F2F2F2F2F2F
28282828292929292A2A2A2A2B2B2B2C2C2D2D2E2E2F2F30
31313132333334353637393A3C3D3E404141414141424243
43454647484A4B4B4C4B4A4948484747494D51535555565C
616264676D8790603A42484244546060605F5D5D5A50463E
35302B25201E1D1B1B1B1B1C1C1C1C1C1C1C1B1B1B1B1B1B
1B1B1A1A1A1A1A19191A1A1A1A1A1B1B1B1B1A1A1A1A1A1A
1B1B1D1D1E1F2021222223232324252626211D1C1C202321
202122272C3034393C36323238547084949593928E878183
817568584A47453F3D4043484A443E3A37383A3A3A3A3939
393837373636363636363636363636363635353433333232
3131313030302F2F2F2F2F2F2F2F2F2F
272727272828282929292A2A2A2B2B2C2C2D2D2E2E2F2F30
31313233333435353638393A3C3D3E3F4040414142424343
44454748494A4B4C4C4B4A4947464646484C505356585A5F
636363636778837B6D50393D42434B5E6B5E524B464D5456
544A3E352D27221D191919191A1B1C1D1D1C1B1B1A1B1B1B
1B1B1B1B1C1C1C1C1C1C1C1C1C1C1C1C1C1C1B1B1B1A1A1A
1A1B1D1E1F20212223232324242525252525262525232121
2225282A2D333A434A4745454B62798995938E8B857F7A7B
796F64564B4948434142434445403C39373839393A393939
393838373737373736363636363636363635343433333232
313131303030302F2F2F2F2F2F2F2F2F
26262626272727282828292A2A2B2B2C2C2D2D2E2E2F3030
31323233343536363738393A3B3C3D3E3F40414142434344
454647484A4B4C4C4C4B494847454545474B4F53575B5F62
6463625F5F69758D9562393A3C3D45596556483D384A5A63
66594B4238312A221C1B1B1A1A1B1C1D1E1D1B1B1A1B1C1C
1C1D1D1D1E1E1E1E1F1E1E1E1E1E1E1E1E1D1C1C1B1B1A1A
1A1B1D1E1F202122242424252525252424292D2E2D262022
252A2F2E2F373F4B555657585D6F808B928E88837C777272
70685F554D4C4B4846444241403D3B393738383939393939
393938383838383837373737373636363535343433333232
31313131303030303030303030303030
2525252626262627272829292A2B2B2C2C2D2D2E2F2F3030
313233343536373738393A3B3B3C3D3E3F40404142434445
464748494A4B4C4D4D4B494847464546474A4E52565D6264
656460585359637C8C7D69472F45564E494541404145494C
4D494645433D37322D2A2623201E1C1B1A1A1B1B1C1C1D1E
1E1F1F1F1F202121212120202020201F1F1E1D1D1C1B1A1A
1A1B1D1F202122232525262728292928282D31312F262025
2B323735343A414D585C5F61657480888D8B86827D756E6B
67615B534D4D4D4B494542403E3C3A383738383839393939
3A3939393939393838383737373636363535343433333232
31313131313030303030303030303030
2424252525252626272828292A2B2B2C2D2D2E2E2F2F3031
3233343536373738393A3A3B3B3C3D3E3E3F404243434445
4648494A4B4C4D4D4D4C4A4947464546474A4D51555D6365
64635F554D4C526A809092653F3F3F4145444342403E3C38
373A3F444744413F3C37322C27231F1C1A1B1C1E1F1F2021
2222222222222323232322222121212121201F1E1D1C1B1B
1B1C1E1F2122232526272828292A2B29292E32312F27232A
3139403D3B3D414E5A61676A6E788084878683807B726A65
5F5B56504C4D4E4D4C47423E3C3A3A38383838383939393A
3A3A3A393939393939393837373636353534343433333232
32313131313131303030303030303030
2424242425252626272728292A2B2B2C2D2E2E2F2F303031
32333435363738393A3A3B3B3C3C3D3E3E3F414243444546
47484A4A4B4D4E4E4E4C4B4948474646474A4E5155595D5F
6061605C595556616E7E8983744D2F384143464745413C37
32333435373B3F4244403C39342E29242123252728282829
292827262525252424242323232323232221201F1E1D1C1B
1B1E2022242627292A29292928292A2A2A29282726282B31
38404646453F3D47525E696D717A818485817C78736D6762
5D57514B46484B4B4B46413E3B3B3A3939393939393A3A3A
3A3A3A3A3A3A3A3A3A393938373736353534343433333232
32313131313030303030303030303030
2324242425252526262728292A2B2C2D2E2E2F2F30303132
323435363738393A3B3B3B3C3C3D3D3E3E40414244454647
48494A4B4C4D4E4F4F4D4C4A49484747474A4E5154555758
5B5E616465615D5A5C6C7C9095673F322D46594C41403D37
312E2B28293139404443413F3D38322E2A2C2F3031313030
2F2E2C2A29282726252525242424242424232221201F1D1D
1D1F222427292A2C2D2C2A2928292A2B2B262321222B3438
3D464D5050453E4752616E72767D8285847E77726D696460
5B534C454144484A4A46413E3C3B3B3A3939393A3A3A3A3B
3B3B3B3B3B3B3B3B3B3A3938383736353534343433333332
32323131303030303030303030303030
2323242425252526272728292A2B2C2D2E2F2F3030313232
3334363738393A3B3C3C3C3C3D3D3D3E3F40414344454648
494A4B4C4D4E4F50504E4C4B4A494847484A4D5052515153
565C61696E6B665B555F6C808C7D6A49334856473C3F403E
3B352F2925272A2C2E30323537383A3B3C3B3A3938373534
32312F2E2C2B292827272726262626262625242322212020
2022242627292B2C2C2C2B2A292828292A2A2A2D30373C39
39454F575B534F5E6C798484848A8D8C898179726C67625C
564E47423F43474A4B46413E3B3B3B3A3A3A3A3A3B3B3B3B
3B3C3C3C3C3C3C3C3C3B3A39383837363635353535343434
33333232323131313131313131313131
23232424252526262728292A2B2C2D2E2F2F303131323233
34353738393A3B3C3D3D3D3D3E3E3E3F3F41424445464748
494B4C4D4D4F4F50504F4D4C4A4A4A48484A4D4F504E4D4F
535A626D75746F6055565D6E7F90947250372A475D4C4042
413B352C25221F1C1B20252A2F363D434644403E3B3A3937
353332312F2D2B2A28282828282727272725242423222222
2223252628292B2B2C2C2B2B2B2C2D30333335393E43463E
3B49566169656578889096928E9293908B8278716B656059
524B443F3D4146494B46413D3B3B3B3A3A3A3A3A3B3B3B3B
3B3B3C3C3C3C3C3C3C3B3A39393837363635353535343434
33333332323232323131313132313131
232424252526262728292A2B2C2D2E2F3030313232333434
353738393A3B3C3D3E3E3E3F3F3F40404142444546474849
4A4B4C4D4E4F5050504F4D4C4B4B4A49494B4C4E4F4E4E50
535960697072726A6362656D77848A81735845525A4C413E
3C3C3D3B382E241D181C2124282D32373A39373635363636
36343332302E2D2B292929282727262524232220201F1F20
2122242627292B2D2E2F3030302D2B2B2E343B444B4F514D
4D5B68727C7E8497A5A39E948A8C8D88837B736D67625C56
5049443F3D4145484944403D3A3A3A393939393939393939
3A3A3A3A3A3A3A3A39393837363635343333333232313130
30303031313131313131313131313131
2424252526272728292A2B2C2D2E2F303132323333343536
3738393A3B3C3D3E3F40404041414242434445464748494A
4B4C4D4D4E4F5050504F4E4D4C4B4B4B4A4B4C4D4E4E4F51
54595F656A7073717070707172767A8388847A604A49473F
3B3F434746382B211A1C1F202225272A2D2D2D2D2E313335
36353332312F2E2C2A2A29282726252322201F1E1D1D1E1F
2021232426282B2D2F3032343637393C4044494F55585C5C
606E7B858E96A0B2BCB0A2918384857F7A736C68635D5853
4E4944403E41444647433F3C393939383737373838383838
38383838373737373736353534333332323130302F2E2E2D
2D2E2E2F2F3030313131313030303030
25252626272828292A2B2C2D2E2F30313233343435363637
38393A3C3D3E3F4040414142424344444546474849494A4B
4C4C4D4E4F4F5050504F4E4E4D4C4C4C4C4C4D4E4E4F4F52
54595E62676C707172787C7C7C7877848D8A8376675B4E40
363A3E414239312C282726242321201F1F2225282B2E3235
3735343331302F2D2C2B2A2827262422211F1E1D1C1D1E20
21212121222325272A2E32373E4C5A666C645B57555C6569
71808E99A2A8AEB9BDAD9B88797878736E68625E5B575450
4D4844403E40434444413E3C393938373737373737373737
3737363636353535353434333232323130302F2E2D2C2C2B
2B2C2D2E2F2F30313131313030303030
2626272828292A2A2B2C2D2E303132333434353636373839
3A3B3C3D3E3F40414242434444454646474848494A4A4B4C
4C4D4E4E4F50505051504F4E4E4D4D4D4D4D4D4E4F4F5052
55585C5F63676B6E727D8586847972808C9192887C6C5B4A
3D3D3E3E3E3B393836312C29241F1A1715191E22262A2E32
3434333231302F2E2C2B2A2927252321201F1E1D1D1F2124
252321201F202223272F373F474F565D61605E5D5F666F76
808F9DA8B0B2B2B7B5A3907D6D6C6C67645E595653514F4E
4C4844413F41424343403D3C3A3938373636363737373636
36363635353434343333333232323131302F2E2D2D2C2B2B
2B2C2D2E2F2F30313131313030303130
272828292A2A2B2C2D2E2F3031323334353636373838393A
3B3C3D3E3F404142424344454646474849494A4A4A4B4B4C
4C4D4E4F4F5050515150504F4F4E4E4E4E4E4E4F4F505051
5355585A5C5E616368747E82847B757C838D938D857F776F
675A4E42393A3B3A38322B27231F1C19191C202326262627
282A2C2D2E2E2D2D2C2C2B29282523211F1F202022272C30
332E292623222323262D353C444A50565C6064696E757D84
8D99A3AAAEAAA4A19B8D7F7065666766645D5754504E4C4A
494644434242434343403E3C3A3938373636373737383838
3837373636363635353535353534343433323131302F2F2E
2E2F2F30303131323232313131313131
29292A2B2B2C2D2E2F3031323334353637383839393A3A3B
3C3D3E3F40414243434445464748494A4A4B4B4B4B4C4C4C
4D4D4E4F50505151515151505050504F4F4F4F5050505151
525354555757585A5E6A757D827E7A7A7C848B8E908F8C8E
8975604C3D3F413F3D352E292623211F1F20222425221F1E
1E2226282B2B2B2C2C2C2B2A282523201F202223272E353B
3E38312C28272727282E343B44525F6C7575757679838C92
999FA4A7A69C92897F766E655E606262625B55514D4B4A48
464645444444444443413F3D3B3A39383737383839393939
393938383737373737373737373736363635343433333232
31313232323232323232323232323232
2B2C2D2E2E2F303131333435363738393A3B3B3C3C3D3D3E
3E3F404142434445464748494A4B4C4D4D4D4D4D4D4D4D4E
4E4F4F505151525253535252525252525252515151525252
52525252535253575C656D747A7D7E7E7F85898C8D8D8D92
93887B6D6059534A433E3936332E2B2825211E1C1A1B1D1E
202223252728292A2A2A2A2A292522201F2123252930373E
423D383533333536394048505A66727D8587888A8D969EA4
A7A49F9B958B80756B6765615F5C59575653504E4B4A4847
474747464645444342413F3E3C3B3A393839393A3A3A3B3B
3B3A39383837373737373737373736363535343333323131
30303030302F2F2F2F2F2F2F2F2F2F2F
2E2F2F303131323334353637383A3B3C3D3D3E3E3E3F4040
414243444445464748494A4B4C4D4D4E4F4F4F4F4F4F4F4F
4F5050515152525353535353535353535353535252535453
53525150504F50555A5F656B727B81818183858789898B92
969490887E7265584D4A4845423C37332E28231F1C1C1E1F
20212223242627292A2A2A2A292624222124282B2F353A40
43413E3D3C3D4042475059636D79848F96979696979FA5AA
ABA1968D837A71655C5C5C5D5C5752504D4D4C4B4A494847
47474848474645434241403F3E3D3C3B3A3B3B3B3B3B3C3C
3B3B3A393838383737373737373736363635343433323231
3130302F2F2F2E2E2E2E2E2E2E2E2E2E
2E2F2F30313132333435363738393A3B3C3D3E3F40414243
44454546474848494A4A4A4A4B4B4B4B4C4C4D4E4E4F4F4F
505050505050505050505050505050505051515152535454
5453515050505154585B5F646B767E7F7F7F7F8487888888
888A8B8B8880766E67635F5A554E47413B35302B2724211F
1E1F212325282B2D2F2C2A292828292A2C3135393C3F4042
43413F3F3E3E3E404552606C78828B949995908C898D9192
928B847E78736E675F58524E4B4D4E4F504D4A4846464545
4546474747464645444443424241403F3E3E3D3C3B3A3A39
393939393939393838383737373737383837373636363535
35343434343433333333333333333333
2F2F3031313233343435363738393A3B3C3D3F4042434445
464748494A4A4B4C4C4B4B4A4A4A4949494A4C4D4E4F4F50
50504F4E4E4E4D4D4D4D4D4D4D4D4D4E4E4F505051535454
545352515050515457585A5E65717C7E7E7B797F8385857F
7C80858B8F8A85827E79746E675F58514A4845423E342B24
1F212324272B2E31332F2B28272A2E32373D42474A474542
3F3F3F40403E3D3E4354667481878B90918C86807B7B7B7A
797673716E6D6C6863584E4641464C4F524E494745454545
4546474748474747464646464545454443413F3E3C3A3937
3738393A3A3A3A3A39383736363738383939383838383737
37373737383838383838383737373737
313132333334343536373738393A3B3C3D3F414244454748
494A4B4C4C4D4E4E4E4D4C4B4A49484848494B4D4E4F5051
51504F4E4D4D4C4C4B4B4C4C4C4C4C4C4D4E4F5152535556
56545251505050525554565B62717C7E7E756F737A848C88
858382868A8B8C8D8D88837C75716C65605D59554F443930
29282726272A2E31322E2927262B31373E464C53554D443C
36383B3D3F3B39393F5265748083848686817C77726F6D6A
686A6B6C6C6965625E5A55524F4E4E4D4D4B4B4A4A4A4A4A
4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A4A494644413F3C3A38
38393A3B3C3C3B3B3A383735343536373736363535353434
34343435353535363636363535353535
343535363637373839393A3B3C3C3D3E4041434547484A4B
4C4D4E4E4F505050504F4D4C4B4A4948484A4C4D4F505152
5251504E4D4D4C4C4B4B4B4C4C4C4C4C4D4E505152545656
575553515050505153525459606F7C7F7E72686B70818E8D
8A847F8285898E9395918C8681807F7B7466584C43434342
4038302B292D313435302C29292E353B434D555C5E514437
2E33393D403C3A3B405365737E7E7C7C7A77736F6A65615C
5A5F64686965605D5A5B5B5A5854504D4A4B4D4E4F4F4F4F
4F4E4E4D4C4C4C4C4C4D4D4E4E4E4E4E4D4B484542403D3B
3A3C3D3E3F3F3E3D3C3A3836353637373737363535343433
33343536373738383838383838383838
3B3C3C3D3D3E3E3F40404142434444454648494A4B4C4D4E
4F50505051515252525150504F4E4E4D4D4E4F4F50505151
515151505050504F4F4F4F4F505050505051525354555657
5755535150505152545455585F6E7B8284776B6665717D82
868685888988878786878786858483817C736A615A56524E
49433D3936393B3D3E3A3735343436393F4B555E61534333
28313C454D4D4D5157636F787E7D7B7A7876726F6B67635F
5D5E6060605E5B5A58565452505050505050505050515252
51504E4D4B4A494848494A4B4C4C4C4D4C4A484745434240
40414243434241403E3C3A383738393A3B3A393838383737
38393B3D3E3F41424342424141414242
4243434444454546464748494A4A4B4C4D4D4E4F4F505051
515152525253535353535353525252525252515151515151
515152525253535353535353535353545454555555565657
5655535251515254555556585C6A7681867C716761666D76
7F8488898986827E7B7F838688868483828282817D766E67
5F58504A45474A4B4B494645423E3B3B3F4B576165574837
2C3745515C5E61686D73787B7D7D7B797775726F6C696562
5F5D5C5A5958575655524F4C4B4E51535554535353545555
5553504E4C4B494848494A4B4C4C4D4D4D4D4C4B4A494948
48494A4A4B49484746444241404143444444434342424242
4346494B4D4F51535454535352535353
464747484849494A4A4B4C4C4D4E4F4F5050505050505151
515152525353535353535454545454545353525251515050
505152525354545555555454545454545454545454545555
555452515152535454545554555D66707A7D7E7973686166
6D757D7E7F8386888989898A8B8B8A8A8986848180848688
8577695E575C616364605C5A564D474547525E696F6A6256
4E555D666E7073787C7E8080807E7C7A7774706C68635E59
565452504E4D4C4C4C4C4C4C4D4E50515253535454555657
56555352504F4F4E4D4E4E4F4F505050505050504F4F4F4F
5052545657585858585756555557595A5C5C5C5D5E5F5F61
6266696D707375787979787777777878
4B4C4C4D4D4D4E4E4F4F5051515252535353535352525252
525353535454545454555555555656565655545352525151
515153535455565657565656565656565555555555555555
555453535354555555555552525459636E7E8A8B85705E5E
606A74757780888D908E8C8C8D8D8E8E8E8C8B8988878685
827C76716E7277797976726F6A615954545D677078787772
6E7074797E8082858787868482817F7C7874706C67625C57
53514F4D4C4A4A4A4B4E50525455555657585A5B5C5D5E5E
5F5E5D5C5B5B5B5B5B5B5B5C5C5C5C5D5D5D5D5D5E5E5E5F
606365686A6C6D6F70706F6F707273757677797A7B7D7E80
82868A8D919497999B9A9A9999999999
555555545454545454555556575758585959585858585858
585858585858585858585858585858595858585757575757
57575757575858585959595A5A5A5B5B5B5B5A5A5A5A5A5A
5A5A5959595B5C5C5C5B5A5857575A626C7E8D959686766F
6A6F747475797C80838486888A8D90929392908E8B888582
7F8081818284868888878583817C77716D7175787A777679
7C7E8182828484858585858584817E7B7775726F6C686460
5E5D5C5C5C5B5B5B5D60636567696A6B6D6E707173747577
777778787879797A7A7C7D7E7F8081828383828282838384
848687888A8D8F919395969798979696969798999A9B9C9D
9EA1A3A5A8A9ABADAEADADACACACACAC
5F5E5D5C5B5A595959595A5B5C5C5D5D5D5D5D5D5D5D5D5D
5D5C5C5C5C5B5B5B5B5B5B5B5B5B5B5B5B5B5B5B5C5C5C5D
5C5C5B5A5A5A5A5A5A5B5C5D5D5E5E5E5F5E5E5E5E5E5E5E
5E5E5E5E5F60626262605E5D5C5B5D626A7B8C99A0988D81
77767777787776787A7E8285898E929697938F8C898B8C8C
8D8E8E8F90919193949493949494938B8483817E7B75747E
878B8D8A87888886858687898985817E7B7A797876747170
6F6F70717272727375787B7D8082838587888A8C8D8F9092
939495969798999A9B9D9FA1A3A4A6A7A8A7A7A6A6A6A7A7
A7A7A7A7A9ACAFB2B5B8BABCBCB8B4B2B0B1B2B1B1B2B2B2
B3B4B5B6B7B8B9B9B9B9B9B8B8B8B8B8
62605F5E5D5C5B5A5A5A5B5C5C5C5D5D5D5D5D5D5D5D5D5D
5D5D5C5C5B5B5A5A59595959585858585859595A5B5C5C5D
5D5B5A595858585858595A5A5B5B5C5C5C5C5C5C5C5C5D5D
5D5D5D5D5E60626362605D5C5B5C5E636A727B868F93938A
828283878A847F7D7D8186898B8E909293918F8E8C8A8987
878D9296999592939395979A9DA0A0978E8A857E786D6A78
868E94918E9192908F909193938F8A8886888A8B8C8C8C8D
8E8F8F909192949597999B9D9FA1A4A6A8A9ABACAEAFB1B2
B3B4B5B6B7B7B8B9BABCBEBFC1C3C4C5C6C5C5C4C4C5C5C6
C5C3C2C0C1C4C8CBCED1D3D5D4CCC4BFBABABAB8B6B5B4B3
B3B3B4B5B5B5B5B6B6B5B5B4B4B4B4B4
696866656463626160606161616161626262626262626262
626161605F5F5E5E5D5D5C5C5B5B5A5A5A5B5D5E5F606161
61605E5C5B5B5B5A5A5B5C5C5D5D5D5D5D5D5D5E5E5E5F5F
5F5F5F606062646565625F5E5D6063686C6D6F77808E9894
908F8F969990888482878C8E9091929393939392918F8D8B
8C92989D9F99949494979B9FA4AAACA197918A827A6D697A
8B959D9B989D9F9E9D9E9EA1A29D9A97979A9FA2A5A7A9AC
AEAFAFB0B1B3B5B6B8B9BABBBDBFC1C3C5C6C7C8CACBCCCD
CECFCFD0D0D1D1D2D2D3D5D6D7D8D9D9DAD9D9D8D8D8D9D9
D8D5D2D0D0D5DADDE0E3E4E5E2D6CAC1BAB8B7B4B1AEACAA
A9AAABABACADADADAEADACABABABABAB
7A797776757473727271717170706F6F6F6F6F6F6F6F6F6F
6F6F6E6E6E6E6D6D6D6C6B6A6A696868686A6B6C6D6E6F70
706E6C6B6969696868686868686766666566666667676767
6867676767696A6B6B6866646466686B6E6F71767D8A9497
98959192928E8B89898D9295989A9C9E9F9F9F9F9FA0A0A0
A0A1A3A4A4A09D9D9E9FA0A4A9AEB0A59A96918E8C888A9A
A9B0B5B4B2B7BAB9BABBBBBEBEBCBAB9B8BBBFC1C4C6C8CA
CBCCCCCCCDCECFCFD0D1D1D2D2D3D4D5D5D6D6D6D7D7D7D7
D7D7D7D7D7D7D6D6D6D5D4D3D3D2D2D1D0CFCDCCCCCCCCCC
CCCAC9C8C9D1D8DDE0E1E1DFD9C9B9ACA2A09F9B9794918F
8F9195989B9EA0A2A4A2A1A09F9FA09F
908F8D8D8C8B8A8988878686858483828282828282828282
8282818181818181807F7E7E7D7C7B7B7B7C7E7F80818283
83817F7D7C7C7B7B7A7A7979787775747474747475757575
75747473737475767674737272747677797A7B7D818B959E
A39F9A9794959697989B9FA2A6A8AAADAEAFB0B0B1B2B3B2
B2B1AFAEACAAA9AAABAAAAADB0B5B6ABA19D9B9DA1A4AAB8
C3C7CAC9C8CDD0D1D2D3D4D5D6D5D4D4D4D6D8DADBDCDEDF
E0E0E0E0E0E0E0E0E0E0E0E0E0DFDFDFDEDEDDDDDCDCDBDA
D9D9D8D7D6D6D5D4D2D0CECCCAC9C7C6C4C2C0BEBDBDBDBD
BDBCBCBCBFC9D2D9DDDDDAD7CEBBA7978A8886827F7B7776
767B81868C9094999B99979594959695
B5B4B2B1AFAEADACAAAAA9A9A8A7A6A6A5A5A5A5A5A5A5A4
A4A2A19F9E9D9C9B9A99999998989897989899999A9A9B9B
9B9A989796969695959494939391908F8E8E8E8E8E8D8D8D
8D8B8A8A89898A8B8C8D8F919496999A9B9C9E9E9FA3A7B0
B7B7B6B4B3B7BABCBEBFC0C1C3C4C5C6C7C8C8C9CACBCCCC
CCC9C5C3C1C1C1C4C6C4C3C6C9CDCEC2B7B2AFB2B6BBC1CA
D1D3D4D4D4D7DADBDCDCDBDBDBDBDAD9D9D9DADADBDBDBDB
DBDCDCDCDCDCDCDCDBDBDADAD9D9D8D7D7D6D5D3D2D1D0CF
CECDCCCBC9C8C7C6C5C5C4C3C3C2C2C1C0BDBAB7B5B4B4B4
B4B3B3B4B8C3CED6DBDBD8D4CBB5A08E7F7E7D7A7773706F
71777D838A8F959A9D9B989695969696
D3D2D0CECCCBCAC8C7C7C7C6C6C5C5C5C4C4C4C4C4C4C4C4
C3C1BEBCBAB9B7B6B5B4B4B4B4B3B3B3B3B3B4B4B4B5B5B5
B5B4B4B3B3B3B2B2B2B1B0AFAFAEADACABAAAAA9A9A8A8A8
A7A6A5A5A4A4A4A5A6AAAEB1B5B8BABBBBBEC0BFBEBBBBC2
C9CCCFCECED4D8DBDCDBDADADADADADADADBDCDCDDDEDFE0
DFDBD7D4D2D3D5D8DAD8D6D8DBDFDED2C7C2BEC2C8CCD1D6
D9D9D9D9D9DBDDDEDEDDDCDBDADAD9D9D8D7D6D5D5D4D3D3
D2D3D3D3D3D3D3D3D2D1D1D0CFCFCECDCCCBC9C8C7C5C4C3
C1C0BFBDBCBBBAB9B8B9BABABBBCBCBCBBB7B3B0ADACACAC
ACABABADB1BDC9D2D8D8D5D2C8B19A8677767673726E6C6C
6E747B828990969CA09E9B9997999999
D8D6D5D3D2D1D0CFCFCFD0D1D1D2D2D2D3D3D3D3D3D3D4D4
D4D3D3D3D2D2D2D1D1CFCECDCDCCCBCACACCCDCED0D0D1D2
D3D3D3D4D4D3D3D2D1D0CFCECDCDCDCCCCCBCBCACAC9C9C9
C9CACACBCBCBCBCBCCCED0D1D3D4D4D3D3D5D6D6D5D2D1D5
D8DADCDBDBDDDFE0E0DFDEDEDDDDDCDCDBDCDCDDDDDEDEDE
DDDBD8D6D5D5D6D9DAD8D6D8DADCDCD0C7C3C2C5C8C8C9CD
CFD0CFCFCECFCFCFCFCECDCCCBCACAC9C9C8C8C7C7C7C6C6
C6C7C7C7C7C7C7C7C7C7C7C6C6C6C6C6C5C4C3C2C0BFBFBD
BDBCBBBABAB9B8B8B8B9BABABBBCBDBDBDB9B5B2B0B0AFAF
AFAEAEAFB3BFCBD3DAD9D6D3CAB59F8A7A78787675716F70
72777E848B939BA2A6A4A1A09E9FA0A0
D5D4D3D3D2D2D1D1D1D3D4D5D7D8D9DADBDCDCDDDDDEDEDF
E0E1E2E2E3E4E4E4E4E2E0DEDCDBDAD9D8DADDDFE1E2E3E5
E6E8E9EBEBEBEAE9E8E7E5E3E2E2E2E2E2E1E1E1E1E1E1E1
E2E4E6E8E9E9E8E8E8E9E9E9E9E8E7E6E5E6E7E7E7E4E2E3
E3E4E5E4E3E3E2E2E1E0DFDEDDDCDBDADADADADADADADAD9
D9D8D7D6D6D5D5D6D7D5D4D5D6D7D5CCC3C2C2C5C6C2C0C2
C4C5C5C4C2C2C1C0BEBEBDBDBCBBBBBABABABABABABABABB
BBBBBCBCBCBDBDBDBDBEBEBEBEBFBFBFBFBEBDBCBBBBBAB9
B9B9B9B8B8B8B8B8B8B9BABBBCBDBEBEBEBBB8B5B3B3B3B3
B3B1B1B2B5C0CCD4DBD9D6D4CCB9A48E7D7A7A7978747273
757A80858C969EA6ACAAA7A5A4A5A6A6
C8C8C8C8C8C9C9CACBCCCECFD1D3D4D6D7D9DADCDDDEE0E1
E1E1E1E1E1E1E1E0DFDCD9D6D4D2D0CECDD0D2D4D6D7D9DA
DCE0E3E6E8E8E7E6E5E2DFDCDAD9D9D9D9D9DADADBDBDCDD
DEE1E3E6E7E7E6E6E6E7E8E8E9E9E8E8E8E7E6E5E5E5E5E5
E5E4E2E1E0DFDEDDDCDBDAD9D8D6D5D4D4D4D4D4D4D4D4D4
D3D3D2D1D0CFCECECECCCACBCACAC8C0BABCBFC2C4C0BDBF
C1C1C1BFBDBCBBB9B8B8B8B8B8B8B8B8B8B9BABABBBBBCBD
BDBDBEBEBEBEBEBEBFBFC0C0C1C1C1C1C1C0BFBEBEBDBCBC
BBBCBCBCBCBCBCBDBDBCBCBCBCBCBCBBBAB8B5B3B1B1B2B2
B2B1B1B1B5C0CBD4DAD7D3D1C9B6A28A77747372726D6A6B
6E72787E85909BA4AAA8A5A4A2A3A4A4
B9BABBBCBDBEBFC0C1C3C5C7C9CACCCED0D3D5D7D9DBDCDE
DEDEDEDDDCDBDBD9D7D4D0CCC9C6C3C1C0C2C4C7C9CACBCD
CFD5DADEE1E1E0E0DED9D5D0CDCCCCCCCCCDCECFD0D1D2D4
D6D9DDE0E2E1E0E0E0E1E3E3E4E4E5E5E5E3E1E0DFE1E3E3
E2E0DEDCDBDAD9D8D7D5D4D3D1D0CFCECECECECFCFCFCFCF
CFCFCECDCCCAC8C7C6C4C2C2C1BFBDB7B3B7BBBEC1BCB9BB
BDBDBDBBB8B7B6B4B2B3B4B5B6B5B5B6B7B8B9BABBBCBDBE
BFBFBFBFBFBFBFC0C0C1C2C2C3C3C3C3C3C2C1C0C0BFBEBE
BDBEBFC0C0C1C1C1C1C0BFBDBCBCBBBAB9B6B4B2B1B1B2B2
B2B1B1B1B5BFCAD3D9D6D1CEC6B5A18874706E6D6D686566
686D73787F8B97A2A9A7A3A2A1A2A3A3
B2B3B4B5B6B7B8BABBBDBFC0C2C4C6C8CACCCED1D3D5D6D8
D9D9D9D9D8D8D8D6D4D0CBC7C3BFBBB8B7B8BBBDBFBFC0C1
C4CBD1D6DADAD9D9D7D1CBC5C1C0C0BFBFC0C1C2C4C5C6C8
CAD0D5D9DCDCDCDCDCDDDDDDDDDDDCDCDCDBDBDBDBDBDBDB
DADBDBDBDBDBDBDBDBD9D7D5D3D2D1CFCFD0D1D3D4D4D5D5
D5D5D4D3D2D0CFCECCCAC8C7C6C4C2BDBABBBDBEBFBCBABC
BDBDBCBBB9B8B7B6B5B5B5B5B5B5B4B4B4B5B6B7B8B9BABB
BCBCBCBCBCBDBDBDBEBEBFBFC0C0C0C0C0BFBEBDBDBCBBBB
BBBCBDBEBEBFC0C0C0BFBFBEBDBDBDBCBBB8B6B4B3B3B3B3
B3B2B1B1B4BFC9D2D8D5D0CFC8B8A48A75716F6F706A6769
6B6E73777E8B97A2A9A7A4A3A2A3A4A4
ADAEAFB0B1B2B4B5B6B8B9BBBDBEC0C2C4C6C9CBCDCFD0D2
D3D4D4D4D4D4D3D2D0CBC5C1BCB8B4B0AEB0B1B3B5B5B5B6
B9C1C9CFD3D3D2D1CEC7C0BAB5B4B3B2B2B3B4B5B7B8B9BB
BEC5CCD2D6D6D6D7D7D8D8D7D7D6D5D4D4D5D5D6D6D5D4D4
D4D5D7D9DADBDCDDDCDAD8D6D4D2D1D0CFD1D4D5D7D8D9DA
DBDAD8D7D6D5D4D2D1CFCDCBC9C7C5C2C0BFBEBDBDBCBCBC
BDBCBCBBBABABAB9B9B8B7B7B6B5B4B4B4B5B6B7B7B8B9BA
BABBBBBBBCBCBCBDBDBEBEBEBEBFBFBFBFBEBDBCBBBABAB9
B9BABBBDBEBEBFC0C0C0BFBFBEBEBEBEBDBAB8B6B4B4B4B4
B4B2B1B1B4BEC8D1D8D4D0CFC9BAA78C76716F70716C696A
6C6F72767C8996A1A9A7A4A3A2A3A4A4
ADAEAFB0B1B2B4B5B6B8BABBBDBFC1C2C4C7C9CBCECFD1D2
D3D4D3D3D2D2D1D0CEC9C3BFBAB5B2AEACAEB0B2B4B4B4B6
B9C1C8CED3D2D0CFCBC4BDB6B0B0AFAFAEAFAFB0B2B3B4B6
BAC2CAD1D6D7D7D8D9DADADAD9D9D8D7D7D7D8D8D9D8D7D6
D5D6D6D7D8D8D8D8D8D6D3D2D0CECDCCCCCFD1D4D6D8D9DA
DBDAD9D7D6D5D3D2D0CDCBC9C6C4C2C2C0BEBCB9B8B9BABB
BCBBBABABABABBBBBBBAB9B8B7B6B5B4B4B5B7B8B9B9BABB
BCBCBDBDBDBEBEBFBFBFC0C0C0C0C0C0C0BFBEBDBCBBBBBA
BABCBDBFC0C1C2C3C3C2C2C1C0C0C0BFBEBCB9B7B6B6B6B6
B5B3B2B1B4BEC8D1D7D4CFCEC9BBA98D76716E6F716B686A
6B6D70727886939FA7A5A2A2A1A2A3A3
B0B1B2B3B4B5B6B7B8BABCBEC0C1C3C5C7C9CCCED0D2D3D5
D5D5D5D4D3D3D2D0CEC9C4BFBBB6B3AFAEAFB2B4B6B6B7B8
BBC3CBD1D4D3D0CECAC3BCB5AFAFAFAEAEAEAEB0B1B1B3B5
B9C2CBD3D9DADADCDCDDDEDDDDDDDCDCDBDCDCDCDCDBDAD8
D7D7D7D8D8D7D6D6D5D3D1CFCECCCBCACBCED1D3D6D8D9DB
DCDBD9D7D6D5D3D1CFCDCBC8C5C3C1C1C1BEBBB7B5B8BABB
BBBBBABABABBBCBCBCBBBAB9B8B7B6B5B5B6B8B9BABBBCBD
BDBEBEBEBFBFC0C0C1C1C1C1C1C1C2C2C1C0BFBEBDBCBCBB
BBBDBFC0C1C3C4C4C5C4C3C2C1C1C1C0BFBCBAB8B6B7B7B6
B6B4B2B2B4BDC7D1D7D3CECEC9BBAA8D76706D6F706B6769
6A6C6E707584929DA5A4A1A09FA1A2A2
B5B6B7B8B9BABBBCBEC0C1C3C5C7C9CBCDCFD2D4D6D8DADB
DCDBDBDAD9D8D7D5D3CECAC6C2BEBAB7B6B8BBBDBFBFC0C2
C4CCD3D8DBDAD7D5D1CAC3BCB7B6B6B6B6B6B7B9BABBBDBF
C3CCD4DBE1E2E2E3E4E5E5E5E5E4E4E3E2E2E1E1E1E0DFDE
DDDCDCDCDBDBDAD9D8D6D4D2D0CFCECDCDD0D2D5D7D9DADC
DCDBD9D8D6D5D4D2D0CDCBC8C5C3C1C1C0BEBCBAB9BABCBC
BDBCBBBBBBBBBBBCBBBBBAB9B8B7B7B6B6B7B8BABBBCBDBE
BEBFBFBFC0C0C0C1C1C1C2C2C2C2C2C2C2C1BFBEBDBCBCBB
BBBDBEC0C1C2C3C4C4C3C2C1C0C0BFBEBDBBB9B6B5B5B5B5
B4B2B1B1B3BDC7D1D7D3CECDC8B9A78B736E6B6C6D686466
686A6C6F7583919DA5A4A1A09FA0A1A1
B9BABBBCBEBFC0C1C3C5C7C9CBCCCED0D2D5D8DADCDEE0E1
E2E1E0DFDEDDDCDAD7D4CFCCC8C4C1BFBEC0C3C5C7C8C8CA
CDD3DADFE1E0DDDBD7D0C9C2BEBDBDBDBDBEBFC1C3C5C7C9
CDD5DDE3E8E9E9E9EAEBEBEBEBEBEAE9E9E8E7E6E5E4E4E3
E2E1E0E0DFDEDDDDDBD9D7D5D4D2D1D0D0D2D4D6D8DADBDC
DDDBDAD8D6D5D4D2D0CECBC9C6C4C2C1C0BFBEBDBDBDBEBE
BEBDBCBCBBBBBBBBBABAB9B8B8B7B7B7B7B8B9BABBBCBDBE
BFBFBFBFC0C0C0C1C1C1C2C2C2C2C2C2C2C0BFBEBDBCBCBB
BBBCBEBFC0C1C2C3C3C2C1C0BFBEBEBDBCB9B7B5B3B4B4B4
B3B1B0B0B3BDC7D1D7D3CECDC7B8A588716B696A6B666264
66686C6F7583919DA6A4A1A09FA0A1A1
BABBBCBDBEBFC0C2C3C5C7C9CBCDCFD1D3D6D8DBDDDFE1E2
E3E2E1DFDEDDDBDAD7D3CFCCC8C5C2BFBEC0C2C5C7C7C8C9
CCD2D9DDE0DFDCDAD6CFC8C1BCBCBCBBBCBDBFC1C4C6C8CB
CFD6DDE3E8E8E8E9E9EAEBEBEBEAE9E8E8E7E6E6E5E4E3E2
E1E1E2E2E2E2E2E2E1DEDCDAD8D6D4D3D3D5D7D9DBDCDDDE
DFDDDCDAD9D8D6D5D3D1CECCC9C7C5C3C1C1C1C0C0C0BFBF
BFBEBDBCBBBBBBBABAB9B8B7B7B6B6B6B6B7B8B9BABABBBC
BDBDBDBDBEBEBEBFBFBFC0C0C0C0C0C0C0BFBDBCBBBABAB9
B9BABCBDBEBFC0C0C1C0BFBEBDBDBDBCBBB9B6B4B2B3B3B3
B2B0B0AFB2BDC7D1D7D4CECDC7B7A488716B696A6B666364
66696D707685939FA7A5A2A1A0A1A3A2
BABBBCBDBEBFC1C2C4C5C7C9CBCDCFD1D3D6D9DBDEE0E2E3
E4E3E1E0DEDDDBD9D7D3CFCCC9C5C2C0BFC0C3C5C7C7C7C8
CBD2D8DCDFDEDBD9D6CEC7C1BCBBBBBABBBDBFC2C5C7C9CD
D1D7DEE4E8E8E8E8E8E9EAEAEAEAE9E8E7E7E6E6E5E3E2E1
E0E2E3E4E4E5E5E5E5E2DFDDDAD8D7D5D5D7D9DBDDDEDFDF
E0DEDDDCDAD9D8D7D5D3D0CECCC9C7C4C3C3C3C3C3C2C1C0
BFBFBEBDBCBBBABAB9B8B7B7B6B6B5B5B5B6B7B8B8B9BABB
BBBBBCBCBCBDBDBDBDBEBEBEBFBFBFBFBFBDBCBBBAB9B8B8
B8B9BABBBCBDBEBFBFBEBEBDBDBCBCBCBBB8B6B3B2B2B2B2
B1B0AFAFB2BCC7D1D8D4CFCDC7B7A488706B696A6C666365
676A6E71788694A0A8A6A3A2A1A2A4A3
BBBCBDBEBFC0C1C3C4C6C8CACCCED0D2D4D7DADCDFE1E2E4
E4E3E2E0DFDEDCDAD8D4D0CDCAC6C3C1C0C2C4C6C8C8C9CA
CDD3DADEE1DFDDDAD6D0C9C2BDBCBCBCBCBEC0C3C6C8CACD
D1D8DFE5E9EAE9EAEAEBECECECEBEBEAE9E8E8E7E6E4E3E2
E2E2E3E3E3E4E4E4E3E0DDDBD9D7D6D4D4D6D8DADCDDDEDF
DFDEDCDBD9D8D7D6D4D2CFCDCAC8C6C4C2C2C2C2C1C1C0C0
BFBEBDBCBCBBBBBAB9B9B8B7B7B6B6B6B6B7B7B8B9BABBBC
BCBCBDBDBDBEBEBEBEBFBFBFBFC0C0C0BFBEBDBCBBBAB9B9
B8BABBBCBDBEBFC0C0BFBEBEBDBDBDBCBBB8B6B4B2B2B2B2
B2B0AFAFB2BDC7D1D8D4CECDC7B7A488706B696A6B666264
66696D707785939FA8A6A3A2A0A2A3A3
BBBCBDBEBFC0C2C3C5C6C8CACDCED0D2D5D7DADCDFE1E3E4
E5E3E2E1DFDEDCDAD8D4D1CDCAC6C4C1C0C2C4C7C9C9CACB
CED4DADFE2E0DDDBD7D0C9C3BEBDBDBCBDBEC0C3C6C7CACD
D1D8DFE5EAEAEAEBEBECEDEDEDECECEBEAE9E8E7E6E5E4E3
E2E3E3E3E3E3E2E2E1DEDCDAD8D6D4D3D3D5D7D9DBDCDDDF
DFDEDCDAD9D8D7D5D3D1CECCC9C7C5C3C2C1C1C1C0C0C0BF
BFBEBDBCBCBBBBBABAB9B8B8B7B7B6B6B6B7B8B9BABBBBBC
BDBDBDBEBEBEBFBFBFC0C0C0C0C0C0C0C0BFBEBDBCBBBAB9
B9BABCBDBEBFC0C0C1C0BFBEBEBDBDBCBBB9B6B4B2B3B3B2
B2B0AFAFB2BDC7D1D7D3CECDC7B7A488706B69696B656264
66696C707685939FA7A5A2A1A0A1A2A2
BBBCBDBEBFC0C2C3C5C7C8CBCDCED0D2D5D7DADDDFE1E3E4
E5E4E2E1DFDEDCDAD8D4D1CDCAC6C4C1C0C2C4C7C9C9CACB
CED4DADFE2E0DDDBD7D0C9C2BDBDBDBCBDBEC0C3C6C8CACD
D1D8DFE5EAEAEAEAEBECEDEDEDECEBEBEAE9E8E7E6E5E4E3
E2E3E3E3E3E3E3E2E1DFDCDAD8D6D5D3D3D5D7D9DBDDDEDF
DFDEDCDBD9D8D7D5D3D1CECCCAC7C5C3C2C1C1C1C1C0C0C0
BFBEBDBCBCBBBBBABAB9B8B7B7B6B6B6B6B7B8B9BABABBBC
BDBDBDBDBEBEBEBFBFBFC0C0C0C0C0C0C0BFBDBCBBBABAB9
B9BABCBDBEBFBFC0C0C0BFBEBDBDBDBCBBB8B6B4B2B2B3B2
B2B0AFAFB2BDC7D1D7D3CECDC7B7A488706B69696B656264
66696C707685939FA7A5A2A1A0A1A3A2
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000]1000`40O003h00Oogoo;Goo003oOol]
Ool004aoo`8001Yoo`<000Aoo`8001=oo`<000Aoo`8000Aoo`80015oo`<000=oo`<000Aoo`80011o
o`@000=oo`8000Aoo`80015oo`@0009oo`<000Aoo`8003Yoo`00Bgoo00@007ooOol001aoo`04001o
ogoo0002Ool00`00Oomoo`0AOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0015oo`03
001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00@007ooOol0015oo`03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`0gOol004]oo`04001o
ogoo000LOol01000Oomoo`000Woo00<007ooOol04Goo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo000AOol00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol03goo00D007ooOomoo`00
009oo`04001oogoo0002Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007oo
Ool0=goo001;Ool01000Oomoo`006Goo0`000goo00@007ooOol001=oo`03001oogoo009oo`04001o
ogoo0002Ool01000Oomoo`004Goo00<007ooOol00Woo0`000goo00@007ooOol0019oo`04001oogoo
0002Ool01000Oomoo`000Woo00<007ooOol04Goo00<007ooOol00`000goo00@007ooOol003Uoo`00
Bgoo00@007ooOol001Uoo`03001oogoo00=oo`04001oogoo000COol00`00Oomoo`02Ool01000Oomo
o`000Woo00@007ooOol0015oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo000?Ool01000
Oomoo`000Woo00@007ooOol0009oo`04001oogoo000@Ool01000Oomoo`000Woo00<007ooOol00goo
00@007ooOol003Uoo`00C7oo0P006Woo10000goo0P004goo0P001Goo0P0017oo0P004Goo0P0017oo
10000goo0P004Goo0P0017oo0P0017oo0P004Woo0P000goo10000goo0P00>Woo003oOol]Ool00?mo
obeoo`00ogoo;Goo003oOol]Ool004YoojT003Uoo`00A7oo0P0017oo00@007ooOol001moo`03001o
ogoo01aoo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo00Aoo`03001o
ogoo03Moo`00@goo00@007ooOol000=oo`03001oogoo0:Eoo`03001oogoo03Moo`00@goo00@007oo
Ool000=oo`800:Eoo`8003Uoo`00@goo00@007ooOol000=oo`03001oogoo00@HaP0848@<H`aS5:DH
aQcW8@PHaP8@Q08DY@8@Q00436<8@PaS48@26<H248@00`aS2488@P09248;36<224801PaS48@DYABU
6<HDY@8@Q0L<H`03248<H`aS00@<Ha<8@P0336<@Q12400H<H`0348@<H`Q20348@PT<H`=oo`03001o
ogoo03Moo`00@goo00@007ooOol000=oo`05001oogoo8@PLi`026<H25:D248@011BU6<HQ21S611BU
0a240PaS00@@Q1BU5:D@Q0<<H`X8@PD<H`0348@<H`aS008<H`03248<H`aS008@Q0@DY@8@Q0l<H`H8
@P848@<8@P848@800003248<Ha24008DY@0436<000000006124a248936<3Ool00`00Oomoo`0gOol0
04Aoo`8000Aoo`07001oogoo<H`e[Be[8@P00QBU00H@Q0aS5:DHaQcW6<H45:D348@236<011245:D@
Q1240`aS2PQ21@aS0Q240PaS0PQ20PaS0Q240aBU0a243PaS1PQ20`@Q20Q20P@Q0PQ200D<HaS69BTL
iaS6008DY@8@Q08<HaD8@P0336<8@PQ201P8@PL<H`0348@<Hgoo009oo`03001oogoo03Moo`00BWoo
00d007ooOole[Cg_>Lh]JacW6<HDYA245:DHaP037>L00aS65:DDY@025:D748@336<:248436<348@2
36<2248236<011245:DHaQBU11243`aS20Q20`aS0PQ20PaS00X8@P@Q24848A249BT]JcF]:DXU:@<Q
20056<HDY@aS24848@0@248536<I248336<2248010aS48@@Q1240goo00<007ooOol0=goo001:Ool0
3@00OomoocF]>LhmkcF];F/Q21S648@DYAS600@Li`DDY@D@Q0@<H`X8@P@<H`<@Q08<H`88@P0636<@
Q1BU5:DHaQBU0a240`aS00<8@PaS36<010aS00<8@PaS36<00`aS1@Q210aS20Q200<<HaBU9BT00S6<
00@]JbU:9BTQ208U:@046<H@Q0aS2482124?248536<I248336<2248448@3Ool00`00Oomoo`0gOol0
04Yoo`800003OolicSW>008mk`05>Lh]JbDY6<HDY@026<H011cW8@PLiaS60QBU00@HaQBU5:DDY@8@
Q0D<H`T8@P@<H`@@Q0D<H`0448@DYABU5:D248@536<00`Q236<<H`0436<00`Q236<<H`0A24802@aS
48@HaR48<H`icRe[:DXU:@027>L01QS67>LLiaS648@<Ha08@PP<HaP8@P0336<@Q124008@Q0@DY@9o
o`8003Uoo`00BWoo00<007ooOol013g_00DicSF];F/U:B4800<HaP038@PLiaS600@HaP8DY@8@Q0D<
H`T8@P@<H`@@Q0@<H`8@Q0<DY@8@Q00336<@Q12400/<H`H8@P@<H`88@PD<H`0448@HaRDY<H`2=Jd0
0c6<9BTU:@036<H01QBU6<HHaQBU48@<H`X8@Ph<H`h8@PH<H`03248<H`aS00<<H`035:DLib4800@L
i`=oo`03001oogoo03Moo`00BWoo00<007ooOol01Cg_00PicSF];F/U:AcW5:DHaR480QcW1AS60QBU
00<@Q0aS36<00`aS2@Q210aS11240`aS0a240aBU0Q2400@<Ha2448@@Q0T<H`H8@P0336<8@PQ200@8
@P848@0436<DYAcW;F/2>Lh01cF]:DXaS2DY6<HU:AS6008Li`<HaP8DY@0348@8@P@Q00P8@Ph<H`h8
@P/<H`0548@LibDY:DXU:@028@P01BDYOomoogoo0000>Goo001:Ool00`00Oomoo`06?Nl00cF]<H`Y
BP058@P47>L36<H00aBU48@@Q00436<9248436<448@236<348@35:D648@236<3248010aS48@<H`aS
1`Q20`aS0a2400PDYAcW9BTaS3W>AS4icS6<0Re[00DQ22DY7>LDYAcW00HHaP8DY@0336<8@PQ20088
@QD<H`T8@PH<H`03248<H`aS008<H`08248<H`aS5:DHaR489BTYBP@U:@=oo`03001oogoo03Moo`00
BWoo00<007ooOol013g_0SW>00He[C6<;F/]JbU:9BT28@P57>L26<H25:D00a2436<<H`0336<82484
36<448@010aS48@@Q1240aBU1a2400<<H`Q224800PQ210aS10Q210aS00H@Q1S67>LYBSW>@Q04AS40
0dYB>Lh]J`029BT26<H25:D00aS67>LHaP046<H248@236<2248F36<9248436<5248236<010Q248@H
aQcW22DY0goo00<007ooOol0=goo001:Ool01000OomoocW>0cg_0SW>00<e[C6<<H`00S6<00<YBRDY
8@P00R481AcW00<HaQBU48@01`aS1PQ210aS1Q241ABU1a241PaS1A2410aS00D@Q1BU7>LYBS6<008e
[@04>Li6<DYBAS42>Lh02Re[9BTQ21cW6<HDY@aS48@DYAcW11S600<DYA2436<070aS1PQ21@aS0`Q2
10aS00@DYBDY:DXYBP@U:@@YBP=oo`03001oogoo03Moo`00BWoo0P0000=oocW>>Lh00Sg_0SW>00<e
[C6<<H`00S6<00@]JbU:9BTU:@DQ20057>LHaQS65:D@Q00336<9248436<448@00`aS48@@Q00248@2
5:D248@25:D00a2436<<H`0336<00a245:DDY@036<H02ABU36<8@PQ248@DYAcW9BTYBP05;F/3<H`2
=Jd022e[9BTQ21cW6<HDY@aS48@35:D01AS648@DYABU48@06`aS2`Q20PaS0PQ20PaS00@8@PaS48@U
:@DYBP039BTYBRU:00<YBP9oo`8003Uoo`00BWoo00@007ooOole[@DicP03=JdaS36<008aS08]J`<Y
BP@U:@8Q20047>LHaQBU5:D236<9248436<448@236<448@45:D03A2436<8@PaS48@HaQcW9BTYBRe[
:DXU:AS600<@Q0036<HQ22e[00@e[@8aS0<]J`05:DXU:B486<HLi`026<H25:D248@236<01A2436<D
Y@Q248@010aS0`Q25PaS1PQ200<<H`Q2248010Q20PaS00H@Q0aS36<@Q2489BT4:DX39BT4:DX3Ool0
0`00Oomoo`0gOol004Yoo`03001oogoo008icP03?NlicSW>008e[@8aS08e[@03<H`]Jbe[008]J`<Y
BP8U:@8Q20047>LHaQS648@336<6248536<648@25:D848@01ABU6<HLibDY;F/00S6<00TU:AcW5:DD
YA246<HU:BU:<H`00cF]0S6<0Re[00<U:B488@P00QcW0QS60aBU0a241@aS00<@Q0Q236<010aS0`Q2
5`aS20Q200X<H`Q236<8@Q247>LU:B487>LQ20HYBPLU:@=oo`03001oogoo03Moo`00BWoo00@007oo
OolicP8mk`03>Lhe[CF]008aS0@e[@<aS0<]J`8YBP8U:@8Q20047>LHaQBU48@336<5248536<548@4
5:D00a245:D@Q00248@011S67>LU:BDY0RU:0Re[00dU:AcW5:D@Q1S67>L]JcF]>Lhe[C6<:DXU:@03
8@P01AS65:DDYABU48@00aBU00@@Q0aS36<<H`T8@P@<H`D8@QH<H`D8@P848@8<H`06248<H`aS6<HU
:C6<1Be[12U:1bDY0goo00<007ooOol0=goo001:Ool00`00Oomoo`03?Nl00cW>=Jde[@02<H`2=Jd0
0cW>=JdaS004<H`2;F/2:DX39BT012487>LDYA2410aS10Q21@aS1Q240aBU0QS60QBU00<Libe[<H`0
0Re[00TQ22U:8@PDYA2436<@Q1BU:DX00cF]00<]Jb485:D00Q2410aS1@Q20PaS5`Q210aS0`Q21`aS
1A240PaS1PQ21@aS00@DYBU:<H`]J`@aS0@YBPPU:@=oo`03001oogoo03Moo`00BWoo00<007ooOol0
0cg_0SW>0SF]00<aS3F]=Jd00cF]0c6<12e[0bU:0RDY00<Q21cW5:D00Q240`aS1@Q20`aS11240QBU
11S600XDYAcW;F/icS6<;F/U:B487>LHaP8@Q00;5:DLibU:=Jdmkd8@?Nle[Be[9BTQ20027>L011S6
48@<H`aS0`Q21@aS5PQ24PaS0`Q22@aS00HHaR48:DX]Jc6<;F/2:DX00be[<H`]J`03;F/00bU:9BTU
:@059BT3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00<mk`<icPLe[@8aS0L]J`<YBP039BTQ21S6
008DY@0348@<H`aS008<H`<8@P<<H`<@Q00:36<@Q1BU5:D@Q1BU6<HU:CF]?Nl2;F/02RDY6<HHaQS6
48@<HacW;F/icTHa0TYB0dHa00U243g_=Jd]JbU:8@PHaQBU48@02@aS50Q24`aS00@8@P@Q2488@P@<
H`03248@Q248008YBP@]J`03<H`]JbU:008]J`04<H`]Jbe[;F/2:DX69BT3Ool00`00Oomoo`0gOol0
04Yoo`800003Oolmkcg_008mk`<icPHe[@03<H`]Jbe[00T]J`06:DXU:B487>LHaQBU0Q240PaS0`Q2
0`aS00<@Q1BU5:D00Q2400XDYA2448@Q22DY<H`e[C6<8@PLi`8HaP095:D@Q0aS48@]Jd8@AS5:DTic
00=BU09>L`06AS5243F]<H`YBR480QBU0Q242PaS4PQ230aS0Q240aBU00<@Q0aS248010Q200D<HaBU
8@PU:BU:008]J`8aS0L]J`8aS08]J`8YBPHU:@9oo`8003Uoo`00BWoo00<007ooOol01Cg_0SW>0SF]
0S6<0cF]0be[0S6<1Re[00HYBRe[;F/YBR487>L25:D00a2436<8@P02248010aS48@<Ha240aBU00@H
aRU::DXYBP8e[@03<H`YBQcW008HaP077>LHaQ2436<@Q1cW?Nl00dic00=BU5JeE[D00UJe00QBU4YB
@Q0mkcF];F/Q21cW0QBU00<@Q0aS36<020aS4PQ230aS0Q2400DDYAS66<HDY@aS00<8@P0836<DYAS6
9BTaS3F];F/YBPh]J`8YBPHU:@=oo`03001oogoo03Moo`00BWoo00<007ooOol01Sg_0SW>00<e[C6<
<H`00cF]0be[1S6<0be[00TaS3F]<H`]JbDY8@PLiaBU48@00`aS00<@Q1S65:D00QBU00<@Q1BU<H`0
14ic00he[BDY6<HDYAcW9BTYBQBU248@Q1cW<Ha:DU:D25Je00I>LdYBAS4mkcF]:DX27>L011S65:D@
Q1243@aS3@Q22PaS1A240QBU00P@Q0Q2248<HaBU8@PYBS6<13F]00<aS2e[;F/032e[0RU:12DY00<Y
BRDYOol00Woo00<007ooOol0=goo001:Ool00`00Oomoo`06?Nl2>Lh2=Jd01S6<=JdicSF]<H`]J`Pa
S08]J`03<H`e[CF]008aS004:DXU:AcW6<H25:D448@05aBU6<HHaRDYCW=S65JeAS4e[B486<HQ236<
;F/YBQcW36<8@QBU;F]244YBDY@00U[F00=Nme[FF]H00e[F00UF]E:DBU96<Cg_;F/U:AcW6<H00QBU
11241`aS4PQ22PaS0a2411BU00<HaR48:DX00be[1S6<32e[0bU:0bDY0bU:0goo00<007ooOol0=goo
001:Ool00`00Oomoo`06?Nl3>Lh3=Jd00cW>=JdaS00=<H`3=Jd0236<;F/YBRU:9BTQ21cW48@236<0
21BU7>LQ22e[F]INmdYB;F/28@P032U:<H`icS6<8@P@Q0Q26<HaS48@AS5>L`9F]@03F]INmekg00AN
m`09F]IF]DicAS4mkc6<:DXQ21cW00@DY@<@Q0H<Ha88@PX<H`0948@DYAS66<HLib489BTYBRe[00<a
S0H]J`<aS0X]J`TYBP=oo`03001oogoo03Moo`00BWoo00<007ooOol01cg_0SW>0cF]00<icSF]<H`0
3S6<0cF]0c6<0Re[00/U:AcW6<HDYAS65:DHaRU:G_M>LcF]008Li`0=8@PYBS6<=Jd]JaBU48@U:CF]
@Q16<DicDY@015Je0U[F1Ekg00MBU4Ha@Q0icRe[:DXQ20036<H35:D548@336<2248536<:248:36<0
1Q245:DLib489BTYBP8]J`@aS18]J`XYBP=oo`03001oogoo03Moo`00BWoo0P0000=oocW>?Nl01Cg_
0SW>0SF]0SW>00<e[C6<<H`00S6<00<e[C6<<H`01S6<0Re[00<aS3F]<H`01C6<00`]JbU::DXU:ABU
248DYC6<F]HicRe[8@P29BT01b489BT]JacW48@Q23g_00=:DP03CW=BU5:D00ABU09F]@0;F]INmf<H
HaQF]DicAS4mkcF];F/Q20027>L26<H35:D548@:36<9248436<02Q2436<<H`aS48@<Ha246<HQ22U:
0S6<1be[0c6<12e[00@YBRe[;F/]Ja0YBP9oo`8003Uoo`00BWoo00@007ooOolicPHmk`<icP03=Jdi
cSW>008e[@8aS0@e[@<aS08e[@<]J`@aS0D]J`8aS00A>LhHaQ247>M6<EJe>Lh]JcW>:DX]Jb486<HQ
21247>Le[@04BU88CW<2DY@02U[FG_MS65kgDYA>Ld8@>Lh]Jb480acW0aS60QBU1Q242@aS20Q210aS
00X@Q0aS36<<Ha2436<DYB48;F/aS08e[@03<H`]Jbe[008YBP04;F/aS36<<H`4;F/E:DX3Ool00`00
Oomoo`0gOol004Yoo`03001oogoo00Lmk`<icP03=JdicSW>008e[@03<H`e[CF]00<e[@HaS005;F/a
S36<=JdaS002;F/01c6<;F/]Jbe[<H`e[E:D008e[@04BU9BU4icBU82?Nl023F]9BTU:B486<HLid8@
AS43@Q000dHaBU9>L`03DY@2CW<00dYBCW=>L`02DY@2E[D01U:DBU9243F]:DXQ20@HaP<DY@T@Q0P<
H`P8@PP<H`035:DQ22e[00<e[@8aS08]J`8YBP8]J`<aS0P]J`TYBPLU:@=oo`03001oogoo03Moo`00
BWoo00<007ooOol01cg_1SW>1cF]2C6<0SF]0c6<00<e[C6<<H`00S6<010icV<HIcUS65kgF]I:DTHa
BU9243W><H`U:B489BU6<@9:DP924005?Nm244HaCW=BU002E[D01E:DBU9:DTHa@Q000Sg_0cW>00De
[Be[9BTQ21cW00@DY@D@Q08DY@<@Q08DY@0348@<H`aS00H<H`P8@P0436<@Q0Q236<348@00b48;F/a
S002=Jd2<H`3;F/012U:;F/]Jbe[136<2Be[1bU:1bDY0goo00<007ooOol0=goo000mOol30004Ool2
0004Ool00`00Oomoo`07?Nl7>Lh6=Jd9<H`2=Jd3<H`4=Jd04C6<>LiNmg>LJeYS65[FCW=244icAS52
42e[:DXaS4HaDY@00Tic00Q6<Cg_>LhicT8@CW=BU5[F0UJe0Tic00E6<Cg_>LhaS2U:008U:@048@PL
iaS66<H25:D848@25:D248@01AS67>LLiaBU48@02@aS0`Q200/<H`Q22488@PaS248<Ha246<HQ236<
008e[@04<H`e[C6<<H`7;F/4<H`:;F/5:DX89BT3Ool00`00Oomoo`0gOol0041oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo1cg_1cW>1SF]2S6<00@e[C6<<H`aS0@e[@07;F/aS5:DLia_NfLiG_L0
0U:D00MF]Dic?NlaS3F]BU9Nm`02E[D024icBU8mkcF]<H`icTYBE[D2F]H2E[D02E:DBU96<Cg_=Jd]
Jb487>LHaP035:D:48@25:D021245:DLibU:9BTLiaBU48@836<324801@aS2488@PQ248@00PaS00<@
Q1cW<H`00SW>1C6<0be[0c6<3be[1BU:22DY0goo00<007ooOol0=goo0010Ool01000Oomoo`000Woo
00@007ooOomoo`800003Oolmkcg_00Dmk`TicP<e[@laS004>Lhe[CW>=Jd2;F/014HaKg]cW6mk0VLi
00MNmeJeG_M6<C6<@Q1Nm`02F]H2E[D01dYB@Q0e[Be[=Je6<E:D00=Nm`9F]@08DYA:DTHa?Nle[Be[
9BTQ208Li`036<HDYA2400T@Q08DY@076<HU:Be[<H`Q21S648@02@aS00<8@PaS36<00PQ200<<Ha24
48@00Q2400@Q23F]?Nle[@8]J`<aS0<]J`<aS0l]J`DYBPPU:@9oo`8003Uoo`00?Goo0`000goo00@0
07ooOol000=oo`03001oogoo00Lmk`TicP@e[@PaS003=JdaS3F]00He[@<aS003>LiJeWNm009cW004
JeYNmdicBU82AS42DY@3E[D015:DBU9243W>0Re[00LmkdYBE[ENmf<HF]IF]@02DY@02DicBU96<CF]
;F/YBR487>LHaP025:D348@636<011245:DQ22U:0S6<00@U:AcW5:D@Q0/<H`88@P0636<DYABU48@H
aRe[0c6<0Re[00<aS3F]<H`00be[0c6<32e[22U:22DY0goo00<007ooOol0=goo000mOol00`00Oomo
o`03Ool01000Oomoo`000goo00@007ooOolicPDmk`@icP03=JdicSW>00<icPLe[@<aS0/e[@8aS00>
=Jd]Jd8@Kg]g_G>LJeYJeTHa?Nm6<EJeF]IF]@=BU00=CW=6<D8@>LhaS2U:<H`mke:DG_MS65[FE[D0
0U:D00M>LdHa@Q0e[C6<:DXU:@027>L00aS65:D@Q00248@436<01PQ236<@Q1cW:DXaS08e[@04:DXQ
21S648@;36<224801`aS5:DHaRDY;F/e[C6<008]J`<aS003=JdaS2e[008]J`8aS0`]J`XYBPLU:@=o
o`03001oogoo03Moo`00?Goo10000goo0P0017oo00<007ooOol02CW>0cF]13W>4SF]00@aS3F]<H`a
S08e[@03<H`]Je[F009g_@08LiaNmdYB@Q1:DV<HF]IF]@9BU00>CW=:DTHa@Q0icS6<:DX]JcF]AS5B
U5[FDYA>L`=BU09>L`08?NlaS2DY9BTQ21cW6<HDY@8@Q0<<H`@8@P0336<Libe[00<e[@04;F/U:AcW
48@=36<01a247>LU:C6<>Lhe[C6<008]J`HaS004;F/aS36<<H`8;F/>:DX79BT3Ool00`00Oomoo`0g
Ool004Yoo`03001oogoo00PicPDe[@<icQ@e[@8aS08e[@0:<H`]Jcg_JeYoogNmIcUBU4icF]H2G_L0
25[FE[EBU4icBU96<D8@>Lh2=Jd012U:9BT]Jc6<0SF]00PicTHaBU9:DTHa@Q0e[BU:0b4800<LiaS6
5:D00Q240`aS0`Q200/<Ha247>LYBS6<=JdicS6<9BTLia24008<H`0348@<H`aS00P<H`055:DYBSF]
>Lhe[@03<H`3;F/8<H`7;F/@:DX69BT3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00PicPDe[@<i
cQPe[@0;<H`e[CF]E[EoogNmJeYNmeJeHaQNm`03F]H045JeCW=:DTYB@Q0icSg_>Lh]Jb489BT]JbU:
9BTQ22DY0RU:0Re[00@U:B486<HHaP8DY@<@Q0P<H`0:48@LibU:<H`e[CW><H`YBQcW5:D448@936<0
11BU:DXicSW>0S6<0SF]00<aS2e[;F/00Re[1S6<1be[42U:0RDY12U:0goo00<007ooOol0=goo001:
Ool00`00Oomoo`0@>Lh;=Jd00c6<=Jde[@02=Jd5<H`4=Jd2<H`024HaKg]cW6mkJeYJeV<HG_L2F]H0
0ekgE[EBU002BU8014Ha?Nlmkcg_0SW>00I244YBAS4mkcF]:DX37>L00b487>LHaP025:D00a2436<<
H`0536<348@25:D011S68@P]Jc6<0SF]00@]JbDY7>LDY@@@Q0T<H`036<HYBSF]008e[@DaS14]J`hY
BPLU:@=oo`03001oogoo03Moo`00BWoo0P0000=oocW>>Lh03CW>2cF]0c6<0cF]1C6<1CF]00PaS3F]
CW=_Ng_NLiaNmf<H0U[F0Ukg00IJeU:DCW=:DTHa@Q02?Nl0448@AS5BU5JeF]IBU4ic?NlaS2U:9BTQ
21cW8@PLiaS60`aS0Q2400@<Ha2448@DY@8HaP8Li`048@PYBS6<=Jd2<H`01BU:9BTLiaS65:D00a24
20aS00<DYAcW<H`00SF]00<aS3F]<H`01S6<4Re[2BU:22DY0Woo0P00>Goo001:Ool00`00Oomoo`07
>Lh013F]>LhicSg_13W>2cF]0c6<0cF]1S6<13F]0S6<00HicUJeKg]_NekgHaP2G_L026<HG_MJeUJe
DYA>LdYBAS42@Q0014HaCW=F]Ekg0f<H00EF]Dic@Q0icS6<00<]J`039BTLiaBU00D@Q0035:DHaQS6
008Q208U:@09;F/e[CF]=JdaS2U:9BTQ21S6008DY@8@Q0D<H`0:248<H`aS48@Q23F]>Lhe[C6<=Jd6
<H`D;F/7:DX99BT3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00HicP<e[@LicPXe[@<aS0<e[@ha
S004CW=S66<HHaP2IcT01F<HG_MJeUJeDY@00Tic0TYB00I6<DicDYAJeUkgHaP4IcT03EkgE[E>Ld8@
>Lhmkd8@>LhYBQcW5:DHaQBU008HaP047>LQ22DY:DX2;F/02CF]>LhicSF]<H`]JbU:8@PHaP035:D0
0a2436<<H`0736<01QcW=JdicS6<;F/aS08]J`@aS1D]J`DYBP@U:@HQ20=oo`03001oogoo03Moo`00
BWoo00<007ooOol013W>00@mkcW>=JdaS08e[@04>Lhe[CF]=Jd2>Lh:=Jd3<H`2=Jd5<H`2;F/00c6<
=JdaS005<H`00dYBHaQW>@04IcT2G_L00e[FE[EBU002CW<2BU8014icDYAJeUkg0f<H0fLi00aS65kg
AS4e[Cg_BU9>LcW>8@PDYAcW6<H27>L01b489BTYBRe[<H`e[CW>008mk`07=JdaS2e[:DXQ21cW6<H0
0QBU00D@Q0aS36<<Ha24008<H`0948@<H`aS7>Le[CW><H`]Jc6<008]J`@aS1D]J`DYBP<U:@LQ20=o
o`03001oogoo03Moo`00BWoo00<007ooOol013W>00@mkcW>=JdaS0He[@8icPXe[@<aS08e[@HaS004
;F/aS3F]=Jd2<H`012e[<H`mke[F0f]J0fLi00IS65kgF]IF]E:DCW<4BU800dicE[ENm`02HaP2IcT3
HaP015kgAS4aS3F]0TYB00<e[B485:D00acW00LQ22DY9BT]Jc6<=JdicP02?Nl023W>=JdaS2e[:DXQ
21cW6<H25:D00a2436<<H`0436<01A2436<<HaS6;F/00SF]00<aS3F]<H`01C6<5Be[1BU:12DY1R48
0goo00<007ooOol0=goo001:Ool00`00Oomoo`04>Lh00cg_>Lhe[@04<H`3=Jd2>Lh:=Jd3<H`2=Jd6
<H`02Re[<H`e[C6<=JdaS2e[<Ha246<H16]J0VLi0V<H00=JeUJeDY@00Tic0TYB00I6<DYBDYAJeUkg
HaP2IcT4HaP024YB=Jde[D8@AS4e[AcW5:D27>L28@P01RDY:DX]JcF]>Li2408mk`08>Lhe[C6<;F/Y
BR487>LHaP8DY@0348@<H`aS00L<H`035:DQ22e[00<e[@8aS004=JdaS36<<H`E;F/5:DX59BT00b48
9BTU:@029BT3Ool00`00Oomoo`0gOol004Yoo`800003OolicSW>00DicP04=JdaS36<<H`3=Jd2>Lh:
=Jd3<H`2=Jd6<H`01Be[<H`aS36<=Jd00c6<00E6<FLiJeY[FVmk00=[FP05IcUS65kgF]IBU002CW<2
BU82AS4014icE[ENmf<H1FLi00US64ic@Q0icT8@?Nl]JacW5:D00QS600LLib489BTYBRe[<H`icP02
@Q002Cg_>Lhe[C6<;F/YBRDY7>LHaP025:D248@836<00a246<HYBP02=Jd9<H`C;F/6:DX99BT2Ool2
000iOol004Yoo`04001oogoo=Jd9>Lh00cF]>LhicP02>Lh:=Jd<<H`2;F/033F]<H`e[CF]<H`e[E:D
JeY_Nf]JLia_N`=[FP05IcUNme[FE[EBU002CW<024YB@Q1244YBE[EJeUkgIcT5JeX025[FCW=243F]
;F/Q21BU48@25:D02AS67>LQ22DY:DXaS3W>@Q0mk`02>Lh2=Jd01Be[:DXU:AcW6<H00QBU0Q241PaS
00D@Q0aS36<@Q248008e[@03<H`]Jbe[00<]J`HaS0l]J`LYBPTU:@=oo`03001oogoo03Moo`00BWoo
00@007ooOole[@dicP/e[@04<H`e[CF]=Jd8<H`2;F/00cF]<H`e[@02=Jd01cW>E[E[FVmkJeYcW6mk
00=[FP05IcUNmekgE[EBU002CW<024YB@Q0mkdYBCW=JeUkgIcT5JeX01UkgCW=242e[8@PHaP@@Q08H
aP8Q20049BT]JcW>?Nl3>Lh2=Jd01Be[:DXU:AcW6<H00QBU0a240`aS00T@Q0aS48@<H`Q236<LicF]
<H`01Re[236<32e[22U:2BDY0goo00<007ooOol0=goo001:Ool01000OomoocF]2CW>13F]0SW>0SF]
1S6<13F]2c6<00Pe[C6<=Jde[C6<>LiJeV]J0Vmk00UcW6mkKg]_Nf]JIcUS65kgE[D00U:D00U>LdYB
@Q0mkd8@BU9>Le[FG_L00e[F00MNme[FBU8mkbe[7>LDY@0348@236<021245:DHaQcW9BT]JcW>?Nl3
>Lh2=Jd01Be[:DXU:AcW6<H00QBU0Q2410aS00@@Q0aS36<<H`88@P036<HU:BDY008YBP03;F/aS36<
00TaS0T]J`/YBPTU:@=oo`03001oogoo03Moo`00BWoo00@007ooOole[@HicPLe[@8icP03=JdaS36<
00<]J`<aS0<e[@/aS0<e[@8aS003?NmNmf]J009_N`04Lia_NfmkKg/2JeX02F<HG_MJeUJeDYA>LdYB
@Q0mk`02@Q001TYBCW=BU48@?Nm2409:DP04=JdYBQS648@836<01Q246<HU:Be[=Jdmk`8icP8e[@06
<H`]JbU:9BTLiaS60QBU00<@Q0aS36<00`aS00P@Q0aS36<<H`Q236<DYAS60QBU00@Lib48:DX]J`8a
S003;F/aS36<00@aS0L]J``YBPXU:@=oo`03001oogoo03Moo`00BWoo00@007ooOole[@HicPLe[@8i
cP03=JdaS36<00<]J`<aS08e[@LaS003;F/aS36<008aS0<e[@8aS003@Q1S66mk009_N`03Lia_Nfmk
009_N`03JeYW>F<H009JeP9BU003CW=6<D8@00924006AS5>LdYB<H`]JcF]0T8@00@aS1cW5:D<H`88
@PH<H`0548@HaRDY;F/e[@02>Lh3=Jd01S6<;F/YBRDY7>LHaP8DY@0348@<H`aS00L<H`0:248<Ha24
48@<H`Q236<@Q1cW:DX2<H`2;F/5<H`4;F/?:DX:9BT3Ool00`00Oomoo`0gOol004Yoo`800003Oole
[CF]00@icPHe[@04<H`e[CF]>Lh2=Jd7<H`00cF]<H`aS006<H`012e[<H`aS36<13F]0S6<00A6<F]J
Kg]cW09_N`07Lia_NfmkKg][FVLiHaP00Ukg00EJeUJeDYA:DTHa0092400<AS5F]EJe@Q0mkd8@BU92
43F]9BTLiaBU0`aS00<@Q0aS36<00PaS00D@Q1S69BT]Jc6<00De[@06<H`]JbU:9BTLiaS60QBU00<@
Q0aS36<03@aS0PQ200<@Q248;F/00S6<00<]Jc6<<H`00c6<0be[42U:2RDY0Woo0P00>Goo001:Ool0
0`00Oomoo`04=Jd2>Lh5=Jd2<H`2=Jd00cW>=Jde[@0@<H`012e[<H`aS36<13F]00<aS3F]BU800Vmk
00AcW6mkLiacW0=_N`04JeYW>F<HHaP2G_L00e[FE[E>L`02AS40148@BU9Nmf]J0U[F00MNmeJe@Q0e
[Be[8@PHaP0948@011S69BT]Jbe[13F]0S6<00@]JbU:9BTLi`8HaP045:D@Q0aS48@736<248@536<0
1@Q236<DYB48<H`00SF]1C6<0be[3bU:1RDY0R480bDY0goo00<007ooOol0=goo001:Ool00`00Oomo
o`0<=Jd00c6<=Jde[@05=Jd0136<=Jde[CF]3S6<13F]00<aS3g_DY@02Fmk00A[FVLiHaQS609Nm`9J
eP07DYA>LdYBBU9>Lf<HKg/00fLi00IF]Cg_<H`YBR486<H248@336<448@011S69BTYBRe[1S6<00<]
JbU:9BT00QcW00DHaQBU48@@Q0Q200l<H`8@Q0036<HQ236<00@aS0@]Ja0YBPDU:@HQ20=oo`03001o
ogoo03Moo`00BWoo00<007ooOol033F]00<aS3F]=Jd02CF]3S6<13F]00DaS48@G_M_Ng>L009_N`04
Lia_NfmkKg/2JeX016LiHaQS66<H0ekg0UJe019BU4icE[ES66mkJeY_NfLiDYA2436<:DXQ21S65:D@
Q0aS248236<248@01ABU6<HQ22U:;F/01S6<0RU:00DU:AcW7>LHaQBU008@Q1<<H`045:DU:C6<<H`6
;F/A:DX39BT78@P3Ool00`00Oomoo`0gOol004Yoo`04001oogoo<H`D=Jd2>Lh00cF]<H`aS00;<H`0
0cF]<H`aS003=Jd014HaIcUcW7>L0Vmk00AcW6mkKg]_N`9[FP03IcUS66<H009S60ENm`9JeP0?HaQ_
NfmkKg]W>E:D@Q0aS2U:8@PLiaS648@<H`Q2008<H`8@Q0055:DHaR48:DX]J`05<H`012e[:DXYBRDY
0QcW0QS600<@Q0aS48@02`aS0PQ21@aS00@@Q1cW:DXaS0H]J`/YBP<U:@8YBP@U:@LQ20=oo`03001o
ogoo03Moo`00BWoo00<007ooOol01C6<4CF]00<icSF]<H`0336<00@e[C6<<H`aS08e[@03BU9_Ng>L
00M_N`03JeYW>F<H00MS6006IcUS65kgG_MS66]J0Vmk00UW>E:D@Q0e[Be[9BTLiaS65:D00`aS0Q24
00HDYAS66<HQ22DY:DX6;F/2:DX012487>LLiaS60QBU0Q244PaS0Q2400<Libe[=Jd00RU:0Re[2bU:
2BDY22480goo00<007ooOol0=goo001:Ool00`00Oomoo`07<H`8=Jd0136<=Jde[CF]0S6<00<e[CW>
=Jd0336<0SF]0c6<0SW>00=>LgNmLi`01fmk00=[FVLiHaP01F<H00AW>F]JKg]_N`9W>@0=HaQ[FVmk
Kg]S65:D@Q0e[C6<:DXQ21S65:D00`aS0Q2400HDYAS67>LQ22DY:DX6;F/00bU:9BTQ20027>L00aS6
5:DDY@0348@836<01Q2436<<H`aS248<H`88@P8<H`04124DYBU:=Jd2:DX2;F/;:DX99BT88@P3Ool0
0`00Oomoo`0gOol004Yoo`800003OolaS36<00PaS0De[@03<H`e[CF]00He[@haS007=JdaS3F]=Je6
<EkgLi`016mk00EcW6mkKg]_Nf]J009W>@ES6003IcU_Nfmk00I_N`0:IcUNme:DBU8mkcF];F/Q21S6
5:D548@25:D00aS67>LQ20029BT2:DX3;F/2:DX00bDY8@PLi`026<H00aBU48@@Q00248@736<00a24
36<<H`0336<524800a247>LYBP03:DX2;F/::DX:9BT78@P2Ool2000iOol004Yoo`03001oogoo00ha
S0Xe[@DaS08e[@@aS003=JdaS36<00@e[@08CW=[FVmkJeY_Ng>LKg]cW0=_N`03JeYW>FLi00ES6004
IcU_NfmkLi`2Kg/2Li`02fmkIcUNmeJeCW=243W>;F/U:AS65:D01Q2400DDYAS66<HLib48008U:@8Y
BP8]J`8YBP8U:@048@PLiaS65:D448@=36<424801@aS48@DYB48;F/00bU:00<aS2U::DX022U:2RDY
1b480goo00<007ooOol0=goo001:Ool00`00Oomoo`02;F/=<H`8=Jd5<H`3=Jd4<H`00cF]<H`aS003
=Jd00cW>E[E_N`02Kg/4Li`2Kg/3JeX2IcT4HaP00fLiJeY_N`02Kg/03G>LMkeg_G>LJeYS65kgDYA6
<CW><H`U:AS6008DY@D@Q08DY@046<HLiacW8@P29BT4:DX39BT012487>LHaQBU11243PaS0`Q20`aS
00<DYBU::DX00RU:0Re[0bU:00<U:BU::DX00bU:2RDY1b480goo00<007ooOol0=goo001:Ool00`00
Oomoo`06;F/9<H`3=Jd:<H`3=Jd4<H`02CF]<H`aS3F]>Lhe[DHaG_M[FP02Kg/4Li`2Kg/2JeX2IcT4
HaP015kgHaQ[FV]J0Vmk0g>L0Vmk00M[FV<HF]I:DSg_<H`U:@026<H25:D548@01ABU6<HLiacW8@P0
0RDY0bU:0RDY0R4800@LiaS66<HDY@@@Q0h<H`@8@P8<H`0348@Q22U:00D]J`8YBP039BTYBRU:00<Y
BP/U:@HQ20=oo`03001oogoo03Moo`00=goo0`0017oo0P0017oo0P0017oo00<007ooOol02Re[1C6<
00<e[C6<<H`02S6<13F]136<0cF]00HicSF]CW=S66]JKg/5Li`2Kg/2JeX016LiHaQS66<H0ekg0V<H
00=W>F]JKg/016mk00QcW6mkJeYNmdic@Q0aS2DY0aS600@DYA2436<<H`8@Q0045:DHaQcW8@P49BT0
0bU:9BTU:@028@P00acW6<HHaP025:D448@>36<4248336<00aBU:DX]J`03:DX012e[:DXYBRDY1RU:
42DY0goo00<007ooOol0=goo000hOol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo00T]JaDaS08e[@@aS0@e[@03@Q1JeUkg009_N`EcW0E_N`03JeYW>F<H00ANm`9S609W
>@03JeY_Nfmk00=_N`09JeYW>EJeBU8icRU:7>LHaQBU008@Q0<<H`0548@DYAS67>LQ20079BT01248
7>LHaQS60QBU11243`aS1@Q20PaS00<@Q2489BT032U:32DY0R480RDY00DQ27ooOomoo`0003Uoo`00
>7oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0003Ool200000goo;F/]J`06;F/G<H`4
=Jd0236<=Jde[C6<=Je:DV<HF]H2Kg/00g>LKg]cW002Li`5Kg/00f]JIcUS6004F]H4G_L2IcT4Kg/2
JeX01e[FCW<mkbe[8@PHaQBU008@Q0<<H`0548@DYAS67>LQ20059BT38@P00acW6<HDY@025:D348@@
36<4248436<01ABU8@PYBRe[:DX00RDY1bU:2RDY1b480Woo0P00>Goo000hOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000=oo`03001oogoo00L]JaPaS0@e[@8aS008=JdaS3F]DYAS65Je
Kg][FP=cW003MkecW7>L009cW09_N`04JeYW>EkgF]H6E[D2F]H00fLiJeY_N`04Kg/026<HDYA242e[
8@PHaQBU48@436<011245:DHaR480bDY00<Q21cW7>L011cW0aBU0Q244PaS1@Q20PaS00D8@PaS6<HU
:BU:00<U:@LYBPXU:@LQ20=oo`03001oogoo03Moo`00>7oo00<007ooOol00Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`06;F/><H`00cF]<H`aS009<H`3=Jd4<H`01Sg_E[EF]E:DKg][
FP9cW0Ag_@9cW006Kg][FVLiHaQJeU:D0Tic0dYB00I>Le:DE[ENmfLiJeX4Kg/026LiE[E6<C6<8@PH
aQBU48@436<248@01aS68@PQ22DY8@PLiaS6008DY@<HaP8DY@<@Q1H<H`D8@P035:DLibDY008U:@PY
BPTU:@PQ20=oo`03001oogoo03Moo`00=goo0P001Goo0P0017oo0P0017oo00<007ooOol01Re[3C6<
0SF]2c6<0cF]136<00I245[FDYABU6]JKg/2Li`3Mkd2Li`026mkJeY[FVLiG_MBU4YBAS42@Q001dHa
BU9>Le:DE[ENmfLi009[FP=_N`08JeYJeTHa<H`U:AS65:D@Q0@<H`<@Q08DY@036<HDYA2400@@Q08D
Y@@@Q1L<H`<8@P0636<48@aS5:DQ22DY2BU:2BDY22480goo00<007ooOol0=goo001:Ool00`00Oomo
o`08;F/H<H`4=Jd2<H`01Sg_DYAF]E:DE[E_N`EcW003Kg][FV]J009[FP04HaQF]DYB=Jd29BT00b48
9BTe[@03@Q003dHaDYAJeUkgIcU[FVmkLia_Nf<HCW<icRU:7>LDY@0536<00a2436<8@P03248436<2
48@25:DK36<5248010aS48@Lib482BU:22DY2B480goo00<007ooOol0=goo001:Ool00`00Oomoo`08
;F/H<H`3=Jd02CW>=Jde[DYBCW=F]E:DF]I_N`03Li`00fmkJeYW>@03G_L01E[FDYA:DSW>7>L00Q24
00@<Ha24:DXicP8aS00?=Je244YBE[ENmfLiJeYcW6mkIcUF]Cg_;F/Q21BU00D<H`0348@<H`Q200<8
@PD<H`0348@DYABU01/<H`D8@P0436<@Q1S69BT9:DX89BT98@P3Ool00`00Oomoo`0gOol004Yoo`80
0003Ool]Jbe[00H]JaPaS0<e[@05>Lhe[Cg_BU924002CW<02EkgLiacW7>LKg][FVLiE[E6<@02@Q00
1Cg_=JdaS2DY48@00PQ201D48@aS8@PaS2DY8@PU:CF]@Q1>Le[FHaQ[FVmkJeYW>EJe@Q0]Jb485:D0
1`aS2@Q200<<Ha2448@05PaS0`Q200<<H`Q224800`Q20`aS00<@Q2DY:DX012U:00@U:BU::DXYBPPU
:@TQ209oo`8003Uoo`00BWoo00<007ooOol00Re[0bU:0be[636<13F]00@icTHaAS4aS08mk`0;G_Mc
W7>LKg][FVLiG_M:DS6<9BTLi`025:D26<H236<05Q2436<<HacW:DXQ21cW8@P]JcF]BU9BU5kgHaQ[
FVLiG_MF]D8@;F/Q21S611240`aS2`Q25PaS10Q200<<H`Q224800`Q20PaS00<8@Q248@P00RU:00<U
:BU:9BT00RDY00<YBRDY9BT01RDY2R480goo00<007ooOol0=goo001:Ool00`00Oomoo`06:DX3;F/G
<H`2=Jd02CW>=JdicTHa@Q0aS2U:;F]JeP03Kg/026]JIcUJeTic>LhYBQS648@236<01a2436<@Q124
36<8@Q24008HaP077>LQ22U:<Ha245:DF]H00f<H00INmdic@Q0]JbDY6<H448@836<7248E36<42480
0`aS2488@P03248236<00`Q236<Q2002:DX00bDY:DXU:@029BT00bU:9BTU:@069BT:8@P3Ool00`00
Oomoo`0gOol004Yoo`03001oogoo00HYBP<]JaLaS0<e[@09<H`mkdHa=JdU:B48:DY>LfLi009_N`09
JeYW>EkgF]I:DSW>:DXHaQ2400<<H`8@Q00336<8@PaS008HaP068@PU:Be[;F/mkdYB0UJe0U[F00IB
U4YB?NlaS2DY6<H348@436<248@35:D448@336<348@B36<424800`aS2488@P03248236<01`Q236<Q
22e[:DXU:BU:00`U:@XQ20=oo`03001oogoo03Moo`00BWoo00<007ooOol01bU:0Re[5S6<0SF]0c6<
00=6<D8@9BT00QS600HQ23W>F]I[FVmkJeX2IcT02F<HF]I>Lcg_;F/U:AcW6<HDY@026<H25:D011cW
8@PU:BDY0Re[00haS3g_AS5>Le:DE[EBU4icAS4icRe[9BTLiaBU0Q240`aS00D@Q1BU6<HHaQcW00<H
aP@DY@D@Q10<H`D8@P0336<8@PQ200<8@P8<H`03248@Q24800@YBPLU:@lQ20=oo`03001oogoo03Mo
o`00BWoo00<007ooOol00RDY1BU:12e[536<0SF]0S6<00@e[DHa=JdDY@8@Q0056<HQ248@G_M_N`03
JeX02FLiG_MJeU:DCW=6<D8@?NlicP02=Jd2<H`2=Jd0236<;F/aS36<=JdmkdHaBU82CW<02DYBAS52
43F];F/U:B486<HDY@0248@236<00a245:DHaP047>L28@P37>L00aS65:D@Q00348@?36<5248236<5
248236<011BU8@PYBRU:22DY42480goo00<007ooOol0=goo001:Ool00`00Oomoo`039BT4:DX8;F/@
<H`2=Jd2<H`2@Q000bDY5:DDY@0248@011BU;F]>LfLi0V]J0VLi0V<H00ANme[FE[E>L`9:DP04AS52
43g_>Lh2=Jd4<H`00cF]>Li24002AS402TYBAS52448@>Lh]JbU:8@PLiaS60QBU1A240QBU00<HaQcW
7>L00R4800<LiaS65:D01A243PaS1PQ20PaS1@Q20PaS00<@Q1cW9BT022DY4B480goo00<007ooOol0
=goo001:Ool200000goo9BTU:@029BT4:DX8;F/=<H`013F]<H`e[CF]0S6<00E6<CW>5:D<HaBU008<
H`0448@U:D8@F]H4IcT4HaP02E[FDYA>LdYB@Q0mkcW>=JdaS004;F/2<H`00cW>?Nm24003AS402T8@
?NlicS6<;F/U:B487>LHaQBU2A241ABU1A243`aS1`Q200<<H`Q224800`Q20PaS00<@Q1S67>L00b48
12DY4R480Woo0P00>Goo001:Ool00`00Oomoo`059BT4:DX8;F/><H`2=Jd2<H`01D8@=JdHaPaS48@0
0PaS00D@Q248>LiF]Ekg00=S6009G_MJeU[FF]IF]DicBU9243W>008aS0H]J`04<H`e[CW>@Q04AS40
1T8@?NlicS6<;F/YBP8Q208Li`8HaP<DY@h@Q0l<H``8@P@<H`0448@HaQcW7>L28@P39BTB8@P3Ool0
0`00Oomoo`0gOol004Yoo`03001oogoo00HU:@DYBPL]J`@aS0D]J`LaS00=;F/icRe[7>L<Ha24248<
Ha248@Pe[DicG_L00f<H00YNme[FE[EF]DicAS5243W>=JdaS0@]J`8aS08e[@03>Li244Ha009:DP96
<@08@Q0mkcW>=JdaS2e[:DXU:@8Q208Li`8HaP<DY@X@Q14<H``8@P0336<8@PQ20088@P0536<@Q1S6
7>LQ20039BTB8@P3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00PU:@@YBQ0]J`HaS004;F/aS2U:
8@P248@236<01Q247>L]JdYBF]IS609[FP07IcUS65kgF]IBU4YBAS400T8@00<mkcW>>Lh00cW>00@m
kd8@@Q16<@9:DP03CW=:DTYB0096<@07@Q0mkcW>=JdaS2e[:DX012DY00<Q21cW7>L00QS60aBU1a24
4@aS2`Q20PaS00@8@P@Q12448@88@P0548@DYAcW8@PU:@0C8@P3Ool00`00Oomoo`0gOol004Yoo`03
001oogoo00XU:@<YBQ0]J`DaS004=JdaS2U:7>L25:D02@aS48@@Q1S69BU245JeIcU[FP02Kg/01V]J
IcUS65kgE[EBU0=>L`9:DPI6<@03BU9>Ldic009>L`9:DP06AS5243g_>Lhe[C6<0Re[00HYBRe[;F/]
JbU:9BT38@P00acW6<HDY@035:D648@>36<=24800`aS2488@P02248336<011247>LU:BDY0b480RDY
3R480goo00<007ooOol0=goo001:Ool00`00Oomoo`0;9BT3:DXA;F/2<H`2=Jd01C6<:DXQ21S65:D0
0Q2400LDYAS68@Pmke:DHaQ[FP02Kg/3JeX00f<HG_MJeP03F]H2E[D2DY@4CW<4DY@2CW<01dYBAS56
<D8@?NlicSF]008aS08]J`8aS004;F/YBRDY9BT28@P00acW6<HDY@055:D448@<36<C24801@aS2488
@PQ26<H00RDY0b480bDY3B480goo00<007ooOol0=goo001:Ool200000goo9BTU:@0:9BT3:DX@;F/2
<H`2=Jd01S6<;F/U:AcW6<HDY@<HaP048@PicTicG_L6JeX016LiHaQS66<H0ekg00AJeUJeDYABU0=>
L`ABU09>L`07BU96<DHa@Q0mkcW>=Jd01S6<00<]JbU::DX00RDY00@Q21cW6<HHaP@DY@D@Q0/<Ha@8
@P0736<8@PQ2248DYB489BT04b480Woo0P00>Goo001:Ool00`00Oomoo`0<9BT3:DX2;F/00bU:;F/]
J`0:;F/3<H`3=Jd01C6<;F/U:AcW6<H00QcW00DHaRDY=Je>Lekg00M[FP04IcUS66<HHaP2G_L015[F
E[EBU5:D24ic0TYB0THa00=243g_>Lh00SF]136<0Re[00DYBRDY9BTQ21cW008HaP@DY@D@Q0`<HaL8
@P0336<@Q1cW00dQ20LLi`=oo`03001oogoo03Moo`00BWoo00<007ooOol00b482BDY2BU:12e[2S6<
0cF]00<]JbDY8@P00R4800DHaRDY>Li>Lekg00A[FP04Kg][FV]JIcT3HaP2G_L015[FE[EF]E:D1dic
0dYB0THa00=243g_>Lh00SF]136<00<]JbU::DX00RDY00@Q21cW6<HHaP@DY@D@Q0/<Ha08@P0336<8
@PQ200H8@P0336<DYAcW00`Q20LLi`=oo`03001oogoo03Moo`00BWoo00<007ooOol01B481bDY2RU:
0be[2S6<010e[CW>>Lhe[C6<:DXU:AcW5:DYBSg_CW=NmfLiJeYW>@=[FP03IcUS66<H009S60=Nm`03
F]IF]EJe009BU0E>L`=:DP96<@04@Q0mkcW>>Lh2=Jd2<H`2;F/2:DX29BT28@P00acW6<HHaP035:D5
48@;36<I24801@aS5:DHaR487>L00R4800<Lib488@P0124821cW0goo00<007ooOol0=goo001:Ool0
0`00Oomoo`068@P79BT9:DX2;F/;<H`2=Jd3>Lh02c6<:DXLiaS6;F]245:DG_MW>F]JIcT00f]J00=W
>F<HHaP00V<H0ekg00=JeUJeE[D00U:D14ic14YB0THa00A243g_>LhicP8e[@8aS08]J`8YBP<U:@04
8@PLiaS66<H35:D548@:36<F248236<324801A246<HLiacW8@P00QcW1R4821cW0goo00<007ooOol0
=goo001:Ool00`00Oomoo`088@P59BT5:DX29BT2:DX3;F/3<H`3;F/7<H`2=Jd02bU:9BTLiacW<Ha6
<EJeHaQW>F]JIcT00f]J00=W>F<HHaP00f<H0Ukg00=JeUJeE[D00U:D0dic14YB0dHa00A243g_>Lhi
cP8e[@8aS0<]J`8YBP8U:@038@PLiacW008HaP<DY@@@Q0X<HaH8@P8<H`<8@P0348@DYAcW00XQ20PL
i`=oo`03001oogoo03Moo`00BWoo0P0000=oob488@P02B480bDY0bU:12DY0RU:2Be[0S6<00@e[Be[
:DXYBP8]J`088@PLib48:DXicTYBF]IW>@M[FP9W>@=S609Nm`03F]IF]EJe009BU0=>L`=:DP=6<@92
4003?NlicSW>008e[@<aS08]J`8YBP8U:@038@PLiacW008HaP@DY@<@Q0/<HaX8@P0348@DYAcW00PQ
20XLi`9oo`8003Uoo`00BWoo00<007ooOol032482RDY0RU:1Be[00LYBRe[:DX]Jc6<=JdU:@027>L2
9BT021S67>LU:CF]AS5BU5kgIcT7JeX3IcT3HaP015kgF]IJeUJe0U:D0dic0TYB14Ha00A243g_?Nli
cP<e[@<aS08]J`8YBP8U:@038@PLiacW00<HaP@DY@<@Q0X<HaP8@P8<H`0348@DYAcW00LQ20/Li`=o
o`03001oogoo03Moo`00BWoo00<007ooOol00R480acW1b482RDY12U:0Re[12U:00H]Jc6<=JdQ21S6
7>L29BT021cW8@P]Jcg_BU9F]EkgIcT7JeX2IcT3HaP2G_L00e[FE[EF]@02DY@2CW<3BU83AS42@Q00
0cg_>LhicP03=Jd2<H`3;F/2:DX29BT00b487>LLi`046<H35:D348@:36<G248436<00a247>LQ2003
9BT28@P<7>L3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00PLi`DQ20XU:@@YBP03;F/YBRU:00<Y
BP05;F/aS1cW5:DHaP028@P021cW9BTaS4HaDYAJeV<HIcT6JeX3IcT3HaP2G_L00e[FE[EF]@02DY@2
CW<2BU83AS43@Q000cg_>LhicP03=Jd2<H`3;F/3:DX012DY8@PLiacW11S60aBU0a242`aS5PQ210aS
00<@Q1cW8@P00bDY0R4831cW0goo00<007ooOol0=goo000gOol30003Ool30004Ool20004Ool00`00
Oomoo`097>L48@P:9BT8:DX01bDY:DX]Jbe[6<H@Q1S600<Q2006:DXe[DHaCW=JeV<H0VLi1V]J0fLi
0f<H00=Nme[FF]H00UJe00=BU4icCW<00dYB0dHa0T8@00<mkcW>>Lh00cF]0c6<0Re[0bU:00@U:B48
7>LLi`@HaP<DY@<@Q0X<HaL8@P@<H`0348@HaR4800DQ20`Li`=oo`03001oogoo03Moo`00>7oo00<0
07ooOol01Goo00@007ooOol0009oo`05001oogooOol00002Ool:7>L48@P99BT7:DX04Be[:DXYBRU:
9BTDYA245:DQ22DY:DX]JcW>AS5>Le[FHaP00VLi1V]J1FLi0V<H00ANme[FE[EF]@9BU09>L`9:DP=6
<@924003?NlicSW>00<e[@<aS0<]J`8YBP049BTQ21cW7>L26<H45:D448@:36<G248436<00a246<HL
i`037>L28@P<7>L3Ool00`00Oomoo`0gOol003Qoo`03001oogoo00Eoo`04001oogoo0002Ool01000
Oomoogoo0P0000=ooacW7>L021cW1B4822DY1bU:00D]JbU::DXU:AcW00<@Q00;7>LU:BU:<H`icTHa
BU9F]EkgHaQW>@07JeX4IcT2HaP00ekgF]IJeP02E[D2DY@014icBU9:DTYB0THa0T8@00<mkcW>>Lh0
0cF]136<0Re[0bU:00<Q21cW7>L00QS60aBU1A242PaS5`Q210aS00<@Q1S67>L04AcW0Woo0P00>Goo
000hOol00`00Oomoo`02Ool30003Ool01000Oomoo`000goo00@007ooOolHaPTLi`LQ20HU:@HYBP8]
J`8YBP039BTHaPaS008<H`0;5:DLibU:;F/e[D8@BU9F]EkgHaQW>@09JeX3IcT016<HG_MJeU[F0UJe
0U:D0Tic0TYB0dHa00A243g_>LhicP<e[@@aS08]J`<YBP038@PLiacW008HaP8DY@H@Q0T<HaP8@P@<
H`0348@HaQcW008Li`<Q20LLi`036<HLiacW008Li`=oo`03001oogoo03Moo`00>7oo00<007ooOol0
0Woo00<007ooOol00goo00@007ooOol000=oo`03001oogoo008HaPTLi`LQ20HU:@DYBP<]J`03:DXQ
21BU00<8@P0:36<DYB48:DXaS48@BU9>Le[FG_L2IcT9JeX3IcT00f<HG_MJeP02E[D2DY@2CW<3BU82
AS40148@?NlicSW>0cF]136<0be[0RU:00@Q21cW7>LHaP<DY@L@Q0P<HaL8@PD<H`0348@HaR4800DQ
20HLi`HHaP=oo`03001oogoo03Moo`00=goo0P0017oo10000goo0P0017oo00<007ooOol00aS62AcW
1b481BDY2BU:00<LiaBU24800`aS00XDYAS68@PU:CF]@Q1:DU:DF]IS609W>@U[FP9W>@03HaQNme[F
009F]@=BU09>L`9:DP96<@04@Q0mkcW>>Lh4=Jd3<H`3;F/2:DX012DY7>LLiaS60aBU0a242PaS6@Q2
10aS0Q2400<HaQcW8@P012481AcW1aS60goo00<007ooOol0=goo001:Ool00`00Oomoo`036<H97>L8
8@P49BT3:DX29BT4:DX00aS65:D<H`0536<02ABU7>LYBSF]?Nm:DUJeG_MS6002IcT8JeX2IcT00f<H
G_MJeP03E[D3DY@2CW<2BU82AS400d8@?NlicP05=Jd3<H`2;F/2:DX012DY8@PLiaS60aBU0Q242PaS
6PQ20`aS0Q2400@DYAS67>LLi`@Q20DLi`LHaP=oo`03001oogoo03Moo`00BWoo00<007ooOol00aS6
2acW1b4812DY0RU:0RDY12U:0QBU00<<Ha2448@00PaS00`8@PaS5:DQ22U:=Je244icF]INmf<HIcT8
JeX2IcT00f<HG_MJeP04E[D2DY@2CW<2BU82AS400d8@?NlicP05=Jd3<H`3;F/01BU:9BTQ21cW6<H0
0aBU00<@Q0aS36<02@aS6PQ20`aS00@@Q1BU6<HHaP8Li`<Q20HLi`LHaP=oo`03001oogoo03Moo`00
BWoo00<007ooOol00aS63AcW1B481BDY00@YBRDY9BTU:@8YBP039BT@Q1BU00<@Q0@<H`0648@HaR48
:DXicTYB0U[F0V<H0VLi1F]J0fLi00=S65kgF]H00eJe0U:D0Tic0TYB0THa0T8@00<mkcW>=Jd00cF]
136<0Re[0RU:00@U:B487>LHaP8DY@8@Q0X<HaX8@P@<H`0448@DYAS66<H27>L38@P57>L86<H3Ool0
0`00Oomoo`0gOol004Yoo`800003OolHaQS6008HaPdLi`DQ20HU:@088@PU:BDY:DXU:@aS5:D@Q08D
Y@H@Q0045:DLibe[@Q02E[D00ekgHaQW>@08IcT016<HG_MNme[F0UJe0e:D0Tic0TYB0THa00A243g_
?NlicP<e[@<aS0@]J`8YBP049BTLiacW6<H25:D248@936<724800`aS2488@P0A248336<00a245:DH
aP057>L00b487>LLi`047>L86<H2Ool2000iOol004Yoo`03001oogoo00<HaPhLi`DQ20XU:@04:DX<
Ha2448@56<H02ABU48@@Q1BU7>L]Jcg_BU9BU002G_L2HaP7IcT016<HG_MNme[F0UJe0U:D0dic0TYB
00A6<D8@@Q0mk`8icP<e[@@aS08]J`<YBP038@PLiaS6008DY@8@Q0X<Ha/8@P<<H`0348@DYAcW00`L
i`PHaP=oo`03001oogoo03Moo`00BWoo00<007ooOol00aS63AcW1R482RDY00@YBQ2448@@Q08Li`04
6<HLiaS66<H248@021BU7>L]JcW>@Q1>LeJeG_L5HaP3IcT2HaP2G_L00e[FE[EF]@02DY@3CW<2BU82
AS400d8@?NlicP02=Jd5<H`3;F/2:DX012DY8@PHaQS611242PaS5PQ200<<H`Q224800PQ20PaS0Q24
00<DYAcW7>L02acW21S60goo00<007ooOol0=goo001:Ool00`00Oomoo`036<H67>L=8@P:9BT01Re[
5:D@Q1BU7>LQ208Li`0;8@PLiaBU48@DYAcW;F/e[CW>AS5F]@02G_L016<HG_MNmekg16<H0Ukg0U[F
0UJe0e:D0Tic0TYB0THa00A243g_>Lhe[@@aS0<]J`<YBP8U:@037>LHaQBU008@Q0/<HaL8@PL<H`03
48@DYAS600dLi`PHaP=oo`03001oogoo03Moo`00BWoo00<007ooOol00aS61QcW3R482BDY00@YBQS6
36<@Q08Li`056<HDYAS66<HDY@0248@01aS6:DXaS36<@Q1BU5[F00ENm`03HaQW>F<H009S6003F]IF
]EJe00=BU09>L`A:DP96<@04@Q0mkcW>=Jd2<H`012e[:DXU:BDY12480QcW00<HaQBU48@02@aS6`Q2
1`aS00D@Q1BU6<HLib4800PLi`/HaP=oo`03001oogoo03Moo`00BWoo00<007ooOol00aS61AcW4B48
0bDY00<YBRDY8@P00RDY00<Li`aS48@00QS600D@Q0aS48@DYAS6008@Q0075:DU:Be[:DXe[DYBDY@0
0eJe00ABU5JeF]INm`9JeP03E[EBU5:D009>L`04BU9243W><H`6;F/5<H`00be[9BTU:@027>L25:D0
11S65:DDYABU0Q2420aS70Q220aS00<DYAS67>L00R4811cW0QS600<LiaS66<H011S61QcW0goo00<0
07ooOol0=goo001:Ool200000goo6<HHaP026<H67>L28@P57>L88@P39BT2:DX01RDY:DXYBQcW36<@
Q08HaP0348@<H`aS00<DY@8@Q0077>LU:BDY;F]244YBCW<00TYB0T8@1DYB00M6<D8@?NlicS6<;F/U
:@027>L00aS67>LLi`037>L28@P29BT01B487>LHaQS65:D00Q2411BU00<@Q0aS36<01`aS7@Q21@aS
0Q2400<DYAS67>L01QcW00<HaQcW7>L031S60Woo0P00>Goo001:Ool00`00Oomoo`066<H?7>L48@P3
9BT2:DX012DY:DXYBR480Q2400<HaQBU48@010aS00@@Q1BU48@DY@8Li`039BTaS3g_00924004>Lh]
Jbe[;F/4<H`2;F/01BU:8@PQ21cW6<H00Q240`aS112411BU0Q2440aS7`Q21@aS00<@Q1BU6<H02acW
31S60goo00<007ooOol0=goo001:Ool00`00Oomoo`076<H?7>L48@P29BT4:DX01Re[9BTHaQ246<HD
Y@8@Q0<<H`0548@DYA2448@DY@026<H01R48;F/aS36<9BTLi`<HaP8Li`048@PLiacW5:D448@:36<5
248@36<J24800`aS2488@P02248436<011245:DHaQS62acW31S60goo00<007ooOol0=goo001:Ool0
0`00Oomoo`096<H>7>L38@P00bDY:DXYBP02:DX2;F/00bDY6<H@Q0026<H25:D448@336<348@01aBU
6<HHaQS65:D@Q0aS00<@Q08DY@H@Q20<HaT8@P8<H`@8@P@<H`0348@HaQS600<Li`8HaPLLi``HaP=o
o`03001oogoo03Moo`00BWoo00<007ooOol02QS63QcW0R4800<U:BU::DX00RU:0Re[00LU:AcW48@H
aQcW5:DLi`035:D011242488@PaS0a241`aS1A240PaS11247`aS6PQ20`aS0`Q20`aS00<@Q1BU6<H0
0QcW00<Q21cW6<H00QS61QcW31S60goo00<007ooOol0=goo001:Ool00`00Oomoo`045:D96<H57>L0
0aS67>LLi`037>L28@P59BT3:DX00b486<HHaP037>L36<H011242488@PaS0a240PaS0PQ20`aS0a24
0`aS00<8@PaS36<03@aS1`Q200<<H`Q2248010Q21@aS6`Q20`aS0PQ210aS00<@Q1BU7>L00b4800@L
iaS66<HHaPDLi`dHaP=oo`03001oogoo03Moo`00BWoo0P0000=ooaBU5:D00aBU1aS62acW224800DU
:BU::DX]JbDY008Li`068@PLiacW7>LHaQBU0a240QBU0a240PaS10Q210aS@0Q21PaS0Q2400<DYAS6
7>L00b4800<LiaS66<H00QcW4AS60Woo0P00>Goo001:Ool00`00Oomoo`065:D66<H;7>L58@P37>L0
1248:DX]Jc6<0RU:00<U:AcW7>L00QcW00<HaQBU6<H011BU0a240PaS0PQ200<48@Q22480@`Q21@aS
00D@Q1BU5:DHaQcW00@Q20DLia4HaP=oo`03001oogoo03Moo`00BWoo00<007ooOol01aBU1AS62acW
1B480QcW0R4800HU:Be[=JdYBRe[:DX36<H01AcW6<HHaQS65:D01A240`aS1PQ20PaS>PQ20PaS10Q2
10aS0Q2400@DYAS66<HLi`<Q20HLia4HaP=oo`03001oogoo03Moo`00BWoo00<007ooOol01aBU1AS6
4QcW0R4800DU:Be[>LhaS2e[008YBP8Li`038@PHaQBU008HaP035:D@Q124008@Q0h<H`88@QL<Had8
@PX<H`8@Q0045:DHaQS67>L48@P67>LA6<H3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00LDY@HH
aP/Li`038@PLiacW00<Li`8Q20079BT]JcF]<H`]Jc6<=Jd00RU:00<U:AcW5:D00QS600<DYA2448@0
3`aS10Q25PaS7@Q22@aS0Q2400@DYAS66<HLi`DQ20DLi`dHaP035:DHaQS6008HaP=oo`03001oogoo
03Moo`00BWoo00<007ooOol01aBU1aS62AcW224800LU:BU:;F/]Jc6<=JdicP03=Jd00be[8@PDY@03
5:D248@536<624800`aS2488@P0i248736<011245:DHaQcW1B4800<U:B488@P00acW3QS60aBU0QS6
00DDYGooOomoo`0003Uoo`00BWoo00<007ooOol01aBU21S621cW224800LU:Be[:DXYBS6<>Lhmk`02
>Lh01CF]<H`YBQcW6<H00QBU0Q2430aS=@Q200<<H`Q224800PQ220aS00@DYAS67>LQ20HU:@8Q20<L
i`hHaPHDY@=oo`03001oogoo03Moo`00BWoo0P0000=ooaBU5:D01ABU31S631cW014Q22DY:DXYBRe[
<H`mkdHa@Q0icS6<:DXU:AcW8@PHaQ24008<H`0348@<H`aS00T<Hc<8@P`<H`8@Q0035:DLib4800LU
:@8Q208Li`lHaPHDY@9oo`8003Uoo`00BWoo00<007ooOol01aBU3AS621cW0QS60acW00HQ22DY9BTY
BS6<@Q02AS401cF]9BTLib489BTQ21BU00l<HbX8@P0336<8@PQ200D8@PX<H`<@Q0035:DHaQcW008U
:@<YBP<U:@8Q208Li`lHaPHDY@=oo`03001oogoo03Moo`00BWoo00<007ooOol021BU31S61QcW11S6
00@LiaS66<HLi`<Q2008:DXe[DHaAS4icRDY5:DHaP8Q20036<H@Q12400`<Hc<8@PT<H`<@Q08DY@03
7>LU:BU:00@YBP8U:@8Q20<Li`lHaPHDY@=oo`03001oogoo03Moo`00BWoo00<007ooOol021BU2aS6
3acW0b480RDY00`]Jcg_@Q0icR486<HLib487>LHaQBU48@636<g248836<448@01QBU6<HHaR48:DX]
J`8aS003;F/YBRDY008Q20@LiaDHaP=oo`03001oogoo03Moo`00=goo10000goo0P0017oo0P0017oo
00<007ooOol021BU2QS641cW1R4800@]Jd8@BU8e[@<U:@058@PHaQS65:D@Q00536<e248936<348@2
5:D01AS67>LQ22DY;F/00c6<00@]JbU:9BTQ20HLia@HaP=oo`03001oogoo03Moo`00>7oo00<007oo
Ool00Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`095:D96<HA7>L48@P032DY;F/a
S3g_AS4mkcW><H`U:AcW6<HDY@<@Q00336<8@PQ20148@P8<Hah8@PX<H`H@Q0065:DHaR489BTYBRe[
0S6<00@]JbU:9BTU:@8Q20HLia@HaP=oo`03001oogoo03Moo`00>Goo00D007ooOomoo`00009oo`04
001oogoo0002Ool01000Oomoogoo0P0000=ooa245:D01aBU2AS61QcW00<HaQcW7>L021cW0b4800HU
:BU:9BTYBS6<@Q02AS4013g_<H`]JbDY11BU0Q240PaS10Q240aS40Q20`aS2@Q22@aS00D@Q1BU5:DD
YA24008DY@046<HLibU:<H`3=Jd00c6<:DXQ20038@P77>LD6<H2Ool2000iOol003Yoo`04001oogoo
0002Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`0348@DYABU00LDY@THaPdLi`8Q20067>LQ
22488@PU:BU:0RDY00<]JcF]@Q000T8@0SW>00<aS2DY7>L011BU00<@Q0aS36<00`aS60Q200<<H`Q2
248010Q21@aS1@Q22`aS00<@Q1BU5:D011S600@Lib48:DXaS0<e[@03<H`]JbU:00LLiaPHaP=oo`03
001oogoo03Moo`00=goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool031BU2AS62QcW22480RDY00<YBRe[<H`01cF]00HaS2DY6<HLiaS65:D248@336<F248L36<00a24
5:DHaP026<H01QcW8@PYBRU:<H`e[@8icP04=JdaS2U::DX38@P67>LH6<H3Ool00`00Oomoo`0gOol0
03Qoo`8000Aoo`8000Aoo`8000Aoo`03001oogoo00dDY@THaPPLi`XQ20049BTYBRe[=Jd3<H`2;F/0
1c6<>LhicSF];F/U:AcW008DY@036<H@Q0aS00L<H`h8@Qh<H`035:DLiacW008Li`04:DX]Jbe[>Lh3
@Q001CW>=JdYBRDY8@P00QcW00<Q21cW7>L011cW61S60goo00<007ooOol0=goo001:Ool00`00Oomo
o`0>5:D86<H67>L<8@P00bDY:DX]J`02;F/2<H`2=Jd01b48;F/aS36<=JdaS2U:008Q20036<HDYA24
00<@Q0h<H`@8@Q<<H`0348@<H`aS00D<H`8@Q08DY@056<HLibDY;F/e[@05@Q0013g_<H`]JbDY0b48
21cW4aS600<DYAS66<H00QS60goo00<007ooOol0=goo001:Ool00`00Oomoo`0>5:D86<H37>L98@P4
9BT012489BTU:BDY0RU:0Re[0S6<00HicSF]9BTU:BU:;F/2<H`01Be[:DXU:AcW6<H00QBU00<@Q0aS
36<07PaS1Q241PaS00@@Q1BU6<HHaP8DY@047>LaS3g_AS42BU82@Q0013g_=JdYBRDY0b4800<U:AcW
7>L01QcW4QS61QBU0goo00<007ooOol0=goo001:Ool2000017oo48@@Q12431BU1aS60acW22481BDY
0b4800DU:BU::DXYBRe[00<aS003@Q0aS2DY008Q2004:DX]Jc6<:DX29BT28@P00aBU48@<H`0N36<7
48@336<448@00aBU6<HQ20027>L00bDY>Li6<@02BU83@Q001CF];F/U:B487>L00b4800<LiaS67>L0
1AcW4AS61aBU0Woo0P00>Goo001:Ool00`00Oomoo`0548@95:D76<H57>L68@P69BT38@P29BT012U:
;F/aS36<0Re[00<e[DYB<H`00acW0Re[00TQ21cW:DXaS2e[8@PLiaBU48@070aS21240QBU0a240aBU
00LLibDY:DX]Jc6<@Q1:DP02AS43>Lh013F]:DXU:BDY124800<LiaS67>L02AcW51S60goo00<007oo
Ool0=goo001:Ool00`00Oomoo`0648@85:D66<H67>L58@P79BT38@P29BT02bU:<H`aS36<;F/U:BU:
?Nm6<CF]6<H02R4800DLiaS65:DDYA2400X<H`H@Q0T<H`D@Q0@DY@056<H@Q1245:DLi`026<H01R48
:DX]Jc6<=Je24096<@06@Q0icSF]<H`]JbU:0bDY0R480QcW00<HaQcW7>L02AcW4aS60goo00<007oo
Ool0=goo001:Ool00`00Oomoo`0748@65:D66<H77>L58@P89BT28@P29BT2:DX2;F/03S6<;F/]Jc6<
>Li6<D8@8@PHaQcW9BTQ21cW6<H35:D01QS68@PQ21cW6<HDY@<@Q0@DY@/@Q0D<H`<@Q0HDY@<@Q00:
6<HLib489BTQ21cW9BTaS3F]>Lh3@Q001cW>=JdaS2e[:DXU:B48008U:@038@PLiacW00hLia8HaP=o
o`03001oogoo03Moo`00BWoo00<007ooOol01a241ABU1QS621cW12481BDY00<YBRDY9BT00RDY00<Q
22DY9BT00bU:00`]Jc6<=JdaS2U:;F/mkdHa>LhU:AcW9BT37>L011S65:D@Q1240QBU0QS61AcW0aS6
11BU3A242QBU00@HaQcW7>LQ208YBP049BTaS48@@Q03AS402d8@>LhaS36<:DXU:B487>LQ22DY8@P0
4AcW4AS60goo00<007ooOol0=goo001:Ool00`00Oomoo`0648@65:D56<H97>L48@P59BT00bU:9BTU
:@079BT00bU:;F/aS002>Lh02S6<;F/aS3W>AS4mkbU:8@P]Jb480QcW00<HaQBU48@00PaS0Q2400@H
aQcW7>LLi`DHaPDDY@H@Q08<H`<@Q0PDY@036<HLib48008Q200@;F/e[CW>>Li:DTicBU96<DYBAS52
43W><H`]JbU:9BT27>L00b489BTQ200?7>LC6<H3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00D@
Q0DDY@HHaPDLi`PQ20DU:@8YBPTU:@04:DX]Jbe[=Jd6>Lh01D8@AS4e[BDY8@P00QcW0R4800@HaQ24
36<<H`8@Q0@DY@DHaP@DY@@@Q0@<H`<@Q0<DY@<HaP0>7>LQ22489BTYBRe[<H`icT8@BU9BU5kgE[E:
DP924003?NlicSF]008]J`8U:@038@PLib48008Q20<Li`<HaPDLi`XHaPHDY@LHaP=oo`03001oogoo
03Moo`00BWoo0P0000Aooa2448@@Q0HDY@HHaP@Li`PQ20LU:@8YBPTU:@07:DX]Jbe[<H`e[CW>?Nl0
0T8@00PicT8@AS5243F];F/Q21S60QcW0QS600DDYA2448@<H`Q2008<H`0348@DYAS600@HaP<DY@@@
Q0@<H`8@Q00E36<@Q12448@DYAS68@P]Jc6<;F/YBRe[=JdmkdHaDYAF]E[FG_MBU48@008icP04=Jda
S2e[:DX39BT00b487>LQ20028@P37>L@6<H95:D66<H2Ool2000iOol004Yoo`04001oogoo48@65:D6
6<H57>L68@P99BT5:DX59BT6:DX01Be[<H`e[Cg_@Q000Sg_00M244HaAS5243g_>LhU:@037>L00aS6
5:D@Q00336<248@236<248@65:D248@236<248@26<H00aBU48@@Q00248@01ABU7>LU:Be[<H`00SF]
00XmkdHaBU9BU5JeDYA>LdYB?Nle[@<aS003;F/YBRDY008U:@HQ20<Li`@HaP8Li`dHaP@DY@PHaP=o
o`03001oogoo03Moo`00BWoo00<007ooOol011BU1AS621cW1B482RDY4bU:00<aS3F]?Nl00Sg_00A2
44HaAS56<@9:DP04>LhaS2U:9BT27>L011S65:DDYA2410aS0a241ABU0Q2400<<Ha2448@00QS600<Q
21cW6<H00QS600HLib48:DX]JcW>@Q02AS4024YBDYABU5:DCW=:DT8@=Jd2<H`2;F/2:DX39BT78@P<
7>L?6<H75:D3Ool00`00Oomoo`0gOol004Yoo`03001oogoo008DY@HHaPHLi`HQ20/U:A@YBP04;F/a
S3F]?Nl3@Q02AS42BU8014Ha@Q0icS6<0RU:00<U:AcW7>L00QBU10aS11240aBU0a2400<DYAS66<H0
0R480acW0R4800D]Jc6<?Nm6<Dic00=:DP06CW=BU4YB@Q0mkcF]0Re[0RU:12DY2R4831cW3AS621BU
0goo00<007ooOol0=goo001:Ool01000OomooaBU1aS611cW1B483BDY00<YBRDY9BT02BDY2BU:0Re[
00<aS3W>?Nl00Sg_0T8@00<mkd8@AS400THa00a243g_>LhaS2e[:DXU:B487>LDYA2436<248@45:D0
1A245:DDYAS67>L00b480QcW00LQ21cW7>LQ22e[>Li24002BU800dHa@Q0mk`02?Nl2>Lh2=Jd0136<
:DXQ22480bDY3b480acW0QS61AcW0aS611cW1AS611cW0aS60goo00<007ooOol0=goo001:Ool00`00
Oomoo`076<H47>L38@P?9BT3:DX:9BT;:DX01S6<>LhmkcW>=JdicP96<@924096<@9:DP0<AS4mkcg_
=JdaS2e[9BTQ21cW6<HDYA2411BU00X@Q1BU6<HLibDY:DXU:AcW5:DHaP@Li`03;F/icT8@00924003
?Nle[CF]00<aS08e[@03<H`]Jbe[008YBQ4U:@8Q20TLia<HaP=oo`03001oogoo03Moo`00BWoo0P00
00=ooacW7>L00acW1R481BDY1bU:1BDY1bU:0bDY3bU:00T]JcW>@Q0mkcF]<H`e[Cg_@Q000THa1d8@
0Sg_00DicS6<:DXYBR48008Li`8Q208Li`8HaP097>LU:C6<:DXLiaBU7>LU:BU:008]J`04=Jdmkcg_
?Nl2>Lh2=Jd00c6<;F/]J`02;F/3:DX29BT8:DX;9BT88@P;7>L38@P69BT2Ool2000iOol004Yoo`03
001oogoo008Q20PU:B`YBP05;F/icSg_?NlicP02<H`013F]?Nlmkd8@1dHa0d8@00E6<Cg_=JdYBRe[
008aS003;F/YBRDY008Q2007:DXe[CF];F/U:BU:<H`00SW>00Dmkd8@@Q1243g_008icP03=JdaS2e[
00<YBPHU:@TYBPHU:@@YBP<U:@<YBP8]J`@YBPD]J`8aS08e[@04>Lhmkcg_?Nl2>Lh01Cg_Oomoogoo
0000>Goo001:Ool00`00Oomoo`069BTa:DX01c6<>Li6<DHa>LhaS3F]008icP03@Q16<DHa00=6<@=:
DP04AS52448@@Q03?Nl2@Q02?Nl01CF]<H`]JcF]?Nl00cW>00<mkd8@@Q001D8@00HmkcW>>Lhe[C6<
;F/6:DX5;F/6<H`>=Jd013W>?Nlmkcg_0d8@00A6<D8@@Q1240=6<@9:DP9>L`MBU0=oo`03001oogoo
03Moo`00BWoo00<007ooOol0<Be[0c6<0be[00HaS3W>BU9BU4YB@Q02>Lh01Sg_>Lhmkcg_@Q16<@=:
DPI6<@Q:DP924004?NlicSW>@Q04AS42@Q02AS40148@?Nlmkcg_0SW>0SF]13W>0Sg_0d8@0dHa14YB
14ic0e:D00=F]E:DDY@01E:D0UJe00=JeUkgG_L00Ukg2E[F1ekg0goo00<007ooOol0=goo001:Ool0
1000Oomooc6<<2e[0c6<0be[00@aS3F]?Nm6<@9:DP96<@04BU96<D8@@Q02AS45BU83AS43CW<2BU82
CW<025JeDYA:DTHa?Nle[CW>AS42BU82CW<01dYBCW=>LdicBU96<DYB00E>L`ABU0=F]@03F]INmekg
009Nm`ES60EW>@Q[FP9W>@9[FP=_N`04IcUS65kgG_L=F]H3Ool00`00Oomoo`0gOol004Yoo`03001o
ogoo00I240lmk`LicP<mk`LicQ8e[@8icP04@Q1:DTicCW<5BU82CW<3DY@8E[D2DY@2E[D025[FE[EB
U4icBU9>Le:DG_L3HaP8IcT3JeXBKg/7JeX3IcT6HaP02V]JKg]cW6mkJeYNme:DCW=:DTHa0d8@00=6
<DYBCW<00U:D14ic0goo00<007ooOol0=goo001:Ool2000017ooF]IJeU[F1EJe2E:D3dic24YB34Ha
0TYB1Dic00=BU5[FF]H00U[F0ekg16<H1VLi1V<H0fLi0e[F00=NmfLiJeX00f]J5Fmk1F]J16Li1f<H
0Ukg1E[F00=NmfLiJeX00Vmk00=W>EJeAS400Sg_0SW>00De[CW>?Nm6<DYB00=>L`=:DP9oo`8003Uo
o`00BWoo00@007ooOom_N`A[FPiW>A=S60iNm`9S60MW>@=[FP03Kg]cW7>L00Q_N`03Lia_Nfmk009[
FP9_N`04JeY_NfmkKg/2HaP2IcT2JeX00fmkJeY[FP08JeX@IcT4HaP:G_L2F]H4E[D025[FHaQ[FVmk
JeYW>EJeAS43>Lh2=Jd013W>?Nm6<DYB0e:D0Tic00EBU7ooOomoo`0003Uoo`00BWoo00<007ooOol0
26]J1fmk1g>L1Vmk0g>L1GNm2g>L27Nm37>L2Vmk2F]J2V<H9Ukg1U[F00MW>F]JKg][FVLiF]I6<@03
?Nl3>Lh01D8@AS5>Le:DE[D015:D0goo00<007ooOol0=goo001:Ool00`00Oomoo`04HaP4IcT3JeX3
Kg/6Li`2Kg/2JeX4IcT3JeX2Li`01GNmLiacW7>LKg/01F]J0fmk1W>L1GNm1g>L1Fmk2V]J1FLi0V<H
0Ukg0V<H00=Nmf<HHaP04Ukg2F<H0ekg1F<H1Ekg1e[F00QW>F]JKg][FVLiE[E6<CW>0cF]00LaS3F]
>LhmkdYBDYAF]@04DY@3Ool00`00Oomoo`0gOol003Moo`@0009oo`<000Aoo`8000Aoo`03001oogoo
00AJeP=Nm`9S60=W>@9[FPI_N`9[FP9S6003G_MJeUkg009Nm`9S609[FP=_N`05JeYW>F<HHaQNm`04
HaP00fLiJeY_N`0CKg/3JeX00fLiJeY[FP07JeX3IcT3HaP9G_L9F]H:G_L3HaP8G_L2HaP6G_L7F]H0
26<HJeY_Nf]JIcUJeTHa>Lh2=Jd00c6<=Jde[@02>Lh00dYBDYAF]@04DY@3Ool00`00Oomoo`0gOol0
03Qoo`03001oogoo00Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo0UJe15[F0ekg0V<H0fLi
1f]J00EW>F<HG_MJeUJe00AJeP03G_MW>FLi00=[FP03HaQNme[F00EJeP9Nm`04HaQ[FV]JJeX5Kg/2
JeX3Kg/2JeX6Kg/6JeX4Kg/4JeX2IcT3HaP<G_L4F]H9G_L5HaP7G_L7HaP3G_L6F]H02V<HJeY_Nf]J
IcUJeTHa>Lhe[CW>0cF]0SW>00=6<E:DDY@015:D0goo00<007ooOol0=goo000iOol00`00Oomoo`04
Ool01000Oomoo`000Woo00@007ooOomoo`800003OomJeU[F00ANm`=S609W>@9[FPI_N`9[FP03IcUS
65kg00=JeP=Nm`04HaQW>FmkKg/2JeX00fLiG_MJeP04F]H3G_L00fLiJeYcW00;Li`7Kg/2JeX2IcT3
JeX5Kg/3JeX2IcT3HaP=G_L2F]H7G_L9HaP5G_L9HaP2G_L6F]H00f<HJeY[FP02IcT00e[FAS4icP02
=Jd2<H`2=Jd00cW>AS5>L`05DY@2Ool2000iOol003Yoo`03001oogoo00<000=oo`04001oogoo0003
Ool00`00Oomoo`04G_L3HaP2IcT2JeX3Kg/3Li`3Kg/2JeX2IcT016<HG_MS66<H0fLi0Vmk00EcW6mk
Kg][FVLi00ANm`=S6003IcU[FW>L00Ug_@IcW0A_N`I[FPI_N`=[FP9W>@=S60eNm`9JePMNm`US60IN
m`ES60ANm`MJeP07HaQ[FV]JIcUS65[FAS400cF]0c6<0SF]00=6<DicDY@015:D0goo00<007ooOol0
=goo000gOol01000Oomoo`000Woo00<007ooOol00goo00@007ooOol000=oo`03001oogoo00ANm`=S
609W>@9[FP9_N`EcW09_N`9[FP9W>@03HaQNmf<H009S609W>@9_N`03Lia_Nfmk009W>@ANm`9S6004
IcU[FV]JLi`9Mkd:Li`3Kg/2JeX4Kg/00g>LKg]_N`02Kg/2JeX2IcT6HaP7G_L5F]H9G_L5HaP8G_L3
HaP5G_L5F]H02EJeF]IS66]JKg]W>F<HE[E6<@03=Jd3<H`00cF]>Li6<@06DY@3Ool00`00Oomoo`0g
Ool003Qoo`8000=oo`@000=oo`8000Aoo`03001oogoo00=Nm`=S60=W>@9[FP9_N`EcW0=_N`03JeYW
>FLi00AS60=W>@9_N`05Lia_NfmkJeYW>@04G_L01V<HIcUW>F]JKg]cW0Yg_@UcW09_N`=[FPQ_N`9[
FP=W>@IS60MNm`EJeP]Nm`=S60UNm`03HaQNmekg00ANm`EJeP09E[EJeV<HJeY_NfLiHaQF]DHa00<e
[@<aS005=JdicTHaCW=F]@04DY@3Ool00`00Oomoo`0gOol004Yoo`03001oogoo00=Nm`=S60=W>@9[
FP9_N`EcW0=_N`03JeYW>FLi00AS60=W>@9_N`05Lia_NfmkJeYW>@04G_L01V<HIcUW>F]JKg]cW0Yg
_@UcW09_N`A[FPM_N`9[FP9W>@MS60QNm`=JePYNm`ES60QNm`=S60ENm`EJeP03E[EJeV<H009[FP04
IcUS65JeAS43=Jd3<H`013F]>Li6<Dic1E:D0goo00<007ooOol0=goo001:Ool00`00Oomoo`2UOol0
0`00Oomoo`0gOol004Yoo`04001oogoo000OOol00`00Oomoo`0LOol00`00Oomoo`0MOol00`00Oomo
o`0LOol00`00Oomoo`0MOol00`00Oomoo`04Ool00`00Oomoo`0gOol004YoojT003Uoo`00\
\>"],
  ImageRangeCache->{{{0, 299}, {179, 0}} -> {-123.424, -22.7207, 1.58571, 
  1.58571}},
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["This gives the error due to compression.", "MathCaption",
  CellTags->{"S2.2.1", "1.30"}],

Cell[CellGroupData[{

Cell["\<\
Sqrt[#.#&[Flatten[data-%%]]/
(Flatten[data].Flatten[data])]\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \(0.0506818263309318961`\)], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["\<\
This is the error computed using the cumulative energy. The \
discrepancy with the above result is due to the boundary effects.\
\>", 
  "MathCaption",
  CellTags->{"S2.2.1", "1.31"}],

Cell[CellGroupData[{

Cell["Sqrt[1-wpE[[1985]]]", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S2.2.1"],

Cell[BoxData[
    \(0.0487979063100247589`\)], "Output",
  CellLabel->"Out[27]= ",
  CellTags->"S2.2.1"]
}, Open  ]],

Cell["2.2.2 Analysis of an Image Using Local Trigonometric Basis", 
  "Subsection",
  CellTags->{"S2.2.2", "2.1"}],

Cell[TextData[{
  "The file ",
  StyleBox["finger.dat", "MR"],
  " contains an image of a finger print. We will use a local cosine transform \
to analyze it. "
}], "Text",
  CellTags->{"S2.2.2", "2.2"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S2.2.2", "2.3"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S2.2.2"],

Cell[TextData[{
  "This reads in the data. It has dimension ",
  Cell[BoxData[
      \(TraditionalForm\`{240, 192}\)], "InlineFormula",
    CellTags->"S2.2.2"],
  "."
}], "MathCaption",
  CellTags->{"S2.2.2", "2.4"}],

Cell[CellGroupData[{

Cell["\<\
(data = Get[ToFileName[{\"Wavelets\", \"Data\"}, \"finger.dat\"]];
Dimensions[data])\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S2.2.2"],

Cell[BoxData[
    \({240, 192}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"S2.2.2"]
}, Open  ]],

Cell["We display the data showing a finger print.", "MathCaption",
  CellTags->{"S2.2.2", "2.5"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[data, Mesh -> False]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S2.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00500801 0.0192308 0.00400641 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.14443 -0.0125 -6 -9 ]
[.14443 -0.0125 6 0 ]
[.26963 -0.0125 -6 -9 ]
[.26963 -0.0125 6 0 ]
[.39483 -0.0125 -6 -9 ]
[.39483 -0.0125 6 0 ]
[.52003 -0.0125 -9 -9 ]
[.52003 -0.0125 9 0 ]
[.64523 -0.0125 -9 -9 ]
[.64523 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.89563 -0.0125 -9 -9 ]
[.89563 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21955 -12 -4.5 ]
[-0.0125 .21955 0 4.5 ]
[-0.0125 .41987 -18 -4.5 ]
[-0.0125 .41987 0 4.5 ]
[-0.0125 .62019 -18 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .82051 -18 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.14443 0 m
.14443 .00625 L
s
[(25)] .14443 -0.0125 0 1 Mshowa
.26963 0 m
.26963 .00625 L
s
[(50)] .26963 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(75)] .39483 -0.0125 0 1 Mshowa
.52003 0 m
.52003 .00625 L
s
[(100)] .52003 -0.0125 0 1 Mshowa
.64523 0 m
.64523 .00625 L
s
[(125)] .64523 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(150)] .77043 -0.0125 0 1 Mshowa
.89563 0 m
.89563 .00625 L
s
[(175)] .89563 -0.0125 0 1 Mshowa
.125 Mabswid
.04427 0 m
.04427 .00375 L
s
.06931 0 m
.06931 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.11939 0 m
.11939 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.19451 0 m
.19451 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.29467 0 m
.29467 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.34475 0 m
.34475 .00375 L
s
.36979 0 m
.36979 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.44491 0 m
.44491 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.49499 0 m
.49499 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.57011 0 m
.57011 .00375 L
s
.59515 0 m
.59515 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.67027 0 m
.67027 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.72035 0 m
.72035 .00375 L
s
.74539 0 m
.74539 .00375 L
s
.79547 0 m
.79547 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.87059 0 m
.87059 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.94571 0 m
.94571 .00375 L
s
.97075 0 m
.97075 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21955 m
.00625 .21955 L
s
[(50)] -0.0125 .21955 1 0 Mshowa
0 .41987 m
.00625 .41987 L
s
[(100)] -0.0125 .41987 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(150)] -0.0125 .62019 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(200)] -0.0125 .82051 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .17949 m
.00375 .17949 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .33974 m
.00375 .33974 L
s
0 .37981 m
.00375 .37981 L
s
0 .45994 m
.00375 .45994 L
s
0 .5 m
.00375 .5 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .66026 m
.00375 .66026 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.14443 .99375 m
.14443 1 L
s
.26963 .99375 m
.26963 1 L
s
.39483 .99375 m
.39483 1 L
s
.52003 .99375 m
.52003 1 L
s
.64523 .99375 m
.64523 1 L
s
.77043 .99375 m
.77043 1 L
s
.89563 .99375 m
.89563 1 L
s
.125 Mabswid
.04427 .99625 m
.04427 1 L
s
.06931 .99625 m
.06931 1 L
s
.09435 .99625 m
.09435 1 L
s
.11939 .99625 m
.11939 1 L
s
.16947 .99625 m
.16947 1 L
s
.19451 .99625 m
.19451 1 L
s
.21955 .99625 m
.21955 1 L
s
.24459 .99625 m
.24459 1 L
s
.29467 .99625 m
.29467 1 L
s
.31971 .99625 m
.31971 1 L
s
.34475 .99625 m
.34475 1 L
s
.36979 .99625 m
.36979 1 L
s
.41987 .99625 m
.41987 1 L
s
.44491 .99625 m
.44491 1 L
s
.46995 .99625 m
.46995 1 L
s
.49499 .99625 m
.49499 1 L
s
.54507 .99625 m
.54507 1 L
s
.57011 .99625 m
.57011 1 L
s
.59515 .99625 m
.59515 1 L
s
.62019 .99625 m
.62019 1 L
s
.67027 .99625 m
.67027 1 L
s
.69531 .99625 m
.69531 1 L
s
.72035 .99625 m
.72035 1 L
s
.74539 .99625 m
.74539 1 L
s
.79547 .99625 m
.79547 1 L
s
.82051 .99625 m
.82051 1 L
s
.84555 .99625 m
.84555 1 L
s
.87059 .99625 m
.87059 1 L
s
.92067 .99625 m
.92067 1 L
s
.94571 .99625 m
.94571 1 L
s
.97075 .99625 m
.97075 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21955 m
1 .21955 L
s
.99375 .41987 m
1 .41987 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .82051 m
1 .82051 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .5 m
1 .5 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
192 string
192 240 8 [192 0 0 240 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EEEEEEE9F2F2EFEBEDF2EAEFEEE9ECE7E7ECEBEAEAE7E9E7
E9E6E8E4E5E8E8EBE3E4E5EAE7E4E2E3E5E5E2DCE4E3E2DF
E7D8D4D5D7DDDEDFDDDEDBDCD6DBDDDFDCDBDDDFE2DEDFDC
DCDDE0DDDDDEDDD9DCDBD5D9DED8DADADCDBDFE2E2E0E0DE
DBE0DADEE0DFD9DFDFD8DFDBD8D8D1DEE2E2DCDCE0DFDFDD
D5CCD0D1D8D0D7DBD7DCDAE4E2E4E0E4E5E9E5E3E9E0E4E4
E6E5E6EAE8E9E6E7E7E8E7EAEBE4E5ECE6E5E7EEE4E7E7F2
EFE9E5EDEEEBEBE9E9EAF1EBEFF2F2EAEAF5EEEDECF1E7EA
E9ECEDECECF2EFECEDEFEDF2EFE8EAE9EAEBECE9EAECE6E6
E8E5E9E3E2E2E3E8E3E9E6ECEAE3E7E6E8E2E3E3E4E3E2DE
E2D3D8DBD5DBDFDCDBDCD8CFD1DFDDE3DBD8DBDDDCDFD8DC
E2DDDDDCDDDADCD6DCDBD5D9DBD8DADBDADEDFDEDCE0E0E0
DCDCDBDEDDE0D8DFDDD8DDD8D8DED9E3DCDADBD7DCDBD8DB
D7CCCDCDDDD5D7D8DADADFDFE0E4E4E0E0E6E2E3E3DADCE0
E7E8E6EFE3E6E4E6E9E6E5EBEBE3E6EBEAE7EBE8E6E9EFFA
F2EEE8E9EEEAEDEDECECEFEDECF1EFEDE9EFEFEAEEEDE9EC
E7ECECECEFF3F4ECF2EFECF1EDEEEEE7E9EDEDEDECE9E6E8
E7E7EBE3E2DFE5E0E0E4E6E9E8E2E7E7E7E3E3E3E4E2DCDD
E2D3D8DDDDE0E2DAE2DEDBD6DAE3D8E2DEDADADEDDDDD7D5
DBDDDADAD7D8D9DBDFD9D1D8DDD1D5D9DBDCDDDBD7DCD9DD
DBDCD9D7DCDEDBDEDBD8D9D9D1DDDBE2D8DDD9D6D9DAD1D1
CDCAD3D1CFD5DAD9DDDBDFDAE2E4E4DFE6E2DDE3DFDCDDDE
DFE3E2EBE3DFDEE5E4E6E4EBE9E5E3EBEBE5EAE9EAE8EBEF
EEEDE8E8ECEBE9EAEEEDE8EEE9EBEAEAE9F1EFEDEDEDE3E5
EEEAE8E8F1F5F5EDF1EEEBEBEBEBEAE3E8E9ECE9E9E9EAEB
E8E8EDE5E2DBE6E2DFE0E6E9EADEDCE0DFE0DADADDDBD8DC
E2DCDEDCDBE4DFDBDDDADCD8E2DFDAE0DCD7D7DBDDE0DBD5
D9D9D8D8D8D7DCDAD8DED4D5D6CDCED3D4DADCE2D8D9D3DB
D7D9D5D9DEDEDFD8D5DBD9D9D5DDDADDD7D8D4D3D4CBC2C6
C4BDC2C7D3D3D5D8DBD7DBD5D8DDE5E3EAE0D9DDDEDCDFDB
DDD7DCE7E5DFE0E5E7E8E8E6E7E0E2ECEDE4EBEBEAE4E8E9
EAE5E6E4E6E9ECE7ECECF2EBE7E2EBF4EDF1F1F1ECEEE2E2
EDEFECE7EFF3F5EDEEEBE9E7E6E4E3E2E9EDE9EAEAE6E5E3
E9E7EAE2E5E5DFE6E0E2E9E7E5DED7E0DBDADBDEE4DEDDDE
E4DDE0E2DEE4DEDBD9D3D4D3D9DBD9DCDBD1D6D5D6D8D7D8
D0DBD6D7DBD6DADAD7DCDBD3D8D4D1CFCEDBD9DED7DBD5D8
DAD7D3DCDCDDD9DAD6D9DCDDD9DEDDDBD4D1CCCEC9BAACA9
ADA0AAADC5C5CFD1D4D4D5D5D6D3DCE3E0DDDCD6DEDBDDD7
D8DEDADCE6E3E2DFE7E6DEE3E8E0E2E8E3E3EBEEEBE7E9E9
EEE9E9E9E7E4EBE9ECE9F6ECEAEEECEDEBEEF1EDEFEFDDE6
EFEDE8E8F1EDF5E9EEEBE9ECE8EAE5E3E7EBE6E9E6E5E6E6
E2E3E7E2E7E6DEE4DEE0E6E9E2E4E2E4DBD8E3E2E2D9DFE0
E0DED9D8D5DED8D4D5D6D4D5D5D7D3D3D3CEC9D3D5D7D6D3
D0D7D6CEDBD9D7D7D4D9D6D0D4CED6D4D3D7D7DAD8DBD6D5
D3CDD4DDD9D8D9DBD8D9DAD6DBDBD9D0C6B2B1A9916D7D6F
77637E718E93ACC9BCBEC9CBD7D0DBDDD8D5D6C1D4CFD1D3
D9DDE0DDDFE0E6E0E2E5DFE7E7E3DEE6E2E4E6EFE4ECE6E7
EEE5EAE9E7EAECE8EBEBEEECEFF3F2ECEBEFF1ECEFEDE4E4
EFECE9ECEBEDEDEAE4E6E9ECE8EAE7E4E3E6E5E9E6E6E5E6
E0E4E5E4E5E6DEE4DAE4E5EAE5E4DFDEDBDAE6E2DCDDDDE0
DDDFD9D4CCCDBFA397D7D0CFCCC9B2B5C4C9D0D3D1D5CFBE
CDD8D5CFD6D5D8D3CDD4D5D1CDD1D6D7D5D7D1D3D6D8D4DB
D7D6DBD8DBD7D0D7D5DDDCD5D9D5CCBCA283938F86666264
6B766D50515976897B6AA4C4CCC7D1D6D6B7CE979BBCC0BD
D5D9E3DFDFDFE7DDDFE4DEDEE3DEE4E8E3E4E5EAE5E4E3E7
EAE4E6E4E2E4E8E7E7EDEFEDEFF1F2EBEAF3F1EEEFECE4E6
E8ECEBEDE8ECE9EAE8E5E9EBE9E9E8E5E3E6E6E8E8E7E5E6
E2E3E5E8E6E5E4E3DBE0E4E7E2E3DEDBDCE0E3E3DDDADADC
DDD4BCADC7C1894D64D4CCC2A3A7708EC4C5C6C9C0BEB0BB
C7D6D1D0D6CCD0C4C6CFD1D3CCCBD9D8D7D9D3D3D3DAD3D8
D9D6D8D6D9D1CAD3CDD9D4D4D6CFB7A69892A99B98A1979C
A2A8726C66627A72726C6E8FA0BCC8C5C9C7CEB67E738281
B1CDD4DED8DFDFDAD6E3E0DFE6DFE2E9E4E5E4E6DFE8E7E6
E3E5E5E0D5E6E4E6E5EAECEDE4EEEFECE8EDEFF5F1EDDEE8
EBEDEDE5ECECEAE8E6EAE6EAE6E7EADFE3E6E5E8ECE5DFE4
DBDEE9E4E7E6E3E4E0E0E4E7E4DFDDE0DEE2E4DCD8C5CAD5
DAD8C2A1B3925F518FCDC29861645F7ABBC2B99C797F8BB3
CACBCABAC0C1B1B9BFCECFD0D5CAD1D4D6D7D3D1CAD4D7D6
D3D4D0D5D7CEC5C1A8B7D3BDCBCEBEBABFB8B6B19BA6AFA7
9AA1989AA7A7A08E88656A748C7C8D7BB7D3CEBEB2627D8A
8482A9C5CDD8D7D5D9DCE4E6E4E4E2E4E2E0E2E8E4E7E5E9
E9E5E7E6E2EAEBE7EAE7EAEAE7E7F1EBE6EDEFEEEEEEDFE5
EFEAEDE8ECE8EAEBE4E6E6ECE6E3EAE2E3E6E3EBEAE6E2E5
DFE0E9E3E3E6E5DEE3DFE2DFDFE2D9E2DEDEE0DACE928FC9
D0D8CFBD986E6091B0C5BB805B45495EABC6A8565871A4BE
C7C2B793AAB5BDC0C8CAC9C6CDCBC6D7D6D6D1D1C6CEC9CA
BEBEC7C8C9B3AAB6A1B7CDCCC6BFB6A2AEA08C8A6C688C5C
455C4D477E98AFA7ABA2949271716B8897A4BEC4CBBCC0BF
B17365759CCCD0D0D8DCDBDBE0E3E2E4DEDFE4EBDFE8E6E4
E8E4E3DEDFE5E3E7E5E8E9EBEAE6EBE4E4EFECE9EBECDFEA
ECE6EFEAECEAEAE7E8EAE8ECECE7ECE3E0E4E4EBE7E9E7E8
E0E0E6E2DFE5E4E3E2DFDCD8D6DBD4D7D7D8D7D1AD708ACE
C7D4C48F76756AA6C7C1A08A86636E83ADB8916D8282A9AA
8D8B8693ABB6B1989AC0C1BEC4B7BACFCECECBC6B7B5A881
6290BBB1B7B2B3B1BBB2BEBB9C7F7A70887A754D47626242
4948483A3F4F7B648D9FA6A1898C65716E6A7E91BCC1CCCF
CBBC906D7588A4B7CADBD5D9D8E0DCE7DDE3E4E9E4E6E8E6
E7E6E5E6E5EAE5E6E6E8E9EAE6E9E9E0E7E8E8E3DFE3E6EA
E5E8ECE8ECEBEEE7EAE8E5ECECE8ECE4DFE5DFE5E7E6E5E5
E2DDD9DDDEE0E3E5DBDCD8D7CDCDC1BBCED1CBBD936D90D0
D8CEA671636B5783CCB6A66E707A6F7FADA791897E82948B
666E7E8A9FAF7C68718398899BBBC6C4BAA69A9557525F62
73A9B0AC89746D749E918A7D565E6A6B7977745F5F7F6162
5B47554D49524F3F4D5F6B869CB39A81777063658373A1BF
C4C4B1A09C9479709CB0D3D8D5E2DBE8DCDBE6E9E8E7EAE0
E9E4E7E9E4E8E5E2E7E5E9E9E6E5E6E6E9EDEBEAE7EAE6E9
EBE9E9E7EDEAEFE8E9EAE5E8E7EAEDE4E6E6E0E3E0E0E3E3
E2DEDCE0E6E0E0DED7D4CBDDCFAE80A8BECBBB8B6C6592C7
D0BE8B6C626883B3C2989876756D6F607679917C707A757A
6E86938D947C55665E675875A3B1B0A2885E596255587292
8F7E7D5F445063738576717B6E66797B7D7C7E8C7E8D6F68
5651516176564D454E5C615D5F88ACB1A79B7D676A596A6B
75B1AEBBBCAA91715760C8D6D5D8DBE5DCD8DCE8DBE6E5E4
E6E0E6E3DFE3DFDFE7E5E5E3E6E7E9E8E8EAE9EAEAE8E4EC
E5E3E7E6EEEBEEE9E7ECE8E8E9E6EBE9E5E3D9E0DCDEE6E5
E5DEDEDFE6E0DFE0D6D6C4D0CE978695ADC6AB77636D85B3
C5AF817D616D7EB1B38E7C666D726F8094868A7B727B635F
6883948D88755E6F6167678E8876625D56665063737F9B77
483B404A55616C778B7E959D9283808A838E939EA293918D
8C7D889181625B65645C63604E5C6F8D9CB0AF85747C7966
727C658BBFC5BBA6746088BAC8D0D6E3D8D4D3D9DBDFE2E8
E6E5EAE4E4E0E3E6E8E9E9E6E7EAE7EBE5E8E8E9E9E8E3E2
E7E6E9E7ECE8EBE4E6ECE8E6E5E8E7E0E8E3DEDFDFE9DEE8
E3E0E2E2E0DEDCDDCCBDC2D5CB9E8BA0C7C6A78F726684B8
C19D856B606E8EBE9C847060514D5D838F806D665B5E4D4D
5670848B706B66636C62756E6D59605E57585F7D916E5D46
4253616565766765766B719A8F7B6E736D819BA99C8C9B9C
889B9EA68F8E85858B85775D534C5858658D92B1B2A8A367
66615E457CBEBFC2B09162867FBECCD8D1B2B1D8CED1D9E0
E8E5E9E4E2E5E2E4E7E5E7E4E3E9E9ECE7E5E3DFEAEBE4E3
E9EDEBE4EFEDE7E6E4EBE4E9E4E5E7E2E2E5DEE5DDE7DCEA
E2DFE5DBE0DEDED5A195BCD8CA9A83A7C5C2988B6D6D80BF
BC8C665C557DAFA9866D5B4C4D5877957E6A584943584C73
6F6F74656464635D8197797D7A64565E60756C5B5B4D5051
5E6D73706556545E5B65727E735767625B5673808E827259
46596C8373768C90A0A09D7E605249424A514482A4ABB393
846F68503E6E92B7B5BE81644A80C5D6CE954EA8C8D7D6DE
E4E6E6E5E0E2E2E7E5E4E3E5E2EBEBE7E9EBE5DEE3E5E3E6
ECECE9EAECE9EAE2E4EBDCE7E0E4E8E7E5E4DCE0DFE5E2E7
E0DFDCDBDFD9DFC87781BCD9BF927B7A88B3895E5167A8C7
B2866A645567B09A866A615F4E769486686C6053465E5F83
827E6757576567647488807A755B535C5F65665552656C6D
7D7A6E4F48465B5357666F70605E625F585C52546F625652
5E6A7C61516D596F8685ADA98D7B614957554F55556392A6
B8A8855D4E41457FA8C9B372545585BECBAC565BC1D1CBD5
DFE0E3E2DEDEE0E8E2E0DFE6DEE9EBECE5EAE5E0E3E4DEE4
ECECE9E6EBE6E7E6E6E5DCDFE9E5E7E0E0E8E6DCD9DDE0E4
E3DEDDD5D7DCD7B66289D1CEA18B858EB1A98F584F7CACBF
9F888164778A9A958A75555B72838E8166665451536A7A7B
756A4D54646F65777B6C6B6852505D5D585C5D5D70818266
684E43414C505757676667504952544D4A3B4F4379778577
6F7F6D615063546656576275839D847471715C5B424D5F63
A2C0B698663F43414FA9C7B28B444E68C8BC9F98A7D1D4D7
E6E2E5E6E3E0E4E5E7E0E8E5E3EFECEEE6EEE3EAE3E8DFE6
EBEDE9E6E9EAEBE7E7E6E2DFE7E4E3DCDDE4E2DFDEE4DBE2
DED9D4AAC8D8D4AB74B6D4C186756F8BAF9080716F9DB9AC
90776B5F6E95837A6C5D5E5D7A89847B7B5C585F6D6C6B73
626147577676707367686B6E5D6161594C4D6E80816A625D
5B5C5262645B4E544740463F5456554344365470897F999E
8C806E6859545B5053494C474A5F727B989D70544E51473B
537AA6B88C726A4A597CB0BAB68B5756B9BCC0A87099CAD1
DCDDE0E0DFDDE2E0E3E8EDE9E3F1EDE6E4EDE9E9E6EAE3EC
E8E9E3E0EBEBEEE4E4E4E5E9E4E5E0DCDCDFDADEE0E0E0DB
D3CFC288C4CECF9D83A2C0AC7582858E9B7572565F8BAE92
6A585D5D888F77655042585792895D5F474548585F544D60
5D5365778E7D6F76767F71776C5F63536C6E757062464C44
464D57685E4A3D4346475D5D746F655D4D5566807E8198B1
A2999090867D6C5F54544E4D50615F506E9788796557504F
42495583AFC0AA60505E6CB8C5B07A4C6891C2BE845FABCE
D7DFE2DCDFD9E5E0E5E8EBE6E2E7EAE9E5EAE7EDEFEEE0E8
E8E5E6E5E8E7E9E3E6E3DFE9E5E5E0DDE2E2E3E2DFDBDBD8
D0C99DA4B8D0CD9B7D9AB3A47A848AA798856B6C7C83A06D
555055779C8D6F5F47446C808B704A3A3B3A3E56514F3944
5064868B85746671717F6E6C585B5C6775716659453A3E4C
454C586044413F51646368796C6572515F646382806D5885
7180857998A192827B73706871605B4854655D80917F6B63
5246446888A6AD946E535D85A9BCAA744960A2C29B4D80BA
D1D6DDDFE0DDE0DDE6E5E5DDE4ECEDE8E5ECE8ECEBE9E2E8
EAE6E5E3E8E8EAE5E0E4DEE5DFE0DFDAE0E3E2E3E0D9D8C8
D1C79993AECAB283758FABA2837E7CA9907E686DA2AB955E
565484A1867671564955768C735C5F44333B4D494D4D4046
54707D6481736D77737D5D5D67646768675B51444244544D
544A4D42484D495951434A5D56505950625B64616E46445D
6160515160734D5E6C6B8A8F988A655B45564E5070778684
6E5C44575465719BAF9C6C5565A4BBB1744572B8B077497B
D3D9D7DEE2E4E0E4E6E7E9E5E2EEEAE0E5EBEAE9E8E8E0E7
E8EBE5E7EEEBE8E0E3DFDDE8E6E9E2D8E3DEDDDEDDD4C0AC
D4BA7C83A1CABD74728891957C7189A77574687EAD93805D
60617A8A7C606F67647D8C77634D3D374144474945413D34
4557715B6C73808281715F68728167624846484A5C656D4F
4643414A575C4246474C4C495565686A70746B6860595460
5D4F524F4E4D424A5140486883A3887151584C524F453E6D
A2865D443B453F54A9C695474D6591BB9D4A517EAFA7655D
A1D4DFDCDADBE0E3E7E8E4E3E0E7E7E3E3E8EDE4E9EAE2E4
E8E9EAEDEAECE7E2DFE0E0E4DFDED7DADDDEDBDEDAC6B9A9
C9B67C939BC9BD8B9B93988A715F999B7A7D7C93987A6756
5F7D81706B675973888D624C454D4549645C46443D394548
4750594A5C77726F62635B6772744F4448484C626B7B6144
3A464948474041444C494E645E7576828880818A737C7C6A
7160575958515C5053514955545F809A8F7B6268524D424C
71958B594142405D83B9B17A4D4E4593B96C4460A6BB9A57
7BBCDCDADBDCDCE0E6E9E4E5E3E6EAE7E4E9EAE5E7EBE6E3
E8EAEAE9E9E9DFE0DCE0E8EBE8E5DFDAD9D7D1D8CFC191A0
CDB37B7C74C6AE818190A9846760748F73797C796C70685D
80976F7355615E80847D524753475D7B655E423344586745
35404949627A6E6A657570735741464542556A7E7D514533
41424E424D5B3B464F656D7B84997E85817B816F5557866A
6465748A9066746D6254464A413D506693849197684E5152
435C989F775F41463B76A9AA7B51548BC0AB656074AFAB67
759EC8DADCDCDCDFE2E0DAE5E5EAE7E7E6EAEBEAEDEEE5E3
E8E6EBE4E2E8E2E0E0E4E5EAE5E3E0DBD1C7BBC4CCB58B92
C6BD918880B99D626783C1886A646A7351597A6A7E7E5C66
94A88C6C636171866E796243586F8D6F5646374666514342
323D47606B654F687371734E4C46495E5E6160665044413B
46414F505759465D6376777784884D614F4C494D544A5650
494A5D7E6B6459596467544F4A574652544A6C9D986E5D4C
4F5D5583A2985B50466074ABAB635374A3B8924C557AB88B
5680A8D3DBD9DAE2DEE6E8E5DDEAE5E8E6EAE9EBECEEE8E8
E9E6ECE6E5E4E5DEE4E0E3E4DCDBD8D7C6A7A7A7C8AC8F8D
B7BC7D7C8FB0A77D7F8CCEAC90857968645C9A8E736D596C
B79873506789929476606647689D755C5D4146545C4A3F39
3F435665585160766B6C704753585D6E7261454353423844
505B576B5E60636A5655544C525B4F4E4D4D3E4147494E52
574C50584F4A394345576E795E4C3F4A5358556E949B7F6C
5952474A649DA67C64595762A9A2564E65A7B5604A6BA7A7
6F5480B7D8D6CDD0E2E7DFE5DAE9EDECE7F1EDE9EFEFE5E4
E9E4EAE6E4E6E7E3E3E0E3E6DFDEDCD8B3889797BD986F73
A8BB978893C4A06C7C94CFC1AF7F63626C889275576A73AB
BB89685C7495A6896C564D5D74816E503A36524F51424149
5F52595044457C72594E515268676C6D614A404A43414959
6C756B72756D665148484C4A5D5E64565C5C614E5452474C
646F5D5F5852444041444A616564575C5C5D5549495B6F9B
7F584D4648609DAA95653D3E6DA172504D9AC49D4C6192BF
AB5F538BCBD7C790E0E4E6E6DEE9EDEEE8EEECEBE8F1E4E7
EAE4E8E4E7E9E5E0DEDEE2E5DDD7D9CE9B8384A2AA896E62
A4A78A808FBE926B769EC5BF82705F5C54758D5C575E71B7
A9886C70759C9164616065806F685C49383E4F4C473E4A68
5249544C3F537B62594D5C6A837D6C5C4A45373E414E6477
7A776462525F54455B656657707C827B7B7B736E73664F60
717F76756A5F494046494641506B827C71555D4C4A4A3E72
9D8D6C63524E5181AC8F474E5C6DA27E5171B7B85D5181B1
BC81508BC4D7C681C8D8E6E6E2E0E7E8E9F2E5EBECEDE8E7
E5E4E6E3E0E3E3E4DCDCE0E7DCD9D4C6938890A3B2896D6C
ABB2866F7BAB73666E93BAB87E6566817E9A86585D61859F
91656F6B65867D675F6D9077575E4C524D4F533937406556
4E5340464C55504A45526C6B64676E4742403B4C6764717D
615B504044444760677B816A7265666F726F6C4D47433040
46566577706A6553594A52495E4D647A899065644A53544D
61919867474741559AAC805359547DB15E5268B5854E6594
C68944548ECEC8919DD1DFE3E6E9E3E4E4E9E8E8E9ECE7E5
E8E9E9E8E2DFE5DFE4E0E3E4D3D3D1BB8D9293A68A6C6E86
B0B68B66819D7B6774BBC2A4665B6086B5906F6F6B7BA0A2
8160636A8D856E6E5D7586655360586D5B464041455B6256
5D61464C4E4C3D3B4C64735F4C555548384141657E5B5455
4C4742353E415E746C628275554C58465B4C584742453E4D
514E49474E46636D6E6455476A51524E6382917454595949
4A5E8AA060545C465189AF64423B4FB79C495479B0635183
B9A651447CC0CBA672CBD4DADCEAE7E6E5E0EAE9E3E8E7E4
E6E7E8E9E6DDE4E3E0DEE3DFD3CED5B87B929185A3806C7E
99AF80818C94766F9EC0A97C615C76B0BE9E73666F84A880
624C5E709F75705E53757A6444636E5754484051604F4948
595B4D4E4A3F4451757C6C4E463E4044363B506C66554844
434A3D4153526156545070484241464F645D5C616A645649
413F4F3A484141434C58665C61554C58534171AC8C6E6A51
4345589E9A624A464362AEA86A45597DB3794159BBA75552
74C2754273ACD1C7A2B3CFD7E0EAECE4E8E7EDECEDF1E2E5
E7E9E7E7E8DEDFE0DFE2DECABEC9CEB565747698A7807B8D
7E9798668179627790C2B0846F7F98B8B67D605D6A86A76D
5664809F8D71644A51815F6D617B6B485D49646E5E473952
56674F3F3F435D6E8D72474645373B3F3B3D515546463A41
5B5F606360505C5146454C43455953657268637573727A66
524752455643414C463F3B4765716C53563F3E6B9DAA8663
46443D58799B6C50424263A29A4548519CA6414680AE773F
74BF903B6699CAC8AA6CA3DEE5E7EAE6E4E9ECECECF3E0E7
EFE3EEEAE2E7E6DFDEDCD6C5B6CECFB1596A6A92A680808B
A6AB89575F656D7C9CC2A27A746EB3BD8E6B726F86AB9577
6A62809E746B544D617464706A8C7555414D6F7060393B4D
5C5B4840496274706351463D473D3D38383941434545405E
6E5F5D544F4F5051464248535D75939E977E827E6E4E557E
8D6D706F6B5E506658483B3B4873737956463F3F579BA38D
5D5948473F83B27D473E4465AE72334464A0653F529A8F3A
60ABB24D537497C9B2539ED6E2E3E4E9E9EEECE9EFF2E5E9
ECE8EAE9E6E5E7DFDFDCD3BEBDCAC7AB737B7384A0948076
BABE8660747797A3BCB76F746C58A69D67606566A4A7766F
657AA38270726D6F5D545E6D826A50475270625F49455162
5F524042637C755C4A4A4A4C534A3A3A3835383F44545781
84564A4A504A474C5D5F6E73737176705F474C57533D4461
81607A8579685F7370573F354443567C655E4E4341597792
8F7453473958B59A6D464152A1943A3949728F394771A94F
4285C5794C7B80AFC04E7BC8DEE0D9E4E8F5ECEAEBF1E5E8
E9E6E6E6EAE3E4DCDFD6C4ACA9BCBCA37F7B73A7AB937588
BFC89266798097B7B79D6E76748BAD99584E6C95B19B5D4F
5C98A6766B6C7E705D617079755D4F495D65484D41446D6C
664D465F8F655247454F5C6058423A4434373D3F5D737E74
6355524D525F6C6F8C857A604452555F52494D514757504F
4F474748443F475B798060564A3A4A5766716D58494A4E51
868F4C394242678AAB813E496DB0734A49539C554A63A35B
466BC8A7405F8BB1C49068B2D9E5DDE6E8F1E9E9E4EDE6E9
ECE8E6E4E9E3E2DAD7D3AA93B5B2A197757E93AEA8857783
A0C47C63577592BAB28F65648FB2B18C5664648EAE7B6164
598D85615F7D7965605E57636A5957526F5556515E796B66
60536271714F3B3A475656795E4C404A343B3F5271726D57
433F5374658491826B5B4F504349545F535D6862645B514F
5545424D5C3B36494559617B674049624E437D775D484C54
597C64475D636A9CBDAD61574A97AD624A508A8B5C47734F
517DAEA9486481A8CDAE4E80C9DFDCE8E4EDE9EBE6E8E5EA
EEEBE9EAEBE5E0D9D8C7818EA4B0A9807F73818F725B657C
BEBD85726095B7C7AD7B54737BA4AF796471606FA8817761
737B5D4A63917A5D615D58605E526D6A644F4E4983774D64
5362765E57503E424E3F4148514138384460526F88554333
2F315F7E7B8C6E6446433A424456686C859C958C83818081
7A6A605E5851444C4142427A9760434C4C4342848D7B5450
464C7D797077656C9BC188496070B09C4A545FB0604D5B6B
605B8DBB75667DA3C7B64D61A2DBD9E7E6ECF3E9E6E9E5E4
E7ECE8E9E7DED8D5D3B67D8293B6A27B72828B85615B5E7E
A3B18A6C6D99C9AC8D766B6F93A6A2777C8991AFA372524F
7363525474A786746471706357646D665249476563584861
6375554D3540404246353B3F3D4438414C687C60513E3439
36436B847665524D434255515F849291888EA4938E827C6E
72838C8967585143454E495B607E7C7C503E3E5384A18247
5D504F747C57544C6F9BAF7650639CB87A484D9E804D5683
404D6DBBB1657094BFC471677EE2E7E9ECF1EEECE9E8E6E8
E8E6EAE5E2D5D7D0C8B36E8595B9A1718090BB9C68615851
5466856A8FB3C19D64577486A6B38F606783B2BFA2635546
7B6D716B97AD8E7C7D88745C586B63524139425C4547598A
7458413136554A463B3744473742464C7086593B40434145
536A766E4C564A4C4A5F7D8684898A7E5958585054504A40
4255607D797C67675B4844443F57808A744C504F55669F7D
524A4F4A477A6F485B648EAC54576B9D974956768F5C7BAF
616E89ADB591728FAAC2A1769ED4E3E4EAEFEEE5E9EBE8EA
EAE9E6E0DDB5C7C9CCC07C8E89AC86858E93AD9B59616C8A
4A515F7A92AEC0AF856E7786A69E6D5F57819AB5976B564E
5D5F6A8D9C7E7F708B9A725B6A6F5E423646484F3E34627D
44393B35404F3940353D4D42484854756851414340554F66
655E5D4A3D596A65819AA188595B5861555C554755526144
455C4F575350528485594D4A453D42598A805E40484A6598
764E423D3B4F9D5B3D4C4D99A05B537FA06B53677E61ABBF
81596BA67A868D6A8EB3BD738FB7E3E0DBECEBE8EEEAE6EB
E9E0E4DFCD9FB7BFCCC48E8073846C778A9EA39B816881AD
8B474D687D91C0AB918392B2BD98775E4C647D987D59755E
4C4E57938D6C67617A9767676160525444514C4E49497150
3A4141404F3F3B373F48414747587554453840404A707253
46404D6162779489857A5F504440474E564C4A5468707261
4D48373F4240515563647F684D433F3F4382623F413E3D61
9B5544463F3A739748475882B99046476EA75355635CB0C1
8B5563A36486AB65806DCEC49A83E4E0DAEEEAE7EDECE8ED
E0E4E7D8C5ABACC1D3BF8B8483AA704D719392867C657BB2
86675F72B0B1A9A1776885B2B8866C756671908B6F6D8364
605C5E917D566B56737F8273616C705B5751534A545B6141
39464C494F333E3D434F53485F9182523E4038507083544F
44516C76808981655B57464D47414F57546B6F6589949F7F
5573526364505446464A6B8A906F4C4D4754626D493A3A4D
7F914F6654435BA28B415D65A8A647405FB07758615884C6
7465809E7072959F6564C1BB689AB1D5DBDFE7E9E9ECE6EB
E5E6DCCFB8939CC0CAB2858299A97C5E5C668C88828C90B2
8472678FB89E7575645F9CC8B9947675777583815B74816C
6A607398626E5F5D9F868B635D8F6E5650484F4C6159493D
396166493A3F4049514A5251778356425041557467534160
64919A8D927D534A4753545B6A76778F8C8E735D607C7054
6B7E858B8E7568454541404F628C7250503F456D8D4C3735
397FA89951464985A95951606FA75B3D6FAA9E515D6D74BB
764A84997C6691AB629FC7B8628694B2E0E0DDE9EAE8DFE5
E3DDD5C598AC9DC5C5A69E8B90A38281775565827E8691B5
7B637E7D8984606D64678DBEA7828C79937D727063868B6E
70928C8B6E686C7F777577636E977F5142474A6364594D48
4C765D463F5E68403F3E566D7445404658527F6F4A433F45
7DAC9D97895E444342647B7E94A3988E7E5C494749494440
474C574D888E9A7C4A403E4653649F7D57424E4A988F483E
4966B2AC5C474E519C8252645799A03D5C679F706D6C5994
9C49688AA471A9AF8CAAB8CC7F6690ACD7E4E2E2E4E8E0E6
E2E3D6BA8D9193ACBB9C8571688F778FA077485C6883BCA2
6854777A72615C8582777EAF8E62646A7F747B75779A8873
5C7CA3776F627B9C67596A63609175495352594C4545546D
7F63423F4577503B384776794E3A404C617A7C524349425D
999A8B7C59545352897A66959266645F5856574F41494240
3B3B43394950658C8E64534F48669F9E955B383858A09C52
476191AB89424C5075B35D48536CA7744E4E829E617F5858
98496377AB947C95B698AEC9AF7688B1C9DEE0DAE2E9DADF
DDE0D3A2777F9BB8AA8C79677B7D88848F886E687BAEB286
8F6D6F90794D77737E7F9AB37F546B677F7D886C70887E75
677F7366556B92914E524F586382534044445B4D47405B85
62443A384C4D4642536C7C443750475F8272594147646471
648084777F746C75977F6B6A57574F636C6470716F816350
493B3B333E403A4E71959E8857475F5D9499733E4367B697
5D585D74A85D394D60A67455596CA98B5D657BBDAF986752
9D667E7A94A65C8DB5A395A4C7929C8BBCEAE8E3E0EBDBE2
E2D9CC86819AA2B1BDA27C64887F8376748E817D8DB39768
80856CAAAB8A8574837A92BE9C666B9288768064746F7674
9A8C616B5F84946758556A6B79574E4752715E4444456373
452F3246443F3A4482945C313761687C645249556B8F6755
5258728BA1A18E7366574042495D7C9B9F8F9A9CA1A49B8C
817565363F4D434E556684A39354524157769161404DA2B7
68495461899E50454F76B276677E9CAA676A82B1BF9F6C73
ACA48D71669C767CAEA96C7CC1B09C92B3ECE9E6DCE0E0E6
DFDBC49992BB9EB9C094798C9992959D84727B7AAEBC7D71
798477B0BAB088795B6495C4AC8F798D88716675766A6581
A98B8C6B729990565E5373885C4442577574593948615E54
4333404F383A3F4A9774332C365F7C7239333A65807F5046
3E4585A6A7A184685648464646639B947D77796A6C685861
6486774C476457564E585980939C57353B64908B4A4A85B8
8F67736165A8603B527EAA944E4F75B38A598E7DBE9E7B67
82BA8470889A737C9191545CAFCCA493BDE5E5E6E6E9E4E4
DBD7AE90919EA7BDAD8F757B9EADAE8F79677A7E9B8C6667
796D799AAE8F7573665497C19D9D896E5752558173585B73
A2927A5C639B68565343778C553E33547F5241363F6D4C44
414343513F485163795234313D4A543B2F2B357C6E5D464D
4C5D72AAA0736D6356637D70625F7B76544E415C4437384D
53566475576B5E553F414E5360889C473E5862A17B59598D
AA834C68607DAD703F607CB7846667A0A4606A6A99A85C6A
5CB9A68079799C7B82A9595184D4B88694DCE3E8E6ECE7E7
DDD3AF7E8EA0BBB38FA07C949FB8A9918A7C839DB2977B6F
7082957D8B8D777D889AB5AA7B9885774D567680714C5097
947659717E826459626E8D6644453A556E483F3B54753D37
39504F404A627C804D3F3744524A433F3A2E3B7146595551
7273819E9C5C84728398836E443D4453464A3A423B3B3847
3D426255546A754941615748425193894C374C7AAA7D4949
75A2465C6860AFA155565CB3B1686198AC6268515EA64D70
74C0BA757162AD6E7595727475CAC58884C8E0E0E2EDDFE2
D4C6B38EA2B7A4A798A2898198BAAD8D7B7A7DA1BF958C8A
678CB7A48D777F759399907F56929D824F629C915F557EA2
7D5E436E8F626458658E8C5B4C5F4F4C62553E4F77624539
4F5D4C494D688267473843475F623A3A40534C553E60836B
8D7F518871A2AA9DA288675445454660758475928C827C73
5147474A4F5C634F4C5F5C5840415D7F74415360889E4E56
8EA4664559506EB075536298BB655272AE625E504EA96E79
8595BF8D7A8BBC886C7F837D6DABCA9475AEDDDDE6E5E3E4
A9B1BB97BBAC7D8B84827D839FC59076629CAEA8AE797673
8BA8B7896F7179798B7F675D627CA4A17C7286916B6AA492
6F646182614D57677A9A654A557A7455534853836D595053
595944494D845F4F4D4F52364E4E3334455B40333B6E9361
5661385798A8AA9B835C485037467A8D939C7D93A299A4B2
9E89624F58544545434A405357653E4486815253758F884D
6A91A674444865AB9B4C667EAE634A569C7C595E62959468
767FBA8E6B80AA9D818BB27B66A3CAAD7C83CDD1E4E3DEEC
D3CEC6C09D82656B7E7A8290ADB07A7A7093AFBBA472687A
8EB2B26E73675485736C6B7F6D6A8DA488556C81809BA270
5F7D857150375170A7945C40578F75574847817B4C3B456B
58443B536B66474856766F3F4848363E48563D323F4D886A
4F5B3D4AA3978472513F44734E6A8B74686B575F5D51709E
A69A8A795D3F303A4A5137323E7E583F5480835E5570A950
5E73AEA7424C6591AF516A7BA18B41557DAA716E678F9D60
7B738FB26F646189AC95C1847E91D4BB7C98A9D6E4E8DAE7
E0D7CCC184656C715E707E9DB8B07E8180A0BCB88D7C6F74
9CC8B28E7D5D659179818D946B74A294615F5F585DA88E59
6075907147347599A2764A455D844D403F59805F424E4855
584941736D443F496C824344494E514F3E47413F706E5D57
515E62719A64544F3F3666976C627C4C5548363D3A3F4568
62605B919365353437473E3A3B5074363B469C753E4EA06D
456EAEB1573B5264A2685C688CA7525C68B89E7F82A1AE83
817961A7746F5861C5C0AB6D8A68D0CD83718BDEE2EAE3E3
E8DDD6B27D7C7F8C7E7490A6B89992848E9CBFAB74717F86
B9C0A2997F8EAD8E76708D8268A1A07A574E4F3976A06570
46619A6B494290A67C5E584A6B5E4242468062473D486044
5B404966473E4A6488603D3B597B703F4041496680543D5D
636E796B5C483B4860627D915F4C4C3A40392C3B30394135
3B4C4C6291A985452C2F4C5C4E416046354179953F427D9D
495C84A47E343F6388B0646B6CA94E6F79A994597388BD99
5E635794B5865B61A9D6A2636C6DAFC77F5393DADCE9DDE0
EDE2D39B6870768F7C7489BDB8858B808ABEBEA8707E928E
BFB8977398AC9B80667E706093A4A16D615253509E8D6764
53827F605D38827E576C646E7B604839607442443F755E3F
423A514E474A5E796045413977944E433945726F6045354A
7A7C564F4E5C507383675060594E4A575859456668737C5C
444F4D445677929B54353A537F6B525C423F5B94623F5E93
683B6C7A9C4A575765BB89635E94556A6E998D4D6F6EA0A7
5B675EBCC48E71648DD6AE6A75779FC6B17983E2DEEFE2E0
E8E5CFA47E869B7E6B607FBFA1797E8691C7C4B1AB76638E
A791757A92AB8D746E7F634A80AE8F6D5B494F77A3778370
8597705548415962596A757C5948464D976B42484C685040
4D594D4F59556F6F47565051886E39403D52674C4A3B3552
7463564A537A754D534751544354746E7A795879777095A2
908055463E364E859E743A50677E66535B49667794494871
883E55669186535557AC95505C7C91566F77A251606C72B7
8B7B70BFC798657194C8B99F8D756BBFCCAB8BBEDAF1E2E3
E7E3DAB68D9A9F6E71636EBD9D7E688E90B8C1A89A7D528B
8E736A6C9E977E767C89744D71B09E735D51509B8B5C6463
7C8E606753766E495D6B8A7145434F72825142535E514342
606F50494F736B5049546D8C7F3D3D515D725449574D5064
474C50447C98623E3F3645405E666254554F525951515184
9AAA9467432E314888A76C515664746B6577516498804261
8E6F4D6868AB545568A39B485C88B2526764AC8B736C79BE
B27A7E8ABB956E7167B6CFC49754619ED4AF6CA3D9E9E2E2
E5E2DDC7B7B2987C80839BC08D65627273B8B18D7F8D8698
8D686F85B0846A579C7F837073AD947E4C517775644F4475
A2715E5E63A3795854808E5B463D5F8F5D4546707C504452
9155413D5980594C47638E9152493E405E6746515E6C6E49
41586E75895E50373E4350605F4D41463F3B4243453F3851
558097957C433439508E9D6433406C767095534770885357
80884D5E629E7054625FA04A5B72B081707491B66D6165B1
9B6F7A638AA06F55609BD0C1A66C91ACCFBC728CD9E6DDE8
E3DECDA6C1B8867B77ABBCB8865E66708FB8A2949199AE98
865C5D918379555B948E816A8AB289947A7A924F5F4D4D91
AC705E67819756544C679B5B45407570544F64916D4D4271
8E544440626053485E6A8165564E46535F5D41478C8D5336
46517B8F636253465B6D58424838363F53607E6150504439
3B47556DA0894932405B959844394E7C89AE61436C746B56
7692596167869D55595B9E6F5565AEAA5763A1B8585670A3
A4776F806EB07B55629BC6C19574677DB3C29285D7E5E0DF
E2D1BCA692A2A87679A1BBAF8374767A9AA4957683AAA876
827788806D60838182887586B6A48B858AA189676A476AA3
86586E5B907F59443E818E594F65855559657985454E4D70
4F444A3750544446647F724D49535E624E4043648A74453D
44638E717362746D515F564148524872939CA2A899867155
3D313541709D9552363962889A6E4D738DBB8A37607E8B57
6690995D6773A457576284986D7F94BA927693B68A8F718A
B370816668AF7E5B5B64BFBF7762534671BB7580C7E6E0E4
DFD19F8F8FA4A6977998B8998C7EA790AE7C66809FBF9A85
887D9D84665C9B776D7A83BEB0887E72A2A479656263A694
5943738A93646449397D5B585882715453718D6B49666C66
473344405342444C758D5146554E685F495B448291484A45
608D6765658691664746596E897D8B848BA09F9E9A8FA3A2
8A4F2E324763A4955B384371A3B374496DA4AB6C3D738F6B
527AA7626C6898754C5B5DA16E7581B7A26583BF94745580
C59983605D979F59614E9DCA97705B524FBE7F71B3E6E5E8
E2C09D82B1A48D9DAAAAB57A828BA3B095706F71A4AC8281
88A2797A73839F7E6470A6B79A797084AE9E68444D84AF7A
52488EA77F5F6F4E494C504E6A8A6651539A725B588D984F
4D3E534E3F46434F744D403E486B744539484A6D59414350
7D77526B8995686349468B9F8C7C75745D4A5481736F8D9E
9F9D633D414586A68948335577B39F466586B19A4253638E
56588A5E535C769854715398677F8198AB6C80B2A17A637F
C6BE835F5191B774797BA4CCAE8566606EC0A47D9EDBE4ED
D9BA9FA8BF8B8192A2BC9D7B6E98A6A47A83807F85977791
90A96A66809B857C63589E8F586B7C8CAB8D5F536D9C895F
644F7FA065756A7368484955896658515F8F5C48577B8D42
465577583D473E4660353A416C86583A395076434E54495E
71555D648E8F6F575F77917C5349474435292B47403E464F
5E98A6795F4155729E7A3D496D8CAE6B4A79A1A94E50679E
684E7E75565254995D58619784757A7AB67479A9B5687050
8ECB90726077B88E7E6589CDC0AC9D715FB7C07EA6CFDBE4
D5B7BABBB8857C95B5AA897F8295ADA18D847583A4886F7B
9D92807F8A90847D63808E7651658499B37D525F84806E54
6E5D818F6E7C568B9865565F955F675B676E54445B776549
45706D42363F4A7D4D35434D86644241517F60383744586B
555F4C47766D7A7777816F593B5247423A3B3631312A2933
355E81A38845454980A66D4F7B77B59B4D6084AE6A457291
724D74A2635C5C8E7D536E837C4D6071B86C7A8BBC837763
77C991675C84C190736472C592B0AF6B6DB3C67A71B6DCDF
DDC0CFCEAE948DA2B18889818079B19F8A816D809E797061
988D8884A67E957F7DA68B8866709AA8927456707E63625D
6A8D8F7D635B4D9C836A7989816066636460484354804F46
59756E4E3E4D79865543426D854949427C814D38445E7F71
495B624D6D5F7E80525059494254716A7C7B776E554F3532
3331507BA37F5D3F628BA0764E6FA1AC614A7DA494455F8A
9C4D5B9279596A6A91627D8B8A667373A8737E79B9A26D6F
6BC09D715B86C6B2976B77AC6182BCAA829CCE9A49B8E0DD
DEDED9D6BD93949DA8887D8C9BA8B2957E7A7A9188706474
8A80718D9E6C8892A39D7084776095A67D6F7B8E64586E61
687C926148454F8D68518092846E58605558615055584445
6E93533F4664896D67396076765151566C4D43465C996753
464A58566B707152405350574C7C919190999C8B7B7C6154
412C3F60A0AB7A57616D99925D4A7AAA8A436188B28E456E
9F555C7EAE606267A47F7686B1827B7AAF907763B39B6673
7AC2B77C7185C6C98E747FB3676FABB17BB1D4C79392DADE
DFDDDAD5BC9895A67C7D97867FA6857680706D8E7A636795
7B7F7C929462898DB697746D85809F9C7370A1835C857D67
6E858F4A5E4E648D57527C90766458665E48606E6E413B3F
7E8B433953745C555235807F4F44667A5D41486894834944
47597576865E483F33474D7C7A9A7E746571727B7A7C72A2
91504D516DA6B076625877A98445649EA841417992A95E5D
7C5B5980AD796C6E9F756577B28B75649FB399749DA26466
51A9C5A064508BCD7A6A71B668828CB285C2CBD3B98FCFE5
E2DDD5D6B88F92A080677F83A08F847173718C7D74687693
767F80A274677B8CA2846C667093AA936F9A997260998663
629F71515C537F884C3F6683546E5D5260496180593E3E4E
8E684356768A46463F467E5648487374473D4C858A64404A
528C80706642473F425C6B895E65554840433F453F3D467B
9A917053557BB1AF704C61A2A248487CAF76417989B18E57
80894C709E8E716D97745E67AA9D91679AC19C797AA27173
5671C5A0705777C98C6F4A9F746C74B074C7BBDAC683CCDF
E3DED3B9A6AEB68D747085B2B08C6F73759DA37F775D7A80
737EA894806B729D95807A7D86A9808382A27F798F916E57
7AA1744C555BA36E603B4D4F618059535F5C857F46403F61
6653574F855E453A456F67403D447551493B4F7E4A413560
85826451504E576663766257574335323533322B2E2F3434
4D85A38A5C4F7FA192505F79AC63337AAA9C487C81B1994E
81AE927099A47474929A626B93C6997097C9975F74B79285
6850BFAE7D7D61C092685B95826E71B97ACCC6DECE80B7DC
E0DCCF8FA2BEC08F818A97C0A491776B749E91817E8D7B68
7CA0AC8F8E97A49D7A65848A9AA78089A48D728A946F6876
838F674C649D9B46504337566B726046687E83655648607E
4F435660543F384F849A654446714E3B3F4F7E803639447B
8C653F3B3E3E4A80626339373E3D38546C72706B4D47372B
2B5086AE7F49516BAB684870949D365E99AF3968809C9F5F
7C95916580AB6F857EAE646186C694768BC8999374B5997D
735BB3B9846B68BCAE71678A948F8EC68FCCC9D4CE7F70C7
E4E2D6B8BEC09A8D9C9B98B097867C7599A67E7B76926374
92A68D8E9790A1906A716B91BBA96486AC7D59759C68615B
8B7D55516EB18438595D4D5664614C37447F6D5D515C6E62
475070764C34496B9F804A4463813954395D904C4449649C
7C593D394259506D464230383E63779B8F8D7A908675735F
33406493A66A3A559F94405C7F9D554792A968457289A648
747C796B799E707B8CB6736771B98B739AC29FAE8EB29B6C
71669CC99C666391C08D7481BA9173C0ABBC9DC8D1887BD1
E4E0DCD4CEAA958692A8AC9361687E8AB9826D7C9A9B7D75
83AD7D647F91927B79807CB2B5A17290A76154808467623D
83514A656DAA663E58758F8455474D40496A525857806C49
4A646454403457738C5F42416C61364046736B3D38495C79
5B4D4446637F56664739344A488D8F8B8B604E554D526A84
6B3A42568F8E46538CAF48486A93883F86A4AF6E62898D50
7071A9747B74738485B5776F60B5A85C77C0937A4FB6AE6F
71688DBF8A636795C5998481BD8D76B7A28093B3D1948FD4
E2E4DEDCD5A69BAEAEB8A08C6C6A5E7EA87C657BA39E6F85
8A89726C7F899F8072737DB89A8D86999264528C6D554859
8F3B4F497A93423E5873A29C4A39586376543A4776A16443
4E4F554F37437B92724844486C443B40567E41383D424666
5D525F7C8860575B53464377738F84765F443A3D333B4555
744F46546F86546183A96A35758B864885A3A78A506D7C6D
797AA6916C72898897BA6F6F71B88F7982BB81544D95B192
686F88AB536D859ACEA3846EBA8261A6B185B7CDD6B0AFE3
E4E4E3E0D8BDA7B5BBB38472768893A280676F82A48F8084
948185678DB7A89C7363A1AC90797AA6835D5E736457518F
7B485C498E7E43524377B376423864926E444A636F8E564E
656D57373A5494725046455471353B4D5C6E43476065556B
685B81916D667A586B807E72625B56463E3434352E303B3F
4D6A6744577676668095924F60829A547B8B7A7F686E7AAC
577781A15B65939598B8676C80BB858080B26A505281B1A1
726890B59C7E8884C8A78573B685648ABBADB5CFDFE0CFE2
E4E7E0DDCBAAA1B7C7A4716F83719D99728391A19C7A888A
9F6A83719DBF847E767EB58D886F909076686E61526A65A0
7E4A7C6F957447463983AB5F4E3B63A15237487186715055
7583523A36637D3D494743716B333B5968593F5C99764F57
70998B594859826F7E89754A46414D6671664F474642433A
37547C614E717251738BAB67618599614D7561716C8A90AC
6070719D61606A8071A8757180ABA88B66AC9758515FB6B2
774566ADB78E566DC7BE8673B0A2747CC29EC0B8DDE2D6DD
E5DDE2D3A4989BB3CBA87665828EA981808F90A29F807790
954E6C82BFA9835F5E99A679796B91705C718A804F518985
565D5E838D4F4D4F4DA7A3614E43948E5D4341898F66655E
917D4D3A38718D4E473B5D8967394160623A36738D5B3F46
7FAB9A45504D679D9088483A41647E9591908C8285716360
44565B6698A08B496E75A05C7186A1A24D5E7059637B75A2
8F73747B5F656F6C567D99776384AE81648DA166544CA3B3
7B577ABCBB843F71BFBF986693A67584BEA15C61DBDFD9E2
E5DAC8CE9B959CC0B8A375798D97A6767F8C93B090826185
736A5492C599866A59A69464737C9A6C60659A7B48509D74
5B6553866138465998A8754F5B52928B564255947C4E4D60
99603F3B3A7C753B383A6C9046424A72463D598A714C565C
8BAA8038364984AB84603B4444677F6E5883948EA39F9992
5477525E7FAB924A4D5B956A5D7498A7546E8898706C74B0
9A4F6E6361747E6A4E56B58F756CB2846385A680644788AB
846267BCB768586790C0854F61B58971B5A9556AD7DFDBE3
E4E2DAD4B9B6B5C4908A75745EAFA060739299A680898882
606B6DAAB8917C7A83997C6371A08E62595DA0745F609E6E
5153619348545167AA954648576D98564444658959424E66
9349493D44643E36364585724340566A4047838C4E3E4173
A88F483B486D928B47353736373F4647423A52577D82ACA1
897B4446677AA46040738A7A3971849E5C5873B3757F7CB9
AC62748475859D6D6456B37F686FBB946364B89171636AAB
64627CBFC68F604957B9836664AA9968AEBB7F6ADAE3DBDC
E5E2DFD6BEC8D0B9867C817062AB8667678CA4897084A268
6E6F84B3A37C7C8DA1A37D7270A483595D76A1625F6A905F
554D648B4F6B6C92A86D444C589F8943485F7F7444494F91
814443344A502E34354F7543454C67554154865C433A3E76
7C653E395C95765152312F36313F3530322E302F465E7F61
7D764641606D928444778A99405E88A97D6384AB48758BB2
A2717DA0AD91A47B656AB1776775B571624CAFA375616BB6
826B94AFC4947F744DB5A68F64AD9362A0B36481CCDFDADA
E6E0E3E0CEDAC9977A89718DB6907256677BAC8E7C9EAC7D
6F6BA8B99B7B7B99A6998B71769374595F9A85525E718E4F
4C6A9D704A5481998E55435268A870545C5CA18A47477289
6E4D4A38405437433D6A4D3A3F577A544958624342384E6E
4850423863A8613533384E453357455738324C3A3438595C
6398644D4A5892943B747AAE61668B9D587A8FA943667392
B07D7F7DC1A9B88E728CB67F6E6EA8716151A7A6736D6FC1
A6908AB6C5B0997D58A1B38D60B9AD6174AC5E5EB3DBCFDB
E7DCE3DCDCD6BA717077869AAD9182767D8E937C8EACA779
767FB1AE886A67859A6B95616776605967B17B4C5D65805F
679291525D648AA0704C3E505DAB6148526AA06044497F56
504A55384252394051774641456C67475352424A4440554D
41403868747E5E363545686348707A713D517D60403D566D
73AF81434953828F3B5C90B168597A9D436370A23E637077
AD72797DCABE9986638BAF768566AA7B5B519BA660585CB2
A28E81C8BBBEB96B5077B98C74C9BC7C62AF4F5288D9CEDD
E8E7E2E3DFCEA7798F809BBF987C77798DB3748D84B68873
7188B38D73605B848A739461927E73959DA76C535685865C
8C9F764C65917F9581564A6773944E475E93814A45719E4F
494C463344533E38656C464352724E35475647474A3E4438
3A3D397B66415D40556D766E6A85756B3E45729F7242416D
6FA69F57515F8B9D455393A9655091A8806546846B635E72
AF755F73C598628E635FAE7B7A61A4766C5D90BA8250519A
97798FB57BAFC9A26754AFA27AB3B37760C06B5771DBD4DA
EBEAE0DCD9C288738479ABB69380667E8C8F7C88A1A67650
77A6B070664E59997A795E63946B7A93B08F50595F9F715B
849C5648777A4E688968517E9F894D536094683E4475A143
3D4144335662433564573F445C51403D605635464A373434
434D4E7743396E5B6D7B5545537B605D343954A6AA733B61
5B7BAA71506685AA595782A97A5576ACB6938898AE8E89AB
BEAD80A1B86B658B6F58A277615DA39A7F657ABA815B68B9
97818FA18C7BB6A07A60A19F7B8EA1916DCC955C64DACBE3
EBE5E4E0DBB2897D7C80B59C7D636A7BA67074A0B38E8381
7AA29565595D8A9B7B7F74848F5E778EAD815C4D73AD6A70
868D645B715B44497454648BA767504A7EA1524E40938639
35514C385B4A3F43563B3654863A3A42814232415D433F3B
3F576D5442467972776A3A3833463F392E3351A88B9D584C
555CA8834E608AA46035649E645F6CA2A7899B9EB991797C
C69C747F9D4F6A86795BB18971598E9D906D65BD927B8ABA
978691AF826CA16A7467B6B6827C97B9BBCBAF8972DDD8E0
E7E2E7DFD4A9898F8B9E996A7A526F80AC736D7FAE626C9B
8BA67763645C8B846C778BAA7E61746AAF6E526B9E9C5C6F
9A6A607583534D76584A7E91954D5353676E3A43398D6D34
3D756846474D5479484643615B2F38517435364A836E4749
49637E4046478B7F6F57333436322E2E2932526748799451
415C89915B6A7F8F733D609B6250889598748F8AB36C6074
B390645764626E8D6F649D81725B94A18B755EB7A17F6CB2
946863AE7A75A77A4D6697B98B6D81BABBCAC0866BD9DEE2
E7E4DED9BC817391A89E986A6A616A99A26E57A98956617B
909C6D775F5EA4896C7383AA6A5E7186AB6C686F9F7B4D6B
9171619B646E829E5B4465678F504F65656A454049755642
527E81514D5E848046464D6B513D4971553E3B6691714741
468C7445454E8D65463F443F484D382C292C46483945A36D
436E77A8605477828349798A6F4D81809D5F8085A85B6D72
A89A61505B6D73947D569875605F85AB6C766BB2987E6A9B
7B6868A28271A1957A6A63AAAC6C6D88C9D9C28F83C4DCDE
E6E8DECC907F7E98A395A67F617F6E8F9C7071936C596872
945F6262627DA76E5D77A89D6B6E80A6A3706EA09561747F
7E4E6F9D687392A05D4D4A888B48486380624A39639B5438
48758D5C445589754E49747C483D4E754E36456D895B4049
68884145426288463E43505D908B7E6A3834455C3B4D958E
455C72AA724C686C90477A8577467D73A85F7A73AD526D6B
AE9D5E6A637F8A8E6B5F916C65677A9E7071659D8F806193
85756B948A6C7AB3856F6486B9827460ABD0B5899DBBDBDB
E7E0DBC27D82919F9F9F7E61677F8D95939F7F7D625C7490
7D417368689994725671AD88626676A38D546FAD8158759A
5E43897956578B77525164A8754F5C806748484077A65241
519D8D5047589062514570514547656D49464E75773B4556
9C763B424477764A50495C7F7A7E81934631426F48487FA2
485673AF79506E6A92416B8E7A48737CA6667084B15F6A9A
B1AE7A676777BA8E5C46868B615E77A465655B9A8D7A62A4
937E619888736BB270766866B16E7659ADCCB972737BD7DB
E8E6E2BD8F9E9898A9A1675D646574A0B29D755F5B657D9B
6D616F57508F9771637597684F5C5C9D6C5860A3817A7EA7
59558B754F688B5F5C507C985249528A6259575499995454
79B58A565B6D8A50495F683F404C86664944497649404653
9462393D425E4D4A494A7E5B534D598B5B2F506C41396DAB
67446DA67A5368769035608B894677909B527A99AD5E707E
A48E95746E68B3905452869C615755A3747062918E7B68B5
B06A68A89B5B5CA767718064B0566A627BC8B6827962D6E0
E7E8E2B9ACC6B9A299906758676B7CA9BF8665645E6868A2
764C595065A36A5F73779C5C5F4F70AA645556A29776A786
51738C6050649163646589894E4E599457596B7F94504A4D
82AD6E59557081554D674C3E53578A3F3F40557A38505776
864A4240544E444A536562404437377452335C6F5D406CA9
8046618C674552747535598D914875929F5E758592657D77
836A9C9E7168958F646471A676573A9163745D9CA1816BBD
958E7EB2A35B57A0765761529D76546A58BAD3917A7DCCE0
E9E8E6D7D3C993738085635370808EBFA87E60747384888D
56456D639283626A54798A6A6161A1A26E558AA96E9CA273
516A83675C5C916A636F92796E6164A86859669875384645
6AA25F50638E634E6374404664798F39414C6F7935445F89
544A43617E31424C8844504A4A4959844849526E57466F9E
79435C827D383B717C325C859B5B6B77945C757E9F5F7772
6B6088AE757298896B70569E8164478F56675E81A67C63A8
978D9DBF825F4A8991636C56918C736E5EAED4A47E7DD7DB
EAE9E7DED9B68170777A6A706C84B6B58360627E747E9C70
467D807BAD6C6B61729A76706B86A7865365ADB77C7AAC6C
4671904D568EA65847819A585560A1A65D5C4A7E793F4A48
86A15053717D4251668F424E66A18834384279823B455F91
44484A84642C5571863955687F59477D523A627C47486597
713B48798141417C9A3E617DA85C73819F627FA19D606E7F
57605FA877666E9A58574AAD7160469A75714D81B5726FA6
818874A28C72578FA6617168B0B7816153AFD6B97F73CED9
EAE6DFDFD9B86C5C8D7D645D6A72B39259527E7E6F7C9258
5F6763938D6B77729199685F77A8846A4767B1AF9275AD74
797C9D6D529B8B5352739F555160A2825D564A867E414F7A
AEA46A718A623A4E7983434255A45F373B5E8C794049647B
374043A25440648C4D4167839749526E6642517F4441538E
7B447E89814341839E466782935C7F8EA3677A88986B7F89
57615FAF8C676EB06A704EAD6E5C528E86615659A186598C
856A71918A765684B86D6584BABC856F5B95C7C8A95FD5E4
E5E6E2DED4A98188B17B6A7D7391AA684F5D72719FA97B65
636788A35362807AA275604D64AE7C554889B59788A99F71
8E8B9C6B4D8A6547608EA65F4E569F6E3B4C50947B3F4877
AC8C6D7D9E554D5C97733E55598E5C3D3D638B7746417362
394455A0575484984D456F997B415988664F679250516485
7A466C8097413A81983A7388A14A68859C576176A6556D89
8C7166BFA27F7B9D676F559E67685CA4A46F58639C76586F
825F60A4A17B568DC06A6262C5B680776573D5CBA9C2DDDD
E5E3DDD0B7889BA4AE7473719CB980686C82794F8B9F7368
6483A1854E6B8F90A0585E62709F6E5455A89B718DA4726E
80AA735C528B5B545D86A9675555A050434D86AC554A4762
AB6F5E7CAA7159628E4F48767F6F463F49618149444F7A40
374F8C9B6367999A554572A45F3E528663475D864F636159
5F6771829B373E7D90347A8FA3536B85AE505F61AE6B7091
8C686BAAA4736797606E57A17F7055A9A3715C769D7C5459
917F5598805C5284CAB1934D9BC584645072CED1ABC2D7E3
E9E5DECDA4959EAE9A80857DB9AB76627E716064AB7F6F54
79A8AE5F51565B9A9E67536D959A705165A87F64929D6A64
99A96558548259497DAD9A65547EA45641459BAB674A6192
A1564F5D974753799844506C9B7E513A3B629A4C5458762E
304783704185A791454C7FA74C42468B5635578449646B5D
4E6658828F333A73A03A729595667192AC545F67A9817D8A
907B70B3AF756A98796F6EB3817A55A0977A6286A2634D68
A48E547E8B655B89CFB8895859BFA4545760CBD4D1D9D9E3
E9E7E0CA94A2BEA9757B7FA0BE7B675F746B72B0A4675B60
76A1A357686E65926A725567A06E736DA0A26261628F676E
88AB71617D735F5C79AA646C71B0A153384FA0AC5F5068AE
75404F5B8A42568E9551575BA89B794944818D424D537D35
3E5F8F57346FA1593E508B9442495182413B506F3A515E52
50516D929941528FAC4C8690906A8B97A1585976A16F6C75
8B757EB9B58C4DA97A7366A27E7F639E8A7B668F84615268
9C6E508EB1725581CB9C7A7B438BAD724C53B9D9E0D3CEDD
E9E5E3DABFB6BE867E6D70A3A36C6F56636594C18A4D5561
6EA3916079688D9752544C6A886C6170B0A0566172974F68
7A95596EA66F5262A097497166B892534E4EA9A0424E57AB
7B56545B8D4362A09C4E595E977C4E617BA38F404E677533
468D91424749A3553B599D7B3644598535366B723D557E5C
5C58739A9E77559D9E53889A8E5476839152606AA26C675F
6F8471AB757757A15F5F558C8A6C5C9F887D6B7D77565D57
83754E8AAC845D5CBB976F626B75747D58599BDACD99C5E9
E4E0E6DFC5CAAB8084948DAC7A6B6F686A659BB7805E5D6E
6BA9796B514A8488565664898164497AB0845665929E626C
9F985D61A8794D548498355D7C9C7F635E499C9F4D5263A1
6C4D4A5D794451A36E5E5F59A07242666EB2893244797D36
508E8841576291474463A8634748687A3D4F73623E528666
4856679A86685793823F759C8D466689825867638E676871
5B835FA162735EAC66645589715C608C80856E68825C644D
9A674F83BA916B61AFA070676DA3615E6E578CD5CAA9D5E9
E4E8E9E3DBCE928C829089926F71686F7E84B98B676C6271
909D5E615B4AA4755D83A8B29A886F9BA7715F5FA989745E
A28E5167A767546B8EA75848799F5756537CB1894850669B
533E62986E444897526E4F4D9D6F477A86AF702A41927731
5C9D83484676913958779C4D3F477E5C3F53804E4D528674
3E5865974D3A508E644C728383577D919363727085656A75
836E5EAB7F8B55A268605284715E4A6B836F5F587B5E675B
9C72585FB38C6054B79886745EBDB57E796E6FDAD7CEC4D9
E7EBE6E4E6C88F8F94959D847361657E747DBC8576747D8D
B7855D64689080596384ABB2857D75B0A87F6F86B368544F
A36E5080AC75526CA3A05568908C41445598AF9150404A94
4E42688F705164993A505267A6684655ABA067355EAA7733
52A2864651818C2E56959739404C744E52598A4053729B6A
3F5280984443608F5C4D7D9B7A576D8395546D7A7F70657A
776A74BB9B8B639F7A75588B80633E49826A57568B60685B
9E8A6A56AE8E6050B8BC8E6C5DB5C1987B7D6ECCD3BAB1DD
E4ECE7E4E0BB90A2BAAEA19D897084747CAD8B7E75726BBF
B182587C74A76A5C5784B18C735D84B98961759BA4624D74
A2674F72A06E6271B1A1597AAAA04E494C60A7734345559E
52596A934F527AA961465777A05E4153A19C513E61AB914F
59948C4A6F818F373B9A6B444754894C48588D4454669152
46578DA84D5363924E5180A27C607D7F924D768A8F6E658E
686763A4657664AC6F7C5C8D7E5749517D52525D9B846D6D
B18A8152A0986349B7C0A3745C8CCFA6938568C8CBA7D4DF
E7EDEAE8D89281A8AFB6B28B71666B709A9F63657789A9AC
7C716A6C9E986C5E6A8AAA665D769DB57258599D9065588A
6A65578AA4615677AD9E4A7DAC9D4A585C97AB5E585C9BA3
705C6E864F5064953F42547AA343425C67593B3752AA9F54
60A08B4C436B8A4452884050508877554D8888476B608940
486392A46051659C48596188624D668068517D8B7E5D5881
606A5E9D60827CAB6C756B8D986649588F6F57489A866E63
A98C7251AA7E594FA6BB8D6D628CC1A18B7E73D0CD9DCCE2
E9E8E7E6D06B7D9DA1BAB3838C7263889C835E5D5964B898
6C5B4666AC805E5E5E988A5C478490AE5F5873AD896B6DAC
6A68859776566074B88A434C6C904C5562A4AD514865B0A9
5353564D47657192424A549C943F415C52505E313F95B74D
41A0A3503F4D918385623E4283A25E556EA261506F7F7732
537DA1976E4A7D9C4459668D714E728675477C7B6D5B7093
6A705C916E7B6F97727B638F896052608A6A5359AF8D6E73
A1556A56A99F6B4D8FB78359555EAC9E7B7E75D0CDB89FE5
E9E3E5E4CE8F809A9FBD987B9D7F7B9F86645754618CA77F
645F5B99A9815D585CA77B524673959D5C5B5BA67D6B7BB1
816A678F7060567BB56A40497A9E805F4A92AA535360AF9D
544E4D493D689DA6554D52976E3D4D6462807D353B6AA846
3881B9774E487097614C48388C755E568E9854616A827739
5777A66C5E6B807C41596FA44D607B85955C7B7E6E5C586E
6466539280825E9F737A6B887B5C46748B60555DBA9E6A5D
AA6D604D9EA47C595EA16C535D558FC6977D95CBD0AF84E3
E6E3E3E3D9AFA99CA9B9806763656FB78061645566A47067
5D7C70AFB3886481859E6C6052667979515F619E6C6266A9
916355A366586D7FBB704A5FA191806060A294445F5CB69A
425952504753A7A74439799D4D4055484D7E9E3B4E53943B
3D6CBCA3533A445045496180845259568F6241518FAA6546
677A9A504A627C6F40607A944660757D955D7784685F527F
8B815898838E6C9E59725D845C4D427E976E6149A2847654
A09D776871C0866354A9B06A675F85C9948073C6D6ADA8E2
E7E9E7E7E8CDC2C7B3A27C66656CA3A96A565D65A4A65961
7781A6A893676A6C8D9C675E6D838C795C5D899B5962809C
89715CAE84657280A77B5E5695645C4F71B58A416B99B894
406D7E70544F8E9D2E4A619B4A41617E36539F4337529844
3E61A1AA7F393F43535E7E9D594656609C3A383A859A575F
70778B50547A9F73425B799946727FA06F6C7E9B736D5393
715C60AC858D5C9D667A618C61674D7A9975625697896C55
B2AE6D507FB17D624EA9C194665995B8766863CAD4C0A6E2
E6E4EAE4E8DFD9CB9F76746C779CB27E70555762AD825F65
729CBFAF884C6B7FA07D5E636874A067574D809870628497
597380AB5F646AA2A66E4E5EA0673E4F68AC574D57B1B262
456E936E6A5B8894345C77A23B4175943345A36B4759846D
375B64948041444E578EA76C3A58849E8D35415495764361
63A691445B8BAF745E6D70994F6E7D9E4F6F7B93616A59A8
6F5F68AC818A58945D6E83947168465DAA7A665D9A93684C
7FB7754E8DA4756C5E8CB899665270B77C6E7EB6DFDFD4D6
E5E6E8E8E2DCDDB97A776F7C90BCAD5F6A5575AA9C585C65
7597B6A89E567172B1835E677A959F605C589E8C5B5E8C8B
444F83A05C5E6FAAAC5B4A649E6F3D5467B0523A4DAEA84A
37626A444762889B3A5B5F72344065973E479C8A3D53609F
4C4138554E433E5158A19140445490AB79464564A48B3D60
88B6A05B6BA3B76F6892959C50646FA04C7371A17C624E9F
85707D9D597948895072779E82634760BF916863A2955E49
5BB67F558AB26C5D526BB1AD896760AE7D7E66BDE3E6D1D7
E6E6E5DFE4E3D1A876666A8089BD90795D6292AC6750504C
6EB69A747D556C97AF7A577C8FB795655F66AA954F6D9E83
5F52A0A14A524A8BA060557C944948596CBA81375DAEB058
437B7F3F41609CA8725D644C314662A439529C9140465695
9B503946476161958F9B443B40509C774948468DA36A408A
BCBC92517FA3A85E6E8D8F7E556B7B9C596C7CA37367597F
68624F8B5D654C915E7E719F8062418EBB8E7B669E9F6F51
4AB08A4870AD82615767A68E706D59BA827C6D90E6E6E0DD
EAE6E7DFE0DCCC9789677B75A0AB80664F549E774F4A6666
A3B27F6465626C9F9E6F6F6484B98B606360A8755E589D73
7A64AD9F515765A7995661709E4C4C60B1BB9E475B819F72
55776F2F406280A673556689384A6594354697A23B404A7E
9C684E486591ABB3B167414A589489474A423F988E376289
BFB7755981AAA33F678BA658506266A7687F70A15C636BA4
65583E865E765C916B7C5F988863467CAE7C6D68AD7E6E58
3EAA9C534AA6927A5D5DAE81746A4DB891869183E4DFD9E5
E8E9E8E0E0DCCBAF959FAC99B68F7C595892A97B555F6B7C
B89A4C597A7F82AF7F5E616086B075645E95AF6F5863B78F
725BB9915B618DC1854F64A0A956496EB7BB954967687642
405F4E2F3F5C898D414D6E9238595C852B4283A84F383E4E
9D515C4D578DA38E8A4A4A567392593F424C4168603974A3
ACAD5E4C6CAAA2396B92AA64577254916B71628C526B8882
73594E825E74529C6B8B739379584666AB6C534DA3686070
44917F524DA18F80606AB68A666751B5BC829FAFD7D5C8E0
E4E5E5DCDBD5BFB2928AAEBAAD7E778F81B0816D626F7FB2
B26C6B546B889BBA8860675FB095635559AB9E5D4D67B766
7A76C0795D5F8AC0734D5997B8765768B0B57F3D5E5F493B
43426233415997823647709430425980314583A76C353A46
815F404F6059525961455E99AB5E3E40486C64724346719A
637F51586EA7943E6E92A6585E6E5C83576B4E834F74957E
7767637D5E5E4F8B626F648D70624757A4676C4686815472
668E8258408D9072607ECBAD897371B9B7897FA3CFE0DDE4
DFE3E5E8DABA938E9E9DB2BC917E7682BAA86565636F92B2
7F6A63596680AEA662556775BB795C6277AA844F56989F4C
7A8FAF5D59598CAE634C6AB0BE9057668C7F683157704A3A
494D813F45599E9447476E9C372F5F8C38458490703E373F
72A2644548526153485C89A38F493A384F6E467A47567181
4968526D9F80905F657BA0466D658A8E666F4E7D41738A8F
7774807C6A6B538E5C5D579F84604944AE5C5C52859F5764
65A091644A749D6E5C66CAC4916A73AFAE717359CFE6E8E3
E2DBE8E4E0A99F98B6BFC7AB816E6872B97B59727F7BB7A3
46604E625D8AAD82525697A2B266636F81B25C6F66A79749
618D934F5B498DAC5F5053ACB561555D64627B353F6E553A
445B8D4C3E4F8FAE70487A9F443B53A0464585A48A4D4A41
5992985F535653555F8FAF8C4542394A6D54496147606E6F
655D576EA98190566AA29B466B71937970676075476D856B
6D5D718E75796E8A808567A66A675243AE6F574476A35767
59A1916D5275B8844F51C0CC8D795798B27E6C6BC9E0D9C4
E7E4E3EAE0BB848DC1CAC69C7A817095B76B7B748BA4B285
576B61707E9BAB6C4A566FC0BA766E7BA4AA587980AF746F
7993B074704673AC5C5452A1B0624D545156703E39777A35
424D98763B446DAA55537CAB594058B2845586AD9B4F424C
5071A0918386868F99A4926E4652426A766D6A554F627D7B
3E526C7AA39A864677AB8D485368A16D5E6B947B645C6C6D
7E6D8F8E7A687C907B806E9F60704D3E9D76724670956D60
64847F6E5D66C8A65843AFCA9A755188BD7B6682D8DDCFC5
E5E5E8E3DCBA98A3C0C9B99A7BA395B89F6D8488B9BFAB6A
5971798D99AB9A5E425B56B2A867586EAFAE67798EAA7F80
807EA868655F89A2646370AFAA5253654746886D408B8441
464EB59D534A64A73F4E6FB1773F64B69B4D95958C6B4547
4551989F93989790946B65545C5C564D63748255595B81AA
6C4E8C6D7B9B685083A6753D487593455E67888A70738268
7168868F74679082668359A4756C55519D5B6F417BA87363
649E8281606CC5AA725DB1CB9F8174B2CB9F8B82D6E2CFC8
E9E5E7E7E6C09CB7CCBEA9998686B7B97F75959BCBC69F83
7F89AE9D9EB68852535E5EA2864E4953AFA67C5C63B29777
7C93A75E6D5CA79C5253949F883A5E88485F90953F80983D
4677BEAE6F476DAA596071AD9042519491405D51478B4F41
404683668D7D6B464A5B51476F91614E5589705F6859ADA9
5763975E6D8F6363719A667D769C6D465D708D777381A86F
6B657D86717FA6866C7B599E826E5E64A16C6C4871B76E71
65A6A16F7479C8A9907A8DCDBE7C6AA1CEC2A395D3D8D5C0
E3EDE3DFE5C6A1D0C8AB8C99868CBFB07B838FC1C8BC8383
7E8192A2AFAA766C5E608DB87D534753A1946A6068B17262
7A94A45C6550AB7A3F4761807E33678160487CA848689D55
5698B3B07647538F5B526EA3724144728E2E2E38509B6753
484D71596B804A39404A4D76806B4855669D526472A0AB82
51679456798C615D74A179768AA98267776D9970675F8B5B
56499283738BAF796C7F5E9B735D586AAD7D6A4C67B38992
71B0AE7A6088CEB7747674D3C1854E65C5CCAF7DD8D0D3CC
ECEAE6E5E5DCC8D1AD91747E90B2C08B725E72B7C7B29275
7B6C7792BE8C657B7E8AC2AB65566185B5715C6356B78A6E
8E9AA3465270725B5050415C8E3F639183345E7D567BA979
4E75AB886244436A514D5D9B813D46619D3F384C5CA89A52
535C585C624E3A483F557D9E70564640528D545861B0B06C
587A9B527F9454627FA95D738E8E8A836F7491747475A74C
82589F768264B977667664A9685E6175B78A724970BB7F93
7BBBBC98708EB9AD817591CDB1714A56CBB99B9AD1D0CFD1
EBE7E8E4E6E7DACFAE7E75869EC0BC80706355BCB2939A88
7F7386B2AC6D55606288B26F665F66ABC87F5E88A8B69376
82AFAC4F546B6B55615344578B5B6794843B62635251A28D
4371AB5C5E5747744A40659098393D62A75F43545780AC89
4940354145343D576B7EA68143433D4F70674E4F6A859954
6283985B82A4556484A45F61977B8F836F79A76B6A85A24F
7657AA738664B570566E79B36F6B5452B584894862C09185
7EC1BE926B57ADA767608BCCA76A5871C6AB6F73CBCBD5D4
EDECEBE7E4E6DBC099807F92A3A3A2836B708CC288726F70
757AA7AF725C665B6489A24E657395C0C1A08682AAB38563
68A2A95D4785A46673825D619E7D62907C345C6E463D7A86
3D599B5B6644347A7A445B7C943B3A619282505B564F82B3
83515D4A356D9A9A9C775B53433743837150504E51687D5F
828F6D4D91A454708284627CAB7385A78481B15D7472AF6F
6C5BAC6D827BAB85707593C29F7F4C56B08A83577FBD987A
63C6B59F7763BAAA6F656FC1C0905359BFA65F4AA9C1D6DB
EDEFEAEAE4E3D6AE937E89AB7B7E83957EA8BB9F5F678F82
71A8BD88595650627BB0825D6271B6BBB6948C869FA69F80
779A97453D7CA26C7FA780768E6A727B794C56735E46628D
41607C505E493A7E8A464F6B913B4462769F4E4853425CB1
B8A88F8A708AABA0714D3848423D6F8859444D6F5D676263
68A16B5EA99E5090A16B719CB78298A7A4B5AD5F7F6EB97E
797C8C777361B088847E6AAE93885576B37D835977BE817D
4AB2AA854D4CA3B5815E63BDC4905F4FAEB36A50ADD1B2CD
EBEEE7E7E7E6C79C9A81B0A86564727998B6BC836272717F
6DA3BA656D5853647EA8776E619CA499A7918277829C8A7A
8F7790583D5C8D668B9B6B6C808474719C4647826C344E91
556C48425D4F4C68923D445F7E50577468A272403B4C77A9
ABABA9AFAB8F7F685638414E576C7059675C815267845B70
859F587CB78F518CB0586E9DAA798AA481B79E5E7567A882
757783665B63BB828F795FB19284707CB07A7B6675C09170
56BCAF7F5B56A6C170594D90CAAC5D5390CA826299E2D7CA
ECEDECE6E0DFB7957B93C5A96C5C5C6BAABDB897736A659C
A7C0AF74585B585B7AA271776A9A7D748F9162607B9F6D7B
6786704D4C4E834C829E4C5B856A5267AC5C528C7D353A79
5D563D507640404D7D5039427F7B766A6AA198513F425567
687082759375494161334751678552445994744E6B945183
AB9D57A7C083709FB15C919FA174A79574909462776EAD7A
717A95656879BC8D8D7F70BE9E805C689F6F81687ABF8475
44B9B57D6A3F8DC17146525CC6B77268A8CCA674A7E2D3D7
EDE8EAE6E0DFD08B88B1C8996470619FCBB6909094676AA0
AFA2886F585F605FB99F6B7C91926A73869B66708D97646F
88A1604D5B6D564E64974C5C7375396C984E47829336346E
585C3B3E7C5F395B677138437C8D5D605F89B19849484A59
73576346636D5B465D445B99884F494D748642448F885B7D
C08267B2BD816CA6955E8FAF687198606F8898567A71A66D
6280997D6B83BD848A9281BD7E6E5B498C626C5590AD8072
4DABC89C5B4E86C8844C3658C2B16F60C0CFBE85B9E0E0DA
EDE9EEE7DEDFC4A090CAB97E6865A1C0CBA78C86A29AA7B6
A66465666D7FA7B3C598637C8981767581A06779909E735D
8CAB654E628F45445B927A59717135709F3D4579974A2F5F
A09C54347681444D6D6F34447F9837525867A3B189554A6D
77575B4150566356588AA79B5C47454C9856384189595B9F
BB9CA2AFC58286AF835493A65482984A758BA45F6C6E7C66
68837B8870A0B76B827C66B87C725B45896466569AB17959
51BAC5AA654E91C49762455EBFAC6D489FD4C6A6CEDEDEDD
EEE8EAE7E4D8C9BECFCC93615C6297B7A48581779DB2BEB6
A36B57537180A0CCB9805C60A36B625E6AA06C707C8B796F
71AD7060637D55516199605D867C3771994E4E6BA677384C
A8AF76398D944840797F494E72A66E48657C669EAC734248
56678265636264647CA08F62595F5377754D486F5F6B7CC0
7D8BC0BFAC618DB5705D8C9C4781B55C75939C6A7FA27970
7091678388A1AE6D736F59AD64636B53A282654D66A66A60
50B3BB9B74487FC29E617766B8BF836365D0D6D1D5E4E0DF
E7E5E8E5E2DFE0DAD8CC9D718271B7A17571656693B2C092
A46E7355996390C991657191B67D6C585FA8636F7BA3766E
6AAE75596D9D6A4E689E5C5D8D953B5F9B684570B7983E4D
9AB06C366D9350415070634A648491795F5E486DA3994947
7188B9ABA09AA8A3AB77584A517D9797504245714F659FAC
5271BCBC805BA9BB6E6793995D9EC57E899A8A6479935F74
58916B7474A4A37D756850B67A65726BB188584870A16555
44A4BE8B6B4168BEA46B7774C4C8A76160CCE2D4CBE5DFE5
E9ECE8E9ECE0DFD5D5C782747480B5726A6866778AC1AB72
866E61797585ADA8657286BAB283636785A0797C84846474
7E9E75606D915F45627E4C5675A9495DA0843758A2A14C4E
8AA676304E8C72384E825B4759676A8654535D5C75B6634E
607CB7C0BDB7AFAC8B5D51464C77A38B4F4A91585784BA9F
467CA7B96D4EA6B66A6EAB9A709BB985798883686686866C
5C9F7260727A7B95746265C79967758AB870524581996463
59B7BB74584E45B5A0637673C9C8AA7268B9C9D9D8E0E0DE
EBE9E4EEE8E4E3D1ABA4767F7FB5A75858687C7A71AD9A6E
6E5B5E6B72889A8F597A85A68971648EB77E6C7986666472
6B9E72737AA75C655B6460537AA44C4C979A3E5D99AA6B44
70A276343E6B814A386E67375067687C6A40516263AE9A66
457174949F9E86925157585B5593765C5F7A9B4E5B92C085
5476BFBB7053B2826682B986729FA87770798C5B529E9066
60A67774986C55B57C7279C5866D606EAA675443A9A9635C
68A8B5716D603DAD9B60667CBBC2917D6FC5B9AAB6ECE4E5
EAE6E8E3DFDDDFBB85808CB1AFBD8B57746C8286A4A8936A
68645C6467AE8C51667072B08B707A8EAA7A6F888C665C8A
909F5F7A6FAA5E63545E71507AB2653F7E8B423E93A87749
67A3883A39547D5D355188414F724F5F7C4F4F586E6FA491
535758816B70566361475E8B9375395B6C9F6B5F5F9FB168
6284C4A28D79A95E6086B9798293955B777C716677B08461
8D8B7A7AAF5C51AA838475B280755570B26F664ABCBE9548
3E70B9846F6E54AEB86C5B7EBAC8B56E7CD4CAA0CBEAE2E6
E6E8EEEAE0E7DC9784707DACC7C17B73748A71A4B8A68460
56655C7398AE8473535D90BA9073776BAA5F798A996D626A
82AF8C6B77AA60635C86503F669F704288A2544299A98E44
4E8A98483F667B8C3A437A55446B72515D836D4D515157B1
7553595C6153605468608BAB7135406182AE51756BB08B4F
75A4B27B8A80A84E707DA8678299926B7D8B726E85B6795D
8F947582936759AC8365439F5B5F597BBA8A5E71C6B08467
443F9E757676619FC6A1666EB5CCBD7D6BB0DBC5C0E9DFE6
E9ECEEEBDEE3D79A837E9EADC8B28575797D7CB2AD895F60
675E6381AE927B795C91B8AD776B7B7BA45C86839D745E4D
80AF926880B76E5F8B9173345E8D6E396BA66E4189A17C3E
50619D6135466B9A5C4A807040617E5B5376925B4E4A4692
A07B44535C575F4688B7B69439434752A0A04F6683BA6447
77AC8E709BA7994A687DA45B80A2857686B382658FAD6A63
946F7CA18F7363A17F70418954536785B77F5588AC8B6781
5748A1816B765792C1A377589FCBC0825CA6D0DEE7E0DFE2
E6EBEAE9E8E7D3928297ACC0A98398655C767EB6A86B4D5B
4F50889FB9846B7670ADBEA65457689CB57D8880AA886557
72945C6092B5674A71A09E3F5467803A76AF983A649D8F43
476B9D8A3E40569982455F7F46416580505C839475504353
908A3E646C6C746599AF95643E515E5BA36E576CA7A94273
92B6717190B17A5073848D5C98B6796382B79B6D84A86865
9E6C7BA3837F67AA687C519A51586292AD6A6863A48B688A
624EBFB17D84749ABD9B6E5386CABF845BBAE3E7E2E3E3E4
EDECEAE8E6EBD8A7C0AEB2BBA17E886A59808FBC6C655859
557CB3BB955C72527DBAAC7E586670ADAB7573ADA06D5860
728C5F6B939E483E6695A74C5F8C8C364EA29A43416E9553
40589CA741374593AA613D868049598E5153545F9A714E59
71936A9AA29AA691A1805848587B689C93566489AF894683
98AD626B7BB6686C79915C608DB250746CAFAB79939F5E6D
8D7D799F866F62A3778051AB73836395C4888970B08D6C7D
7266C2B99A8A6B67C4AF745082AB9A776ED5E3E5E3E8E3E0
EEEDE8EAEBE6DCD6D8D0B8A2888C777A5D7795A162667254
5790C0B27555738BA4B0A4755E6279AF92748EAA85585B4A
8568406C9BB3683464A0AE505C9591385FB1AB4F4364986E
414C90B77D345093A9834C77A65F3F848F5541557A94745C
5373859AACADA77E6E614439537294A27F5065B7A8564983
A9815D6C81A9837B839F46637FB35C796EC9AC71849A4D62
6D7279996C77869F6F817DB87B8053B8C69D7E74B393777B
727ACBC8987F6452B6B0635B5C7FB18A5FBFDEE0DEEBD9DE
E8E7E7E7EEECE5DAD5C99DA66E6E6E8881B1A37775725144
5788AFB0734D849FB8B58C736D6691B36F80A7BC8E425B5E
976D3B7392B9984A6392A842518E9E404697B36A3858978D
4F3A7BBCA9615472AB986563A27335649D82424D60677F59
48566D5567727963546261455E6EA6655C5450BF9162678D
AE576379A78C6F8CB0A3436389B7717692B8A96575926770
646C688B6277A69C6B6FA2B27E7E51B5BEA38168B8A87280
6CA2C1BEAC9071529AAC56655FA7B18671C2DAE0D6E2DFDB
E7E7E9EAEDE4DFDBD79D8B86796A5782B0B1744A686A4F6E
75A37D866C647173A2B088745C5F99A456759DC0B581705B
99893B6E85B5903B61959A484E99A145377DAD803A3F7C97
7B315FAEB88356478BA982628C9849497B94754F4A49615C
405167594F616F636575555B5FA88948515590AB4F5B6C89
8B4D6A7BA471546CAA864C7093A4807D7C899A76799D5188
77707C836071BFA37573A4B3808D4FAEBE8D775DADAC7281
5BA2738B9A796453AAB5805F6FB1BF9F6ABADCD5CADCDADC
EAE7E8EAE6DDE2DCD09C8192867B8279AD7A704D575E7183
BEAF746F825868779E9B7C6F4C7AAEA14874A6BBBB775C77
9CA24548629B9842517D9E3B558CB15931609AA35837639E
9A39466FA98034406AAAA37C80927B5F566B9071464E4952
5158604D4749605C657049749D955441417EB98844486391
5E596B9E91465168A8555C7D7F79657B7A719D6F72BDA292
7E93AD68706FC47A7774ABA37E743EB1B566604CAA936162
4D9C6B7D9F7A615894BD725E82CFD1BC719ACCD5D6DEDFDC
E7EBE9E9E2E9E7DECFA3778B9499A2B1AD6A7262657468A7
BFBE90717B6164939D806A7F6582BF996B70AABDAD7E5580
97A3625F5B9A8F414984A945426FB77537519AA6413D5692
A24D3E59A0A06846729DAD937C778D864E526D7A8162555F
6C446E61523B41576EA793A29958494373A7A74D5F4E74A6
537298AC544D727BB35C5F676E6475A2A2808E7B84B6BB84
88B0A7627B79B06B8872A88464653EB5AB68624D948D586B
4D95625FB77E676384BB594D73D0DBC99768C6D1D8E5E2DA
E9E7EEE7E9EEE7DCCCA2AB84ABA9B09E7C7D5E5E6465768D
A9BD635F6C677FB29A5D6276779CB05E7F71B7BA9A84567D
829C6548597EA04D458AAA543B67AE6F364C80AE5C3E4E77
AA6F3E4977A98F5B7791B1A06E5574986B4F51669EA39D9A
864C534E42523D7EA4B79F816C484156A2AC733E605B9B90
487CA1A74F5B6FABAC59677C89668A8D906F978479C2AA6C
88B991747A849A6A7C76AA624C4F4AB0956D6E3E88A2726F
529E6155BB917F74B6BE7B5C74B7D6B78290CDD6D3E4DEDF
E8E3ECEBE4E5E6DCC79EB5C7B89D93A48B8F7E7A7A7F6074
9EB37E596A77A8C0AB7E577479A79053647FB19B6C615C4C
6E906D3E4F82A25D4680AB604770A68F3B4261A09A3E415B
A4813952419E97323D5B988E443E6091A25D404F7695ADB3
B38A6256559A81A8A88E5F43443B387FB58239425F9B9C55
517FB7A8565F7DBAA3616185975062899C82856C81BC9359
81C7916A738E8A627779B16C685E5BB584617C4E8DB67357
80A26070BDAA7BACBEBF83606F9ED5BEACB7D9DADBE0D9DA
E2E9F1EFE9E7DDDBC6B2C8CDAC807E6879988F95A07C5165
88BA6C53546D9CC48A70547F99B074726BA7B0896C606247
61A3904A5B99B05D327EA667496594934A37548FA8465340
6A9A5442447E9D4A3235538E7C49446D938F544655597A8E
A6AFA1A39BAA9E97715C4D3741518CAAA059474F7DB27F45
5595B19D4A686EBA947085B298557F919C985D6D85B36E7A
82BE79706F9D8D68847AAD806D648EAF816A6777B3B78152
B2B06A6BC1B284859FBE647470BBCBBD93B2DDDBE2E5DEDA
E3EAE9EBEBE8DFDEDCD9D7C58D7B554E759F8381A460515E
95A86B6D556FB0C585536291BEBB7E665B909D727A7E854C
6589A14A547FAF6E3773AB6E366689A87D3E497CA75C3A41
50A791473F4D998B493A5172A775483F65948D64444C4958
587A7B666A7D5E5C5C4043404477AB80554A508FB57C4A4C
74B0A76351688F9E537F8EC48E6B7DAE709B627582AC5586
8DB5658B88998084769EA46F8863A6B7706F6F81C5B38161
B6A47B5EC2A179676FB67E7377C2C49F7FBBD9DEE6E3DEDD
EAECEDE8EBEDE3DEDBDDCEAC686A5760828BA38D806A5264
A793526A6671B0B68365858DB3B88655709B79627DA79879
898DA63D4E91B56A3D6A947D3A607CA18D3E4F6AA3824046
468FB283424881AD8A38484E7D9B704D4F5D858E6F5F4E4C
48524C46565E6362674F474C6FAE9D55485067C08F5E375B
82B8A8545375B1853D6892BC647C9A986B9B7475AEA95389
9EA76A9FACB08E8EA8B7A28C8F60AEBE7474709ABFB58E5D
92A8776CB085736F75B57C7483A9BB8EA0BAD1DBE0DFDBCF
EAF2ECE9EBECE5DDDDD9BD8263626168ACB1AE866667708A
A8706C88979BB98D7C73739CB19F68516FAB746474999E61
70A29442476BA78640618A933A4F5C88A657406899A34A50
4C74B29D4D436A8FA66457434F7AA46E5048598DA1A37A52
5F554352635F5C71736F9F98ACA26A4656648DAE50544966
90BB92526E7BAE7A467BA4B9597BB59785A88A88B99A7080
BA9A8CABB9BC7F8480B1987A7663BAB67A865D81C2B09550
6EA2776CA7808D707CB8917C77C0B0828E8BC8E5DFE6DAE5
E8F4ECEAECE3E2E5D9B2888C857577AAA78676646C779A9F
92748581AEC1AE7B586A74A3B5995D5C76B3564F6D8BA74C
5F8E993751669B714E507F91434D4597BC827A81A1BA894E
40538BA879444D5B92A3793D486C9E90684D426586B0AD8D
767E5961684C95AFAFB1B19F9B5B4D454F8FB16D54516771
98B55D5F6C8BB06E577DB2B05483AC6F9C808DABB2687C91
A77A88A8AAB3857361B58F654A7FAB8E85A16E60ABB07D50
80B39DA3A47795738FB7938476BDC4779CBBD9DFE7E9D6E4
ECF4ECECEBE5E4E4D6977C929497B5B0685E54565899AC94
8A8C889B93C17C747C63616C95835E727FA86C545991A959
5586A7463E799D74465091A66C35507DC1AF9183A3BBAD62
404963A0945B393D6CAB94443F596E818D7B4A4F6798ACAF
ACA68B6D8288B7BDB5A77365946D506083B383587192666D
A68B536D70AB925183A0BA9B6E849C72AD719DB3B55C818F
A8647F928DA16C8884BD89775777955C77956E4A90B7776B
55BEC1BA8173B69E98C5A6776DBBCBA6A0D5E7E4E7E8E3E8
EEE9EAE8F6EBECE2D49E8E90C7B8BEA2705D646797B8A48D
8C887DA3B8AF986B74906051636C6C81A7A06A67547C914E
5568AB833F658494435168B39A414866B2B96B6485A8B08F
4041439FA85B3439457CA08547535D5356957D575C606C95
84A2A19C7A84AB9B7D77544DA4B097A7AB7F4548988E6E88
AD7D758588A2986A98ADAB676A98A388BA8C9FB6AC547FA9
B06A8D88BAA7709993C68F7B4E9075688494535179B29975
5CAFC7B16773AA89C8C8B8665CCEDAA999DEE5E0DFECE5E5
EDEDE7DCE0E6F4DEDFCBC4D4CEBF9D7A7B64637BC5B28979
7B8288ACC292805C64A48E505D55658FB08D5C736A865F3B
495C9EA054457CA2403F58A9AD5B3E59A0AD8B7CA293B1B0
7A383E6FA4A056413F53759B905C484257739E8F664F486C
5256657D554365565C657066A0CBC1A26B54476179627E9C
A4837BA29EA38A7B8CB18D587AB57099A784ABC0A47098BA
AF868AABC7978D8D7BC58E70659460668695584E6FAE9E82
5F9CC49A506B8CA2D3D0B56F4DC9E3C29EE4E7E3DDE9E0E5
F2EEE7E5E4EDEFE6E6E0E0D9CDA8947E67687AB0C08B7074
7583A3A99F6E746475A2AF7C81685870AE7A47557191733D
3D5E9CA9534472B1823B4A8EAB8A3A5674C1B792B5B6B7BF
A24A465471A984434E3D4959ACA37D4750597F6C525C4741
4C484E5150633D464F5E5E9DAFBFAF72505373996391B0AA
6E716E79B597617BA4C17E73A6B562B07588B7BC898DAEC5
A6959FC8C57290AEB9BA7F74B39F6876A4BD886482B27C7C
5265B18C636E7F9CC7C6AF8C5FBEE2DAD5D1D5D6DEE8E9E6
EFEFEAEDEFF3F1E4E4E5D8B8B3836F747E8EABA4A16A6F85
7EA1B3A98D6B687372A2ABAE77644D6B9E5E5E5C659E8C3A
5C6B8BAA835265B2B04E5681B19E51556ABBC5B8B6AEC1C9
AE9D6F544991A97A4E3B39598DB2A16D56584849554D493D
3F47443F48615349556673B2A69A6C5B647AA075519CC7B6
554772A0AE5B6D7DA9C1868CC0B99ABC829FBBAF4F92B0C9
9CA3B9CDB1728AAACBBEA1B6C6AB707DBEAD736FABBC8493
565C9D94625F708FBFA17E7CA9DAE5DFDBC8D9E7DFE4E2DA
ECEAECEFF1F5F6E4E5E3D49D8992889BB2C294745D737E99
A1ADBE8E7A7C676B62B1C1A4685356718B4157545FB2A648
518580AF97424F80A9715067A9A9585165A3C2BEBF9CC4BD
B5B8A858404C809F7C3F494C6DA1ABA8997F676E75828571
976F625B51515B6C94A39D7E635D64487DA28888598BC5AD
5970AFBF954E60759E8973B6C1B3B79983A7C2A6608DA8C7
9E9FB0C89E72AFC2C2A29AC1BA987382C2AF8986B7B37F94
70A2BEB185685B74C1987A81C0DBE9EAE5E0E2E3E4EBE2DD
EBEBE9ECEFEDF1E6E9E7DCA090B5CBC2C2AD5F5C7C6A88B7
BCC1B28E866A5B61AFB39165615579819D44425B899EAA73
466C6A9D9B38485DA18E4A537EAF74535C67A2C1B3809EA0
9FBDBB94403A6071AE7E53474A6A6793A9AEAFAEB6AEAE9F
B0A1A08E909298779E90774E40526C708C915F6660A0B789
5C8AC6C48C64638DB15B8ABB9F80C2778FB7B55D6480AAB5
629AADCC8D80AACBB66780A1B3A281A2ABAD7F82BA9D828D
7B90C5B6846C5E77C4817E8FA8D7E7E3E3E0DADFE7E4DDDE
EBEDEEEEE2E8EDE3E9E3DEC5BCC9BCB8B192626D7C849BBE
B6BEB38E836B719BBC986F6349537BBCB87F5266896A8498
5146626D985F495183A05E50658F7F53546273AEA1485773
55A3BDAB624748599FAF9B6A3341546279A39EA195A2A292
8EA4A0A2A8A79A67645B523E475F86B197546B80A8B76D6E
6476C586636368A6996088B17C92B2899EC2A8377190B9A2
4F9DB6C4668891B1BA7F8CA2AE867AA9BB9E8C79BB805785
839DBBAE6F6B629EBD868573A1C7E0DEDEE3E0E8F1E9E3E6
E9EDF1EDE2E9EBE0EAE5DFD8D7BC7681908F6D6B7AA2C5B6
A2A397838A94A7B0AF73656F435E98B9AE8A58576B4C6C8F
7C3D6865A87F516774A45E58567DA670536462A0A6493F55
557EB8B790493B606E9DAC94544C4E5D635F68646E89796D
6A7774779067554E5261423949669282686D8CC0BE9E7063
567BBE68727676A75E5F607F8299AA718DBCA152838CB77D
6F9EC1BC656E84B3A37E9085AB638975BA9C7173C59F527C
65B5C29C565F7EB29E7D7267BDBAADD3D4DCDFE6EEF3E8E7
E6EBF1EDF1EAEAE9E6E6E9E7D8A2626C778D6B83A6B6B5B3
9F8474818D849B997E575C60607EA0A0B3945353724C4E7B
A3664C5485A164715283664A5579ACAC6560507DA9976155
534A759CA76C436F616793A0A0795C4F49555B4A4260595B
7172666B655D5B584C577B8C7B8B6A5671689FC8A267705E
6EB79A6C656A9F925286926B80A26A849EBC82618BBBAE47
7EA1CBC56E7A8CAA8A7F95B8AF617673A37E686CC8916480
61B7C89D6F7086C09881726DB9BB90AEC2D1DCE0EEF1E7E5
E6E6EEECF1EEEDEAEEE5E5DEBEA17671837C9FC1AF8D8F9A
8A8F738AAD97A1744D4E6286718D5668889E4C3E57865655
97AE683E5EA26D49516C8F4F454D94C49440497A6EA3A76F
5F4A637D928E5C5E656E7B79A7A9746D6A5E67604A4E5453
52736B5D64617077858FB9B7945C484E6B8EB2AA7964616A
AB9B4D6F597EB26D6FAA927DA48E498AA8B048668FBE9E4C
7AA2C6C87E818AC7768391C2A46E567CA0855C5CC2A76882
6BBCC58E7C6EB2BA9B88724FB5A774BFCFB2E2E7EDE8E7E9
EAE9ECEAEDE4EDE9EBEAE4D0AD9EBF9790A8CAC7A85D5E81
7C7E98B5A4B0A66B4C53579D858339586C8D3E334C835D54
68AEA7464F8FA45149619D8C46477DC0AB664E4C547BAEA3
8A5F4E6788A69C6448515B5773A8B2A1A88E7C8A75676F60
5C67747AA09CAAB6C4C6B895573D3E62899E986E637694B5
B14A607C58ACA6567FB9729CBA806C7AB38B3D8A9ABF8D4A
8192CDAB8289C4C77A6A6FBD976E5892837C556FB9847D83
75B6CC9A8C7295CA9B857143B0B890CBD9E5E7EAEAE9E6E9
EEECECEBEAEAEBEDEBEAE7E3C5BBD1C9CDD4C1ABA06B7E94
8A8CAEC49E8A86644F6060A7689D593E639F594652805941
609D9D56487CA79446526CAD74465F739F764E3F5E6B6DAF
A88356587C8EA39C757C8566596BA89DA9A4AEADB09BA2A4
958CB3AEAFB3ABA8BA94926E483F6F9AA89055557477A3C1
9E6174937FB1764E89A991AEAD667D8CB27B55959BC58E55
7381BD8D85A0D3BC687A55BD7981689879774691AC678D7E
68B7AF74857AA2D3A38D7B59C1BBA4E6DFE9E9E8EBECE6E8
ECEBEAE8E2F2E9E9E9E8EAE3DCCAD9D3D0C9B7829D717584
ABB2C0BCA87C7056576E9AB28582644D51A9794A55A88439
5274AD8549627EA96244639D8E4651629EA66E4548655774
AFBA9466837A81AAADB8A679636B646E8590A19FB0BABAAB
9BA8AFA29B755C646F6B5D555986ACB28F5263465C82B8B0
827589BFBEAA6159955D8FB3746D6583A154738AB2BA5D74
6DABB55F9BC6CA8B7E616BAB806E5E956557518D956D917B
86CE9A6C8A6699CC9A798BA9D4C5CCE4DEEDECE2E6EDE0EA
E9E3DDEBE6EFEDE7E6ECE7E8DEDCDDC8918A8F6383778ABD
C0C1A795775C494F7CADBBA97650665962857E3F659F9F52
365BAA9C6C5566778E3D4054974D54558CA1A2614D565252
90B7B3948C5C617A9AB5B89E725D4E4C504D676E61837F7E
6E7D7E5963544F5155565F8C8BAEAA6F5253625064908E8D
7F5C9DC8B976797FA0689FB15E7388AB6E4163A3C8A7586B
9AC77E679CD0B96777719A6A706F9798777677AF89838C8A
A1C4987F8D7AC6BF807F9CDBD8C7D4E5E9E9DFE5E7EBE3EB
E8E5E9E9E6EEEEE5EAEDEBE8E0DFD09980726C6A8092B3CD
C1B2836F6A5B6E8FB1AFA0826E5C6B64618986496460A693
4F516C6F986E5260858642377A894237516AB9A17158575F
799EB7BAB8975E617579B6BDB29D89635B544A594F4A4353
6D565B475054584E4C7F9BABA19074474E5D6C8FAC9B5368
6865C4C9B9496F947D6FB9914A73B2A648587097BD677094
BBAB558B9AC98F677370A8596D75AD8D8A7385AE7F8A8689
C9C7B0957B94C2A48C88C9DADCD3C9EBEDEEE3E7DFE3E0E6
EAEBEBE9EBEFEBE8EFEDEDF1E5DACA7484A76D6D90B9C9B8
A191766E6679B5BDAF6D55604C5D5C6F5C75987E545473B0
A8736485B6A2564E62A4804C9DA66F517182AAB3B098615C
61638AB7B0BD9B7B5D517792B1B8B8A19B5C475B4540404A
566A6273606F6B5976AAA7817F684C5748446BB9BA985855
7185C1BAAC798D9F6B85AF7C5F70B68D376E85ADBC6A8DAF
C59C54859DAB778973A0715870B8AB859D8E9F9C907C6F9E
D5C8B6828099A99C7FA3CAD7D6D7E3E4EAEEE6DFE3E8DDE2
F1E6E7E9E6F1EEECF2EBE7E8DDA2896AA7D7BEA0C0D1BE89
75856A807AAFB8B683535460504E4E4F4864B6AD633A6283
BA94637BA9B1934E5B88A490B0BBA27783718198A8AF8273
4A455C6365A3B5AD9064464C6289AFB7B99A7A6D7A7A757B
88A0A7A792A7B59E9A907D5E59504F715E649A8F7F655672
9CADA3827F7182BBA9AC73635673B86F54608EB6897A8FB9
B87E6185AE9567859AA354716DB283758EABB5927A7472AB
CDA9A49DB7BEBA937782DAD1D9E2DED1E6E8E6E9E3DCE0E3
F1EBEAE7ECF2F1ECECEEE8E5D9AC7E9DCCDDD9D3CCCCA17A
64757BBABAAF7B837E536A6B8F769F857599BCBCA353516B
A1A87A6A6CA6A8564E728A98A4BBAB585F57766B79ACB09B
5F553A4E537783B7B6A76D3F464A6591B8B6AC9FABB0AAAE
B0B3BAAFB3AA9971615D5555564374ABB0A18164646F5B92
B8AE8D615D576CBBA6937A596AA08D3D6D6CA0B163668DAD
99586182B173666C8B94426B619465858891AD726E6759AB
C8898B8DB0C6B5A195ACD4D3DAE5EADBDEE9DCECE8ECD6DC
EEE8EBE4E6EEEFEAEEEDE8E5DDAED0CFD4D8D8CDAF998877
8183C7B7B87F5D68746C6E8EC1C9CBC6BFB1B2ADA99D6263
89A76A54688BB68C5866607B849AB281534C5753535FB1B7
AC976E6C645658568FB6A881433848666E92936E71947289
A082917B676F6457584E4C51595DAFBD9B8453625F8473AA
906F62663E73AEAB6868846A91B957427686B5A9586889AD
596472AA7C465B7DAC9D606E9A75637A5EA3855C67745DB9
AF729194B7BC9D869EC5D8D8DEEAEAE5E4E7E3E8DCEBE2DC
F2EAEEECEBECE9E9ECECE6EAE6DDDDD8D5D5C7AC92778284
97A3B8887E7A66627DA4B2BDCDCBCCC5A69993899AAB9F58
71ABA6504D6EB5B592645D5F685D85AD93514C454D50769E
B8A4A7AAA96B49484F83B3BA82453A53465F53453F4A404A
5F4847494F6557624952527B9CABB1A26E5960637EB3A06C
6C504D526BAEAB7B5F7A7C9FC9B35C598DA9A75D596EA6AD
597585A750476C9DAD5C6579A8595E5D58AF747B5E6D47B0
7D75759AB0C58D83A6D1DAD7D9E5EBE8E6EBEBEEE9F1E8E4
EFF1EEEBEDECF1EDECEAE9ECE7E6E3CBA88F8B89908F9C89
9FAC8166726A9CB8A2BFBFC0B7A69E8183768E6C5870AAA4
9BB9A9433E5D6C94BA8D725358665688AF8C61683E445671
98A98F8EAAA6958B584683ACB29C765B413E353E44433D37
463B3D4353645C567093A9B3B09C8080645D6E6491B08F65
67607B949EB88E4961755BA3C28B5D6B88C19E45747FB570
5B83B0834C669FA980676585955858579F865C55706D669F
6F626B65BAAE8D8ABBC9D4D0C8DDE9E9E7ECE3EEECECEDEA
EFEDEFEEEFEFE7E8EFECE6EAEBE4E2BE88675D7098A292A2
A0BF8A726B74B9CABDB59E998A896C6B776165775F4E719C
B8BFAF865B444D68B6B2A46C575347669CAFB18E42413E40
4D7A5E3A4E6C7EB09448407BA4B5B79E5D60538690957D6C
8D6C5D537B9AA3AEB8B1A6727666637258657FA0B0827572
8595929CB3996F525B95647F905D7B6BB6BE83516C949E52
5CA3C6805574AA99505F80B67652606ABE76555061609CA7
895D715CB0AA84A3D3E2D8C0B9E0E6E3DDEBEFE8F1F1EFED
EDEFECF1F2EBE9E4EDEFE5E6E7E5D8909993648AC9C795A8
A7C2C8BAB9B0BFC2B0816B866B7A6359629260958D3F434E
738C95B8A87A605C8FB1BCA08165595979B2C4B29385643D
49608A483A3F4886997F395364A7B0B1A99EA2B3B7B9B6A9
AAABA8A1A3AEA9AB9D7C553B5D7776837F9BB083676F748A
A2745C7DC55E4E6662A1B19A485E899EB9955462808A6764
6B95A95B5D67AF795B6A9DA0636294B1A96370747694ADA6
906B5F65C28986A2CFDADBCCDADFDFE3E2E5E9E4ECF2EAEC
ECEFF7F3F2ECEBE9EDEAE9E7E3E7DB8888C28EAE9EC2AC9B
B9CFC8BEBA908D93836D687D7B93AB97B8C5B7BEB6797357
536877ABAAB786525689C8C2BA953B38457DB3AEBAB79D6D
749CA09A824442475EA45441446279659C9EA7AAA1A89377
82657475576C6C756A50434147937CBEBCBA9E685764A7B7
9D59739EB55F5D6DA4BFC49B426E84C2B15660748A733F61
8AB55E63657CA4586180B2886F73B7C2B3898690A0B9B99F
8F6F7D9EA6809FADCEDED6CAE9DDDCE4E5E8E8E9EFECE5E0
EBEDEFEEF5F2F1EAECF1EDF1EBE8DFCFBBAAB9C8A89DBC9D
BDBFA2948F7955635E767BB5B9CAC4B9BCCDC7C1C1BDB89D
6C6E867D8EB8A48C516182A4B1B07C433E525B8AB6B6A18D
61655EAEB294684956BCA05D3E36484F5B646C56614C4745
4448434438473F474D4258578AB69CAEBDB06F6C908694A8
759291AD8E6A5B97C8B3B0956E86AAB27D6354759E595D80
94A25B6389A661506473AE716B9CBBBCA68592B2C8A98195
9FB3ACAD7D9FBACFD0DAC0D4EBEAE9E4EDEDEDEDF2E6E6E9
ECF4F6F3F3F6EDEBEAEEECECEAE5E6DADAD3D8D0BBC89F8D
8E927F8677745F6E8A7A8AB9AA98AD8E9BBEBEACB6B5B0A1
6E6753686A80B3B6834F4558A4ACA68D3E50554E9FAFA748
453B4A668EABA78C97BFC1B6933F3F51544E513F423D3937
4549373D42477F888A97A3A9BFBAAA989F6E7477A8958C9F
95BDB9956E71B0B7B18E8C8FB1B1B58256666699A0525968
9A596E79AF82465B6E8B67657E9BB38A7A6C95CBBF8F7789
A6CAB2A37A89CBDDD8D6D5E6E3E6EAE9E7EDF1EEECE8CFE8
EEEEF1F5F3F2EEEAF1F2EAECE8E9E0D8CFAFB9CAAB9F9A7F
638664717F768286B8A9B39F8F8A62758684986B65747EBC
B69F6E535E5586C1B1986C3B637F98B69776433A56999D6E
3E3D454A536F947F8285A3ADB8914C4D4C51554849473A52
918F6E546383A1AEB5AFB3B29C856B5355467E9CA8648890
AFBEA96F6895BEB66353728BBAC5AF385163959155657294
7A6B628689584C556680576A89AF7E657084A8B18D65869A
B9BEA16D8BA2D1D7D6D5E9E5DFE9ECF3E5EEEEEBEAECE2E2
F1ECF2F6F1EDF4EDEBEFEAECE9E7DDCEB38089A492758084
72838BA2B7A89EB1B6BBA2A4A093615E7F4E4E47404C5683
8497A37C674F5C8CA8AE8D3D5468729FB79E4E443F5F6B85
83593F51564E4D474A4D6D709DAE9EA1A09DAC9997A19A9F
AFABABA39AA7A39584686E6C565B4E576B769EB68F6F8FB0
C1A9737A90A7B27A4153688DCDC0AF715CA2A97342719CAF
5F65749A745C5C63865E5D5C83A048517688A69A6E6E7F7D
C8BB867E92CAD1C8B6BADDE3EBEAF3F2E6EDEBEAEFEFE8EC
F6F2EBF8F1EEF2EBE9ECEEEAE9E7E0C56F897E84B3948593
92BEBFAEC2C8C1A38C9F98A9A7778F9A99977B6A5844404C
598094AA9C84525E659FA6663D475781A2989C8265404C53
8AA69494906A4D42484D5D535C7C91AAB7B8AEB3A6AEB5B2
9F988C6B4F65614D4D3E40414767619BAFBDB88F7771A2BE
A69172799AB17D55454F99A2929F77A9B3B18D565860A371
5960A88B5E5375887B5B5C569C81475E7B89A96B5B667C8E
D08B578DBAD4DBCAB8CDD9D8E3E7F2EEE8EEE9ECEBF1E6E9
F3F2EDEFEBECF7F1EEECE6E7E6E7E6C26D7784BECDBDB6B3
BFB6CECDD1C9BCA97281977697657693958FA38FAD8F774A
577975799AB18966505D9294514E4A57535E70A2915B4050
6C709EACB1A34E524A454F403D4F56757E8C8D756F898290
705D5E49434C384A5E5244557E9CA2B0AFA09280738EBCA1
7C81A3B5BC977E68548BB1637E8C6686BC986D5D659F8963
7295B1676065A49C5B75608C985039507DADA0574F6D91C2
BC6864A0B2DECEAAC1D5E6E4E3E7EBECECF2ECEDE8E5E8EA
F5F1F1F3EFEAF6ECF1F5E9EEEFE8E9D4A4ABD0D4DDD7D4D8
D4CDD0BAC0BBB380687777637F636E756F81838AA6B0AF94
714E5C4F66A9B8996D5572B39E764F3B3E424870AE9E604D
52465271ACB19295988F8D664A5342434261585055766257
493836353A35498BA89A84A6A7BFAC925E7C5F626DAC806B
8F99BBB5A67B807A63BCB9816C8095998A646873AD986572
9CA683606E6FB77E58676AA0664C46497FAD8668656FA4B0
98637B9EBCD09D90D5D0CFDDE5E9E5E3EAE9EFEADDDFD6E8
F5F4F4F4F1ECF2F1F1F1EAE9EEE8E8DED5DCDCDDDAD5D7D5
CAC1A783798B7F636C5B62636853585C616F756A8583A7A3
9A6A584A5C8B9395A9A6AEBDBAB298625F66615F6FAFAA7C
59493E506E825B797AA6ADA497756445484D40636F676F68
8C88817B7B859FA9A7928B797C79666847525B5C649F604C
77CCBB6F7571675D76C5C49D808FBCAC5E5E7F95B074579C
B091635363A49974526A9286424A5866999755676384B9A0
72668292C4BF9090E2D3D4D1EBE5E9E4E8E6E8DBE2E3DBDB
F1EFF5EFEEEDEAEBF1F1E8EBEBE8E7DEDCDDD3D3ADB3C5BF
9495817C7371757A86A99E95A281534A7A72915D5B80898A
A8B09E6F705763668BA094BABFAFC4B6AF74444568A4A7AD
A67F55414F5043463F639588ADB7AF9A864848979894A2A8
AB99989A9F90817761525B414456584C485891A7ADAF7576
A7B7A84A515273B1C1B5837473A9C8886E60AFB1847B8AAC
A160556D90916761588D8972595E6484A26B65646588BFA7
728071C6CAA681AED4D6CBD9E6E6DBE5EDE4E2E2E4EAE6DB
F2EEF4EEF1EDF6ECF1F2E9EAE7EAE9E2E2D9A8B19A7F8B94
747D89727B8E92A3BFC4C6C0ADA7A995A299AC77575E7674
9FA197AE9F767C6864766786B186B0B8BDB173585D6C6377
ACA98D795B53515E41466050557AB1BCAE927E75495E5E74
6E6F5C5B6545404443405257587080676BA3A9C2BEB3A7A4
94728C5C7C8C91BCB2843D4E8BC2A06D9880B375647FA97F
5C5E6D9B9B6F5D6C84916759626794A2836570807BA4AB72
6A799ECBBBAF85C9DBE2DCDEDFDFE6E3E9ECEADEE0E9E8E6
EDF2F4F1EDEEF6EEEFF1ECEAE7ECE6E5E4D79CA3987A8384
6E9DB68CA8C2BA6AC4A1BCBA8573BA9F9C8CA1A4774D516F
77616384B0B59F9E6F61496681829188B3BBB6A15B454C4A
8CAA9EAAAA8F655544494541464E6197ABBFA86E4A424054
4250413D413E505C7D72738088B8BEB3B2B5B3C6BF9C7B77
6E4A517CB9C2AD9F726C6393C1CB7E7DB1A19F666F828A59
646690A2604F586EA78162585E98996452536D83959E746D
6173B3AC93ABAEB6D6DBDEE5DED5E5E5E6EEE5E3E6EAEAE9
EFEEF7F3F2EFEFECF1EDECF1EAEBE4E6E4DDD1AF8DBABDA3
94C8D8C8C9CEC9A89C8CA0AF4A4F6A6879666B6293835F50
54555C567CAEA7C2B28B4E3D4C68556388A0AEB1A27C554A
4F717589A0B5AB946E5E50403D504D5D71A1AD92817D7C66
5B6673627F8A9FB5A9AAA8B6B3B5B3BF9C868D817B6D5864
7B797389C79E73755F6C91CACFC4B69B8E7D6D8AAF7F5D61
84A69E77575D6D95AA6C675B7FAA815C4D5983AA9571685F
65908C6D7B7DA2DAE0E3E6E6E2DFE2E6E2E0DED7EAE4E6EA
F4F1F1FFEBEBF1ECEDEBE9ECE8E9EDE6E9E4E7D9D0CDDAD5
C8D6DDD6CCC7C79C569BC4BD5E47684E5F4641475FB39B58
40355D5C4E6566A3B3C2A97B454634394C566577A1AB9A5E
463849535E9799ABB8B1947F6B564340466B6D5874A09A9D
9AA9AFA7ABAAAEADA8987C948D86747F5D5666777B7666A7
AAA8B5AE95556D636492CACCCEC9AA5D6E6673A28458596F
9D9D79636272988E6768677C99AB6F665D66A8B7635B6E72
8FA36A6193C7CAD3DDE3E4E5E3E9E5D8E0EBDEDCE2EEE8E8
F2F3EFF6F2ECEBEAEDECE8EDECEAEAE7E7E8E8DED9DDD7DB
D5D5D1BFAD9FB3B788BBBAB79C98ABAEAB765F3D61BFBDAA
7B3B374C453E4D746FA9C5B898835F363A41484E5997B6A1
76393741535E4E86AEC1B2BDBBA98A7D7F7C7656424D5C76
797A8E907B5E5C5767645C5B565268595455709F9BBEBBCB
B7B6AB845F4C585B91C6C4C1C7B2754958668C7C646C7597
8A6E50636C98A3754A5560A0AE726F62668AA3855557568D
ACA46C7AAAC9D5CFD6DCD5D7E0DFDED9E3D8E6E4E0E5E4EA
EBEDE8EDF3EEF6EDEBEDECEEEBE7E7EAE9EAE4E4DCC5BCCF
D4B2A76F5F8F80896BA38C897A898CAB9B7A7491AEC1C9C0
B395797C605953685575A9C1B8B7A37E634E403F42517393
8D9F624054453B53759CB6B5B8B1B1BBBAB5A98675513B3D
49504D4E46423E4443474C4651495952506AA2CBC5C8C7B8
B07E726A6E839CAEB3B9A76E977B67626888AF504D81A78B
625E59668CAD72604E84A6AD9A667D6C7CAE9F6F5974A4BD
97798D7FAFD6DBDBD5DBDAD3D6DDDAE4E7E4E6E6D7E5DFE4
EEEBECF4ECEFEAECEDEBECEFEAE5E8E4E7ECE6E7D59385C4
BA858462899B72618A75666B656281765D535C9FAE93A7B5
B5B0B3BA9F8C58665E5F8D8095AFB6B8A06B38493B3F5360
519DA0654C3938354C5B7B6273888BAAB3B1AAABB59E6F71
61494C3D334039404845506095918298939CC2CAC4BBB875
8689766EBDC8C2C8BDA26C62816353628CC1C07A67957C63
62556B86BA8A63656EA2A0885C5D5E75B2AB7359638BBFAA
53576F8FD4DED9BDCDD9DCCDDADCE5EAE8E3DFCDE8E9EBEB
EDECEBEDF3EAEEEFEDEEE8EAE8E7E8E2E8E8E8E5CA6F91BD
93639185B39368587B6576636B6E906646424F7C795C7B88
849A9C9AB6B5A47142405755557497B39AA89054514C403B
3A5CB8A37C40443831333E3E40474E526B8C797C99ABA7A9
A49A9584818C92909B9DB2C4C6BCB1B8B3B3AFAE887F8C67
626191A4CBC1B6AD95926A4E56466A84ABB9AD9B83665F55
757D9EB8AB7061559BAD986F565C739E947255506EA6A08D
584C91CDD4D5BE98C1D9BBD6E5EBE9E7E5E9E8DDE8EEE6E7
F1F2EEF2F6EEF1ECEAEDECF1E7E8E6E5E5E8E7E2CC7CAED0
ADA4A0C6C48E6866686A7D9095BBBB9E60615D6E6647666A
4E58635E75C0BD9E6B3D4C565B6E74976D92A497958F7148
3A55BFC5B2928F635164667261443D3A465D49425F7D9EA4
B1BAB0BEC2B6B2BDBFBEC9C0B6B09798959574825C6B6573
6F6688C6C6B173747E6E5C5D6E61A0A1B29498806666625E
949E8C9D7A5B658EB3A96F5B466BB7B17966686BB29C7984
6474BEDDD8AF9181D4D9CDCEDFE3DCEAE8EBE8DFEBF2E2E2
F2F5F1EFF4F3F5EEEFF1E8EDE9E8E6E7E4ECE7E2DCCDD1DB
D3C8AECDCD9D9CB893A885ABBCC9B68E76A3B3A385505642
474851597CA6B5AAA86640454C5D747F585D6D95ACA0AF9C
84A7ABB7BEBCB1AC9CAFA9A8A3A08C6D537B825B4239548A
849F9A9D9A9E9DADB1929B9A796660665B544A545B7A8AC1
B5A198B58F7B50625D5F6483988ACBC69C666471656E9389
9C855F5D5F5C6EA7A87B686165ACB79B66606D819D755C91
8DC0CAD8D19E8CB5D4D9D6DADDDED5E3E6EAE9E3E9ECE3E5
F3F1F1F1F3F2EFF1F1F3EBEFEDE9E7E4E5E6E4E6DFDCD4D6
D9DBD7CFCC9C91D4CABDAF86A8A3886680B1CB99BAB3ADA2
9C89655D51757C7191AE8B6153454D66574C586482659A9F
7688A09AB7A8B2ACC2C9A8749892B5B7A4AEB6A76C56474A
425B5B6050556A77717A6C6A556062737F6C487986A9C2C7
C6B87A8C57606F6B566D628CBFBDC09760686B6A799B9B8E
665B53706A7699AC7064647CA3AC6B748A7DA6988A75739A
B8D3C7AE9D9EB0DBE2DBDBD5DFE5DFDFE0DFE7E3DFE5D3E7
F2EFEAF5EFF4F2EEEFEBEEF4EDEDE8E7E9EAE2E4E2DACEA8
C0CDD6C6BCC2B9CDCCBEB09074656A678AAEBCA9B2C2C0BF
BEB0AC9E6E3D4D3A51B5B99F8D4A3534363541353943595C
465476676F627188BAC78B4C4F5D799C95B1ADAEAC9C774E
4D4A3A3F51555C5D4F47765B54727CB2BBC1A3C2C9C7C7BE
ACA1576E79638FB7B7ACB7C4C1B39361605C536DAEAD9459
5361506B7A9AAC8456627195A481657795B5AF7463776E93
C8C199798AA7C1D3E3E0DBDBE0DADEDEE3E6EAEFE9F4E6EE
F5F3F1F4F3EFEDEFEDF1EEF6EDE9ECEAEBE8E7E0DEDAC08B
8E8DBB857DABB3B8B5A4ABB99757435160648C817EBBC4A9
A2B1C0BEAE82563F44B7C1BBAAA164494350433B37393333
38444749373E495788B09777454F53555864727172A0A7A8
A476494670A4A375717C9FA19CAEBDC1CAC7C1C8BAAA947D
83624365A1B2C7C6CBC5D4CFBF825B6B5F7488A3A19A535F
625D4C82A1AD816159557C9E7F6F6F98C0B2935C5C6475B9
B390736E8ACFCED9DDDDDADEE3E4E2E5DCE9E9EBEBEEE5EA
F3EFF3F2F1F1ECEBECEBEDF1F2F2EAE9E7E2E3E5DCDCA08D
8A648A798F66676F6C7D8DC1A784686B5D4F61684F718877
7FA78DB5BDB09C9499C18F9CA1AAB1A89C9C755858685643
36443F503430363F475553677F857C845D454143445466A9
BBB0AFAFB0B5C2B8B7C1B9C0C6CDC5C1B9AF9E8B5F585762
7E755F8CBDC8C6C5C8BDB7A69E54485E83ADA48D65657071
5E5C84A6A0A26862798F9F6F607089C0BA8C7A6366979DAB
8072857FBAC7D5DDDFE5DFE6DEE5E4DFD9EBE9ECE8ECE8E5
F1EEEEF3F2F2EEEBF2EEEFF1F1EFEDECEBF1E3E4E8DEAAB2
B0689DACA1535C7A706E848F7F60A9AF907D6A745C4D465E
5D77828D928F8C7DA6AF655E668494A9B2B1A897A6B2958E
798F909E57474C403B3B36445F97B3BBA3865F6A81675656
6098C0C4B3C1BFBFBEC7C4B0B3AE948F6E815D5445415B95
C1C1B5C9D6CFC6BEBBB2A765685F6674B1B2566561666B70
6688B7A2987D717BA9A68651587DB0B9926F616597B5A474
6C7C7F9BD5CFDBDDD9E6E5E6E6E9E0E0E3EDE5EBE6E5E7E3
F2F2F2F4EFF2F2ECF2F1F3F5F1E9EEECECECE6EDEAE6D9D4
CABBC2C5A25493927492645E5D4D678CB8BEB3998B6E5E63
715859504D7776746CAC5D425C656D748B86765D9CB3AEB3
B0ADADABA3A99A9A7067575E4D5154828BAAA3A7AAA69861
545D8CA189AAA69CADA79A7F86819283637C555F8985ACBC
CDD0C1BBC2B873747F886D5C504F7FC2C48E55686690BCB8
B5BEB28F758064B3A4686F6B9AADA8927B748DABAFA27D67
689DBFC7D9C8E2DCE5E7E4EAEAE5E0E2E7E5DFE6E8E9DCE8
F6EFF4F6F3EFF4EFF1EFEEF1E8EAEEEBE7EDECEBE6E4DBDD
DDCAD4D7B9899EBAA2B37A607D50616EB5C9C5C0A0B6AEA6
955446494459595D70A9824D5453647055566257599D827B
A8797BB1ABB8ACBEAB958A8B705F564644516C7D8291A49B
775E65755D666B656F77797982B0B8AFA9A29DA0BEC2BCC1
C0C88A76B59D457F5C57536B7F8EB6C9C0938EAFB3C5D3D0
CBBDAA7A857A9B8970616EA6BA95706F809CAFB09B827A84
ABB9C9CDD8D4DCDEDBE6E0EEE9EBDEE7DDE3DCE4EAE4E5EB
F4F1F4F6F2EEF2F2EAF4EFF6EDEEF4EAECE8E7E0E8E8DFD6
C983B1D4C8C7C9CAC9C8AA6C7358485B8EB19DAEB6BCBDC2
C091767262524F5B7B85A9914D4A5D583E3B534C3D424343
63544651638892B1BBADA9B7B2AFA08B845E4F423A52556F
AC8866403F3B3E5741575B869CC6CAC1C1C5C5C2BFA7AC74
918C667E9861668A756585BBC6C7D0CAC8C8BBC0CDC8D0CC
BBA1AB939BA89A60A49EACB9AA70636D7FBDBF8481728FAE
C6CCD5D1BAC2DCD9CEC2DBE8EAECE9DCDCE4E5ECEBE8DDE9
F4F2F4F3F2F1F1F1F1F1EBF2F3F1F1EEEDEBE7E8E7DDDECF
956A8BA79EB9BECACFC8BCA3A08D4546526262A1ADC2B5C7
C5B1A2BBAA7B6C627A5E8B889D9960484D3F3D4540473B36
3A3835374C4565726E778098B0B2B5BDBCAD8B6C553A4C66
BEADB19384647A7A7A9497B8C7CAC19F899FA3AB9061775C
706862949577B0CDC0C5C4CBC9CAC5C8C9B7BFC2C0B5AF9A
99A29385BCB2B770B8C2BFB77D6C857DADAD74A08293B7BA
D1CFC5AC5E7DC9D5C2D7E4E0E9E7E5D7DCE3E2E7ECE6E3E7
F1F1F5F7F5EEEEEEF1F2EAF5F3EDF1E9E8EAE9E9E8E4DAD1
6B889C8276809FA8869EA093BBA85D4A466163616B8C85BA
AA9C95BEB2ADB1A79954594F93AFA66D81674840667E706A
59553F494565485B3D394164867B9CAFC6BFB3B8A784ACB7
C2BEBEC4BBBCBCB6BCB8CCBEC6CDAE6A5152616761606B62
648092C0C6C2C2CECDC5B2B6AEBC83A6C07586889CA28D8D
81868DA3D3C8CDBABDB79191727297B68D81758C9DBEB2A8
B3AEA394A47ACBC8D3E4EAE7E7EAEBE8E7EAECEEF5E8EADC
E8F5F7F6F5EDF4EBF2F1E7EEEDEDECE4F2EFECE9E6E5DCCC
84C1C0A0835895846C635F67A6C7AC654E6A5D71645E628A
8A8C92858F8BB2C1AAA277567BB1BBA6ADA78E8AA9AAABA1
9EA1907D93A3826E54353E3E42435270A2A2A7BAB7B8C4BC
C5B8C5C7CCC7C1BEC1C5C9C2C9CEBC8D6159747C6E7F86A8
B3BEC8CBD5C9C6C2BF8C6F6A899A667E996A686D7C7486AF
9C8BC0D3D4C9CDC7AD89778991A1AF9A7D90A1B0A9978688
7E889B8CAAB2D5D6C8D3DDE7ECEEECEDE8ECECE8F2F7E7E5
EBF2F6F2F5EFF1EDEDECE6E5ECF1F3E3E8EAE9EDEDE7E0D9
C6D4D4C8A08B807B4E4C675F91C1A4A78F8F9E6F646E5858
5060685852568AAC8AB1B1A09DB7B8A6ABA98C748CAFA397
998FADB2B7BAB6AFA68E928B5C4D5141554858847DA09BAB
9BA4A9B3BDB8B7B6A9BDB7BDBAC9C6C7ACABB2C7BABDBDC6
C9CDCDC4C6B7AB917E6661647767667E555C7191B1B5ABCE
C6BDD6D6C9C0B8945B526B74B0B2AB9362B2C0A47163687B
8280A3A2DEDBD9DDDFE2EAEDECE9F1EAE5E6EFE9F3E9E2EA
EAF4F1F4F4EFF2EEEEEDEDE8EDEBEAE2EBEEE7EBF1E3DED7
AFBCD6C98198B2B7703F5660A87E5E70B181B0B3607F766F
5742454043446A6F64637B657080A399737C74444F5C6E6C
606184918C9AA0B3B7AAA9A4ABA39E756556545F53687A58
565C617389766F7780828F8082AFB3C0C4B7B7C5C7C4C7C9
C6C1BA917F8D6D65605E725F7294768676869191B2CBB7CE
CCCAC2C0AD7D70684C637AA9BAAA989983B0BCA26D6C726B
A6BBBDC7DDDFDDD5E3EBEAE8E5EFEDEADFEEEFE5E6E9EBEB
EBEFF1F1F1EEECECF3F2EBEEF1EFF2EBF1F4E8E9EDE3E0C7
8A86B9BBA9C5C8D4AB6E7179AF74626BBA9BA0BC98687A7E
8D60585E54555255553F554D6D56616C5C4753413E415052
4040443E46465B9D92A4A19DAAA4ABA9A4A9A097806E583F
3F3851505344514945575E5C675D7D849AA1C9C5C1B6AD98
A7AA7E59797A7C70767FA6A0B3BFB7A9AEA47E8F8D9EC5C4
B5BB88726F626C6C7176A4C0C5A376A0A7727C977E64ADA6
BFBFC6D5D4D0E8EAEEE8E4DBE2EEDED5E4EEEFECECEFE9ED
F1EEF5F7EBEDF1F4F5F1ECEFF3F1F2EBECF1E7E5EDE9DBB2
7A75AC8CB0C4CACAC5B3BFC2BA67729EC5B2AEB6BEB0ACA7
98726A5D6060583D5940404C5B4F4948543839323F515D40
3B362F31343440725D67625889A3A6A3AEB1ADB6ABA9A27F
37454A5B475E704541516691A78068457572BDC09C758483
7B5F7762728FA8AFB3B6BEB9AAB5AEB0BE9444778FA4B7AF
8488684D5D595D74ACABC7C1A88B6490846B679EA2B2C5C0
C0B0B6C7CFCDE2E9E6DADFDADBECE3E4DBEEE8E4E8F1E9E8
F2F2F9F5EFEDF5F1F2F4EFF6F1F2F1E7EFEDEFEDE9E5DEB7
898CAF886C8EB79DA9A7B5BDBD7B6898AAA9808597B1AAA2
8E7197857A7B6E616C6E5B3F504A344968454D4F85B8A17B
8383808051393E47755845413F65658598A6A6A7B5B8B1B8
998F929E92B2AE9D94ACBABEC0C6B39BBCB2B78A6E6A6E76
7C7D8D8CBBBFB1AB9E889F6F7E838594909C8595B7A8946D
57716B67475F6198BDBCAC8067708093A082ADC8C1BFBAC5
B9AF9FBBB2CAE7EAEBE7DBE0EBE3E5E4E5EDEFE2E6E8E6EA
F2F2F2F3EEEEEDF2F3F1F3FAF1EAEEEFEDE5EFEDEAEDE5B6
79C5CD8E5B677E6F6C5B60769A94607E947A55686E76705E
77717D91A6BBABA38BAB9F647C72728EA79A949FB1C4C5B6
B5B7B3B9B5918397B8AF978B4E50403B4967809297A6ADB9
BEB9B7BBC8C4BEBABBC7CBCBCDC5BAAFACA2A1666574A295
7FAFC2BCCBBDAB8164686A66766A838085C1C7B09386816E
64777D6C89B6BAB7B6BC8C5D60679EBDBEBEC6CCC8C1B0B0
A99D93B5A6BAE8EDEBE7E5E9E3E3DCE0E9ECEEE9E6F3ECF2
F6F6F4F3F3F3F4F1F1EEEFF4EEEDEDEEF1EDECEFE8ECEADE
C5D5DEC580A18C5F615253556B7F5D6766724F58604E7B48
4F59505B8DAAB3B5BFBFBA9EB5B8B0B7B5C2B7A7B9C2C1C6
B5BAB8BFBDB7ABB9BDBCAFB9A09D807C6C674C465065899C
AEA3A8AAA8B3B79EACBFBDBBB6A989777C819FB0A9AABCC7
BBB7BDAA889E67536875797589B5B0A7A8A2916B89737489
8499A994ABB7BCAA94915F665676A0ADC6BDC7BDBABE958C
A27F91B7C4CBE0EBE7E8E3ECE0D9DDE3E8EBF4DEECECE4EF
F3F1F3F6F6F5F4F6F4F2EDF2EEF3EDE6F2F5E9EEEEEAE6E6
E2DCDDCAADD3C6839057576B68985E5474705F5572426D47
42535144717D8997C1BCC6BFBBBFAEB0BBB8ACA8AD9F9BA9
8F85738497929492A8B5AFB9B8AFB0AAB5A98F67424E4656
70686C5C6B7C6A527C9D8D918895A19E9EB0C6CCC6BECBC2
A4736C6F6A6062767998A9B5A4C7C0B282736C7191996EBA
BBC0C1CDCFC6AF6D656168726385ABB9B3B5BDB37C8A8C8D
94867EB9D0D9E9E2E3DFE6E7E2DCDFE7EAE9F1DDE8EADDE7
F3F2F7EFF4EAF1EFEFEDEEF1EEEDECE6EBECE9E7EAE8E7E5
DED1D8D4CBD0D4CC867AA1A48EC28A4F61765C946F565549
4D485D3D404C4F508AB1AE99A67F8E9981846F6C7964666F
4A495057514345415F7D857B94889FA2B9B7BCA7A3A67151
5480583E463E32344866656E988D9ECAB6C2BFC9C0B1B894
58546268A0A18DADBBBFB9B0928FAC94736C6D828EB0AFC5
CFCECBCED4CA794F5D6C606BB6B2BEB0859D9A8E5B608981
AEA1C6D4D4DEE2D4D5E6EBE8E4E5EADFE6E7EBE4F2F2E0E8
EEF4F2F1F8EBEBEDEDF8EEF7EDF2EBECEBEFE5E9E5E0E2D6
D9B7A6D3C6A6AACABBAEC4C4BCC9B898A49CA9B2A97B5862
8453815C3D455E4955616A5E5148506B575043383D463835
3743414C675132373E3947404840565E807195B8BEC6BCA6
AAB5AAA79A7A4D444A4E80A1BEB7AEC1AC8186A9816A7B71
82A7AFB8BEB5C0C4C1BE9F7F5C70807698AC9AB0C0CBCCBD
C9CBBD9AB0B8685B65AE949DD0BBB893858972928C758AA6
A9BBE3DDCDD1E0E2E6E5EAEAE7DDE9E9E8F6F2F1F5F2E5E8
F3F6F6F3F6EEF2EBEFF5EDF2F1F4EDECEEECE9EBE8DFD3B9
A2A874A3A9A19790BCAFBCCCD1C9C7BE9FAE9DA6B9B5B192
B29CBA92363E4F5650563D404542384A5B4A55605C585D42
344D7C8CB9A26B719A6B7E624339443A3B4F6C9DA8C2C5B6
BFBDB9BCBEBDACA6B5ACB9C0C9CCCCC05956656554656775
99C7C4C7CBC1B58BA39F6173617E7982C4C1CFCFC2CBC7BE
B5B28C6B8089726390C7C0C7C28A8B886172718398C2C6C1
CBCCDFD1C2D5DFE4EBEBDEE6E7E3EBEDECF6F4EFEDEFE3F1
ECF1F6F4F6F3EFEEF5EFEFECF1F4F2EAEDECE6EAE9E5C183
7D8C587F938E847E898FA4AF9CBBA6C7B1C09595A1BBBBB7
C4B9C09F5B4D53594C43476B6D644D839F9895B0AFB1A68A
7785ABB6C2C9C1B9BCBEA6A08F799B7375764F5065777F91
ABACC1BCB5B8B9B0C7C0D1BBD4D4CEC98F7A859E85AB9DBD
B7C6C8CAC59C735E759F8186ADB7B8A9C7D0C7C5BD947794
AD8375768B919A7B9CBFD6CAAA74717674606D95AACAD0DA
CFD1D0BCAADDE3E6EAE6E4E4DFEFF2F2EAF2F1EBE9EDE8E9
EFF8F4EFF3EFEDE8ECF3EEF2F2F5F2ECEBF1ECEAEAE4D59E
8A975B6C635C52737D646D66778D72909F86937D7299ADBA
B6ADBDB2A08C9392607089B3ACACA3B2B3BBC0B7B6B1AAB0
AEB5ABB6BAB8B6BEBDAFA8ABA8B9C5BFB7A09379746D4354
6375888A8693ABB0C1BFBFA7BFCBC1C1BCBBB9C7C6BEBFC1
B3988C98A279609F66C2C5B9C8C5C7BFC4C2BAC49F407067
77749898BCCAC49A6598CDBD826260628F6B9EBDB0ABD4D7
DDD4B1B0D9E0E4E9EAE9EEE8E9F3F7F6F2F1F3DCEEF7EDEF
F1F7EFEEEEEDEEEAEFF1EAF7EDF4EDEEEEEDEEE9EBDFD6D3
B8AEA46F656A734F745F5C4E5B5F5E5B8858605157707E81
71617D856E6A71AA9CA7BEC2BBB1B1B09DB1B5AD98928188
9089767973869BA2A3948D92B3B8B7CBBEB3C0C6BDAB858D
514E4D664F5E656777908B707B9DA6A4A4B3C7C7C5C5C284
686C686B8876B1CBC8CACECCCDCACAB7BEB382766E4C7A6D
6285A3B2CAD1C57F6B8DBC7660645665829FC0C6B9B5C4D3
D7C88D95EBE8EDE9E6E8F1EFECF3F5F2EBF4F4E2E9F3EAEF
F1FDEFEAEEEAF2EFF5F6EDF4EEEFECE7EDEAEEEDEBE9E2E7
D9DBC8A2BB95B5819795A079867C61586E445B4A5F56765C
61524D4C435F515E9480849EA1798F70637F7C73575D4F4F
5250485C4D4F4A62565242546B8AB5B8ABB6C1BFC2C6B7B1
AEA16C716554533942607253888D586A6079AD8591B0B26D
887A706DC2C7D5D3D9CDD0CBC9BEB992836D5E6E6F8AA2B2
A398C8D0CCD7C8827CA6A15F665D647EB9B8BDCDD0CAC0C1
D7CEBBCFDFDBEDECEDE8EBEAE9F3F4F5EFF2EEE9E8F1EDEE
F1F4F2EEEFF3F2EEEFF3F2F2EDF2EAE3EDEDECEFEFEDEAE4
DEDBCEC1BECDC7BEBFBBBDBDB9B6B3A97B455052655C6167
554D50454A484E4E61708166584D5B64535E6C5E50465457
45604D7F5D59533737563938385D816E86A494A6BCC6BBB3
CABDB7BBAFA6955F424A775194AB76846A475B607DA69D93
BEAFAAB1CDCDCED6CFC9CBA87F8E85646064828CA6BDBECB
C1B3B7C2BDCFC79F9B9E766163606CBDB0A294C0CAD0C0B1
ACDDD7E4E2E6E5E9E8ECEBEEF2F4E9E5EFF2F5EFEDFCEAEF
F2F5F1F1F5F4F9F5EEF1F2EDF2EEE9E5EAF1EEEEEDEBE5E0
DBC790ABA8CCB171A8C8BEBF8EB0C2B2B29167919792B3B5
857F52465D5846454D4A505E4C42424438444E958550919B
9EB0A9B0B6A89F718CA890734C54555460593F52839AB6C6
C2CAC4CFC2CDC1B1ADA4B5A2C2C9B8C5AF7577707BB6A3B8
C7C8D0D0D5C2B3B1AC86B16E51635E816075B8BFD5CFD3CA
BE998989A4D1C0B09D74796F8A92ADB78E7B89B0C7A4849F
A8E3E6E8E7DDDEDEE5E9E0ECF4F1ECE5EAF3F4F2F9F3E3ED
F2F4F5F2F7F7F5F1F1F3EEEEF1EDEDE6E9F4ECF1F1ECDCDD
D5B17583D1C2A6A1A4BBA9938256987F7EA09AA0856EB5C9
C2BF9982BCA36E61734D404A454848677B5F5FB8B2A9ACC5
C4CBC0B9C4BDBEBDBECAC9BDB9B2A7A2A07C51523A577D93
A9B5C1CECCC9D3D5C4AFD4D5D8D8C7C2C8C5CFC6BFC2C6D1
C9D5D7CACFBA615966538559735B7DA762ACD6CAD5CBBF93
646E7E8F8CC1C48A976B7093ACB6AEA9677F95C1B67E92B5
CDD6DDE4E4E3E3DFE4EBE5F2EEF3EBEEEDF1EBEEF1F4E8EA
F6F2EFEDF5F2EFF2F5ECECF1F3F4F5EDE6E5EAEEEDE7C0AF
BBC28B9FD6BB7E55716497856A6F8E604F6264857A82C0C1
D1CECACDCECCB7A7B1A490A394835D81C5B9BBC8BFC5BECB
D0CAC0BACFC4C7CAC8C8BCC4C6BCC5CAB9B1B09752464254
6B6293C1C7CBCDBFC6CECFD5D1C6C7C7D6D4D8CBCDC7CDD4
D4CFCE97988F4C5D5F6366868584B7B5B1C4CDC7CFB5704E
62828AAB95A27D747B76AFB6A08C899B7089B3B3AAA6ABC9
DCD4D1DBE5E2E6E0ECEDEFECEBF2E6EFF5F5F4F2EEF6E4EA
F6EEEEEBF1F6EEEBF2F3F3EFF1F1EDECE7E5E0EDEBE0C89E
9ED0C5BEB9AC8360603B56795D76AF754C5372766374BBC1
CDD1D3D6D4CB987FC6C9C6C7BDB7B5C2CAC7CAC5CBCDCEC6
C7BDBAB6B7B2C0CECDC9CACACDCED3D1C9C1B5B8A491656C
343955A9CAD3B273B2D7DBD9B790B1C2CAD3D3CDC7C2CDC2
BAB5B757515B49635D5F55A1C7B2C9BFC2CBA1A4C7AD5561
6EBAC1BA8F617D857AA9B29160759FB095AD976FACB0C2D1
C9D5D3DCDDE2E7E9EEECEFF1EFF1F3F5EFF4F5EEF1F2EEED
F5EFF5F3F8F9EEF1F7F3F4F7EDECF2E5EAEEEDEEE8DFD692
998DAD929376865F7F685483886BA471617491565E99C5B7
B8C4C9BDC2B375599AC5CBC2BDC1BCBEB09FA795ABB6B0B8
B19D7C756A6375BBB1B5BEC5B9CCCAD1C9BBCBC5CABFBDA8
5E3E67B6C7CB7F3770D0D7CCC48F6E7291BAC2DAA6ACC8A3
516F8942535F76B7837AA2A2BCCAC9C4D4C05680CAAF5572
92D1C78D766681A2BEC5B9765472B0BCAD6D7072A9B7C8D0
D3E4E7E4DCE2E4E4F3E9F2EFECF3F2EFF6F3EDF1EFF3F1E7
F2F2FAF1FCFBF5F5F2F2EFF6F3F1F5ECECF6EAF2E7E6D9D3
9D7C7D5C6B656D6F557F596675598B643F5283456BBBB293
6C72A3737B85774377ABCABBBD9C8B8B75625C716563676D
858C5F4A4E4C6B675494A7919B94C0CBB3C4CBC9C298A6AF
B5AAB29C8BB574507BA9BCC4C6C6B67B5B689CD67A809A6D
3E4960488DA9D0D3CCC8C0A46775BEC8BC795075BACA8393
B3C2A96480738BC8C8CECBA3848BC1C29A6E727CBFC2C2D6
D1D9E8E8E7E6E8E4EDEDF2F4F2F3F1EFF1EDEAF5EDF2E6DF
F3F4F9F5F9FDF2F4F3F5EEF7F6F1F1EAE6EEEFEFF2ECE8E5
D8BFC4916B7693996E624D5556525E6A535B6E617E8F9574
4C56765B475D75545B80A9A974606E6845493F5465614E53
5145433A516A6C4F36686A7C575274856590A9C1BC7E8C59
81AD9F5E6486814F858E8B8D8BBDC7B89B5FC9CCA342685C
7D616E6CB6D7D4D8D8D5BE4E396C9AD4BE515985D5D0B7C2
859574947977AAC5BDD4CFC0D7C4CBC79793AACBC5C9D0D9
D7D6EAE2E3E8EBEEECF7F3F4E7F7F2F5EFF3F3F6F6F8EAEF
ECF3F4F4F9FCF6EEF5F1EDF4F6EFEFE5EEE8E7EAEDEEE4E7
E9D8CFC5B5BAC4B99272818B5C5F565E715E5B52464D4F71
5453765940476F9C8C6D5E91635946555C727177443B6774
463943565D976442393D496D534152394F477AD0C7B7AA71
5F6B9D9D8A7EA49A94675455637E7EA48572CED9C473416A
CEC8C4ACCBCCCBDCDCD6A6385988BBCEBF7062B9CDC9B370
6B848B7EACB6D4AE74D3D6C6CCD3C7A3B6B1C4CCD3CFCDD9
DBDCECEBE6E9EAEDEFF5F6EFE3EFF4F4EDF7FAF3F4F5EFF2
F2EFF4F2F3F6F1E8EBEAEDE3F4F2E8E7E8EAE7EAF2F3EDF2
E6E5E0BFB89A8BA2938092B3B5A98E9FB1A4997752505689
524E6761474F688D9A905E4F65606674809BB1AD9B7EA4B1
8254526BB8BF9E5B474981B9A982703F724261D7C8916DB8
A3AEC0C2C0C6C6CCCDBB6C7DA2AA66B3A086CFBBD1B581AD
D9D8CFCBBB8289D1D7CC6D5086ACBEAB95AD79BCCC8E8561
9E6D92AED5C9BF7F7BBBB5C1B5CBAFB2C6C8D7D9DDCDD1D7
DCE2EBEFE9EAEAF4F3EEF3F5EEEEECF5ECF7F9EAF2F9E9EA
FBF1F1EDF7F6F6E8EAF2ECE9F1EEEFE9EBF3EBEEEEEEEFEC
E9E0E4D9A99D9386947F8ED0A2ABA4A6A8C1ADA79591809D
76474F855C3A7F625F848E544D62506FA9B29598BDACB0C0
C2B8AFABCACBBB8B4D88C1C9C8C2B69DB5AEABCBAA5162BD
C6C6D5D5CECFD7D8D8D3C4C4CAD4CAD8CFD0C583BFCDC9D4
D5D1CDB282417BB1D0C57D56AACEC75C5BA3CACCC472757A
95B9C2D5D1D4A6617ECAA2BACCC79F9CD0D0DDD8D4C8D0C8
D7E4E6E3E5EFEFEAF2EEF7EFF1F2F4F6EDEFEEEBEFEDEDE8
F4F3EFEEF4F5F6EBECF1ECEFEAE5E9EAECF2F1F1F4EDECEF
ECE7E7DAC8C4B0B0B0BFAEA08D7390736FBAABBBAFA18AAE
904342AFAE5664514F72A2A294865E90A293A1B6B99DA3BC
CFBAB9D1CFD0C8C2B7C8C2CFD6CCCFD4CCCED5BB8E93B8CD
D4CED8D7DCDCD7DBD3CDDBD6D1DCD7D3D4DDD8B3CECECDBD
DACFB9624D657ABDDBC6A198CCC9B7415F7CACDCBB827E84
CACFDDDDCAC5948EAFC9B8BBD7C2C2D4D7D3D5DFDBCFCECE
E3E0ECE9E9F2F5F3F8F4F2F6F1FAF7EFEFEFF4F4F3EDEFF3
F5F2F2F6F3F7F4ECF2EEF3F4F1EAECEAF3F4F4F5EFEFF2F2
EDE7E9B7C7BC849395A99FAE9F5E8D97A9BCBAA99CA6BFC5
A864679C9CA8976C4C56A1AC90888B6B554C5F979FAFC8DA
D5CCCBD7DAD6D0CDCDCAD0D3D4CFCFCDC1C7D1CBBAB7CACA
DACFD9DBDBD6D4D9D9D8DBDADDD4C9DED8D5D8CFD4AB8690
C5CEA83B5F5EA3D4C280C0D4D7CBC256A78EB9D4D9C9809D
CCCCD3CDC6A3C4C6CDBFDDD5DCCED5DCD9D8DBDDDCD6D1D5
E4E8E9ECE5EFFCF3F6EDF8F5EFF3F4F2F4F2F3E8F5F7EBED
F5F3F1F2EEF4F5EFF1EFF5F5F2EBEEE7F1F3EDF5EBE7E7EC
E7EBE7A79FC88363618BA9999A67577B85A28899636898C6
C9ADA06E5F6BA97453517F8C8CAFB39E73574F85CB6DC4D3
CDB1CAC6BFB6CFD1BCC2D6DDDAD3D7A3569ED6D9D0CDD3CA
DBD3DBD7DBD5CE8F97D3E0E5E5D6BEE4E3DCD6DDD1894C80
C6CEBE757E86CBD49752C5D8D6D9D6BFDAD9D4D5DDD9C5C0
D5D3CAA1A4ADE2D5DAD8DCDBE2E0D9D7E4E4E2E8E2DDDFE5
E9EAE4E8DBEBF4F4F6E9EBF2F5F2F2EFF1F4F2EDF1FEEEEE
F4EEF1F4F3F5F1E8F3F1F3F4F3FBEFEEEEEDF1E8F2EEE7F1
E8E3EAD6CACA91816A7B929282796B6D79515F71525661A6
ABBEBF9F7D4591BA8464746C55C5CCCDB79999BCDAC1CED5
CBC1B9927A6DB9CF8075E2E5E3D7CE893A62D8D7D9DBE6E3
E2D3D3C4D1D6C98371D4DCE3E3E5E6DDE2E2DEE2DCC4A9B2
DBDBD3D7CDCDDBCFB672BADFE4DDE4DEEAE4E6E4E2E2E4DF
E3E0CFA2C2D8DFE2E0E4E6DDE5DED7E0EAE5E7E6ECE7E4E7
E8E3ECEDEDE5F3F7F6EAF4F6F5EEF6F3EFEBE9EAE2FCF2EF
F3ECF3F2EDEFF4E8EFEEF2F3F6F1EEEBEDEFF1EDEDEDEBEF
ECEAEEE5E6E6D6CBB283616D9FAEADA695625E6A687392C4
CBC4A6CFC0AFB6CBBDB0686279D0D0D9D7D4CEDBDBDDCDBC
CDD8C7A8605EC8D0BDBCD9DDDDD6D3CCA89ED1DFD8DBE7E2
DCDAD1CDD8DDCFC1ABD6E4DDE2DCE4DED9DAE3E7E8DBD3D9
DDDDDFE8DFDFDFDDD1D3D6DFDCDEE5E2E2E6E2E2E2E9E8EA
E2DADBDBE5E9E5DEDDE7EAEBE4DEDBDCDEDEDFE4DBE8F5EB
EBEAEFEDEBEFF3F4F8F3F5F6F2F3F4F3ECECE9DEEFF3F1EE
F6EFF3F5F4F1EFEBF6F1F3F1F2ECF2EEEDEFEBF2F2ECEDEA
ECEAE8E6E8E7DEDBDAB99DAA8DB6D8D4C8C1B8BD97BFC7D7
DCCDCECCD5D9DBD9D7D0C193C2D7D9DADED4D6E0DBD4A35C
9AD8D6D4C4BBD8DADBDBD6DDDEDEDFDDD4C4C9E3D9DDDCDC
E3E9E0DFDCD9DCDCD4DFE0DEDFE5E6E2E4E6E3DBE8DDDEDB
E0DEE2E5E7E6E0E5DBDDDEE4E2E3E4DEE8E8E3E2E6E3E2E5
E9DEE0EBEEE8E5E7E0E6E7EDEBDEDCDCDEE0DEE3E4EBECF3
E6E7F4F2E9E2F2EDF7F4F5F3F3F5F9F3F7EEEAE9FBF5F6F2
F7F1F5F7F8EFEEF1F2E5EEFAF6ECEAEDEDF6EDF3EFF2F4EC
ECEAEEE8E7E8E3DFDAD7D7D3C8D9DDDBD9CFD5D6CFD7D7E3
DADCDBD4D7CFDCD7DDD3D3D7DADFE3E5DCDADFDCD1BB9875
57B5D8DAD09FBBE4D6DDD3DEDFD9E3D8D0D5CFDEE2E3DADC
E4E4E0E3E3DFE2E0D8D9DEDFE2E0DCE2DFE5E7E3E3E3E0E0
D5E2DFE6E6E4E5E8E3E4DFE0DEE4E9DAE6DFE0E7E5E2E4E7
ECE0E7F2EBE3DEE6DFEAE9E7E9DEE4E5E5E4E4E3ECEDEBF3
F3EBF9FBEDEEF4EDF2F6F4F6EDF7F8F2F1F9FAF5FAFAF6F1
EFF4EEF6F6F6ECE8EBEBE5EFF2EEECE7EDF4EBF4F2F1EFEE
E7EBECE9EAEBE8E0DFD4D7E4DEDDDDDADCE4DFDFE3DCDFDB
DEDDE0DDE2D9DEE0DFDCDCE5E2E0E2E5E0D7DDE2D6D6C5AA
6763D3D9E0D1D0E3DBE6DDEBDDD9E3E3D9DCD8D6E0E6DDDA
DFDBDEE5E2E3E0E8DDD9D9DFE3E3E2E3E4E2DFE6E3E5DDE8
DDE0E5E4DFDFEAE7E5E4E7ECEBE4E6E0DFE2E6DDE4E0DEE5
EAE6E8E8EFEBE4E5DEDDD5DDE3DEE5E9E8E5E6EAE4EAF2F3
F4F1F3F5EBF1F3F5F2F2F4F3EEF4F5F5EDF8FAFDF6FDF1F1
F3F3F9F7F8EDEEECE9F4EAECEEF2F2EDECEFEFEEF2EFF2EE
EDEBEEE7EBEBE4E3E5DBDCE3E3E2DBE2DCE6DEE2DDDEE4E2
E2E0E5E4E3E5E0E0E3DEDCDEE2DDD4DBDFD6DDE2DCE2E0CA
94A8CDDCDEDCDDE4D9E3E6E7E3DCE2E2DFDFE0DEDBE0DBDC
E0E2DAE6E8EAE0E6DFE3E8DFE5E5E2E9E8E9E5E6EEDEE3EA
EAE7DDE3E3E0E4E9EAE7E4E7E7E9EBE4E7E5E4E3DEE5E3E3
E2E9E8EBEBEFE8E2E5DCD6D8E9E2E3E8E9E5EAECE9E7ECF1
F4EDF2F1F3EFEAEDE4F4F5F3F5F2F7EFF6F6F4F4F7FAF2F5
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],

Cell["\<\
We perform local cosine transform using a rectangular window, that \
is, using Cos\[Hyphen]IV basis.\
\>", "MathCaption",
  CellTags->{"S2.2.2", "2.6"}],

Cell["ct = CosTransform[data, {48, 60}, Taper -> False];", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S2.2.2"],

Cell["Here we do cosine transform on the data with smooth windows.", 
  "MathCaption",
  CellTags->{"S2.2.2", "2.7"}],

Cell["\<\
ct2 = CosTransform[data, {48, 60}, Taper ->
{{Polynomial[2], 24}, {Polynomial[2], 30}}];\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S2.2.2"],

Cell["This gives the density plot of the coefficients.", "MathCaption",
  CellTags->{"S2.2.2", "2.8"}],

Cell[CellGroupData[{

Cell["PlotCoefficients2D[ct2]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S2.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00496032 0.0238095 0.00396825 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.27183 -0.0125 -6 -9 ]
[.27183 -0.0125 6 0 ]
[.51984 -0.0125 -9 -9 ]
[.51984 -0.0125 9 0 ]
[.76786 -0.0125 -9 -9 ]
[.76786 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .22222 -12 -4.5 ]
[-0.0125 .22222 0 4.5 ]
[-0.0125 .42063 -18 -4.5 ]
[-0.0125 .42063 0 4.5 ]
[-0.0125 .61905 -18 -4.5 ]
[-0.0125 .61905 0 4.5 ]
[-0.0125 .81746 -18 -4.5 ]
[-0.0125 .81746 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.27183 0 m
.27183 .00625 L
s
[(50)] .27183 -0.0125 0 1 Mshowa
.51984 0 m
.51984 .00625 L
s
[(100)] .51984 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(150)] .76786 -0.0125 0 1 Mshowa
.125 Mabswid
.07341 0 m
.07341 .00375 L
s
.12302 0 m
.12302 .00375 L
s
.17262 0 m
.17262 .00375 L
s
.22222 0 m
.22222 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.37103 0 m
.37103 .00375 L
s
.42063 0 m
.42063 .00375 L
s
.47024 0 m
.47024 .00375 L
s
.56944 0 m
.56944 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.66865 0 m
.66865 .00375 L
s
.71825 0 m
.71825 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.86706 0 m
.86706 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.96627 0 m
.96627 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .22222 m
.00625 .22222 L
s
[(50)] -0.0125 .22222 1 0 Mshowa
0 .42063 m
.00625 .42063 L
s
[(100)] -0.0125 .42063 1 0 Mshowa
0 .61905 m
.00625 .61905 L
s
[(150)] -0.0125 .61905 1 0 Mshowa
0 .81746 m
.00625 .81746 L
s
[(200)] -0.0125 .81746 1 0 Mshowa
.125 Mabswid
0 .06349 m
.00375 .06349 L
s
0 .10317 m
.00375 .10317 L
s
0 .14286 m
.00375 .14286 L
s
0 .18254 m
.00375 .18254 L
s
0 .2619 m
.00375 .2619 L
s
0 .30159 m
.00375 .30159 L
s
0 .34127 m
.00375 .34127 L
s
0 .38095 m
.00375 .38095 L
s
0 .46032 m
.00375 .46032 L
s
0 .5 m
.00375 .5 L
s
0 .53968 m
.00375 .53968 L
s
0 .57937 m
.00375 .57937 L
s
0 .65873 m
.00375 .65873 L
s
0 .69841 m
.00375 .69841 L
s
0 .7381 m
.00375 .7381 L
s
0 .77778 m
.00375 .77778 L
s
0 .85714 m
.00375 .85714 L
s
0 .89683 m
.00375 .89683 L
s
0 .93651 m
.00375 .93651 L
s
0 .97619 m
.00375 .97619 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.27183 .99375 m
.27183 1 L
s
.51984 .99375 m
.51984 1 L
s
.76786 .99375 m
.76786 1 L
s
.125 Mabswid
.07341 .99625 m
.07341 1 L
s
.12302 .99625 m
.12302 1 L
s
.17262 .99625 m
.17262 1 L
s
.22222 .99625 m
.22222 1 L
s
.32143 .99625 m
.32143 1 L
s
.37103 .99625 m
.37103 1 L
s
.42063 .99625 m
.42063 1 L
s
.47024 .99625 m
.47024 1 L
s
.56944 .99625 m
.56944 1 L
s
.61905 .99625 m
.61905 1 L
s
.66865 .99625 m
.66865 1 L
s
.71825 .99625 m
.71825 1 L
s
.81746 .99625 m
.81746 1 L
s
.86706 .99625 m
.86706 1 L
s
.91667 .99625 m
.91667 1 L
s
.96627 .99625 m
.96627 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .22222 m
1 .22222 L
s
.99375 .42063 m
1 .42063 L
s
.99375 .61905 m
1 .61905 L
s
.99375 .81746 m
1 .81746 L
s
.125 Mabswid
.99625 .06349 m
1 .06349 L
s
.99625 .10317 m
1 .10317 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .18254 m
1 .18254 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30159 m
1 .30159 L
s
.99625 .34127 m
1 .34127 L
s
.99625 .38095 m
1 .38095 L
s
.99625 .46032 m
1 .46032 L
s
.99625 .5 m
1 .5 L
s
.99625 .53968 m
1 .53968 L
s
.99625 .57937 m
1 .57937 L
s
.99625 .65873 m
1 .65873 L
s
.99625 .69841 m
1 .69841 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .77778 m
1 .77778 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .89683 m
1 .89683 L
s
.99625 .93651 m
1 .93651 L
s
.99625 .97619 m
1 .97619 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
192 string
192 240 8 [192 0 0 240 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFF001A56A18E4D578316FF5AB7CA00C1FF0056FF3B
5A26B7716DAB7B95C38F927180839693938DA4B27D907366
FFFFFFFF00A2FFFBBEBEFFFADFFDCFE1D6B07FC3A6C3C964
7843747ADBC88F6273959672A0A4317B878B83807F7A846F
FFFBFF006555ECCB776E331F000055AB079DA4E0729D48B5
72817B827973AF59848E6498948756767E85878276748FB5
FF00FFE60000F1DB699387A78A1020A42FCCB499433D7C9E
709E127B96E8AA817249618B4C61945A72797B836A527D72
FF000000FF26B0D900E12DB800732924FFFFFC00968D5383
A3C07975BA5783798B8C8771835C679A89566572908EB08F
FF00F44FFFDCDA594DE7FFFFACF292C495D9DA79349BAB71
F690B07D717F87846C68A36C9D9486A58B638CA282828B8B
FFFFFF1200AE7AA2D1FF54995C5DD5FF8F589BAC55BB8299
618E3D7D7B829C59816A678485857E8E87AA6C8C79626EAB
FFFF00FF00FF00B60F006180348FA835FF75D0EE70A34675
735F9EB96C737A6C6B92887A956B96B3958A7490868E7285
FF00FFFFFFBC708E5E82FF729AFF31ED00DC0000FFFF0053
C810635D86B8705B928B65A292936389C95F997A765B7B60
FF2300D1A0E100AF6BBEC33C4D06020887BBAB7BB797B37A
8C9051A2B8A77A82518F6695666B655D8C9896798A80866D
FFFFFF8594E80C243C4C40669E2D11A2408AE6755D4ECD21
9C7A69A23C6F8A7E9D8C825F73808673A6619A93809B56A6
FFFF6600FF00DF5BFF5C636E609AC1744FF20070C7348993
ACBB4A8EA83980AF8554638A90874D8A8467804C956A677F
FFFFFF3D000025655F6A00F1FF00FFC300DBB2FF805656FF
50B3A85F91826C969A787F5C6C8A6C774D857C91889A8182
FF662558C8634D324E0000000036395B0066C6AD56A73A37
AD7990975D957E858F8EA045887C98888C9B8980824D8594
FF34FF0013FFFF993679FC96C766B4A88C9AA639A4A225C4
6D2FB6B2B39D83C645797BA49F9B93888C838D8583537397
FFFFFF001AFF005500FB369BD79589FF5F00FF0054FF7A5C
D767835242CB527BC3AD837F6984BA6F74948AA9669A8378
00D700005EFFF5FFF340EF00001DFF0D729011FF0000F660
3EB1B891448858AF779A62B08F6BDB69498D987A5A6E7D80
FF53D4D700FFFF00C2B84F00B29BEE51007D948AACA96077
548B4EAD93847BB146649C9C8B7D857C6C968E9474718581
FF00CBBFA096D5FF253090FDB3EF429DC0739A99C136DD7B
AD687388B45042695A8B796867847A887A5E8A6D94828155
FFFFFFE54A8FAF00B780FF0C8C204A5DFFFF00FF9850F5A7
00AADD406152E5B8375B8084AFB876906E6B785BA663809A
00A000B6AAE342002DB3D500FFFF006AFF506A4063ED7873
833618AF89978B923B7A7EBE4A7F588175BC50689093849C
FFD6CF003D6E7B79003000001EBAFF6D39623D0037A4706D
69B5706F3E8B60637A904A748994827571557B818574797B
FF00E6A340E537E22B97250B49DA4042AC169F4F50B27B46
6D575D9E63A99975915C7A858EA8A776788E70767A6D6F6E
FF88E4FF0B2ECD4B6590A3A800EE549BD400FFBD9C1481CD
FF8900EE7789707EBD86A6956B866D81C08567886595A77E
FF5C15FFD173C321187FF700FF00CBFF005B2DD191B7BE97
7FFF7463865BA45E79A38949807A5685A07987AC74736184
FFC2007E4C32F00075318E4064777F000040C147963632AE
7F51577A3F82849B7D657C5D6065718F997257A58FA97360
CE0000FFDB1C7D79C32DA16FB1FFAA5CCAAB725BCD4A1AE7
869C9273A47F3F85A9C2847F6A6C828F4D77716C629B8644
6A9EFFF9920051FF37A288E6D50BFF0000FF0000E1FF0636
61359E26E782677649B57D57815F9667488F9C728B7F6D6E
749A6CB9004500FFE4733F9EBBFFFF00FF90FF4173384310
8217A6AC606D9E768E76716879D883938843738E7A8E8892
FFFF052F6CFFB95FED344FF3FFFFFFDDA79C42713575647D
8B9C9F6D49816CA5997290B57F9B8A89907C6C5E927F6A84
F700A8C3FFBC063BA99EB759BF72AF009D6966E75735ED00
E3A7538B7694698B9C6C61649A646E877C6D8070B57FB96B
97F179FFFFBA609CE900C65FEE9401FF2800FFD20000BCCF
11E9A38D008D975DAF72798C78715E99BF776B817386B5A0
07B082FE00E1FF7F8741F35800D400FF69001E00F5B485D4
D3C2517A7D8A69816DA0639488595C748D87A4789575707D
B7FFD500506B33A34BABFBFFFAFFFFBB8C88466086894F61
6DAB71638054A75C70818C86926D765F7885A977978E7979
00001FEB0900C9A2CAFF9F8C2EB4C400E1B3662F76D831C4
40858164636C7C7C8A919B7D7384787F6696757D6C927064
41006A98F8FF705A97C100FFAEB40000FF2E00E7FCF08F51
FF007CF1D80A457F79A9635799AE7A7B5476728A9A8C5F5A
B4729E6717C17C002E9048BA73FF00FF00EDFFFA38A4626E
1D5355A27B61988B92409D945E74AE9C66C465617B788A8B
0DFF180862664C001DDDFF72F06E3F00DAFFFF77BCFBAAAF
9D8E9638937797AEE4856D9F9BAB6EB3676943777B959360
451F011ED6063800124FD7626D86761A49D900B27947844A
A0CA7169986784A08A54A66668628651746886A36C81853E
8A9D04505A85FFC8574AE061FFFFED6511FFFF00A700069F
51FF4900779F678C6C40B48B5F5DB45E969E728678685682
BF39994CFF789C53FAB400FDA914C6AA02FF003A9B1361DD
B889A6943A8B66A27C58D3566F84A66E7459747297798982
1268FF003A3BD07D1FFFFFA9005400000800000000145B9C
617C93486D6A7B639B8C7A837B73897C9557826859889186
00005EBB3BEACE239E806D50F600D805B9380D727BBC57E0
9C5AA52A5D557B8C7683CB98AA7C6695A87779A37F67857D
723379525D9FE86F50C2484B00A7D808007DEFA4FFFFC761
4E0AFF933B7B8F5E8E99408DAE9531A9695BA77645A2C084
D100FF00C45B6B45E2C01F801119FF00FF00FF23FFD7943F
57648546F8977B59889D4C83929564689B9F78BE5F7A6C75
00B9B529031917314FEEA60000000E497EBE42A8FFD4E17A
64C3A1549996735184856E7B6A8F52747F5C8E838E889177
259948F7AE261D5635FF7BC9FF6D49BE30FE4859EA00B39A
3EDE7096995A6358486D707069966973898C5D85818B8D82
4F5700608C8361A8BB0464274E458BFFFF00B76B0000E555
CF9400E29588A04E68659C7A82329757686F6586B661638B
D100FF9C628CF1303244CF9FC2DB739F6E6300FF16447B97
68E968844C0EBD67AB7093676764A093958571796C8C9092
3E00FFA27C1727F450D9297A5C632EF4FFFFFE842B6870B8
B8668B828C6A7D74A45E88959DAD9F82846D735A90908D87
A3FFE0FF3E54093E980080D27F66AC2874006D533693C06C
7680E17EB57B849791657C8DAB8A7985818C7C51979E8592
A5185C188E909D975EBE5B37002190A477A6BEFFFF001FFF
82CFC32AE49BA2E17CBA854461D658589A9B844E68AB866A
9E00F043F72E32F8FF0161853E6D969439A0FF0A9B95A052
A85B629D92D1966A7873778B9B87895F8B53976590828882
FF007FFF80F6A7C958AA4F9B5FFF8C99CF0300D8FF665460
2B502E8BAAA5798D81906F7B867278838D8F908C7F78898C
FFFF4CFFC7334FF29F5206D7A3F53FFF6194BA00F58B98DB
5B7B82886E63836E5567629163A98B5F8480778550856D8A
0DBCA7BC9FB18710776D9A802062A6F2D5000000BAFF0900
653F647026797A7EB427A4BD67169CCB525183BD84589679
FF3EEA4562A58B3245C8C37148EF2C55C88013FF4C6389AD
6674759A7E4869968F9D4A7E8D9468A773B6748E906D6B74
F327C4FF18C3B227A2AF3984A0000035BAE8FF447CCBC4D1
848496867BA36A9E74967E64636D66827D858F7D816D7679
C7FF8D4541016D58F10039FF6087897A19FF1FCC636C9C5F
759A986F9DB68976798F8B9088B28A8E649DA2938E788B70
0000A7C49E2E6AFF737A5159A62F00C5FFFFFF0000FFFF9D
66A5A0E2C2B9AB6081C6344D99D18344B8B1592F65918383
2476D700FF5FDF926A607BC53A3FC22BD13AC71193D84C3E
9E92917A58B36E966654BD756A60898D6877726C698F7182
FF37E5F8FD28692EAD1625FF3242BC55CD7000FFA7041161
559A779889B47A73A7355C616F518B8EA5C295AA74785D75
FFD80000DED56A5197822F7100BE0096FF00FF0040AD8832
B06FAB6474759A58939359956D89718F7481866D7A8967AB
717B836376B4814095B39AB08D4C000000EFFFFF00002FFD
520563554A60627F777E9D687F609ED83C5BAF9F9577555E
71AD4E706F3D735A8671994FA08CAD838F705CEA6B4983CE
5361957382877345A78D778C6D9C769A7D8E7E7B6A848460
CF00CCF258608CFFC535FF0000362BA8A0E9FF002A8AA184
949A9BA2858091AA89948A7F8447476F5E5F5A7C727F9485
B2DF835544D134B4A87DFFC602FC09FF00FF8FC354D139BE
4590449C52A368849C809E5B709F6D8477724D739C707A76
1B87A269000019511151D1FFFFFFBD05000064FFFF9B5882
CACB57A0B54880B37180ABB085975967F87752794C939068
789F97B457C96C66DF848466905E6A417D9BAF4D6F9F7168
AE6F9D8C50C05CCC415B9D5C9573786D8586889D787B7AA9
4090BD3A6770C7FF8ACD0E005200FFB9D9B50072B3420165
B793598474739D9EA07BA68C9D907D909F8DA0A791707B89
43BC367752D77CCFD19ACE00D13E2F987100D788AB279759
C86775B06C99B088AEB86C808758937B9858A85D8A947483
8E8B3F46DE8435435F003082FFFFFFFFFF5D0022C6C16E44
6D76912B5CC17581B359558B797EAF6000BECF9CC95A5D92
48E857339C46BB5081534D94AA54D3539D865A8F7F788C6A
3DDC5450BD815D898DD73D959D8C5F908473918A8471668E
07CA2481C735E1BA55AF008C11FFBBB21200FFD4835E785F
684C38889485374044845787847D7D9C61897C57558C6074
005F6380EB2B7CE74CA5A225FF00FF50A5D06FD575BA45A2
886E147E6D9287536C8473818F73825F6D6B6080985A8188
E065EE90509DA23000000000000F5DA4C36E270645543184
9A8683A55E6F9F4672B08771966978BFDC3C2A5F7183AB9A
B07279C0689258A6AA748A9C726B5492A43974B569847FA0
766C919391598F5867639875757886968C74686265B58C71
0084221DAE78B878FF61FF1FFFE0994B2BFF345260616D62
9C519372385B6E539279A88D8A948A8082836C7E75908286
00E68274FDC883FA00FF000500FA0035820038ED5A6CB435
D55A9F8D898E94A445797E937D7F8569AB5A987F7E78779C
CCF2235F806C944D778C2600000000638CFF9651438BC663
7FA66E68A24157893F8B8E7384BF4A367495A39290AC7532
57DD199C9992A9099D9A5D964F8952CC8A8967808367AD5F
A1568F6A7E749397996D7275946D8D73667EAF9A88717E5A
22B133F3BFAC5D5DEC2AD000FFD1175DFF00009B85578958
8BB6385E83A9915E89A8675E5E7B7C766176A3966B7C7E8C
00D2FF258C6200FFA6FF11FF3973FF916662FC6D9E694A7C
543B41714E747BA878828E8890606A7968A68180927B9E8F
6A22997FB1864CFFFFFFFFFFFFFF9089B24DC3554B6C5D68
605B64497BA9736E6A368EA68F5ED5CE3F599961707CA5B6
4ECC539D219D5FFF4E63A2598BFF2EA64296997A70797851
809180748D7AAA5B887AA68084658A978D6B7F7C6C778E8B
B4947291547D13CD5FFF00CC92CA27FF1F25B47374B17751
A2A4A58BA88549AA8CBE7DAA8081937DA58F7978926E6982
00ADFD002EFFFFEC00CBFF00FF464537798430F910869285
9162879E877F6CA07B7D5791A445B8779A7F86955B8D7F8A
4FA87BBE84A5F3F3FFFFFFFFF3A13E001D793BA390408095
575897A64F8DD2B6938656926D69334EB19E67B6BE73807D
5F977AC9B66037D3328ABC35827D64AD6E5085938E8E86AF
9D3D9D877E64957967B425A777A96F546CC06E6E8B986D71
B5293A4162FC00A27C69AF90E976FF07489C4D767E538A9A
99938B877B64617A90797F6F7947654F688E847E84669798
0027AAA8DEA60000FF00CB024B6B3CEC4068FE538A6B63BB
49769B7596597460B37D7E707B8A58A0759A8A846C809962
B497AC7090B5AFCEB4A167807B6DC1AC5146E495B5B57B8F
624C84C89E3342598DB7A97EB2ACA8835D4361687B9F736C
997700A14ABF628C869390C5888435B855F5715084827242
748A666F9A7890779A72B04F9C33CE81987F86927F6B918B
573E5C727A43A300D00349FF69FB0034C9762F6F7C95A27D
B4A5A6B5C66B7B6E418045629AA99FA49767807C8B818184
00E9FF430031EC00FFFFFF855A7D8600F37E534A32CE767E
9377796E97A985A6727C9D5A9F569C757C8C649B6D73798A
8B9A95946A97B9784C0E2A5ECEFF939DA27A4EA3856EA280
B4985A5694AA6C9971564C4C405772878CB7D28C66666A92
5BAE957167927AEC439088533BD27AA44E6075B1677088A2
9472A28775967C647C7F58BD78942F907A7D6E75977A7362
69A24A58DE3A916847A886E6B8690D56952262824D98A07E
957A695E56708E6BB45AAC969F8EB35A4D7F896E78736E74
FF0000BF4900FFFF550000003A00B9D458E66F90FF697E86
A5AB756CA55089648C60839453C97A8C887579826E7D7174
A59292B2BA9C2E3B0B2F7C8E5E4D9B648C6B81758D700A5D
5A74605F7783BF869EDCC0809A89556C7990897C6373857C
7F2CCC9885784262889F6A96A13BA3728696934CBB78866A
3E8D7075888359A08866A0687F82CD7C856F9A867A679C8C
65524760A0D33C3BAC31FC8DFF3E5EB53C8CD766ADBAAEA1
849F648DBB619AAA7F9D5D63807664858A765D5E72618F8B
FF2800DDFFA7080059767A6779B03E3DE0827D4C6EE06487
55837671A1AB9B866A78B94B8877958362836686706F8A6A
9CA870938140542A426A8166959F8BCBAB956B5180BBBE7D
8B828660568D705C797D72916769C1AC826363A8B88B5A80
789A8A623BED876A9D618A7D939D6D67659C8861977456AA
AA7A7D748C9C8F818777707181835A6E958B858D887D8177
B4537BE4AF7A73679A1E8E8296008241762F608737A9767F
974593935D8F7573534F9693798582789AA09E927680858D
41FBD34D7659A9D0F1AD00979377A69488F23D74BE5D7B87
859960AD5791675F768C7D815B7D906F876074847E90837F
7F3D86645F9519415E516E856C92B48E827A7FB7849CA4A2
4B5A8D817AA790C07871C28258585396AEA8725584608DA9
868E3494B121A77C569E9D6B73856E80A4606D958A9E8097
339488A45C80549C5D8595788E878B8C7B8978696C9E7BA5
CBAC9688BE4947958370958280257D865686A59887758689
6196A4AB8D72856A57A99A759A5394AC6B775D7F8D958477
FE344C7F5E8E919A6BE991E9D4FF5A72A967A87293708565
6668C26B927D575A757EA4789D91748F5A7E8C7765897C8D
5E8D768C647AA1776D8A76525E596278B8E3B17086626C71
92A95D7794408A656D8D5AA3EE904025576E937C49BFB47B
62A858CF529B8566BD3970ADBA4DB1799D509D6C7875895D
B06651BE62928499787E8F6F647C7E89857E8CA27F6A8875
1D3D697FCB7FA4B2708956B2505AA276867B937E836C9C63
6B83A095657DA5A4936F7D977B8F4B606D7D867D78856D77
B620329D3CA296CE89DDBCB590ACE26CC3A9478FB45E978C
8C9B6DA981876C8D8286797789758F9B7F8D945A967A9B71
879871438292A1B178534D444F7A729E534371C2818B80A1
B15D8685609782837C4532546192BDAE5A3E4C92AA5F5876
6EA35A8F7A827D8350C48247AA48805D797EA568BB7B53B4
86AD696F8A817E6D8D886588977788845A92876E768B7062
527E7D96AD835BD265BD76A41A8252A6738B9292918E7081
8472913F6A9B4E9D81857B83573C618D8480676D81967074
DC2500997DA9A18626D974ABE4A466847163A4879058737D
6154A65279639350AE937D88788471818163918274776B86
6A668B8A807A817578806A5E544E5F60979598767B78668D
8FC7B182775683969CA2BC654F75B69E888B75676F748C91
CB228CC63671C354699D965D7EA9B976698C807670868E69
706A938A6573908D7B7F7784669F7372A98D5F7E9078968C
734FB3705881288012B138BB628EA6B6B6B79DA6B39C8E98
6D69646B9E75809361527E995A9C6D6E8667969AAA7F886D
9E713FDDCC8054947098759037BC8059748D54A95F4FB251
748AAD796E5C7B78733F887C65867475AA579079AA888C8B
7C5C3F8B8270607CA17A567D987A8568659078A691A0BA7D
7C8C8D7C9866314D737C7699A987415B948A8974736E7279
7B75AD7DA141AA609E665992D60073978074709E5BA65BB1
596D9B8291847F6689759D8272886A87607792887474739B
967E828893AEA67F5E8B99757997848D989683989453A59A
759F537369808371598B87AF9F77C08A8E8F7C687D7B667E
045760E2C662005C7832667A87287D83485B9572A3815CB3
8E988385977362AD777F77A0718C689867906B8578907C71
4194D75A6567807D739BA98B6AAF75416B7E7E5774704568
837E80BEB2D2CA706A5A52607087A763667194A09F9D8578
89698A748E8D569680947E7C8C8BB94E7A8886807A7C7F7A
8E9569598477918788807B987A917B8483786B77747F9574
E48D7E7556938D5F8FBE8237827C994D61A083A4839B757F
575C89639B9B9387A763897A60A78A7C608B886B83778777
7FC9879198693F5B4C3A8D6E8E753CAA5749747A50907FB5
7F72736C934C9D7573656470928078777A7D8066746F7F70
76A455A17C91848499796D98B1495170713D6EA3646A7A4C
5E5F5D41788195B09698B499847A79B191828A7A7A80849A
74907847A68381836CB76F82399A90888875638E7D897B7B
5D7EA48E91858E6F68915970946A87967D8683868B837C78
BD8484BB5B97A14DC77959697782965BBA717C768E6B6889
757B5F5B6D70977C6DB28D8D847A8A729D876366727D867E
69BDB677A03B17849485AF6A3961995C49AF6075869D8790
5F93607F63849073867D6FA3869A925A7BA184997790637D
BE55884D72789980696BAA9C3A73927142848960919A90AD
8AA67F74573B5D5367837B706A587A6F8491736B7C8B7062
905F95A754728794616F58A5BF477A52946B93658F70898F
908973778C606D899566A48E828C85816E7375787F799382
C38A7AA09337A828954B6E689EA19796978A8B804167927E
6C6F8D7159759287A96585613C9CBDA77186978379667480
B07DA7775D643F76A3675F7E696E89BC8740A76E6388B06E
8B80628758995EAD5EAE6575668C6073768E707F81829E7B
7BA97B9F94A9889386CAA85997956E69B062668C7D6E7A84
A481AD9E8698746278727E957E99808D999B818B9676929C
88799051879F6572A58F71986D7F888B91777E73A5656A8D
778C8C8070A1988C727D80666E8B6B8C749A90718B877277
9C7B6E9560548D80988EA08390B4B89A9170838263C7968A
5A706B618D718A936A8E7E728D946E677C6E737F808E9388
AAA28B51446BAF78886596B2784E7E8E87777E8165828383
A654BF937893737D808C9678A0679186AB7C989075827498
878F8D80985F4F6E925951BD879ACBE4A78758605D666873
5D737592AF8887C98B747B8D9E978A8763899A907B987C85
4EA079709A80669D72708E518DA954A4517E747685899758
A17691758E7B81647693887E94807E84897C6C89816E8C95
8D5AA67B593C64888F6C6B875E767F9A90688277895B6F6F
566A6D959481B45A83629385906F8C887F7C9A816B839B70
67C8E01748888CABBF83AA6F9A93AF689C646F6D4C7B6A80
77A360A08573978B7C7F5B7760917E727975838B95758755
53A99B826770618484AFBB83B5A29E8E89A9A05E637D8F78
6B633E496679774F74985C4E938E6E777C6E8C9376798678
92A564858A8D6B788B747B9A797E8A697FAB8CA864698A81
8E71837A6DA255908590746E83739673777E80947581766C
7D6391B0587283BB779D9B7964707B9C778188616D546D76
567FB9A783A054AB6492895567A67A697C756E92929596A5
50DA902C7DAEAF799B8F5F8B92859A5981BA8AC16D996985
5F8B3CAC5ECB728680A37B8D897D9C7488766E8E79887E9B
746487635783BAACA27458736C8057518E7295B9B3D18894
8E79A081587872A79E799C90739C927A7A856160828E7E8E
63A273827E4CAE8E9D618F857D7A93929356748F69998173
708B9C898E77868F78637E936B6C8E8B9682767F8F698F79
63769E9D7C7D7E9F7B924C998DB47AA2528376915C6D7784
7C98A36AA5739A8CB58A5E50B1807F7F727A7B7C788D9B84
5C956B676495CDAB5D867B84807E9C79A684C47BC872B07B
B76A8E65AB4D7A6A646C7B6B8070947F79889D8086719286
7CA46C709B98825B585A7D87777E8887679F7D676865A29C
9BBE81B0C09793727A89836C776B7386826C77818D83787C
9A7CAC55B27C89736E7D809953A4807884798C8B7F858A6A
8F8F6E6788786E7B7D986E8B898A8076739188716F8D8663
A49493ACA07570C1517B9698A879719B659F5F944F738974
81949CA65871786C716C9E9E79837F7C7A888B977E899D8B
467CB4688EAEC3536B9B76719E67857AA25C976E934F6C4A
BD5ACA747D90A5869FBB8F75728083658C7C7552728E918A
877C848A8C7A707D698EA2A5A28882807C4B7691804C4B7D
525D9F717489827D617C8CA7956E708A746B6D736D796D76
954A9F718F735E7EA29975B559886794768A6E9F64906B77
847A837D9C838C728B816A8B6780758A8479808D8E77788A
65AF875A537174785D7D8893616F727B6E81857D908CA37C
8A7B7A726AA4806856966D778082947C8674927677886E7F
5957807BA87D9F4B5E7C8E6BC278685A697981916EAC8775
64A6526D8F845F6D6F538B5C88745DA86EA3868986717B8E
79898F587F876D87908075515C6F687F614F4A56556E694F
7454569B9B947C799274A38A6380747F8376889F916E7A8B
847777AC5C7CB06F568D5C8582A377666F96696B97709382
907E64B8575B857A86519C7E6B8D97667F9C86767594848B
458382749383997D5B9C9F9E705D94647A89905D88847798
7E5F6A859B71664C85907E9D826B8C8A698E9E6DA1898077
A33C44A5BB728B896CB4BD81536E3D816EAA7294799359B5
4B82A371B464A74EA08980A47C7683846071877D8C8E677A
8A7576AA9277875788AB7A65627496718CA68F79AF968B9A
8DA375638A87828F7A76606C756C848C8D9388666C8A8E88
86AE6C8A578B996E92888873638A70888C817778807F9579
6A897E75709E887A908D8F60925D78778C6A968A767F6895
7A8B88607FAB9E9572849B5E74737973786987A398838C7D
918678836E898192798760977C857E947D8E89958B917F7A
905968C1676171C84C5A864B777D7FCE5997816A8A88894A
7D5F6B6B8C87679D8A88626C9A78768B6781918A7B8C7B77
988881867B64809D6B81A67559617B9199A9B4B28D9B8C95
7E6A81634961756A8A947585949272707B9E817B7B7A888D
698472717B9B43888E5D858A7D878F837F688AA1934E9766
868F5D90935D7182727977948098888E7F7D807B9871957E
71913B6B8496A695A285908474868C797769977A85758379
A2708D7E659084786B799C756C8B807A767E8C7083785685
A5735195977E7891642C5D904C8A52929F608470B350808D
6B8E64A16678835A754F7F9F6D7F85867D76818D6B83738C
6B5C6A75788E8572936F7497918F958D9F8A9DA896858E6F
877D89A19F7E75A18068827C7B8E7C719977897B69757181
89897398776D9D81A3677B77848D605E84867D6387867A91
88828C7D6B9689738093687481765582947385897987726C
907A55516992956C8C549C7C738659878667647672777F7D
787A876E7C83957F7E8D847A9F8069728F8B898D858C8386
8489A8A18A7973628E8385B14B799C70A17EB42792B8638B
5A84905E806F8E828C7F90847F7F888A787E917D7E7E7786
7A95767181818D8E62898A7DA4A4606E7687755B5B5F80AC
82736E8678778582796E6D94878A8E9671718BA492798078
807B83617B8A7F56689A836E846C9E9088967D8A797E7B81
6572777B7E7F7F79857B89859095958170898D72728A8590
9E6F576E909D816291648A70917C82788D65879068787590
7C8F75746E7A777C8C8BA07D838D6F7E826F6F5D87837F73
62807C8F71798275AD795D64899C7E76AE6D53AD466E7674
B3569E8680927B889165827C6A87809386818074836E9586
A2898D8C4B687F85917371827D86907C57516C5F797E8983
8992A38477766F72818270758C7C836D8B77747A738C7079
8D757D80AF677794A6658E84818480716C8B578588887878
9B8F8793836B98907E6E806F7187807585737D7F986D836D
748D67876961577F955483476A9891826882B187A9888F85
8B667177836F76846C8F83757B728872A28D817D7F696E6E
A0A06C5C77AC7C508BB77D978397BB6149BA589B6C5B9089
7A985D9D627B659858848C8B7E7B7F71887C69867689817E
7E6A7D738FA298907998947A778E744A678E7B717F7E8679
8E81839B958370647F7F8D797A986F90718989698983868A
8C777E876D76979463807F898971896E9A6E8C90778F6E8A
8076725D998073696D9F8386A0628C7887768D847D8E7C78
919A938D85646E748A757287866E8384677B72807097649B
908B9C89716A8B6C8C867B7694907F7C7C81647A8E918788
9070877F60604A82A8BA7D95B2466AA055A271719FA57E92
5B909D567E81959E849C8E8576917A6F99938A7D8A759367
64886C948D7B68837161758E765F4D628778767F7E69617B
8BA98072877FA7926E7565716D71927791707192708A8573
7A7F87757D8768A758969763816E918F797481687D918974
7A7A9B95628880888B747C81887A7F8A8583708D727A839A
68749A9999535E7A99A3707798879F989AB481615A827F7E
6F857481677D868B7A6A6E696F8382808D7F717A707E6781
738993717D70A6776FA3642E849D548E919B6B6D83837C7C
A26D7F7C897992686C7480657A9A7F8F797B846A7A807979
86716D829A88857885967251746EA6CC8D8C9A8F7F778279
81728483819364849586908675738A95807C8181A0817C81
9B7A7764A0A6637B9F7D6976847F7F7B7A8298637B707C95
91718D7A90738A917C7677838580896A7985887878878286
6D788F80846C4A7872767E968264739169887E767BAA796E
888CA390897493747D8E928E9790746B6D81897C8679748E
716F917379729A946D5598C07287A26F907F6C9A9D7DAA6D
7788877B7981968D829079828E7B8E6580817691676E8A6A
89989478707371707B8090865E9171607C6D7D8E8D8B747F
537B817B61788B6873778084857A757778808B816F7B7D84
6D6C989E696990797A7086968A6E7383738C6A8A8A8C786E
7480998C6FA07072729D838C6B84877B7F7E819591757980
82948674AA7A81A4887B7F936873627E7291708F7B7F816F
768E7E958B7F737C7A9D787D8171807C7E877E747B876973
AB4C5468DBAC4A72A570799497507A7F7777877072767389
8992818C7B886C727E9C7F827483837B8E799D72958A727D
878B7F6E728781807F7572818873A97F688C768079878D65
7D6D66788074898A6B74788B897D7F76867674817D8A8376
8F9073847B8E7882777799627C908A7B91797B8B71757291
908E597692738C7D95767D916B747E88976476756F838686
767B7EA7B58D89A8779766A36A59729B6E6B846B7A827B81
758078829A81806E81877675757D6A76849B6E69886C827A
5496BA8A57828A70AE8C7074818E8B8A8365858B77788590
6397748E897F727681768B7D757F6E83777C758084707271
8489849D755D81897978959689A05A9AA3788F919D8B8F8D
7A787079717B7E8592898F8C8D91787A748C94725C768886
7A717D7E77927A738B75917D747D7883837F8869777B8882
5F89A076867584927A6D896E8B90837B62A1888987778376
728D6C867E9074896C8484B4706A897E887F8B6F877AB364
8486899382A1868981908793706B7F79817A8B86738E7C6C
759085A2757997965A9189627C6E8F6B6F8D978179829B84
A0798B788870707F8671747A87829184928377948E8A7F95
6D8C8B66818F6A83817D898C89767A64808777736B80967A
6F7F977A7C836A6A7E81797E897E93788084797D927F8083
7A8D8A648E5B9D8870915F72A2738583787B7A9A8278798F
7B7D708B7888668B6F8C7B8276827E87797C7D6291917B6E
6C729660727B99738B648693697B8E7A9A87857C9399788A
8A87727D817A777A797D8D69757D7C6E608D837E8D729777
A77D615D89748368708097857A867F868373A78E8FA26A61
806F858A72886F8E74906C8D7C83756D6A64766D867D8975
8C82808A8284AB8F9A856474768B96A36F998B87A1837E8B
8B8F7293927B8B887775856670858C928A7F798F89948A7B
8D7E8097639E667E73818371836E72AB897A7D83626F7F7F
7B96757E8B6B85857A927B8686737F8F8E6E888D6F797C89
90777E876A9F90877C886C9596888E648976997F968D8B85
7E7D5B6E78938F809E6E877B8D937A877D7B8592747F7089
72887381787A74817E6D6E808D92605E7D7297716C617674
7490847D976D777477767B7680817A8486847A8C81907682
825A749A9C8D7588797A7E6B6D78716A887D867970766E6C
6A65848A7A828C8FA2937C8483757C89847A84706D777C86
60797397779C6F887E9086808C7C7876778C806EA08B7B74
748983628C88936479897365857A888C827387838E7A8583
856989668199867E8A5374847F6984857D7174719E7E74A6
79807364747F739582757E82739076877E857C727A817E6F
8286689A8C6A5591836E90689079B59C849079747E737883
9F797B826B848C958378818A8370867E6F7A7E7777888E7B
7A748D97826C808884878D7E7B84789484717A8475726480
888E857D8A917D887C748F706B7885807D8B7E857A797378
978280887E5D898D6B848189747B8F91777F9B707A7A7A84
7486897A8E7A7787857D8672AD7986706D907873897E7C85
78987F6D80A1817E767F8A7E9982A8836B6F6F90886C6873
96788B878876819985927F647C8D8C7B92889B8484898588
7381867E82807D84928B9D82498F85688A77A288686C7F7C
778E76717E816F787277847B9C80936F819B9E89868C7D7A
808C70747B8D7E6F8F94848E92898B7E6C7D768184669C9E
8A797574776E7C607E91717776746E6E808388847D7E8878
7E6D7777948E867991728D7B7782867F7A768A7678708982
7A7E84897D82778A81828286796F84987D917D8369737D81
869087787C688D7B937D9A69798190806D888094797C5392
83888C7A7D6975828C77865D77726D7577838B7F76788291
8695888E82968B615A687E9A6C7D7C868E6F6D79767D8E82
786771569070987BA370778B817F729E7C8468747E81787C
7D5F8271767E75868A74817F74717C695E5669717E92746E
8388867A7C7D778772738185867E80716D7787908E827083
719983976F828C609A798C7A8E877184707C828991897E7B
847983769076938A7D7E8285747F7C6C74886B8B8194927F
868170786BA3847F9884908A727C7AA986B26E8D7387897F
997E7A75816B777377817987727D8B74737D777A7A858D74
987E678C87729F97798C7B8B75728F92898D7F8B8A877483
8B7D67848691856D898C8D84777D7284797A827B88726892
79846F857583958E616D748E8C89607D84827A6C8980818B
7F8D8C938A9687868D75889E9A888187816E737C7B827E83
847F7B71848F7A7D898A669771637E938E8A727D76708688
699976758974797E628383788D8B758D91727C7984726F64
9185897E8586717C738C86627C8DA3897689807461977781
948A8F798795728E6A64816A7C657A6F9D836D7E81817276
93808E8D7A6B70837F7F70766992777173677D787C9B817F
73828686787F808B8A987F7397837B7C8E6C827A81858298
7A967A7BA17C938169807F6F7D70968B7882779086716B7D
8E8586777C748D8B7F928A7377897C637E89866F6E8CA284
FFFFFFFFFFFFFFFFFFFFFF79A59DFFA1364F85D8686AD080
BE4172B9B978BD9E80DD72726A84427E7E9954BB8D928998
FFFFFFFF00CE00BEFFF1A1B2873200FF000048AB4BE58646
618ADD71278C8197447BAE879C628B95893F7C94A57E6271
FF00FFFF890691D50027285A7FC1B879A6A2A6EA009A0000
FF25975022F37F44718C5F782E8F376967B180ADC75F4678
FF00FFFF8250DECF156681FF00E5834ECF944799FF3D92FF
FFE45AFFDA436B5EB0008E619E6BB0A66AE31A4C523A350A
4F000000009A00B832EED26071B4FFD1FF7E226F00620081
142EC2CA6D7574B9F36BA7845974938CA37482A7807D6897
00FF574F2FD9329C9B46BE5F8478FF0099FFDDFF00002FFF
009C61A4FF8C7501B610B1E66E3ADBA14E96564B9733AD85
00FF297AFFBBFE030C4F5E659A5708E17D5ECB6FFF07FFFF
00FFABE9EF3F3581A89DAE9C79BE6CA5CCAA7AA45087427C
00002500FF17FF3AF129ECA5A36DBF7C3B40FF00A8FF0000
005D00633FCE509AD464DD93764829AEFFAAA9EEFFFFFF73
FF8442C47CB1E4FFAD6A8F25290047D000202A32FF5CFFF6
E6B8E596053A95965B56584B93B79C4B7DAC789889A89179
FF28E48529E0A700B1FF98CC8B290092FF001B00FFFFAA00
FF9E78FF1C7E75ED69A35B28D9807F866F9062B952DA7F64
FFFF112949C4E47C646C877800113D4AB2818E183600F72D
00005A00D00D32857C919E675E7D7BAC9183597E8138FF00
81004B00AD7DC100FF02888836006D0ABA7D00FF00BBFFFF
1700FF005CF097579E62A8B4A263BD697097755D0000C7A6
0A190000FFFFFFC4EDA052D38900E2C6FFFFFFFF00DD007C
00A5010084485D90BA627A627351A85E8B69797C7D599461
FF14FDFFB372D5FF3A21FF44621BFF2E0069FFFFFF0000FF
00214972EABCE9386B94877D668451A6A3929849E26C47C3
FC33B65DB4130AFF6A4F870000324097BCFF8D00E69A00E6
FF58ECFC00ADFF36823C6E929E2CAC458535B580ACE500FF
FFB37098EF3C13589600378100A21DFF005CFF0066002FFF
FF3D449204ACC3A7767A636F21670157338B976588220077
00A7007D40DAECF2D9C4A8B6DB47C8F786B80100D800FF00
C500576F8D8FAB7F848EA29A8D866C9C43978B99AC9568BF
00C8666878BBE8007D5B6A74D88D4875C1FF000000FFFF00
8DFFFFD033487C9BA86B709861D3E09457016DBA2E7EAA61
0000007DF0003570DFB100851A8670FF19003DFF3EFFFF8D
FFBB0054FFD20FA17F71B9525BB47275678E007CB570C044
005E1DF1F6DB00CC4CA9FF6BA7A9BA00FF00FFFF004B8700
FFFF00FFA0C60061518F8289EDC4899651A66052FEFFC760
E65E00BBFFB712C3E3FFFFF20000A21BB6260000A83900CD
00FF8FFFC58FBDBD516864407D76D5B5D972AE8097818869
0E9A4E00CED100DCA39B8BB9FFFF3D00FD0000A7FFFF00FF
89A5160CFFEAC763926C833BAD2C119E799EBD5D779913B9
1E539DF9F4C2029871CF7B6C6799D4B9231EAD0000C25200
300098FF009CC18E7F8F9729926B4F668D5EF86F00D5B260
60796EFF007B00E29611D628F017FF18FF0000FFFF000080
00FF00AD6A65FF519160CEDD00FF6087D30F4661ADB9FFC9
FFF87EE983FFB28DEEFF350032FF00FF9500FF00FF692C52
00C1BACC578D828F9B7AAA95A9576C9D299E4D7E417557B9
C4543C297CC27A84C5736E91006926FF00F9B6FFAF000000
1F0073DE6D40546A755D8DCE5E3EC8C89C581FAA2028AB80
FFC97C62006B002C5A5D2F4071026779FF8966FFFF00FF66
B2FF6868756DD36D50CCB874D0A1835A2AA50677FF00C74A
0074BA3E00FFFF43FF00FF1BA4377F00F48700FFFF2000C3
2CFF91A1EF579E5194EF1DE77331F92D95FFC8645A5833B6
4674BDA9A594A3030900FFACFFFF8F00E3FC00FFCC00FF00
FF2BFF00FF0F8C98A0A039A965416787996D88657E394671
B10048D9DA4730988C4A51AD6B8100004BD6FFFFFF22CF19
D1D99879C8CD88BAFB8AAC3445FFB33D1A3F6671C9B6AD7A
A89C651EFFFFFFF9BE976AFAF3EF44745F84B624F20AFFFF
B600FB0BBA818286CB455F76B369B976C3416D723797A194
916500A5A4460074D3134DFA2CFF0040FF6D44AAF63C009C
005AFF40FF94E4FFB5949A19D656379A0D6CFF8B7B5F007B
9B8FAA0068E90073E6FFD3FFFF000056FF00C3FF00FF00FF
8DCE5470AA66628C6D6AA579A66C8B8B82A3698146856565
3C39EE252281C8549EEB2F40004F8FFFFFFFC6AB00FF78FF
C1FFAEB5FF2B95F05131687ED37146BBCEEE9B9B8F753674
82E1F6A14796D3507F8B5A8915C0470763AE0000FFFF0002
00E8007BD865D768C3709A96459BB77057A4EF45C0CC83BD
005DF000BB999127FF7E00FF4CFF7500FF0030C687A60032
0000DD4CD3566B866A6B817D48389EC04B1B676892000BB7
8D81EBA5BB7905FF34594F00004EFFFF00F3FF0000FF00FF
00E07B98526B9D6DB5C781D9609E8662A175A487BB929AAF
658793CFBFF96A2DDBAB0AB9A998C73EFFFFEE00FF724C00
6D3DD8755CB27D478CF2C097AB78B6A1A22F00828A56929D
1F0093097DA25D6A4E6D72BD06A0FF4E2600FFA2005800FF
00FFD69342FFA77CB066B196B41C60A94D7114D64572444C
FF9C2D1F71FFE00D3C458E90AC8A6F54505E9FFF16CA0040
5567BF3B59A741713D3A80D5671FE6AF5D517091A74C5725
C952685A783D4158E3A37626C148000BB5FF9B00BEFF62C4
00AB9B705C787BB8BA4393678B6561754AE179C1A59EB652
809BD7777ADE7293364F8DC32773F0FFFFFF1AB5FF00201B
002D7A47B76B587099858FAF3A764F215C6EF1C75FA8CB62
2191007770F962592B00371400008C5E9B00CB2267FF00FF
A75A12E0935CB2816382439898A842B0B3256492387DA44C
F3A5B6B6820B00BF007F144F15F2D1AF8F9AC9FF6B490B3E
2E68008D8422787B9E166380AC0050FFB6B342868D7DB86D
5066FB7794DF65440003730021ECFFFFFFDB003BFF222600
887BE379D05AECA5649559864900894E857F459C559D31B0
BF4FB431FF7369180F00BA9CAE4CFF8CF37D00FF630C7F74
5CB4004EA28F735C4ABE4FB49D730065388BC63DA949832A
26085DEFFEBC34B6FF42C7FFFF9CDBA8FF22EBFFC1FF014D
479896408A894ACC588C7D69A4E096822BF98D9576A7BE55
A4DE08ED727259FC0048D5007B72FFFFBBEF37CA562F0054
2FB4671F5E18EC00FE5D3E62F87628CF8C793FE87BFFC43B
19AF969C3F89CE003CFFF3A445E04BB5469E3200B21B4A6D
A2AE47BFFFE44E8B935B8270598A7738BE6C763E8337BD40
5B0EEB876A7184958FC554C326FF54D6548B5AFF1A865F06
FF48A5FF5C978393A55A655E6C005684B6B71EA54F8E71C8
B38787FFACA7762E428479006C430000E2B400E500FF04FF
204F06C7228FA9797C5F81AF689377257C9E495DAC6A59A2
72F96246F648FF2E816A74B36BFADCC5D0A03CDF724F0064
A0A380A09E1BCBC06E6E907DBF90207E8C0073B367F6865F
D3BDFF8982625E3BC4BB009A89E3879D2B430087FF14C46C
EF627ADE5A602B79437E6F439575CE963E775C78867986B3
BBA43DDF3792F9A5FD00FF218F4D0093A6A1FFFF156A29FF
881EB22E9E8584696A9F62CE54A4C4935A40494F7788B880
FF7F9FB5FF586B00909DDD1D92B7FF354700002600FF5B92
4BFF408786A76BA1517D502D5F3EF0B48A87AE6DA5457D97
4D4A9D00C158DFC2B76945F498A9AA71CA797000427EB5A7
D3C0728F9B8E3861F17E3189A7834A3F7F2C3A7080BDB6A0
95CCB272FFCE636A3C5E5E50005AC31C82C7ADFF5A625692
A85D502939D200939B67B15EA9A3353DB570A666A27A8A9B
927ABB3E3846A4D994FF8BA61CBF5100E405FFFF514BB2D2
967C803D4C4E7E511F57863580B6E7ABA555D674BD8C4F56
F9778D529FB477094FF2F87701000000250034FF09BF8F9E
56A944FF7C9952B8C02A1679C538559F9DA59A54D58DC59C
4B94C0A83BA83CFF4686696BA6326C2BB000260004FFCF59
F6AD71A66E9F9E6BC7B247976D6D78515D7F229B8672A978
6CFF4FA980847C637BC500C7B46A9846CCDD3D5F87908BC3
BE124B5E8BC4A775C2885811EB427EFF305B77A2A029AB52
A058007A87CBB284C2AEA8A0FF877275E000FFFF1D375C95
49B6723A236F5825795AA3DD98EC156486FFE3B469906CE7
5B76112400E5C9FF675A705C001E9C45EE1B00E2004F53AF
399E1D9B7CB273815DAA51797F5D49927252B8C1A57C3578
7E9C61FF0914C9547B5810E765566A88450000797173C300
EC773C7B9B517DB591785B76964787AA693A8D71BDB78193
8588C3818073608ABB7F7BCD174D618300BC0E3581C3D300
7355BC7AAF973749BB1593E757649A4955DA64C0475B8F82
AD6087C4000000B16EB9A42DA700FF00E900FF9157DF6299
C5AFB6C8934490C2867EABBCF985878B7A81454C9548794C
D4FF818432EED16A000000B15ADCFF52EC8500FFC65B4332
408887AB588D99C29F81AA847D944E4BA185A7464E675FAA
E598DC7300B126719F83805BBA88B57F2708B97186A1D07E
407991A347B0CC768083819E61784299A04A6362A9B792AA
7D8BAED86AB8710E7A543A5656862B5032BF96E0CD912BDD
B87483B655457AB82280AEA11DE1887598B242A33F8A469D
8342F632A430D462531335D37D7CE612DD00EFB6D728B4A2
BF8F0EC77A6F7E5492A28068C87FA978A21B2F313EA7845F
004F63499FA18BADCC82235E2F9E9029FFFF00314D20C08A
30806498527E6E6153977BCA3B895B957F535F6E62D198B5
361AFFA67DA20060259B668498E38532840CB0DF50875F35
6074AA44AA4D6F92938897BD5B6F8E7379356E497DB29297
1DC48559B8428F6B3FA4C3834F3D956665A479809C8283AF
5975B61A85CDCE3C33DFB6585AE73C7FCE3DB0797B86825D
A769944000B6006CFF45D76ACF28377346009657FFB775A9
B677B625348A6E8FC6A3A94D8843A8976A647C528B90647F
CB7DD3BDFF5F6900006FC0FFFFFFFF006839008BFE1E989D
69557C7A4B7B7F8C95799AAEA89C97988FA5D0C753966381
AE95173ECBA53F8E6BF75D9743ADF134617273AC555C484E
CC83826254BA7198969EA7837C82A13A362F357AAC989093
C2860F565E81665691B2A4F5897675729987378402AA81FF
003172D1BE3D0BA8C4BD4AAAA86077BD579F8664A75F5F6F
6C4B8E57B2329F6CD76CF48535A2C40AFF3CAB88B68EA2BF
896126576D4D67B2A1A06878358688425968419F727173A3
1400001FE0EC678260FFFF7700D5CF00DBFF9C8E6331647E
726D7FA567544A6B8D50657C898870B09EC6318956734192
B57B9ECAEFEB1EE8E29B9498462DFF68849F71B89A178182
75B495D46C998B3A95ACC6CB887D8F8A32529C70BCB0A5AF
2E6A4941556F97AF63E3E86D276D4F7E807D46B7C3BB7C52
6FC4C55A2700FFF084949298825A7B7E458888C87D777772
F5A3A0EA9CCB3F53854091EF87BC8C894CB17781E9686C65
669882747C8F81B6C28974858B998F55498C459A4D90BF79
FFDF795B526184880000FFFD17FFFF0C4E480093C071569C
90CA7B92ACCC8D4DB46E5D56A2927087479B3252C48EAC7F
206EA05979F7737A1EEE5A6EEDC293D77C8AB97FF27F1898
4FB4856F87539D627F8F677C79648F4F0048914862677B8C
99745BBA4F915BFF50A1A52D08929D85B17C1FBF7A635386
C182467176A1A044A5C5652D605EA0B97D4F818494569A93
724DA3589C5992416600667DE088FF58745F4D588266778E
7F7F664FB2AE8E7F63479162BE8F9655CB5EB48D8E808450
007FF9DC00A7FFFF4339FF74003672020FFF6A23BD909C0D
6461B37A3F459A5D673A842771B76CA934CB767DB05AAD4C
6A3D355373787CBF90B8823C7474887574626C73D06E6466
2E4B795F469A6745BF7E5E9763816B614A50646E768C5684
ECB785D7635D3B5B51384D9E91836D9A76745BBA56C88198
467940A40AACABB6C7201F9FEA9AAC973799B5785E968D92
F0918EAD3BA072702C9AC6BD2E97979EB12F917F9D562486
B8AF7E8DCA8BE579AB5A94A4C7CC52796F3E8E5777CA6CC2
00FFFFFF000050DC2F1DF2BE000F7E4A63BEB7466E7BA748
86AB8278A09EC79786A398D35F9A7FA3ADA9A6666E75D275
C87ED69AA77336609E805A7C816691655E883BACA87FB65C
62914281A8998B9A60A17B6472906A42626EA58E73777366
2EB0E2BB78A45955AF537F5A774D808E9E905C6391CA5E59
82D439AB5E8B8E237DA473B06E6A9541A9B78C636C679C4E
0C6638DBB880B6AB6DD610EF639E601F794D5D88603D9693
735F78A03D8A68AE8FADD0CED89B75BB6B74878CD88B9292
00A5FFFF0000E2FF80E5D893004BB8601CB69E874D9FC93A
AE2D9F94785A8EA46567947F7D8F78BD9C53916FA967825F
95D08F6EDFA7A0777B6B969EB5D83D4A9B76751F716D798B
8C7E9159919D63B867967D5074462A6DA06C7AA098908088
8AC35B8E87617B985FC07E69A15F9B7855B96E9EC6557F64
A0BAAD7E7F71617C7F8551745B637D86676D8C6B6D5F6154
B8A6818D4B02586D517F549966CF6465A0A7978C7C7AC593
B6566E92654F8E897ECA63C79F7582A183707D7F78637F8A
00C6FFC00000FFFFFEA41642072EB2AF888C7CD39765CF99
FFA17C8DC8B97F8F9E685D8F6B5C40617E6FD15DA15CB063
6CC2DD9895C38D6E766842A08094957B6268685882AA8756
B088C1827C9A6553884E8B63599147737E798971639675A1
3B80A75B62EB65A8CA4CB2985F5F163578B165A082689B8A
718270D447E59A6F22A660B170A05D7B7A8B69868E81575D
48616D781F61684C3FE048AE9EC26EA770488A89866C8F6C
6E7B40AD41949E65A977609E5C67C781517A7E726975A091
43B6FF7D3D1B74FFE8BF373A334197295B4E34B566859C7B
618A7EA564828E7D6BA189745B964A928670885ACB776595
2A7A7B3C728D6C50525F8E8DA86CACC133699D6CA59CC380
6AF55373568D5F7B8C799B5D627D9F8A8D7F7F8C8B8D5652
77C749918A678289D17C73B9A0475236898F527B9E70A096
9F8732D6A48D397D7B5F99757D6DB45F97BC5667AC7F807B
548CA5CAA9517349605ED35670817E6E8466958736486656
956496A277A67B894F698F8B8888BB7F3B249AB13D72835E
47AF52BF3C41948D96708E7C55472962A436299F898DB85F
A273946B2DAD36846C678654BCA86A7052BAB27776A48185
006046505D997CA6938DC24E5775B899A77A6D68B28E5E95
524F885C6F5F72B55381A06A7892C78C838C696C7E8B8F8B
616761F064754B4DA8A672B893646763A54B65B0DA7DAF7B
999A77733C957FA38A9F54805D6B896F7E93642D95A97F82
840753ABA9665FCFA1743B7C7735C4A76492BDA0697B4DA7
719B79B28274BC4FC59875846F99CD627BC96997859B8E9B
A76BBBD6B4849D8189B8AB48436D1D13879166AE4F576867
948975924FC25D957F729CAF9E67829DA56A81846D486E64
82464A7648A42C7B5452ABA27EA16D65B7686EA487AF787D
8B8B874A7D6A94716C739A4C7A70B1A58A957897858C5293
DB4E82714E6885B5896D7D4D6C77886494646984E26D8365
6F7BB27193A28C8D4A629A6B9598B49585608985566773A2
7E8F9F0DBA72695C8063842685A58B939C9F846A996A756C
267E737BAA7B819EA5A37D889797BE7C5C539C9198675E80
81666349608576347BA199767E9C9621958DB4767DA29B88
6D7150776AAD75A0C07DA2BBB39FA0568F365A6B88746E5D
AA52C25BC49A61C1A0A279796163A07D699536AB866D76B0
857F84797684732F607E7F619DA17C8FA26F7F877887858D
B68FB88E5B754F7D5E876351B14E8E589190868E86A78C34
5890B39C467C566042A47EB6AE6A9B6B7D8C8D7DAA5C6F71
958964AA82903C739448A78F81757EA0A09F7774889488A8
6B6E7E6656C1809F808A5CAE7295E96866786C7D697A9280
B5C58ABBA98A9B85A88A92274B9A891B9A58BD7A728B87A4
706173687C88A6657F9BA07D93796D24825AA985984E8E60
83526C927290B443996796AA72B67CAA3A5FA256B19F90AF
71BD6C889D9B8F6575967F6584927554725390815E766D81
DAAF73B55024707F1E948A57868E90AD835F9AA0A78962B2
7B757550584D629591A083A47A559792598A8583BC7F2F4F
9E5EDB6B995BAE4A768F4B958E8ACABF8C5E8369AA81A381
97A650A1867864B5A3B866AF909FA4565381829796507A92
6D6259CB89847259A2969C685451787CA6948BBC4FAF7768
93A59181B187D26DBC66527D7D9AB0B2705F81778079B07C
5F47785D9888B78C4DA9A6588A857A6C635C6B7755A58D97
A08B86619D9E7E976D539866B49D93908D85807D73737080
9F72B180458A3A687B696A84927E47859A8D6BB6979C9F58
92559D647874A765857C805D89A6C27D919E686C608E829B
80865EB4B3A7705EB34FA388A88182826CBF729083639A59
777699A48D92649F6A9D5AB357B08C8B5A6E7599687C905A
9EA98A96615E867C87AB8C848162688B818A9D7F5F8A8B51
818FA277868CA7416D7C88A0939A8C6A749D4C717B72A36B
76848F604A378C5B7FAA6B86AE9137ADA2868DCE81909D9D
A5834DA5A5807175968E9A8494A7A27E8D8D999D968F8278
A19056707A3997A28A96848D93AE6B767F7F9D7082A39461
7672717E7C7967618A94746CA1897A55937F7B8197676985
74651A6179B4A2AF95A26152997677818C8DB95466658D71
7C996B8E5977A4818272639F587E7CA18497928B8E9989AF
7A8D3A57A658B96C87A0904A6FB87ACB467F528279B77C9F
A59E9F6031579188899F727691588F807C957B7D93697153
894A9C86808A72BC8864619CAE53B879BFAF8B8A5845BB52
71AB7E769F77BCA067828C727D84AE8C6FBDA598A38D7491
94858563796B6D6D70BE6D5B6B917093A56C5393976B9378
BB76708161737A92945F8DAD7F8D7E9674718E826F839684
6B956569429D8D5C5BB05B5D8596689682366A60597F78A7
98886A77836D9F5C8F7081A045797D9896848A929D75737B
A86481694DA68C74358D55A862E269746D68BC8A628A8591
6D96947D617A9B79707D3E7B897CA8A0848678996998698D
8BAEA3AC5F4A9C6C8A9255A5A16780726CA37B877D9D5A7A
7873966CAFA76F7F6E9B69739174987B73799A73998B787C
43A0A67E88B0548FA07E93BB7F5C6A5C6586857A7E6E80AE
6C7A99516D85719D5B8E96947D98738A656A7C9D5D84A5A4
C96744B4B25E658D94857C7D9965496C778B565B93696571
618A74A690765F7E7D7567827B8D54755F57747A8A59868A
24579B6957518DC183B881A38C4E9C7C6E6B7C5BB3747C70
763930A97B77586352977877816E61876E81876E696F8989
A588C8A5628E7B6D98707B8CB05E8370749A7194A1A4835D
918089A63F8C64438471827A9C67678FA5938EA78E718187
93836C81659579807B45BFAA80776D8C879D8378829E6E9E
6B87A17E4486665A837F7A615E919E787680748185778460
579D7C8E6A5F8298A06E30657DAA8D8F80867CAD7B5A7780
60A17BB28859BB867E907D84827980975D7D7A787C6F776F
517BD1806F75967F876062A3898E618794B4709541668C87
B09F91805E90B875877F768E8087A1808A6B8A7E688D7979
51618F6058BB7C6B888B7CAB7FA75A7A955D926B8E6A716D
84999973B54D646C7A765684787F7B8D68779D6D5D956C72
7B81728EAB7C71986E705F849DB68152985A5A89989C8559
859A74856168587999A0707E86819C7F8476977B779EA29F
6F67AAAA736F857F78958B7B658C816D7C4A877E6A846A71
7280B37C5A94747371768DB1A072747DA84B757D957B5591
ABA87FB67A568797A166928BC25C7588927B86867774674B
898F7992665B8022457C717F6E716D7985748D908D7BA598
48727561878B83A8467F645A689ABF699980809C975E9C75
87837B7D84A45CB45E7A7E6A6E637E8C707C7C70A8957589
A3729C8580BA4B748595937468787769966DA382923B6795
7F8D8F756E876A936A6D6D7FA06DAE9F887B787A80728084
769E836BA87D948D97A8A668688A926760974362918D7773
8B7769769F60A194718B566A6F7D6A9464898C937C737172
76904A94A28B6897D0716C8D99858B9B84A7877F777B8F7D
A697669A73548AA0A59C676263765F8276665C9669845579
8978A45A875F6C884C5997628B6A7E72A0A76295AC918284
6A8D7D9A90918F8F8E6970905B8F716372746878A07A7F6D
899A73A161498295AA776E7695959578728689A25C9675A7
7381726E7C758681767BB06A7A82997E727A6D5F75AE8685
935A878F8C96A28690966A94B39A8784793995A37E6C7A78
BA547D646D8966996A6B927787626D70656B727D666D9F6C
A07D8482AF6D927EB85D716D7F688DAC826AAB847D58653C
83777C9595937A50597870767C8E846D897F80626C8AA176
7E6A717D92547864878D6CAA727AA7958683A56C714F73B0
708A83758B79837F72738D6A608C6B5F71834787A2797B89
775E75816E7F75A66EA190A7809189957B6BA36F6C7F8CA1
8D9E7A776E8C7D9E70728269958D8971A5618C9E90758C65
9B646D897A736C594AA174887A83597F809876898D70957B
7874729372598187817D77777A7E7A908B68739173947E76
B6579576778D746D83A58E6F9D827B7D685F385975899E8A
B66E7B75685D80857678845681726F637E71897996905889
687B6D7D71996368718471AD795C87A4877B92819A6D7192
96A15B8888777B826F69A96E7E9573785B8077829F677E5D
A47D86837D54595C859BAE6B93A4822AA793706265719B73
74585DA7968057838396786F79968691A0777B7F8484738A
B2927556667D8191A6B04A809E9B69917C999E769281977E
9A89719970626F657082736E868E8D9983A38E896A856D69
867A68775FC586C28B875C658B6F9081688A6A99948D659D
92798E9A846585898FA88071587E6074698D928D78858E82
556BA0717E798084617C8BA1947EB1998884BC916C9B607E
A07D838C878C70788B886CA0687B7F79678A70627A94836D
7C93837587795F92997388978C9D6C7989917D887B706D86
7E6F758BA26D567A888686B1937A9186657B6A7B6A906398
948E8F959B9B7383AE705F836D7E86796C97A16EA58780B1
7F7B54A9786B817D888E8B8D8862788F9D9C717766798B84
A5956C6164985E7D48686F64A577A491A87C5367AD8CA195
CD718180707F88997179757D696F9589947A6774856A7472
55707874846D4D7B889499787D5D818B6E5388947B877483
7D8D7761716D7981836B7B979D7A95798179717C7E9A7D76
8B6F798B74646A5C9389817170827E5BADA0977D95547778
8296A5888BAA7D4675768986707B8B648AA481AA7E71A196
8498866997995D545F7A829262986A92A7A1869D64987A96
5F698F977362779B78B16D817B8C617E78808A7979849188
5C6175937D9678A1C37167807980848488856D4785817B9D
89687D92975A76A24E8365A36C76718E7A857B8D62898E86
6177B17398A27AA26D67848E5680516775A3617E737C776E
728B875A748B727D8268787A8B8B9D7A7E9B7B6D8F96746F
8F7057A79384829A768C7C6A6A82917560A5A95C5F8F7D6E
868559798273658979938B8679867A7897747A617E725E73
736F7B817C868AAF797B717C71909B6D517A418A84757B8F
77696C7387A1A084955E848583A98194828A93817566966F
7F9A8B68818861736F6A72AB8E967E986FAF5A73B67E7171
A47983889E658A86847E7F67787B706961887A6A8A878783
8881A37BBD867E944E7371608D806E7B96908480AC79767B
8597878551817C8C6B759483998DA1778A848B878C906E8D
8997705F9A6E6272AA607F83598A9F72757D8D8BB06E6D8C
906D7C72878F78917E9E497269998FA77271807A60916F87
6F998E8594798D70B2A2878288728B875F6B94928A667B90
879B6D515E8D8D907B847A73A7AE737A899E768D81857F76
757C95847D6B717CA952827D8AA46A7193938F619E846A5E
7C78658B857A746F957A807E717E88658D6D8B80728F7B6A
8AAB8D9584778E7A7E887085937D626B726664918B597276
767D899C7C6E679D9D72687971757C8A9A7690867E8C7D75
766A8A876DA296817B70936F7D826B989D8E748E927E658C
72807E9582858A827E706A8471716C7E757E627D65878FA4
77A43D7A754F886A8A5792876D757B958E54658A688184AA
9E7F93868D8C9F7A5485878E7B7C755F89637F7485777D83
9690757E7B6F748A7BAB607E769CAA69879664717572926A
7069708686959C7FA28794728F7E7B757070855981847592
6566808B787A738A7F7687617A7F95B4867E9953627D9B85
73806C7E997C89778489A464868CA78C849B7E716B938F7D
AE9183657984717C915174897C749A78886C706F6E75886E
9382837F907460887E788C6D7B7A78877897788F99806C75
8767859B82977B7D739E9485A18EAC8283878760948A7770
5A827D795F5E639A646571647387748E7B7F657D81717180
84717F5D80848C868D987F668B7475657E6D6D8EA3826067
7C88819B579778888E937B7065827299867D817F84957098
715D726A7669746B7D63896B846B6E75757E789C71848BA0
9B677F8C767A6F5B6C72798F8382719182836286845E8678
80AC5C6E9576AA918B997D746788758658758A77967D5C93
8B7473A27F8E628B6C837F8E5C78886E81777A9170828670
678D8893858A7478746B816D9D8F799A926F7E8D7E768590
84677E869D9E96897DA68A848C8C7071876B7E738E7F7F90
A388559266947987738D686A7E965E669B9F7C82717F6F88
8153988C756D8D8878A1897A856C79726E738177947282A3
8E7486A97B719A896F6E906D75888D759966A1797A866A99
87846D619A8B6A789C7CA07F737885796E818B8181799297
62846CAA90759465686C667F8E8B888C758A8069A7B08384
847A7E926574817998687B85797B807363778A847B7D917B
70396E8B866FA48A688B859D6E7C787E807D6C7C7D9D71A1
86998286717F73916D7F686F777184857276737D75609191
826A5197989B867384608A7D7F686F61737D957D976F5285
7A9C9A8C718F73887EA36F5C6B8F7D72897E9B817080767A
8A95AF848A938CAB5773719B87729687727F896C705F6B80
68898F437C897A8D7E5A755896766757758C5D8790987F8C
8391795574728C8765889A6F787D89A1A16D4786957D7E84
7F587C838F637F929C788775757883938E86597D7C877074
70859899677D7A89848E746383809680758D7391867E6F78
93918E7986747C8B6E7C8389776F8D847B9798755B968169
9076A07D9A8A8D92737D92A398807C7B8C99896A706C7889
78827A9091739E9A9D7D8A7278797F87848D8C817E809B80
6F96677F7F8A7C82758474759F84698D6677879090548297
9281767F6E9C768D86848F678F739B7992766970747E7766
8F818597986E5873A781657E695F7D6E9392837C6F608378
8B927D6380827B759A7C6DA2687F788C77A0786A78898174
837996749E928464A465919D7C8F5F73839B7A787A6F8697
8268687880818F959D8D86838184998395699479757F7D89
788357656F9D9E8B8C7192796066678081867E808C87627D
6D867F7F6E948B827F717D7B7487717B6A87788B84897C7F
8075836A77A8AD5F83728984806F79A4789F818090798082
908B768A718E6E8073806A6C7A6C94706F84867D8882848A
897B8E688E8562677597896186707A66787EA3848686A97A
8B966F846670807C6F8987815F848C7B7F746B788978856A
AB6D7C819F6E7979788B90917276778185946E7F7E788D9A
917D91818B7F7C8F948B90988D82866D7687807F7A76757A
578B8190916A82686E6F98A48264767D8081737780556F68
79927A96697275789E857596636780867E7B6A9171918484
4D7786537370638B7170647D7053708F7085827B747D7872
7D7788836A8381796B6C76847A899C798C697A8673839294
8368618D63947F8976756E898D807C8A8E7578AA796C815D
A7918586828E7E987965727A7472967B8A6F89779586848A
72888C79768F838774798AAB989181939D6D8071A1717782
6E75827095817A728262839C948A866C7F7469707B856F89
747EC47C70659D897A7592816568857D8769876D7472974E
707D888F8A66816795808A777460847A80897D8D83828979
8078AB8382988CA08B818D7D7296A69475826E86869C7B75
98868F796B7C7D7C897D7C8E7385889E837E757F9870818C
728C717F945D866588798C858CA37C676D8CA89D4E606364
6F70998083908F4A9C8F8C99937B926471947F7F78878A6A
71728A8E76888E7B8D6E7C6F6B8577887A818B9A80688477
9197897A886095798289615E5F957795818C838B62607693
739993918590776B87896E8C7A6F647B98697D8D94679071
786D958B8192898AA1847A8C837C8173947676707D648A77
718D8A997778948A5F7687649A7173818691847E8E8C656E
9276839A5792807C5CA1886185829376967E738D78837C6A
8985889884727C979D647C55857E886E787E8F9089717F6C
678A6D998483768792967E918C7F85769D7E6F886B68A6AA
908C7F7F78746C7A868174937D647B6076958D9087906C72
856C907E8A7968785D6D7D81818F838788738680747B8785
8B758E75747E837E7A7E6A849A9B679496835B9F917F7873
81888E7F849D7B7377747F82828696798F8A798A707C8F7E
8890869275918BA4597E9E648A8F9687827E82838389759B
7F62859D6D9988858D91897A907E698670776C7790698E7A
81899389818091628579948B8982458F8A85697A7A8B7170
916D727B9B9085827A8B84777F6E76617D7C7481917E7062
9168928F848D898C788B85915F797F74996D73687078877E
989A7F7F878E94748B828A87826F808386816E808B87819B
8C777E8E777D889A86757A6D71669282679188927B727F8B
868B6B928E847E887A8976867D83817889616678818077A1
6A728676767D738B907B989A7883A54C859C88887D9D7F5E
818F768E7D8A857A985D78978C5E808D7A9D7F766F8F767D
887D9098827B5F7F6DA089737D7F866C919C858C8C7E5E8B
8A8F75718E91687B8288778A8C6E8F8F89675B8083767785
91866F72909C7492638E8972818177827C8A7C706C6E7182
7C67716881717F8A7B7B9673829B8A96756C7B8C777D7A8A
89936B9D8A81858A8190817978808D9C8C948281748A7C69
8D80668B829C7E80887D877C71858D7E81897695716E8772
8B7F6F6D6B7C806C789B897B62928C867E8A8D5F82818698
866D9876787D697E6E9481948190926E777C8D928E8E8674
8C948F89726B796F9057A08E708977A07498607581765B9F
8F8574928D6B706A8A8C936B7D84918285827B90848A6D8F
637E91747E698E7D8A7B8F9E8A727E7E60807E9292816D78
846D7E8486758A809B757B7A84877B607D7F858D848C8A8B
977D777DA38C6D7D90967E817386A57E85857E80816E8B8D
978E7D748B7788907B876A9B687C7A895E7A8366857E7F7B
70817E689B8888827E8079717E7B7C958987907E8781817D
8D8F6F787F986E777A9077837D7A82636D948C6F8D7F766B
57A29488808F96816B8198997462679585848E7B95878F9A
6B7478945D7986886C737B887B98676380787F8777828E7F
738CA08B6D80949685917F8176958F6688997A767F89969A
879278888084888485817BA29A9B88797D898995797D7585
96996A7392898892836D757D88A7A07484727A54868E856B
826A99836E908295948569697B7D83886376738A81907883
8D92927F7A8C997D957678847A7C8275978E71809074797E
846C78718D707D90747973857F86808B767B767A72738381
707E6A83887A6D8E947B806E86858C609A917D8983887188
7B9D67848C858F85867B757E868A88896A75858679798C8D
777C687D9D7C7B79557B896A73728381A87679847C879595
907F7C807A79757081686E72827282978C758A697B8D8B7A
6F6A77836D8B9C896B82868A6D747F668686826D89849F7E
7D83827E996973778A827D997C6A868E7177708187779984
7589835A7381597C75556E7F667A748569796A8689909172
7D5D7698856C93A47A6F8F778F7C74878C7B7F886B758967
FFFFFFFFFF9FB7A0477517CF0038376517E3CEFF00D400FF
0072BFA8C85FB2A18DDAD5774DB242698F7D61A78C91A364
FFDFFFFF72CC465E8465A7A300B5E4CE7A4A780000F40000
00000E1688FF734B2CA4223BC4708FA3AB707F803FA0D084
FF00FFFF000013FF3F3ACDCF53B4A500A6DF3C466200FF00
409A00BE0EFD276895E481CE73738C2BF79418E0AA83A836
FF00FFFF0000006E3C2EFF6C6200E32200FFFF000000FFFF
009C1BEA79B77B71D2D62C3DFF490000FFFF560000111B55
00000065FFFFFF2BD66B590057F38D8876B11D4F32411F85
A0E4AB40C79DA1945B89888F965151B88B509F55933C7E74
00FFFF760092FFFFB2A835FFA57661B87B6BD70000FFFF50
F508A1002FFFB39880997055D77969B9C55B7AA32E799654
0029CBFF7B00833B46775438DF385D78FDC63A648C00FFB3
678C9E7521A954567BFF92808D9283637E9D50B9839256AE
004B00FF00FF0082AE61DC2965DA01C4FF00FF0000FF0C72
3CAF63520995AD657670EFCD7800007FFFFFA82F24935D81
FFFF0000712734FFEFFF423E50FF9260FF5960006205A198
78FF7F9FD5797138978FA28D9265907F768A6D6A665F7C83
FF37FFD54B8CB5FFA7C26BFFACB2C9DA8130000000A1E7EA
FF3B470000FFFF826E974485AAA962E2F3849CAD65B89F79
FF8FCCFF4E5B52917F394B14A35D1714F7FF0A93EE00FF5B
EC67B41A982AA448CD8A67B1B3B9739A83A866D2549E5EDB
FF008091B45A00FF813953C5474467FFFF00FF0000FF004C
CC64005ECE36A16657EB824062001BC4E5EF5821A9B353A8
FF8100FFB21758A0465AFFA8FF71AD00FF006D006A00EE60
B1FF247AF487414F648E4FB0B7A37B744680578C407B5AA4
7C00001CFF62A5DBC0FAC5BC7AF8BF3F033D0000000000B3
FFFD4E0053BCAE57A3854E7487ADBBDDFFEAE0B0A8696C7F
FF15D3A76DBA0193FFCA2C55598899A1FF682326FF26FF75
B365FF00929D593D7E967C7B80A76CCA6E8767C26BCD17DD
FFFFA2CF00091CB3C1D837A93A5AEB33B400FF0000FF4C00
02C44A8BA93AB5A766A8844E1066964BEFA33C37AEFF3B81
2500F700CA33C46393898C9992CB02FF00588439397EE764
C845B586414E7C93339099759D8AA6A759794E445FA445B3
9BFFFF920877B556B993FF354DA1C598CEFFCD9B00000000
FFCFBC1065C0C2AA5726888841925DB9A7C4AEC0CCB9A69F
00D176000069FF92B9733FFFDB84CFE2FF1B008F38C06EFF
B700FF0091BB947A92868952A6CEA497585FA85D4CC313C4
3F008AD618FF6B97D04967CAFFE50021FF0097FFC69CA500
00AA8FD7073AFFDD3909AF8D00E45B00FC3346F2BEFE8F98
09A900309037E77D447BFFED340074EE995100CF00FF6971
FFC02ABC0096216F9BA8928C8684B135749F4D596F924398
0000FFA9009AFBFB0B006AF533DFFF66FF17FFFFFFBC0000
E98EDC324A64FBB3976B7EB47043B6F6AD5B767BB8D8BACC
00FF916E9D9E6600DCD4FF35610EC0B71EE6006E6AAC00FF
7D7DF5006ACE00B373914FAA8C6271DA8173B08143AD37B1
00AE62FFB33CC7881B83624C76842490FF0085CE00000055
9B76AB243D90DBD5397BC98A90F358009588ABEBA1B16691
FF5ECB27841EA0FB5499AE8500AFFF00A69E00FF00FF1BCD
DD825E4B818C7F5E69BA607D74887966923B8E879F894073
FF74BEB38E36003FCA0CAB6900B5FF0030000017FFFF0055
FFFFF75B6E58409260605966729FAF9B5E22989A789D7EA0
66930000FFE20E4D27FF42845AA6163AFFCC4400FF0068C0
0090DF00BCFF00BB43A7A35A7B5071825581849D48A3499D
FF490900507DA83F6DC254ED6718BF0571FF0000000000CD
FF9F5B84FFA1009AFF156CFF977E5321B5D98086878887A0
D9AE006D2BA2B6569BFF860000FFFF00FF8000FF53E5C847
7DA56932B88474EE4E862B6B59758FBC6D71967C939844B7
FF6200DAFD8C22904AB92C007325FF68FF6A000022FFA14D
DDA7AC9A1F09647F6B7F6AB2925191BCA66EE2206E947B73
80588B007FB7BF7AFF8290005CFF31851FAC1500E400FF7C
00D6B930CC4AA3C84590346C863B8AA39A5D53FA3E9E4E76
FF00FFD988CD334A552876C445B51935FFCA19FFFFFFFF6D
CCFF62FFEB632150FF008DFF0D56BCFFDB81789D46064577
6379509058E358C436FFD70072FF0000FF008DFF2FB96AB3
B19B68B48F29C332BE40C46A4A67929388938489407FA026
0098ACFF72AEBE5B9927DF4484C6FF00AEFFFF0000677800
72D990C8674DA0814E73939BBDC7A49AB747ED6E9E8F6B8F
FFF153BA78D011B97994F055534E2028AD3700FF00FFDE5C
00FF009FB06647454C528F994EB86DA53F9870A42E6A898F
4C002EFCA15A9800BE55000048802F9F0000FFE96592644B
84BBCCC06632896B5FA3CC0755A2E3FFC044A4921B23A8A5
D14289654979126BA8FF0900FFFF00AE001CE2AF00FF78D9
962EB98C5E79AE3C7B7677837F67AC73C236C94F80746A89
A0BF61F9BB167BFFD500AD5EE95FFF390000FFFF0091DE00
A6BF3964609391555F8C71814997A79A7172B7A275705653
00EFA393FFFF2C3C4391BE99524E470000B2FF0000FFFF00
64FF0E79419354657B928685B6BF55CEB800BC5C864C6B73
0095FD5A809B71AEB0A9D381DADA0025AF830000000025FF
3600D86002574988BB701367BB5E5FD8763A6E4755B6B6AB
FFEF006027047852FF0000A3FFFFEB00004ECE38CD76FF94
9E07AFB416A973B475795F8862A47381BB44D20BA05ECC63
F9005CE2FF950198CF9200003E8AA4D6FF0000FFC67AFFBD
6CCCD53FB36CB0BD3D48699362A4D8856C2D6E97617F5684
D2000097175696FFF7394F0657235F0000FF0000F4FF0000
FF704B6FA2C65C6CC3B85F9DC2B7A857EF45AF346C146DBD
FF09F334AAFF91ED9B606B5BBE1B4BFF6866FFFFEBFFFF43
63005C53008BA03D00299ECAA28466646D979BC6D2B68B6D
D46159FFA04875AB001C3A4AFFFF7200007274F4A78F55CD
8CA7597A344D86A9A743867E52BC46AC6DB5777A843DEB5F
81004EFFC36EB2AE7900FF12B16E0B15FFFF002A7A0018AD
7DA4EA523A43D6D24AA0AA6C753A57C1991E7ACA97A47C72
C2D22B00000CAD7BD189002771380200C63400FFEC7B0756
72B4BD00FF2F4FBA724D3FE25CC9E050E560A0D40BB56C9A
00F7FFFC2200910A77007E7D6CB40020A1FF610000003900
37C0BEB89F83715D66EB8C229FBEAF6FBAEE5F909F7A484B
C911EFF7AB8A680018E58171FF354400967DFF3570FF1BB8
624FA87837C273A2702FA687754B998A75A86C92864D868C
911EA7C627A38A43738E969741FFFF000AFFFFBCFFFF00D4
6B888B3CA5A270D70B6B75756D5E9171B488AD7E888F6460
AA763581A79B00000D002B2A641265FF0000FFE2C1005200
D3BE00E89D56B200C175528988AF5499DA588BB164ADDB31
B9000067554FFF694D00EF7A00826FFF5B00FFFFD9FFF56C
3E7D8EFFEF84E7F0B56B91795B93836E4B641E1D416A7765
FFCA22FF08701322FF00ADFF0000FF443300FFA2FF252C63
7C7260C49A434EA8958D5555729E7D73806A6C9F656F6FB2
AA006C9FFF00B2E24A50FF000000CDFF0039FF0000FF3DF6
5A8AA7243B75756A5C6958AF67AE5E5B6672A49A75A48B6C
703425FF991C69A63C3B245D11FFA40000FF5DFF4DE81793
B33E54D723CA3628CF81898DC0678189E22C9A9D7F68ED00
FF814D49EE2083262E41386B7FFF321BFFEEA383A91C009B
9B56A14362E9CBBBF6AEBC7B22588EAA49313BA58684C5BA
FF3498151DFFA71D00FCFF0000FF5ED12EA4A3FF6D3017B4
85A3428A57898E7A61C235A57A999C4A8E5B87778A85A075
34612F8B68342F4E379804C4FFFF00C2FF0C95A300000073
879EB87E398682AD506A8A9381D0FFA364559C655C8E976D
DE0730164A43264EBE1C699FFF9200FFDA89FF15E600E3FF
1C5A780DFF321BF082F66AC163909FA145B4A74B3CC09E1D
1538FFD98500ED0395F300951E00E9E105251E4096AFC68F
ABC17666A5645FA09C834376C55165AE76A9A1AF86705171
A19400FFFF00DCDBFFF60000FF6CBF71C15676956F41A2DB
460BD8796B89A32DCB6461A59C71A37470566B828D916680
41B1BD2AEAFC8300FFEAFF0000BBFF00CAFF71FFFF8BB3AA
938FAAAA639FB3906F9E649C5B83BDBA9548825B4A958356
883505F7675FFE43FFD3FFFF0006FF288AFF11FF00FFFFEA
1C0046FFA255E06FBB8E239493A5A89363B765A7798C3AFF
350EEEBDFFC0E01416AD02A4FF4D004C72FFECBEFF96670A
23867691E6916A7B627A7C8F945067688F80551A587268A5
8246ED0000FFA2FF2A00FFFF7D9A007ED7944AB6D200A4AD
6D6E7D7868E1773EC14D57C4988C962FB95DA46C527A789E
7B0062E0FF1CFF363600FFFFEF00D061003D00239E009C5F
BBA0268D3164BD6353A5739A6F649381989060A0868B84AE
8D8F1E46962093FFB0F5FF0058AB00FFFF4FA400FFDDFF34
6803A3906667593BFF7C73E02A93D168B082A58DCA7C3EFF
30ABFF1AD6621AAB3EFFCF007AE9D566002A4A40654050BC
955D61196FC0849987AB73318BCF8C4C74549497978B617B
6F6900EEFF1859002BFFFF00000047FFE77383990BA68E96
3F7C8BCC6773529E59797AD957957180928D947C3992883F
FF60FF1BFF8F0785FFFF0000FF607BFFAAFFDE04FF006062
57EB9EA2F36B8F776BB688AB928D405A7171946C789C6598
0000002339DE0029FF005E790000FFFFFFC500CFAE945259
32998D837A323BAA12D4D680709799979B634AE297328E31
FFDA000091A06FA3F7D9197F74967FABC69D9180B16082FF
90ADB65CBA8749AD657B353588809098A692E2D2838C8286
00FFFF7800FF00FFE0FF00BC3761F1D0756DD70A8D31F14D
514CE04F886E7EA68E7B81808D927D3F78BD69A070995378
00F7000840FF61FF0014FFE4DFD51F8F9C00FF66FFFFA1FB
D68F9EA4BE8C887853C3954C7ACFC27F7A87636EA3778578
00000076A1CEFF6C46F1000000FFFFFF8E00F82A93075D9E
4167677970544F655F8AB664C45B9ECA4C6285C65E57B97C
404356657E1A9B4191DE1CBC9B7C7B267050B76044639545
558E698052AE6A5A723E828C8F5D77763B243C6146B2CF61
FF00003CFF00FFA80000FF9AA259EB3E71AA9356B27E9B05
6DC9F55A255A89CEAE5E50B17D7B929080648EB063A86652
9A3B00FF000E0000FFA4005F0161FF00FF752F5149002A51
58C08AB4947B48AA72AAEF210AAD8E578CB57D7571B18C7B
FFFFFFFFFFFFB3A1000000FFFFFF5A000ADF000000F9728A
8D2D806A8C238771FF5836CA707ADF56545DB13184C67770
710047567617AAE3478B7DCE80C5F6D252589A67A06E579E
97A484852870617D8E3D5675A7AF926C3E93B16F764B534C
00FF9CFF00D6471786BB25FF24C303ACA300D882A8C14667
58E196685D4F4696869944BD7379917FCE3C7C7A84946A65
AB8F9B00FFFFAFFF2DFFFF55FF0097BA48FFACFF68FF4C87
7D9475A55AB5468D1A358FD74B78809B56834B93D8BE7A93
FFFFE45FC4140000D7FFFFB00C0000E2FD004E00FF95CA56
94A480395D8364B34C65976D64E25F5E41DA67725DB9986C
C4B1A69C6493B6997D3B649D9D491D8ED3A776505369768A
626A6F4E6A7686704B8E536D92585793A7A8A55C62558A9F
F035A419F90000FAE500FF167E0CBF59A96C51C1B8518756
AB8652C41447A882A15F7E60B56F5DACA251788C727290C8
8AD200FF001D1800143FE23200FFEDAC25400E46592D6A86
A06A51FF1CCC4DDAB77F8C908F7A8DA3A56F7C9082756F68
0000000000E2FFFFC700000000C9C1CB262F20B59CFF462E
82B53459715BB3948BE86959EC528241A8FF386896887826
6BFAEC4972EF647EE05C9A9E909E8567035689CE8F809993
BC8B5254907B759B989362698490606F5C252A72D4E7AB66
ABAB15EE3948DD4E2FFF00F837A55B793DC6B4727C55B1A4
661F9EB479404B8EA7C0654C8665747E8E72757F82A99784
DA34FF00BACC1BFF5BF900FF560000EB4FD4D785844C7066
7D6465DEA1C69974B9A27B4F52666D93D78083639D9B8172
FFFFFFFFFFD3000000000E75FF379B3B241FFFE0FF376354
773F986797ADB966EB76448B9E697252A471A16AADA5914E
5152C9667C877D91811C54D9F39AA3F69F9E31A2AD039B77
A497517845C3E16D789B8579A4697FBF7FBFA8A67D4A6E6A
79C73A967E9F9040BA00A833F24F53A59F50B67B7D5AAB5E
89B0B963417B3E90BC99653C997F79907957949A7F99729C
7FFF00FF2DA98D6A00D8CC252BFFA24DCE438CAA3F433456
035A004C3465AF6865639C797372895F5381949D90778C7B
34000000007FACB0DDFFFF587BFFAD9CB5FE874614E14775
3065A09A9A96B6949742A266417F6DBB57A26691DB677E6C
C62E844E71936E92836A957655AB8EAE65846F436D45BF78
9AA5A2CBC5984D9BD27AA3765355707A796F33649F8D655C
AA5939B55ED45A8B39CD997C2A992BAE98BCA8007D808A92
A990557E3D9D7C8A9D9A3A659BBB61AC6E668E977F8A4A8F
DC1539005C9000AFC3515BA19400ED478397626A60747286
229F98A673459A898F66846F626986917A698C888A667073
7DFFFFFFFFFFC4E7CC9495FFCB4065BAA361554CBD6D2653
BBB9B65F5B90D05140E25F80638B98A0C93E7285BC597851
5D43716362DD9244986C7C85A7B63E6EAAB8A887AB7A6E7D
6750918C3986A59C5C69A5857DA65E85864A687CAEAE9578
D28D14497B78FF07A1B7468FF7506FBA29A0985E868B9023
AC6EA54F8C9C847AAE5C838B77958E72808C8B848D5B76A1
A05FFAFF5C00FF003FBAB135F39CB6C7B970CDD1347974A2
87739A98CD86755DB264867D9B6295A591A3946DA2574E6F
720000000020CD7E4FA97F00986F7447256CFB7D586C70E7
80D24546A3FF7858B87679389AA080AA613B70BA5D9E6672
87C58C97B1CFA3014D8360945D7C99706D74362A5D7D986E
6683626E87BC6863BA7A6C685D757383926A868C6E4D6D7B
7A696C7F976774F3575467A39C5ECA3685516794C27B2E5E
7F9FA059908E649A7B898C80787F708C8C75A069986D788A
606D535E7E7200FFFF1EABC41C6728442BB87466B9700A38
6989C14B747CB4684E77847A997984817B766D847F6A8D79
7DD1E0B3FFFFC7E8992D69B3365F90D6C96887A53D7E798A
D1822CBED17D7E8E98916A757A97B8708D6B6986B6578F58
A17864998D617EBC8577AF567DB17364AEA2BF95C2A79EC6
76AC937271976FA55937908C77947D42504B50A4998E8981
58828468D3707F579CAE6078896861BB83B9636F317BA35A
ACA079643CC277ADA35F7493767A6D9A4FA67968738E6271
CCA1B27829EAB24831D30B95A97DBEFF408FD17366A48193
5C9FC67A47617F786BBB973CC27B8E685C4F4B79897A9565
331C00535D569A808588A29A6DA1BFA5825F9D2C747170BC
608C795067819E8781944355739D7E55939F7C674C9D7C90
87689C8F7D6864B5A2B48B3F567A88926854A54651787E93
5572496C6A6947688B86A4729084829AE5CD9F8749749B7C
7D855294568DDA90599A82C35C4CA66DBE556C6C69933574
9EC9884BA7904980C07BA758625D7B7E97745E9D518B8C5E
4E8D1D928C004BA38367EB605669775EA58845EF6A345A5B
668A6372C4504E96625B769B61AD7C62678D869092778D75
72BAFFC6DFDB254479588A4B72E36A76D597838F865C7D5F
9653AF5A628DA4807A4F4E81A6675B92957489635D587568
9285914E8097A3B778AD747A7B93CB888152977C7992A0B9
687582928C8696926F4A7C95926E9062436461565AA27C6A
753DA9328DA6C12A78808F9B7295A24A7FA977DB704565B3
6D8D5DA0997E55C0746E747E7F7F697397848158B17E6785
4C7EA3933D75D800C65E06B16098A3BE3984697C958D3E74
8F9ECD614DA45A9B84715AA74236974A5A8A6D8B8F728F76
685E3483204CA3DCA2A08CC8CC90B4B1A281DE88A2894A96
7B6D5CB47642A06B49B183A26A578DA0A17186707C838DAA
754A7FCB5D6E65838547368568617A73A679A48C56634B61
8D9996796E7E866F905456988E85AA6D858A7B7F65686A7E
59B74BB0679C935C6F7B8BB07F663AA29A85856D5BA9A743
6D8673C45B6E82A2638B5C9F549482866073967679924A81
FF4F9A8A9C39AD7962809C948061508E7FB6AE7D4D9B7779
832E5AA38764877770A7727FA79881A9988D526E757B656D
5F36B494A98A8F9F5E7EAA8FA6A06E6C7B8892A96B519277
63517092A5B47C4687A8D77374848F86748D91806163938D
A4B06C73584C13868E8FA87F978993967B81BE67728F8892
6684754B8AA57D5C71A5AA6E939D746C66755E51849E4476
A13BCE7661816EA77C7493838A77BA750F5ECE6A86C32F64
BF85696E79857679958D6A6B8957B17476827A76808E5A7F
728F71B411C0333B688190915A6CA18FAD8D8D819185533F
7CAA7885699985949691665A957A7281838E94AA8579867F
60663E2C8CA63631AFD07680CAA5938E8E85D8948D3A7D53
AA5A5489B6056BB3C3EB7368758093D3AC7BA596967EA683
696C4D5165656F997075979E856F8C856768757E7D6A708A
97956F67AB634FB2A07B5456737280969A4D677D768E7983
69B5597195663ECAB843C59D36AF5B9B56549CA75A707AB4
8E8583518891A279757294638B8C857D6F7D885E7477778F
94674D8872C76E946F8C836B8572497A57954970864E7869
46627A3B7CA187744E91AD6B927251607067967A91917382
93C2D4785E9191995D3C5F738637A38EC26A859037583E92
8862DE4D2466A998B764BE68798CAA5765B89D939090905D
7FA26B847B939A6A577C916A9781889C8C866B845F759484
7D4F4F6C81836F67868698988D96713A763182A37087899C
A76B5082905E7BA8669490886E6F6F8A93B34C776071B186
5B9437A78A8B5D9D73A48E8A796C9E8E89775B92925EBD82
52906F97819C29B64C857751529093834F9F93616B816A8B
B95876C17F99657E93592A516D7D809D8F63AB95685E7779
9CAA6CA87654AF9F70607185B5C29C7D443A7F5C74978079
C7A9375EAD84E28052BFAA7B7D86A9686C5698A59A826E85
9C959874808762809C795963508A947A809B64509560838F
6B89896D75B6787A78918E685E7AAC919C8AA1908E72658C
4FB0888996456A86915C88927B5197B998717B7F81637574
8E96A0447E82A17E984B9A917582A0597D838E708F9E9768
6C839F9A49757FA2965DC65B916FADC3A0651EAFA1858557
6B89668D826DBA42A18E9D62608B8578849A92707CAA6662
587D6F416E973B4A3B4D9385BCADA07F84905C696995A0B7
6D2C4F72A3B871869647948E968653925B6274B59F875682
A790A15A556782638ED85F8984717E6A69A2BC5F95A28C8C
7F81636D857863847FA7AE91A777768D77927153888083A9
54BB6194744D8A6AB25BC45A5096B59D975987897F6D788D
7C8763A082796A7C909D76737F7CA07E647F8847AC797E91
9978799B87939B4D65688A77826775633DADB6276D365985
51B59247A158AD7F805F7F987D6884636A717698A4869884
4A5D5B9542908676CE656A6DCCB088967A345465A884807B
477181545F788B8D3E8090A2926E9358865CAB8B8B4C8173
987276655E71886A77BB7C6A5F855880BF5D5846A5B69370
958979935A76A57D767A6C7CB0AA837F9E8B6677907B6791
7C8F914F9B3F62CF67868B6BAF55906F7EB0917871756C88
85616C909D7C5774A9767C5C977B9F787E7C856A926E9A75
872CDA32924B86298B91929944A18EA7BA336189B59E57A8
947DEA95869FB37D6B6375636B75599373A57D7D7C6B6AAD
83396560686863AC8A83D695565551217B60B1B87F769165
806B8194BC916A5077A48A4F719A9384488E6D739CA67171
668581AB823F7E905C67736D6982898C777DAA8485778E61
4F92A0AD9F8F6B68918D797A9473867584665F87546A937A
788449DF689774248ACC91A52D806F87B751568E9888A040
997E7E878B777A8E5A7382739B63718B9C75856A69AB747A
6C8676917657846E50405F6D91718F659171905A367B7572
A36B616D6E6C9F5D77938368688A626B7B756190908A9090
51325F695E6D859D948966747B2266638DAC627EA7B5666C
6B7370A2A8806699714A559A7DA2718B9B749D8D5E6E8BA7
9A8F7391936C77826D86B584A1785C949DA5A7969376656D
7670867B95738061489F84707A8AA2949493619A888C8868
8D82658F8A6F7F985C9494887C56A486525C8B8AA9787B82
988C7D806C75798373746F9288747995968A556A816DA47A
779C86415AA1587C3B8893AF8275A8778F9B667E8F6F7C87
7698A17B916B938D7F7688795F92A47D6B6B7583948BA077
5F705A6A80B7A977647756957FAD8742A255B29074799665
3D5E5677907FBB8962279A86A3757D6C7FA95C7F8F7F6C6E
80AE8B745556789B8185836B7A67818A636B6B744D687E86
885C74696F6C839C86A89EA09A8E75766266708D88847975
7985968378676E69BB894C7EAC8B7385588D5875A7677888
86A7727D8A50BA5F4C819A837054967D806C90889F97508F
7455737DB6688C6FB57C985A9D8398966C4D836E8D6571A2
52716D89AC687A7B638B789588787B6373919C897C6C5E7E
6D9B67CA9987855F9070BE9E5F697C9F8BB7938A998E8D69
625F6B9179A06F8555B893A8AA8A9376879A94927C616687
6C70757373A89064876B619B63767E84AC73658880936A6E
7871696E6D7D88717F8B80738780759D5F906E7A72798A72
6B8B76A6688F7A815F7FBD637F93428BC54D9784638BCF53
7B7F777F93895E8B9585668270857D7B797F878C909C7285
7469795A6AA4B54D65346C8B45325A5881398D3E8A7D8972
987FA377798969847A7883567A6F9673946FB3B2807AB78B
4E61634E67795386948FCFA4B99731B051485AA79EA98B4E
6F7BB86F78846AA182828D7C8693696C8B97989563919769
6A626F93958A7F7D7A588F86518E6D9B90677692AF7CA59D
6A96A0967978877F7B879D747D867299737C647BB2888A74
8955A256BA63947B5BA279765AA34F83867B97788DA25F8E
838361767668827D5B99857277899778906D61988F99995E
8399A5CF89769D987B8D99998379529BAD64957A87758F76
779A897086956F537278BF6A8D8194868D995E7D94816662
796055677786A1AF958A647644323E516EB0BA937753658E
9D908290997F9D8D6F7D768CA57B76547D928F608283B27B
828D5C6C799C658CBF666B8FA367529592A381858D5F9286
4D6D79629B6D6E7873818386878C7575819383876246828F
AD656270A3A97A66679F8E6F6C8272816D959C7B8A5E8787
956F8F8886655472CF556C7B669C80977A86617185917A79
74827CAC5D75735D61863382766F8E647877918A798D877F
7E93B586738D8788A45B7B6B68677D6D69A7617B6E897986
D683B7818DB0778D7D404E7C88799F8DBEA780544D7EA7A7
71809B8B6A929577A37277957F805C8A839A6682759878A9
7C6E566352848C625A9C844FACB8867D754C738D81887989
91AB946774658980859C9591667D787275617D9D8C88847C
81859A655D79759786707C878A8A926A728C998863804772
8DAE8D685D7165A58295678178548C9A9271767D726C8589
A3B4658BCA90B0B988739C8CB4736893A47D93A481705570
7B7A93739A6A739173B172AB93899C7E6C9E718D84958E98
4A8173AE8F3F844899C2C78C9DB156814F749398BEA1889B
91978150927D4F6A7C8988866480AB998F63946B8C928485
8E6B7B93A54D8E9675978779715792989586925464A96E59
86806F837C6B878C8D657680829363868756838858A1877A
AF6480737B648A81808980677A8B6C7F98908F6D51699585
856E6CB161987E709C77857D8189569571967B9767678E86
8C2C9A6C75708942A68176925176B6718B6DA69B788BA46A
846A8F738D8C9A7A599E637F957A7C7970738F74818E9087
6C8A72616AA3B0AF7580A2866A827284AC58977F797786A5
997072877E5586786D756568807C8E5280936B995C868894
4E6B7373755D75678084677F7D72887765A2A98E7C796A6A
6E7D8D9A70A1A4917553948A87876E85737D948476718994
728F8681717471A3AA6066859977718D70A26D868C84629E
7C84717794956C7A7D7E6A767C9B8F65796D7C876E8E88AF
65B87784749565B294537B80A07E757C7A71758E85708480
B4856FAC8D6D585A747F8A74808B767E8884747A937E7163
8295B17F649D847C718755787B9EB7838D7B8B858A6E9170
85845B6D809972737DA5A479789E63726C7EA2657361AB6A
7394748372788C818B698864917D6288927E7F769D867458
77876892948E6F77A07C9E918184978D6A888B968377758B
6A937E8A7F718CA4716A75979A7B867F77777D6597937C76
606E9D8D768572768D838186859080866368737AB27F9183
AB73919F7A7E9E7B7CA37C7D694E866F8347845B6CA48684
4F8D839376757D8D70887E7D6E8E8D6E6F69858B6D5C7A83
AFAD6663748C9F9674949B6974952167699C6C7698988A66
6D8F817076A663668B6B857C7F548E8C8485888B6E6D5F7D
69996D7188A248577A606D7E8583996E66697F7485A88C85
8184928A73A48B8D897F896B7C857C8F8B6F708A8478A298
7A887D9387946995775881AF7492768183925E80677A7E9F
818C76547489976876869795A4615B6C69857B838E7B6E6B
6C9C9C8E7E9C61A68191795F77807363816E598290805988
8E8C776179876C4C85868783995F86977E7C8F7B7F867877
AFA38F769CBB917182828E805B87BF696A869C898B7C959E
6D92928A83958E6083757F81737B877289708E6A85849060
708297908E78857D83899BA37E6190A4A664838C767E8288
7687A77B9777718A7898A28B787068788687716F84976A73
787D6B7C97756F955C7C62A38666917F68A98363708B708C
8B848C707861839A92866D708F835B7497728E93847E6D82
877A70987D94A54E696E7581938E769A7E7379996A8FB573
A7948A95768887748F717D6D70B487657B70976F75738572
5B685C5A463E798386A76CA1967F8D7A8CA8876D52936359
9489687AAE7569A67C736C7369719D5D868E929A8474857A
8F917E7C8E847C846D7779867B777377716B6D69A48A5B87
756E668E80677D76798A6D7F71716582775F968F657C8B82
87756AB06A8693866872A56C73A05890787D7B78A062849D
96597E67978B7F77927095737B76826F6E92879C777A75A2
797880609A907DAB7891887F8E906444807D6A68827A729A
7DA18284907675618083876C8D648892846F917B85776F5C
6E656F8EA2AB80746F8975465CA88A6D7A8996529E7E9286
796572805788935E77778D4D828A878B8A767A7690827991
5C7B9EA2AEA48B8F7C6B9B81909A939AA277928370726B77
6B7F768184736D6D7E6A6B9C90807F8B8C8189878478837A
797095809D77817990866DA67068648F88717D72A5A9966D
708A8C80667F738D759D927E83629C6987659083898E7178
6E6194799E7A874E9C6C7CAD83759AA37B978A7766808E77
72917A926B91825F7D7A686573925A917E837E6E80788D82
79556E4C727F707DA18B9A93667D968B728A818D71686A74
956D7E7D6092677E81957B748596999F8677788A9B917D77
7D86989E7C97907B937E908A80786D6F82806B777091866A
9C7E857B797079897F866D6A7A77908F867865787A718983
66A2737FA359788E977B7D77787E7162827876A08291699B
846C81808E8A717B8A8B846E7A5C98817E829E6180927B70
8C84829B83A387925CA47170828D726DC07C9A7F808C7D86
6F74A47A9A776A838994817C7D89828A8974926F78849378
866EA66D889495766B52804F649B787D8E8B787F7490846E
908A5E8D8573898064767F8B757D77847696736F918E876E
8B8E92758986728E9A856F818D757490728F8698737D6057
8B7A6F8879AA7F7BA1728A848F806E829399957C7F758072
88588A7E95817088797A7C817A5F7F6E8C5F86907378A4A2
6D90836975947C937C74887F7E9F7D6988947B68718D6F7D
A37C8B927E6B9488877E95877E846D867989937490987289
7698A2707F74939C75778B7B827E795F899982986E848A77
8166697B74737279518B799187796F6F6D8B7280838F7D6B
83A1918E7A909A59956C69797590786A8579AB6E818A6D96
5F9D826794806D8B85756298797B888F759B6E718798719D
A38A8697738F95737970938778788883757B847A8E7A7290
A17248938C7B7A79856D848095866F78837185727178959B
94A465768C8C7D80806A869B6D8B6D8A9764847C65757775
5E8F6C92729A67BC7F7B6E905C7D856B7676748C97849079
79886A898154668B877281837B719275766B84878C79798B
8685938E7E6A87787EA28A7E848B6C7E6D798188767D756F
7179707A968078908C8EA55B9480778D6787547F85767172
97A269578B837677707F8084817D736E816B6D9978AC9689
707C86828F89987C746D7A8380787D8497808089A4766D9A
A670796B8E7384AD6D7A859A685B777F7C956886818A9569
8480A47D907E6B9B8D63A17D807D81848081727387697A69
8A88946D86798B7DA197977C837679738388867D55827498
6E8F84998E6A79938A877D7A8F95708F677C7A7B8C828587
6E497D5F858586989698868A7896947D7D829D896B86909B
6375817E839F6D66609876898D7E81757B6F7F9E64756178
77938870888E9D797D7B7B8B606EA3987C7B5B838277769D
8687747D6C7FA26C7A817370A1907275897D886F6E908E7F
73826E918763946E839693747A677AA377977F78848B6A70
82709A986E6E8E7A7E889873727592898A6187716F849288
81817E8C8666648D82777D7A6E7781A67B6E939F7D7B6689
7A96897A6B8B65687B7088647872928E736B96917D977B8C
857B96A35F6C7F8863907E8C8A7C7B758F8A715CA28C6A67
9087849490818B7D7F8A7D6F85897C6E777B856FA07C6F8C
728C878C83696A889E887B6B6997727C769299666C947D71
7C757B6D736D827481868582867E93807779638389758488
807D786F888876998876687989767F79986F6F927E8D7373
799683826E70AA6381908861809F8A7190777B7B7D6C886B
98887DA8939C7F779794996F738786786E987A786D867A78
856D7771807F9684708D97728577A18C9C877E70898C8E87
71638A716E9D84928D868C799385828E5A5D8C82847F8D7B
806887A4757977628E91747365808E79776F897991807280
7985637683968466718D6F848F768E8089768B8C83858292
68708588968F647B6C6C8B77758B73719C8C7E877466737C
7D7D81797F87A37474757276A17299718B6A847D6DA35C75
886C81917A6BAA7A7F8D73769A8081A58C5A82877984656D
7A8E776D818365845C92946D8A715E8480886E5969868662
736B74985D95898E7985747882877680607D7C7A8174787B
AA8A8E927C7B52846560848C9A85858A549394907A6B6F71
77AA7877A39E776974847D7D77827A76A98D847284648A86
90898D897871646F6689929A6A79A06F97977C747E667480
95857587567C8987937F8C8F897C86837878897C86747384
8075649B74799771836E998A7E8F766F99718D7D798C8A78
8475787C6F976C75878F73748B8C7B768584818D6D79886F
9D66698D7974917F6D7E808F7D6B5F7A878B8FA354718481
718769767E6A7C687A848C816B7991859D9B7B7A7A767F7D
6176917B7E7E828B729B729A6D638597746D829A80827767
8571809C98666C878585888C867F797F84857C8B80797C7E
6084797E76717F89979667719B86837A8D7B7685807D7C6B
906E7B877F7B7B89728768879E8D757186777F777B6B8077
7B8082877D6F99838870788D935C8B6C789B636C90A27590
85697D8E6F906E76888E7EA0797D7E7A7F8487728C81597C
80837C73A16C93648584957A61637C56736670816A8C7278
8E66856A8C7D899B7570858B8386738377617C6279978589
805A9282787864825D6B726C7F87718280927D867D7493A0
5C948D68788E5A9E687D9F6D788589A376847F869464897B
67917D7A82A17254838C637F9774897F7295827D61868369
8A85808795786086788B856179748991967C8072747B686A
FFFFFF000003D227F15FBD0200E09A537F38E32183C4484E
9E81845BCF93657CCEDA825B67A35B9A98827B98968661A6
FF00FF731B13FFFFB0FF409E61E3AD00C1FF8868698D8C68
19497A8B91A2B38D58815E708AAF75B07A729B656B807B5C
FF00FFA6007E91FF60455600BEA9FF976C3D45FFE14626A7
2E777F7A7E7DFF6E42AC8873D187518B923DBAAB997B709E
FF00FFFF00FFB254469931D65F0500D2A98766C0A12D19B2
499E4E8E73C4869D66865D787D6B7479A694648E8D5F7587
0000FFFF0000FFDEA70A7DEC1CAA939E745944FF6D843D9F
9B9C69B35E976B8D84838939A271708A93558F9771788B65
00FFFF030010733D15008AB04BFFA795999F7047A687C463
00987D954A85677D71797972AA4C8EA27D7A496A4B6B7E6E
001EB1B39E7800987C8BFFFFF5FF228AA42C9300A700BF7A
B27C86C0773400B067A4A9A64FA0966B9D7A788E819B4D63
00FF00003EFD73B39D81A4D6EFD195DCFFA5003AAB94BABA
656FB16972683F4A7F9B7B9C8A5F50937E87725E686A6B7C
FFFF00CD1E1525FF7D308A5FB732FF50A92923FF7600FF32
7D4CC38200E5854BC14AA0865AA598629C5493847F906591
FF000045FFAB20B7FF95E10005CA50EB96335FFF43308C7A
BF883C4D8B689A7877B1B14F658B7D81765F98927B5E6072
FF008F90FFC8001899305BA41F31A6FF00E582EB74A1DD8B
6A8740816EA2B7A881835590DD7F31808E519F9B85666CC1
FF00E58C3F02008AA38A4724554B0C00AD7C47DED5554D6F
2F61ADADBCE38D6F83695A946B7386878DAB904C53837E82
FF00FF0007AA79A690983F4BA9F05A9B386A7BBF42A7738C
13DA952FA86EC94E7B8E7F845286B55864DA517C8C9E3899
FFD151008000A40470FFE1C86D318C1FE2922E007E489AFF
239D9E7E2A7B6A64628083AD9C90978069596B4E9B707D75
0086E60FCCD72EFF75B6AA648CFF7F0FCA3F103B895BCA00
73EA7D2F90798166686A8E82AA7E9558A97259A66F9E8A77
8D00C5C1D2D43033E0FF556EA4BB86F5FFAF6BE3F863484E
5E636C7163AAA6876866C9A8585EBB8C60477F697F967F7E
00E300FFC400EBA89B726120ACDE43795A20FF055BFA6034
91C47220CDAC44AB749C58739E6C719076639851AB7D786D
007E00007B5B000098003D31FFFF4AFF4F688F462679AEA1
E475FCFFC760885861916AB19079939576929FB16FB194A6
3500008CFFA9A7FF4D7DDF7E3D00E0FF00729E8B74A4B18C
5BA7576DB3408346949B447B8C64905FB1BB9579545F8DA5
EE95735A7FFFF5C7FFFFD49466347BA772643E117BAD8761
AA7F799EA08B9A76475CAE9E476CB7AA768FABA17B848BA1
00FFAE8A14A28200E2C3006762B8CD008A7BA07BAB6967A4
639E719C736A7DA85468AC56878D7670A0678972B565719D
FFFFFFEBD2719FE982FF3037B000216CD148AAE1917AA5B4
36197D515A2D8AA5909199A9486B81B78580876E6588645B
F8FFFF2F0C003B8F23738467FF3FD349994614DE5DE19E55
8A77E67F899C884558B19165A85684727879888A6D7B9882
9DDFFFF9AB231070897DA49E6E74849C00295B1D0368778D
9FA0AE8B7D6B987F77A49F7F92A77A574686989E8E929D86
FF0FBDC852687AACABB10FF900FF585C94748A83B84254DE
6A6A99A6665BA7B24B8582897C6A9170738E7D9C7E6F9056
00A82ED76FE4DA7F02ADFF63D2FFB48226CD65955357778D
B69597D88B9970B5777D7A71717A958978968D798774637E
FF00E5FF3CE3F2FFC53DE2FFC8B16628917D8188337E9A81
6227A5BE8637986774768B8A50D788704A8C7C96859C4771
FF9C70FFFF8C59717666265B6D33A0FFE9C9F77041BBB084
603865788196927C5B86A1837E869E9B7B85977E87929181
62FE4694A2179F38A467806F3AB9C25CA83EE95C7DAB518E
9E7988896A73859C876E8E849C6C968D6B827DB551897D94
66C3136B2E004400C21A3A00005A0025FFEE49B83D014F6B
22203131A179D7C2CE725A71768475688C787F838C6D8578
00B97B367877802129905EBDA700B19576BB00FF539E5599
74C028557A946274A292A76D897B5D8E569D957386649755
0000005D3458E098495673ECC06500160913659B94C58D84
795676A2948587A4694D708F7563879285BBAB6E526B8874
57A23EF614AD43BD19FF9C2277BF6FC1578763A48C51769D
668CC03884A46673A47A815BAE7894805F8D9A58977A69BB
FF00FFFFAFD656655C1196AB8A37FF0D7DFFDF7CD89FB148
9E7E283B534A436E4B8A7B5988737753718B72758A54A581
FFFF0088FF00459AB922FF0EB65F00C6FFBBC25D1F98D100
97775EC06AD044687B70A2898F2C8F926A975B53B778A064
0E003BB3DB81945D005AD9C1C3A96FA3A241588FAE86A4C9
996C7E8D7071839D74688CBAA29A6E324185A28E8B67676C
6D0EFF00FF440E78B066BE39B76B4EFD2E956C5AF753705E
B241796C8E8F749E52BF5736C7688B706494A64F9084807B
007F7EC45E14FF8E09415D00A4FF54FFBE6540985A2F3B8B
E0FFD7B6C6946464C18E8E9DA4946D795D6C9D749F6F78A1
001EE2FF69F1A783BA9970B5CD59FF9C00A1970BC438D282
BB95988AA24B9EC815726C979B896B7C708D8C9B77894EA1
A9428FD1F22B2FE36072AA46210432F9FFC47AF5E5CCE9A8
646977ADB1A374746A585A6C685992869594939081567483
3DFF00EA717536BA05FFB200F75440F317D900B9E33071AC
A288609B8F57A16F8D798A4B96918F8166988C836A8E7475
FFF4FF2496FFFFEE67B969AE34A93D006860FDD178C53047
50585B87668C715286AD73A5A66F59776988749FA28277A9
EAFFD51EDF00FFFF41FF16081B72AF46A94EB166B3976043
A6D442224FBA748276C8A4597458BE88A24C8978729F5D49
FFFFFFEE530061FF7073FFD6AA9B4078D45A0079B8E3AE59
7EA36F9B8E2B3CD3EA72587B6A8AACB3988C838B837B8096
DC000EFF93237A5FB961D26C81689C75ED5712FF506835D3
71A6815AC6666F8FB9398F6F94984FAF568D857E7D6E917E
330000FF931D00FF3A2E73DED6FF6B88B779EFE2F5555BEC
CDB493B29B6A54505E807A8A6657774D5287669F8A969276
B1E7029AFF439AFFBA7ACDF05DDB4FE9E571E200A41FFF5F
629994A0797EA7A49C935E8FA675849F4D82946E787C82A7
8A9699FFFAFFA4000093F76186A338B3FF7C23686D82968D
4C2B2C607D466ED9AF978E8D6F82806477918F8B947F6D7E
26FF6E00FF67B54176F65B739742F62DB331AEBC1AF60F7D
C7668954B95951D45C826374AC7B63838C54889A78609E8F
00FFFF00FF5AF13AF423FFD7FF392D564188622419651F56
818A9F7054459E839478A4B29E7AA6A1A4956A78626B5F48
0000FFFF5AC7F50086FF00C83583AF00FF003A86AD0BCB50
44B7AB0CE56DE1CE5285A969A28967A2449A76735686AB9D
250055A517000000D8FFD49CFF6B00B7FF8E00001600946C
4D778293A3876F4E4E6C5C6F807D7D9CABA782837A819677
14DFBA00AF9774CD00D6A17209FF884595448DFA3B7A9D55
AE50A699468075B1627D707B879F45AD6F61A0897A7F9188
E11FFFFCD5EEB6FFFF3A8EDFE100442798548A2C60256E79
A14768936C8A795475B2739BAA4E8B9689B4977E7957828A
FFE60000E3006175792F13E000A00078FF24FFA564608281
2CD355217F757393BC9A9D7D8871959F7D6B6C7AC9648663
0080FF9D0079FFFFFFC80000720334FFFF2B000000006D66
72C2C05D5C88867F9B8B547DACB1959973768DA8986F918B
FF0079FF00309EC5CF0097768987879C6332CCA3578AAF5C
7EA256AF84519E8D7D6F64878C6E905D9771788B6C899744
00FF00000011555E80FFFFB0000C00677A2C0079616962AC
3A917A6AAEA95C247D7A6C77609F7A849D7F717F938C7874
DE520FFF00FF64B0D500D957FFF5CD118B88165CCE1E9EAC
AE94925A8C4966DA2D4C7096AA75C05B72C57B8E8E768266
0BE7FF4FCDFFFF0000000000433FC3FFFF22007E45398452
40617A746097B7BAACA686728F89899D834B7CA38C626272
08FF00FF008A918CFF0C31B3A865F02C8122FF3A3CB0CA23
41FF6748918C57AB7A897966B46D72709D7483836B7C7683
A000FF00DA2EB6BFFFFF67FF4A004EC5000D59666B4A545F
513993A9638F34696B9BB6A1A372A7656B9264905E8D857A
5C9CFF5600FF0078FF51FF0074FF077EFF978EFF5CFF1E00
853D4C6E8B6DC878759AC0766D5EB13FA8767B888B6A7C9D
88B406002B210000E4D28FFFFF0027FFFF060A0F00005656
6D5FB2E0878DAF75577E8C94787B6D839781706E9395A38A
FF00FFBB006FFF00FF7500CD54DAE800E253CB5A8984A491
41999FB03E91A1846D789E6659B965864F9B838080867E69
FF00FFFF9CFF5C0012FFFF1A0043A19D5FA0962EF557BDFC
AD647F5E85E8D452798E87C49B5F587C826A838B7A6FAC7C
FFD24F00FF0000FF3C00FFE751FF609757FF1F607C946BCD
BFA77DBD715C84819B81A4657BB44A91998A887B6DA3647E
632E4874100000DCFF9C53750000F1FFB500363500104F60
825E4A6B7875928574747C7E453A585C5783826A6F8DA08B
FF00FFFF1A00FF23FF9F009B85BF3EA7836865A84FCE408A
A9447EB9BF10C2817B7C8E6A7B986996766F9F806AA56387
0000FF988D007D0000EAFF85824542CC0A59B0D8CE51695F
C2B16F847D9B79919989A492858B8C9170859A9569687085
00008BFFFF48FFB80E16FF00AD31C8008E7E00FF16144F72
A1183B755264AA6741726092788076795EB07591726A776C
FFE1FFFF73A4FFFFFFF5FFFF8EFFFFFA0000001B446A8FA0
8151495F7B878F645E566C7B7F7C8A7964698D8C8881977C
0FFF00FFD600BBFF00A0B4516F84ACA93D8B97617BAD7958
A0805AB08B588A648888966166A56A778274748C8C7D60A2
FF0000000000000000FFC6152E2D8D67AAA5FF84FF9D6051
525766846F53769FA0675F74A37F84736E53846863849448
BDFF03004CFF00FF00FF9FFF57890063BADA43968FCD615F
68565C7D778D8564B6A48361829F58987048949578786C71
388DFFF8C0FFFF8455FFFF8B8AFF9D000000003E5F4F7990
6595E6D98787AB80545B6C8E9F85857D9B95938F7178A8B2
00FF00FF00FF00FF00E2F4007BC679A223B849AD58957382
7B549D8D6E81965A9F869363709F894085A83B909879A532
FF6500FFEF1000000083FF37729AA6B93B47C65982C7D67D
79396F7AC077852C813C72A75B6C7C5D9B8490907153675F
FFFF52FF5B00FFFF00AAF3FF34DA391BFD6A006DF04859D2
BA48A970C06168C6876A6A87A49D67935AA47B946FAE525D
397654004B1B000000430300BAFFD80000102F819D51376B
8AA7BD9E765C638A86727F7C9C623F639A9C939C766B7A8D
5D2AFF3000FF008033CEB60F7FA96C47A5B301ED27B36C61
A66A8B788EA24955D65C8A567C8E61A08184719A925A8E81
00FF8F3BFF00FF81008700000000FF2369D0806E8068837E
7CBC5778968D8484B593AD626074636E6B8B76A080AE8684
FFFFFFFF00FFFF00368450D35AFF3285FF004C9869960280
4B8F5D5D8C69C25D6AB156CC586A974B824D7184A06A89BB
A2A45C2E824F60A3D7A0A0FFFFFF0E000073A44A4C7A919B
A78A3D638D575796915B7D99A4AA8A9375838CA59E88777A
299871FF009AFF9800FF9B5368C86E6A858E70877897598D
8A5B8C7D929F5B56DA772BC5597A81867263918D994087BB
04FFFF00FF4BFFF3002462550000D6C5687FB0A5C4C4ABB7
7E93989080409A994277726B8C6F815493618C638D777E75
00006400FFFF000000FF00FF8BCD2D2BFF7E9518E1E930E1
666F849E7574BB6E77A07D8768B1907E9966A8934C699886
678180595D4A7287723C3A433F00000AFFFA76456B746C49
5E624F888D7C8F936C5B8F8569616B785C90A4A89293989E
44EB6798C600FF5811FF0BDD487AAF6AA76D51E04A62A88F
6370A36397916565C3795AA094549EB14189887B817B788E
FF00FFEB7392FFC1220044860000ECD7DEA248967B003276
DFE57D8F5E7E174E696F6265708F6A828E7A75A863686B83
6A000000FFFFFF00004C8F74FFC0B534CB2A3BD07A3D5085
9D3470936183876C53E47287AD46BE6E928FA69B77857A98
C190906D42657913002E3F1B2E1281FFFF58094D67686261
9C977D816C6379A88C5F96A68C637772555C9F9294A39E75
D500FF00FF009BF022A46EC26F1BFF5063A68B837A7C7E91
6599907E66B239BC6573A06072848B9266808389817B7B81
FF1958FFFF00FFA13D0598F50000DA00948299E6971E7657
326596AB8DA7DE90776775705795978382806D706C5F8C7C
3CBB00FFFFF4FFDBC10A0060FFFF216A94B6A01DF2AD8574
21AD92857A87727358B27F8ABB6DB660767A618B7D7F7364
A96CD0FFE7FFDF8682DAE9978C887B5C5E7A8436339C8F5B
6A618D747E5278CBBC5B6593ABA5938C6C53635581AF8474
B900FF54B23029FF3E496EF90EAA93B030828795657F8D86
68848272876A8E6A7BA47F5B9E80668F8D7C729C9A6871A8
9468E200FF00FF7B5300B7978A786C5286653984A54C7E79
B1449475939F9C8494B3717C906F90879B8293457C549C7B
000000FFFFB0830000970000C2009929C026C522C1907ABF
864A9867A08B7F8B738D7075947F867C559D6F8878638675
8D00014B8775530047A3855C5F88A1886825222B47885A40
655B88A181586E8C4D4D5B739EA28A8670515D5F8A918F76
7B2FFF00BC935968A3AA1280F816B67484786391A4517B95
699072A187686C7D9379924C9387679E8E44928C8280766D
FF00FF00FF0000FF007800F700A6B6B0936DABDE732CC5C4
A25B7143AF73947C618BAC366B7A747C6C8C745E8D98867F
00000F0000640000FF854663FF50BA05CF2B2730D2677035
9F926569C252416F91BD918375409B875C757061768D9088
7150354200249BFDD7936C92E8FFE25E223E7196846A669A
BBA46E706B397A675384968D8E927E6D5C444D6A73917683
8C16FF0083F600FF087E9B29ACB76C8A7A77A86C91976683
7968827B93775890727A7D8B7573A7747B6E93897194865A
FF00496400FF00FF009193536FC4708FB843449E9D62597D
CE7B436677566C407998855A8082565366769A6C7B9C8A85
00008F73C90000FFB5BD7896348D576BBD8FEC3AF7B498A9
748C529BDE8980C69E50748F7361AB7D7C9B65828B9F4E62
B469519475105E908D82AEFFE1BB6C1E63FFFF7552747069
7866789181547A9D80786F7E6B7B7D836D928C5776A38369
A34BACA157964BC38E5D847EA45BA58586769095816C8E5A
B4667B956F6F779F4F9D5F8574856DA2628290876D8B8075
87D8839F005E0DEA1478AC3117668496A4967A846B3C7087
A073A98B276B5692807592AD5F80988E8370747677797170
144B0A29D6BDFF4986A089CB7B7B985E9C41B963BC67AE8C
A48EA842659A377066796990747A8B806192A084746F8AB0
F26C5C86A38FB8682949848B3C4679B4A073628EAE805F52
675D66876A4484BDB266576C838DA1967A686A5A698A6E61
7169FF00DEAE21A5967F5C7F856C7E6BC5389E66907C9348
9B7F7397797572AB598388638287867B9066A9905D849363
A18D00A24CBB0FFFDF927E4F496D695EC380C4C53E4B5C53
744368AE9E487B8164637C8A886EB395B67EAD8E945C7B73
FF5F0024F0FFFFCDE3E68C75A0CB856FBDFF6D3FDFBF7458
AB4B837B98936D519792917A9B796DB36DB8436678814F7F
4586C1AF84A3F0AD0D407F456992A0D2A4526EDFC7756DA3
925D5E5256727199AF8C7080938D73756E7F7E5A5C908771
C500FF8D568E78943BAC8D7C63859554A755AC735C76B64A
8C90878368939674738F8F7873958B746A808285648F8A7C
93C14ACB543CFF35FF9CD617D53DE24DFC5978468A715171
4C678C685C64788AA37578995B887F967C659F5D6A848B80
4E42B1FFFFFF30978B628B7E7E4CB48A5FAC6EA25D6E4DBF
6F5F827294A2927C92912FA18C746678986E79907FA8898C
8E818A867A649F8177928460A1996D7E98A2855E4F4B8CD6
CDC2B0A07A788896754C6B928C8987839FA68D6A7896776D
81A53BC769838D6B9E71768C72927F7B7F8281839577757E
96956F7181826E9B5D957A5688A95F81778E8E5F938C5BA0
0080BB78F196F61E80B43A5D733E61518D918E534A9F9958
934C88A193968998816F707F955D54B0697C6D8061836B8C
80C3F2FFCE685FBFAD4E3A8A6A53D26A69B96E7FAE707865
24AD9B3A906E4E7291886CA73E809434818A79777B9F9E98
976B697787877F6EA2A27D849D9993817A7C84735B5D8BAC
87615B54505AA49E4C4376876696938F967E817C6167806D
58A6AB2CADAB3E8C9C9440CC34A97C5BAC60A07088924781
B07A78788F7681886C966C738889798A7664AE538C7E748D
2784C1CBBF5BB5AEA73980859452B45D73A27A918B723A69
637F8459967E7C6B958D7076A39C968D838F8B7A8A7EA399
FFB4A2E8D49AF17D347575CA212B553C38B3942C47BE849C
A09B4E9BA6769F468182784D95A7788E59AB45A48B90528B
7183A07A69696A3D1B004082897987745A75A18961637277
5D63618F8C869669384B8768548C8981939F97737C8B8F8C
955550EB2C819B8C61A47E7665A890637F757E9F85816E7C
9B7161BF6A6FA0817F7A71998E639D767E7B866C767D9567
84865B15FF9C919572EE8C786B003F012BB55C6950B27A69
89C06975958E66998E5E8B856F6E765B77A18E828474788E
B766375D51965F465F006FFF904C596A2D83796257517671
7F655782946E708F7A816C6A869C7FA3728A998B7C7F9391
A891AAA394B7A07F716B58616E1A134D6F81867E93999664
7E9A8779869DC2834A5A82847B8E9D9D8884907078967D71
6F838E49A6818248C451889A4BE63D73AD654BAF8B606EB7
5E76799E6E78827DA162897DA770709197716998887E73A1
8C66D74577F23FDB29E1A98FBB7C4383008067C3515F705C
6859615181788E648AB38762775E5B6C679287819870968C
8DB1BB8CB87582E7A8E7A6818062AACA8A68A768BB998988
8E747C7B957BBA81A752987B739E68929CAC7091836B6991
6A76818A595A4D77B1DB7B6A904E30859C8D798BA098778B
8D766E9090AFBE8D7085858B8E7C77817C979B9A91978973
76C11FC3738F7C8D788B7673928953A05595A43FA08952A6
618B789564927F889B678D82758D5B8A886F79798180767E
F4689297547C6D00AE009F57FF519B715C28B1CDBD8D8283
BD91C43F676D7F677E94567A6D5FA37A7279815B6F5F6769
82A9F3C6E4A4A9AB89959A998650A8A54F45D1774E82A4A1
B9919B5B7B86A9527F837B76A98673A1799D647469938095
96809B744656726471635A8BB3A39B92A795897B846E6899
9975729387957B2C487F7263AFA7858AABA69A8E697F8D7E
5DDC2F7DA284619E9F55A76778A445C93480C5603ACD7560
77967E787E64818D61A5658D858B80847B7D807676A4863A
6A6C5860A7789A7C4F18685C39BE27825090A3C931639E6A
7D8282AB8E8D7773786B835493A88A84738A8F7E7AA1828F
A6C28F94C943AB9C442D3A8091C54B828DAD8FBB875EB662
6653827F619D838C7791756EA374627B6A96757065A8A981
AF7D7E7A909E838093607499726FA48D8E8B80929C9692A4
AA8C515A6E81885852887C7594A2938C9495716856646A70
8C72747581908A44A493588B8F8E589A9130C25E659B7A98
49958F737D855F9378898A6F838A6D848778638B817D8B76
8D44D79C82B14572A335413E7AA6AC7A7150735D708F8F8C
6D64773B677D708C8D8293A47D847E92776A5D6D83848980
CDDDF87976AC7B2998B6AD54AEB1AE7EA77A53C96AB3748F
77858B8E36AF85737B795D7DA8927D8969816A708B71847A
66786B787F9C71A5A26866A97F6C8B63534D6394918B7A94
9C908C80706D797E809EAC9693958F858A8D7E8C9793757E
966E5D8DC318C26B739354B2667E8A818E9161B24C99A765
808B6F90748D5D91AB48979A616AB85A73897B8E638B7D69
8D633F955D6CDB5FC237AF254C57B957642E7C6740878C70
9D98A38390747D6680856C8087747657788582A56F6E877C
837D8B547592643B875D4F8A613A9F97707F75B143893865
806F827B7E5A8A828B6B7A85784B9B606390737F7A76A38C
72AA876083A08A95BCAE98A79A948A665A58537C878E746C
6E5C8895654E546A8790715E96A3837C7E7064758E7F7C7E
78888056C06E75A8499879777670986472B5399F53A57A7A
806498946C7D8C6B89837B7E956F928C688C818476956D75
CE9B7547804E33A200CB88B22D8C65A2759F5DC9548F6074
53A67A6086849F937D7F877181925F797C77799C7D8B9698
A562A8B441964650586D3D916077A28B7650497966796998
A0886A8F8476B8517F4D8180759E6E967D807689638B78A0
989474596C4F677491838473758D85777777756B74986889
8C81778D8B7C85949499736B818A908A867D78728778888A
6E9062BA4F8C896E56B0768D49A6698579A17671719A8D7B
689365A869608F6380768A6B8C8771858480827E9B727D93
66424B1DFCCF5A695864B3A57663A5847B88956EABA15891
C1A9976C608E75917971706E856C5B80857B8589738A6790
43877D7490C868806A8FBD70858746779C766E557A7F8B78
5F89C16464809F595575538086957A9F759E71718E746E9D
8487756A685770848174879693877E716A7A847F857B6D64
7F736B818978A2B5987C7385789A9385838178858C85A891
5FB37A39E74174878B5BA76F8755A47A816C9C6C79988F73
777F8F69978F6572A26A788F69819070768E7B6FA27A6985
89875FC366548F7A5296D89282FC79759C8E88999990506A
666DA26391748581955C7C7B6C777D71647682887A6A9597
ABD955004456A77C524476E3B284336B7191B4829F819367
73839989846C7C8C7196728787487B439385838272768982
51688A9499956D6D829474696E746A838B83687A7F7E777D
778CB38E7783A2BA857180728A926B64827B607F82787B85
796B897C70AE5C68B05C8B6B817B9E6393817066A47A739C
7A608B965F8F6D8D62978465AB6492798D66927399806090
75EA4155446B4EBE1E53796B9F9972CDB291744DC9A67261
9165C46372629793667C88AD86806683928784606E6C627C
A0BACD9D8294837ACF916E6D6089BA7AB3936AB44E8A988E
9D8D7C7C9BB283706E9192A2707072998A8C75894BA17164
6F678C9C7884757E827D5D6061887F6C7E95797A6E66709F
A48682908287808B6B6C969C9A857E9CA58A688383737B86
8F5E9A79985DAE5D87AE619A68967D6770807F886B93858C
628B7C936585837675848871798584887E7C6497856C8688
96389186599C96898E4F5E7450B68E94CCACB887AA98936D
6F5E6C718D7F83746789796C78796A877A5E968A6D887A7A
8A695056A7AA8AB8938EB467497E6C93C6A483715F5A8E60
837B8A3BAB92779C7D7F7162795E7C7F689C7F7B887DB190
6D958C7A5C7B90A6966366849997B6B7868A73767FA39481
85614575B28C787D917F8F897469778780767A86888A8685
6599726A9C7E788E66A16F699577868473828D686C928284
668B8973828B7B709D788C7F7A948175849068849871788A
BD3558956C356246E1859FBF008B38897E6779BD9CB46781
69AA806696909753678E807A768B93848A6E687B75507882
6B71685A708DA6867171729AA8D453618A85B08973A07069
8890915A569C82A89C85828867AC7E6D9A88718A826E868D
5A8C8E71637F95817F7A6F82A1907DB5AA9593988C9E9799
979E85888676698A8E868C86959B836F73818177978C8783
928778AF43AD886072C23BB4698A7288767786787C7C846C
8B63908E7687578E92629B7D60818F7F758B7777936570A2
7E7C9373B565608A485C86A45C59868C8589977FA98B8D93
799F9B7C78AA836B668782AA7695887A82B39D8B6C977074
5C4186988B6C7189685F7BAF589F6A9A838C8CA85883767A
65857C919D6292797AA277AA8792997C729274907B7F9175
606C7F7570697169687F77798881656D8E6B72756E617684
6C7486828381766870828A837E84717090957F647E7A8286
9252B853B64B868F689E6392847094758C529A7B728D7D63
94578A907879728B8C7C7F716A8676856E63877694717299
6973829EA68E20B45B657883B48F9F6E6FA6AEAA8EC7787E
5FB186646D527A84A67FA987646E767D7A65897B8B96766F
55503E8E856F86B89F85DA95759767819E718A5F8B766AA0
728B6265A1857F5B6F905B99A353814C6C7880787F89878C
716A807567799685728D817181806F54836C5F7F70779A86
6D81AABE9396869599847A70797E758480987D8E70697A8C
5EB07F6BA86C859777678983699E96599A5E64BF7349B563
838A81937D7D757C898A65827D8C7B7C7078827097778D5C
8A915365007E9760BF84D7565D6B7483687A596C9AA79178
95A48661859A917F65609F7E7B8F9C9278728F719F85927A
6739A1BB6CACB37FA3B3806491937E6C65736C905FA96A96
6C95806977B376888893679D669B6F728081797F848A5C71
6D697B76787F80768A787C829EA27266A49D7583806B8862
516F88825E5F767D816550678BA28EA490777A9F8D697F90
6CA46A7C88905FAF687B818189728C9B6C74809277856A8C
77759C7174986B82819180816E878E766E8B74877D7B807E
ABCE7C8C5B737F5AAD7E86C245A0666589AF8E7B87907C75
90868287819778836D707D7B807C6F7E7D756074687F7171
4B8F836B79817D2D45576D90688862827E777C7179788F68
A17A7E869B7B878F72A0725E879B816D7E79A17697848A7C
977975827B86785A86725C838F717786B58D6B6E77635B47
5C8F65618F9F845E627E77785A66818F706F71847E656E84
70A7696AAC6F728399666AB26A7A7E896F8675907E6B8381
7F7B777F8D7C9075738E85737A8F857079897F877686707F
7DC05AD0729D719E55B8669748A3688D788094B162A8658C
6F9B857B5C8E7D72658780858D8D7479787B637F8276808C
8FAB577CA98086AA6C93A1AE8E9C7A9F955C8A86995DA089
8A648A6F749C7B907B8E8B857982878F679390827F797E7D
B677646F87A68E6A7A96949B827798938689917D80886F6B
93936577A98F546887908C8B87757F897D7D7A63696C8087
56B86671816F8959A2519A7F807D7B859B687FAA567F9468
79A55F739F7480807F7D7B936A7D877A7399708D807A9375
5A7B92917A6FA78B969AB5C28857AA929A76806A7A827766
6C94786B9C98558A8A7B7D687C9373825F96918F6C7C7884
3294A2916E6C6E8658BB61B2858EB47874817E5E756C8A70
6FA75F7A9A857583968380896D708E8B747A6A7593737E7C
786B677C73747C808EAF947F767A7C866A7A797A74798A59
5E977E7680815B7184747AAA9975878D767466627170757E
84927579888C687F9B7C6E9A707F84797B6FA07C5FA07A62
9973867B76A3747B818C7470A9797891717F918175798A89
9086A58478A983478C5DAB7B8B855765658D8EA47C895156
5C898190696B7A688A92768C927A6F75828B7B5F7984806A
41A1607E646861867795844F81A89972B7779A60997F745B
6B6F5E658B7D7657857A666A81798E747A71AF627474917B
8D5C8894807E80897D897D7C8F8A787D957C6C788A86907D
89A1886E587A92998A7F6A8D9A8C8273545C80977C6E7B7D
759076776D8D727376975C938A7D7F7B85867B9B7A7A8889
708C727D7E897F73798D6D6993668E7E738C828078947084
978E7CB14B9496776C737E9C586C9F9E82A553A18D7D7383
8C78678F7580827A9883988B6D7974777A7496757F7F8475
7794A28F66747B91867F997185888AA0A18D58BA51928E59
8A77866A6C6F847F847B8C648A82759D7D7B8889707F8476
90829B85778898837B675E819376709898A1898A906E6479
756E7B8071727377817D747983838D8B7E878F8D7F8B857A
92749A5780936A97667C728980838E6B8F80749081877C87
8A70838C777F788088637D9A716D8D81768188926B7B8783
8CB449AD9C71347D769671AB5C7F7B637379725A678C906D
8C7A90A6856D9E837B658D848C7A757E887D6E82839D6568
9D65788A88737F8A666F79817F5E718B7FBD7AA168977386
728C749F8B7AB25C878B72739679827889767A5A977B759F
65768675728B8583917668877E697883716A8A89795D6D81
7B7E798B979783656978848385736A82796C7B7B75957C7F
886A839C6A967E7E80925D958A8063AF608A98687F837A75
8874728082868281807E8E6B8F81659A6B8189827A89876F
86795F6889B078864D9B757E82845A67539E9190B1A4868F
837C63838678888F896268687D748B83858E828F9492957D
689283758F8263808C87758779578B7C887E7D8589627685
707A8D6481897E5B9F7D697997737984697C8592799F7075
6779766780978B8D97738EA2A9898C7B5A61817A7C7C837F
7787846E6E80837F7D7C8270716C6C7E6E56989779867266
858F7B86738A7C888C838A6E9C897488728C827377897989
7A7B867D718297746B8E77866E88845E96856E8A788A7C73
70AAA9A2815F9B9354767E9E909387AC7F8E6469967A8D68
848C708173797E6880A874577A718D957F7C737184967682
458780845862748F935F7D977B72887297856577798E886E
8B77A2706075846799797C72888A8478796B798781918587
969C837C8086888E7B81957F7472A378788B8A7D6979826B
60678282666870766C787B738B8F88939A78717A7C7B7C8C
7D78976393687E8D6A98638B6F838E71787D917B798B73A7
669479866684837E73818783847895658C7E6D976E758481
A7817D6F519B6A3C66A85797AEA3658FA77D9278806C7D8C
8A7F9D8F928774708A84788C867D7E837F606B7D6682847A
3C7F5D5DA1AF939889579B6B777F7362AA9C9D6580BC7A8D
797D6E75698E8B66817D917A8089828A7A8B797871859C6B
939486717E8B886B848E8B8D90929C80728691888686819B
9C878A82758E9C82859078809D9F7965786A527FA1787B84
92656CAB588C83926F9E677A92757484877B8D7792797889
8785738B7687807E877C8E6BA363818C7D807C8267897E6B
705E824372825B9D839D87AB9C8B917B799D908269998C6F
91896E72A8867D818B87978D85837B7A717B76648E87766C
838D7E7A948B7B8C6960AF697BA47D797A8A807F77679983
6485B68A67A0717C90769F707C8B9988837A74779C7A866F
6679938D788D7F6E68747987969071697C725B6D77747779
7367827577818A859288696594977D6A7A8184877A73759F
816C86817F7E83829367A5778F6C986F8B758E75997E6F8A
8B75848A707E8B75897E7B887B78867F719379777D7D887A
9B98739F905BA2A9A6A4976C739D97737988638487847767
71736A7C828F7A7784866F99886B997F7E776F8B7F787584
6D7E7663646181878393A66D9B9655857781697E7D809C80
4B6C987F6990907E8378677A9170967487767E78817C7D77
6F797F9288886A7C707E827D69748C837B8777766F7481A4
8D80827E76728A79728088848C798C898C8B826F707892A7
816E9B757C867A7F89779C7F9A4D9C8D6281A05A7B946297
7880986C877C817D82827B7D8C7B7E7E767B84728E74888C
A278647293AAAB7F76B0877D81698E7288828F94B5818888
8C7F617193848080797C8389749879697C81889B896D6D80
637377686B839C97908756797853739C7387818E9E7E7C84
658957738F8B8873747F6D8583747A7A8A818A7E7483935F
868C6B678B8C5C697C7E7C84836F767B8286A28E76739A94
908D838D92908C7F87988F7C75668B8C7B93908D8D9E8C7A
78768A766C858C6E7C887F818874847A7A82898372997974
9C53848B65987071917C81807E82767594688F7E79907183
806882718E6E6F853D8EA56C987F6B787B72928B6F719C6A
85967F78906F936E6C7C98A2888C899C7F7B897D9D896889
78766F988F7A92A6825B697B64897D8F62808C7476856E76
82A2849D868666788A77A37E776C916FA5717C739B737A8A
6E9C8172758E646A71776E6A7F6C6D7891848A7463707E6D
696C768D8D7F77798D96756D72868C8883A7958E93837270
pop
P
% End of image
.5 Mabswid
.02381 .02381 m
.02381 .97619 L
s
.2619 .02381 m
.2619 .97619 L
s
.5 .02381 m
.5 .97619 L
s
.7381 .02381 m
.7381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .2619 m
.97619 .2619 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .7381 m
.97619 .7381 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],

Cell["\<\
We calculate the cumulative energy function for both \
transforms.\
\>", "MathCaption",
  CellTags->{"S2.2.2", "2.9"}],

Cell["\<\
(norm = Flatten[data].Flatten[data];
 ctE = CumulativeEnergy[ct, 5000]/norm;
 ct2E = CumulativeEnergy[ct2, 5000]/norm;)\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S2.2.2"],

Cell["\<\
We display the error versus compression ratio curve for both \
transforms. The transform with smooth windows (solid line) is obviously \
superior to that with rectangular windows.\
\>", "MathCaption",
  CellTags->{"S2.2.2", "2.10"}],

Cell[CellGroupData[{

Cell["\<\
Show[MapThread[
ListPlot[Transpose[{Table[240 192/i, {i, 1000, 5000}],
Sqrt[1-Take[#, {1000, 5000}]]}], PlotStyle -> #2,
PlotJoined -> True, DisplayFunction -> Identity,
PlotLabel -> \"relative error vs. compression ratio\"]&,
{{ctE, ct2E}, {Dashing[{0.02}], {}}}],
DisplayFunction -> $DisplayFunction]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S2.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.025835 -0.329248 3.9735 [
[.04406 .0556 -6 -9 ]
[.04406 .0556 6 0 ]
[.17324 .0556 -6 -9 ]
[.17324 .0556 6 0 ]
[.30241 .0556 -6 -9 ]
[.30241 .0556 6 0 ]
[.43159 .0556 -6 -9 ]
[.43159 .0556 6 0 ]
[.56076 .0556 -6 -9 ]
[.56076 .0556 6 0 ]
[.68994 .0556 -6 -9 ]
[.68994 .0556 6 0 ]
[.81911 .0556 -6 -9 ]
[.81911 .0556 6 0 ]
[.94829 .0556 -6 -9 ]
[.94829 .0556 6 0 ]
[.00573 .14757 -24 -4.5 ]
[.00573 .14757 0 4.5 ]
[.00573 .22704 -24 -4.5 ]
[.00573 .22704 0 4.5 ]
[.00573 .30651 -24 -4.5 ]
[.00573 .30651 0 4.5 ]
[.00573 .38598 -24 -4.5 ]
[.00573 .38598 0 4.5 ]
[.00573 .46545 -18 -4.5 ]
[.00573 .46545 0 4.5 ]
[.00573 .54492 -24 -4.5 ]
[.00573 .54492 0 4.5 ]
[.5 .63053 -108 0 ]
[.5 .63053 108 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04406 .0681 m
.04406 .07435 L
s
[(10)] .04406 .0556 0 1 Mshowa
.17324 .0681 m
.17324 .07435 L
s
[(15)] .17324 .0556 0 1 Mshowa
.30241 .0681 m
.30241 .07435 L
s
[(20)] .30241 .0556 0 1 Mshowa
.43159 .0681 m
.43159 .07435 L
s
[(25)] .43159 .0556 0 1 Mshowa
.56076 .0681 m
.56076 .07435 L
s
[(30)] .56076 .0556 0 1 Mshowa
.68994 .0681 m
.68994 .07435 L
s
[(35)] .68994 .0556 0 1 Mshowa
.81911 .0681 m
.81911 .07435 L
s
[(40)] .81911 .0556 0 1 Mshowa
.94829 .0681 m
.94829 .07435 L
s
[(45)] .94829 .0556 0 1 Mshowa
.125 Mabswid
.0699 .0681 m
.0699 .07185 L
s
.09573 .0681 m
.09573 .07185 L
s
.12157 .0681 m
.12157 .07185 L
s
.1474 .0681 m
.1474 .07185 L
s
.19907 .0681 m
.19907 .07185 L
s
.22491 .0681 m
.22491 .07185 L
s
.25074 .0681 m
.25074 .07185 L
s
.27658 .0681 m
.27658 .07185 L
s
.32825 .0681 m
.32825 .07185 L
s
.35408 .0681 m
.35408 .07185 L
s
.37992 .0681 m
.37992 .07185 L
s
.40575 .0681 m
.40575 .07185 L
s
.45742 .0681 m
.45742 .07185 L
s
.48326 .0681 m
.48326 .07185 L
s
.50909 .0681 m
.50909 .07185 L
s
.53493 .0681 m
.53493 .07185 L
s
.5866 .0681 m
.5866 .07185 L
s
.61243 .0681 m
.61243 .07185 L
s
.63827 .0681 m
.63827 .07185 L
s
.6641 .0681 m
.6641 .07185 L
s
.71577 .0681 m
.71577 .07185 L
s
.74161 .0681 m
.74161 .07185 L
s
.76744 .0681 m
.76744 .07185 L
s
.79328 .0681 m
.79328 .07185 L
s
.84495 .0681 m
.84495 .07185 L
s
.87078 .0681 m
.87078 .07185 L
s
.89662 .0681 m
.89662 .07185 L
s
.92245 .0681 m
.92245 .07185 L
s
.97412 .0681 m
.97412 .07185 L
s
.99996 .0681 m
.99996 .07185 L
s
.25 Mabswid
0 .0681 m
1 .0681 L
s
.01823 .14757 m
.02448 .14757 L
s
[(0.12)] .00573 .14757 1 0 Mshowa
.01823 .22704 m
.02448 .22704 L
s
[(0.14)] .00573 .22704 1 0 Mshowa
.01823 .30651 m
.02448 .30651 L
s
[(0.16)] .00573 .30651 1 0 Mshowa
.01823 .38598 m
.02448 .38598 L
s
[(0.18)] .00573 .38598 1 0 Mshowa
.01823 .46545 m
.02448 .46545 L
s
[(0.2)] .00573 .46545 1 0 Mshowa
.01823 .54492 m
.02448 .54492 L
s
[(0.22)] .00573 .54492 1 0 Mshowa
.125 Mabswid
.01823 .08797 m
.02198 .08797 L
s
.01823 .10784 m
.02198 .10784 L
s
.01823 .1277 m
.02198 .1277 L
s
.01823 .16744 m
.02198 .16744 L
s
.01823 .18731 m
.02198 .18731 L
s
.01823 .20717 m
.02198 .20717 L
s
.01823 .24691 m
.02198 .24691 L
s
.01823 .26678 m
.02198 .26678 L
s
.01823 .28664 m
.02198 .28664 L
s
.01823 .32638 m
.02198 .32638 L
s
.01823 .34625 m
.02198 .34625 L
s
.01823 .36611 m
.02198 .36611 L
s
.01823 .40585 m
.02198 .40585 L
s
.01823 .42572 m
.02198 .42572 L
s
.01823 .44558 m
.02198 .44558 L
s
.01823 .48532 m
.02198 .48532 L
s
.01823 .50519 m
.02198 .50519 L
s
.01823 .52505 m
.02198 .52505 L
s
.01823 .04823 m
.02198 .04823 L
s
.01823 .02837 m
.02198 .02837 L
s
.01823 .0085 m
.02198 .0085 L
s
.01823 .56479 m
.02198 .56479 L
s
.01823 .58466 m
.02198 .58466 L
s
.01823 .60452 m
.02198 .60452 L
s
.25 Mabswid
.01823 0 m
.01823 .61803 L
s
[(relative error vs. compression ratio)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 ] 0 setdash
.97619 .60332 m
.975 .60305 L
.97381 .60278 L
.97263 .60251 L
.97145 .60224 L
.97027 .60197 L
.96909 .6017 L
.96792 .60143 L
.96674 .60116 L
.96557 .60089 L
.9644 .60062 L
.96324 .60036 L
.96207 .60009 L
.96091 .59982 L
.95975 .59955 L
.9586 .59929 L
.95744 .59902 L
.95629 .59875 L
.95514 .59848 L
.95399 .59822 L
.95285 .59795 L
.9517 .59768 L
.95056 .59742 L
.94943 .59715 L
.94829 .59689 L
.94715 .59662 L
.94602 .59635 L
.94489 .59609 L
.94377 .59582 L
.94264 .59556 L
.94152 .59529 L
.9404 .59503 L
.93928 .59476 L
.93816 .5945 L
.93705 .59423 L
.93593 .59397 L
.93482 .5937 L
.93371 .59344 L
.93261 .59317 L
.9315 .59291 L
.9304 .59264 L
.9293 .59238 L
.92821 .59212 L
.92711 .59185 L
.92602 .59159 L
.92493 .59133 L
.92384 .59107 L
.92275 .5908 L
.92166 .59054 L
.92058 .59028 L
Mistroke
.9195 .59002 L
.91842 .58976 L
.91735 .5895 L
.91627 .58924 L
.9152 .58898 L
.91413 .58872 L
.91306 .58846 L
.91199 .5882 L
.91093 .58794 L
.90987 .58768 L
.90881 .58742 L
.90775 .58716 L
.90669 .5869 L
.90564 .58664 L
.90458 .58638 L
.90353 .58613 L
.90248 .58587 L
.90144 .58561 L
.90039 .58535 L
.89935 .58509 L
.89831 .58484 L
.89727 .58458 L
.89623 .58432 L
.8952 .58406 L
.89417 .58381 L
.89313 .58355 L
.8921 .5833 L
.89108 .58304 L
.89005 .58278 L
.88903 .58253 L
.88801 .58227 L
.88699 .58202 L
.88597 .58176 L
.88495 .58151 L
.88394 .58125 L
.88293 .581 L
.88192 .58075 L
.88091 .58049 L
.8799 .58024 L
.8789 .57999 L
.87789 .57973 L
.87689 .57948 L
.87589 .57923 L
.8749 .57897 L
.8739 .57872 L
.87291 .57847 L
.87192 .57821 L
.87093 .57796 L
.86994 .57771 L
.86895 .57746 L
Mistroke
.86797 .5772 L
.86698 .57695 L
.866 .5767 L
.86502 .57645 L
.86404 .5762 L
.86307 .57594 L
.86209 .57569 L
.86112 .57544 L
.86015 .57519 L
.85918 .57494 L
.85822 .57469 L
.85725 .57444 L
.85629 .57419 L
.85532 .57394 L
.85436 .5737 L
.85341 .57345 L
.85245 .5732 L
.85149 .57295 L
.85054 .5727 L
.84959 .57246 L
.84864 .57221 L
.84769 .57196 L
.84674 .57171 L
.8458 .57147 L
.84486 .57122 L
.84392 .57097 L
.84298 .57073 L
.84204 .57048 L
.8411 .57023 L
.84017 .56999 L
.83923 .56974 L
.8383 .56949 L
.83737 .56925 L
.83644 .569 L
.83552 .56876 L
.83459 .56851 L
.83367 .56827 L
.83275 .56802 L
.83183 .56778 L
.83091 .56753 L
.82999 .56729 L
.82908 .56704 L
.82816 .5668 L
.82725 .56655 L
.82634 .56631 L
.82543 .56607 L
.82452 .56582 L
.82362 .56558 L
.82271 .56534 L
.82181 .56509 L
Mistroke
.82091 .56485 L
.82001 .56461 L
.81911 .56437 L
.81822 .56412 L
.81732 .56388 L
.81643 .56364 L
.81554 .5634 L
.81465 .56316 L
.81376 .56291 L
.81287 .56267 L
.81199 .56243 L
.8111 .56219 L
.81022 .56195 L
.80934 .56171 L
.80846 .56146 L
.80758 .56122 L
.80671 .56098 L
.80583 .56074 L
.80496 .5605 L
.80409 .56026 L
.80322 .56002 L
.80235 .55978 L
.80148 .55954 L
.80061 .55931 L
.79975 .55907 L
.79889 .55883 L
.79802 .55859 L
.79716 .55835 L
.79631 .55811 L
.79545 .55787 L
.79459 .55764 L
.79374 .5574 L
.79289 .55716 L
.79203 .55692 L
.79118 .55668 L
.79034 .55645 L
.78949 .55621 L
.78864 .55597 L
.7878 .55574 L
.78696 .5555 L
.78611 .55526 L
.78527 .55503 L
.78444 .55479 L
.7836 .55456 L
.78276 .55432 L
.78193 .55408 L
.7811 .55385 L
.78026 .55361 L
.77943 .55338 L
.77861 .55314 L
Mistroke
.77778 .55291 L
.77695 .55268 L
.77613 .55244 L
.7753 .55221 L
.77448 .55198 L
.77366 .55175 L
.77284 .55151 L
.77202 .55128 L
.77121 .55105 L
.77039 .55081 L
.76958 .55058 L
.76877 .55035 L
.76796 .55012 L
.76715 .54989 L
.76634 .54965 L
.76553 .54942 L
.76472 .54919 L
.76392 .54896 L
.76312 .54873 L
.76231 .54849 L
.76151 .54826 L
.76072 .54803 L
.75992 .5478 L
.75912 .54757 L
.75833 .54734 L
.75753 .54711 L
.75674 .54688 L
.75595 .54665 L
.75516 .54642 L
.75437 .5462 L
.75358 .54597 L
.75279 .54574 L
.75201 .54551 L
.75123 .54528 L
.75044 .54506 L
.74966 .54483 L
.74888 .5446 L
.7481 .54438 L
.74733 .54415 L
.74655 .54392 L
.74578 .5437 L
.745 .54347 L
.74423 .54324 L
.74346 .54302 L
.74269 .54279 L
.74192 .54257 L
.74115 .54235 L
.74039 .54212 L
.73962 .5419 L
.73886 .54167 L
Mistroke
.7381 .54145 L
.73733 .54123 L
.73657 .541 L
.73581 .54078 L
.73506 .54056 L
.7343 .54033 L
.73355 .54011 L
.73279 .53989 L
.73204 .53967 L
.73129 .53944 L
.73054 .53922 L
.72979 .539 L
.72904 .53878 L
.72829 .53856 L
.72755 .53834 L
.7268 .53811 L
.72606 .53789 L
.72532 .53767 L
.72458 .53745 L
.72384 .53723 L
.7231 .53701 L
.72236 .53679 L
.72162 .53657 L
.72089 .53635 L
.72015 .53613 L
.71942 .53591 L
.71869 .53569 L
.71796 .53547 L
.71723 .53525 L
.7165 .53503 L
.71577 .53481 L
.71505 .53459 L
.71432 .53437 L
.7136 .53415 L
.71288 .53393 L
.71215 .53372 L
.71143 .5335 L
.71072 .53328 L
.71 .53306 L
.70928 .53285 L
.70856 .53263 L
.70785 .53241 L
.70714 .5322 L
.70642 .53198 L
.70571 .53176 L
.705 .53155 L
.70429 .53133 L
.70358 .53111 L
.70288 .5309 L
.70217 .53068 L
Mistroke
.70147 .53047 L
.70076 .53025 L
.70006 .53004 L
.69936 .52982 L
.69866 .52961 L
.69796 .52939 L
.69726 .52918 L
.69656 .52896 L
.69586 .52875 L
.69517 .52853 L
.69447 .52832 L
.69378 .52811 L
.69309 .52789 L
.6924 .52768 L
.69171 .52746 L
.69102 .52725 L
.69033 .52704 L
.68964 .52682 L
.68896 .52661 L
.68827 .5264 L
.68759 .52619 L
.68691 .52597 L
.68623 .52576 L
.68555 .52555 L
.68487 .52534 L
.68419 .52513 L
.68351 .52492 L
.68283 .52471 L
.68216 .52449 L
.68148 .52428 L
.68081 .52407 L
.68014 .52386 L
.67947 .52365 L
.67879 .52344 L
.67813 .52323 L
.67746 .52303 L
.67679 .52282 L
.67612 .52261 L
.67546 .5224 L
.67479 .52219 L
.67413 .52199 L
.67347 .52178 L
.67281 .52157 L
.67214 .52136 L
.67149 .52116 L
.67083 .52095 L
.67017 .52074 L
.66951 .52054 L
.66886 .52033 L
.6682 .52012 L
Mistroke
.66755 .51992 L
.6669 .51971 L
.66624 .5195 L
.66559 .5193 L
.66494 .51909 L
.66429 .51889 L
.66365 .51868 L
.663 .51848 L
.66235 .51827 L
.66171 .51807 L
.66106 .51787 L
.66042 .51766 L
.65978 .51746 L
.65914 .51725 L
.6585 .51705 L
.65786 .51685 L
.65722 .51664 L
.65658 .51644 L
.65595 .51624 L
.65531 .51603 L
.65468 .51583 L
.65404 .51563 L
.65341 .51543 L
.65278 .51522 L
.65215 .51502 L
.65152 .51482 L
.65089 .51462 L
.65026 .51442 L
.64963 .51422 L
.649 .51402 L
.64838 .51382 L
.64775 .51361 L
.64713 .51341 L
.64651 .51321 L
.64588 .51301 L
.64526 .51281 L
.64464 .51261 L
.64402 .51242 L
.64341 .51222 L
.64279 .51202 L
.64217 .51182 L
.64156 .51162 L
.64094 .51142 L
.64033 .51122 L
.63971 .51102 L
.6391 .51082 L
.63849 .51062 L
.63788 .51042 L
.63727 .51023 L
.63666 .51003 L
Mistroke
.63605 .50983 L
.63545 .50963 L
.63484 .50943 L
.63424 .50923 L
.63363 .50904 L
.63303 .50884 L
.63243 .50864 L
.63182 .50844 L
.63122 .50825 L
.63062 .50805 L
.63002 .50785 L
.62943 .50765 L
.62883 .50746 L
.62823 .50726 L
.62764 .50706 L
.62704 .50687 L
.62645 .50667 L
.62585 .50647 L
.62526 .50628 L
.62467 .50608 L
.62408 .50588 L
.62349 .50569 L
.6229 .50549 L
.62231 .5053 L
.62172 .5051 L
.62114 .50491 L
.62055 .50471 L
.61997 .50452 L
.61938 .50432 L
.6188 .50413 L
.61822 .50393 L
.61763 .50374 L
.61705 .50354 L
.61647 .50335 L
.61589 .50315 L
.61531 .50296 L
.61474 .50277 L
.61416 .50257 L
.61358 .50238 L
.61301 .50218 L
.61243 .50199 L
.61186 .5018 L
.61129 .5016 L
.61072 .50141 L
.61014 .50122 L
.60957 .50103 L
.609 .50083 L
.60843 .50064 L
.60787 .50045 L
.6073 .50026 L
Mistroke
.60673 .50007 L
.60617 .49988 L
.6056 .49968 L
.60504 .49949 L
.60447 .4993 L
.60391 .49911 L
.60335 .49892 L
.60279 .49873 L
.60223 .49854 L
.60167 .49835 L
.60111 .49816 L
.60055 .49797 L
.59999 .49778 L
.59944 .49759 L
.59888 .4974 L
.59833 .49721 L
.59777 .49702 L
.59722 .49683 L
.59667 .49664 L
.59611 .49645 L
.59556 .49626 L
.59501 .49608 L
.59446 .49589 L
.59391 .4957 L
.59336 .49551 L
.59282 .49532 L
.59227 .49513 L
.59172 .49494 L
.59118 .49476 L
.59063 .49457 L
.59009 .49438 L
.58955 .49419 L
.589 .49401 L
.58846 .49382 L
.58792 .49363 L
.58738 .49344 L
.58684 .49326 L
.5863 .49307 L
.58577 .49288 L
.58523 .49269 L
.58469 .49251 L
.58416 .49232 L
.58362 .49213 L
.58309 .49194 L
.58255 .49176 L
.58202 .49157 L
.58149 .49138 L
.58096 .4912 L
.58042 .49101 L
.57989 .49082 L
Mistroke
.57937 .49064 L
.57884 .49045 L
.57831 .49026 L
.57778 .49008 L
.57725 .48989 L
.57673 .4897 L
.5762 .48952 L
.57568 .48933 L
.57515 .48915 L
.57463 .48896 L
.57411 .48878 L
.57359 .48859 L
.57307 .48841 L
.57255 .48822 L
.57203 .48804 L
.57151 .48785 L
.57099 .48767 L
.57047 .48748 L
.56995 .4873 L
.56944 .48711 L
.56892 .48693 L
.56841 .48675 L
.56789 .48656 L
.56738 .48638 L
.56687 .48619 L
.56635 .48601 L
.56584 .48583 L
.56533 .48564 L
.56482 .48546 L
.56431 .48527 L
.5638 .48509 L
.5633 .48491 L
.56279 .48472 L
.56228 .48454 L
.56177 .48436 L
.56127 .48417 L
.56076 .48399 L
.56026 .48381 L
.55976 .48363 L
.55925 .48344 L
.55875 .48326 L
.55825 .48308 L
.55775 .48289 L
.55725 .48271 L
.55675 .48253 L
.55625 .48235 L
.55575 .48216 L
.55525 .48198 L
.55476 .4818 L
.55426 .48162 L
Mistroke
.55376 .48144 L
.55327 .48126 L
.55277 .48107 L
.55228 .48089 L
.55179 .48071 L
.55129 .48053 L
.5508 .48035 L
.55031 .48017 L
.54982 .47999 L
.54933 .4798 L
.54884 .47962 L
.54835 .47944 L
.54786 .47926 L
.54738 .47908 L
.54689 .4789 L
.5464 .47872 L
.54592 .47854 L
.54543 .47836 L
.54495 .47818 L
.54446 .478 L
.54398 .47782 L
.5435 .47765 L
.54301 .47747 L
.54253 .47729 L
.54205 .47711 L
.54157 .47693 L
.54109 .47675 L
.54061 .47657 L
.54014 .47639 L
.53966 .47621 L
.53918 .47603 L
.5387 .47585 L
.53823 .47568 L
.53775 .4755 L
.53728 .47532 L
.5368 .47514 L
.53633 .47496 L
.53586 .47479 L
.53538 .47461 L
.53491 .47443 L
.53444 .47425 L
.53397 .47407 L
.5335 .4739 L
.53303 .47372 L
.53256 .47354 L
.53209 .47337 L
.53163 .47319 L
.53116 .47301 L
.53069 .47283 L
.53023 .47266 L
Mistroke
.52976 .47248 L
.5293 .4723 L
.52883 .47213 L
.52837 .47195 L
.52791 .47178 L
.52744 .4716 L
.52698 .47142 L
.52652 .47125 L
.52606 .47107 L
.5256 .4709 L
.52514 .47072 L
.52468 .47054 L
.52422 .47037 L
.52377 .47019 L
.52331 .47002 L
.52285 .46984 L
.5224 .46967 L
.52194 .46949 L
.52148 .46931 L
.52103 .46914 L
.52058 .46896 L
.52012 .46879 L
.51967 .46862 L
.51922 .46844 L
.51877 .46827 L
.51832 .46809 L
.51786 .46792 L
.51741 .46774 L
.51697 .46757 L
.51652 .4674 L
.51607 .46722 L
.51562 .46705 L
.51517 .46688 L
.51473 .4667 L
.51428 .46653 L
.51383 .46635 L
.51339 .46618 L
.51294 .46601 L
.5125 .46584 L
.51206 .46566 L
.51161 .46549 L
.51117 .46532 L
.51073 .46514 L
.51029 .46497 L
.50985 .4648 L
.50941 .46463 L
.50897 .46446 L
.50853 .46428 L
.50809 .46411 L
.50765 .46394 L
Mistroke
.50722 .46377 L
.50678 .4636 L
.50634 .46342 L
.50591 .46325 L
.50547 .46308 L
.50504 .46291 L
.5046 .46274 L
.50417 .46257 L
.50373 .4624 L
.5033 .46223 L
.50287 .46206 L
.50244 .46189 L
.50201 .46172 L
.50157 .46155 L
.50114 .46138 L
.50072 .46121 L
.50029 .46104 L
.49986 .46087 L
.49943 .4607 L
.499 .46053 L
.49857 .46036 L
.49815 .46019 L
.49772 .46002 L
.4973 .45985 L
.49687 .45968 L
.49645 .45951 L
.49602 .45934 L
.4956 .45917 L
.49518 .459 L
.49475 .45883 L
.49433 .45867 L
.49391 .4585 L
.49349 .45833 L
.49307 .45816 L
.49265 .45799 L
.49223 .45782 L
.49181 .45765 L
.49139 .45748 L
.49097 .45732 L
.49056 .45715 L
.49014 .45698 L
.48972 .45681 L
.48931 .45664 L
.48889 .45648 L
.48847 .45631 L
.48806 .45614 L
.48765 .45597 L
.48723 .4558 L
.48682 .45564 L
.48641 .45547 L
Mistroke
.48599 .4553 L
.48558 .45513 L
.48517 .45497 L
.48476 .4548 L
.48435 .45463 L
.48394 .45446 L
.48353 .45429 L
.48312 .45413 L
.48271 .45396 L
.48231 .45379 L
.4819 .45363 L
.48149 .45346 L
.48109 .45329 L
.48068 .45313 L
.48027 .45296 L
.47987 .45279 L
.47946 .45262 L
.47906 .45246 L
.47866 .45229 L
.47825 .45213 L
.47785 .45196 L
.47745 .45179 L
.47705 .45163 L
.47665 .45146 L
.47625 .45129 L
.47585 .45113 L
.47545 .45096 L
.47505 .4508 L
.47465 .45063 L
.47425 .45047 L
.47385 .4503 L
.47345 .45014 L
.47306 .44997 L
.47266 .44981 L
.47226 .44964 L
.47187 .44948 L
.47147 .44931 L
.47108 .44915 L
.47068 .44898 L
.47029 .44882 L
.4699 .44865 L
.4695 .44849 L
.46911 .44832 L
.46872 .44816 L
.46833 .44799 L
.46794 .44783 L
.46754 .44766 L
.46715 .4475 L
.46676 .44734 L
.46638 .44717 L
Mistroke
.46599 .44701 L
.4656 .44684 L
.46521 .44668 L
.46482 .44652 L
.46444 .44635 L
.46405 .44619 L
.46366 .44603 L
.46328 .44586 L
.46289 .4457 L
.46251 .44554 L
.46212 .44537 L
.46174 .44521 L
.46135 .44505 L
.46097 .44489 L
.46059 .44472 L
.46021 .44456 L
.45982 .4444 L
.45944 .44424 L
.45906 .44407 L
.45868 .44391 L
.4583 .44375 L
.45792 .44359 L
.45754 .44343 L
.45716 .44326 L
.45678 .4431 L
.45641 .44294 L
.45603 .44278 L
.45565 .44262 L
.45527 .44246 L
.4549 .4423 L
.45452 .44213 L
.45415 .44197 L
.45377 .44181 L
.4534 .44165 L
.45302 .44149 L
.45265 .44133 L
.45227 .44117 L
.4519 .44101 L
.45153 .44085 L
.45116 .44068 L
.45078 .44052 L
.45041 .44036 L
.45004 .4402 L
.44967 .44004 L
.4493 .43988 L
.44893 .43972 L
.44856 .43956 L
.44819 .4394 L
.44783 .43924 L
.44746 .43908 L
Mistroke
.44709 .43892 L
.44672 .43876 L
.44636 .4386 L
.44599 .43844 L
.44562 .43828 L
.44526 .43812 L
.44489 .43796 L
.44453 .4378 L
.44416 .43764 L
.4438 .43749 L
.44344 .43733 L
.44307 .43717 L
.44271 .43701 L
.44235 .43685 L
.44199 .43669 L
.44162 .43653 L
.44126 .43637 L
.4409 .43621 L
.44054 .43606 L
.44018 .4359 L
.43982 .43574 L
.43946 .43558 L
.4391 .43542 L
.43875 .43526 L
.43839 .4351 L
.43803 .43495 L
.43767 .43479 L
.43732 .43463 L
.43696 .43447 L
.4366 .43431 L
.43625 .43415 L
.43589 .434 L
.43554 .43384 L
.43518 .43368 L
.43483 .43352 L
.43448 .43336 L
.43412 .43321 L
.43377 .43305 L
.43342 .43289 L
.43306 .43274 L
.43271 .43258 L
.43236 .43242 L
.43201 .43226 L
.43166 .43211 L
.43131 .43195 L
.43096 .43179 L
.43061 .43164 L
.43026 .43148 L
.42991 .43133 L
.42956 .43117 L
Mistroke
.42921 .43101 L
.42887 .43086 L
.42852 .4307 L
.42817 .43055 L
.42783 .43039 L
.42748 .43023 L
.42713 .43008 L
.42679 .42992 L
.42644 .42977 L
.4261 .42961 L
.42576 .42946 L
.42541 .4293 L
.42507 .42915 L
.42472 .42899 L
.42438 .42884 L
.42404 .42868 L
.4237 .42853 L
.42336 .42837 L
.42301 .42822 L
.42267 .42806 L
.42233 .42791 L
.42199 .42775 L
.42165 .4276 L
.42131 .42744 L
.42097 .42729 L
.42063 .42713 L
.4203 .42698 L
.41996 .42683 L
.41962 .42667 L
.41928 .42652 L
.41895 .42636 L
.41861 .42621 L
.41827 .42606 L
.41794 .4259 L
.4176 .42575 L
.41727 .42559 L
.41693 .42544 L
.4166 .42529 L
.41626 .42513 L
.41593 .42498 L
.4156 .42483 L
.41526 .42467 L
.41493 .42452 L
.4146 .42437 L
.41427 .42421 L
.41393 .42406 L
.4136 .42391 L
.41327 .42375 L
.41294 .4236 L
.41261 .42345 L
Mistroke
.41228 .42329 L
.41195 .42314 L
.41162 .42299 L
.41129 .42284 L
.41096 .42268 L
.41064 .42253 L
.41031 .42238 L
.40998 .42223 L
.40965 .42207 L
.40933 .42192 L
.409 .42177 L
.40867 .42162 L
.40835 .42147 L
.40802 .42131 L
.4077 .42116 L
.40737 .42101 L
.40705 .42086 L
.40672 .42071 L
.4064 .42055 L
.40608 .4204 L
.40575 .42025 L
.40543 .4201 L
.40511 .41995 L
.40479 .4198 L
.40446 .41965 L
.40414 .4195 L
.40382 .41935 L
.4035 .4192 L
.40318 .41904 L
.40286 .41889 L
.40254 .41874 L
.40222 .41859 L
.4019 .41844 L
.40158 .41829 L
.40127 .41814 L
.40095 .41799 L
.40063 .41784 L
.40031 .41769 L
.4 .41754 L
.39968 .41739 L
.39936 .41725 L
.39905 .4171 L
.39873 .41695 L
.39841 .4168 L
.3981 .41665 L
.39778 .4165 L
.39747 .41635 L
.39716 .4162 L
.39684 .41605 L
.39653 .41591 L
Mistroke
.39621 .41576 L
.3959 .41561 L
.39559 .41546 L
.39528 .41531 L
.39497 .41516 L
.39465 .41502 L
.39434 .41487 L
.39403 .41472 L
.39372 .41457 L
.39341 .41442 L
.3931 .41428 L
.39279 .41413 L
.39248 .41398 L
.39217 .41383 L
.39186 .41369 L
.39155 .41354 L
.39125 .41339 L
.39094 .41324 L
.39063 .4131 L
.39032 .41295 L
.39002 .4128 L
.38971 .41266 L
.3894 .41251 L
.3891 .41236 L
.38879 .41222 L
.38849 .41207 L
.38818 .41192 L
.38788 .41178 L
.38757 .41163 L
.38727 .41148 L
.38696 .41134 L
.38666 .41119 L
.38636 .41105 L
.38606 .4109 L
.38575 .41076 L
.38545 .41061 L
.38515 .41046 L
.38485 .41032 L
.38455 .41017 L
.38424 .41003 L
.38394 .40988 L
.38364 .40974 L
.38334 .40959 L
.38304 .40945 L
.38274 .4093 L
.38244 .40915 L
.38215 .40901 L
.38185 .40886 L
.38155 .40872 L
.38125 .40857 L
Mistroke
.38095 .40843 L
.38065 .40828 L
.38036 .40814 L
.38006 .40799 L
.37976 .40785 L
.37947 .4077 L
.37917 .40756 L
.37888 .40741 L
.37858 .40727 L
.37829 .40713 L
.37799 .40698 L
.3777 .40684 L
.3774 .40669 L
.37711 .40655 L
.37681 .40641 L
.37652 .40626 L
.37623 .40612 L
.37594 .40597 L
.37564 .40583 L
.37535 .40569 L
.37506 .40554 L
.37477 .4054 L
.37448 .40526 L
.37418 .40511 L
.37389 .40497 L
.3736 .40483 L
.37331 .40469 L
.37302 .40454 L
.37273 .4044 L
.37244 .40426 L
.37216 .40412 L
.37187 .40397 L
.37158 .40383 L
.37129 .40369 L
.371 .40355 L
.37071 .4034 L
.37043 .40326 L
.37014 .40312 L
.36985 .40298 L
.36957 .40283 L
.36928 .40269 L
.369 .40255 L
.36871 .40241 L
.36842 .40227 L
.36814 .40213 L
.36785 .40198 L
.36757 .40184 L
.36729 .4017 L
.367 .40156 L
.36672 .40142 L
Mistroke
.36643 .40128 L
.36615 .40113 L
.36587 .40099 L
.36559 .40085 L
.3653 .40071 L
.36502 .40057 L
.36474 .40043 L
.36446 .40029 L
.36418 .40015 L
.3639 .4 L
.36362 .39986 L
.36333 .39972 L
.36305 .39958 L
.36277 .39944 L
.3625 .3993 L
.36222 .39916 L
.36194 .39902 L
.36166 .39888 L
.36138 .39874 L
.3611 .3986 L
.36082 .39846 L
.36055 .39832 L
.36027 .39817 L
.35999 .39803 L
.35971 .39789 L
.35944 .39775 L
.35916 .39761 L
.35889 .39747 L
.35861 .39733 L
.35833 .39719 L
.35806 .39705 L
.35778 .39691 L
.35751 .39677 L
.35723 .39663 L
.35696 .39649 L
.35669 .39635 L
.35641 .39621 L
.35614 .39607 L
.35587 .39593 L
.35559 .39579 L
.35532 .39565 L
.35505 .39551 L
.35478 .39537 L
.3545 .39523 L
.35423 .39509 L
.35396 .39495 L
.35369 .39481 L
.35342 .39467 L
.35315 .39454 L
.35288 .3944 L
Mistroke
.35261 .39426 L
.35234 .39412 L
.35207 .39398 L
.3518 .39384 L
.35153 .3937 L
.35126 .39356 L
.35099 .39342 L
.35072 .39328 L
.35046 .39314 L
.35019 .393 L
.34992 .39286 L
.34965 .39273 L
.34939 .39259 L
.34912 .39245 L
.34885 .39231 L
.34859 .39217 L
.34832 .39204 L
.34806 .3919 L
.34779 .39176 L
.34752 .39162 L
.34726 .39148 L
.34699 .39135 L
.34673 .39121 L
.34647 .39107 L
.3462 .39093 L
.34594 .39079 L
.34567 .39066 L
.34541 .39052 L
.34515 .39038 L
.34489 .39024 L
.34462 .3901 L
.34436 .38997 L
.3441 .38983 L
.34384 .38969 L
.34358 .38956 L
.34331 .38942 L
.34305 .38928 L
.34279 .38914 L
.34253 .38901 L
.34227 .38887 L
.34201 .38873 L
.34175 .38859 L
.34149 .38846 L
.34123 .38832 L
.34097 .38818 L
.34071 .38805 L
.34046 .38791 L
.3402 .38777 L
.33994 .38764 L
.33968 .3875 L
Mistroke
.33942 .38736 L
.33917 .38723 L
.33891 .38709 L
.33865 .38695 L
.3384 .38682 L
.33814 .38668 L
.33788 .38654 L
.33763 .38641 L
.33737 .38627 L
.33712 .38613 L
.33686 .386 L
.33661 .38586 L
.33635 .38573 L
.3361 .38559 L
.33584 .38545 L
.33559 .38532 L
.33533 .38518 L
.33508 .38504 L
.33483 .38491 L
.33457 .38477 L
.33432 .38464 L
.33407 .3845 L
.33382 .38436 L
.33356 .38423 L
.33331 .38409 L
.33306 .38396 L
.33281 .38382 L
.33256 .38369 L
.33231 .38355 L
.33205 .38341 L
.3318 .38328 L
.33155 .38314 L
.3313 .38301 L
.33105 .38287 L
.3308 .38274 L
.33055 .38261 L
.33031 .38247 L
.33006 .38234 L
.32981 .3822 L
.32956 .38207 L
.32931 .38193 L
.32906 .3818 L
.32881 .38167 L
.32857 .38153 L
.32832 .3814 L
.32807 .38126 L
.32783 .38113 L
.32758 .381 L
.32733 .38086 L
.32709 .38073 L
Mistroke
.32684 .38059 L
.32659 .38046 L
.32635 .38033 L
.3261 .38019 L
.32586 .38006 L
.32561 .37993 L
.32537 .37979 L
.32512 .37966 L
.32488 .37953 L
.32464 .37939 L
.32439 .37926 L
.32415 .37913 L
.3239 .379 L
.32366 .37886 L
.32342 .37873 L
.32318 .3786 L
.32293 .37846 L
.32269 .37833 L
.32245 .3782 L
.32221 .37806 L
.32196 .37793 L
.32172 .3778 L
.32148 .37767 L
.32124 .37753 L
.321 .3774 L
.32076 .37727 L
.32052 .37713 L
.32028 .377 L
.32004 .37687 L
.3198 .37674 L
.31956 .3766 L
.31932 .37647 L
.31908 .37634 L
.31884 .37621 L
.3186 .37608 L
.31837 .37594 L
.31813 .37581 L
.31789 .37568 L
.31765 .37555 L
.31741 .37542 L
.31718 .37529 L
.31694 .37515 L
.3167 .37502 L
.31647 .37489 L
.31623 .37476 L
.31599 .37463 L
.31576 .3745 L
.31552 .37437 L
.31529 .37424 L
.31505 .37411 L
Mistroke
.31481 .37398 L
.31458 .37384 L
.31434 .37371 L
.31411 .37358 L
.31388 .37345 L
.31364 .37332 L
.31341 .37319 L
.31317 .37306 L
.31294 .37293 L
.31271 .3728 L
.31247 .37267 L
.31224 .37254 L
.31201 .37241 L
.31178 .37228 L
.31154 .37215 L
.31131 .37202 L
.31108 .37189 L
.31085 .37176 L
.31062 .37163 L
.31038 .3715 L
.31015 .37137 L
.30992 .37124 L
.30969 .37111 L
.30946 .37098 L
.30923 .37085 L
.309 .37072 L
.30877 .37059 L
.30854 .37046 L
.30831 .37033 L
.30808 .3702 L
.30785 .37007 L
.30762 .36994 L
.3074 .36981 L
.30717 .36968 L
.30694 .36955 L
.30671 .36942 L
.30648 .3693 L
.30625 .36917 L
.30603 .36904 L
.3058 .36891 L
.30557 .36878 L
.30535 .36865 L
.30512 .36852 L
.30489 .36839 L
.30467 .36827 L
.30444 .36814 L
.30421 .36801 L
.30399 .36788 L
.30376 .36775 L
.30354 .36763 L
Mistroke
.30331 .3675 L
.30309 .36737 L
.30286 .36724 L
.30264 .36712 L
.30241 .36699 L
.30219 .36686 L
.30197 .36673 L
.30174 .36661 L
.30152 .36648 L
.3013 .36635 L
.30107 .36622 L
.30085 .3661 L
.30063 .36597 L
.3004 .36584 L
.30018 .36572 L
.29996 .36559 L
.29974 .36546 L
.29951 .36534 L
.29929 .36521 L
.29907 .36508 L
.29885 .36496 L
.29863 .36483 L
.29841 .3647 L
.29819 .36458 L
.29797 .36445 L
.29775 .36432 L
.29753 .3642 L
.29731 .36407 L
.29709 .36394 L
.29687 .36382 L
.29665 .36369 L
.29643 .36356 L
.29621 .36344 L
.29599 .36331 L
.29577 .36318 L
.29555 .36306 L
.29534 .36293 L
.29512 .36281 L
.2949 .36268 L
.29468 .36255 L
.29446 .36243 L
.29425 .3623 L
.29403 .36218 L
.29381 .36205 L
.2936 .36193 L
.29338 .3618 L
.29316 .36168 L
.29295 .36155 L
.29273 .36143 L
.29252 .3613 L
Mistroke
.2923 .36118 L
.29208 .36105 L
.29187 .36093 L
.29165 .3608 L
.29144 .36068 L
.29122 .36055 L
.29101 .36043 L
.2908 .36031 L
.29058 .36018 L
.29037 .36006 L
.29015 .35993 L
.28994 .35981 L
.28973 .35969 L
.28951 .35956 L
.2893 .35944 L
.28909 .35931 L
.28887 .35919 L
.28866 .35907 L
.28845 .35894 L
.28824 .35882 L
.28802 .3587 L
.28781 .35857 L
.2876 .35845 L
.28739 .35832 L
.28718 .3582 L
.28697 .35808 L
.28676 .35795 L
.28655 .35783 L
.28634 .35771 L
.28612 .35758 L
.28591 .35746 L
.2857 .35734 L
.28549 .35721 L
.28528 .35709 L
.28508 .35697 L
.28487 .35684 L
.28466 .35672 L
.28445 .3566 L
.28424 .35648 L
.28403 .35635 L
.28382 .35623 L
.28361 .35611 L
.28341 .35598 L
.2832 .35586 L
.28299 .35574 L
.28278 .35562 L
.28257 .35549 L
.28237 .35537 L
.28216 .35525 L
.28195 .35513 L
Mistroke
.28175 .35501 L
.28154 .35488 L
.28133 .35476 L
.28113 .35464 L
.28092 .35452 L
.28071 .3544 L
.28051 .35427 L
.2803 .35415 L
.2801 .35403 L
.27989 .35391 L
.27969 .35379 L
.27948 .35367 L
.27928 .35355 L
.27907 .35343 L
.27887 .3533 L
.27867 .35318 L
.27846 .35306 L
.27826 .35294 L
.27805 .35282 L
.27785 .3527 L
.27765 .35258 L
.27744 .35246 L
.27724 .35234 L
.27704 .35222 L
.27683 .3521 L
.27663 .35198 L
.27643 .35186 L
.27623 .35174 L
.27603 .35162 L
.27582 .3515 L
.27562 .35138 L
.27542 .35126 L
.27522 .35114 L
.27502 .35102 L
.27482 .3509 L
.27462 .35078 L
.27442 .35066 L
.27421 .35054 L
.27401 .35042 L
.27381 .3503 L
.27361 .35018 L
.27341 .35006 L
.27321 .34994 L
.27302 .34982 L
.27282 .3497 L
.27262 .34958 L
.27242 .34946 L
.27222 .34934 L
.27202 .34922 L
.27182 .3491 L
Mistroke
.27162 .34898 L
.27142 .34886 L
.27123 .34874 L
.27103 .34862 L
.27083 .3485 L
.27063 .34838 L
.27044 .34826 L
.27024 .34814 L
.27004 .34802 L
.26984 .34791 L
.26965 .34779 L
.26945 .34767 L
.26925 .34755 L
.26906 .34743 L
.26886 .34731 L
.26867 .34719 L
.26847 .34707 L
.26827 .34695 L
.26808 .34683 L
.26788 .34671 L
.26769 .34659 L
.26749 .34648 L
.2673 .34636 L
.2671 .34624 L
.26691 .34612 L
.26671 .346 L
.26652 .34588 L
.26633 .34576 L
.26613 .34564 L
.26594 .34553 L
.26575 .34541 L
.26555 .34529 L
.26536 .34517 L
.26517 .34505 L
.26497 .34493 L
.26478 .34481 L
.26459 .3447 L
.26439 .34458 L
.2642 .34446 L
.26401 .34434 L
.26382 .34422 L
.26363 .34411 L
.26343 .34399 L
.26324 .34387 L
.26305 .34375 L
.26286 .34363 L
.26267 .34352 L
.26248 .3434 L
.26229 .34328 L
.2621 .34316 L
Mistroke
.2619 .34304 L
.26171 .34293 L
.26152 .34281 L
.26133 .34269 L
.26114 .34257 L
.26095 .34245 L
.26076 .34234 L
.26058 .34222 L
.26039 .3421 L
.2602 .34198 L
.26001 .34187 L
.25982 .34175 L
.25963 .34163 L
.25944 .34151 L
.25925 .3414 L
.25906 .34128 L
.25888 .34116 L
.25869 .34105 L
.2585 .34093 L
.25831 .34081 L
.25813 .34069 L
.25794 .34058 L
.25775 .34046 L
.25756 .34034 L
.25738 .34023 L
.25719 .34011 L
.257 .33999 L
.25682 .33987 L
.25663 .33976 L
.25644 .33964 L
.25626 .33952 L
.25607 .33941 L
.25589 .33929 L
.2557 .33917 L
.25552 .33906 L
.25533 .33894 L
.25514 .33883 L
.25496 .33871 L
.25478 .33859 L
.25459 .33848 L
.25441 .33836 L
.25422 .33825 L
.25404 .33813 L
.25385 .33801 L
.25367 .3379 L
.25348 .33778 L
.2533 .33767 L
.25312 .33755 L
.25293 .33744 L
.25275 .33732 L
Mistroke
.25257 .33721 L
.25238 .33709 L
.2522 .33698 L
.25202 .33686 L
.25184 .33675 L
.25165 .33663 L
.25147 .33652 L
.25129 .3364 L
.25111 .33629 L
.25093 .33617 L
.25074 .33606 L
.25056 .33594 L
.25038 .33583 L
.2502 .33571 L
.25002 .3356 L
.24984 .33548 L
.24966 .33537 L
.24948 .33525 L
.2493 .33514 L
.24911 .33503 L
.24893 .33491 L
.24875 .3348 L
.24857 .33468 L
.24839 .33457 L
.24821 .33446 L
.24804 .33434 L
.24786 .33423 L
.24768 .33411 L
.2475 .334 L
.24732 .33389 L
.24714 .33377 L
.24696 .33366 L
.24678 .33354 L
.2466 .33343 L
.24642 .33332 L
.24625 .3332 L
.24607 .33309 L
.24589 .33298 L
.24571 .33286 L
.24554 .33275 L
.24536 .33264 L
.24518 .33252 L
.245 .33241 L
.24483 .3323 L
.24465 .33218 L
.24447 .33207 L
.2443 .33196 L
.24412 .33184 L
.24394 .33173 L
.24377 .33162 L
Mistroke
.24359 .33151 L
.24341 .33139 L
.24324 .33128 L
.24306 .33117 L
.24289 .33105 L
.24271 .33094 L
.24254 .33083 L
.24236 .33072 L
.24219 .33061 L
.24201 .33049 L
.24184 .33038 L
.24166 .33027 L
.24149 .33016 L
.24131 .33004 L
.24114 .32993 L
.24096 .32982 L
.24079 .32971 L
.24062 .32959 L
.24044 .32948 L
.24027 .32937 L
.24009 .32926 L
.23992 .32915 L
.23975 .32904 L
.23957 .32892 L
.2394 .32881 L
.23923 .3287 L
.23906 .32859 L
.23888 .32848 L
.23871 .32837 L
.23854 .32825 L
.23837 .32814 L
.23819 .32803 L
.23802 .32792 L
.23785 .32781 L
.23768 .3277 L
.23751 .32759 L
.23734 .32747 L
.23717 .32736 L
.23699 .32725 L
.23682 .32714 L
.23665 .32703 L
.23648 .32692 L
.23631 .32681 L
.23614 .3267 L
.23597 .32658 L
.2358 .32647 L
.23563 .32636 L
.23546 .32625 L
.23529 .32614 L
.23512 .32603 L
Mistroke
.23495 .32592 L
.23478 .32581 L
.23461 .3257 L
.23444 .32558 L
.23427 .32547 L
.2341 .32536 L
.23394 .32525 L
.23377 .32514 L
.2336 .32503 L
.23343 .32492 L
.23326 .32481 L
.23309 .3247 L
.23293 .32459 L
.23276 .32448 L
.23259 .32437 L
.23242 .32425 L
.23225 .32414 L
.23209 .32403 L
.23192 .32392 L
.23175 .32381 L
.23159 .3237 L
.23142 .32359 L
.23125 .32348 L
.23109 .32337 L
.23092 .32326 L
.23075 .32315 L
.23059 .32304 L
.23042 .32293 L
.23025 .32282 L
.23009 .32271 L
.22992 .3226 L
.22976 .32249 L
.22959 .32238 L
.22943 .32227 L
.22926 .32216 L
.22909 .32205 L
.22893 .32194 L
.22876 .32183 L
.2286 .32172 L
.22844 .32161 L
.22827 .3215 L
.22811 .32139 L
.22794 .32128 L
.22778 .32117 L
.22761 .32106 L
.22745 .32095 L
.22729 .32084 L
.22712 .32073 L
.22696 .32062 L
.22679 .32051 L
Mistroke
.22663 .3204 L
.22647 .3203 L
.22631 .32019 L
.22614 .32008 L
.22598 .31997 L
.22582 .31986 L
.22565 .31975 L
.22549 .31964 L
.22533 .31953 L
.22517 .31942 L
.225 .31931 L
.22484 .31921 L
.22468 .3191 L
.22452 .31899 L
.22436 .31888 L
.2242 .31877 L
.22403 .31867 L
.22387 .31856 L
.22371 .31845 L
.22355 .31834 L
.22339 .31823 L
.22323 .31812 L
.22307 .31802 L
.22291 .31791 L
.22275 .3178 L
.22259 .31769 L
.22243 .31758 L
.22227 .31748 L
.22211 .31737 L
.22195 .31726 L
.22179 .31715 L
.22163 .31705 L
.22147 .31694 L
.22131 .31683 L
.22115 .31672 L
.22099 .31662 L
.22083 .31651 L
.22067 .3164 L
.22051 .31629 L
.22035 .31619 L
.22019 .31608 L
.22004 .31597 L
.21988 .31586 L
.21972 .31576 L
.21956 .31565 L
.2194 .31554 L
.21925 .31544 L
.21909 .31533 L
.21893 .31522 L
.21877 .31511 L
Mistroke
.21861 .31501 L
.21846 .3149 L
.2183 .31479 L
.21814 .31469 L
.21799 .31458 L
.21783 .31447 L
.21767 .31437 L
.21752 .31426 L
.21736 .31415 L
.2172 .31405 L
.21705 .31394 L
.21689 .31383 L
.21673 .31372 L
.21658 .31362 L
.21642 .31351 L
.21627 .3134 L
.21611 .3133 L
.21596 .31319 L
.2158 .31309 L
.21564 .31298 L
.21549 .31287 L
.21533 .31277 L
.21518 .31266 L
.21502 .31255 L
.21487 .31245 L
.21471 .31234 L
.21456 .31224 L
.21441 .31213 L
.21425 .31202 L
.2141 .31192 L
.21394 .31181 L
.21379 .3117 L
.21364 .3116 L
.21348 .31149 L
.21333 .31139 L
.21317 .31128 L
.21302 .31117 L
.21287 .31107 L
.21271 .31096 L
.21256 .31086 L
.21241 .31075 L
.21226 .31065 L
.2121 .31054 L
.21195 .31043 L
.2118 .31033 L
.21164 .31022 L
.21149 .31012 L
.21134 .31001 L
.21119 .30991 L
.21104 .3098 L
Mistroke
.21088 .3097 L
.21073 .30959 L
.21058 .30948 L
.21043 .30938 L
.21028 .30927 L
.21013 .30917 L
.20998 .30906 L
.20982 .30896 L
.20967 .30885 L
.20952 .30875 L
.20937 .30864 L
.20922 .30854 L
.20907 .30843 L
.20892 .30833 L
.20877 .30822 L
.20862 .30812 L
.20847 .30801 L
.20832 .30791 L
.20817 .3078 L
.20802 .3077 L
.20787 .30759 L
.20772 .30749 L
.20757 .30738 L
.20742 .30728 L
.20727 .30718 L
.20712 .30707 L
.20697 .30697 L
.20682 .30686 L
.20667 .30676 L
.20653 .30665 L
.20638 .30655 L
.20623 .30644 L
.20608 .30634 L
.20593 .30624 L
.20578 .30613 L
.20564 .30603 L
.20549 .30592 L
.20534 .30582 L
.20519 .30571 L
.20504 .30561 L
.2049 .30551 L
.20475 .3054 L
.2046 .3053 L
.20445 .30519 L
.20431 .30509 L
.20416 .30499 L
.20401 .30488 L
.20387 .30478 L
.20372 .30467 L
.20357 .30457 L
Mistroke
.20343 .30447 L
.20328 .30436 L
.20313 .30426 L
.20299 .30415 L
.20284 .30405 L
.20269 .30395 L
.20255 .30384 L
.2024 .30374 L
.20226 .30364 L
.20211 .30353 L
.20196 .30343 L
.20182 .30333 L
.20167 .30322 L
.20153 .30312 L
.20138 .30302 L
.20124 .30291 L
.20109 .30281 L
.20095 .30271 L
.2008 .3026 L
.20066 .3025 L
.20051 .3024 L
.20037 .30229 L
.20023 .30219 L
.20008 .30209 L
.19994 .30199 L
.19979 .30188 L
.19965 .30178 L
.19951 .30168 L
.19936 .30157 L
.19922 .30147 L
.19907 .30137 L
.19893 .30126 L
.19879 .30116 L
.19864 .30106 L
.1985 .30096 L
.19836 .30085 L
.19821 .30075 L
.19807 .30065 L
.19793 .30055 L
.19779 .30044 L
.19764 .30034 L
.1975 .30024 L
.19736 .30014 L
.19722 .30003 L
.19707 .29993 L
.19693 .29983 L
.19679 .29973 L
.19665 .29962 L
.19651 .29952 L
.19636 .29942 L
Mistroke
.19622 .29932 L
.19608 .29922 L
.19594 .29911 L
.1958 .29901 L
.19566 .29891 L
.19552 .29881 L
.19538 .2987 L
.19523 .2986 L
.19509 .2985 L
.19495 .2984 L
.19481 .2983 L
.19467 .29819 L
.19453 .29809 L
.19439 .29799 L
.19425 .29789 L
.19411 .29779 L
.19397 .29768 L
.19383 .29758 L
.19369 .29748 L
.19355 .29738 L
.19341 .29728 L
.19327 .29718 L
.19313 .29708 L
.19299 .29697 L
.19285 .29687 L
.19271 .29677 L
.19258 .29667 L
.19244 .29657 L
.1923 .29647 L
.19216 .29637 L
.19202 .29627 L
.19188 .29617 L
.19174 .29607 L
.1916 .29596 L
.19147 .29586 L
.19133 .29576 L
.19119 .29566 L
.19105 .29556 L
.19091 .29546 L
.19078 .29536 L
.19064 .29526 L
.1905 .29516 L
.19036 .29506 L
.19023 .29496 L
.19009 .29486 L
.18995 .29476 L
.18981 .29466 L
.18968 .29456 L
.18954 .29446 L
.1894 .29436 L
Mistroke
.18927 .29426 L
.18913 .29416 L
.18899 .29406 L
.18886 .29396 L
.18872 .29386 L
.18858 .29376 L
.18845 .29366 L
.18831 .29356 L
.18817 .29346 L
.18804 .29336 L
.1879 .29327 L
.18777 .29317 L
.18763 .29307 L
.18749 .29297 L
.18736 .29287 L
.18722 .29277 L
.18709 .29267 L
.18695 .29257 L
.18682 .29247 L
.18668 .29237 L
.18655 .29227 L
.18641 .29217 L
.18628 .29207 L
.18614 .29198 L
.18601 .29188 L
.18587 .29178 L
.18574 .29168 L
.18561 .29158 L
.18547 .29148 L
.18534 .29138 L
.1852 .29128 L
.18507 .29118 L
.18494 .29108 L
.1848 .29099 L
.18467 .29089 L
.18453 .29079 L
.1844 .29069 L
.18427 .29059 L
.18413 .29049 L
.184 .29039 L
.18387 .2903 L
.18373 .2902 L
.1836 .2901 L
.18347 .29 L
.18333 .2899 L
.1832 .2898 L
.18307 .2897 L
.18294 .28961 L
.1828 .28951 L
.18267 .28941 L
Mistroke
.18254 .28931 L
.18241 .28921 L
.18228 .28911 L
.18214 .28902 L
.18201 .28892 L
.18188 .28882 L
.18175 .28872 L
.18162 .28862 L
.18148 .28853 L
.18135 .28843 L
.18122 .28833 L
.18109 .28823 L
.18096 .28813 L
.18083 .28804 L
.1807 .28794 L
.18057 .28784 L
.18043 .28774 L
.1803 .28765 L
.18017 .28755 L
.18004 .28745 L
.17991 .28735 L
.17978 .28725 L
.17965 .28716 L
.17952 .28706 L
.17939 .28696 L
.17926 .28687 L
.17913 .28677 L
.179 .28667 L
.17887 .28657 L
.17874 .28648 L
.17861 .28638 L
.17848 .28628 L
.17835 .28619 L
.17822 .28609 L
.17809 .28599 L
.17796 .28589 L
.17783 .2858 L
.17771 .2857 L
.17758 .2856 L
.17745 .28551 L
.17732 .28541 L
.17719 .28531 L
.17706 .28522 L
.17693 .28512 L
.1768 .28502 L
.17668 .28493 L
.17655 .28483 L
.17642 .28473 L
.17629 .28464 L
.17616 .28454 L
Mistroke
.17603 .28445 L
.17591 .28435 L
.17578 .28425 L
.17565 .28416 L
.17552 .28406 L
.1754 .28396 L
.17527 .28387 L
.17514 .28377 L
.17501 .28368 L
.17489 .28358 L
.17476 .28348 L
.17463 .28339 L
.1745 .28329 L
.17438 .2832 L
.17425 .2831 L
.17412 .283 L
.174 .28291 L
.17387 .28281 L
.17374 .28272 L
.17362 .28262 L
.17349 .28253 L
.17337 .28243 L
.17324 .28233 L
.17311 .28224 L
.17299 .28214 L
.17286 .28205 L
.17274 .28195 L
.17261 .28186 L
.17248 .28176 L
.17236 .28167 L
.17223 .28157 L
.17211 .28147 L
.17198 .28138 L
.17186 .28128 L
.17173 .28119 L
.17161 .28109 L
.17148 .281 L
.17136 .2809 L
.17123 .28081 L
.17111 .28071 L
.17098 .28062 L
.17086 .28052 L
.17073 .28043 L
.17061 .28033 L
.17048 .28024 L
.17036 .28014 L
.17024 .28005 L
.17011 .27995 L
.16999 .27986 L
.16986 .27976 L
Mistroke
.16974 .27967 L
.16962 .27957 L
.16949 .27948 L
.16937 .27938 L
.16924 .27929 L
.16912 .27919 L
.169 .2791 L
.16887 .279 L
.16875 .27891 L
.16863 .27881 L
.1685 .27872 L
.16838 .27862 L
.16826 .27853 L
.16814 .27843 L
.16801 .27834 L
.16789 .27825 L
.16777 .27815 L
.16764 .27806 L
.16752 .27796 L
.1674 .27787 L
.16728 .27777 L
.16715 .27768 L
.16703 .27758 L
.16691 .27749 L
.16679 .27739 L
.16667 .2773 L
.16654 .27721 L
.16642 .27711 L
.1663 .27702 L
.16618 .27692 L
.16606 .27683 L
.16594 .27673 L
.16582 .27664 L
.16569 .27654 L
.16557 .27645 L
.16545 .27636 L
.16533 .27626 L
.16521 .27617 L
.16509 .27607 L
.16497 .27598 L
.16485 .27588 L
.16473 .27579 L
.16461 .2757 L
.16448 .2756 L
.16436 .27551 L
.16424 .27541 L
.16412 .27532 L
.164 .27523 L
.16388 .27513 L
.16376 .27504 L
Mistroke
.16364 .27494 L
.16352 .27485 L
.1634 .27475 L
.16328 .27466 L
.16316 .27457 L
.16304 .27447 L
.16292 .27438 L
.16281 .27429 L
.16269 .27419 L
.16257 .2741 L
.16245 .274 L
.16233 .27391 L
.16221 .27382 L
.16209 .27372 L
.16197 .27363 L
.16185 .27354 L
.16173 .27344 L
.16161 .27335 L
.1615 .27325 L
.16138 .27316 L
.16126 .27307 L
.16114 .27297 L
.16102 .27288 L
.1609 .27279 L
.16079 .27269 L
.16067 .2726 L
.16055 .27251 L
.16043 .27241 L
.16031 .27232 L
.1602 .27223 L
.16008 .27213 L
.15996 .27204 L
.15984 .27195 L
.15973 .27186 L
.15961 .27176 L
.15949 .27167 L
.15937 .27158 L
.15926 .27148 L
.15914 .27139 L
.15902 .2713 L
.1589 .27121 L
.15879 .27111 L
.15867 .27102 L
.15855 .27093 L
.15844 .27083 L
.15832 .27074 L
.1582 .27065 L
.15809 .27056 L
.15797 .27046 L
.15785 .27037 L
Mistroke
.15774 .27028 L
.15762 .27019 L
.15751 .27009 L
.15739 .27 L
.15727 .26991 L
.15716 .26982 L
.15704 .26973 L
.15693 .26963 L
.15681 .26954 L
.15669 .26945 L
.15658 .26936 L
.15646 .26927 L
.15635 .26917 L
.15623 .26908 L
.15612 .26899 L
.156 .2689 L
.15589 .26881 L
.15577 .26871 L
.15566 .26862 L
.15554 .26853 L
.15543 .26844 L
.15531 .26835 L
.1552 .26826 L
.15508 .26816 L
.15497 .26807 L
.15485 .26798 L
.15474 .26789 L
.15463 .2678 L
.15451 .26771 L
.1544 .26761 L
.15428 .26752 L
.15417 .26743 L
.15405 .26734 L
.15394 .26725 L
.15383 .26716 L
.15371 .26707 L
.1536 .26697 L
.15349 .26688 L
.15337 .26679 L
.15326 .2667 L
.15315 .26661 L
.15303 .26652 L
.15292 .26643 L
.15281 .26634 L
.15269 .26625 L
.15258 .26615 L
.15247 .26606 L
.15235 .26597 L
.15224 .26588 L
.15213 .26579 L
Mistroke
.15201 .2657 L
.1519 .26561 L
.15179 .26552 L
.15168 .26543 L
.15156 .26534 L
.15145 .26525 L
.15134 .26516 L
.15123 .26507 L
.15112 .26498 L
.151 .26489 L
.15089 .2648 L
.15078 .26471 L
.15067 .26462 L
.15056 .26453 L
.15044 .26444 L
.15033 .26435 L
.15022 .26426 L
.15011 .26417 L
.15 .26408 L
.14989 .26399 L
.14977 .2639 L
.14966 .26381 L
.14955 .26372 L
.14944 .26363 L
.14933 .26354 L
.14922 .26345 L
.14911 .26336 L
.149 .26327 L
.14889 .26318 L
.14878 .26309 L
.14866 .263 L
.14855 .26291 L
.14844 .26282 L
.14833 .26273 L
.14822 .26264 L
.14811 .26255 L
.148 .26246 L
.14789 .26237 L
.14778 .26228 L
.14767 .26219 L
.14756 .2621 L
.14745 .26201 L
.14734 .26192 L
.14723 .26183 L
.14712 .26174 L
.14701 .26165 L
.1469 .26156 L
.14679 .26147 L
.14668 .26139 L
.14657 .2613 L
Mistroke
.14646 .26121 L
.14636 .26112 L
.14625 .26103 L
.14614 .26094 L
.14603 .26085 L
.14592 .26076 L
.14581 .26067 L
.1457 .26058 L
.14559 .2605 L
.14548 .26041 L
.14537 .26032 L
.14527 .26023 L
.14516 .26014 L
.14505 .26005 L
.14494 .25996 L
.14483 .25987 L
.14472 .25978 L
.14462 .2597 L
.14451 .25961 L
.1444 .25952 L
.14429 .25943 L
.14418 .25934 L
.14408 .25925 L
.14397 .25916 L
.14386 .25908 L
.14375 .25899 L
.14364 .2589 L
.14354 .25881 L
.14343 .25872 L
.14332 .25863 L
.14321 .25855 L
.14311 .25846 L
.143 .25837 L
.14289 .25828 L
.14279 .25819 L
.14268 .25811 L
.14257 .25802 L
.14246 .25793 L
.14236 .25784 L
.14225 .25775 L
.14214 .25767 L
.14204 .25758 L
.14193 .25749 L
.14182 .2574 L
.14172 .25731 L
.14161 .25723 L
.14151 .25714 L
.1414 .25705 L
.14129 .25696 L
.14119 .25688 L
Mistroke
.14108 .25679 L
.14097 .2567 L
.14087 .25661 L
.14076 .25653 L
.14066 .25644 L
.14055 .25635 L
.14044 .25626 L
.14034 .25618 L
.14023 .25609 L
.14013 .256 L
.14002 .25591 L
.13992 .25583 L
.13981 .25574 L
.13971 .25565 L
.1396 .25556 L
.1395 .25548 L
.13939 .25539 L
.13929 .2553 L
.13918 .25522 L
.13908 .25513 L
.13897 .25504 L
.13887 .25496 L
.13876 .25487 L
.13866 .25478 L
.13855 .25469 L
.13845 .25461 L
.13834 .25452 L
.13824 .25443 L
.13813 .25435 L
.13803 .25426 L
.13793 .25417 L
.13782 .25409 L
.13772 .254 L
.13761 .25391 L
.13751 .25383 L
.13741 .25374 L
.1373 .25365 L
.1372 .25357 L
.13709 .25348 L
.13699 .25339 L
.13689 .25331 L
.13678 .25322 L
.13668 .25313 L
.13658 .25305 L
.13647 .25296 L
.13637 .25287 L
.13627 .25279 L
.13616 .2527 L
.13606 .25262 L
.13596 .25253 L
Mistroke
.13585 .25244 L
.13575 .25236 L
.13565 .25227 L
.13555 .25219 L
.13544 .2521 L
.13534 .25201 L
.13524 .25193 L
.13513 .25184 L
.13503 .25176 L
.13493 .25167 L
.13483 .25158 L
.13473 .2515 L
.13462 .25141 L
.13452 .25133 L
.13442 .25124 L
.13432 .25116 L
.13421 .25107 L
.13411 .25098 L
.13401 .2509 L
.13391 .25081 L
.13381 .25073 L
.1337 .25064 L
.1336 .25056 L
.1335 .25047 L
.1334 .25038 L
.1333 .2503 L
.1332 .25021 L
.1331 .25013 L
.13299 .25004 L
.13289 .24996 L
.13279 .24987 L
.13269 .24979 L
.13259 .2497 L
.13249 .24962 L
.13239 .24953 L
.13229 .24945 L
.13219 .24936 L
.13209 .24928 L
.13198 .24919 L
.13188 .24911 L
.13178 .24902 L
.13168 .24894 L
.13158 .24885 L
.13148 .24877 L
.13138 .24868 L
.13128 .2486 L
.13118 .24851 L
.13108 .24843 L
.13098 .24834 L
.13088 .24826 L
Mistroke
.13078 .24818 L
.13068 .24809 L
.13058 .24801 L
.13048 .24792 L
.13038 .24784 L
.13028 .24775 L
.13018 .24767 L
.13008 .24758 L
.12998 .2475 L
.12988 .24741 L
.12978 .24733 L
.12968 .24724 L
.12958 .24716 L
.12948 .24708 L
.12939 .24699 L
.12929 .24691 L
.12919 .24682 L
.12909 .24674 L
.12899 .24665 L
.12889 .24657 L
.12879 .24648 L
.12869 .2464 L
.12859 .24632 L
.12849 .24623 L
.1284 .24615 L
.1283 .24606 L
.1282 .24598 L
.1281 .2459 L
.128 .24581 L
.1279 .24573 L
.12781 .24564 L
.12771 .24556 L
.12761 .24547 L
.12751 .24539 L
.12741 .24531 L
.12731 .24522 L
.12722 .24514 L
.12712 .24505 L
.12702 .24497 L
.12692 .24489 L
.12682 .2448 L
.12673 .24472 L
.12663 .24464 L
.12653 .24455 L
.12643 .24447 L
.12634 .24438 L
.12624 .2443 L
.12614 .24422 L
.12604 .24413 L
.12595 .24405 L
Mistroke
.12585 .24397 L
.12575 .24388 L
.12566 .2438 L
.12556 .24371 L
.12546 .24363 L
.12537 .24355 L
.12527 .24346 L
.12517 .24338 L
.12507 .2433 L
.12498 .24321 L
.12488 .24313 L
.12478 .24305 L
.12469 .24296 L
.12459 .24288 L
.1245 .2428 L
.1244 .24271 L
.1243 .24263 L
.12421 .24255 L
.12411 .24246 L
.12401 .24238 L
.12392 .2423 L
.12382 .24221 L
.12373 .24213 L
.12363 .24205 L
.12353 .24196 L
.12344 .24188 L
.12334 .2418 L
.12325 .24172 L
.12315 .24163 L
.12306 .24155 L
.12296 .24147 L
.12286 .24138 L
.12277 .2413 L
.12267 .24122 L
.12258 .24113 L
.12248 .24105 L
.12239 .24097 L
.12229 .24089 L
.1222 .2408 L
.1221 .24072 L
.12201 .24064 L
.12191 .24055 L
.12182 .24047 L
.12172 .24039 L
.12163 .24031 L
.12153 .24022 L
.12144 .24014 L
.12134 .24006 L
.12125 .23998 L
.12115 .23989 L
Mistroke
.12106 .23981 L
.12097 .23973 L
.12087 .23965 L
.12078 .23956 L
.12068 .23948 L
.12059 .2394 L
.12049 .23932 L
.1204 .23924 L
.12031 .23915 L
.12021 .23907 L
.12012 .23899 L
.12002 .23891 L
.11993 .23882 L
.11984 .23874 L
.11974 .23866 L
.11965 .23858 L
.11956 .2385 L
.11946 .23841 L
.11937 .23833 L
.11927 .23825 L
.11918 .23817 L
.11909 .23809 L
.11899 .23801 L
.1189 .23792 L
.11881 .23784 L
.11871 .23776 L
.11862 .23768 L
.11853 .2376 L
.11844 .23752 L
.11834 .23743 L
.11825 .23735 L
.11816 .23727 L
.11806 .23719 L
.11797 .23711 L
.11788 .23703 L
.11779 .23695 L
.11769 .23686 L
.1176 .23678 L
.11751 .2367 L
.11742 .23662 L
.11732 .23654 L
.11723 .23646 L
.11714 .23638 L
.11705 .2363 L
.11695 .23621 L
.11686 .23613 L
.11677 .23605 L
.11668 .23597 L
.11659 .23589 L
.11649 .23581 L
Mistroke
.1164 .23573 L
.11631 .23565 L
.11622 .23557 L
.11613 .23548 L
.11604 .2354 L
.11594 .23532 L
.11585 .23524 L
.11576 .23516 L
.11567 .23508 L
.11558 .235 L
.11549 .23492 L
.11539 .23484 L
.1153 .23476 L
.11521 .23468 L
.11512 .2346 L
.11503 .23452 L
.11494 .23443 L
.11485 .23435 L
.11476 .23427 L
.11467 .23419 L
.11458 .23411 L
.11448 .23403 L
.11439 .23395 L
.1143 .23387 L
.11421 .23379 L
.11412 .23371 L
.11403 .23363 L
.11394 .23355 L
.11385 .23347 L
.11376 .23339 L
.11367 .23331 L
.11358 .23323 L
.11349 .23315 L
.1134 .23307 L
.11331 .23299 L
.11322 .23291 L
.11313 .23283 L
.11304 .23275 L
.11295 .23267 L
.11286 .23259 L
.11277 .23251 L
.11268 .23243 L
.11259 .23235 L
.1125 .23227 L
.11241 .23219 L
.11232 .23211 L
.11223 .23203 L
.11214 .23195 L
.11205 .23187 L
.11196 .23179 L
Mistroke
.11187 .23171 L
.11178 .23163 L
.11169 .23155 L
.1116 .23147 L
.11152 .23139 L
.11143 .23131 L
.11134 .23123 L
.11125 .23115 L
.11116 .23107 L
.11107 .23099 L
.11098 .23091 L
.11089 .23083 L
.1108 .23075 L
.11071 .23067 L
.11063 .23059 L
.11054 .23051 L
.11045 .23043 L
.11036 .23035 L
.11027 .23028 L
.11018 .2302 L
.11009 .23012 L
.11001 .23004 L
.10992 .22996 L
.10983 .22988 L
.10974 .2298 L
.10965 .22972 L
.10957 .22964 L
.10948 .22956 L
.10939 .22948 L
.1093 .22941 L
.10921 .22933 L
.10913 .22925 L
.10904 .22917 L
.10895 .22909 L
.10886 .22901 L
.10877 .22893 L
.10869 .22885 L
.1086 .22877 L
.10851 .22869 L
.10842 .22862 L
.10834 .22854 L
.10825 .22846 L
.10816 .22838 L
.10807 .2283 L
.10799 .22822 L
.1079 .22814 L
.10781 .22806 L
.10773 .22799 L
.10764 .22791 L
.10755 .22783 L
Mistroke
.10746 .22775 L
.10738 .22767 L
.10729 .22759 L
.1072 .22751 L
.10712 .22743 L
.10703 .22736 L
.10694 .22728 L
.10686 .2272 L
.10677 .22712 L
.10668 .22704 L
.1066 .22696 L
.10651 .22688 L
.10642 .22681 L
.10634 .22673 L
.10625 .22665 L
.10617 .22657 L
.10608 .22649 L
.10599 .22641 L
.10591 .22634 L
.10582 .22626 L
.10573 .22618 L
.10565 .2261 L
.10556 .22602 L
.10548 .22594 L
.10539 .22587 L
.10531 .22579 L
.10522 .22571 L
.10513 .22563 L
.10505 .22555 L
.10496 .22548 L
.10488 .2254 L
.10479 .22532 L
.10471 .22524 L
.10462 .22516 L
.10453 .22509 L
.10445 .22501 L
.10436 .22493 L
.10428 .22485 L
.10419 .22477 L
.10411 .2247 L
.10402 .22462 L
.10394 .22454 L
.10385 .22446 L
.10377 .22438 L
.10368 .22431 L
.1036 .22423 L
.10351 .22415 L
.10343 .22407 L
.10334 .224 L
.10326 .22392 L
Mistroke
.10317 .22384 L
.10309 .22376 L
.10301 .22369 L
.10292 .22361 L
.10284 .22353 L
.10275 .22345 L
.10267 .22338 L
.10258 .2233 L
.1025 .22322 L
.10241 .22314 L
.10233 .22307 L
.10225 .22299 L
.10216 .22291 L
.10208 .22284 L
.10199 .22276 L
.10191 .22268 L
.10183 .2226 L
.10174 .22253 L
.10166 .22245 L
.10157 .22237 L
.10149 .2223 L
.10141 .22222 L
.10132 .22214 L
.10124 .22206 L
.10116 .22199 L
.10107 .22191 L
.10099 .22183 L
.10091 .22176 L
.10082 .22168 L
.10074 .2216 L
.10066 .22153 L
.10057 .22145 L
.10049 .22137 L
.10041 .2213 L
.10032 .22122 L
.10024 .22114 L
.10016 .22107 L
.10007 .22099 L
.09999 .22091 L
.09991 .22084 L
.09982 .22076 L
.09974 .22068 L
.09966 .22061 L
.09958 .22053 L
.09949 .22045 L
.09941 .22038 L
.09933 .2203 L
.09925 .22023 L
.09916 .22015 L
.09908 .22007 L
Mistroke
.099 .22 L
.09892 .21992 L
.09883 .21984 L
.09875 .21977 L
.09867 .21969 L
.09859 .21962 L
.0985 .21954 L
.09842 .21946 L
.09834 .21939 L
.09826 .21931 L
.09818 .21923 L
.09809 .21916 L
.09801 .21908 L
.09793 .21901 L
.09785 .21893 L
.09777 .21886 L
.09768 .21878 L
.0976 .2187 L
.09752 .21863 L
.09744 .21855 L
.09736 .21848 L
.09728 .2184 L
.09719 .21833 L
.09711 .21825 L
.09703 .21817 L
.09695 .2181 L
.09687 .21802 L
.09679 .21795 L
.09671 .21787 L
.09662 .2178 L
.09654 .21772 L
.09646 .21764 L
.09638 .21757 L
.0963 .21749 L
.09622 .21742 L
.09614 .21734 L
.09606 .21727 L
.09598 .21719 L
.0959 .21712 L
.09581 .21704 L
.09573 .21696 L
.09565 .21689 L
.09557 .21681 L
.09549 .21674 L
.09541 .21666 L
.09533 .21659 L
.09525 .21651 L
.09517 .21644 L
.09509 .21636 L
.09501 .21629 L
Mistroke
.09493 .21621 L
.09485 .21614 L
.09477 .21606 L
.09469 .21599 L
.09461 .21591 L
.09453 .21584 L
.09445 .21576 L
.09437 .21569 L
.09429 .21561 L
.09421 .21554 L
.09413 .21546 L
.09405 .21539 L
.09397 .21531 L
.09389 .21524 L
.09381 .21516 L
.09373 .21509 L
.09365 .21501 L
.09357 .21494 L
.09349 .21486 L
.09341 .21479 L
.09333 .21471 L
.09325 .21464 L
.09317 .21456 L
.09309 .21449 L
.09301 .21441 L
.09293 .21434 L
.09285 .21426 L
.09278 .21419 L
.0927 .21411 L
.09262 .21404 L
.09254 .21396 L
.09246 .21389 L
.09238 .21382 L
.0923 .21374 L
.09222 .21367 L
.09214 .21359 L
.09206 .21352 L
.09199 .21344 L
.09191 .21337 L
.09183 .21329 L
.09175 .21322 L
.09167 .21315 L
.09159 .21307 L
.09151 .213 L
.09143 .21292 L
.09136 .21285 L
.09128 .21277 L
.0912 .2127 L
.09112 .21263 L
.09104 .21255 L
Mistroke
.09096 .21248 L
.09089 .2124 L
.09081 .21233 L
.09073 .21226 L
.09065 .21218 L
.09057 .21211 L
.0905 .21203 L
.09042 .21196 L
.09034 .21189 L
.09026 .21181 L
.09018 .21174 L
.09011 .21166 L
.09003 .21159 L
.08995 .21152 L
.08987 .21144 L
.0898 .21137 L
.08972 .21129 L
.08964 .21122 L
.08956 .21115 L
.08948 .21107 L
.08941 .211 L
.08933 .21093 L
.08925 .21085 L
.08917 .21078 L
.0891 .2107 L
.08902 .21063 L
.08894 .21056 L
.08887 .21048 L
.08879 .21041 L
.08871 .21034 L
.08863 .21026 L
.08856 .21019 L
.08848 .21012 L
.0884 .21004 L
.08833 .20997 L
.08825 .2099 L
.08817 .20982 L
.0881 .20975 L
.08802 .20968 L
.08794 .20961 L
.08787 .20953 L
.08779 .20946 L
.08771 .20939 L
.08764 .20931 L
.08756 .20924 L
.08748 .20917 L
.08741 .20909 L
.08733 .20902 L
.08725 .20895 L
.08718 .20887 L
Mistroke
.0871 .2088 L
.08702 .20873 L
.08695 .20866 L
.08687 .20858 L
.0868 .20851 L
.08672 .20844 L
.08664 .20837 L
.08657 .20829 L
.08649 .20822 L
.08642 .20815 L
.08634 .20807 L
.08626 .208 L
.08619 .20793 L
.08611 .20786 L
.08604 .20778 L
.08596 .20771 L
.08588 .20764 L
.08581 .20757 L
.08573 .20749 L
.08566 .20742 L
.08558 .20735 L
.08551 .20728 L
.08543 .2072 L
.08536 .20713 L
.08528 .20706 L
.08521 .20699 L
.08513 .20691 L
.08505 .20684 L
.08498 .20677 L
.0849 .2067 L
.08483 .20663 L
.08475 .20655 L
.08468 .20648 L
.0846 .20641 L
.08453 .20634 L
.08445 .20626 L
.08438 .20619 L
.0843 .20612 L
.08423 .20605 L
.08415 .20598 L
.08408 .2059 L
.084 .20583 L
.08393 .20576 L
.08386 .20569 L
.08378 .20562 L
.08371 .20554 L
.08363 .20547 L
.08356 .2054 L
.08348 .20533 L
.08341 .20526 L
Mistroke
.08333 .20518 L
.08326 .20511 L
.08318 .20504 L
.08311 .20497 L
.08304 .2049 L
.08296 .20482 L
.08289 .20475 L
.08281 .20468 L
.08274 .20461 L
.08267 .20454 L
.08259 .20447 L
.08252 .20439 L
.08244 .20432 L
.08237 .20425 L
.0823 .20418 L
.08222 .20411 L
.08215 .20403 L
.08207 .20396 L
.082 .20389 L
.08193 .20382 L
.08185 .20375 L
.08178 .20368 L
.08171 .2036 L
.08163 .20353 L
.08156 .20346 L
.08148 .20339 L
.08141 .20332 L
.08134 .20325 L
.08126 .20318 L
.08119 .2031 L
.08112 .20303 L
.08104 .20296 L
.08097 .20289 L
.0809 .20282 L
.08082 .20275 L
.08075 .20268 L
.08068 .2026 L
.08061 .20253 L
.08053 .20246 L
.08046 .20239 L
.08039 .20232 L
.08031 .20225 L
.08024 .20218 L
.08017 .20211 L
.0801 .20204 L
.08002 .20196 L
.07995 .20189 L
.07988 .20182 L
.0798 .20175 L
.07973 .20168 L
Mistroke
.07966 .20161 L
.07959 .20154 L
.07951 .20147 L
.07944 .2014 L
.07937 .20132 L
.0793 .20125 L
.07922 .20118 L
.07915 .20111 L
.07908 .20104 L
.07901 .20097 L
.07894 .2009 L
.07886 .20083 L
.07879 .20076 L
.07872 .20069 L
.07865 .20062 L
.07857 .20055 L
.0785 .20048 L
.07843 .2004 L
.07836 .20033 L
.07829 .20026 L
.07821 .20019 L
.07814 .20012 L
.07807 .20005 L
.078 .19998 L
.07793 .19991 L
.07786 .19984 L
.07778 .19977 L
.07771 .1997 L
.07764 .19963 L
.07757 .19956 L
.0775 .19949 L
.07743 .19942 L
.07735 .19935 L
.07728 .19928 L
.07721 .19921 L
.07714 .19914 L
.07707 .19907 L
.077 .199 L
.07693 .19893 L
.07686 .19886 L
.07678 .19879 L
.07671 .19872 L
.07664 .19865 L
.07657 .19858 L
.0765 .19851 L
.07643 .19844 L
.07636 .19837 L
.07629 .1983 L
.07622 .19823 L
.07615 .19816 L
Mistroke
.07607 .19809 L
.076 .19802 L
.07593 .19795 L
.07586 .19788 L
.07579 .19781 L
.07572 .19774 L
.07565 .19767 L
.07558 .1976 L
.07551 .19753 L
.07544 .19746 L
.07537 .19739 L
.0753 .19732 L
.07523 .19725 L
.07516 .19718 L
.07509 .19712 L
.07502 .19705 L
.07495 .19698 L
.07488 .19691 L
.07481 .19684 L
.07473 .19677 L
.07466 .1967 L
.07459 .19663 L
.07452 .19656 L
.07445 .19649 L
.07438 .19642 L
.07431 .19635 L
.07424 .19628 L
.07417 .19621 L
.0741 .19614 L
.07403 .19608 L
.07397 .19601 L
.0739 .19594 L
.07383 .19587 L
.07376 .1958 L
.07369 .19573 L
.07362 .19566 L
.07355 .19559 L
.07348 .19552 L
.07341 .19545 L
.07334 .19539 L
.07327 .19532 L
.0732 .19525 L
.07313 .19518 L
.07306 .19511 L
.07299 .19504 L
.07292 .19497 L
.07285 .1949 L
.07278 .19483 L
.07271 .19477 L
.07265 .1947 L
Mistroke
.07258 .19463 L
.07251 .19456 L
.07244 .19449 L
.07237 .19442 L
.0723 .19435 L
.07223 .19428 L
.07216 .19422 L
.07209 .19415 L
.07202 .19408 L
.07196 .19401 L
.07189 .19394 L
.07182 .19387 L
.07175 .1938 L
.07168 .19373 L
.07161 .19367 L
.07154 .1936 L
.07147 .19353 L
.07141 .19346 L
.07134 .19339 L
.07127 .19332 L
.0712 .19325 L
.07113 .19319 L
.07106 .19312 L
.07099 .19305 L
.07093 .19298 L
.07086 .19291 L
.07079 .19284 L
.07072 .19278 L
.07065 .19271 L
.07059 .19264 L
.07052 .19257 L
.07045 .1925 L
.07038 .19243 L
.07031 .19237 L
.07024 .1923 L
.07018 .19223 L
.07011 .19216 L
.07004 .19209 L
.06997 .19203 L
.06991 .19196 L
.06984 .19189 L
.06977 .19182 L
.0697 .19175 L
.06963 .19169 L
.06957 .19162 L
.0695 .19155 L
.06943 .19148 L
.06936 .19141 L
.0693 .19135 L
.06923 .19128 L
Mistroke
.06916 .19121 L
.06909 .19114 L
.06903 .19108 L
.06896 .19101 L
.06889 .19094 L
.06882 .19087 L
.06876 .1908 L
.06869 .19074 L
.06862 .19067 L
.06855 .1906 L
.06849 .19053 L
.06842 .19047 L
.06835 .1904 L
.06829 .19033 L
.06822 .19026 L
.06815 .1902 L
.06809 .19013 L
.06802 .19006 L
.06795 .18999 L
.06788 .18993 L
.06782 .18986 L
.06775 .18979 L
.06768 .18972 L
.06762 .18965 L
.06755 .18959 L
.06748 .18952 L
.06742 .18945 L
.06735 .18939 L
.06728 .18932 L
.06722 .18925 L
.06715 .18918 L
.06708 .18912 L
.06702 .18905 L
.06695 .18898 L
.06688 .18891 L
.06682 .18885 L
.06675 .18878 L
.06669 .18871 L
.06662 .18864 L
.06655 .18858 L
.06649 .18851 L
.06642 .18844 L
.06635 .18838 L
.06629 .18831 L
.06622 .18824 L
.06616 .18817 L
.06609 .18811 L
.06602 .18804 L
.06596 .18797 L
.06589 .18791 L
Mistroke
.06583 .18784 L
.06576 .18777 L
.06569 .1877 L
.06563 .18764 L
.06556 .18757 L
.0655 .1875 L
.06543 .18744 L
.06537 .18737 L
.0653 .1873 L
.06523 .18723 L
.06517 .18717 L
.0651 .1871 L
.06504 .18703 L
.06497 .18697 L
.06491 .1869 L
.06484 .18683 L
.06478 .18677 L
.06471 .1867 L
.06464 .18663 L
.06458 .18656 L
.06451 .1865 L
.06445 .18643 L
.06438 .18636 L
.06432 .1863 L
.06425 .18623 L
.06419 .18616 L
.06412 .1861 L
.06406 .18603 L
.06399 .18596 L
.06393 .1859 L
.06386 .18583 L
.0638 .18576 L
.06373 .1857 L
.06367 .18563 L
.0636 .18556 L
.06354 .1855 L
.06347 .18543 L
.06341 .18537 L
.06334 .1853 L
.06328 .18523 L
.06321 .18517 L
.06315 .1851 L
.06309 .18503 L
.06302 .18497 L
.06296 .1849 L
.06289 .18484 L
.06283 .18477 L
.06276 .1847 L
.0627 .18464 L
.06263 .18457 L
Mistroke
.06257 .1845 L
.0625 .18444 L
.06244 .18437 L
.06238 .18431 L
.06231 .18424 L
.06225 .18417 L
.06218 .18411 L
.06212 .18404 L
.06206 .18398 L
.06199 .18391 L
.06193 .18384 L
.06186 .18378 L
.0618 .18371 L
.06173 .18365 L
.06167 .18358 L
.06161 .18351 L
.06154 .18345 L
.06148 .18338 L
.06142 .18332 L
.06135 .18325 L
.06129 .18318 L
.06122 .18312 L
.06116 .18305 L
.0611 .18299 L
.06103 .18292 L
.06097 .18286 L
.06091 .18279 L
.06084 .18273 L
.06078 .18266 L
.06071 .18259 L
.06065 .18253 L
.06059 .18246 L
.06052 .1824 L
.06046 .18233 L
.0604 .18227 L
.06033 .1822 L
.06027 .18214 L
.06021 .18207 L
.06014 .18201 L
.06008 .18194 L
.06002 .18188 L
.05995 .18181 L
.05989 .18175 L
.05983 .18168 L
.05976 .18162 L
.0597 .18155 L
.05964 .18149 L
.05958 .18142 L
.05951 .18136 L
.05945 .18129 L
Mistroke
.05939 .18123 L
.05932 .18116 L
.05926 .1811 L
.0592 .18103 L
.05914 .18097 L
.05907 .18091 L
.05901 .18084 L
.05895 .18078 L
.05888 .18071 L
.05882 .18065 L
.05876 .18058 L
.0587 .18052 L
.05863 .18045 L
.05857 .18039 L
.05851 .18032 L
.05845 .18026 L
.05838 .18019 L
.05832 .18013 L
.05826 .18006 L
.0582 .18 L
.05813 .17993 L
.05807 .17987 L
.05801 .17981 L
.05795 .17974 L
.05789 .17968 L
.05782 .17961 L
.05776 .17955 L
.0577 .17948 L
.05764 .17942 L
.05757 .17936 L
.05751 .17929 L
.05745 .17923 L
.05739 .17916 L
.05733 .1791 L
.05726 .17903 L
.0572 .17897 L
.05714 .17891 L
.05708 .17884 L
.05702 .17878 L
.05696 .17871 L
.05689 .17865 L
.05683 .17859 L
.05677 .17852 L
.05671 .17846 L
.05665 .17839 L
.05658 .17833 L
.05652 .17827 L
.05646 .1782 L
.0564 .17814 L
.05634 .17808 L
Mistroke
.05628 .17801 L
.05622 .17795 L
.05615 .17789 L
.05609 .17782 L
.05603 .17776 L
.05597 .17769 L
.05591 .17763 L
.05585 .17757 L
.05579 .1775 L
.05572 .17744 L
.05566 .17738 L
.0556 .17731 L
.05554 .17725 L
.05548 .17719 L
.05542 .17712 L
.05536 .17706 L
.0553 .177 L
.05524 .17693 L
.05517 .17687 L
.05511 .17681 L
.05505 .17675 L
.05499 .17668 L
.05493 .17662 L
.05487 .17656 L
.05481 .17649 L
.05475 .17643 L
.05469 .17637 L
.05463 .1763 L
.05457 .17624 L
.05451 .17618 L
.05444 .17611 L
.05438 .17605 L
.05432 .17599 L
.05426 .17593 L
.0542 .17586 L
.05414 .1758 L
.05408 .17574 L
.05402 .17567 L
.05396 .17561 L
.0539 .17555 L
.05384 .17549 L
.05378 .17542 L
.05372 .17536 L
.05366 .1753 L
.0536 .17523 L
.05354 .17517 L
.05348 .17511 L
.05342 .17505 L
.05336 .17498 L
.0533 .17492 L
Mistroke
.05324 .17486 L
.05318 .1748 L
.05312 .17473 L
.05306 .17467 L
.053 .17461 L
.05294 .17455 L
.05288 .17448 L
.05282 .17442 L
.05276 .17436 L
.0527 .17429 L
.05264 .17423 L
.05258 .17417 L
.05252 .17411 L
.05246 .17404 L
.0524 .17398 L
.05234 .17392 L
.05228 .17386 L
.05222 .17379 L
.05216 .17373 L
.0521 .17367 L
.05204 .17361 L
.05198 .17354 L
.05192 .17348 L
.05186 .17342 L
.0518 .17336 L
.05174 .1733 L
.05168 .17323 L
.05162 .17317 L
.05156 .17311 L
.0515 .17305 L
.05145 .17298 L
.05139 .17292 L
.05133 .17286 L
.05127 .1728 L
.05121 .17273 L
.05115 .17267 L
.05109 .17261 L
.05103 .17255 L
.05097 .17249 L
.05091 .17242 L
.05085 .17236 L
.05079 .1723 L
.05074 .17224 L
.05068 .17218 L
.05062 .17211 L
.05056 .17205 L
.0505 .17199 L
.05044 .17193 L
.05038 .17187 L
.05032 .1718 L
Mistroke
.05026 .17174 L
.05021 .17168 L
.05015 .17162 L
.05009 .17156 L
.05003 .17149 L
.04997 .17143 L
.04991 .17137 L
.04985 .17131 L
.0498 .17125 L
.04974 .17118 L
.04968 .17112 L
.04962 .17106 L
.04956 .171 L
.0495 .17094 L
.04944 .17087 L
.04939 .17081 L
.04933 .17075 L
.04927 .17069 L
.04921 .17063 L
.04915 .17057 L
.04909 .1705 L
.04904 .17044 L
.04898 .17038 L
.04892 .17032 L
.04886 .17026 L
.0488 .1702 L
.04874 .17013 L
.04869 .17007 L
.04863 .17001 L
.04857 .16995 L
.04851 .16989 L
.04845 .16983 L
.0484 .16976 L
.04834 .1697 L
.04828 .16964 L
.04822 .16958 L
.04816 .16952 L
.04811 .16946 L
.04805 .1694 L
.04799 .16933 L
.04793 .16927 L
.04788 .16921 L
.04782 .16915 L
.04776 .16909 L
.0477 .16903 L
.04765 .16897 L
.04759 .1689 L
.04753 .16884 L
.04747 .16878 L
.04741 .16872 L
Mistroke
.04736 .16866 L
.0473 .1686 L
.04724 .16854 L
.04719 .16848 L
.04713 .16842 L
.04707 .16835 L
.04701 .16829 L
.04696 .16823 L
.0469 .16817 L
.04684 .16811 L
.04678 .16805 L
.04673 .16799 L
.04667 .16793 L
.04661 .16787 L
.04655 .1678 L
.0465 .16774 L
.04644 .16768 L
.04638 .16762 L
.04633 .16756 L
.04627 .1675 L
.04621 .16744 L
.04616 .16738 L
.0461 .16732 L
.04604 .16726 L
.04598 .16719 L
.04593 .16713 L
.04587 .16707 L
.04581 .16701 L
.04576 .16695 L
.0457 .16689 L
.04564 .16683 L
.04559 .16677 L
.04553 .16671 L
.04547 .16665 L
.04542 .16659 L
.04536 .16652 L
.0453 .16646 L
.04525 .1664 L
.04519 .16634 L
.04513 .16628 L
.04508 .16622 L
.04502 .16616 L
.04496 .1661 L
.04491 .16604 L
.04485 .16598 L
.0448 .16592 L
.04474 .16586 L
.04468 .16579 L
.04463 .16573 L
.04457 .16567 L
Mistroke
.04451 .16561 L
.04446 .16555 L
.0444 .16549 L
.04434 .16543 L
.04429 .16537 L
.04423 .16531 L
.04418 .16525 L
.04412 .16519 L
.04406 .16513 L
.04401 .16507 L
.04395 .16501 L
.0439 .16495 L
.04384 .16489 L
.04378 .16483 L
.04373 .16476 L
.04367 .1647 L
.04362 .16464 L
.04356 .16458 L
.0435 .16452 L
.04345 .16446 L
.04339 .1644 L
.04334 .16434 L
.04328 .16428 L
.04323 .16422 L
.04317 .16416 L
.04311 .1641 L
.04306 .16404 L
.043 .16398 L
.04295 .16392 L
.04289 .16386 L
.04284 .1638 L
.04278 .16374 L
.04273 .16368 L
.04267 .16362 L
.04261 .16356 L
.04256 .1635 L
.0425 .16344 L
.04245 .16338 L
.04239 .16332 L
.04234 .16326 L
.04228 .1632 L
.04223 .16314 L
.04217 .16308 L
.04212 .16302 L
.04206 .16296 L
.04201 .1629 L
.04195 .16284 L
.0419 .16278 L
.04184 .16272 L
.04179 .16266 L
Mistroke
.04173 .1626 L
.04168 .16254 L
.04162 .16248 L
.04157 .16242 L
.04151 .16236 L
.04146 .1623 L
.0414 .16224 L
.04135 .16218 L
.04129 .16212 L
.04124 .16206 L
.04118 .162 L
.04113 .16194 L
.04107 .16188 L
.04102 .16182 L
.04096 .16176 L
.04091 .1617 L
.04085 .16164 L
.0408 .16158 L
.04074 .16152 L
.04069 .16146 L
.04063 .1614 L
.04058 .16135 L
.04053 .16129 L
.04047 .16123 L
.04042 .16117 L
.04036 .16111 L
.04031 .16105 L
.04025 .16099 L
.0402 .16093 L
.04014 .16087 L
.04009 .16081 L
.04004 .16075 L
.03998 .16069 L
.03993 .16063 L
.03987 .16057 L
.03982 .16051 L
.03976 .16045 L
.03971 .16039 L
.03966 .16033 L
.0396 .16027 L
.03955 .16021 L
.03949 .16016 L
.03944 .1601 L
.03938 .16004 L
.03933 .15998 L
.03928 .15992 L
.03922 .15986 L
.03917 .1598 L
.03911 .15974 L
.03906 .15968 L
Mistroke
.03901 .15962 L
.03895 .15956 L
.0389 .1595 L
.03885 .15944 L
.03879 .15938 L
.03874 .15932 L
.03868 .15927 L
.03863 .15921 L
.03858 .15915 L
.03852 .15909 L
.03847 .15903 L
.03842 .15897 L
.03836 .15891 L
.03831 .15885 L
.03825 .15879 L
.0382 .15873 L
.03815 .15867 L
.03809 .15861 L
.03804 .15856 L
.03799 .1585 L
.03793 .15844 L
.03788 .15838 L
.03783 .15832 L
.03777 .15826 L
.03772 .1582 L
.03767 .15814 L
.03761 .15808 L
.03756 .15802 L
.03751 .15797 L
.03745 .15791 L
.0374 .15785 L
.03735 .15779 L
.03729 .15773 L
.03724 .15767 L
.03719 .15761 L
.03713 .15755 L
.03708 .15749 L
.03703 .15744 L
.03698 .15738 L
.03692 .15732 L
.03687 .15726 L
.03682 .1572 L
.03676 .15714 L
.03671 .15708 L
.03666 .15702 L
.0366 .15696 L
.03655 .15691 L
.0365 .15685 L
.03645 .15679 L
.03639 .15673 L
Mistroke
.03634 .15667 L
.03629 .15661 L
.03624 .15655 L
.03618 .1565 L
.03613 .15644 L
.03608 .15638 L
.03602 .15632 L
.03597 .15626 L
.03592 .1562 L
.03587 .15614 L
.03581 .15609 L
.03576 .15603 L
.03571 .15597 L
.03566 .15591 L
.0356 .15585 L
.03555 .15579 L
.0355 .15574 L
.03545 .15568 L
.03539 .15562 L
.03534 .15556 L
.03529 .1555 L
.03524 .15544 L
.03519 .15539 L
.03513 .15533 L
.03508 .15527 L
.03503 .15521 L
.03498 .15515 L
.03492 .15509 L
.03487 .15504 L
.03482 .15498 L
.03477 .15492 L
.03472 .15486 L
.03466 .1548 L
.03461 .15474 L
.03456 .15469 L
.03451 .15463 L
.03446 .15457 L
.0344 .15451 L
.03435 .15445 L
.0343 .1544 L
.03425 .15434 L
.0342 .15428 L
.03414 .15422 L
.03409 .15416 L
.03404 .15411 L
.03399 .15405 L
.03394 .15399 L
.03389 .15393 L
.03383 .15387 L
.03378 .15382 L
Mistroke
.03373 .15376 L
.03368 .1537 L
.03363 .15364 L
.03358 .15358 L
.03352 .15353 L
.03347 .15347 L
.03342 .15341 L
.03337 .15335 L
.03332 .1533 L
.03327 .15324 L
.03321 .15318 L
.03316 .15312 L
.03311 .15306 L
.03306 .15301 L
.03301 .15295 L
.03296 .15289 L
.03291 .15283 L
.03285 .15278 L
.0328 .15272 L
.03275 .15266 L
.0327 .1526 L
.03265 .15255 L
.0326 .15249 L
.03255 .15243 L
.0325 .15237 L
.03245 .15232 L
.03239 .15226 L
.03234 .1522 L
.03229 .15214 L
.03224 .15209 L
.03219 .15203 L
.03214 .15197 L
.03209 .15191 L
.03204 .15186 L
.03199 .1518 L
.03193 .15174 L
.03188 .15169 L
.03183 .15163 L
.03178 .15157 L
.03173 .15151 L
.03168 .15146 L
.03163 .1514 L
.03158 .15134 L
.03153 .15128 L
.03148 .15123 L
.03143 .15117 L
.03138 .15111 L
.03133 .15106 L
.03127 .151 L
.03122 .15094 L
Mistroke
.03117 .15088 L
.03112 .15083 L
.03107 .15077 L
.03102 .15071 L
.03097 .15065 L
.03092 .1506 L
.03087 .15054 L
.03082 .15048 L
.03077 .15043 L
.03072 .15037 L
.03067 .15031 L
.03062 .15025 L
.03057 .1502 L
.03052 .15014 L
.03047 .15008 L
.03042 .15003 L
.03037 .14997 L
.03032 .14991 L
.03027 .14985 L
.03022 .1498 L
.03017 .14974 L
.03012 .14968 L
.03006 .14963 L
.03001 .14957 L
.02996 .14951 L
.02991 .14945 L
.02986 .1494 L
.02981 .14934 L
.02976 .14928 L
.02971 .14923 L
.02966 .14917 L
.02961 .14911 L
.02956 .14906 L
.02951 .149 L
.02946 .14894 L
.02941 .14888 L
.02936 .14883 L
.02931 .14877 L
.02927 .14871 L
.02922 .14866 L
.02917 .1486 L
.02912 .14854 L
.02907 .14849 L
.02902 .14843 L
.02897 .14837 L
.02892 .14832 L
.02887 .14826 L
.02882 .1482 L
.02877 .14815 L
.02872 .14809 L
Mistroke
.02867 .14803 L
.02862 .14798 L
.02857 .14792 L
.02852 .14786 L
.02847 .14781 L
.02842 .14775 L
.02837 .14769 L
.02832 .14764 L
.02827 .14758 L
.02822 .14752 L
.02817 .14747 L
.02812 .14741 L
.02808 .14735 L
.02803 .1473 L
.02798 .14724 L
.02793 .14719 L
.02788 .14713 L
.02783 .14707 L
.02778 .14702 L
.02773 .14696 L
.02768 .1469 L
.02763 .14685 L
.02758 .14679 L
.02753 .14673 L
.02748 .14668 L
.02744 .14662 L
.02739 .14656 L
.02734 .14651 L
.02729 .14645 L
.02724 .14639 L
.02719 .14634 L
.02714 .14628 L
.02709 .14623 L
.02704 .14617 L
.02699 .14611 L
.02695 .14606 L
.0269 .146 L
.02685 .14594 L
.0268 .14589 L
.02675 .14583 L
.0267 .14577 L
.02665 .14572 L
.0266 .14566 L
.02656 .14561 L
.02651 .14555 L
.02646 .14549 L
.02641 .14544 L
.02636 .14538 L
.02631 .14532 L
.02626 .14527 L
Mistroke
.02621 .14521 L
.02617 .14516 L
.02612 .1451 L
.02607 .14504 L
.02602 .14499 L
.02597 .14493 L
.02592 .14487 L
.02587 .14482 L
.02583 .14476 L
.02578 .14471 L
.02573 .14465 L
.02568 .14459 L
.02563 .14454 L
.02558 .14448 L
.02554 .14443 L
.02549 .14437 L
.02544 .14431 L
.02539 .14426 L
.02534 .1442 L
.02529 .14415 L
.02525 .14409 L
.0252 .14403 L
.02515 .14398 L
.0251 .14392 L
.02505 .14387 L
.02501 .14381 L
.02496 .14376 L
.02491 .1437 L
.02486 .14364 L
.02481 .14359 L
.02477 .14353 L
.02472 .14348 L
.02467 .14342 L
.02462 .14336 L
.02457 .14331 L
.02453 .14325 L
.02448 .1432 L
.02443 .14314 L
.02438 .14309 L
.02433 .14303 L
.02429 .14297 L
.02424 .14292 L
.02419 .14286 L
.02414 .14281 L
.0241 .14275 L
.02405 .1427 L
.024 .14264 L
.02395 .14259 L
.0239 .14253 L
.02386 .14247 L
Mistroke
.02381 .14242 L
Mfstroke
[ ] 0 setdash
.97619 .25726 m
.975 .25713 L
.97381 .257 L
.97263 .25687 L
.97145 .25674 L
.97027 .25661 L
.96909 .25648 L
.96792 .25635 L
.96674 .25622 L
.96557 .25609 L
.9644 .25596 L
.96324 .25583 L
.96207 .25571 L
.96091 .25558 L
.95975 .25545 L
.9586 .25532 L
.95744 .25519 L
.95629 .25506 L
.95514 .25493 L
.95399 .25481 L
.95285 .25468 L
.9517 .25455 L
.95056 .25442 L
.94943 .2543 L
.94829 .25417 L
.94715 .25404 L
.94602 .25391 L
.94489 .25379 L
.94377 .25366 L
.94264 .25353 L
.94152 .2534 L
.9404 .25328 L
.93928 .25315 L
.93816 .25302 L
.93705 .25289 L
.93593 .25277 L
.93482 .25264 L
.93371 .25251 L
.93261 .25239 L
.9315 .25226 L
.9304 .25213 L
.9293 .25201 L
.92821 .25188 L
.92711 .25175 L
.92602 .25163 L
.92493 .2515 L
.92384 .25137 L
.92275 .25125 L
.92166 .25112 L
.92058 .25099 L
Mistroke
.9195 .25087 L
.91842 .25074 L
.91735 .25062 L
.91627 .25049 L
.9152 .25036 L
.91413 .25024 L
.91306 .25011 L
.91199 .24999 L
.91093 .24986 L
.90987 .24974 L
.90881 .24961 L
.90775 .24949 L
.90669 .24936 L
.90564 .24923 L
.90458 .24911 L
.90353 .24899 L
.90248 .24886 L
.90144 .24874 L
.90039 .24861 L
.89935 .24849 L
.89831 .24836 L
.89727 .24824 L
.89623 .24812 L
.8952 .24799 L
.89417 .24787 L
.89313 .24774 L
.8921 .24762 L
.89108 .2475 L
.89005 .24737 L
.88903 .24725 L
.88801 .24713 L
.88699 .247 L
.88597 .24688 L
.88495 .24676 L
.88394 .24664 L
.88293 .24651 L
.88192 .24639 L
.88091 .24627 L
.8799 .24615 L
.8789 .24602 L
.87789 .2459 L
.87689 .24578 L
.87589 .24566 L
.8749 .24554 L
.8739 .24542 L
.87291 .24529 L
.87192 .24517 L
.87093 .24505 L
.86994 .24493 L
.86895 .24481 L
Mistroke
.86797 .24469 L
.86698 .24457 L
.866 .24445 L
.86502 .24432 L
.86404 .2442 L
.86307 .24408 L
.86209 .24396 L
.86112 .24384 L
.86015 .24372 L
.85918 .2436 L
.85822 .24348 L
.85725 .24336 L
.85629 .24324 L
.85532 .24312 L
.85436 .243 L
.85341 .24288 L
.85245 .24276 L
.85149 .24264 L
.85054 .24252 L
.84959 .2424 L
.84864 .24228 L
.84769 .24216 L
.84674 .24204 L
.8458 .24192 L
.84486 .2418 L
.84392 .24168 L
.84298 .24156 L
.84204 .24144 L
.8411 .24132 L
.84017 .2412 L
.83923 .24108 L
.8383 .24097 L
.83737 .24085 L
.83644 .24073 L
.83552 .24061 L
.83459 .24049 L
.83367 .24037 L
.83275 .24026 L
.83183 .24014 L
.83091 .24002 L
.82999 .2399 L
.82908 .23979 L
.82816 .23967 L
.82725 .23955 L
.82634 .23943 L
.82543 .23932 L
.82452 .2392 L
.82362 .23908 L
.82271 .23897 L
.82181 .23885 L
Mistroke
.82091 .23873 L
.82001 .23861 L
.81911 .2385 L
.81822 .23838 L
.81732 .23826 L
.81643 .23815 L
.81554 .23803 L
.81465 .23792 L
.81376 .2378 L
.81287 .23768 L
.81199 .23757 L
.8111 .23745 L
.81022 .23734 L
.80934 .23722 L
.80846 .23711 L
.80758 .23699 L
.80671 .23687 L
.80583 .23676 L
.80496 .23664 L
.80409 .23653 L
.80322 .23641 L
.80235 .2363 L
.80148 .23618 L
.80061 .23607 L
.79975 .23595 L
.79889 .23584 L
.79802 .23572 L
.79716 .23561 L
.79631 .2355 L
.79545 .23538 L
.79459 .23527 L
.79374 .23515 L
.79289 .23504 L
.79203 .23493 L
.79118 .23481 L
.79034 .2347 L
.78949 .23458 L
.78864 .23447 L
.7878 .23436 L
.78696 .23424 L
.78611 .23413 L
.78527 .23402 L
.78444 .2339 L
.7836 .23379 L
.78276 .23367 L
.78193 .23356 L
.7811 .23345 L
.78026 .23334 L
.77943 .23322 L
.77861 .23311 L
Mistroke
.77778 .233 L
.77695 .23288 L
.77613 .23277 L
.7753 .23266 L
.77448 .23254 L
.77366 .23243 L
.77284 .23232 L
.77202 .23221 L
.77121 .23209 L
.77039 .23198 L
.76958 .23187 L
.76877 .23176 L
.76796 .23164 L
.76715 .23153 L
.76634 .23142 L
.76553 .23131 L
.76472 .23119 L
.76392 .23108 L
.76312 .23097 L
.76231 .23086 L
.76151 .23075 L
.76072 .23063 L
.75992 .23052 L
.75912 .23041 L
.75833 .2303 L
.75753 .23019 L
.75674 .23008 L
.75595 .22997 L
.75516 .22985 L
.75437 .22974 L
.75358 .22963 L
.75279 .22952 L
.75201 .22941 L
.75123 .2293 L
.75044 .22919 L
.74966 .22908 L
.74888 .22897 L
.7481 .22886 L
.74733 .22874 L
.74655 .22863 L
.74578 .22852 L
.745 .22841 L
.74423 .2283 L
.74346 .22819 L
.74269 .22808 L
.74192 .22797 L
.74115 .22786 L
.74039 .22775 L
.73962 .22764 L
.73886 .22753 L
Mistroke
.7381 .22742 L
.73733 .22731 L
.73657 .2272 L
.73581 .22709 L
.73506 .22698 L
.7343 .22687 L
.73355 .22676 L
.73279 .22665 L
.73204 .22654 L
.73129 .22643 L
.73054 .22633 L
.72979 .22622 L
.72904 .22611 L
.72829 .226 L
.72755 .22589 L
.7268 .22578 L
.72606 .22567 L
.72532 .22557 L
.72458 .22546 L
.72384 .22535 L
.7231 .22524 L
.72236 .22513 L
.72162 .22502 L
.72089 .22492 L
.72015 .22481 L
.71942 .2247 L
.71869 .22459 L
.71796 .22448 L
.71723 .22438 L
.7165 .22427 L
.71577 .22416 L
.71505 .22405 L
.71432 .22395 L
.7136 .22384 L
.71288 .22373 L
.71215 .22363 L
.71143 .22352 L
.71072 .22341 L
.71 .22331 L
.70928 .2232 L
.70856 .22309 L
.70785 .22299 L
.70714 .22288 L
.70642 .22277 L
.70571 .22267 L
.705 .22256 L
.70429 .22246 L
.70358 .22235 L
.70288 .22224 L
.70217 .22214 L
Mistroke
.70147 .22203 L
.70076 .22193 L
.70006 .22182 L
.69936 .22172 L
.69866 .22161 L
.69796 .22151 L
.69726 .2214 L
.69656 .22129 L
.69586 .22119 L
.69517 .22108 L
.69447 .22098 L
.69378 .22087 L
.69309 .22077 L
.6924 .22066 L
.69171 .22056 L
.69102 .22045 L
.69033 .22035 L
.68964 .22024 L
.68896 .22014 L
.68827 .22003 L
.68759 .21993 L
.68691 .21982 L
.68623 .21972 L
.68555 .21961 L
.68487 .21951 L
.68419 .21941 L
.68351 .2193 L
.68283 .2192 L
.68216 .21909 L
.68148 .21899 L
.68081 .21888 L
.68014 .21878 L
.67947 .21867 L
.67879 .21857 L
.67813 .21847 L
.67746 .21836 L
.67679 .21826 L
.67612 .21815 L
.67546 .21805 L
.67479 .21795 L
.67413 .21784 L
.67347 .21774 L
.67281 .21764 L
.67214 .21753 L
.67149 .21743 L
.67083 .21732 L
.67017 .21722 L
.66951 .21712 L
.66886 .21701 L
.6682 .21691 L
Mistroke
.66755 .21681 L
.6669 .21671 L
.66624 .2166 L
.66559 .2165 L
.66494 .2164 L
.66429 .2163 L
.66365 .21619 L
.663 .21609 L
.66235 .21599 L
.66171 .21589 L
.66106 .21578 L
.66042 .21568 L
.65978 .21558 L
.65914 .21548 L
.6585 .21538 L
.65786 .21527 L
.65722 .21517 L
.65658 .21507 L
.65595 .21497 L
.65531 .21487 L
.65468 .21476 L
.65404 .21466 L
.65341 .21456 L
.65278 .21446 L
.65215 .21436 L
.65152 .21425 L
.65089 .21415 L
.65026 .21405 L
.64963 .21395 L
.649 .21385 L
.64838 .21374 L
.64775 .21364 L
.64713 .21354 L
.64651 .21344 L
.64588 .21334 L
.64526 .21324 L
.64464 .21313 L
.64402 .21303 L
.64341 .21293 L
.64279 .21283 L
.64217 .21273 L
.64156 .21263 L
.64094 .21253 L
.64033 .21243 L
.63971 .21233 L
.6391 .21223 L
.63849 .21213 L
.63788 .21202 L
.63727 .21192 L
.63666 .21182 L
Mistroke
.63605 .21172 L
.63545 .21162 L
.63484 .21152 L
.63424 .21142 L
.63363 .21132 L
.63303 .21122 L
.63243 .21112 L
.63182 .21102 L
.63122 .21092 L
.63062 .21082 L
.63002 .21072 L
.62943 .21062 L
.62883 .21052 L
.62823 .21042 L
.62764 .21032 L
.62704 .21022 L
.62645 .21012 L
.62585 .21002 L
.62526 .20992 L
.62467 .20982 L
.62408 .20972 L
.62349 .20962 L
.6229 .20953 L
.62231 .20943 L
.62172 .20933 L
.62114 .20923 L
.62055 .20913 L
.61997 .20903 L
.61938 .20893 L
.6188 .20883 L
.61822 .20874 L
.61763 .20864 L
.61705 .20854 L
.61647 .20844 L
.61589 .20834 L
.61531 .20824 L
.61474 .20815 L
.61416 .20805 L
.61358 .20795 L
.61301 .20785 L
.61243 .20775 L
.61186 .20766 L
.61129 .20756 L
.61072 .20746 L
.61014 .20736 L
.60957 .20726 L
.609 .20717 L
.60843 .20707 L
.60787 .20697 L
.6073 .20688 L
Mistroke
.60673 .20678 L
.60617 .20668 L
.6056 .20658 L
.60504 .20649 L
.60447 .20639 L
.60391 .20629 L
.60335 .2062 L
.60279 .2061 L
.60223 .206 L
.60167 .20591 L
.60111 .20581 L
.60055 .20571 L
.59999 .20562 L
.59944 .20552 L
.59888 .20542 L
.59833 .20533 L
.59777 .20523 L
.59722 .20513 L
.59667 .20504 L
.59611 .20494 L
.59556 .20485 L
.59501 .20475 L
.59446 .20465 L
.59391 .20456 L
.59336 .20446 L
.59282 .20437 L
.59227 .20427 L
.59172 .20417 L
.59118 .20408 L
.59063 .20398 L
.59009 .20388 L
.58955 .20379 L
.589 .20369 L
.58846 .2036 L
.58792 .2035 L
.58738 .20341 L
.58684 .20331 L
.5863 .20321 L
.58577 .20312 L
.58523 .20302 L
.58469 .20293 L
.58416 .20283 L
.58362 .20274 L
.58309 .20264 L
.58255 .20255 L
.58202 .20245 L
.58149 .20236 L
.58096 .20226 L
.58042 .20216 L
.57989 .20207 L
Mistroke
.57937 .20197 L
.57884 .20188 L
.57831 .20178 L
.57778 .20169 L
.57725 .20159 L
.57673 .2015 L
.5762 .2014 L
.57568 .20131 L
.57515 .20122 L
.57463 .20112 L
.57411 .20103 L
.57359 .20093 L
.57307 .20084 L
.57255 .20074 L
.57203 .20065 L
.57151 .20055 L
.57099 .20046 L
.57047 .20037 L
.56995 .20027 L
.56944 .20018 L
.56892 .20008 L
.56841 .19999 L
.56789 .1999 L
.56738 .1998 L
.56687 .19971 L
.56635 .19961 L
.56584 .19952 L
.56533 .19943 L
.56482 .19933 L
.56431 .19924 L
.5638 .19915 L
.5633 .19905 L
.56279 .19896 L
.56228 .19887 L
.56177 .19877 L
.56127 .19868 L
.56076 .19859 L
.56026 .19849 L
.55976 .1984 L
.55925 .19831 L
.55875 .19821 L
.55825 .19812 L
.55775 .19803 L
.55725 .19794 L
.55675 .19784 L
.55625 .19775 L
.55575 .19766 L
.55525 .19757 L
.55476 .19747 L
.55426 .19738 L
Mistroke
.55376 .19729 L
.55327 .1972 L
.55277 .1971 L
.55228 .19701 L
.55179 .19692 L
.55129 .19683 L
.5508 .19673 L
.55031 .19664 L
.54982 .19655 L
.54933 .19646 L
.54884 .19637 L
.54835 .19627 L
.54786 .19618 L
.54738 .19609 L
.54689 .196 L
.5464 .19591 L
.54592 .19582 L
.54543 .19573 L
.54495 .19563 L
.54446 .19554 L
.54398 .19545 L
.5435 .19536 L
.54301 .19527 L
.54253 .19518 L
.54205 .19508 L
.54157 .19499 L
.54109 .1949 L
.54061 .19481 L
.54014 .19472 L
.53966 .19463 L
.53918 .19454 L
.5387 .19445 L
.53823 .19435 L
.53775 .19426 L
.53728 .19417 L
.5368 .19408 L
.53633 .19399 L
.53586 .1939 L
.53538 .19381 L
.53491 .19372 L
.53444 .19363 L
.53397 .19354 L
.5335 .19345 L
.53303 .19336 L
.53256 .19326 L
.53209 .19317 L
.53163 .19308 L
.53116 .19299 L
.53069 .1929 L
.53023 .19281 L
Mistroke
.52976 .19272 L
.5293 .19263 L
.52883 .19254 L
.52837 .19245 L
.52791 .19236 L
.52744 .19227 L
.52698 .19218 L
.52652 .1921 L
.52606 .19201 L
.5256 .19192 L
.52514 .19183 L
.52468 .19174 L
.52422 .19165 L
.52377 .19156 L
.52331 .19147 L
.52285 .19138 L
.5224 .19129 L
.52194 .19121 L
.52148 .19112 L
.52103 .19103 L
.52058 .19094 L
.52012 .19085 L
.51967 .19076 L
.51922 .19067 L
.51877 .19059 L
.51832 .1905 L
.51786 .19041 L
.51741 .19032 L
.51697 .19023 L
.51652 .19014 L
.51607 .19006 L
.51562 .18997 L
.51517 .18988 L
.51473 .18979 L
.51428 .1897 L
.51383 .18962 L
.51339 .18953 L
.51294 .18944 L
.5125 .18935 L
.51206 .18927 L
.51161 .18918 L
.51117 .18909 L
.51073 .18901 L
.51029 .18892 L
.50985 .18883 L
.50941 .18874 L
.50897 .18866 L
.50853 .18857 L
.50809 .18848 L
.50765 .1884 L
Mistroke
.50722 .18831 L
.50678 .18822 L
.50634 .18814 L
.50591 .18805 L
.50547 .18796 L
.50504 .18788 L
.5046 .18779 L
.50417 .18771 L
.50373 .18762 L
.5033 .18753 L
.50287 .18745 L
.50244 .18736 L
.50201 .18727 L
.50157 .18719 L
.50114 .1871 L
.50072 .18701 L
.50029 .18693 L
.49986 .18684 L
.49943 .18676 L
.499 .18667 L
.49857 .18658 L
.49815 .1865 L
.49772 .18641 L
.4973 .18633 L
.49687 .18624 L
.49645 .18615 L
.49602 .18607 L
.4956 .18598 L
.49518 .1859 L
.49475 .18581 L
.49433 .18573 L
.49391 .18564 L
.49349 .18555 L
.49307 .18547 L
.49265 .18538 L
.49223 .1853 L
.49181 .18521 L
.49139 .18513 L
.49097 .18504 L
.49056 .18496 L
.49014 .18487 L
.48972 .18478 L
.48931 .1847 L
.48889 .18461 L
.48847 .18453 L
.48806 .18444 L
.48765 .18436 L
.48723 .18427 L
.48682 .18419 L
.48641 .1841 L
Mistroke
.48599 .18402 L
.48558 .18393 L
.48517 .18385 L
.48476 .18376 L
.48435 .18368 L
.48394 .18359 L
.48353 .18351 L
.48312 .18342 L
.48271 .18334 L
.48231 .18325 L
.4819 .18317 L
.48149 .18308 L
.48109 .183 L
.48068 .18291 L
.48027 .18283 L
.47987 .18274 L
.47946 .18266 L
.47906 .18258 L
.47866 .18249 L
.47825 .18241 L
.47785 .18232 L
.47745 .18224 L
.47705 .18215 L
.47665 .18207 L
.47625 .18198 L
.47585 .1819 L
.47545 .18182 L
.47505 .18173 L
.47465 .18165 L
.47425 .18156 L
.47385 .18148 L
.47345 .18139 L
.47306 .18131 L
.47266 .18123 L
.47226 .18114 L
.47187 .18106 L
.47147 .18097 L
.47108 .18089 L
.47068 .18081 L
.47029 .18072 L
.4699 .18064 L
.4695 .18055 L
.46911 .18047 L
.46872 .18039 L
.46833 .1803 L
.46794 .18022 L
.46754 .18014 L
.46715 .18005 L
.46676 .17997 L
.46638 .17989 L
Mistroke
.46599 .1798 L
.4656 .17972 L
.46521 .17964 L
.46482 .17955 L
.46444 .17947 L
.46405 .17939 L
.46366 .1793 L
.46328 .17922 L
.46289 .17914 L
.46251 .17905 L
.46212 .17897 L
.46174 .17889 L
.46135 .17881 L
.46097 .17872 L
.46059 .17864 L
.46021 .17856 L
.45982 .17847 L
.45944 .17839 L
.45906 .17831 L
.45868 .17823 L
.4583 .17814 L
.45792 .17806 L
.45754 .17798 L
.45716 .1779 L
.45678 .17781 L
.45641 .17773 L
.45603 .17765 L
.45565 .17757 L
.45527 .17749 L
.4549 .1774 L
.45452 .17732 L
.45415 .17724 L
.45377 .17716 L
.4534 .17708 L
.45302 .17699 L
.45265 .17691 L
.45227 .17683 L
.4519 .17675 L
.45153 .17667 L
.45116 .17659 L
.45078 .1765 L
.45041 .17642 L
.45004 .17634 L
.44967 .17626 L
.4493 .17618 L
.44893 .1761 L
.44856 .17602 L
.44819 .17593 L
.44783 .17585 L
.44746 .17577 L
Mistroke
.44709 .17569 L
.44672 .17561 L
.44636 .17553 L
.44599 .17545 L
.44562 .17537 L
.44526 .17528 L
.44489 .1752 L
.44453 .17512 L
.44416 .17504 L
.4438 .17496 L
.44344 .17488 L
.44307 .1748 L
.44271 .17472 L
.44235 .17464 L
.44199 .17456 L
.44162 .17448 L
.44126 .17439 L
.4409 .17431 L
.44054 .17423 L
.44018 .17415 L
.43982 .17407 L
.43946 .17399 L
.4391 .17391 L
.43875 .17383 L
.43839 .17375 L
.43803 .17367 L
.43767 .17359 L
.43732 .17351 L
.43696 .17343 L
.4366 .17335 L
.43625 .17327 L
.43589 .17319 L
.43554 .17311 L
.43518 .17303 L
.43483 .17295 L
.43448 .17287 L
.43412 .17279 L
.43377 .17271 L
.43342 .17263 L
.43306 .17255 L
.43271 .17247 L
.43236 .17239 L
.43201 .17231 L
.43166 .17223 L
.43131 .17216 L
.43096 .17208 L
.43061 .172 L
.43026 .17192 L
.42991 .17184 L
.42956 .17176 L
Mistroke
.42921 .17168 L
.42887 .1716 L
.42852 .17152 L
.42817 .17144 L
.42783 .17136 L
.42748 .17128 L
.42713 .1712 L
.42679 .17113 L
.42644 .17105 L
.4261 .17097 L
.42576 .17089 L
.42541 .17081 L
.42507 .17073 L
.42472 .17065 L
.42438 .17057 L
.42404 .17049 L
.4237 .17042 L
.42336 .17034 L
.42301 .17026 L
.42267 .17018 L
.42233 .1701 L
.42199 .17002 L
.42165 .16994 L
.42131 .16987 L
.42097 .16979 L
.42063 .16971 L
.4203 .16963 L
.41996 .16955 L
.41962 .16947 L
.41928 .1694 L
.41895 .16932 L
.41861 .16924 L
.41827 .16916 L
.41794 .16908 L
.4176 .169 L
.41727 .16893 L
.41693 .16885 L
.4166 .16877 L
.41626 .16869 L
.41593 .16861 L
.4156 .16854 L
.41526 .16846 L
.41493 .16838 L
.4146 .1683 L
.41427 .16822 L
.41393 .16815 L
.4136 .16807 L
.41327 .16799 L
.41294 .16791 L
.41261 .16784 L
Mistroke
.41228 .16776 L
.41195 .16768 L
.41162 .1676 L
.41129 .16753 L
.41096 .16745 L
.41064 .16737 L
.41031 .16729 L
.40998 .16722 L
.40965 .16714 L
.40933 .16706 L
.409 .16698 L
.40867 .16691 L
.40835 .16683 L
.40802 .16675 L
.4077 .16667 L
.40737 .1666 L
.40705 .16652 L
.40672 .16644 L
.4064 .16637 L
.40608 .16629 L
.40575 .16621 L
.40543 .16613 L
.40511 .16606 L
.40479 .16598 L
.40446 .1659 L
.40414 .16583 L
.40382 .16575 L
.4035 .16567 L
.40318 .1656 L
.40286 .16552 L
.40254 .16544 L
.40222 .16537 L
.4019 .16529 L
.40158 .16521 L
.40127 .16514 L
.40095 .16506 L
.40063 .16498 L
.40031 .16491 L
.4 .16483 L
.39968 .16475 L
.39936 .16468 L
.39905 .1646 L
.39873 .16452 L
.39841 .16445 L
.3981 .16437 L
.39778 .1643 L
.39747 .16422 L
.39716 .16414 L
.39684 .16407 L
.39653 .16399 L
Mistroke
.39621 .16392 L
.3959 .16384 L
.39559 .16376 L
.39528 .16369 L
.39497 .16361 L
.39465 .16354 L
.39434 .16346 L
.39403 .16338 L
.39372 .16331 L
.39341 .16323 L
.3931 .16316 L
.39279 .16308 L
.39248 .163 L
.39217 .16293 L
.39186 .16285 L
.39155 .16278 L
.39125 .1627 L
.39094 .16263 L
.39063 .16255 L
.39032 .16248 L
.39002 .1624 L
.38971 .16232 L
.3894 .16225 L
.3891 .16217 L
.38879 .1621 L
.38849 .16202 L
.38818 .16195 L
.38788 .16187 L
.38757 .1618 L
.38727 .16172 L
.38696 .16165 L
.38666 .16157 L
.38636 .1615 L
.38606 .16142 L
.38575 .16135 L
.38545 .16127 L
.38515 .1612 L
.38485 .16112 L
.38455 .16105 L
.38424 .16097 L
.38394 .1609 L
.38364 .16082 L
.38334 .16075 L
.38304 .16067 L
.38274 .1606 L
.38244 .16052 L
.38215 .16045 L
.38185 .16037 L
.38155 .1603 L
.38125 .16022 L
Mistroke
.38095 .16015 L
.38065 .16007 L
.38036 .16 L
.38006 .15993 L
.37976 .15985 L
.37947 .15978 L
.37917 .1597 L
.37888 .15963 L
.37858 .15955 L
.37829 .15948 L
.37799 .1594 L
.3777 .15933 L
.3774 .15925 L
.37711 .15918 L
.37681 .15911 L
.37652 .15903 L
.37623 .15896 L
.37594 .15888 L
.37564 .15881 L
.37535 .15873 L
.37506 .15866 L
.37477 .15859 L
.37448 .15851 L
.37418 .15844 L
.37389 .15836 L
.3736 .15829 L
.37331 .15822 L
.37302 .15814 L
.37273 .15807 L
.37244 .15799 L
.37216 .15792 L
.37187 .15785 L
.37158 .15777 L
.37129 .1577 L
.371 .15762 L
.37071 .15755 L
.37043 .15748 L
.37014 .1574 L
.36985 .15733 L
.36957 .15726 L
.36928 .15718 L
.369 .15711 L
.36871 .15704 L
.36842 .15696 L
.36814 .15689 L
.36785 .15682 L
.36757 .15675 L
.36729 .15667 L
.367 .1566 L
.36672 .15653 L
Mistroke
.36643 .15645 L
.36615 .15638 L
.36587 .15631 L
.36559 .15623 L
.3653 .15616 L
.36502 .15609 L
.36474 .15602 L
.36446 .15594 L
.36418 .15587 L
.3639 .1558 L
.36362 .15573 L
.36333 .15565 L
.36305 .15558 L
.36277 .15551 L
.3625 .15543 L
.36222 .15536 L
.36194 .15529 L
.36166 .15522 L
.36138 .15514 L
.3611 .15507 L
.36082 .155 L
.36055 .15493 L
.36027 .15485 L
.35999 .15478 L
.35971 .15471 L
.35944 .15464 L
.35916 .15457 L
.35889 .15449 L
.35861 .15442 L
.35833 .15435 L
.35806 .15428 L
.35778 .1542 L
.35751 .15413 L
.35723 .15406 L
.35696 .15399 L
.35669 .15392 L
.35641 .15384 L
.35614 .15377 L
.35587 .1537 L
.35559 .15363 L
.35532 .15356 L
.35505 .15348 L
.35478 .15341 L
.3545 .15334 L
.35423 .15327 L
.35396 .1532 L
.35369 .15313 L
.35342 .15305 L
.35315 .15298 L
.35288 .15291 L
Mistroke
.35261 .15284 L
.35234 .15277 L
.35207 .1527 L
.3518 .15262 L
.35153 .15255 L
.35126 .15248 L
.35099 .15241 L
.35072 .15234 L
.35046 .15227 L
.35019 .15219 L
.34992 .15212 L
.34965 .15205 L
.34939 .15198 L
.34912 .15191 L
.34885 .15184 L
.34859 .15177 L
.34832 .15169 L
.34806 .15162 L
.34779 .15155 L
.34752 .15148 L
.34726 .15141 L
.34699 .15134 L
.34673 .15127 L
.34647 .1512 L
.3462 .15112 L
.34594 .15105 L
.34567 .15098 L
.34541 .15091 L
.34515 .15084 L
.34489 .15077 L
.34462 .1507 L
.34436 .15063 L
.3441 .15056 L
.34384 .15049 L
.34358 .15041 L
.34331 .15034 L
.34305 .15027 L
.34279 .1502 L
.34253 .15013 L
.34227 .15006 L
.34201 .14999 L
.34175 .14992 L
.34149 .14985 L
.34123 .14978 L
.34097 .14971 L
.34071 .14964 L
.34046 .14957 L
.3402 .14949 L
.33994 .14942 L
.33968 .14935 L
Mistroke
.33942 .14928 L
.33917 .14921 L
.33891 .14914 L
.33865 .14907 L
.3384 .149 L
.33814 .14893 L
.33788 .14886 L
.33763 .14879 L
.33737 .14872 L
.33712 .14865 L
.33686 .14858 L
.33661 .14851 L
.33635 .14844 L
.3361 .14837 L
.33584 .1483 L
.33559 .14823 L
.33533 .14816 L
.33508 .14809 L
.33483 .14802 L
.33457 .14795 L
.33432 .14788 L
.33407 .14781 L
.33382 .14774 L
.33356 .14767 L
.33331 .1476 L
.33306 .14753 L
.33281 .14746 L
.33256 .14739 L
.33231 .14732 L
.33205 .14725 L
.3318 .14718 L
.33155 .14711 L
.3313 .14704 L
.33105 .14697 L
.3308 .1469 L
.33055 .14683 L
.33031 .14676 L
.33006 .14669 L
.32981 .14663 L
.32956 .14656 L
.32931 .14649 L
.32906 .14642 L
.32881 .14635 L
.32857 .14628 L
.32832 .14621 L
.32807 .14614 L
.32783 .14607 L
.32758 .146 L
.32733 .14593 L
.32709 .14586 L
Mistroke
.32684 .14579 L
.32659 .14572 L
.32635 .14566 L
.3261 .14559 L
.32586 .14552 L
.32561 .14545 L
.32537 .14538 L
.32512 .14531 L
.32488 .14524 L
.32464 .14517 L
.32439 .1451 L
.32415 .14504 L
.3239 .14497 L
.32366 .1449 L
.32342 .14483 L
.32318 .14476 L
.32293 .14469 L
.32269 .14462 L
.32245 .14455 L
.32221 .14449 L
.32196 .14442 L
.32172 .14435 L
.32148 .14428 L
.32124 .14421 L
.321 .14414 L
.32076 .14407 L
.32052 .14401 L
.32028 .14394 L
.32004 .14387 L
.3198 .1438 L
.31956 .14373 L
.31932 .14366 L
.31908 .1436 L
.31884 .14353 L
.3186 .14346 L
.31837 .14339 L
.31813 .14332 L
.31789 .14325 L
.31765 .14319 L
.31741 .14312 L
.31718 .14305 L
.31694 .14298 L
.3167 .14291 L
.31647 .14285 L
.31623 .14278 L
.31599 .14271 L
.31576 .14264 L
.31552 .14257 L
.31529 .14251 L
.31505 .14244 L
Mistroke
.31481 .14237 L
.31458 .1423 L
.31434 .14223 L
.31411 .14217 L
.31388 .1421 L
.31364 .14203 L
.31341 .14196 L
.31317 .14189 L
.31294 .14183 L
.31271 .14176 L
.31247 .14169 L
.31224 .14162 L
.31201 .14156 L
.31178 .14149 L
.31154 .14142 L
.31131 .14135 L
.31108 .14129 L
.31085 .14122 L
.31062 .14115 L
.31038 .14108 L
.31015 .14102 L
.30992 .14095 L
.30969 .14088 L
.30946 .14082 L
.30923 .14075 L
.309 .14068 L
.30877 .14062 L
.30854 .14055 L
.30831 .14048 L
.30808 .14041 L
.30785 .14035 L
.30762 .14028 L
.3074 .14021 L
.30717 .14015 L
.30694 .14008 L
.30671 .14001 L
.30648 .13995 L
.30625 .13988 L
.30603 .13981 L
.3058 .13975 L
.30557 .13968 L
.30535 .13962 L
.30512 .13955 L
.30489 .13948 L
.30467 .13942 L
.30444 .13935 L
.30421 .13928 L
.30399 .13922 L
.30376 .13915 L
.30354 .13909 L
Mistroke
.30331 .13902 L
.30309 .13895 L
.30286 .13889 L
.30264 .13882 L
.30241 .13876 L
.30219 .13869 L
.30197 .13862 L
.30174 .13856 L
.30152 .13849 L
.3013 .13843 L
.30107 .13836 L
.30085 .13829 L
.30063 .13823 L
.3004 .13816 L
.30018 .1381 L
.29996 .13803 L
.29974 .13796 L
.29951 .1379 L
.29929 .13783 L
.29907 .13777 L
.29885 .1377 L
.29863 .13764 L
.29841 .13757 L
.29819 .13751 L
.29797 .13744 L
.29775 .13737 L
.29753 .13731 L
.29731 .13724 L
.29709 .13718 L
.29687 .13711 L
.29665 .13705 L
.29643 .13698 L
.29621 .13692 L
.29599 .13685 L
.29577 .13679 L
.29555 .13672 L
.29534 .13666 L
.29512 .13659 L
.2949 .13652 L
.29468 .13646 L
.29446 .13639 L
.29425 .13633 L
.29403 .13626 L
.29381 .1362 L
.2936 .13613 L
.29338 .13607 L
.29316 .136 L
.29295 .13594 L
.29273 .13587 L
.29252 .13581 L
Mistroke
.2923 .13574 L
.29208 .13568 L
.29187 .13561 L
.29165 .13555 L
.29144 .13548 L
.29122 .13542 L
.29101 .13535 L
.2908 .13529 L
.29058 .13523 L
.29037 .13516 L
.29015 .1351 L
.28994 .13503 L
.28973 .13497 L
.28951 .1349 L
.2893 .13484 L
.28909 .13477 L
.28887 .13471 L
.28866 .13464 L
.28845 .13458 L
.28824 .13452 L
.28802 .13445 L
.28781 .13439 L
.2876 .13432 L
.28739 .13426 L
.28718 .13419 L
.28697 .13413 L
.28676 .13406 L
.28655 .134 L
.28634 .13394 L
.28612 .13387 L
.28591 .13381 L
.2857 .13374 L
.28549 .13368 L
.28528 .13362 L
.28508 .13355 L
.28487 .13349 L
.28466 .13342 L
.28445 .13336 L
.28424 .1333 L
.28403 .13323 L
.28382 .13317 L
.28361 .1331 L
.28341 .13304 L
.2832 .13298 L
.28299 .13291 L
.28278 .13285 L
.28257 .13278 L
.28237 .13272 L
.28216 .13266 L
.28195 .13259 L
Mistroke
.28175 .13253 L
.28154 .13247 L
.28133 .1324 L
.28113 .13234 L
.28092 .13228 L
.28071 .13221 L
.28051 .13215 L
.2803 .13208 L
.2801 .13202 L
.27989 .13196 L
.27969 .13189 L
.27948 .13183 L
.27928 .13177 L
.27907 .1317 L
.27887 .13164 L
.27867 .13158 L
.27846 .13151 L
.27826 .13145 L
.27805 .13139 L
.27785 .13132 L
.27765 .13126 L
.27744 .1312 L
.27724 .13113 L
.27704 .13107 L
.27683 .13101 L
.27663 .13094 L
.27643 .13088 L
.27623 .13082 L
.27603 .13076 L
.27582 .13069 L
.27562 .13063 L
.27542 .13057 L
.27522 .1305 L
.27502 .13044 L
.27482 .13038 L
.27462 .13031 L
.27442 .13025 L
.27421 .13019 L
.27401 .13012 L
.27381 .13006 L
.27361 .13 L
.27341 .12993 L
.27321 .12987 L
.27302 .12981 L
.27282 .12975 L
.27262 .12968 L
.27242 .12962 L
.27222 .12956 L
.27202 .1295 L
.27182 .12943 L
Mistroke
.27162 .12937 L
.27142 .12931 L
.27123 .12925 L
.27103 .12918 L
.27083 .12912 L
.27063 .12906 L
.27044 .129 L
.27024 .12893 L
.27004 .12887 L
.26984 .12881 L
.26965 .12875 L
.26945 .12869 L
.26925 .12862 L
.26906 .12856 L
.26886 .1285 L
.26867 .12844 L
.26847 .12838 L
.26827 .12831 L
.26808 .12825 L
.26788 .12819 L
.26769 .12813 L
.26749 .12807 L
.2673 .128 L
.2671 .12794 L
.26691 .12788 L
.26671 .12782 L
.26652 .12776 L
.26633 .12769 L
.26613 .12763 L
.26594 .12757 L
.26575 .12751 L
.26555 .12745 L
.26536 .12739 L
.26517 .12732 L
.26497 .12726 L
.26478 .1272 L
.26459 .12714 L
.26439 .12708 L
.2642 .12702 L
.26401 .12696 L
.26382 .12689 L
.26363 .12683 L
.26343 .12677 L
.26324 .12671 L
.26305 .12665 L
.26286 .12659 L
.26267 .12653 L
.26248 .12646 L
.26229 .1264 L
.2621 .12634 L
Mistroke
.2619 .12628 L
.26171 .12622 L
.26152 .12616 L
.26133 .1261 L
.26114 .12604 L
.26095 .12597 L
.26076 .12591 L
.26058 .12585 L
.26039 .12579 L
.2602 .12573 L
.26001 .12567 L
.25982 .12561 L
.25963 .12555 L
.25944 .12549 L
.25925 .12543 L
.25906 .12536 L
.25888 .1253 L
.25869 .12524 L
.2585 .12518 L
.25831 .12512 L
.25813 .12506 L
.25794 .125 L
.25775 .12494 L
.25756 .12488 L
.25738 .12482 L
.25719 .12475 L
.257 .12469 L
.25682 .12463 L
.25663 .12457 L
.25644 .12451 L
.25626 .12445 L
.25607 .12439 L
.25589 .12433 L
.2557 .12427 L
.25552 .12421 L
.25533 .12415 L
.25514 .12409 L
.25496 .12403 L
.25478 .12397 L
.25459 .1239 L
.25441 .12384 L
.25422 .12378 L
.25404 .12372 L
.25385 .12366 L
.25367 .1236 L
.25348 .12354 L
.2533 .12348 L
.25312 .12342 L
.25293 .12336 L
.25275 .1233 L
Mistroke
.25257 .12324 L
.25238 .12318 L
.2522 .12312 L
.25202 .12306 L
.25184 .123 L
.25165 .12294 L
.25147 .12287 L
.25129 .12281 L
.25111 .12275 L
.25093 .12269 L
.25074 .12263 L
.25056 .12257 L
.25038 .12251 L
.2502 .12245 L
.25002 .12239 L
.24984 .12233 L
.24966 .12227 L
.24948 .12221 L
.2493 .12215 L
.24911 .12209 L
.24893 .12203 L
.24875 .12197 L
.24857 .12191 L
.24839 .12185 L
.24821 .12179 L
.24804 .12173 L
.24786 .12167 L
.24768 .12161 L
.2475 .12155 L
.24732 .12149 L
.24714 .12143 L
.24696 .12137 L
.24678 .12131 L
.2466 .12125 L
.24642 .12119 L
.24625 .12113 L
.24607 .12107 L
.24589 .12101 L
.24571 .12095 L
.24554 .12089 L
.24536 .12083 L
.24518 .12077 L
.245 .12072 L
.24483 .12066 L
.24465 .1206 L
.24447 .12054 L
.2443 .12048 L
.24412 .12042 L
.24394 .12036 L
.24377 .1203 L
Mistroke
.24359 .12024 L
.24341 .12018 L
.24324 .12012 L
.24306 .12006 L
.24289 .12 L
.24271 .11994 L
.24254 .11988 L
.24236 .11982 L
.24219 .11976 L
.24201 .1197 L
.24184 .11965 L
.24166 .11959 L
.24149 .11953 L
.24131 .11947 L
.24114 .11941 L
.24096 .11935 L
.24079 .11929 L
.24062 .11923 L
.24044 .11917 L
.24027 .11911 L
.24009 .11905 L
.23992 .119 L
.23975 .11894 L
.23957 .11888 L
.2394 .11882 L
.23923 .11876 L
.23906 .1187 L
.23888 .11864 L
.23871 .11858 L
.23854 .11852 L
.23837 .11847 L
.23819 .11841 L
.23802 .11835 L
.23785 .11829 L
.23768 .11823 L
.23751 .11817 L
.23734 .11811 L
.23717 .11805 L
.23699 .118 L
.23682 .11794 L
.23665 .11788 L
.23648 .11782 L
.23631 .11776 L
.23614 .1177 L
.23597 .11764 L
.2358 .11759 L
.23563 .11753 L
.23546 .11747 L
.23529 .11741 L
.23512 .11735 L
Mistroke
.23495 .1173 L
.23478 .11724 L
.23461 .11718 L
.23444 .11712 L
.23427 .11706 L
.2341 .117 L
.23394 .11695 L
.23377 .11689 L
.2336 .11683 L
.23343 .11677 L
.23326 .11671 L
.23309 .11666 L
.23293 .1166 L
.23276 .11654 L
.23259 .11648 L
.23242 .11642 L
.23225 .11637 L
.23209 .11631 L
.23192 .11625 L
.23175 .11619 L
.23159 .11613 L
.23142 .11608 L
.23125 .11602 L
.23109 .11596 L
.23092 .1159 L
.23075 .11585 L
.23059 .11579 L
.23042 .11573 L
.23025 .11567 L
.23009 .11561 L
.22992 .11556 L
.22976 .1155 L
.22959 .11544 L
.22943 .11538 L
.22926 .11533 L
.22909 .11527 L
.22893 .11521 L
.22876 .11515 L
.2286 .1151 L
.22844 .11504 L
.22827 .11498 L
.22811 .11492 L
.22794 .11487 L
.22778 .11481 L
.22761 .11475 L
.22745 .11469 L
.22729 .11464 L
.22712 .11458 L
.22696 .11452 L
.22679 .11447 L
Mistroke
.22663 .11441 L
.22647 .11435 L
.22631 .11429 L
.22614 .11424 L
.22598 .11418 L
.22582 .11412 L
.22565 .11406 L
.22549 .11401 L
.22533 .11395 L
.22517 .11389 L
.225 .11383 L
.22484 .11378 L
.22468 .11372 L
.22452 .11366 L
.22436 .11361 L
.2242 .11355 L
.22403 .11349 L
.22387 .11343 L
.22371 .11338 L
.22355 .11332 L
.22339 .11326 L
.22323 .11321 L
.22307 .11315 L
.22291 .11309 L
.22275 .11303 L
.22259 .11298 L
.22243 .11292 L
.22227 .11286 L
.22211 .11281 L
.22195 .11275 L
.22179 .11269 L
.22163 .11264 L
.22147 .11258 L
.22131 .11252 L
.22115 .11246 L
.22099 .11241 L
.22083 .11235 L
.22067 .11229 L
.22051 .11224 L
.22035 .11218 L
.22019 .11212 L
.22004 .11207 L
.21988 .11201 L
.21972 .11195 L
.21956 .1119 L
.2194 .11184 L
.21925 .11178 L
.21909 .11172 L
.21893 .11167 L
.21877 .11161 L
Mistroke
.21861 .11155 L
.21846 .1115 L
.2183 .11144 L
.21814 .11138 L
.21799 .11133 L
.21783 .11127 L
.21767 .11121 L
.21752 .11116 L
.21736 .1111 L
.2172 .11104 L
.21705 .11099 L
.21689 .11093 L
.21673 .11087 L
.21658 .11082 L
.21642 .11076 L
.21627 .1107 L
.21611 .11065 L
.21596 .11059 L
.2158 .11054 L
.21564 .11048 L
.21549 .11042 L
.21533 .11037 L
.21518 .11031 L
.21502 .11025 L
.21487 .1102 L
.21471 .11014 L
.21456 .11008 L
.21441 .11003 L
.21425 .10997 L
.2141 .10991 L
.21394 .10986 L
.21379 .1098 L
.21364 .10974 L
.21348 .10969 L
.21333 .10963 L
.21317 .10958 L
.21302 .10952 L
.21287 .10946 L
.21271 .10941 L
.21256 .10935 L
.21241 .10929 L
.21226 .10924 L
.2121 .10918 L
.21195 .10912 L
.2118 .10907 L
.21164 .10901 L
.21149 .10896 L
.21134 .1089 L
.21119 .10884 L
.21104 .10879 L
Mistroke
.21088 .10873 L
.21073 .10868 L
.21058 .10862 L
.21043 .10856 L
.21028 .10851 L
.21013 .10845 L
.20998 .1084 L
.20982 .10834 L
.20967 .10828 L
.20952 .10823 L
.20937 .10817 L
.20922 .10812 L
.20907 .10806 L
.20892 .108 L
.20877 .10795 L
.20862 .10789 L
.20847 .10784 L
.20832 .10778 L
.20817 .10773 L
.20802 .10767 L
.20787 .10761 L
.20772 .10756 L
.20757 .1075 L
.20742 .10745 L
.20727 .10739 L
.20712 .10733 L
.20697 .10728 L
.20682 .10722 L
.20667 .10717 L
.20653 .10711 L
.20638 .10706 L
.20623 .107 L
.20608 .10695 L
.20593 .10689 L
.20578 .10683 L
.20564 .10678 L
.20549 .10672 L
.20534 .10667 L
.20519 .10661 L
.20504 .10656 L
.2049 .1065 L
.20475 .10645 L
.2046 .10639 L
.20445 .10634 L
.20431 .10628 L
.20416 .10622 L
.20401 .10617 L
.20387 .10611 L
.20372 .10606 L
.20357 .106 L
Mistroke
.20343 .10595 L
.20328 .10589 L
.20313 .10584 L
.20299 .10578 L
.20284 .10573 L
.20269 .10567 L
.20255 .10562 L
.2024 .10556 L
.20226 .10551 L
.20211 .10545 L
.20196 .1054 L
.20182 .10534 L
.20167 .10529 L
.20153 .10523 L
.20138 .10518 L
.20124 .10512 L
.20109 .10507 L
.20095 .10501 L
.2008 .10496 L
.20066 .1049 L
.20051 .10485 L
.20037 .10479 L
.20023 .10474 L
.20008 .10468 L
.19994 .10463 L
.19979 .10457 L
.19965 .10452 L
.19951 .10446 L
.19936 .10441 L
.19922 .10435 L
.19907 .1043 L
.19893 .10424 L
.19879 .10419 L
.19864 .10413 L
.1985 .10408 L
.19836 .10402 L
.19821 .10397 L
.19807 .10391 L
.19793 .10386 L
.19779 .1038 L
.19764 .10375 L
.1975 .10369 L
.19736 .10364 L
.19722 .10358 L
.19707 .10353 L
.19693 .10347 L
.19679 .10342 L
.19665 .10337 L
.19651 .10331 L
.19636 .10326 L
Mistroke
.19622 .1032 L
.19608 .10315 L
.19594 .10309 L
.1958 .10304 L
.19566 .10298 L
.19552 .10293 L
.19538 .10287 L
.19523 .10282 L
.19509 .10277 L
.19495 .10271 L
.19481 .10266 L
.19467 .1026 L
.19453 .10255 L
.19439 .10249 L
.19425 .10244 L
.19411 .10239 L
.19397 .10233 L
.19383 .10228 L
.19369 .10222 L
.19355 .10217 L
.19341 .10211 L
.19327 .10206 L
.19313 .10201 L
.19299 .10195 L
.19285 .1019 L
.19271 .10184 L
.19258 .10179 L
.19244 .10173 L
.1923 .10168 L
.19216 .10163 L
.19202 .10157 L
.19188 .10152 L
.19174 .10146 L
.1916 .10141 L
.19147 .10136 L
.19133 .1013 L
.19119 .10125 L
.19105 .10119 L
.19091 .10114 L
.19078 .10109 L
.19064 .10103 L
.1905 .10098 L
.19036 .10092 L
.19023 .10087 L
.19009 .10082 L
.18995 .10076 L
.18981 .10071 L
.18968 .10066 L
.18954 .1006 L
.1894 .10055 L
Mistroke
.18927 .1005 L
.18913 .10044 L
.18899 .10039 L
.18886 .10033 L
.18872 .10028 L
.18858 .10023 L
.18845 .10017 L
.18831 .10012 L
.18817 .10007 L
.18804 .10001 L
.1879 .09996 L
.18777 .09991 L
.18763 .09985 L
.18749 .0998 L
.18736 .09975 L
.18722 .09969 L
.18709 .09964 L
.18695 .09959 L
.18682 .09953 L
.18668 .09948 L
.18655 .09943 L
.18641 .09937 L
.18628 .09932 L
.18614 .09927 L
.18601 .09922 L
.18587 .09916 L
.18574 .09911 L
.18561 .09906 L
.18547 .099 L
.18534 .09895 L
.1852 .0989 L
.18507 .09884 L
.18494 .09879 L
.1848 .09874 L
.18467 .09868 L
.18453 .09863 L
.1844 .09858 L
.18427 .09853 L
.18413 .09847 L
.184 .09842 L
.18387 .09837 L
.18373 .09831 L
.1836 .09826 L
.18347 .09821 L
.18333 .09816 L
.1832 .0981 L
.18307 .09805 L
.18294 .098 L
.1828 .09794 L
.18267 .09789 L
Mistroke
.18254 .09784 L
.18241 .09779 L
.18228 .09773 L
.18214 .09768 L
.18201 .09763 L
.18188 .09758 L
.18175 .09752 L
.18162 .09747 L
.18148 .09742 L
.18135 .09736 L
.18122 .09731 L
.18109 .09726 L
.18096 .09721 L
.18083 .09715 L
.1807 .0971 L
.18057 .09705 L
.18043 .097 L
.1803 .09694 L
.18017 .09689 L
.18004 .09684 L
.17991 .09679 L
.17978 .09673 L
.17965 .09668 L
.17952 .09663 L
.17939 .09658 L
.17926 .09653 L
.17913 .09647 L
.179 .09642 L
.17887 .09637 L
.17874 .09632 L
.17861 .09626 L
.17848 .09621 L
.17835 .09616 L
.17822 .09611 L
.17809 .09605 L
.17796 .096 L
.17783 .09595 L
.17771 .0959 L
.17758 .09584 L
.17745 .09579 L
.17732 .09574 L
.17719 .09569 L
.17706 .09564 L
.17693 .09558 L
.1768 .09553 L
.17668 .09548 L
.17655 .09543 L
.17642 .09538 L
.17629 .09532 L
.17616 .09527 L
Mistroke
.17603 .09522 L
.17591 .09517 L
.17578 .09511 L
.17565 .09506 L
.17552 .09501 L
.1754 .09496 L
.17527 .09491 L
.17514 .09485 L
.17501 .0948 L
.17489 .09475 L
.17476 .0947 L
.17463 .09465 L
.1745 .0946 L
.17438 .09454 L
.17425 .09449 L
.17412 .09444 L
.174 .09439 L
.17387 .09434 L
.17374 .09429 L
.17362 .09423 L
.17349 .09418 L
.17337 .09413 L
.17324 .09408 L
.17311 .09403 L
.17299 .09398 L
.17286 .09392 L
.17274 .09387 L
.17261 .09382 L
.17248 .09377 L
.17236 .09372 L
.17223 .09367 L
.17211 .09361 L
.17198 .09356 L
.17186 .09351 L
.17173 .09346 L
.17161 .09341 L
.17148 .09336 L
.17136 .09331 L
.17123 .09325 L
.17111 .0932 L
.17098 .09315 L
.17086 .0931 L
.17073 .09305 L
.17061 .093 L
.17048 .09295 L
.17036 .09289 L
.17024 .09284 L
.17011 .09279 L
.16999 .09274 L
.16986 .09269 L
Mistroke
.16974 .09264 L
.16962 .09259 L
.16949 .09254 L
.16937 .09248 L
.16924 .09243 L
.16912 .09238 L
.169 .09233 L
.16887 .09228 L
.16875 .09223 L
.16863 .09218 L
.1685 .09213 L
.16838 .09208 L
.16826 .09203 L
.16814 .09197 L
.16801 .09192 L
.16789 .09187 L
.16777 .09182 L
.16764 .09177 L
.16752 .09172 L
.1674 .09167 L
.16728 .09162 L
.16715 .09157 L
.16703 .09152 L
.16691 .09147 L
.16679 .09141 L
.16667 .09136 L
.16654 .09131 L
.16642 .09126 L
.1663 .09121 L
.16618 .09116 L
.16606 .09111 L
.16594 .09106 L
.16582 .09101 L
.16569 .09096 L
.16557 .09091 L
.16545 .09085 L
.16533 .0908 L
.16521 .09075 L
.16509 .0907 L
.16497 .09065 L
.16485 .0906 L
.16473 .09055 L
.16461 .0905 L
.16448 .09045 L
.16436 .0904 L
.16424 .09035 L
.16412 .0903 L
.164 .09025 L
.16388 .0902 L
.16376 .09014 L
Mistroke
.16364 .09009 L
.16352 .09004 L
.1634 .08999 L
.16328 .08994 L
.16316 .08989 L
.16304 .08984 L
.16292 .08979 L
.16281 .08974 L
.16269 .08969 L
.16257 .08964 L
.16245 .08959 L
.16233 .08954 L
.16221 .08949 L
.16209 .08944 L
.16197 .08939 L
.16185 .08934 L
.16173 .08929 L
.16161 .08924 L
.1615 .08919 L
.16138 .08913 L
.16126 .08908 L
.16114 .08903 L
.16102 .08898 L
.1609 .08893 L
.16079 .08888 L
.16067 .08883 L
.16055 .08878 L
.16043 .08873 L
.16031 .08868 L
.1602 .08863 L
.16008 .08858 L
.15996 .08853 L
.15984 .08848 L
.15973 .08843 L
.15961 .08838 L
.15949 .08833 L
.15937 .08828 L
.15926 .08823 L
.15914 .08818 L
.15902 .08813 L
.1589 .08808 L
.15879 .08803 L
.15867 .08798 L
.15855 .08793 L
.15844 .08788 L
.15832 .08783 L
.1582 .08778 L
.15809 .08773 L
.15797 .08768 L
.15785 .08763 L
Mistroke
.15774 .08758 L
.15762 .08753 L
.15751 .08748 L
.15739 .08743 L
.15727 .08738 L
.15716 .08733 L
.15704 .08728 L
.15693 .08723 L
.15681 .08718 L
.15669 .08713 L
.15658 .08708 L
.15646 .08703 L
.15635 .08698 L
.15623 .08693 L
.15612 .08688 L
.156 .08683 L
.15589 .08678 L
.15577 .08673 L
.15566 .08668 L
.15554 .08663 L
.15543 .08658 L
.15531 .08653 L
.1552 .08648 L
.15508 .08643 L
.15497 .08638 L
.15485 .08633 L
.15474 .08628 L
.15463 .08623 L
.15451 .08618 L
.1544 .08613 L
.15428 .08608 L
.15417 .08603 L
.15405 .08598 L
.15394 .08593 L
.15383 .08588 L
.15371 .08584 L
.1536 .08579 L
.15349 .08574 L
.15337 .08569 L
.15326 .08564 L
.15315 .08559 L
.15303 .08554 L
.15292 .08549 L
.15281 .08544 L
.15269 .08539 L
.15258 .08534 L
.15247 .08529 L
.15235 .08524 L
.15224 .08519 L
.15213 .08514 L
Mistroke
.15201 .08509 L
.1519 .08504 L
.15179 .085 L
.15168 .08495 L
.15156 .0849 L
.15145 .08485 L
.15134 .0848 L
.15123 .08475 L
.15112 .0847 L
.151 .08465 L
.15089 .0846 L
.15078 .08455 L
.15067 .0845 L
.15056 .08445 L
.15044 .0844 L
.15033 .08436 L
.15022 .08431 L
.15011 .08426 L
.15 .08421 L
.14989 .08416 L
.14977 .08411 L
.14966 .08406 L
.14955 .08401 L
.14944 .08396 L
.14933 .08391 L
.14922 .08386 L
.14911 .08381 L
.149 .08377 L
.14889 .08372 L
.14878 .08367 L
.14866 .08362 L
.14855 .08357 L
.14844 .08352 L
.14833 .08347 L
.14822 .08342 L
.14811 .08337 L
.148 .08333 L
.14789 .08328 L
.14778 .08323 L
.14767 .08318 L
.14756 .08313 L
.14745 .08308 L
.14734 .08303 L
.14723 .08298 L
.14712 .08294 L
.14701 .08289 L
.1469 .08284 L
.14679 .08279 L
.14668 .08274 L
.14657 .08269 L
Mistroke
.14646 .08264 L
.14636 .08259 L
.14625 .08255 L
.14614 .0825 L
.14603 .08245 L
.14592 .0824 L
.14581 .08235 L
.1457 .0823 L
.14559 .08225 L
.14548 .08221 L
.14537 .08216 L
.14527 .08211 L
.14516 .08206 L
.14505 .08201 L
.14494 .08196 L
.14483 .08192 L
.14472 .08187 L
.14462 .08182 L
.14451 .08177 L
.1444 .08172 L
.14429 .08167 L
.14418 .08163 L
.14408 .08158 L
.14397 .08153 L
.14386 .08148 L
.14375 .08143 L
.14364 .08138 L
.14354 .08134 L
.14343 .08129 L
.14332 .08124 L
.14321 .08119 L
.14311 .08114 L
.143 .0811 L
.14289 .08105 L
.14279 .081 L
.14268 .08095 L
.14257 .0809 L
.14246 .08086 L
.14236 .08081 L
.14225 .08076 L
.14214 .08071 L
.14204 .08066 L
.14193 .08061 L
.14182 .08057 L
.14172 .08052 L
.14161 .08047 L
.14151 .08042 L
.1414 .08038 L
.14129 .08033 L
.14119 .08028 L
Mistroke
.14108 .08023 L
.14097 .08018 L
.14087 .08014 L
.14076 .08009 L
.14066 .08004 L
.14055 .07999 L
.14044 .07994 L
.14034 .0799 L
.14023 .07985 L
.14013 .0798 L
.14002 .07975 L
.13992 .07971 L
.13981 .07966 L
.13971 .07961 L
.1396 .07956 L
.1395 .07951 L
.13939 .07947 L
.13929 .07942 L
.13918 .07937 L
.13908 .07932 L
.13897 .07928 L
.13887 .07923 L
.13876 .07918 L
.13866 .07913 L
.13855 .07909 L
.13845 .07904 L
.13834 .07899 L
.13824 .07894 L
.13813 .07889 L
.13803 .07885 L
.13793 .0788 L
.13782 .07875 L
.13772 .0787 L
.13761 .07866 L
.13751 .07861 L
.13741 .07856 L
.1373 .07851 L
.1372 .07847 L
.13709 .07842 L
.13699 .07837 L
.13689 .07832 L
.13678 .07828 L
.13668 .07823 L
.13658 .07818 L
.13647 .07813 L
.13637 .07809 L
.13627 .07804 L
.13616 .07799 L
.13606 .07794 L
.13596 .0779 L
Mistroke
.13585 .07785 L
.13575 .0778 L
.13565 .07775 L
.13555 .07771 L
.13544 .07766 L
.13534 .07761 L
.13524 .07757 L
.13513 .07752 L
.13503 .07747 L
.13493 .07742 L
.13483 .07738 L
.13473 .07733 L
.13462 .07728 L
.13452 .07723 L
.13442 .07719 L
.13432 .07714 L
.13421 .07709 L
.13411 .07705 L
.13401 .077 L
.13391 .07695 L
.13381 .0769 L
.1337 .07686 L
.1336 .07681 L
.1335 .07676 L
.1334 .07672 L
.1333 .07667 L
.1332 .07662 L
.1331 .07658 L
.13299 .07653 L
.13289 .07648 L
.13279 .07643 L
.13269 .07639 L
.13259 .07634 L
.13249 .07629 L
.13239 .07625 L
.13229 .0762 L
.13219 .07615 L
.13209 .07611 L
.13198 .07606 L
.13188 .07601 L
.13178 .07596 L
.13168 .07592 L
.13158 .07587 L
.13148 .07582 L
.13138 .07578 L
.13128 .07573 L
.13118 .07568 L
.13108 .07564 L
.13098 .07559 L
.13088 .07554 L
Mistroke
.13078 .0755 L
.13068 .07545 L
.13058 .0754 L
.13048 .07536 L
.13038 .07531 L
.13028 .07526 L
.13018 .07522 L
.13008 .07517 L
.12998 .07512 L
.12988 .07508 L
.12978 .07503 L
.12968 .07498 L
.12958 .07494 L
.12948 .07489 L
.12939 .07484 L
.12929 .0748 L
.12919 .07475 L
.12909 .0747 L
.12899 .07466 L
.12889 .07461 L
.12879 .07456 L
.12869 .07452 L
.12859 .07447 L
.12849 .07442 L
.1284 .07438 L
.1283 .07433 L
.1282 .07428 L
.1281 .07424 L
.128 .07419 L
.1279 .07414 L
.12781 .0741 L
.12771 .07405 L
.12761 .074 L
.12751 .07396 L
.12741 .07391 L
.12731 .07387 L
.12722 .07382 L
.12712 .07377 L
.12702 .07373 L
.12692 .07368 L
.12682 .07363 L
.12673 .07359 L
.12663 .07354 L
.12653 .07349 L
.12643 .07345 L
.12634 .0734 L
.12624 .07335 L
.12614 .07331 L
.12604 .07326 L
.12595 .07322 L
Mistroke
.12585 .07317 L
.12575 .07312 L
.12566 .07308 L
.12556 .07303 L
.12546 .07298 L
.12537 .07294 L
.12527 .07289 L
.12517 .07284 L
.12507 .0728 L
.12498 .07275 L
.12488 .07271 L
.12478 .07266 L
.12469 .07261 L
.12459 .07257 L
.1245 .07252 L
.1244 .07247 L
.1243 .07243 L
.12421 .07238 L
.12411 .07234 L
.12401 .07229 L
.12392 .07224 L
.12382 .0722 L
.12373 .07215 L
.12363 .0721 L
.12353 .07206 L
.12344 .07201 L
.12334 .07197 L
.12325 .07192 L
.12315 .07187 L
.12306 .07183 L
.12296 .07178 L
.12286 .07174 L
.12277 .07169 L
.12267 .07164 L
.12258 .0716 L
.12248 .07155 L
.12239 .0715 L
.12229 .07146 L
.1222 .07141 L
.1221 .07137 L
.12201 .07132 L
.12191 .07127 L
.12182 .07123 L
.12172 .07118 L
.12163 .07114 L
.12153 .07109 L
.12144 .07105 L
.12134 .071 L
.12125 .07095 L
.12115 .07091 L
Mistroke
.12106 .07086 L
.12097 .07082 L
.12087 .07077 L
.12078 .07072 L
.12068 .07068 L
.12059 .07063 L
.12049 .07059 L
.1204 .07054 L
.12031 .0705 L
.12021 .07045 L
.12012 .0704 L
.12002 .07036 L
.11993 .07031 L
.11984 .07027 L
.11974 .07022 L
.11965 .07018 L
.11956 .07013 L
.11946 .07009 L
.11937 .07004 L
.11927 .06999 L
.11918 .06995 L
.11909 .0699 L
.11899 .06986 L
.1189 .06981 L
.11881 .06977 L
.11871 .06972 L
.11862 .06968 L
.11853 .06963 L
.11844 .06958 L
.11834 .06954 L
.11825 .06949 L
.11816 .06945 L
.11806 .0694 L
.11797 .06936 L
.11788 .06931 L
.11779 .06927 L
.11769 .06922 L
.1176 .06918 L
.11751 .06913 L
.11742 .06909 L
.11732 .06904 L
.11723 .069 L
.11714 .06895 L
.11705 .06891 L
.11695 .06886 L
.11686 .06882 L
.11677 .06877 L
.11668 .06872 L
.11659 .06868 L
.11649 .06863 L
Mistroke
.1164 .06859 L
.11631 .06854 L
.11622 .0685 L
.11613 .06845 L
.11604 .06841 L
.11594 .06836 L
.11585 .06832 L
.11576 .06827 L
.11567 .06823 L
.11558 .06818 L
.11549 .06814 L
.11539 .06809 L
.1153 .06805 L
.11521 .068 L
.11512 .06796 L
.11503 .06791 L
.11494 .06787 L
.11485 .06782 L
.11476 .06778 L
.11467 .06773 L
.11458 .06769 L
.11448 .06764 L
.11439 .0676 L
.1143 .06755 L
.11421 .06751 L
.11412 .06747 L
.11403 .06742 L
.11394 .06738 L
.11385 .06733 L
.11376 .06729 L
.11367 .06724 L
.11358 .0672 L
.11349 .06715 L
.1134 .06711 L
.11331 .06706 L
.11322 .06702 L
.11313 .06697 L
.11304 .06693 L
.11295 .06688 L
.11286 .06684 L
.11277 .06679 L
.11268 .06675 L
.11259 .0667 L
.1125 .06666 L
.11241 .06662 L
.11232 .06657 L
.11223 .06653 L
.11214 .06648 L
.11205 .06644 L
.11196 .06639 L
Mistroke
.11187 .06635 L
.11178 .0663 L
.11169 .06626 L
.1116 .06621 L
.11152 .06617 L
.11143 .06612 L
.11134 .06608 L
.11125 .06604 L
.11116 .06599 L
.11107 .06595 L
.11098 .0659 L
.11089 .06586 L
.1108 .06581 L
.11071 .06577 L
.11063 .06572 L
.11054 .06568 L
.11045 .06564 L
.11036 .06559 L
.11027 .06555 L
.11018 .0655 L
.11009 .06546 L
.11001 .06541 L
.10992 .06537 L
.10983 .06532 L
.10974 .06528 L
.10965 .06524 L
.10957 .06519 L
.10948 .06515 L
.10939 .0651 L
.1093 .06506 L
.10921 .06501 L
.10913 .06497 L
.10904 .06492 L
.10895 .06488 L
.10886 .06484 L
.10877 .06479 L
.10869 .06475 L
.1086 .0647 L
.10851 .06466 L
.10842 .06461 L
.10834 .06457 L
.10825 .06453 L
.10816 .06448 L
.10807 .06444 L
.10799 .06439 L
.1079 .06435 L
.10781 .0643 L
.10773 .06426 L
.10764 .06422 L
.10755 .06417 L
Mistroke
.10746 .06413 L
.10738 .06408 L
.10729 .06404 L
.1072 .064 L
.10712 .06395 L
.10703 .06391 L
.10694 .06386 L
.10686 .06382 L
.10677 .06377 L
.10668 .06373 L
.1066 .06369 L
.10651 .06364 L
.10642 .0636 L
.10634 .06355 L
.10625 .06351 L
.10617 .06347 L
.10608 .06342 L
.10599 .06338 L
.10591 .06333 L
.10582 .06329 L
.10573 .06325 L
.10565 .0632 L
.10556 .06316 L
.10548 .06311 L
.10539 .06307 L
.10531 .06303 L
.10522 .06298 L
.10513 .06294 L
.10505 .0629 L
.10496 .06285 L
.10488 .06281 L
.10479 .06276 L
.10471 .06272 L
.10462 .06268 L
.10453 .06263 L
.10445 .06259 L
.10436 .06255 L
.10428 .0625 L
.10419 .06246 L
.10411 .06241 L
.10402 .06237 L
.10394 .06233 L
.10385 .06228 L
.10377 .06224 L
.10368 .0622 L
.1036 .06215 L
.10351 .06211 L
.10343 .06207 L
.10334 .06202 L
.10326 .06198 L
Mistroke
.10317 .06194 L
.10309 .06189 L
.10301 .06185 L
.10292 .0618 L
.10284 .06176 L
.10275 .06172 L
.10267 .06167 L
.10258 .06163 L
.1025 .06159 L
.10241 .06154 L
.10233 .0615 L
.10225 .06146 L
.10216 .06141 L
.10208 .06137 L
.10199 .06133 L
.10191 .06128 L
.10183 .06124 L
.10174 .0612 L
.10166 .06115 L
.10157 .06111 L
.10149 .06107 L
.10141 .06102 L
.10132 .06098 L
.10124 .06094 L
.10116 .06089 L
.10107 .06085 L
.10099 .06081 L
.10091 .06076 L
.10082 .06072 L
.10074 .06068 L
.10066 .06063 L
.10057 .06059 L
.10049 .06055 L
.10041 .06051 L
.10032 .06046 L
.10024 .06042 L
.10016 .06038 L
.10007 .06033 L
.09999 .06029 L
.09991 .06025 L
.09982 .0602 L
.09974 .06016 L
.09966 .06012 L
.09958 .06007 L
.09949 .06003 L
.09941 .05999 L
.09933 .05995 L
.09925 .0599 L
.09916 .05986 L
.09908 .05982 L
Mistroke
.099 .05977 L
.09892 .05973 L
.09883 .05969 L
.09875 .05964 L
.09867 .0596 L
.09859 .05956 L
.0985 .05952 L
.09842 .05947 L
.09834 .05943 L
.09826 .05939 L
.09818 .05934 L
.09809 .0593 L
.09801 .05926 L
.09793 .05922 L
.09785 .05917 L
.09777 .05913 L
.09768 .05909 L
.0976 .05905 L
.09752 .059 L
.09744 .05896 L
.09736 .05892 L
.09728 .05887 L
.09719 .05883 L
.09711 .05879 L
.09703 .05875 L
.09695 .0587 L
.09687 .05866 L
.09679 .05862 L
.09671 .05858 L
.09662 .05853 L
.09654 .05849 L
.09646 .05845 L
.09638 .05841 L
.0963 .05836 L
.09622 .05832 L
.09614 .05828 L
.09606 .05824 L
.09598 .05819 L
.0959 .05815 L
.09581 .05811 L
.09573 .05807 L
.09565 .05802 L
.09557 .05798 L
.09549 .05794 L
.09541 .0579 L
.09533 .05785 L
.09525 .05781 L
.09517 .05777 L
.09509 .05773 L
.09501 .05768 L
Mistroke
.09493 .05764 L
.09485 .0576 L
.09477 .05756 L
.09469 .05751 L
.09461 .05747 L
.09453 .05743 L
.09445 .05739 L
.09437 .05734 L
.09429 .0573 L
.09421 .05726 L
.09413 .05722 L
.09405 .05718 L
.09397 .05713 L
.09389 .05709 L
.09381 .05705 L
.09373 .05701 L
.09365 .05696 L
.09357 .05692 L
.09349 .05688 L
.09341 .05684 L
.09333 .0568 L
.09325 .05675 L
.09317 .05671 L
.09309 .05667 L
.09301 .05663 L
.09293 .05659 L
.09285 .05654 L
.09278 .0565 L
.0927 .05646 L
.09262 .05642 L
.09254 .05637 L
.09246 .05633 L
.09238 .05629 L
.0923 .05625 L
.09222 .05621 L
.09214 .05616 L
.09206 .05612 L
.09199 .05608 L
.09191 .05604 L
.09183 .056 L
.09175 .05595 L
.09167 .05591 L
.09159 .05587 L
.09151 .05583 L
.09143 .05579 L
.09136 .05574 L
.09128 .0557 L
.0912 .05566 L
.09112 .05562 L
.09104 .05558 L
Mistroke
.09096 .05554 L
.09089 .05549 L
.09081 .05545 L
.09073 .05541 L
.09065 .05537 L
.09057 .05533 L
.0905 .05528 L
.09042 .05524 L
.09034 .0552 L
.09026 .05516 L
.09018 .05512 L
.09011 .05508 L
.09003 .05503 L
.08995 .05499 L
.08987 .05495 L
.0898 .05491 L
.08972 .05487 L
.08964 .05483 L
.08956 .05478 L
.08948 .05474 L
.08941 .0547 L
.08933 .05466 L
.08925 .05462 L
.08917 .05458 L
.0891 .05454 L
.08902 .05449 L
.08894 .05445 L
.08887 .05441 L
.08879 .05437 L
.08871 .05433 L
.08863 .05429 L
.08856 .05424 L
.08848 .0542 L
.0884 .05416 L
.08833 .05412 L
.08825 .05408 L
.08817 .05404 L
.0881 .054 L
.08802 .05396 L
.08794 .05391 L
.08787 .05387 L
.08779 .05383 L
.08771 .05379 L
.08764 .05375 L
.08756 .05371 L
.08748 .05367 L
.08741 .05362 L
.08733 .05358 L
.08725 .05354 L
.08718 .0535 L
Mistroke
.0871 .05346 L
.08702 .05342 L
.08695 .05338 L
.08687 .05334 L
.0868 .0533 L
.08672 .05325 L
.08664 .05321 L
.08657 .05317 L
.08649 .05313 L
.08642 .05309 L
.08634 .05305 L
.08626 .05301 L
.08619 .05297 L
.08611 .05292 L
.08604 .05288 L
.08596 .05284 L
.08588 .0528 L
.08581 .05276 L
.08573 .05272 L
.08566 .05268 L
.08558 .05264 L
.08551 .0526 L
.08543 .05256 L
.08536 .05251 L
.08528 .05247 L
.08521 .05243 L
.08513 .05239 L
.08505 .05235 L
.08498 .05231 L
.0849 .05227 L
.08483 .05223 L
.08475 .05219 L
.08468 .05215 L
.0846 .05211 L
.08453 .05206 L
.08445 .05202 L
.08438 .05198 L
.0843 .05194 L
.08423 .0519 L
.08415 .05186 L
.08408 .05182 L
.084 .05178 L
.08393 .05174 L
.08386 .0517 L
.08378 .05166 L
.08371 .05162 L
.08363 .05157 L
.08356 .05153 L
.08348 .05149 L
.08341 .05145 L
Mistroke
.08333 .05141 L
.08326 .05137 L
.08318 .05133 L
.08311 .05129 L
.08304 .05125 L
.08296 .05121 L
.08289 .05117 L
.08281 .05113 L
.08274 .05109 L
.08267 .05105 L
.08259 .05101 L
.08252 .05097 L
.08244 .05092 L
.08237 .05088 L
.0823 .05084 L
.08222 .0508 L
.08215 .05076 L
.08207 .05072 L
.082 .05068 L
.08193 .05064 L
.08185 .0506 L
.08178 .05056 L
.08171 .05052 L
.08163 .05048 L
.08156 .05044 L
.08148 .0504 L
.08141 .05036 L
.08134 .05032 L
.08126 .05028 L
.08119 .05024 L
.08112 .0502 L
.08104 .05016 L
.08097 .05012 L
.0809 .05007 L
.08082 .05003 L
.08075 .04999 L
.08068 .04995 L
.08061 .04991 L
.08053 .04987 L
.08046 .04983 L
.08039 .04979 L
.08031 .04975 L
.08024 .04971 L
.08017 .04967 L
.0801 .04963 L
.08002 .04959 L
.07995 .04955 L
.07988 .04951 L
.0798 .04947 L
.07973 .04943 L
Mistroke
.07966 .04939 L
.07959 .04935 L
.07951 .04931 L
.07944 .04927 L
.07937 .04923 L
.0793 .04919 L
.07922 .04915 L
.07915 .04911 L
.07908 .04907 L
.07901 .04903 L
.07894 .04899 L
.07886 .04895 L
.07879 .04891 L
.07872 .04887 L
.07865 .04883 L
.07857 .04879 L
.0785 .04875 L
.07843 .04871 L
.07836 .04867 L
.07829 .04863 L
.07821 .04859 L
.07814 .04855 L
.07807 .04851 L
.078 .04846 L
.07793 .04842 L
.07786 .04838 L
.07778 .04834 L
.07771 .0483 L
.07764 .04826 L
.07757 .04822 L
.0775 .04818 L
.07743 .04814 L
.07735 .0481 L
.07728 .04806 L
.07721 .04802 L
.07714 .04798 L
.07707 .04795 L
.077 .04791 L
.07693 .04787 L
.07686 .04783 L
.07678 .04779 L
.07671 .04775 L
.07664 .04771 L
.07657 .04767 L
.0765 .04763 L
.07643 .04759 L
.07636 .04755 L
.07629 .04751 L
.07622 .04747 L
.07615 .04743 L
Mistroke
.07607 .04739 L
.076 .04735 L
.07593 .04731 L
.07586 .04727 L
.07579 .04723 L
.07572 .04719 L
.07565 .04715 L
.07558 .04711 L
.07551 .04707 L
.07544 .04703 L
.07537 .04699 L
.0753 .04695 L
.07523 .04691 L
.07516 .04687 L
.07509 .04683 L
.07502 .04679 L
.07495 .04675 L
.07488 .04671 L
.07481 .04668 L
.07473 .04664 L
.07466 .0466 L
.07459 .04656 L
.07452 .04652 L
.07445 .04648 L
.07438 .04644 L
.07431 .0464 L
.07424 .04636 L
.07417 .04632 L
.0741 .04628 L
.07403 .04624 L
.07397 .0462 L
.0739 .04616 L
.07383 .04612 L
.07376 .04608 L
.07369 .04604 L
.07362 .04601 L
.07355 .04597 L
.07348 .04593 L
.07341 .04589 L
.07334 .04585 L
.07327 .04581 L
.0732 .04577 L
.07313 .04573 L
.07306 .04569 L
.07299 .04565 L
.07292 .04561 L
.07285 .04557 L
.07278 .04553 L
.07271 .04549 L
.07265 .04546 L
Mistroke
.07258 .04542 L
.07251 .04538 L
.07244 .04534 L
.07237 .0453 L
.0723 .04526 L
.07223 .04522 L
.07216 .04518 L
.07209 .04514 L
.07202 .0451 L
.07196 .04506 L
.07189 .04502 L
.07182 .04498 L
.07175 .04495 L
.07168 .04491 L
.07161 .04487 L
.07154 .04483 L
.07147 .04479 L
.07141 .04475 L
.07134 .04471 L
.07127 .04467 L
.0712 .04463 L
.07113 .04459 L
.07106 .04455 L
.07099 .04451 L
.07093 .04447 L
.07086 .04444 L
.07079 .0444 L
.07072 .04436 L
.07065 .04432 L
.07059 .04428 L
.07052 .04424 L
.07045 .0442 L
.07038 .04416 L
.07031 .04412 L
.07024 .04408 L
.07018 .04404 L
.07011 .044 L
.07004 .04397 L
.06997 .04393 L
.06991 .04389 L
.06984 .04385 L
.06977 .04381 L
.0697 .04377 L
.06963 .04373 L
.06957 .04369 L
.0695 .04365 L
.06943 .04361 L
.06936 .04358 L
.0693 .04354 L
.06923 .0435 L
Mistroke
.06916 .04346 L
.06909 .04342 L
.06903 .04338 L
.06896 .04334 L
.06889 .0433 L
.06882 .04326 L
.06876 .04322 L
.06869 .04319 L
.06862 .04315 L
.06855 .04311 L
.06849 .04307 L
.06842 .04303 L
.06835 .04299 L
.06829 .04295 L
.06822 .04291 L
.06815 .04287 L
.06809 .04284 L
.06802 .0428 L
.06795 .04276 L
.06788 .04272 L
.06782 .04268 L
.06775 .04264 L
.06768 .0426 L
.06762 .04256 L
.06755 .04253 L
.06748 .04249 L
.06742 .04245 L
.06735 .04241 L
.06728 .04237 L
.06722 .04233 L
.06715 .04229 L
.06708 .04225 L
.06702 .04222 L
.06695 .04218 L
.06688 .04214 L
.06682 .0421 L
.06675 .04206 L
.06669 .04202 L
.06662 .04198 L
.06655 .04194 L
.06649 .04191 L
.06642 .04187 L
.06635 .04183 L
.06629 .04179 L
.06622 .04175 L
.06616 .04171 L
.06609 .04167 L
.06602 .04163 L
.06596 .0416 L
.06589 .04156 L
Mistroke
.06583 .04152 L
.06576 .04148 L
.06569 .04144 L
.06563 .0414 L
.06556 .04136 L
.0655 .04133 L
.06543 .04129 L
.06537 .04125 L
.0653 .04121 L
.06523 .04117 L
.06517 .04113 L
.0651 .04109 L
.06504 .04106 L
.06497 .04102 L
.06491 .04098 L
.06484 .04094 L
.06478 .0409 L
.06471 .04086 L
.06464 .04082 L
.06458 .04079 L
.06451 .04075 L
.06445 .04071 L
.06438 .04067 L
.06432 .04063 L
.06425 .04059 L
.06419 .04056 L
.06412 .04052 L
.06406 .04048 L
.06399 .04044 L
.06393 .0404 L
.06386 .04036 L
.0638 .04033 L
.06373 .04029 L
.06367 .04025 L
.0636 .04021 L
.06354 .04017 L
.06347 .04013 L
.06341 .0401 L
.06334 .04006 L
.06328 .04002 L
.06321 .03998 L
.06315 .03994 L
.06309 .0399 L
.06302 .03987 L
.06296 .03983 L
.06289 .03979 L
.06283 .03975 L
.06276 .03971 L
.0627 .03967 L
.06263 .03964 L
Mistroke
.06257 .0396 L
.0625 .03956 L
.06244 .03952 L
.06238 .03948 L
.06231 .03945 L
.06225 .03941 L
.06218 .03937 L
.06212 .03933 L
.06206 .03929 L
.06199 .03925 L
.06193 .03922 L
.06186 .03918 L
.0618 .03914 L
.06173 .0391 L
.06167 .03906 L
.06161 .03902 L
.06154 .03899 L
.06148 .03895 L
.06142 .03891 L
.06135 .03887 L
.06129 .03883 L
.06122 .0388 L
.06116 .03876 L
.0611 .03872 L
.06103 .03868 L
.06097 .03864 L
.06091 .03861 L
.06084 .03857 L
.06078 .03853 L
.06071 .03849 L
.06065 .03845 L
.06059 .03841 L
.06052 .03838 L
.06046 .03834 L
.0604 .0383 L
.06033 .03826 L
.06027 .03822 L
.06021 .03819 L
.06014 .03815 L
.06008 .03811 L
.06002 .03807 L
.05995 .03804 L
.05989 .038 L
.05983 .03796 L
.05976 .03792 L
.0597 .03788 L
.05964 .03785 L
.05958 .03781 L
.05951 .03777 L
.05945 .03773 L
Mistroke
.05939 .03769 L
.05932 .03766 L
.05926 .03762 L
.0592 .03758 L
.05914 .03754 L
.05907 .0375 L
.05901 .03747 L
.05895 .03743 L
.05888 .03739 L
.05882 .03735 L
.05876 .03732 L
.0587 .03728 L
.05863 .03724 L
.05857 .0372 L
.05851 .03716 L
.05845 .03713 L
.05838 .03709 L
.05832 .03705 L
.05826 .03701 L
.0582 .03698 L
.05813 .03694 L
.05807 .0369 L
.05801 .03686 L
.05795 .03682 L
.05789 .03679 L
.05782 .03675 L
.05776 .03671 L
.0577 .03667 L
.05764 .03664 L
.05757 .0366 L
.05751 .03656 L
.05745 .03652 L
.05739 .03649 L
.05733 .03645 L
.05726 .03641 L
.0572 .03637 L
.05714 .03634 L
.05708 .0363 L
.05702 .03626 L
.05696 .03622 L
.05689 .03619 L
.05683 .03615 L
.05677 .03611 L
.05671 .03607 L
.05665 .03603 L
.05658 .036 L
.05652 .03596 L
.05646 .03592 L
.0564 .03588 L
.05634 .03585 L
Mistroke
.05628 .03581 L
.05622 .03577 L
.05615 .03573 L
.05609 .0357 L
.05603 .03566 L
.05597 .03562 L
.05591 .03559 L
.05585 .03555 L
.05579 .03551 L
.05572 .03547 L
.05566 .03544 L
.0556 .0354 L
.05554 .03536 L
.05548 .03532 L
.05542 .03529 L
.05536 .03525 L
.0553 .03521 L
.05524 .03517 L
.05517 .03514 L
.05511 .0351 L
.05505 .03506 L
.05499 .03503 L
.05493 .03499 L
.05487 .03495 L
.05481 .03491 L
.05475 .03488 L
.05469 .03484 L
.05463 .0348 L
.05457 .03476 L
.05451 .03473 L
.05444 .03469 L
.05438 .03465 L
.05432 .03462 L
.05426 .03458 L
.0542 .03454 L
.05414 .0345 L
.05408 .03447 L
.05402 .03443 L
.05396 .03439 L
.0539 .03436 L
.05384 .03432 L
.05378 .03428 L
.05372 .03424 L
.05366 .03421 L
.0536 .03417 L
.05354 .03413 L
.05348 .0341 L
.05342 .03406 L
.05336 .03402 L
.0533 .03398 L
Mistroke
.05324 .03395 L
.05318 .03391 L
.05312 .03387 L
.05306 .03384 L
.053 .0338 L
.05294 .03376 L
.05288 .03373 L
.05282 .03369 L
.05276 .03365 L
.0527 .03361 L
.05264 .03358 L
.05258 .03354 L
.05252 .0335 L
.05246 .03347 L
.0524 .03343 L
.05234 .03339 L
.05228 .03336 L
.05222 .03332 L
.05216 .03328 L
.0521 .03324 L
.05204 .03321 L
.05198 .03317 L
.05192 .03313 L
.05186 .0331 L
.0518 .03306 L
.05174 .03302 L
.05168 .03299 L
.05162 .03295 L
.05156 .03291 L
.0515 .03288 L
.05145 .03284 L
.05139 .0328 L
.05133 .03276 L
.05127 .03273 L
.05121 .03269 L
.05115 .03265 L
.05109 .03262 L
.05103 .03258 L
.05097 .03254 L
.05091 .03251 L
.05085 .03247 L
.05079 .03243 L
.05074 .0324 L
.05068 .03236 L
.05062 .03232 L
.05056 .03229 L
.0505 .03225 L
.05044 .03221 L
.05038 .03218 L
.05032 .03214 L
Mistroke
.05026 .0321 L
.05021 .03207 L
.05015 .03203 L
.05009 .03199 L
.05003 .03195 L
.04997 .03192 L
.04991 .03188 L
.04985 .03184 L
.0498 .03181 L
.04974 .03177 L
.04968 .03173 L
.04962 .0317 L
.04956 .03166 L
.0495 .03162 L
.04944 .03159 L
.04939 .03155 L
.04933 .03151 L
.04927 .03148 L
.04921 .03144 L
.04915 .0314 L
.04909 .03137 L
.04904 .03133 L
.04898 .03129 L
.04892 .03126 L
.04886 .03122 L
.0488 .03118 L
.04874 .03115 L
.04869 .03111 L
.04863 .03108 L
.04857 .03104 L
.04851 .031 L
.04845 .03097 L
.0484 .03093 L
.04834 .03089 L
.04828 .03086 L
.04822 .03082 L
.04816 .03078 L
.04811 .03075 L
.04805 .03071 L
.04799 .03067 L
.04793 .03064 L
.04788 .0306 L
.04782 .03056 L
.04776 .03053 L
.0477 .03049 L
.04765 .03046 L
.04759 .03042 L
.04753 .03038 L
.04747 .03035 L
.04741 .03031 L
Mistroke
.04736 .03027 L
.0473 .03024 L
.04724 .0302 L
.04719 .03017 L
.04713 .03013 L
.04707 .03009 L
.04701 .03006 L
.04696 .03002 L
.0469 .02998 L
.04684 .02995 L
.04678 .02991 L
.04673 .02988 L
.04667 .02984 L
.04661 .0298 L
.04655 .02977 L
.0465 .02973 L
.04644 .0297 L
.04638 .02966 L
.04633 .02962 L
.04627 .02959 L
.04621 .02955 L
.04616 .02951 L
.0461 .02948 L
.04604 .02944 L
.04598 .02941 L
.04593 .02937 L
.04587 .02933 L
.04581 .0293 L
.04576 .02926 L
.0457 .02923 L
.04564 .02919 L
.04559 .02915 L
.04553 .02912 L
.04547 .02908 L
.04542 .02905 L
.04536 .02901 L
.0453 .02898 L
.04525 .02894 L
.04519 .0289 L
.04513 .02887 L
.04508 .02883 L
.04502 .0288 L
.04496 .02876 L
.04491 .02872 L
.04485 .02869 L
.0448 .02865 L
.04474 .02862 L
.04468 .02858 L
.04463 .02854 L
.04457 .02851 L
Mistroke
.04451 .02847 L
.04446 .02844 L
.0444 .0284 L
.04434 .02837 L
.04429 .02833 L
.04423 .02829 L
.04418 .02826 L
.04412 .02822 L
.04406 .02819 L
.04401 .02815 L
.04395 .02811 L
.0439 .02808 L
.04384 .02804 L
.04378 .02801 L
.04373 .02797 L
.04367 .02794 L
.04362 .0279 L
.04356 .02786 L
.0435 .02783 L
.04345 .02779 L
.04339 .02776 L
.04334 .02772 L
.04328 .02769 L
.04323 .02765 L
.04317 .02762 L
.04311 .02758 L
.04306 .02754 L
.043 .02751 L
.04295 .02747 L
.04289 .02744 L
.04284 .0274 L
.04278 .02737 L
.04273 .02733 L
.04267 .0273 L
.04261 .02726 L
.04256 .02722 L
.0425 .02719 L
.04245 .02715 L
.04239 .02712 L
.04234 .02708 L
.04228 .02705 L
.04223 .02701 L
.04217 .02698 L
.04212 .02694 L
.04206 .0269 L
.04201 .02687 L
.04195 .02683 L
.0419 .0268 L
.04184 .02676 L
.04179 .02673 L
Mistroke
.04173 .02669 L
.04168 .02666 L
.04162 .02662 L
.04157 .02659 L
.04151 .02655 L
.04146 .02652 L
.0414 .02648 L
.04135 .02644 L
.04129 .02641 L
.04124 .02637 L
.04118 .02634 L
.04113 .0263 L
.04107 .02627 L
.04102 .02623 L
.04096 .0262 L
.04091 .02616 L
.04085 .02613 L
.0408 .02609 L
.04074 .02606 L
.04069 .02602 L
.04063 .02598 L
.04058 .02595 L
.04053 .02591 L
.04047 .02588 L
.04042 .02584 L
.04036 .02581 L
.04031 .02577 L
.04025 .02574 L
.0402 .0257 L
.04014 .02567 L
.04009 .02563 L
.04004 .0256 L
.03998 .02556 L
.03993 .02553 L
.03987 .02549 L
.03982 .02546 L
.03976 .02542 L
.03971 .02539 L
.03966 .02535 L
.0396 .02531 L
.03955 .02528 L
.03949 .02524 L
.03944 .02521 L
.03938 .02517 L
.03933 .02514 L
.03928 .0251 L
.03922 .02507 L
.03917 .02503 L
.03911 .025 L
.03906 .02496 L
Mistroke
.03901 .02493 L
.03895 .02489 L
.0389 .02486 L
.03885 .02482 L
.03879 .02479 L
.03874 .02475 L
.03868 .02472 L
.03863 .02468 L
.03858 .02465 L
.03852 .02461 L
.03847 .02458 L
.03842 .02454 L
.03836 .02451 L
.03831 .02447 L
.03825 .02444 L
.0382 .0244 L
.03815 .02437 L
.03809 .02433 L
.03804 .0243 L
.03799 .02426 L
.03793 .02423 L
.03788 .02419 L
.03783 .02416 L
.03777 .02412 L
.03772 .02409 L
.03767 .02405 L
.03761 .02402 L
.03756 .02398 L
.03751 .02395 L
.03745 .02391 L
.0374 .02388 L
.03735 .02384 L
.03729 .02381 L
.03724 .02377 L
.03719 .02374 L
.03713 .0237 L
.03708 .02367 L
.03703 .02363 L
.03698 .0236 L
.03692 .02356 L
.03687 .02353 L
.03682 .02349 L
.03676 .02346 L
.03671 .02342 L
.03666 .02339 L
.0366 .02335 L
.03655 .02332 L
.0365 .02328 L
.03645 .02325 L
.03639 .02321 L
Mistroke
.03634 .02318 L
.03629 .02314 L
.03624 .02311 L
.03618 .02308 L
.03613 .02304 L
.03608 .02301 L
.03602 .02297 L
.03597 .02294 L
.03592 .0229 L
.03587 .02287 L
.03581 .02283 L
.03576 .0228 L
.03571 .02276 L
.03566 .02273 L
.0356 .02269 L
.03555 .02266 L
.0355 .02262 L
.03545 .02259 L
.03539 .02255 L
.03534 .02252 L
.03529 .02249 L
.03524 .02245 L
.03519 .02242 L
.03513 .02238 L
.03508 .02235 L
.03503 .02231 L
.03498 .02228 L
.03492 .02224 L
.03487 .02221 L
.03482 .02217 L
.03477 .02214 L
.03472 .02211 L
.03466 .02207 L
.03461 .02204 L
.03456 .022 L
.03451 .02197 L
.03446 .02193 L
.0344 .0219 L
.03435 .02186 L
.0343 .02183 L
.03425 .02179 L
.0342 .02176 L
.03414 .02173 L
.03409 .02169 L
.03404 .02166 L
.03399 .02162 L
.03394 .02159 L
.03389 .02155 L
.03383 .02152 L
.03378 .02148 L
Mistroke
.03373 .02145 L
.03368 .02142 L
.03363 .02138 L
.03358 .02135 L
.03352 .02131 L
.03347 .02128 L
.03342 .02124 L
.03337 .02121 L
.03332 .02117 L
.03327 .02114 L
.03321 .02111 L
.03316 .02107 L
.03311 .02104 L
.03306 .021 L
.03301 .02097 L
.03296 .02093 L
.03291 .0209 L
.03285 .02087 L
.0328 .02083 L
.03275 .0208 L
.0327 .02076 L
.03265 .02073 L
.0326 .0207 L
.03255 .02066 L
.0325 .02063 L
.03245 .02059 L
.03239 .02056 L
.03234 .02052 L
.03229 .02049 L
.03224 .02046 L
.03219 .02042 L
.03214 .02039 L
.03209 .02035 L
.03204 .02032 L
.03199 .02028 L
.03193 .02025 L
.03188 .02022 L
.03183 .02018 L
.03178 .02015 L
.03173 .02011 L
.03168 .02008 L
.03163 .02005 L
.03158 .02001 L
.03153 .01998 L
.03148 .01994 L
.03143 .01991 L
.03138 .01987 L
.03133 .01984 L
.03127 .01981 L
.03122 .01977 L
Mistroke
.03117 .01974 L
.03112 .0197 L
.03107 .01967 L
.03102 .01964 L
.03097 .0196 L
.03092 .01957 L
.03087 .01953 L
.03082 .0195 L
.03077 .01947 L
.03072 .01943 L
.03067 .0194 L
.03062 .01936 L
.03057 .01933 L
.03052 .0193 L
.03047 .01926 L
.03042 .01923 L
.03037 .01919 L
.03032 .01916 L
.03027 .01913 L
.03022 .01909 L
.03017 .01906 L
.03012 .01902 L
.03006 .01899 L
.03001 .01896 L
.02996 .01892 L
.02991 .01889 L
.02986 .01885 L
.02981 .01882 L
.02976 .01879 L
.02971 .01875 L
.02966 .01872 L
.02961 .01869 L
.02956 .01865 L
.02951 .01862 L
.02946 .01858 L
.02941 .01855 L
.02936 .01852 L
.02931 .01848 L
.02927 .01845 L
.02922 .01842 L
.02917 .01838 L
.02912 .01835 L
.02907 .01831 L
.02902 .01828 L
.02897 .01825 L
.02892 .01821 L
.02887 .01818 L
.02882 .01815 L
.02877 .01811 L
.02872 .01808 L
Mistroke
.02867 .01804 L
.02862 .01801 L
.02857 .01798 L
.02852 .01794 L
.02847 .01791 L
.02842 .01788 L
.02837 .01784 L
.02832 .01781 L
.02827 .01778 L
.02822 .01774 L
.02817 .01771 L
.02812 .01768 L
.02808 .01764 L
.02803 .01761 L
.02798 .01757 L
.02793 .01754 L
.02788 .01751 L
.02783 .01747 L
.02778 .01744 L
.02773 .01741 L
.02768 .01737 L
.02763 .01734 L
.02758 .01731 L
.02753 .01727 L
.02748 .01724 L
.02744 .01721 L
.02739 .01717 L
.02734 .01714 L
.02729 .01711 L
.02724 .01707 L
.02719 .01704 L
.02714 .017 L
.02709 .01697 L
.02704 .01694 L
.02699 .0169 L
.02695 .01687 L
.0269 .01684 L
.02685 .0168 L
.0268 .01677 L
.02675 .01674 L
.0267 .0167 L
.02665 .01667 L
.0266 .01664 L
.02656 .0166 L
.02651 .01657 L
.02646 .01654 L
.02641 .0165 L
.02636 .01647 L
.02631 .01644 L
.02626 .0164 L
Mistroke
.02621 .01637 L
.02617 .01634 L
.02612 .0163 L
.02607 .01627 L
.02602 .01624 L
.02597 .0162 L
.02592 .01617 L
.02587 .01614 L
.02583 .0161 L
.02578 .01607 L
.02573 .01604 L
.02568 .01601 L
.02563 .01597 L
.02558 .01594 L
.02554 .01591 L
.02549 .01587 L
.02544 .01584 L
.02539 .01581 L
.02534 .01577 L
.02529 .01574 L
.02525 .01571 L
.0252 .01567 L
.02515 .01564 L
.0251 .01561 L
.02505 .01557 L
.02501 .01554 L
.02496 .01551 L
.02491 .01548 L
.02486 .01544 L
.02481 .01541 L
.02477 .01538 L
.02472 .01534 L
.02467 .01531 L
.02462 .01528 L
.02457 .01524 L
.02453 .01521 L
.02448 .01518 L
.02443 .01514 L
.02438 .01511 L
.02433 .01508 L
.02429 .01505 L
.02424 .01501 L
.02419 .01498 L
.02414 .01495 L
.0241 .01491 L
.02405 .01488 L
.024 .01485 L
.02395 .01481 L
.0239 .01478 L
.02386 .01475 L
Mistroke
.02381 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],

Cell["\<\
Keeping 10% of the total coefficients will give an error of \
9%.\
\>", "MathCaption",
  CellTags->{"S2.2.2", "2.11"}],

Cell[CellGroupData[{

Cell["Sqrt[1-ct2E[[4608]]]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S2.2.2"],

Cell[BoxData[
    \(0.0899546015766334505`\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"S2.2.2"]
}, Open  ]],

Cell["We do the inverse transform on the compressed data.", "MathCaption",
  CellTags->{"S2.2.2", "2.12"}],

Cell["\<\
InverseCosTransform[Compress[ct2, 4608],
Taper -> {{Polynomial[2], 24}, {Polynomial[2], 30}}];\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S2.2.2"],

Cell["\<\
This is the reconstructed image. Again it resembles the original \
very well.\
\>", "MathCaption",
  CellTags->{"S2.2.2", "2.13"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[%, Mesh -> False]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S2.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00500801 0.0192308 0.00400641 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.14443 -0.0125 -6 -9 ]
[.14443 -0.0125 6 0 ]
[.26963 -0.0125 -6 -9 ]
[.26963 -0.0125 6 0 ]
[.39483 -0.0125 -6 -9 ]
[.39483 -0.0125 6 0 ]
[.52003 -0.0125 -9 -9 ]
[.52003 -0.0125 9 0 ]
[.64523 -0.0125 -9 -9 ]
[.64523 -0.0125 9 0 ]
[.77043 -0.0125 -9 -9 ]
[.77043 -0.0125 9 0 ]
[.89563 -0.0125 -9 -9 ]
[.89563 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21955 -12 -4.5 ]
[-0.0125 .21955 0 4.5 ]
[-0.0125 .41987 -18 -4.5 ]
[-0.0125 .41987 0 4.5 ]
[-0.0125 .62019 -18 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .82051 -18 -4.5 ]
[-0.0125 .82051 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.14443 0 m
.14443 .00625 L
s
[(25)] .14443 -0.0125 0 1 Mshowa
.26963 0 m
.26963 .00625 L
s
[(50)] .26963 -0.0125 0 1 Mshowa
.39483 0 m
.39483 .00625 L
s
[(75)] .39483 -0.0125 0 1 Mshowa
.52003 0 m
.52003 .00625 L
s
[(100)] .52003 -0.0125 0 1 Mshowa
.64523 0 m
.64523 .00625 L
s
[(125)] .64523 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(150)] .77043 -0.0125 0 1 Mshowa
.89563 0 m
.89563 .00625 L
s
[(175)] .89563 -0.0125 0 1 Mshowa
.125 Mabswid
.04427 0 m
.04427 .00375 L
s
.06931 0 m
.06931 .00375 L
s
.09435 0 m
.09435 .00375 L
s
.11939 0 m
.11939 .00375 L
s
.16947 0 m
.16947 .00375 L
s
.19451 0 m
.19451 .00375 L
s
.21955 0 m
.21955 .00375 L
s
.24459 0 m
.24459 .00375 L
s
.29467 0 m
.29467 .00375 L
s
.31971 0 m
.31971 .00375 L
s
.34475 0 m
.34475 .00375 L
s
.36979 0 m
.36979 .00375 L
s
.41987 0 m
.41987 .00375 L
s
.44491 0 m
.44491 .00375 L
s
.46995 0 m
.46995 .00375 L
s
.49499 0 m
.49499 .00375 L
s
.54507 0 m
.54507 .00375 L
s
.57011 0 m
.57011 .00375 L
s
.59515 0 m
.59515 .00375 L
s
.62019 0 m
.62019 .00375 L
s
.67027 0 m
.67027 .00375 L
s
.69531 0 m
.69531 .00375 L
s
.72035 0 m
.72035 .00375 L
s
.74539 0 m
.74539 .00375 L
s
.79547 0 m
.79547 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.84555 0 m
.84555 .00375 L
s
.87059 0 m
.87059 .00375 L
s
.92067 0 m
.92067 .00375 L
s
.94571 0 m
.94571 .00375 L
s
.97075 0 m
.97075 .00375 L
s
.99579 0 m
.99579 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21955 m
.00625 .21955 L
s
[(50)] -0.0125 .21955 1 0 Mshowa
0 .41987 m
.00625 .41987 L
s
[(100)] -0.0125 .41987 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(150)] -0.0125 .62019 1 0 Mshowa
0 .82051 m
.00625 .82051 L
s
[(200)] -0.0125 .82051 1 0 Mshowa
.125 Mabswid
0 .05929 m
.00375 .05929 L
s
0 .09936 m
.00375 .09936 L
s
0 .13942 m
.00375 .13942 L
s
0 .17949 m
.00375 .17949 L
s
0 .25962 m
.00375 .25962 L
s
0 .29968 m
.00375 .29968 L
s
0 .33974 m
.00375 .33974 L
s
0 .37981 m
.00375 .37981 L
s
0 .45994 m
.00375 .45994 L
s
0 .5 m
.00375 .5 L
s
0 .54006 m
.00375 .54006 L
s
0 .58013 m
.00375 .58013 L
s
0 .66026 m
.00375 .66026 L
s
0 .70032 m
.00375 .70032 L
s
0 .74038 m
.00375 .74038 L
s
0 .78045 m
.00375 .78045 L
s
0 .86058 m
.00375 .86058 L
s
0 .90064 m
.00375 .90064 L
s
0 .94071 m
.00375 .94071 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.14443 .99375 m
.14443 1 L
s
.26963 .99375 m
.26963 1 L
s
.39483 .99375 m
.39483 1 L
s
.52003 .99375 m
.52003 1 L
s
.64523 .99375 m
.64523 1 L
s
.77043 .99375 m
.77043 1 L
s
.89563 .99375 m
.89563 1 L
s
.125 Mabswid
.04427 .99625 m
.04427 1 L
s
.06931 .99625 m
.06931 1 L
s
.09435 .99625 m
.09435 1 L
s
.11939 .99625 m
.11939 1 L
s
.16947 .99625 m
.16947 1 L
s
.19451 .99625 m
.19451 1 L
s
.21955 .99625 m
.21955 1 L
s
.24459 .99625 m
.24459 1 L
s
.29467 .99625 m
.29467 1 L
s
.31971 .99625 m
.31971 1 L
s
.34475 .99625 m
.34475 1 L
s
.36979 .99625 m
.36979 1 L
s
.41987 .99625 m
.41987 1 L
s
.44491 .99625 m
.44491 1 L
s
.46995 .99625 m
.46995 1 L
s
.49499 .99625 m
.49499 1 L
s
.54507 .99625 m
.54507 1 L
s
.57011 .99625 m
.57011 1 L
s
.59515 .99625 m
.59515 1 L
s
.62019 .99625 m
.62019 1 L
s
.67027 .99625 m
.67027 1 L
s
.69531 .99625 m
.69531 1 L
s
.72035 .99625 m
.72035 1 L
s
.74539 .99625 m
.74539 1 L
s
.79547 .99625 m
.79547 1 L
s
.82051 .99625 m
.82051 1 L
s
.84555 .99625 m
.84555 1 L
s
.87059 .99625 m
.87059 1 L
s
.92067 .99625 m
.92067 1 L
s
.94571 .99625 m
.94571 1 L
s
.97075 .99625 m
.97075 1 L
s
.99579 .99625 m
.99579 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21955 m
1 .21955 L
s
.99375 .41987 m
1 .41987 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .82051 m
1 .82051 L
s
.125 Mabswid
.99625 .05929 m
1 .05929 L
s
.99625 .09936 m
1 .09936 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .29968 m
1 .29968 L
s
.99625 .33974 m
1 .33974 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .45994 m
1 .45994 L
s
.99625 .5 m
1 .5 L
s
.99625 .54006 m
1 .54006 L
s
.99625 .58013 m
1 .58013 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .70032 m
1 .70032 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .78045 m
1 .78045 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .90064 m
1 .90064 L
s
.99625 .94071 m
1 .94071 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
192 string
192 240 8 [192 0 0 240 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EAE7DEDEE4DBD8DFE2E5E6E9EBE8E9E2DADDDCE1E6E1DCDC
E0E1E2E3DDE3E5DBDBE2E0D4D8E2D9D3D5D6D2D4E4E8E3E0
D8D6D8D1C9CBD1D5DCD8CACDD3D3D7D7D1D3DDE6E6DDD4D1
CCC9D1D6D0C8C8D0D7D9D9DCE0E1D7CDCCCCD3DDD2C4CFDD
DEDDDCDEE0DAD6DCDFD6D0D3D8D7D4D1D1D7E1E2E0E0DDD8
D0C7C7D0D9DCD9D5D2D4D9DDDBDADEDCDBDED7D0D6DEDDE2
E3DEE4E4D8D6E1E3DFDDDDE2E3DFD7D9E8E6DDD9DDE4E2EF
F2E9EEF3E8D2D2DCD7E2F4F2F0F1E5DCDADFE9E4E4E3DEE6
E2DBD7DEE9E3DAE0E5E7E8E5E1DFE3DDD7DDE0E5E7DDD4D7
E1E3E1DFD9E2E8DDD6DBDCD5D9E4DFD6D4D4CFCDDAE2E1DC
CFCCD2CEC6C7CDD7E7E4CECCD4D6DBE0DBD9DFE2E4DDD3D5
DDDEDBD7CFCBD1D7DCE1DFD4D3DADAD7D4CACDDDD5C5CCD5
D9E1E0D9D4C9C7D6DED9D3D3D6D7D2D0D4DEE1D5CED1CCC6
C4C0C3D1DAD8CEC9CCD4DDE2D8D2DBDCD9DDDBD7D7D6D3D5
DFE6E9EADDD5E2E3D9D7DAE3EAE2D3D5E9EEE8E1DDE2E6EE
F3E7E2E7DBCFD6D8D8E6F3ECE1E5E3DADDE4E6DFDEE4E3E2
DDD7D6DFEBE9DCDDE6ECEDE4DCD8D8D6DBE5E9EBE7DAD3DB
E8E8DFDAD5DCE1DBD6DAE1DEDBDFE0DED8D1CCC9CED2D4D3
CCCCD2D4CFCBD0DEEAE0CCC9CED0D7E0E3E0DCDDE1DCD3D5
DADDDDD3C8C9D1D0D3DAD1C3C6D2D7D8D6CED1DCD8D0D2D0
CED3D5D4CDC2C4D1D9DDDBD2CDD1D1CDD4DDD9CBC5C8C5BE
BDC0C4CCCFCBC7C7CFD8DFE1DBDAE0DED7D8E0E0D6CDCACB
D7E1E2E7DFD8DFDBCFD1D7DEE6DBCBD3E9F7F7E9D8DAE9EF
F0E2D3D5D2D9E6E2E0E8EBDDCFD8E4E0E2E7E5E4E5EAE5DE
DDD9D9DFECF1E6E3EAF4F1E5E1DAD4D5E0E9E7E5E0D6D5DF
EAE7DDDBDBDBDADADADEE9EADCD6DCE3D9CDCFD2D3D1D0D1
D2D7DADDDCD2D2DDDED5CFD2D5D3CECFD6D7D4D9DBD0C9CD
CFD3D7CCC1C7CDCACED4C9C2CBD0CDCDCFD4DBDCD4CFCDCC
CDCDCDD1CCC4C7CDD4DEE3D8CCD1D3CBCDD1CFD1D2D1CAB9
B1B7BEC1C3C8D2D6D5D7DBD7CFD0D5D8CEC8D4D7CFCECCCD
D5D6D6DADEE3E5DED3D2DBDBE1D9CCD5DFF1FBECD6D4E9EC
E4DFD3CFD6E0E8E9E5E9E7D8D0DBEBEAE6E6E3E7EAEAE1DA
E3E0DEE1ECF8F4EDECEFE6DEE4E1D9DCE8EBE3E0E0DDDFE0
E1DEDADFE3DDD7DDE1E0EBECD8CDD9E4DCD3D8DDDDD9D4D3
D8DAD5D7DCDADAD9D0CCD1D7DFDED0C7C8C1C0CBCCC2C1C6
C5C7CCCFD6E3E4DDDCDBD0CFD7D2C7C7CDD6DBD6CBC5C5CB
D4D6D1D1CFCCCED0D4DDE0D9D1D7DDD4C8BDBAC1C2BAAC98
90979C9DA2B5CCD0C9CBD6D1C0BCC3CDC8C0CBD0D2DCD7D5
D7D0CCCBD3E0DEDFE0E2E6DDDFDED6D9D5DFEFEBDBD6E7E3
D5DFDDD7E1E2E0E4E3E6E9E3E1E6EEEEE8E3DEE1E5E7E0DD
E6E6E6E6E9F4FAF5EDE2D7D7E4E7E0E1EBECE4E3E6E7E6DE
D7D7DBE3E6DEDAE3E4DAE0E4D6CFDBE3DBD7DBE0E5E5D9D0
D2D5D0D0D9DDD6C3B8C5D1D2D6D3C4C2C5BBBDCBCAC7CDD0
CBC3BFCBDEE5E1DCD9D6D1D0D3CFC9D0DBDCD7D4CDC8C8CA
D4DCD5CECFD3D3D0D2D4CCC6CAD4D8CDB7A398979083746C
7279766F738AA2A5A4B1C7D0C6C1C5C7C5C3C6C9CED7D2CF
D2CFCBC9D0D2CCD3E6EFE8DFE1E0D9D6D5D7E2E9DFD8E1DA
D2E1E0D9E4E9E3DDDCDDE3ECECEEF0EBE8E2DDDEE0E3E0E0
E5EAEDEAE3E8F5F9EED9D3D9E2E6DFDBE2E7E5E4E7E7E1D9
D5D8E0E5E1D9DCE5DFD3D6DFDEDEE3E1DBD5D4D9E4E7D8C6
C5D0D0C8C7C5B29698BBD0CAC1B6ACB8C6C1C3C9C4C2CACF
D0CAC2C9D3CBC4C4C3C2C3C5CCCDCCD3DCD3C7CBCFCFCDC8
CDD8D3C7C7D2D4CDCBC8B8B3BFC7C0AD9B918B85796C666C
797D7569647079767A899FB9C7CDCCC0C0C5BFB7ABA4A7B1
C0CCD1D9E0D7C9C9DFECDCDBE8E4D4D1DEDCDBE3DED8D8D7
DBE1DAD3DFF1EED9D5D5D9E9E7EBF1EAE8E6E4E4E4E5E1E0
E6F0F0E9DFDAE6F0E3D2D3DADDE0DBD4D7E1E5E4E6E3DAD8
DADEE5E6DCD4DADFD7D2D8E0E6E6E1DFDFD8D0D3D8D8CEBE
C0D0CDB6A89F897684ACC2B59F8F8DA4BABBB6B0A5A2ADBC
C9CFD1D4CDBEB5B2B2B8BFC9D6D4C8C5C6BEB7BFCBD1D2CD
CED6D4C9C3CBD1CAC4C1B9BBC5C4B39D959CA09B8D85888E
8E8D8C877E7B776F6E6C7289A2B1B4AEB7C4C2B190777B8E
A1B3C6D6E1E0D6CDDAE2D1D4EBEAD3D2E7E1D6D9DEDED7DD
E0DBD6D1DDF2ECD6D2D7DBDFDADFEAECE6E6E8E7ECEAE4E4
EBF3ECE4DCD3DDE3D6CED3D9DBE1E0D4D2DCE0E1E6E3D8DB
E0E0E4E6DDD5DADAD3D8DBDBDFDBD1D5DFD9D2D6CFC3BDB8
C1D2CCAE998C7A7991AFB69E7B646887A7AF9F8878788FAF
C0C7CBC9BFB8B2AAAFC1CBD4DED1BCB5B9BEC1C6D1DCDED5
CDCDD5D6CCC9C9BDB7BCC6D0CCC2B7A7A5B0AFA293949E96
807A869397968E8883746B71797E858EA0B7C7C1A68C8489
898998A6B5CFDAD7E0E2D2D0E4EAD7D4E5E2D5D4DDE1DDE6
E0D1D4D4DFEDE3D7D4DEE5DDD9D7DEEAE1E0E4E4EEEAE4E7
ECEDE3DFDCDAE2E1D6D4D8DADDE7E6D7D2D6D7D9E3E2D9DD
DFDBDEE2DDD6D8D6D4DCD7CDCCC6C1CBD8D3CFD4C5B1AFB8
C4CDC4A78F827A8DB3C3B28E6852597A9EA78A66576388AF
B8ACA4A1A5B2B3A7B0C6CBCBD1C8BABAC4CFD3CECDD3D3C3
B2B2C4D0CAC0B5A7A4B2C8CCB4A8AFABA6A6967D707C8874
5248556D8693919095918B897E6F6B717C92AAB9BFBAB1A6
92776F7482AAC8D1E0E4D6CED3DED9D2DDE1DBDADAD8E0EA
DFCFD3D8DFE9E2DCDAE0E7E2E1D9D6E2DEDBE1E5EBE6DEE1
E2DFD9DEDFE6EDE6DFDFE0DDDDE7E2D5D5D6D5D6DFDFD6DA
D8D4D7DAD8D1CECDD2DBD3C6C1B9B9C6D4CFC6C3B19EA4B9
C4BFB2977B707596C4CAA47F6B5D5E7592998267647897AD
A68E808395A8A6989EB1B5B4BDC3C0C1CBD0C6B29E979A96
919BA9ACA69C959197A6B1A37F778E958D846E56505E6652
362A2C3C586F717084959BA09A897D72696E75859DAFBBBB
AF957D7B8294A6AFC5D4D3CDC6CED8D6D9E3E5E3D2CCDDE6
DED3D6DEDFE8E4DCDFE1E1E1E2D8D3DCDEDADEE8EBE6DCD9
D3CED1DDE1EBF1E9E5E6E6DDDBE2D8D1DADDDDDADDDAD0D2
D1D2D7D9DAD2CBCAD0DAD6D1CAB8B2BBCBCCBBA7908393B2
BEAFA08869627094BDBC947B7A726770828B81777D8A9492
83757580919A8D7E7E8A929AA6B0B1B0B4AC95806C636D77
809091857B767B868F928C7659586E79766D615A5A5D5D53
443937384253524B5D737E8A959FA0928073645C617693A9
B8B6A7A7A999878491AAC5CFC7C5D2DCDAE1EBE3CBC7DCE5
DFD8DBE1E0E4DED8E4E5D9D7D9D4D8DDDEDCDCE7ECE7DFD6
CDCCD4DDE0E8EEE9E8EAE6D9D7DDD2CFDCE3E4DFDDD8CFCF
D0D7DDDDE1DBD2CFCFD2D1D6CEAF9DA2B8C1AC8C6E6982A9
BAA9957A5C5B7397B0A5847375746F7580837A7880838074
65687A868B877768646773848E8F8E8E8E7E676368696D6B
6B73706766687080867F736961636D757C7D7B7E7D767371
68636561555450454D57585C6B8BA4ABA99E8F72575C6D82
9CABACB1BDA982706578AECECFC4C9D9D2D7E9DEC7C5DDEE
E6DDD8D8DFE1DBDAE5E4D1CED6D9E0E1DBDCDDE5EAE5E0D7
D7D9DEE5E3E5E7E1E7ECE5D7D4DBD3D2DFE7E9E1DEDCD4D3
D4DCDFDBE0DCD6D1C7BFBDC8C19F8A90A8B4A17E616381A6
B8A99070555D80A2A790735D565F717F82796D7077706962
5C6E8A8D7E72655B595C6C7F7F70696D71675B6475766851
4A54595C64696B767E7A74767A7A797F919A9898938C8E8D
83808A8C796965626462564441597993A5ADB39C7D7B746A
727D828BA9AF9A89696291BAC2BECAD6C4BDCED2C9C5DBF0
E8DFD1CEE0E3E0E2E3DCCFCFD9DFE3E0DCE0E3E3E3E3E3DC
DFDFE2EAE6E5DFD7E4ECE8DBD5DDDADAE4EBEBE0DDE0DBD7
D7DCDAD2D6D6D7D1BDAEAFBDB89B8C92A5AE9C7E666E8CA9
B4A4896B576891ACA0806344364E768A8371656968584F54
5E7790886F615C59595F6D79725E5358636562696E644C37
3B5462646869646670787C7F7D7873768892908F8D8A8B87
7D7E8F9C9382808689847054403B475A6A7C969C99A49974
5F5B575D7E9EAFB296777B8E93A7D1DEC09C98B6C8CBD8E0
DDDCD0D4E6E9E7E4DED7D7DAD8DCE0DEE2E8E9DFD6E1E7DF
DDDCDBE2E4E3DFDAE3E8E7E0D8DFE1DFE3E8E9DEDCE4E0D9
D5DCDACFD0D4D7C9AAA0AFC3BA9D9298A9AF9A7B677597B1
B19779615A749BA9927256372E4D7A8B7E6960615C50515D
6873786C5A545A5D5F666C6C655A52576266636461554740
4C6269615C5D5B595E6A7370686465666A696972746D655F
5F687A8A887F85909490877D6A514341414B647B8BA4AA8B
70655449536E95B1B19A7E6C607FBEDEC88D6E92BFD4D7D1
D1D7D8DFE5E8EAE4DDDBE3E2D3D4DDDEE4F0EED9CDDDE7DF
DFDFD7D9E1E1E6E9E5DEDFDFD9DEE1DCD8DDE4DCDBE4E0D4
CFD9DCD0CED6D6B68D90B7CFBC988990A3A98F6D5B709CB7
AD8665585E799598836C59464761797D6E5F595550566673
73655550515762686A706E625C5A5558605E5A5C5C5B5F60
6061584B464D575653575A564F515A5D54484D5F665A4C4B
556169695F5E6B78797680919179645A534C4F5860728688
8A8E7E5E4440587B9BAB9D78585E89BDCA9D747EADD4D9D5
CFCEDDE0D8DDE6E7E1E4EBDFD0D4E1E2E0F2F2D7D3DDE4E2
E6E5D8DAE5E2E9F0E2D6DAE0D9D8DEDBD3D7E1DBD6DCD9CD
C6D0D4C5C3D5D6A7788ABCCEB0897A8499987858506E9EB7
A4785C5D6D7F8986786C635B66777B72665E584E495A7380
755B484E5F6C76736E70695C5A5B575758575B62646A7270
6353484545484F4F4A474545474B514F433D4B636E6B676C
75776F5E4B48535B574F5B7788827877756753453D3C4861
85A6AC9064453E496C9CB3A381645C86B4B39A8899BCD3E1
D2C3D9DDCED1DDE6E6EDF0DBD2DCE7E6DDEDEED9DFE3E2E5
E9E2D5E0EAE0E0E6DCD4DFE7DAD2DBDED8DAE1DAD2D4D5CD
C4C7C4B1B2D0D5A17591BDBB987D7887988A644F5779A0AB
91695969808680766A625E61717F7A6D645F5D555160777F
735E5664768080756C6E696467625855555C6C726B6A6C64
56494A57564940414545444C555751453B4159717B808C99
978A7C6D6058595A53444050636A6F757D7D664F493E343D
5E87A4A88F7A63444A729CB8B58E5C5787B0B9A7898BB7E0
D6BFD2DECFCDD6DEE3ECEDDCDBE5E7E2DCE4E4DCE6E9DDDE
E6D9CEE1E9DDD8DCD9D6E3EBDBD0D9E2DDD9DBD9D3D2D5D2
C7BEB3A0A6CACD99789ABBA7857A81929D86615B6E87978E
715859738A877562524F566272786D5F5653595E5D62696A
65656F8087837A7070797975726251535C68746C5953534E
484856665E4639404C50525E696A6150444E687C7B788798
95867A7A7D786F6D6A5E4D4B545A5D5E6B7F786D746E5642
3E4A678A99A89E684A4F699DC4B57B4D5C8EB7BF865C8BCB
D9C9CFDCD2D1D8DADFE4E3DDE3EAE0D6D9E0E1E2E7E7D6D5
E1D2CCDFE8DED8DEDBD8E3E9DFD4D9E2DCD1CFD6D6D1D1D1
C6B3A196A6C8C28D779DB89E7E7C869397826A6F8691886F
5653647C8A81694E3D44586A6F6551454143505F5F574F4C
54667B8985766E6F767C746D6B5F555C6A6E654E3C3D4546
444958615645424B505055636B6B675B50556A7D77635F6E
77726B717F80737078776C6666665B4D51667076898D7962
48323A587BA4B092715B4F669FB5966B516093BC985869AB
D1D4D3D6D2D5DADADFE2DDDAE2E5DBD0D6E2E4E5E5E1D5D6
D9D0D4E2EAE1DCE2DCD9E0E4E1D8D8E0DCCEC9D6D8CAC5C9
C3AB918BA5C7BA867698AE967B7C868D89786D7B93957C5D
4F5C74818175634B3F4E68766C503831363D4A58584A3E3F
4F637379736B6C73756A58535F6766686C624E3C36404C4D
4748505049485053483F485659575A5C5A5B6777765B454B
5D615958626559596971757B7E8071594D4D5867787C7276
70554441527087999B8C614065909B986A4364A4B27C638B
B9D4D7D1D3D7D8DBE4E8DED8D9DBDDD5D5E1E2E0E1DDDADC
D5D4E1E9E9E2DEE0DBD7DADDDFD9D7E0E0D2CCDAD9C1B8C0
C4AB857D9EC3B485788E9C87727885877B6D6C7B93917257
556B7E7D7168655C5764777A634433374348484B493E3841
4F5A616469707775695444485E706F64594C44484F535651
4847494643454B4B403942515452596873746F7273645151
5E5F544D4E4B434856595C6A798786766453515C625A5470
897E664B3F3C4B769EAF864A48668CAD8E4C4889BBA07170
98CAD7CFD4D5D8DEE6E5DCDCD3D7E3DBD6D9DDDEDDDADADB
DADCE9ECE4E2E1DFDCD7D5D7DBD9DAE2DFD0CAD9D6BCAEB5
C1AD817395BCAD8377858B776671817F6C636B798D856455
62798073605C69717175766B513F4454605A473F3F3A3A43
484B50576577796A584B4B57646B665646414C61685C5048
43474A443E38373F484B525F696B6F7E8F8E7D716F6E6D70
706861605E534E575B4D3C40546C7D7D76695E6363524459
767E786A5538314979A59E7A5952719EA6704B71A4AC8763
75B3D0D2D4CFD7E1E3D9D7E1D6DAE5DDD9D3DBE2DBD9D9DA
DFE0E8E8E2E1E2E0DDD9D5D7D8D5DAE0D5C3BFCECEB7A6A8
BAB0847291B5A47C74828974616C7B75605F6E7C88785758
73867E6855586F8081786959494C6373715C433E4846403E
383C49525E6D6B5E5658646B6357514A4448586C6C553F37
3C4A4F443A3333496369666D7D8077788483736662646D74
6D6265707064616C6E5C3D2E384B5D687174717578664C46
505A6E8380604238507B979D7B55557BA897675F7FA9A167
568FC4D6D3C5CCDDDED3D8E4DBDDE3E1DFD6DFE6DFDDDDE0
DFDFE6E2E1DDDBDFDBDBD9DAD8CED6D7C4B3B1C0C1AC999A
B5B58A748FB3A279748B9A85696B736D5E677A81846E5564
848C78625B687F887F6B585153677E7F6A503F4656524134
2D3B515552575C5E61646B6A5644434C52545862604C3831
3C50554A46484F63757061667977605257595351504C4D51
4D49515E605958636E6C5C483F3F434E5D6B7581897A5E4B
413E547C92896D5045517596926A465990AC9260609BB07D
506DAECDCCBFBED3D8D7E0E0DEE1E4E7E0DCE2E7E6E2E5E9
DEDEE4DCDCD3CDD8D6D7D9DCD9CDD3CCB2A2A3B5B59D868C
B1B68E7893B7A77A7599BAA67C6C6A68677687847A655C76
8F8B71636C8190856E584D546479816E5242414F594E3B30
3248605B4A495867695F58544A444C5B62584D4F544E4642
48565C5B636C6D6D6753455168684E3D4147484C4F49403E
414648474545424451616D6450423F4649505D707F776E63
5645405B7A92958062485072928452466AA7B8794F7AAA9A
6D5D88B2C1C5BBC4D0DCE5D9DDE3E8EBE0DFE1E4E8E5EAEB
E2DEE0D9D7CEC4D0D3D3D5DBDBD2D5C5A39195ABAD90747E
A9B08C7D99BBA9766E9FD2C48E6B5F6672838B7C675B698C
98886C62738A8F765B505363737A6E513C3C47514E413738
4155655C4B4C5D6A6553484B53575C636252424551575B5E
5C5A5C6572766D5F4F3E3A4C6770625458626460605C524E
5A655E4F4A4A413436475A5D504A565D4E4243515F637277
72634845507497998B64434E7B91774F4C8BBE99525491AF
98605D92BDD1BDB0C4E0E8D5D4DFE9EDE7E1DADDE2E8EDE9
E4DFDCDAD7CEC5CED5D6D7DBDBD5D4BF9B888BA2A7876875
A0A6898098B39E6B659AD0C38B645C6F818A856D56577DA2
9E81655E71858266525A6974766F5C453B3F4749413B404A
5156595552575F5E564F4D58696D62584F443F49565E676F
6757515A605C54504F5257616F7C7C716F78796D64615957
68787366666655403B424749485675826F5F5549444C6574
7877684E394A6C829786543F5782936E4C69A1A666416FB1
B8704175BED7B99BB0DCE8D3CBDAE6EBEDE0D6D8DDE9E8E1
DEE0DEDFDCCEC9D2DADCDDDCD8D0CBB89B8B8C9EA07D6274
9B9F877F8D9E8C676A98BEA6735C6684948D7B614F5F90AC
95715B5D7280765A51687B786A5F57524D433D3B393E4A56
59524B4C5358534848535A6373735A42363744545C5F6468
604D4548453E415064777C7165676E696163655C534F4744
516366656E71625352565148485976807D8383623F404E5C
627387704E4243578095774E425E8A8C68587999824D519E
C3893F58B1CFB4929CCADED4CEDCE2E1E3DBDADBE1E7DAD6
D6DCE1E7E0CBCAD7DCDCDCD6CEC9C2B1998B8E9E9A776376
9799847A81897C6B7CA3B18B5E59769BA48F765F556C98A3
7F5F58677D816F53506D7D6D58545C645C4335373C40454E
565349484C4B433C485B5D5963644D3328334C5D5C565150
4E464445413F485A6E807F66483E4A534D47494C4D4C443B
3C44494A50575551576162574D5257505A79937D564F4744
435B8B8E80644342608F9571483D64958E5F577A97724679
B4A1514492BAB4948DB1CCD7D3DCDFD4D5D9DEDBE4E5D3D2
D9D8E2EFE4CBCBDADFD9D5C9C5CCC6AE8F7D869C98776779
929381777B7E716C8AAFB2875D5F84A9AB8F7362627A958D
6A5B687F8A7F6953536C77655558636759403B484B41373F
555D514744434449596559474C5143312936525F55463C3C
444B4E5253565B5E636762533F36475D5E52515B63625C51
464341362B303D424552615F56564E37375175837E7C6546
34426C8A9B8760464572948D63354285A67948599898534F
90AC6F456FA1B79F8A97B9DCD4D4DCD3DCE4DDD6E4ECE1DC
E4DAE3F2E4CECCDDE5DDD0BEC0D2CDAA7E66749494776C7E
9697827477786B6C8EB0B08B65688DADA7836763748B9178
5F6784968C75645B5C6B7168666A645647404D6058413440
5B635241414C5A626968544041463E352E364D574B3A333D
4F5A59585A5E5C544E48444A5257677B7D706D7576716E69
5F5B59462A27383F3B4252565763675442404F6D8E9B8D66
49404460818B7D5637447395854D34619C9450417DA06D38
67A98E57568AB8B3917DA2D9D8CED7DBECF1DDD7E8F8F0E7
EAE1E3ECE2D2CDDDE9E7D1B6BACECBA37258688B91797188
A6A98A6F70736D7794A79F82666D93AB986D5665889E8C66
5A74969D836862636164686B76775D413B485B6555424050
615D473D4A606F6D645C4D4345453E39322F3C47453D4052
666B5E524D4C4A4847433F4E647179817D706C716C626266
676D776E52444C524E4B4B45475D7277644C3F486C838E83
755E3C384D748971452A51889B743A3A759B683A558D843C
4A9CA96F4C76ACC39B6A8BC9E1D1D0E1F1F4E1E2F3FBEEE4
E6E5E0E2E1D7CED9E7EACAA9ADBEBF9E755D698A9582778F
B3B9936C69727C8FA09B8670647295A0825A4F709CA67F56
5A7B96937765686A60595C677670513B44595E554746535E
5D5144485B6E6E5F534D4A4C504D433E372B2E3F4E515767
726E5D4E464449535C5B54576167696960524D524F48484F
535D717B6F5F5B656B66584338445A73715E4A3B444D647E
918254302B56838D7242486A938F502A49867D443B769151
3D88B7854E6292C2A76B7BB2E3D3C5DFE9EEE3E9F7F3E2DD
E0E4E0DFE2DAD0D5E2DEB8999BAEB39C7E6B758F998A7889
AEB99268647690A8A89071636B7F958E6D535881A69E6E53
6882887B6E6E736F60575A646A604C46586556444555625C
4D4B53606A6B5A49484C5156595449433E31334963686565
615B5657585C646E7471655A535050525047424547434040
3E3E4A5B605854606D6F685841353D5560615E5648353C5B
82886944314270969E7C584E73917238306187653C628A64
4175B39254557CB1B67F6C99D6D1BED4DFE6E3E8F0E7DCDC
DDE6E5E7E4D8CFD2DECCA39094A8A8947E74838E8E836F7A
9FAC8D64617CA3B7A582625D7890967E625A68899E8A615E
7F87715C647A7F72625B5E63605B555A635F4A4055686750
3E4B646D685B463D48535758574F46404340475E746F5D4A
3F414F65747B79736A60564E494A4A505C636567645C5451
4B423C3F474743494C53606C5A3E373C434D5D756C4C363D
5B6D6B6057485F84ACAF76475583945C3341848C51506F6C
4E68A297605676A3C5985D7DBED1C1CBDDE2E2E6E8E4DFE0
DCE5E8EEE5D1CACFD8BD979198A89E8672758A82746E6371
91A089666587B0B999735B5D839F9673616B798B90755967
89825A455D818371645E5D5E5C6166675E4E4146616D604A
3D4F645F554C414048504F4D49413C3948545E6B73624831
2C3C566C7B7C6B57473F3F44515F6162708390908370676B
6E67594F4F4B443C2F3149696A584F453838497684754F3C
414C65747C5C516395BA9356486EA4895131719E6E48566F
555B92A27C62759BCBAF5D64A4D3CDD4E6E3E0E1E5E7E4E3
DDE0E0EADFC7C4CED0B08E919EAB997A67748D79605E6171
848F856F7497B8B28A6B5D678EA68F66637D8E978E6C535F
7C76554C678A846F68615A585C6B72695241404A58595453
515555433F47484A494945433D393A3E5464676562503D33
3B556766625C4B3D3A414B58697F827B77808D8A765F5B68
7478726C6961594C3B34405B666B6F69524040607B8D715B
483A586C7E6649486E999C6E525E98A4753556908453567B
584F88B09C706D8FBFC0786193D1DBE5F0E7DDDBE3E8E5E2
E2DCD7E0D3C1C2D2CDA7868797A796776A7D937D5C596A78
7575767383A2B9A9816A657798A380565E839FA7966E5351
656A616C8194826D6F6E645C6170715F4942444842414F67
6A5A4732374A50504B49433F3A3C444D5F645B4F4F4D4A4D
596C6C5344413F4654687576738289806B61635F52444650
5860646B6F6D6D6A635852534F5C6C7D715B45475B808483
663E414D6265564A51638D85755E7597874E497589656F90
674D7DB4A47B6D81A1C0A17991CAE1E8EBECDDDCE1E4E1DE
E6DAD6DECABDBED1CEA7867D879B8F75768E9E8962597383
6F5E606D86A1B4A481706F849D99724D57799BA693715C4D
545C66849191776875817767666D655045454340353A536F
6D5340353E4C4C4947483F3B3B47545C5E52413B48586263
63645A45414D5A697282867358576263524847494B4E534C
444549515A606B7178746D5D3F3B46676F6749383B587A92
7F533538485F70654F3D728E9A6C52718674515D7B6F8DA3
7D5571A8907D78777FADC29E91B8DBD9D9EBDCE0E3E2DCD8
E4D9DAE2C6B7B4C7CDAF8E7B7D8F856F7994A08C64597B95
7A57556C889AAAA18578798FA08F6C535A6F898F7D6C6859
4E4D5B7F877B635F758B826A63665C4B47443E3D3D48565F
55443F41474A433D3E3E3435425663635441343A50656D63
574C4F5464777E7D73756E54342F3C47444B525A68777760
4D464544474E5758616F7B73503B334A575D4E43383D5979
7C6946413E52787C5E375980A57C475381966850626F9CA8
8357699A7A79877A6992CCB58798C7CCCCE4D6DDE4E3D9D3
E1DEDCDCBEA9A8BBC6B5947D7F9085686A84907E636084A8
8B5C5E7B92959A97817A87A0A6896D616975807A67657068
5149597376624F5970897F645F655E514C433F46565C5443
3E41454A4847413B3B37333E5668665A4A4344505D666858
5251667B8A8C7C69575955493D414E595A64696E7985856F
5F5C5C565659523F3D516C7469625046414C575F55493F4F
60736D5E4142688171494D69968B564779A481504E6593A2
79566A8F7470908E6A7BBFB87C7AACCACBD9D2D4DFE1D4D4
E0E8DBCEB1969DB1BBB1907D86988D6C616F776A636E90AF
8E616C89998E8384757592B1AA836F6E7A8180746469726D
59586F78735A4D5F6D7E7661636D67594E464A556A644F38
42534D4941454A45443F46586E6B5142435461675F585A56
68778D94897052403F515C646C777E817A73696663656863
6167706E757A6746343D4C536783805B3C3C516D75714435
3F6E9181523C567F816B4F5B8198734767958F604A5C7F96
70586D897C6B93A47D73ACB7806E93C8D2D0D4CFD9DDD0DA
DDE9D7C2A58691A6AEA58A7A84958D79706E6A62697F9BA7
83606E868E7D6F746D7193B2A1766B74818178726D767164
5E6D888174635F6E6C6D685F6A7769584C495458665A4E47
56614B3C3B4A534C4A4A596B745A352F4869706650444F5F
85969B8A694B37374C65727F8A8A848479655652473F4046
4D525D5F6E7D745E4F52473B57869F7B5440415C7993673B
2C619D9E6D404872858C585068988F52527289775D657388
72606C87896F8FA5947EA4BE937382BED6CFDBD2D5DED6DF
D5DDCDB3987F89A1A89B81737B878583877B69677992A498
7561687C7E6D686F6E748FA68E645F7586796A6D76826F5B
667D8C77676F7B816F5C595B6B7765534C4F574A4D47525E
605539314154564746515C636248343F5E75675343425269
8C918773594B4B58727C7573756B5E62645A575A4F433E3F
3F3B3B3440565E64707D6A525B78988D7C64434361978D5F
36568CA4844D3D54749A6549518999674854798D7E79707A
806E66848F7B8393A391A0C0AA827DADCDD3E1D8D4E0DFE0
D1D0C09D88828DAAAE96756D797F80838B806A708BA2A58A
70686A7F806F6D6D707A8F9C835D58778D78666F7D857161
788C83615478928B6F5656606B6F6053575F593D373D5A6C
593C2A334D5B50424B5B584B46475066746F50464C586069
78746F727170717782775E4E4E53515D6F73797E756E6A60
554D3E2726333D53768D887A6F6569748B8D5F3D457D9F8C
5954678B8A68403758917C534B758F82524E719A9C896E6E
8F7F647A89867585A89893ABBA9683A1B8D7E5DCD6DBDFDD
D6CBB48A818F99B5B6976F71868888807C77697395A7997D
7172768F907C736A6D7B949E886B607B907C6C78827D7173
8E987B545382977B605967746E605857676F5B3C3644626C
50322E3F4D4E4548606B553835536A776A543D4C6771635B
5557698797907E6E6C61493C4663757F8B8D918C83898D81
767463473835303E5F707782806241486E938157436392A1
805F4A627D84552F437E946D54647E9A6D5E7099AB926B64
918D6D707F8A6C82A1917B84B8A792A0A6D8E2D9D7D5DEDB
E1CCAE87899BA0B1B199767F979D96826F6C6B77969E8671
717983999A86716A6D7B9DA49583747F8075717B7D666780
96967055678C8B57445B7C8866474A556F6F564043545F5E
4B3E40443B363D556F6A492C325B6A5F4135365C79745447
3F4D7196A4917156545853515D7A8F8A7F76776B636E7871
6E7B7768564B3D3A45484F708776483D4A75897B605B7293
97774544678E703F416C9884635773A2886F6A8CA5986D5A
8196806E7587708493856567A4B1A29F9FD5DBD3D8D6E2E1
E7CCA98B959F9FA3A29781889CB0A4876C64728697947C6C
6C798E9C9A876C707780A3A59B92867F6668767A6C4B5981
8D815D5A7D8C793F365D83844F323F557060494152605046
464E4F412F324B65664B31293A5C593B20263B6472654A47
495B7A90927B63585C68716D696E736350464C4743444B45
445D6A6B6261584E42383C5E777C655342526B887F645774
988E54375985855F4F5F879376536B92957461768D9C6F53
70A2996C6A848788827C5B6389B4AE9397CED9D3DDD6E2E9
DEC3A38C9B9E9E999391858592B6AB886D62799B9E8D7D6E
6A7B99A196846B7683879B97908F8C7D5764807D5D43597F
7D66505F857D6746496B7E6C3D34485E6D52414863664231
4252503F394F6A6E522A25354655492F2535475B5B5B5968
6B717A7B786B6F797E7F7E6D5C4C4D4842424E525047463B
3244545C59686D6950474855555F686B584546778877535C
8A95673D56728B81675C72998D5C6378956D5A5E72A07156
64AAAF6D6583A290777C637073AEB68C8CC4DDD9E2D0D8EA
CBB6A4919E9C9993878C87838AACA5816C6C84AAA3847A72
7387A3A18A786B798887847C79808C805F6783815D5B7081
6F5453678063555E707D73523F505F64624A4A596F674130
484F48404D707D6B4828374B4B433B3845525244435A7088
7E7068667179919C968371594D40515F666C76797B737067
554D4D4F4757646A585D5B513B40567172533D5C79866151
74908055575C8298805E63939C6B5C65936C5A4F66A47962
5FA8B8756E83AA947887788067A2BC9885B2D9DBE4CFCDE1
C0B6B49D97948A897B848889909C967A6F8397B0A27A6F74
859CA79475686D7B8883706665758B887269757B6A818D7E
604F6574734A4A728E83623F4B6E6C5C4F495C676A5F4944
584D404056706C5D4D4554584630303E5C5F4D33385A7583
69554C5C7E95A79B8469605151536C7D828285868C8C9698
866E5D554542425151605C4C383F4B6375694E4B5D7B7055
5F899C7A584C779E8F5B5788A07953578F7B6A556A9E8872
619AAA817B7F9C9286928B866698C1B08197C4D9E2D7CDD2
C7C5C5A48585767F6F758493A094887B7A9AABAE9C766976
96AFA4856A647280877E6B6665788E8D8069626B759A9871
54597A7F623B4F84997A50355478674C4251696551505258
644E3F4052574A515D635B504233353E554E3D39485C6361
4843455F8396906F56495F63656672726A6262656A6F8290
8D7E7573664C353D42504A423F4B494D6072684E485E7863
5580AC9C5C416B94915A567E9C80484786938064708F977D
69868C8C84788185989E95826891C3C17C7AA4D5DDE4D7C7
D3D3C9A073786F7C6A69819BAB907F8187A6B5A993786F7E
A0B8A28277737C8685776E717086928A8269585C779B8A5F
4F68877B4F376396956E4A3E5F715B4548656B573A485758
5C4B44484C4336516F6D483D49555044443639546A5F4A49
435459636B716346424A6C766C5F5F534134373B3E424752
5D606F888F745042393E383F4D564D434B6C7E694B4B7874
586EA0AA63355276876B64718C8044417EA18B656D84A181
6C7070978F73646DA5B19D786285BEC87D698CD3DCEDDFC6
D6D9C49C6E787B826F6985A6A98977808FAAB5A287767989
A5B6A088888888877F6D69707392958279625154798E7556
5272846B3F3A729B8264565A706550475B7A624C384F5746
45454A5149433C56746232335876675040374C727D573847
59736956464B4F4C5C63716C57494A443A2E333C4243362E
353C50718F8971593F3534495F655A423D5A81845C436880
665985A3773937567D8B795F7381504B7B9F895964839E86
6D6066A2A3745158A6C6A7775F78B1C8886D88D1E4EEDDCA
D4DDC8A276818D8577708CB19C7D73788FAEB59F80717E8F
A3A9948389938D81796964626C94957B6852495881816757
5D78795D3D467485665B68727358464E6B7B5345455C5035
34434E514B52515663502F3E6479604D484E667C6E43344D
6B795F42384A5B65716B614E3D3D464D554E53626C6E6053
534E43455F6D736F583E384B65756D422F426C8867414E7F
784D698E945A3A4B7AA6875362866C58779589565B7E8F94
7A6168A5B47C55559DCDAC8A6C749FC39F7E8FCBEAEAD3CD
D6E3D5AE888C937E77738FB38F7471738DB2B89F82767F8D
989380768293877577736A5A699494775B494B688B735B5F
707F705B4B5E70634F5A74725E4A43576F68454453604537
3C4D504B516365514A47455B6C5F433C50636967513B4052
68604C424B62625C5B554A404045505B6560646E777C7D86
9286613C32395773785E463E54767C4F313B5A7E72513E72
844D52739F7A554F76AC8B545A888B626B878D69556F7EA3
8E696B9FB784665E8CC1B0A9837589B8BE958FB6E0E5D0D0
DAE6DEB59C988E746F7790AA87706C728CB2B79B87848587
887E6F71869176677883775D739994775A535F78865E4C68
8680675D5E796D4A46687F6144444B65674D404D5E593D49
565A4D45566A6B493D4C66766B462E3658635247474D5751
57484C59686D533C3A424349534D5257564D4F4E4F536382
9C9C84603D2537587E7E673F3C617B6A53585B71806E4462
875A46578A7F6A516A9B8C5D537C9F725D779085565F75AB
9B6B6B95A88B726578ABB4C2927572A5D3AB8599CCE2D6D1
D9E2DAADA8A48A736B829BA3886E65738DABAC8F88938F84
7C746D758F8B635C788A7C65819F937C676B787E724A4675
95765858688C6F42497B89533B4B596B573C4860674F3B5A
6A5D44455A67624240577A785E3D32436356373A57696748
49475D6C7362443B3F4A4C5053413E3F413D413E342E405B
6B78828373482F2E5A798D62374761767C825E587E80545A
8875524A6E7B77535A7C916C516BA48B5A6C919C5F576EA6
9E6B69858E8F77686594B7C79773628CCBB77C87C0DDDBCE
D7D7C99AA4A98D7A7291A8A78C71677691A2947F8AA19984
74727479897F5A5A76857D738F9E8C807A85877763495787
94654B586E9371434E808A52415A6262483D5B736D4D3F64
6B523C465C5F543F4E6476664F434856644A324A7378613E
4C5970726C5C50585D5D54514D363237495A6D69533F4149
4546577995805224335793865344466E909E613C68846758
868D694E607C865C5062937B5C669FA4666992AB715A689A
A0726C7374937E6C5781B4C097715870A6B37C81BCD8D8C9
D7C8AE8C96A89580809BABAA88777A8196967A7693AA9F82
6E727B7877756463727B848B9A947E808E97856A645E7A94
8257506A768B6F474E7177534E68635245526E796C564A67
5D453C495C5A4C44616E60504C545F5A55444168846F4F3D
5C6D7A71686D696A665E585E645450566D8CA9A4886E615E
523A314D839987503A3E6E857B664B618CAC763C57857B5B
758A77585C788F6A4E5489856C6996AF7B698CB18968668B
A186726565968C6E5076AFBA9770535B81AA827CB4D4D3CB
DABD979295A4978393A0A29F7B7F91929A886B7698A89E81
6D7881736B777A726E718CA19B85717F9D9C76566B7D9691
664F63857F77644F4D5A5C515E7061454B6E726D62655F64
4E3F454F5553464C72704740546966524644547A7D574147
6878776F728173605653617583837E777F8BA4A996878282
7C603E365C7F968B6C43406390946D5577B0975C527A8866
5A6D7C625A698E7A554E7489746988A68D6B82AF9975667B
9DA17B595B95A2725070A4B8997A5C536DA4917BA4D2D2D0
DBBB91A8A69F8E8AA7A8978A6F839DA3997C6D7C9299927F
7685846E6E7F8B7E6A6A8DA68B746D83A59561436C939B80
514D74957F61595C53504D5371745D3F4D7B645755757559
44445358494840547A64313B5F775F4847526170643F3F59
66746C6B77836D545358717F8186836F604F5C6E6E758089
908A7353494D719C96612F4187A88C4F5A9BAE82495C8478
4F507C6E5B5584885D4B618874617293966C7CA19E7E656D
93B6844C5390B87B586D95B39E92755B65A4A88392D0D6D5
D7BD9BBEB8997E94B4AB927D71859FAE9071757F8D8A817C
8292846B78858F816B6F8F9B7165748DA98A55426B968C6D
5356799079585C6D6559545C7D7356404D7151444E7F7C4C
4352665D41404260744F223F6A7651405969635347394D6F
626761646D786A59686C79725D575B4B342028323644505B
708293835831417D978343366C9E9F5E4673B1A14B407489
5A4679785D42718D66505E83745B5E859B6E798F9F896663
85BE8D4B4F88C38567718AAE9EA5947264A6BC8B7FCADFDB
D1BCADC6BA96739CB2A38C7A7B8BA3AF826B77818F827279
899582718285897E7081928A5C5C8199A8845C5B6C887762
6569777E715E677A7667686A7C6F4F49535F4940517F6F43
4F6673583E42506D633A214B6F64413969775B3B3545647C
605E585D626E7068746B6F553B35433F37373F392B252324
344F7D957E4C32567A9168444E83A579454E9CB6653B668F
6D4F7279613D5F88775F69827C61577C9D747882A396675E
7ABC9459547FC291797A86AB95A0A98D67A4C5926CBAE4DF
CEBAC0C6B298769CA49280797F95AAA1746973838E776879
8A8B81808A80807C7C928D76525D8E9E9E7F6D7A6A76685E
7174766D6C5F677B76697875766A4A535A514D4D5E72573F
6576704A3B4D62705231345A6A503A3E6E715439405D6E71
5253545F686B7469614F583F35405C6268777F70593F3126
2228497D99834D475684825F406A9A90553875B1864C5F86
7A5F69797450597F8A6F74888F715E729D817C81A59B645E
77B69C6E5C75BCA0857B81AB868BAA9E6AA0C89F69A4DCDF
D1BFD1C8AE9B81948D8378777D9CA6886D6C73867F646981
857C828C8B7975838F977F645568989A887A7D89646E6760
7275766368535D75665D7C7B71664C565B4853606A614240
78795B3C3D5C6B644837566B5F4547546A5D535066766053
3C46596E75656956463F4F454E5D848C8992998C816C6562
533327568CA37C584269837D535E819F723B539A9C6E5F72
7D6B5F7B8E6C5C73927474899F836B679A8F83819C9A6160
71AAA7836569AFB0897276A778779EA06EA1CBB78395CCDD
D9CDDCC5AD9B8D8C7779787E809F937270737A866B597188
7B6F838D87736A91A293786163789892747B868668727269
707A776163455C72584C6E776A6555555A445A6E6E573C4C
7F6D443C4F6865504247717051485E6D6048537188804C40
3B4A657977555348414B62646D698381716C736E7268778D
8A643844679CA1834C507596765E619C91594887AC946860
79765D799D7B586793736B7DA1917A64999B887B8B9F6462
6194B3986F5C98BC8A67699C73708E9A77AACCCEAE8FBFDF
DFDCDEB6A798978A6C737E918F9A7C69797F877F62627885
73708A898372659CAA897C6B77878E8B7388867C79797A74
7687756060496B72523D51695F666257604B647166564761
7C5B384B6B6B544040557360414F6A6E4E3C51828772464D
59646F6F62424651545F7479755A53483D35414645385375
84896C5B5784A7A86B49669E8E6042819F7C4B7BB0AD7358
778867729C8056659677626C9A9F88689BA68E7680AB7064
537AB6AA77547FC291625B917D77859783B5C8D5CE8BB3E2
E3E4D9A5A09DA08C707382A8A08D6D6C818D917365717579
737F938B82766D9CA37E7E778A927F858491797288787678
7E91705D65627C694E35385B5C666856655F6E6B57565972
6E4A3B5F7861433D4E606245365964553540587969564668
7A766C5642354A636B6765675D3B28262D2D404336222D3A
4B7A8D85646D8AA4885F5B8B94673666978F4D679EB37E56
7799726D9886626C9787605E93AD8F6C9CB2967C81B67F67
5365ABB47E536CBFA06452888F83859D8FB7BECBD382A1DF
E7E5D2A1A3ABA58B7D7D87B4A37B677388978E6D6F79716E
7B95968B7F7C8294927777839B99717F9686616A8672676E
848C665B70847E574C3E3C5D68645D49617272604E556671
583F47696B503E4D6E7153373F6A563727556965473E4877
7F705D4634355267705D404140333248605D69644F403A26
1D4A7F977D625C7D95804F628D7A4B5D8C964F5180AD855A
7199756D928A70739098635A8CB58E6D99B89A8386B98E6B
5B5996B5855863B4AD7155819C8B87A89AB0AFB8C97D8DD7
EBE8CFA9B1B39F8B898C8DAB966C687A90937E737D7B766C
82A0897E78849B8E83757496AE98697E996C4C67786A565D
837B5858799A754650595F70725F493B59756E53555D6C65
413E576654444967897C4D3B547147262F6F72522E324E75
745C4C4B4746575E6045292F3E5462839C85817D6663694E
262F5A828D6C3F5A948E463F808F6A5886A261516A997F63
678B766E8384767B85A2696085B4896A8EB3967F7FAE9871
625986AF8A6066A5B584677CA19082ADA1A4A3ADC18884D1
E8EBCEB8C0AF9697949B969684686F8596836D7F8B7F7F73
839A7869718EA88D7A757DAAB78E7086925B496A6C634A53
7C674C517A9C683C567588816A553D3F56656145676D6C57
3649635740425975846B424462603525477F64402632556A
6D4B455E6665625852392E3F5A777C8D9270686D565C7976
5139445F867B47518A8D4A397B98785081B086655D806F70
67807B746D727A877CA5706883B0836780AA906D6A9A9F7C
69617FA98E6A7299BA957C7EA79576A4A69FA2B3C4A18BCA
DDE7CEC9CBA690ACA5A89C84796C7C8F91776D8995858080
85886F607598A28C737187ACA78081938A5C587167604B5F
75574D4D7B93593A51829E80534745595A4D4E3B7572664B
3E5D6045324767706743344C63462A35607C48393B435857
6849506D74796D5A554C4C5C6D73645F513C3D432D335069
69514845697E5E598090634C79937F557BAE9B705472687F
6F7D82835E64819277A4776B82AB846C79A58C5A5386A78C
706A7CAB94737C8DBEA18987AF986896ACA1A6C1CABC9FC4
D7DED1D9CCA18EBBB8AF997B76748B9080777E8D998A7990
8C716F6C879E8F836D738D9888768E9380656B75645D597A
70505C5784874C3E49859C71403D5D7A623E40427D695A43
557154382D5474655024385B603C2F506E683649665F5941
625E6B6C676C686467716D645B54443C353634341F1C283A
575F5C3E577B6B5B78968763698A8B647093886350747392
7478838E5D67898E739D7E667CA3907A77A38B514975AB98
736876B39B75777FBFA68789B1975F8BAFA3A0C3CAD0B9C7
E0D9D5E1BE9D91BCC4AB8877797E97886F7F8E909A8C799B
91606B809CA083756881918075788C83716575715B576D8F
6C51676D8B7643464F8C90603841778E693E465E865E4A47
6F7C4B37386C805F46254C6F5E3D3E656B52366487705939
6B81875E475061777A8877543E474D565D6C5C5346413828
41626C4E6387715068939E71568397755E716A57537B7FA2
78707B8C5C6C8B7C698D88606F97A18A729B91584A64A39D
6D5E6EB9A0736672B8A57779A5955E84ACA087ABC3DACBD3
E9D6D4DCA99998B7C39C73747987977C708B919698878499
885A628BAAA284686692937273838471635E796A4F527F8E
66546282825F41506795815237508588654052808B573D56
7D73493D508181553D39607C57384B6B5B46437384655049
84978D4A2D486A8C817F614234516E87899D8A7A7B7F6F48
4B606A5E78987E4452879E764F809E8952606A6A5D7F80AA
846A6F7E596783635A76935B6487AE9267899C6C5258959B
64576CB9A1715668A6A36A608D99667BA79E6A87BCDED0DB
E5D3CED0A09FA7B4B88C6770768E8D727A93909C8E7C908D
725F628EADA087636B978B6B728E83665E5E7F684C578E7E
59565A8C6C4C466083956C443B61826D5038528D7E4C3764
795A46405E816C44304B697A493351654E4456736D4A465E
8F90763730567896745E443A34556F877D8D857B87959879
6A6258587B9C8D4C497691774A79A29C556680926A7C7AAC
90696E7261667E5450639E60647BB38C5B73A6825F57879B
625A74B7A57853648CA26D5472A07273A5A45C6FB9DDCDD8
DCD6CAC6A9B1B5B2A8816972769584697995979B8176967F
5D657195A8967F697D9382686A95885D5C6B8A695162966C
47555E8B594A55779284533A49727C5337324F85633E3E6E
6F44423C57684A362A576A6A3B39595F4C47666D5B3A4368
7C71522E486A7784583F34362845505B4A51515463759690
796547436B9197624D68867A3F6599A259708DAF6C7074AB
986B76717F78885A5960A96C6F77B07D5663AC956A5C7FA2
716881B9AB8B6364739F826161A57E6CA0AA626FB7D9CCD2
DBE5D2C4BAC5BBA9917F767E819B8161698FA59377849775
54698BA39E846F79938F856863928652557E916656668D5B
37586A7D4F556D8E94673B3C5E89794B353F617B4E3D5279
69424737494A3036345F5F51354464564D4D6A60533D4A67
614F3E375F7A6E61413938371F363A3E29282B2C3A4C7281
75664739547D9C724D6285864152879B536A89B061636C9F
9D6F7A79A6939B706C66AF717974A8725857AAA06D5A79AD
887488BCB1A37E6B5F959D7B5AA488678FA96C77B1D6CFD1
E0F4E2CCC8D0B6977681869392987D5E618CAC87759D946B
5A72A4B18F6E638798898C68698A794F548C8D5E5762774E
3D6872674E61809A8C50304B729F764E4759837347496A81
62505335453F2E4446654C373A4F6C484B4E614F4A44565F
503C3E4E6B7F644438474F462F454747363337313439516B
7074604040689B7C485B8B9C54547D934C5C7AA0595B658F
9F717881C1A2A4827A68AC6D7469A1745B4DA3A6694E73B4
997688BCAFB399755586B28E5A9E906979A66F73A5D6D2D0
DFF6EBD8CED1A983638494A89A8B775F6E91A17A7AAC8D5F
6381B1B17C5C618A897C856579816B5D669683575A66614C
5E83755457668298824E395F7FA2674A5671936244577C78
525957374A483D4F59663C2A4A5D683D4C49544340445850
463A47656A6E583D3C5B6C5D4E68635C57545D61553F4664
758E895235579489494F90B1665F809459596E90635F6887
9E717286C89D98867B61A46C6A5A9D7E60489BAD674570B6
9F7285B7A0B2AD805778BC955F9998736DAB706594D7D0CA
D8EDE5DCD0C894765E839DB2927972618398887488A7835D
6A90AF9E694F64877A707566897C616D8499745464765451
8194714B64626E8B7A5E5070889053405D81864E40618962
3E58503D4B55494C6561352C5A67573B54444C3B413F493F
3C3C4F715A4C50494E6E7668637872635F5B728D7E574D63
7493A46A385190964D478FB76C5F7F9E7868778A7B717586
A1766E88BC858080745FA076695198886B4D95B7724D70B4
A27383AE8C9EB488616DB79768939B8171B67D5D83D6CFC7
D4E6D7D6CFB77E73667D9FAD806A6F658A9671749A947B6B
7098A2845E4D6A877C716C758F765E7398925F5273855152
8F8D624E6B575376726A627B8E78473D668C6C4441709251
34564D4248574C436358373861633F3E5D42453B4F403430
314257704334565D6279665758646454474669978E6C585C
5F76A07C4458909B524383AB695273A0937D8E8C90817D83
A7806C82A6686B7B72689C847153928D7B5A8CBC87676EAF
A37983A37C81AC886A66A89D7588948C84BF956579D6D4CE
D1E3CCCEC9A2707B75789F9E7361686E8689687BA37F757E
79999471605673868174718D896A5F78A0875154838C5454
8D7D54606C5148646A65678092674644708B544546808F4A
375C5947445252495751424A655B2B41623E3D46654C2D29
2F545F6339386670666C4C39394345362E3459887C6A6557
45568C7B4D608A9B593D6F94624E6C949981958AA0827A7F
A88868718D59657D776F958C765A8B8F866880B6987F67A5
9E7E8098776B9E866F6095A68278838A9BC7AD737CD5D8D5
CCDFC8CBBC8E7489857C9D8C715E5F7D867C6E86996C7087
8392816B6866827F746F7AA07E606786A67C5565908B5D61
8F7454796D57566566576383945B484C717D3C4549837840
3D68714B3E50635D504F56616B56284B623D3B557B5E3433
3C6B634D38527B745551362D3038372924335372595B735D
3B4A817A4E5D7E94603C5F8064546F8B90708983A776717A
A78A60617B5D71837A6D8E8A6E5E8695846F74A999855C98
917A768D7B68928A725E83AA916E737DACCFB77B88D2D2D0
CCD8CCCBA97F81908F85977973635D8A8F777B9182626D83
8A7F686B6C718F745D6A84A6775F7097A970617C91806576
8E6B5F886E626E77694E628694514C566E6E2C43517E5C33
44798A513655756C51506A716B50345E5D3D426086683B48
537960383B6B876D433D2E3F4D4F4D402B324F5C3E527F6D
4049838B545270846346607D71587390895D7C80AA6A6B76
AA8E5D5D7169868676648E825B5C81A179706C9B8E7C558F
8572698883708A95776176A5A06C6D6EB1D6B47691C7C8C8
D2D2D5C9997D8F90948B8B6A706A678E977D82926F626D7E
8C6853666A7A9670516D8E9B7262749E9E62648A886C6984
7958698268657F856F4E668A8949516874683243627D4F34
528B9954355C7C6B504F726C5D42466D543A476A7E603D53
6579562D43727B61413D3F5D6D6F70663D2B4353374B867F
464B859F664A657A674D6C87794F729690597381A95E6C77
AE996C656C7696846D59907E4C5A78A96C70679086745691
826E638D8B737DA17E646895AB6E6D62A8D6B16F8CB2C6CB
D6D1E0C2998C9D9194877E61696E788F9A867C8266686E7F
895C535E6988917051719182685D729D88565F8E825F708B
5B4872715E6185816C526D8B7042557A7A614749767F4F42
6398955340657B644E526D5A4E395C6E4B3848746A4C3B52
6D6C4C324D6A5A504A4C59696D71797D4F2B415B4045808D
4F4C799F7349627D6E486E8A7B446D94995D6B81A2556E75
A99D806F6A7B9A80624C89824D5C6AA4636E638B87775C9B
877366978C6769A681605780AC6D6A5C98CCB6707C98CED3
D3D2E8BAAAA4A596907F745E646F88989E8B706B636D7283
7D5F625670988269526E8B6A5D55739D7051629080657D8D
4D4D8164565D89745D587684563E5A8471545A548175504A
70987C4D5270785E545A644848427362413C4A75533B3D5A
735C4941515E4141575B615B5153677E5234506951467195
5E475F907544627F73406080813F678A9A5D658094516D6D
9C8E857869719481594476895B605895606961888C8363A3
8C7F74A08755589F7F56496DA36A615584BBBF7E6E81D3D4
D3D6EAB9C1B39E92887B6F5C667496A7A28A6B60616D7D86
6A616A577D9B715C557287645E597A9A5D5077957A788C88
515D8E5E4E5F916C4D65857A4F44698B5E4D676B89614D47
7A915D4A5E756E596063573C4B5F7E4C3840506A40354A72
7653484F53513E4763605C4B3B3C57754C3C5D755C4B6597
66434C82763C597B7A3B57788B44667D975C66848B4E6B6A
886D7D837062878C5B4762936A614D8965666288908D66A4
8C8984A5804E55957F5049649C705D4E6DA8C5926F75D0D1
E0DAE7C0CEB187807F7C6B59697C9FA99A806D67626C8B82
585C6368898B67515F838969676F848B4E508E9B6D82967B
57698D5A44679666477292725654809251516D848E4F4746
868C4B4B64715D536A6A4834557F7B352F425B6138395A87
6B4B4760584247606A595D53413F5870483E5B7958475E96
68444A807E384C7B883E5B798E4B6D78975D6A8E8D4D6D70
734C72917C5B7C9A6654569D715E4B8670696689928D669C
89898AA97F585C8E87525567A382654E5698C4A67E75CAD2
EED9E2CBCDA777747E7D625669809E9683706E7268708D74
505962888E7469526D9083666A8B89714955999F69839D71
5A728659407692594A789669555D8E8F4A52678C88433F50
948E50526F6A4C5373753F3A659271282C4D6E613E43618A
543B4A765B385476694C5F6E5E4960774A435B784A40558F
6C485286873B4C7D9647627A8F4D717E985B709193507076
6B426CA08A5D77A06F65519E725C4D8B7F7168879484618D
867D7FA982665F8A985B626BB29A76584891C4B7907DC7D8
F1D6DDD1C29F7A7F887B5B586B81957D6E636874767B815E
516172A58A6572607B8B6D59669D88594E65999C7788A072
637F835C468583474F7B935D47568D83434D5A82763C3A61
9C8E5C5E7F67455C7E7E434A7292622C325F816248496180
3E2F52855C3C6686603B5B827549627E504B608046444F7F
6C4E58898B43507A9A4B627C954F6D8297556B8799556B75
6F516CA99465729D706F4D956F5B51928F7766849778597C
846C6CA5856C5886AC6A6B6AB9AC88664690C6C49A8DCBD9
E9D7DBD0B4998997917860627A8886726B5E6574868B704F
536D88A3775E77768B7C55536FA4824B577A938B85939673
7289805C538970415585955A41528E77404D5D7E693D4273
9B835A6A8D64466885744D57748850353666865E4C4A646F
313560865D4D7C9154315B8B77405B785851648F5151536D
6457607F88464970954760819E576A80984F546F9E5E6674
77666EA99E726B946B6E49916D5C58989B7965829A6E526E
84635D9A866B4D7FBE827364ABB4936B4786C5CB9EA2D4D7
E3DCDBCAA99494A490786D7293947872725F687A9391674E
557895845E5A6F8A9873475C8DA4784A5E8A8A6C83977D6C
818A745B5E7F674D62949A644F649A6F4051748866434E84
94704A6B915C49718459516179834A3E305E7B554C4F6959
2F45747E555E8B8D493667926D31536F594D648F565D5C62
5D5E68767D3F3E6990485F85A6606C829B4B405BA26D6B77
80706CA9A97D679166684C967361639BA07368839A694E66
86695A8C8B6C4B79C89E7E6089AF9865446EBCCEA3B6DAD6
E2DFDBC5A3989DA087787683A796696B73606A8698866357
5C8699664F556493946B4467A79769556B947D51788E6764
8B87635F69766A5E749A916D6485A5643C4B8E9362455395
8C5B3D668B4E4F787F45526D8C8B59482F61714C47586D3D
3652826D3D628D7D4043789A64295470503D607D4D61635F
575A707E793A4171914F648AA5606F87994B43599F78737C
88756DACAB7E64976765569E7D686B999C696A8395654B63
89765E8198725276C9B2856167A397604056B1D1ABC2D8D9
E4DBD9C5A3AAA99782787893A9885D5767636B9397705C5A
6895975B4F5365927C60496DA87F5C6A889A6D4D78846165
8E845867797B6E6481927063709DA454364396965A4257A5
874E3F667F41557E7D4755719B9267514378714439607128
40618356275D8D733C5088965630607848285669435C6D5F
494D768E85464F8591536F9596566C8091555964966E707C
8A7E77AF9B765B9C70635C9A7F6D68909060667D8F5F4D61
8C7D5E79A7775975C2B17F6555949267454DA6D3B2BFCEDC
EAD6D5CBAABCB090847C799C9A745A475C6D779F925F5457
779D895A5454738F655A5976966B587DA6965E5B8783656B
8D7F546F8A85686087864C50759F984B394A9498544162AC
81474B737339597F7C50516798895D56639375352A6A7320
487685492A60916F4065938640396C7C4526575F44587763
414675978E565D978D527499804B667A8A5B6766875F6875
84807AAF846F509A745B588B796D5A82805D5F738A5B5360
8E7B5A71B079576FB9A17169588D8E76535797CEB3B2C7E0
F0D9D1D4BAC4A78C8B888297826A604B5F7B93A9865C555A
869770575A5D808A5F5D728A8766618AAF8B596A988A686F
8F7E517698865D5B8C87404B7E94824B4862949A50416CA2
6F3D56846933587E7753465C9076465782A572282D7C7127
4F8A8F4E45759662467F97712B376B743F3A6E5A4B5A7E6B
4E4D6F927F55609C81516C92714766818B57635C7A616870
79746CAE76704D966E53507E756C4C78745E5B6A895B5B61
91795B68B07A5264B4966A6B62929283636682C8B3A5C7E4
EEDFCDDDCEC1958C9596908D6D6C675E6E8AB0A67261606D
998B5E5865707F7A6464899C7F677397A27F6170A08C616C
96824D7D9E7C565B94924B5C8B8C6349567799964A416C91
58315B8E6832558068504061966A3C5C95A6652C45977232
57979655648A904F478E955B1F386364395282524E5D8A73
5A596783654958986D496393724E6B858B535F5C7B6C6D76
6F6460A96F77559A69564E7E766D48747360596389626162
967E625CA97E5157B49E6F6C679E9E8C707273C5B7A0C7E3
E0E2D1E3D7BB858D9E9C9B8763706B6F7E91B58F5E66708C
A9815E6476847362676995A0726287A791756B769C814F64
9B824D7F9F6F56649E9A5A70948C4C435984A18749446C89
4E3460906A3A55825B494371A3653E609593553B60AD753A
59999351708C7F444B8E8B4A254C63583C5F83454F5D936E
525C6B7F504051925A41659C745172808456666D8272717F
675C61A06A7D62A66C6954897A704A737962555A896C6161
9F8669519F84544FB6B17A6A66A2AA92797870C7BDA5C2DB
D4E1DEE7D0B27B8DA1999D8B65736F75848E986E526983A4
A57561738489635168739B915E5B96B184696F85926C4063
9475567A97675973A8995A7494934942538BA572504E788F
58456489634A5C80583F467DA5593D5B7F784B3E68B47A3F
52908E4C657C71465D8575443F676F55476E813E55618C58
455A7E8A463D5894514769976B4C77807A54767E826D6E7D
615B6299668073AF707E5B8F7C6F466E8065504F8B75615D
A68467499689574FB4C07F616194AE987C7974C7C0ADB8D4
D5DFE8E8C0A7758A9F999E907175767A85857054526E95A6
875F587A8C7B58506A819C784F5CA1B1785C7099875C4872
876465768960587CAF8E49678E9D574B4E8CA15E56558A9A
634F5F7750576A7F5C384B849745374E696C4E3256AB8546
4B87904E4D636E58736C5241608077555A7F8549636D813E
44649090494462954E4F67875B497D83734F80867C5D6172
5C605D93647E7AAF71875989766C3E6A826B51498D7D6758
A8775F498F925E56A9C27D515979AA9D7D7978C2BCB4ABD3
E1DDE5E7BAA17A8E9CA1A18A787179868879544859779D92
634D4C7D956F55586989935E4F64A1A96A5572A47E57658A
825A707D7A56557AB080395C86A268554B889C505359979F
61485160425D7C865D37568E8633384865745D2D3897994F
488697583A50736F7846313C7A8F704F6C837F5D787E7E33
51769985515363884952667F4D4D858672517B83794C556C
5B6656916C7E75A97484557F6A673F6C8472574D93847358
A76D5A4E8C9F6B6094B97B465461A4A3837B7ABDB9B49DD4
EDE0DBE4C4A58DA19CA99F7874647694886C4A4A6A879575
52575988A1725D606888804B566A959B5D52749F78587A99
85596D8A74505676A8773D5D829C755F528B9A525067A596
56404A54436390935633629D792C4650647770372985A551
3B7DA375414B6E6E6A34324682825E4F777765587D877B40
667E906E4E616C753D5467824D55848C7356727D77485572
61694E977C7E6DA3768056786161467385705D57998B795C
A9755C5289A9776579AE844E57559DAE8E7B7BBABBB398D1
EEE4D3DFD0AEA6BBA0A595686A607B9A7F604C5686967E5C
5A787F979F77636370876D4A5C6B868957527B92735B7D95
8159628E74565B7A9E774F61878C7565659C925B5680B483
4841555E4D679E9845296CA369335A6157697F452D799B4E
2866A095614F585556435768785D5659795E434074826C4E
717E8159476A7F7538566D874E597991715B6B7F75526282
6A684CA08981699A727E5C79635C4B7386665A5D9F8F705C
AB8D615182A97C635EA29A69645593BB947279B8C3B5A2CC
E6E3CED4D3B8BBCBA295856267749193705953699A95654E
6894A5A28D716160818A625760707F7A5958878A71627C87
715A618D725F5D8598745A608F7A695D73AD7E575797B86B
39486C6C5162998F3727759A52406B764553885134688653
254C829A7B4E3D3C4963827F5E41646E7C42293B767D5A4D
68837C4F507890864359778B49596C8F6B636B8A735B6A91
706856A2857F668C66795F826B55486D8D62555BA38F5C56
A1A8674C789E7B614B96B185725780BE8E6375B3CDBCB5C8
DCDDCBCAD3C4C8C99C8376646F96A9815F535E80967C554E
719DB8A87E695F628F885D626681816D5C6196896C64817C
5B5C71966D5E5A8B9368595E8F6B574B74AB684451A1AC59
2D517F664A5686863C3876863C45758639478E633C54796A
403F5B81724330344B85936B403B7C86842F22568F804D4C
6492875162909F8B55657D894A5E678C666D7598705F6295
776B619D7775608059715F8D745343679E6B5B59A38E4E4D
85B4704B70947D644687BA90735366B4815B76ABD7C6C8CA
DADACEC9D7D2CFBA8C776D6B81AFAF71514F70927E5C4E52
7699B0A47D686372927F5D69749B8C655865A38B625E857A
4B5F89A3695755878B5D53648E604A44739E603D53A19C58
2F5C85534152808B525071722C3D6E85344B987C433F738A
6F46405E5542424B61957F41354B8E8B812C307CA7804158
81AA93566BA1A97B637C807C536A6B9267727F9F6A63578F
7B6661936A6A5C7A526E629979564067AF7B6A5BA38D524C
61AF7B516C93846B4F77B1896C4F52A67C647CA3E0CFD0D2
E0DDD7CFDEDBD1AD7E75707B9AAFA26A4853879A684B4958
8193958D7E696E8E9173607188B096624E65A589585A877D
4963A1A9674F5486865B4F719356434D7F9B6C4A6098925E
3C647D47405A8A91655E6B672735617C3450A3984C306896
91573B464C55677981875C2B44628F766E36448B9D6D3F73
ACBE8A4F72A7A7636587886D56716C936B727E9F6662578C
73585D8360675C785D766CA1785C426BB181745DA18C5F53
48A08359689A89735C6BA380684F50A28475819DE3D4D1DB
E7E2E0D1E1DCD1A97B7D7A91AE9D8B6B4B6698905A4C4B68
9993776F7B6C78A58E685F7498B1925C4B6B9B7C55638F88
546AB0A6654A6193835A4E819A51415B94A77E5363888857
46656B4347628E865F57636A30376079394CA3AD5A2A4F82
966043435A7185968E66453A68757C535648578179504990
BFB8724676A39D51628695624D68668E6C6D70946263688E
64485971596A5E796E7F76A17261466BA6766D589A87665B
42908059619C897765659C846C535AA79282859ADED2D2E3
E5E2DFCDE1D3CDAC838A88A5B18B786C638895764F515883
AF946259787380AA865C54709DA081575584926A55749B8E
6475AF99624B79A17F534B909F574363A6AD844A59767344
45625D3F465D857045425E773C396A76384294AD652E2F61
90634A46647F84857A494762917C5C39475A67755E40569F
AD98624B749A984A63869A5C4F5A648F69685F7D586D7A8B
5D465B695D6A5E7C757F74966A65486599625E508F866162
4B89794F559288766366A299755765AA9D858597D4CED5E4
DADED9CBE0C1BDAB909B99ACA38370728CA37E5E4B557199
AD8C564D727D879E7B514871A08D70586DA3925D56859D80
6C80A3865B528FA977474799A5664865A89F7A3D4D685F36
405E61403B54836B3438628041366E722F2F7C9C6A382048
8A715349607164565B4A6C8C996B43354A686A6F5546679C
85765F56779895506484965E65616F8C68695A6A4A717C81
61576A7067625D88787664886465485B9455574D85905A69
598A7A454B7C8A725769AEB47E5C67A5A17E7C8AC8D0D8DB
D4DDD8D3E0AEA19D99ABA7A48B7F6C7AABA463585C668B9E
937A514B6C8A958C6F504D82A682645E8AB38C595E918B64
6F899F7B555499B06E3E479DAA6F4E5E8F846E3944645D31
385A734D3557857A444170854130667D321F6E8F6F402942
7A8B644E55584D3C546A999D794D3E425168616D535A7687
6165646388968659698A92596F6F80846E6C5A62426D7A7B
6269797F735D5C927C6F578864654853985A5B4E7E9D586D
628E87494A6B93704B64B4C9855E629DA0756A77BFDDDBCF
DBDFDBDEE1A8868B9FBBB19778776C85AD8E5C647E889E96
746453566E98A27B6254619CAB7D5B63A1AD78586D9C7853
708EA57E524E93B26640529FA7664F576B69694340696B31
2D578967395A7E895E4A788A4833609A5128759177474047
58957C5F53505B4F6A92A78A53394654556059674A667877
5859696F958F74566C9B8A49606F857469676665456D7E77
60727988765C609681745C926C6947519D67624B77A15768
658D945D536BA2774955AACE8C5B5C9BA0775F6CBAE9DCC6
E2DCDADEDBAF7F87ADC7B58E74757B9498796F769EACA58C
61575F6C7BA1A26C535272ABA7765767AAA36A5A77A37959
6F8BA680524C89A55F4E64A09C564D5759586D5A436F7E3B
29589D84414D6C8E6447788E573C63B17D4A84917952504C
3A87857166627A72809A87644946505A596159634360747E
615171708D886C4A6DA37D3F536B805E54607C6F54708171
5E7370856F5C6C92827E669875704954A1706144729B555E
648996715F78B48B594B97CB965B5D9FA7866671B9EAD5C0
E2DCD9D7D2B88E96BEC6AA85758097A1826D8687B1C2A684
626176868EA598634A4C75A899695466A19B685B77A58768
6A849B7855588F985A5F77A08D4E51605B5476724A728E51
3763AA9B503C5B8A5C457290673E64B1955B7A816F5E5250
376F80747C7E82787876554E5C675B515D6E61634E617C87
675E81647F7D62487199754C5C7B80534E6289746175866D
5A696E7F6C6782877A85649777704F56A3705F40749A595D
668C90786282C1A2715087C89F68679EB49A797EBDE4CEBE
E2E5DFD5CEB8A3AAC1B0927B7691B0A278678B97B9C5A780
6D798C979EA389624E53779D89544C618D8D65596FA28A6D
6B85916C596A9C9253627B967B49596C6559777B4F709965
4C72ADA6613A53835B4A6B91753A65A18C44526063714F53
435A796E7D83624F5C553E576E745D4B658065595E7A9787
61718C577B795E4D718674667D9984565A6E8F766778876A
5B607C7E70759E806D85589576695459A66E63407CA5686A
6D9B90755F80C5B1836182C9A57A6E91BEAC8B8BC5E0CFC5
E4ECE1D9D5BCB5B8B4947F7B7DA4BD97746282A8BBB7A37C
71828E98A49A76605D6C83957C444B69857F5F566EA48366
7193925D5972947F495566806C425A7E775866735269966D
5075ADA4673E4E7757486699843A668B81312B405580625C
4C4A695B626E432D47524E6B746850496A8363536693A97D
58789056768166507383707494A1876064769576697B8569
615F8D7E7379B381637F569D7966535EAB746D4282AE7D78
74AE9C785E7AC1B0886D83CCA9876C7EBFB99391CAD9D2CE
E5E7DADDE7CDC2BCA38179878BADBE8C6C5D7EB3B5A19275
6C748497A38B625C6B89938B73495F8491815E5A7CAB7B5A
74A49D56546D7A6246494A6E6C455993874C53645160876E
4168A991623F476A4C3A5EA1923F6276863D223E4C808768
4E445346405641395067767867523F4D6D735D595F8DA06F
577A8957708D72557C8B676A8A88876B657A98756C7B896C
646194766F74B983627864AD7E6B4C61AF8179417FAC887A
73B7AA826274B8A5846B83CDAC886172B9BF8D8AC1CACDD1
E6E0D8E0F5E3CAB9997B799394A9B78A5D5C89B1A68E7E72
6967859D9B7B575E779D9B796B6381A3A78E666894B07854
6DA5A457526D715A585141707F5E63998642525B47567575
3B5C98725F4340685236529A983F5569905B355852729B75
5B4D4D45305157606E7C8E794B3841646F60575E507B8B61
6283715579947164848A64617C6A867D7180977268789372
6360946B686DB481687574B47F6F4663AF8F844177A58872
69B1AE88676CAE9C7E607ACAB185576DB0B87A73AEBCC7D1
E4E2DFDEF3EACDB4977C809D949AA6915C6CA0A58B817475
6E6E959F876855627DA097686480A1B0AF977577A0AF7E59
65949A53537A826A746F5077937C6E8D774059603F476784
4B5A7D5C5F4740706D434A838B3B41609280556452598B8A
83665B5743697681847271683C365E7E675154615A797A58
6C8D5C5B91946272867D6D6E896185958A90976A5F76A074
695F91686565AD7D71747CAE7D714A68B1968E4972A58569
5CA5A7846563A8A07A5967BEB78C5367ABAC64549EBBC7CF
E2E8E7D8E4DFCAAC958193A78C858892748EB3986E70767D
7A87A4936E5B56607E988961608EAAA5A2917A7A97A68967
6882804551808B73858F627091826C7C7348576D42395A89
5E5861555B4443738152466475453B5A899C6C5544476E94
A380777C778682847B534051444E6F8265565660727D7666
768B5367A79959788366758AA86A859C949F9A645E74A673
796A9368635EA77F7F727EA5807A5C72B38F8F5574AF8763
52A0A17F5F5BA6AD785651A6C09D575CADA95C449CC6CBCF
E1EDE7D5DAD2C4A29089ACAC7B6B658892AEB89662607A87
8CA3AB825E5A585B83947A63668C998B8F836D708A998872
797C6B3F4D6E7B6C839B6D657D73607582574F774F364C7A
5E4F47515B413B60855B3C4A6D5F495C789D744939425C87
97808F9CA08E766A5C3D2D505F635E69686B60597E7A717A
88875879B3975983895A7A94A96F8690899A925C6573AD75
8072916A6463A9848B7082AA8C856C74AD7E835C7ABC8F63
4FA3A6815A54A1B773533D88C6AD6156B5B66F54A7D3CECF
DFEEE0D8DBCBBC968D9AC0A66B5B5783A8BBAE9B725E798D
95ABA171585E5D6193976F6976898273847F606A8A917B6F
89866A494F5A625C78946F637164547A955F4A80643E4168
5A4B394A604E354684643341777B595D64887A5A45475A76
776B878E8F7C644A453F3F6D7B61454D6373665077766378
A28C6591BD875F978C60838A8E6C857977828959636EAD74
78728A706975B286907685B491846C669F6A725B80C59265
4FA8B18A5C4B96B571543971C8B26E5AB9C69278B2D8CACF
DEEDD7D6DCCBB7918FADC696675D6995B7B59C9A8D707E93
9194846156616A7CA5976D72888A7263808A656F92977265
8C9778525B605447688B6E65765F468099544289834B3C64
6A5D43466567403D83683241829161525273857E69575D6B
675A635C5B5A533B4A5D65897E513B486964534E6E6E5B77
AF8F77A5BF7C6EA67D658C887D6F8560667292615D669469
727C85736C83B7878C807CB281746456965E665581C28966
4CAAB79264418AB0795B446BC3AE785FAECCB399B3D7C6D0
E5EFD5D2DBD4BD9A9ABAB67C696484ABB8A187889A8D949F
8B75655C5F6A83A2AC8C70798F8565577A936D6F92A27560
859F85556874543A5D866C607B6138768B4739809A623D65
88875C486D814F3F7D653A437F9968494E678B998F695862
6E604F3E3E4B554C63888083684B46597A4B3C5E6E626383
A08A95B2AB727BAB726B8E8A737596636676976260707D61
72887A71748DB080777A6DAB6D625D529B62655078B1765E
47ABB6946D3B83B38A615768B6A47A5D90C9CBAEB0D7CFD6
EAEDDCD5DEE0C8B6B1C19B61696A98B0A686757190A0ABA6
876656616F7798BCA075737D8C7D5F577A956D6A8AA1785F
7B9E83546B7C5C40648566557A6E315D7F4E35629E7D4059
98A96D487891553A706A49436A8C7C5A595F7F969F7E4B51
74706E6158656F7282A37F66494E63727D3D3C6864607F92
797BA6B68F6388B06A698F88687EAA7A728190606D837363
7592736D798E9D77636962A969575A5DA46C664A6F9D6454
48B0B2926F3A78B998626762A9A07B5A6EC1D5B8B0D8DDD9
E7E6E6E1E5E6D2D3C9C187566D77A29C826B6C6884A1AD9B
80675666777E99B3865F78868B7D696881957070838B7160
76976F506C7F654C75855C4E7C81344D886636499C914246
8EB2704275905C325A7861444D6C8874695B687590914B45
707A9E9B8F95929E908E63543F5F8C81603E5462556EA193
5068A6B57B5299B85F5F9686638BAF847A86876575867066
76977A6B7983827663605EB174555768A66F5E436E955D4F
53B5B08C6C3966B99C5F6F5FA7A784655DB9D4B7B2D6E2D3
E0E5ECEDE7E2D6DCC9B080627B879E785D5A6C6E849D9F84
756B5C667A878F90695580948C7C7578878F777B7F6C6063
7B905A5076896D4F757B554F808E424D947A3A48A09C483A
7FB070375C816732477C704A3B4C777970575254739A684F
5F72ACB3ABAAA1AC7A5A4B57577C9C77434B68635483B58B
3A5CADB26946A7B45D61A283608FAF827B7F7B636F847668
708D816F8675647F716262BE835A5067A26A51427C9D6154
5EB0B2856C3A58B09B627063ADB18E7562B4D0B1B4D5E1D1
DBEBECEDDED8D5CDA98F7E7D95978F5C4B59707A8FA09174
69655E667D988A6B5255869D8872717B8684777C8161596A
8690585B7E8F714A6167514F8091524D8D82434F9FA1583B
76B07B3140716D3B426C684F3C455F6A6851424969928567
4C5A8FA294878C89534355677C857B6751646A685E99BF87
4760B7A6624EAB9A5F6DA8846489AE797673765D6A8A8067
717F80759C6C4C8E7F6867C387664F67A2674A4A91AB695B
5F96B17E724659A9A16C6C67B2B5937C72B7CFADB7DAE1D8
D4EEEAE3CFD1D0B483747E95B5A9845A5463768AA0A6876C
5E545667819E875A4A5988A082666B81877E79798B74656C
8C9B6D697A8D704757604F467E935A487D864C4C93A06642
67A69141326871504A595E554654565B5E604B4B6273868A
604B5972615A705B484E6D80997349576B78636A6EB0B375
657CB88E72659D795F75A8806C84A56F756D795F72998662
7E79787DA76B4799856A69B77D6D5571A66C4E59A4B07261
5871A57B735B65A7B17D6C64B3B89A7979BDCEB0BCE0E2DA
CFEDEBDBCBD5C59F737081A0C9B280676269799FAFA37E6C
5D4B527087927E5E54658DA17E636F8D8D7D817C96897164
8AA5816E778F6E4C69785B3B79955D457691574288A17041
508FA35E31607B70584F625C4C635C585B796C5758516B9D
8D59374E4D4F5F45677089979255344B7A85565F7EB18D5E
7B9FAA6F88818D6559729F73788F90667977806880A48460
907E75889D6E519E8469679D6A6B5E80A5705866ACA9796B
5252957F6D6C6B9FBF8B6D59ADC0AA7571BECCBEC4E0E3D5
D2E8EEDBD6E1BC977C7F8BA6C6A97B6A5F667DAFB0927370
6855628794827264647C9BA37A617097977B7E8198846B5D
879C7C6D7F9365507B97793C6C9065456FA36F3F7BA47E3F
427AA174364E778B6A4968664A5C62645776827160484F8E
A4784553666561478B9BA3916E4441548A8846528C9C5F5C
81A993598C9B8B5C57738A6286A37D617C93856886A97D64
998279938C6F5B9D7A6867855C646386A1705F6BA59B7779
54478F8D69736A8BBE93694D9EC4BB7366BACFD3D1DEE2D4
D7DFE7D9E4EABC9E9597A0B1B4997865546789B19F78646B
6C6981A29E7667646F93ACA471596B9B9C757383916C5D5D
848662658790524173A1934963896D4160AD8A4562958F49
416A918842325B907E4B6A754D485D705A5E757D77614872
9788666987897E5E92A8996A534F63708D7645669F884466
80A37B5584A7895E68826F578CAE73627AB3876082AA7670
937D7C9B7D695D996C696F8359636383A274646A9A906C85
5B509DA674746A71B39B674986B7BC7567B9D8E2DDDADCD7
D7D6DBD7EBEBC6B5AFA9B0B09B897963537196A486645759
6079A4B3996C656B7EA3B09962526D9D936D728B89585863
80764A5D8C944A2D619E9F576689734052A6954F42729759
3F5888A05720428C925D647D654953736D52516A858A605D
6F79767899A1947486917747485E8288805C508CA67B4876
8C9D5C5286A9836D7F8B575990B76B5D72C191657C9F6976
85787E9A6A60639A696D7D94626A5F81A6826B69998F668C
6563B2BE88756B5AA6A66E4C6C9DAE7A76BDDAE4E0D8D3D6
D7D5D8DBEDE9D4D0C0AAAA9C81787365627E998D7561534B
5682BAB689646C809BAFA68351557A9E8068819B8C4F5769
7E703F6193A8612F5C9DA358669080474B9A975B33599165
3A4784AE79303E86A178567588614A6D8A65414E739A8458
475F7274939E8D7B7A705A3E476C9280654653AAA0665082
98934F578A9A757C97924F608BB7696572B5966976916576
756D78955D60779B6C6F8EAC6F6F5389AB927369A3966D8C
7178BBC59572684A98AD7B525F899F8085BFD0D9DAD7D0D5
D7DCDDDDEAE7DEE0C8A29788776A676D7F888B746E66574F
6188AFA275596B8FB1B39C7347618EA3756A93AC9A53536C
80713E6692BA84455E989F46589891504393A06D39508679
483974A79D5A3F719B8A52618E794D5F95855546517F8858
3D56675F758175726D5F4F4456808D654E3955AF8D4D5289
94755A6D8984677AA494586D84A96F7677A1946972896F76
6D697B8A59698F996E6B9CB9786E489BB4967463AA9D7786
788AABB5966B62478CAC8258648D9C8588B5C4CCCED0D3D5
D6E3E6D9E1E0E0E1CC9F89868067637C9A8875606B665C66
8392938265515F88ADA796714870A2A46B6799B3A661516C
897E445C7BB5935055889533499A9A533484A5814441739A
6E335A91AF7F4155808F6C5E7A85604F7A8C72564257604C
49595E4E5459575F5D6154566E8E734B4B49759B653E5F94
885363808C725D74A27D5D7B8496787E758F927476848179
7077937A586F9F957068A0B1756949AEBD8B6C53A29E7678
70948A989564605388AA7D5A71A7A98A7F9FC1C9C7C9DBD8
D5ECF4D9D8D6DBDBCEA2838A8970708DA27B5F5669646482
ABAA846E61555D7E998F876E5181AC94575B93B0AB6F5470
9997514C5B9E915043799B383F91A1592166998A462C5AAB
943D4477AF944F4C71979B7B70807252576C776B504C4141
524F564B46413C52586D6775808555375878A179423E7099
7A4D708E8C5A517DA76055727B827F8B7D7C867B78909F7E
7284A871637CA6876D69A09C6C604CB1BA7B6443959A6E67
5D96697C9665666790AF745878BFBD967889C5CECBCBE6D8
D2EFFFE1D6D0D9D9CBA5869192858A9B9D725A5769666C90
BABB866661636D848B7972635D8FAB7D475A94AEA9785B70
9CA56346498B91533C77A94B3782AA681E4D868D5027489B
A456395FA3A36D5978A4BA996D6A797351415E75756D5954
563E565A4D443354678A899079623F3979A59B4D374E8098
6655879981485892AB554A64787476948E737D7974A2B078
7292A872738BA5766D73A0805F5347A7A770613F90996D5B
5194576E9D706E79A0BC745674C5CDAB8085CAD3D2D0E8CF
D0E9FCE8DED8E0DDC2A392A1A29F9C9A947966606D6F718B
ABB383605E7185968C6D625E6A94A5724D70A4AA9A7A6261
82A07245498C97544283A5503371A77A3347759A6F34407E
9D6D3A4B89AA8F5E709AB4965A4C72926D4145668D929088
774E5E695D61526E7C9F9287643F405C96A26534476E8682
4C62A0A0674573A7A75F4F718471678E98797E7973A7A26D
73A89D737891996C6F7E9D6C564D439E8F6B634B95977157
5B97576DAD817682ABC67B596ABBD2BD9695CFD5D4D1DFC3
D3E3EEECEDE6E7DCBBA3A4B8B0AA8E81848476707D7B6E7C
96A27B5A5D7A97AB976E5E657C94996F6089AD987A6D624D
62937F4451999C4C4588924D356599854E435DA093433662
8E804B3C5F9EA2564D66877F51405C8D8A6A474E7E8AA7AB
A37E727A71817E8B838C6D5D4B36638D927A3C436394805C
407AAE984F4C8BB39C756790886E628799857B7C7FA7886C
76B8906971918D6A6A84986D5F534DA27E6765609D97735B
77A26271C1917B80A8C37B605DACCEBEA9A9D7D9D7D0D6C5
DCE2E4E9F8EDE3D2C0B1B8C9B09E6B60718883879180606D
8C9673555A7B9FB4A0746375969F8D686E96A07D63666149
5C908B4651999F4A3B7A8B5A3E638F8B5A3742889E4E2A49
7D916B3B367FA05E392D506F7157466E84845E4F5C5A848E
9D9C8C8B8386808479633F39344B98A975573A647BA8744D
4D91A5834B5F98AC7D7D81A7846B6687928E778390AA7671
80B685636E908C73678F927A746168B279616677AA9B7161
93AE6970CA977A7898B8766A5BA7C7ADAAAED9DDDED2D2CF
E3E3DFDFF4E9D9CACFC9CACBA1834D536E8F929B97775466
898C684D577C9FAE99736C88B0B0835E74988B67657C7554
6798964A48859F5A38678D714964838D61313265965F2F40
68918D54285B9384521E3767907B4A54667F7B6E4E3A4E50
6E857D797B73676461433340497DAE924E42518B88905952
66A49C7152729C94587491AA796C738E8A9371809BAD7275
8DA37E6F81978F8070A08F81866E84BE7A5E698ABCA77462
9DB0686ABB96777188AF78796AAFC3979BA9D1DBE2D1D0D2
E7E1E2D7E6E4D7CED9D5CBB88665435F7B96989B85655870
8982634F638BA39D856E7493BBB5754E6F967B586D9E9660
6A9991453E729B7147628D7C48566A8C743F3C59987E4B44
5180A37B374583A9803D3E50809070584B66848F6C554132
465151545F5B594E54555D6B839E815E3E44729C785E3D5A
82B38F5D5A819E82486497A773758D8F8394727AA1A17075
9C8F7F86A09E88867FAC8E7985769ABC7D656F90C9B47A5B
8DA86C6D9F957C6F80AB838280B6BC888AA9C9DAE3D1D2CE
E4DBE8DADCE1E1DBD8C9B4946D5A54798A8E88846C5D6B84
8D7C6B6480A3A88D756D758DB4AE65416895765167A6A664
63907C353668977B54678D7E3C3E50898F615765A6A27048
4074A696503E69A3996C4A31558796774E496F948D8D694C
473F46494D596B667288918B9F8C423A50698C8A5C463C5B
93B27A4F698998785465A6A86C7AA78A858B7C83A8866A78
A9848591B19F787C82B08B6B7478A5A981747283C2B98052
729F817C8B948E7380AB8E7E87B6B68689B6CADFE6D6D4CB
D9D3E9E3D7DFEBE2D0B39679707681978E73676967698091
9079757E9CAEA07B7075707DA5A2624A709B7B565B949F5E
598D762F306592724E61888A46354484A5856F72ADB38E53
3E6794A0694047708C91602F3D68968E69465C7581A09582
716A685B58799AA6AAA392808D6E383C6C978D6D605C4F5F
999E6E56778B8D706D84BD9F5E7AB485947C8C9CAF6B637F
AE7D8587AEA0716E79B189656375A08B847F6F67A4B88554
619FA1908490A07A86B296717FB4BC9093C5D3E4E6DBD6CE
D5CEE3E5D5DFEDDDC4A1897A8FA5ACA181554C5E7D889093
8E757993B1AE8D6B707E6E6C8A87656A899E7E5E58868F51
4C95924735668E69424D789F6E43427CAE9C7774A3AAA274
494970A17F4A313B69998152404C78797662655963869098
92988D7A7497B5C5BC9E6F5F756F5E6287A37159727A6778
A48869647E958F6B7D9CBA8A5C86AF7E9A769EB5B6595F89
AB7A8177A1A379727AB287645F76906F8382684E84B28C5D
61A2B79A7C84A58390BA996472B8CC9C9CCCDCE7E1DDDBD8
DFD3DCDDD3E4EBD5C0A29798B6C2B28D6B4A4D6C9FA9998B
867178A1BEAB7E60708673626B656386A196716161847D47
3E8FB0754B658A76453A69AC8E514470A3A57C6D969FAA93
552B4894946B382B4D7D907D56415648698081605A636686
85888687818DA19A8B875254839D908D8777525A7885758B
A6836D6F889E8C6D92A69B756A96A48B9B80A6B6AF60759C
A2757D7CA6A7848286B18C6A6C837F608389644473AB9265
669CB7996D799B8F9FBF955D6CBADCA49FCBE3EADEDFE5E4
E6D9D7D5D2E6E9D8CDB7B9C1CFBE9A7260586B8AB5B59179
777078A2B49B6E576F8D81655D525D8BA8875D5F70886D43
3672A99261597E915D365EA6995C47608EAB907195A1A79D
652C347598975F3E414E7B8B75584E30527789725F513F60
564D5C6E6E60685248684E6E9ECAAC9469454B6972878491
8D7D6D7AA19A776DA0AA7E7089A291A5988CABAF957698AF
A37A849AB19A849095B29679839875628C986B4975A69266
638AA99460728798AFBD8A6472B9E5AFA8C8E4E9DFE2E6DE
E4E0D9DAD6E4EBE4E3D2D4D5C8A47C676B728AA0B1A17A6A
7480889F9A815D516E95997C6A54567A9B754E5979916D46
375D92926D4D6AA181434F97A974485183B2AF8CA2ABABAB
7E4C415880A98D60403059769192744646526D6B5D533341
3933434B533C372C36596296A5C39A7253516B7B6685A0A0
6C656989B38668719BAA7577A8B183AE8E8CB3B37684ACB7
AB8C9BB8AF817F9DA7B3998E9BA9746C9BA5795984A78E6A
5E789F935E6D7191B7B37C7983B8E8C1BEC4DEE3E3E5D8CD
E4E8E1E9DEE5F0EBEADDD8C9A98A72768788929B937D6A74
8BA5A5A0856F555172A0B0967A544C64856544537E9E7F53
43618C927B4C589997564286BA92504A7EAEC1ACB0B5BCC4
9D7D654A528A9E7A4F35415895BCA2745A4B575E5B624747
4E5351414A3D394059717FA09490695157809A8A5C8ABBAB
5B537C9FA862657E99A87883ADB692A98886A7A46085B6BB
9F92AAC3A87883ABB2A896A3ABB07275A6A8876D97AD8B77
6375A3996668607EB3A2749098BEE9D0D5C5D7DDE6E5CCC6
E5E8E3EEDDE7F3E8E0D9CEB3938B8798A897868272677093
ADC3B79C786A5A5E7DA7B295744A4B637D5E4257829E8F67
5164899B8C504B7D93664074AB9C654D7092B3B3ACB1BEC5
ADA88F52325285836E53394478A5A59484746C73757C7970
7A8376625F5C5F698BA0947B6C57515E6E93A17D56A0CCA0
58539AAC91546A869E8F7AA1A9ABAD958490997D577DB8BA
828AABBC9C7F8CBAB58E92A8A9AB747EABA1887AA5AF8783
7284AFA371675B74AD927597A8C7E4D1DDCCD5DCE4E4CCCD
DFE1E1E5D3E3F0E1D7D7C7AA99A3A8B3B79A736B66728BAC
BBC5B28F6F6A6D7B90A097775A435F81885F49647F878B74
57527496925443628B7C4F6283907A545A6A91A2938C909A
9AB4AE743D31627C857B4E46495F788F9BA397959192A49A
9E9E8C8888888181979D824C4B466F80757A7F6868AEBC82
5A6AB4A3795B708A9D6B79B5A196B27E84A49C59607FB9AE
6C82A3B28B8395C1AE75909CA09C7888AF99807AAAA77C86
7F9ABBAA7268637CA8887A8EAFCDD8C5D5CFD7E1E2E4D7D7
D6DFE6E0D0DBEDE2DBD7C7B4AEB4AEAAA38A62617496ABB4
B0B0A2856F72879E9F8E72574749799F9565506972697678
5C3F567F8E5C44558793645764878B5F4B54829A7E62505D
74A0B99E6B374B6F8A997B6137324E6D81A09F948D8EA29B
A19988969D997E686C61573C4E6294897061687591A08F6A
648CBE895F617C908B547C9B8A869F728DAFA14E7592B997
6982A3AE7B7F98BB9D699196A2867789B2957775AA9D6C84
80AAC0A668636E8FA183797FAFCCC4B6CBCADAE3E4E7E2DC
D3E5EDE2D9D4EBE8E5D9CFCDC5AF92867F765E6889AFBBAC
98908E7F777E97A899795C504D5E82A1A07758656658647E
714244658A745753708F72505182A07B5054869E8569413F
557EA9A891524266829898895B4A494E546E736868707A72
7D7C798C8878583B3B404F4D6A7F8E7D7663789CAC877062
6D9EAA6C50688B906C568372767F836F9AAC9C598BA3AE79
7191B6B1727592B18D698E9AA9756E80AD917173AF97607F
77AFC09C5D5975A0977F7274B0C4ABABC6C1DAE0E4E5E1DC
D5E9EDE4E2D2EAEEEBDDDCE1D09D766E6E75707E95A7AE9B
83737D7C828B9A947C64585D627274849C8A5F5B5E5B5C7F
89614D518290744E44767A4F4574A9A16751769592906C53
505D86929A6F4C616C788F9989815E4B4D504B40424D574D
5863637269544B3F405B7674887F6469776F96B9A8746460
749F8D5B51779585657586697C7D717AA59F875E92AD9D5C
729EC8B5726F8FAE8268849FA8706078A2876770B7936176
6CADBE965F587CAE937B6B6AB0B895A8C5C0D7DCE2E1DBDC
DCE9EAE1E2D5E9F2EAE0E1DBC48F78777B89919D9A8A8C88
7A6E7F85949D9B7C5E555D6F73785D5A7E845A4D58685A6E
8B89734A6A968B522C698763485895B4824B4E77869E9C83
644961728F876A6253586D7C8BA383717664594F49485047
4F605F6C6C5F67777C92A89886573C5E7C7F99AB85606C7B
878D735A5A8E9E7974967F7F9E886A84AA8D726194B38E47
67A0C7AD72769AB48167729B9A74587F9776546CBC8C706D
68AABB956E6486BD9B7A6A5EABAF8AACC5CCD3DAE3E4DFDF
E3E9E8DCDEDDEBF0E0DFDBC6B293979CA0AAB7BBA074717A
7E7D8F95A3A5946B5155668081744D3E6177544255755D57
75999752487EA0733C6D97895C4378AD9859334D5D83A29C
85564A54809A8C745A5A56596D97A19F9D888A8676666A6C
646F7F8A8D8E93ABB2AEA98F64313E7293897B7E60578BAF
9A6C666E6D9B986C84A57A90AF916888B185656EA0B78446
5B98B492718CAEB6826B65988871568A8C61446DB987836B
6BA7B38F7E7393C9A781715DA9B391B8CADDD2D6E3EBEBE6
E6EAE6D9E0E8EFEBD7DAD8C6B9AABAC2C3C3C7BD9C6E6A7A
8A939D9CA094785D58657A9896744D3C5B7D61485C896E4E
5687A4693A60A591506490A6753C5B8B9C7A3F383C5E808C
9E8153437196928A81816A5F556690989698ACB0A09196A6
8A7EA4A9A3A8A0A9AD9775644B396A94A17C6057536BADCA
914F6E958E997D5D8D9E7D93977E688CAC7D5E7EB0B47C57
629BA17479AABCAC7872699C7B6B5D8880544577AE858E72
72A5A880847C9ECCAC8B8178B6C5A9C9D6E7D2CDDDEBEEE7
E9EBE3DDEAF0ECE6D6D7DADCD5C2C8C9C4B7AB9686767B8D
A4AFA5998F75585B707F8FAAA2765A495E877752619A854D
38679B7D49538C895B5368977E3D38578992694C404D586E
A2A87C596C7C788C99A799855E496A686D88A0ADA4A6A5B0
9682A6A0998B6E6E776A555B525C949992695E435988B6B8
774C80B4B2956E608D8687957A636F8F8A635E8FB7A26C6C
8AB5986683BEBD9C66757897766E6F7A715657859D7E8C7C
7FA7A2767F7FA4C4A38F94A3CED5BFD6E2E6D2C7D7E4E7E1
EDEDDEE4F1EFDDE0DDD5D8E9E9CEC3B7A58D7766738C9AAB
BDBE9F89756053719295979E91706E5D6082835A5B958E56
37578883665769736F5B4060704B2F3E759291735E5A4757
8BB0A98F8A765D78859EAFA38262685353656B807B867A76
777077646B56363B4E596A8377829C7566546B5377969380
5B5C97C6C17F6D71867DA095655E879B6E496098B58D6684
B7C5876889C1AB8357748385757C84716665749190778384
94AFA67A7986A8B7948DA5C4E0D5C7D9E7E3D2CAD6E1DFDC
EBEAD5E1EBE8CDDCE7DAD4E7EACDB8A28A755D5577A6B4BC
B9AA837060616F95A89989786A6279695F73866856798676
63637580866B525E827D4440686D514E6C84A4907F7D5751
6FA1BAB5AE8B646F656F939EA2988D6C5C4F3C5952534638
4F59493847403F44587B989D938A774C3E3F72819F95674F
526BA0C7BF6573807A82B390596BA49B6144699BAD7B6F9E
CCB36A6C89B78E75627C856F718E947565748E9A8E797C8A
AEBAAA867E93ADAA888AB6D2E3CCC6D3E9E4D4D1D3DFD7D6
E5E8CBD8E0E7CDD9ECE0D4DFDCBCA28E8887766F90BBBDB5
9C82696C6A7E99B0A4846E564A50726A606D8F7F5757738F
937965729A8A574C79956B5985997D6A6D729B98949C795F
5B79929FA69C8E89614C67789AB6AE918068425A544E4E3C
5265555A645F7B74759BA789886D46443C477DAAAA84514B
73849BADAA5E7D8D7E859F7F5071AE7F4B4E79969D717AAF
C38850758EA3787E7F8D7D5E6EA09C7D6F7FA29D90807391
C2BDA58F91A3B39D7F8AC3D3DDCAC9CCEBE9D9D5D0DFD1D5
E7EECED3DAECDAD7E6DDD4DACBA48A8498B2AEA3B2C5B49E
7F6E738D919BAAAB896455514E516A696A799F97694E5F86
A18E686897A3754C57818286ADB49A766963828F95A79772
4E4548637789A19C7755524662909C9FA7A07A807C808E7A
80948C9A9B8DA3907B80816367564667687986A891694E66
A5A79A837B59809C978B7D654E709E6440608787866F87AF
A35D4F8B9B89627F8E936E5C75A68F7B7F8CB097867D6796
C6B29391A7B2B6927B8DCAD0D4D2D2C9EAE8DBD9D5E7D7DD
EEF1D8D4D9F0E7DADFDCDADFCAA49298B3D5DACCC2B99A7E
6F7895B1AA958A826A53526D7D7D827F8492AEA98D675565
929F806A82A79A694862819BB2ADA67858516176829CA386
66492D4657607D8890856D4236455C85A1B1A0979FB1B8A1
96A9B1AFA4938C79684846484B576F99A1A16B7672626385
AB9E8763545C88A29587755F6C8A7F57507B988270698EA1
804F6BA196674B6D8A875C65849671718796AF83706F6098
B7987D8FB2BCB18C859ACFCCCEDDDFD0E3E1D6DCDFF0DFE1
F1EDDFD8DDF1F2E2DFE0E8ECD6BAB6BEC8D8DAC9B09B7F68
6F8BA9AE99715B5C6367719CB6BBB4A9A2AAB4A89F856258
87AA8D63639AAF93635E71838F8FA98B5C463F4F5B799398
9D8A6570725A5664899DA07E4B2C3157728883718899897F
77808D7E74735C4D4E2B2E4F5F7892ACAF8E4351747C8186
7968685B5073969B7C76796F9CB26D596E99A27F62639694
685989A07C514C6585705276937E51617E90986C60656497
9B7A6C8AADBCA58D9BB0D3C9C8E3E9DEE0DFD5DFE6EDDEDA
F1E7E1DEE2EDF5E5DDE0EAEAD7CBD2D5C8BCB5A690837B6E
7E96A28C755A54638197A2C0CBD3C7B7A1A1A0888B8D8277
9DBB8F55457A979E896D5954686F97A07F5C3E3A384F6F92
B1B29E9D9B775753657CA7B3865F44414A534E3D534F2C3A
4A4642394050423B4D50607E969C979D95614363919F9075
52485B666C9E9E86716A6A87B9B2695F7EADA47158699D87
5B6B9A9163516D7D85625D8B976E4257737E775A5A646E98
83646482A5B4988CADC0D0C4BFDFEBE5DFE2DCE4E9E6D9D8
E9E3E2E0E2E2EFE4DFDCE1DDD3D5DAD0B393878685858A83
9098937064687D92ABBBBABCB1B6A18F7773715E6573868F
ACBF96633E515E88A48D67495755698E958A6C4C313C4E6F
89938C7B88816F726D617DACABA27B564130363D503A1B32
4E4834364D67635D7396A59DA7947D796D4A6188A3A88E72
5F586D839FC495676B6D619BAF89625E85B19B5E53799773
557FA78B585E969B8463719E8C6649647D725F515A657A9E
7C5C5F77A2AC928AB3C3C7C2BADAE5E0DEE4E5E8E9E4D8DE
DEE0E2E2E1DAE5E2E6E1DED9DBDED4B997746B7C93989996
A3A4997A7689AABBBEB39C8A7F896E5E50555A56574E6478
90A69C8E5F4B4070ABB098695B47436D95B1A87C4F49434D
5864603A4F677895906144739BB7A888674455738A7E707B
887F686D86A8A89498AC9F7F846F645B55547F9591887A78
7E737D9AB8B0704F63837E9B82656B77A1AD82545E888A63
5891AF875368A295756A7FA67B60608693755F5667708DA8
805F5C74A2A8908BB2C1C4C6C5DEE1D8D9E0E6E7E9E7DEE3
DDE5E7E7E9E0DEDCE6E7E4E0E7DFC3A089737189A6A8A1A3
BAC0B39B959BB0B8AA8B6E6169806F636073818378525257
617E97B3967A595F94B2BD9A77523B5178AAC0B3896D554D
4E636D44444A5973826832426590A6A59A868DA0B3B3AAA8
A79D908D98AAAC9B8F8360485A5C6A717C8B9C8568657786
88706D8EA1744A52709EA68F5D638BA5B99E6F607A89735D
6DA3A2714C6A9378617083996A627FA8A47B6C6D8A8DA7AB
856C67839FA48F96B6C2C8CDD8E2DFD6D4DAE2E4E9ECE6E7
E1EBE8E6F5F1E1D4DBEAEDE9ECDCBDA2989294A2AFAB9EA4
C0CDBBA89F928E90846D66718AA4A49A98B0BEBDAF816B54
485F83B0ACA4845E6F8EB7B89D744D3B45759FBCB19A806A
647E9988775744436C886046384F7386999B908D8E8C8380
807D776F6E616A705F50393E5B768AA0B6BAA9735D759193
7E6C708B8A574875A0B4B383586FA4BB9B7762708D7D595E
89A7805A5D757F635A7F897F5E6E9DBAA97C7B8AADA9B0A3
8884849B979E97ABBFC9CCD1E4E1DDDBD4D6E3E0E8E9E7E4
E2ECE2E0F8FCEBD6D8F1F2EAEAE0CEC2BAB7BABDB5AC9A97
A9B8A3958D79656A6E6E8095A6B2BBB3B3C9D4CECAB09976
5D62718A8D9C9C74605A78919D967C543F54658AAABAAD81
68748F9E9E80635279A6946A3C3546526871665A4F494448
4B4741393B2A3E564B525B788DA4A0ACB9A892727A969F94
7A8899A188666BA0C5B3A7817586A8A15F4F627D8C6C4C65
9596625A81866A585E8D8C69617DACB4A078899FB5AA9D93
8FA2A2A68D96A9C2C5CFCDD5E5DDDAE6DED9EADEE6E2DFDE
E1EDE5E2F4F7EEDFDFF7EEE2E2E5E0DED1C4C7CABCAF9989
8896847C7A6C5763788297A09891979098ACB5A9A9ACA997
877E6F62617C9D9A825A4B527EA2A18A705E3F4D82B3B179
4D42526F85888679859BA599795E463E444C4C3B38332B37
48473D373D435E767B8FA2BCB2A98C8A897575828F8B8591
8DAAAE9A7C7C99B1AB888C8CAAB1A7733F507B8D7C5C5774
8B7D5B6B8C804F4F63867D61778BA498857097AFA8967E84
9AB3AA988291BDD0C2CDCEDBE2D9D8EDE8DFEFDEE7DED9DD
E3F0EFEDF0ECE8E5E4F6E8E0E3E7E3E0CBB3B3BAB1A38E7C
727D73767F7D6E7F9AA2A89D8878746A737B786563768A97
9D967C5B4F597DA3AC916945628A95A0997A422F5384906D
4B3635455A6E7D7B737192AFB3996B625D595C4A56564E5A
787D6B666D8B9EA19FA8ADB5967B615A55597BA2976E6A97
A4B29D7B7192AF9C73526994C9C7AA604D709689645A7987
756465817B694255666B67628F938973646C9EB2947F6D7F
A6AF987E8099CACFB8C4D5E2E4DCDCF0E9E1ECE0E6DBD9E1
E6EDEFF0F0EDE7E8E5EFE8E8EDEADDCCAC8E8E9A968C8078
747F7F8A9DA4979FB4B7AF9A8A837B70756B5947424C5D7B
93978F7B654C547E9EA892574A5E7294A394694544586669
6D685C585E5A515250455F87A5A792A09D8A887C8F979392
A3A68B81839F9E8676736E66535053575A7399B1926E7DAA
A89A807189B1AB77523F538DC0B49D6A7394A1765363908C
66607A9265544F6D6F585964928A6B5E5E789B9F7A6B6E89
AD9F7F7192B4D1C6B0BFDBE6E6E3E7F3E5DFE7E5E5D7D9E3
E8E7E4E9F5F8EEE9E5E6E6EAECE8D9B78B737C8D908C8789
93A3A7B0C0C3B2A6A9A99F8D888F918E9085766D62504757
6C78879690705B5E6F899168474556758A8D8578644D4352
738C91908A663B36423F425169808EA5B1AEA5949EAAA89F
9D947C6961685B4841423E363F5B728697A6AA9B7E80A0B2
99847B87AAB99665545A647C9991848399A2936F5E6F887F
6975938D57526D837357576A8371575C738E917C605F789A
A88C707AADD1D0BAB2C2D9E0DEE2EEF1E3E1EAEEE7DADDE5
E6DED6DFF6FCF0E5E6E1E5E6E4E5DAB58C8396A7ABAAA7A8
B9C9CCC9CDC9B59A88847E78777E868A8B939593876F5E5B
5F5D65829A9D886557677C7B604B474A5761738F8E664241
597994ADB493635662655547455360617C988E7E7B857F76
695A52413B35384752545459768F97A5AEA695766F8EA998
858997A8B4A07D65628693787277769A9E826A717E7E7473
7B919A705467948B6A5D627F765749588097846156628AA8
96796E8BBCD8C1B0BDCAD3DAD4DBEBE7E3E8F1F1E5DFE1E4
E2D7D0D9EEF2E6DEE8E0E4E5E4E2D9C4B3B7C5CDD1D1C9BE
C7CECBBBB6AE9E816A65656B68615F666D87928C86848788
7B5F4755759DA6876E73859B89705635323D527C9C8F674F
4A50648DAFA88A808B9280726555462A3A54546363655D57
4D4A514749435D8B978B8787A1A599917E6A68576A969670
7B9AAFAC9C79605F6DA3BA90697281A4825C5A819B85646F
8E9E8C515579A783596077936D4A42567F9175575F739FAD
826C7698B5C2A6A7C6CDCFDAD6D9E3DAE3F0EFE7D8DDE1E1
E6DAD7DCE1E2DCDFEBDEDDE2E7DCD1D0D9DCD7D6DCDDD3BF
B9B1A8928B857C6B63656673725F4E5464868C786E8097A4
9A765148567C97958C96A3B5ADA48C5D4C4A4D608FA3876F
5F483D54757D6E7083979AA1A08868443A3136646E6B6E76
797C7B7173728BB0AD94897482837C633E3E595E77947B5B
84A9AF8C69524B6285B3B59670839B9E6D607897A0816474
8D8C724D607B91675067889461494A68848968586881ACA7
796D88A5ACA791A3C6C3C9D7DCDCDFD3E0EFE0DACCD9E0E1
EBE2E3E3D6D5DAE6F1E0D8DDE6D7CAD4E4D7BDB3B9B8B09F
978D846F6D717172818A889291806C69748E90705A6D859B
A3937D6962656B737A919EA8AEB9B7A2927B614E6C898792
97785144474E4A4E566E8494A9ADA29379575679837D8498
9E8E807C7C7F787470625C424D5D694E34527A8F9F9B7B71
99A89E7359596B8CA4AA816E73A0A57F6575919587767580
7B6962697A786D58687C8679555665888B80605E6E8BA995
72739BB0AE9B90A7C5BAC1D0D9DEDFD5DCE4D1D5CFDBDEE2
E9E7E8E7D4D2DCEAF3E9DFE1E2D7D1DCDFC39F8B88837F79
7C7D796D748284899FAFACABA69D958E8D9795775B636875
889098938E7A68635C6E7B86919FACB4B5A07E514E59638D
B4A9846F605B4E4239485E617890A3B8AC948C82725D5B74
785C515958604B3D4A4B51444C6B88766D8DA2B9C2A68B8B
90827E747B8DA3B3A5844F5082B39F6B6C828E7E6B718486
6F5564858A6A536692917455536D828E7B6D61707B96997A
66739FAEB0999FB5CAC1C2CFD4DADCD8D8D5CBD9D9E0DBDD
E6E7E8E7DCDDE4EBF0EFEBE9DED7DDE4D6BBA08B807E7A79
83929898A3ADA0909AAEB09D867E8B8F8E8D8B7C6D726157
5E6C899AADA59D916F5F50515B70879BAFB19F77604E4861
8996919C998D6D4F3D3C453741506993A9B1A9835F453D4E
5139333B3E5057687B767F8287A5BCB1A7ADA4ACAF907A7C
6B5B677B95A7A59D86665973A3B8A78A868D897A737B7F7A
706271887D50487B9E8B64415D83886F595F718B89958165
657590979E95ACC2CECECEDADBD8D6DAD7CFD1DEE0E3DCD9
E6E7E4E6E6EDEDECE7EAEEEDDCD6E2E4CFC2B9ADA8ADA7A0
A4B8C5CFD5D0B18F879DA88A5F4D656E6D6460626C827156
494A5F6D8C9CB4BBA17F4D34365167728C9C9E989077614D
4D54628DA3AB9B85735E4F3636363F56718D8A7570777371
6C5F595D6A7D92AFB4A1A3AEA8B5B9B19C8F7B777C6D6571
6B69788A97947B68646B97B5C3BAADA08782828A8F7B6465
797F807A6A4F5C8D8D6E5E4C758F7E524765869882786562
7E89827B8291B3CACBD3DBE6E8D9D3DBD9D4D9DEDEE3E2DB
E5E5E0E3E9F1EAE5D9DDE8EBDDD6DEDED0D2D6D4D4DBD2C6
C1CCD2D8D2C6AA8D8299B29D765E6E6C6250454D668A876F
513B37354A5C85A2AFAE8A6C5D61503744566B889F9E9166
3E2F33597491A4ADB1A38E746F5F50444C60565266859190
949897939EA5A6ABA7968E8F8183827F685D566275787C8E
979D9E9582685851618DCDCDC2B297816A67718A8E69576A
83887C67687689977256637095947753567A94916B565870
9FA07F727A99BECFC8D2DEE4E8D7D4DCDAD7D8D8DBE4E8DF
E2E2DCE0E8EFE5DDD1D7E4E9E3DDDCD9D7E0E6E4DFDDD8D5
CAC4B6ADA29D948A879AB3A99181908D816C5F697F9DA69D
7E5642383A354D6683A5B2B09F926534282B3A537693A489
624C3D3E465E7489A3B3B0A7AEA696837D7960554D4F5A64
78888A7F7F7C6F6465675E584E505B63534E5D82A1AAADB1
B1AF9D7E60495A6D81A6C6B1A69B76595D6870796E5F6B85
81706059739CA28A59517393A68D7164769194805C526D8A
A99C7E7D8FADC9D3C9D2D9D8DAD3D9DCD8D3D0D0D9E4E9E6
E4E0DADEE9EFEAE0D7DDE5E8EBECE2DBDDE1E4DDC9BABCC8
BFAA8D8282888684868D96887A7B93988A79788D9DADB4B7
A78F847F724E454C5F80A5B8B0AB92775B3D302C3F60848F
8682724A333E4D5B728E9394ACBEC2BBB6A48B8369493D38
41474443474640383943464F574D536867698BB0C3C9C5B0
9D937B6061688AA4A89E8F8586786050718988725E6A7F88
6D53506487A18E6B516485978F70657191A18C6F596A9BA3
9277748DAEC1CACBC8D2D1D0D0D4E2E0D8CFCBCBD8E0E8EF
EBE4E1E3ECF0EEE6DDE1E2DEEAF5EBDEDDDCDDD5B79A9EB2
AD9176788B91817777767163606F837D6155698A989DA0A7
AEB4BCBCAA7D5D52545F819892949BA48D6751413F434F60
6E8A9A6D3E3A3D3E465E5F5A687C8993A19E989C9786725F
53413338454E5355545A63849C847387979ABEC7BBB6A985
72776D7191A5B8C3B89168626557546594ACA0816D7B796B
58566A8B9D8E634F678A957E5F4D637F9BA17D635E82B9A5
6B5271A0C5CABAB6BFCECAD0D1D7E8EADBCFCCD1DDDEE9F6
ECE9F2EFF1ECEAE4DDE3E2D9E1EDE6DAD9D8DBD5B79799AA
A88D7B879D967967696A65636F83866D49455B7171707581
8E9BA4A6A599856B4D35476469768FA69B8A7E736D593F31
3C6DA69B77654B312A3736373C3B3E506A767C7D8CA2A5A3
9B8677747B817F8B959A9FBFD4BCA3A8BAB1BDA88F84775D
5368799DBCBDACA39C87665352515D86ABAFA08E7D7C6959
5E7B97A79D744F5692AE9560414A7F958E856968748FAE87
4D5189BACDC1A1A1B8CAC6D2D2D5E7F4E4D7D4DEE8DFE9F0
E1E8FCF7F2E7E7E4E1EAF0E6E0E4DED6D6D8D9D2BEA7A9B6
B69F959FA793786C7177787F94A99E82696D716853484C53
53575F6B83A6B29767373046556882908888848890886E4E
4B73ADBEB3A4835E555A535E675946424B51554854748CA5
B6BBBDB8B5AD9DAAB7B8B3BBB8A9978E917F786964646665
63738DB4B5A2755F6570675A64768AABA58A7D7C7579736F
7994A69A8365657CADAE85574E6FA7A0735E5C7C92938B67
527BB5CDC1A88E9DBFD0C9D4D4D6E2F5EBE0DFE9EDDDE2E2
DEE5F6F2ECE3E9E5DFE7F4EFE1E1DFDBDBDCDAD4CBBFC2CA
C8B9B8B9AF9A918F92979595A1B2A694919E98836E626159
47455361749AADA18869534C4D576B72666267839CA5A188
7E91AEBBBCBBAF9BA2A58F8B9595806B686F705548464D62
7A94A2A19A938E9CA29E91806F6A655F5B4B424E6377899A
9F9C9DA287744A3746626D7D93A8B7B88E665D666E848A86
81878B74666184969C866E667391AA9165596D8F99856E69
80B3CFC4A38C8DACCED8CED7D8DBDAE2DDDBE0E8E9DDE0E1
E4E2E8E8E6E3EBE4DADEECE8D9DBE2E2DEDDDDDDD9CFCED0
CECACFC8B5ACB9BDB8B5A7948F978B8899ADADA7A5A4A696
7C7376746B6D6F72808B83675048535A4B3E446578828E82
77808D97A1AEAEA6B9BC99797A949B989DADB294795B4639
3849514E485361696D6F67544D55606E7371667A91ABBDC3
C4B08F7A656758545E798FADBCBCAC90705F616E7F958F7A
6D65655C606C8F8C7157627E8D8D8276748393917D66638B
B9CEBDA187869EBCD1D6D1D6DBE1D4C8C5CDD9E3E6E1E3E8
E5DCDDE6E7E6EDE8E0E4EFE7D6D7E1E4DDD7D9DFDBCBBFB9
B6BAC3BAA9AFC8CCBEB5A994857D6866798D9AA8B7C1C6B6
A6A1988770563D3F608EAE9D795945413932353C36374C51
49515F66707D7F7EA0B49764516576818AA0B1A89E8F826A
544939353A525D504F5A62606473849AADC0B7BFBFC3C2AF
A38D6962738895A099A4B5C5C2A879555766727E8F9C8661
544B51667C878D7252486C8C8D725F7094AEA6805D576FA8
CCB68C7E7F99B9C6CACDD2D5DBE3D9C6C3CDDAE6E9E4DFE6
E4DDE1EFEEEAEDEAE8ECF1E9DDDDE4EAE3D8D7E0DCC8AE9B
8F9199948890A4A79A98A09C8F795D52565E728695A0A89E
A7BCB5A4987B5045618CB3B4A48E6854565A513A251E2D37
2F3A48453B3C404C73918B6955595A5851596C7A858D9DA7
A1886765748888716D7E91999BA2AAB6C2D8D6CAAA958C7B
6D5F506893AAC2D5C4BBC1BDA984594A647D838384897C58
4B4B60869C967F6057618382735F678CAEAE8E6658718BAB
AD8365758EB5D1D1CBCED3D7D9E1E1D6D9DEE6EDEBE3D9E0
E5E6EFFAF1E9E9E6E7E7E5E4E2E5E6EEEEE1D8DDDFD0B398
837D807E6E666E7470778C999381726A5D535D615E616765
81ACB0A8B0AB8B7F9199928694ADA292999D86625956524C
444D554C362A2E38474F596373868D80624A40494F4F6996
B2ADA0A7AFB6B5A0A0B4BEC1BFBAB4B0A5A29E89614B5469
74716F8CADB5BFCDC4B5B4A07E62596A8F9B8675696C7865
526289A5A78F706577858D6A57618DAEB18E67576A9CA499
7F60648DABC7DBD9D7D7D7E0E0E1E2DEE6E7EBECE7DFD8DE
DDE6F3F8EDE7E5E4E7E6E1E2E4E6E3E9EEE2D0CED7D4C2B2
A3989893755B5B65646574818580868C7E6E6C6250444546
5C7E838192A4958CA19D7555658D9999A9B5A288929D9388
8688827C69544C483B2C334F6D88A5AA98806B6A644F4E68
8399B3C1BCBCBCADB3C1B5AEAB9D91897560584E43445B8A
B1B3AAB5C4BBA9A4A5988F7757506384A59C6E5D5A698A84
6B83ABAF9F867681978F7C5E5F7EA9AD9470626B84AFA480
676587B6CAD0D7D8DFDFDEEEEDE7DFDAE0DEE2E5E0D9D7D8
D9E3ECECE6E8E4E4E8E8E7E7E6E5E0E2E8E1CFCAD5DAD3D2
CBBFBDB7906F717E7C726D6A69697C98A4A19B8D77656768
6665584C58767770888B674A4F637179848980778CA2A7AA
AFA89EA7A696887764514C54565467777E8B95A1A4927969
616E8E988F929792A0A286818278787D796D6063778A96B3
D6CFB0ADBAAB88797E6F60585468849AAB976C68718AACAF
98A6B59E857B8090977B6A72889EA0856E738B9A98A18F74
7487B0D5DED7D2D1DBDEE1F1EFE4DAD4D5D0D3DEDED9D9D6
E0E3E2E0E5EBE4E4E4E4E6E9E7E8E7E3E5E4DDDAE5E9E5E2
D3C3C5C7AB939AA5A1937F6A5C54638EB5BEB9B2A89B9D9C
886F543D384F5D657F866F5A54555E6760514A5266747F89
8B817E94A4ABADA7A39A8F8B7D5D504B485B727F8A8F8B85
73605E5C52545C62726E5C6E818795A6B4B6A8ACBDC7BDB8
C0AB837F8C7D64646D5D50637DA1B5BDBBA7949DA0B1C6CC
BDBAAC8972747E8283767D9BA59B7D626692B5B599898385
9EB1C7D4D5D0D0CED2D3D9E6E3DBD7D6D3CDCCDBE1DFDFDE
E3E2E0E2EDF1EAEBE8E3E6ECEEF1F0E4DEE2E5E4E7EAE6D7
B8A2ACBCB7B6C3C6BCAE9981705E5469879096ABBDC0C0BA
A59388755847465A798A867866544F514A41414A4E444147
4A484C5863778B9DB0B5B3B8B49B8E7F665D58473E46618E
9B7D6258493D424650596186A6B3B5B7C1C7C2C4BEB1A090
8C7D67717868687D897E7996B6CBCCCDC3AFACBEBABFC3C3
BAAC9C88868F8A7D8697A5AF947562667FA5AD9D898490A6
C3CCCABAABAFC4CDCBC7CFDCDDDEDFDEDBD6CFDCE7E4E2E2
E3E6EBF2F9F3EBEEECE4E5EBF0F4F0E1DAE2EAE3DADADAC1
967F8A989DAEC3C6BBB1A398917B584B52566383A3B2BBBD
B1AAB1B29977666F7D82827D786E615651504A453C2E2A2F
313133353B4B5967747C8CA0AAACBABEAC94785639325190
B7AB948E83757672708092AEC3C7AE8E828992937F6D6460
666C718A8B8397B3BCB8B4C5D0C9BABFBBA59CAEB0B0A59E
9C908C95AEBDAB94A0B3AE99705E6D839397847A8798A5B3
C2C5BC9E838AB2CDCCC8CFDCE1E7E6DFDDDCD5E0EEEAE3E2
E4ECF6FAF8EDE5E7E6DFDCE1EAEEE9DDDCE8F1E7D8D5D4B8
8D7C84817883989F9A949199A3946B504C4E53606E7F98A9
A49BA4B2B1A9A5A4937864637B959787776D605556626B67
5D5148474E53514938375063697C9BAEB6B2A89F8C7D8CAB
C0C4B8B6B7B7BEB9AFB5BDC3C6C2A27052596C6A5A595D5E
6E8091AEAEABBDD1D2C5B9B8B09F97A1A38E7D8896988883
8C898FA8CAD7C2ABA9A48E786C7892958A80747D9AAAA59E
9DA0A193828BB0CED1D2DBE1E2E5E1D9D8DAD8E3F1EAE0E0
DDE7EFEEECE9E7E7E4DED7D8E1E5DFD6D8E4EBE6DEDBD7BF
A19EA898796E76786F656A88A9A57E6562615B58555B7386
8179818D8D91A3B0A68C746B7FA4B8AE998E87818AA1ADA1
938A828284807E725241473E31425D6B7C8FA3BEC2BBC4BF
B8C0C2C0C4C9CFCDC3C2C4C5C3C1B48F6C6D807C74889793
A1B0BACECABEBEBDAC907E7972707476746B69788B8E8386
9AA3ACC1D3D3BFA8947C6F7890A9AE927C8691989D998B80
7C7F8A98A3B0C5D2D4DAE3E3DFDEDAD8D7D9DAE5EAE0D9DA
D7DFE6E6EAF0F0ECE9E3D9D6DBDDD7D2D8E1E1E0E1E2DCCB
BBC0CEBE957C7C755D45456C9DA2847E8B8674695A4F5A63
5950575C565D7EA1ACA69C8B8398B3B29E91898081939D92
89909EA9AAA9B3B29986795F4A535C504852647C8A91A09B
92A0B3BAB7B4B2ADAAAAABAFB5BECCC2ABA0A6A59FB1C2BE
CCD4C9C6B7A2978B725953565C65665F5F62758C969899A1
B6C0C4C6C1B6A18770606F97B9C1AD89809CAD9C81727075
797E8DAAC6D3D8D8D6DBDFDEE1DFDBDDDEDDE1E7E3DBDBDA
D7DFEAEDF2F6F1EBEAE7E0DFE1DFDBDCE6ECE2DAE1E5DBCA
BABAC9C5A799A39D79554B668C876E83AAA89184705B6268
57453F3D3C47637C7E787F7E747F95938275675855616A64
58607B8B8A8FA2AFAEADACA3999995795C5A5D5A5C5D5D57
545E7380797679757A828080899AB0BCBBB2B6C1BCB8BBB7
C3C4A6918376746B5B5C6E7B878C7F7B837D879B9DA6B7BE
C4C3B8A6958B7760586185B5C8B69A84869A9F8466647281
8C96A7C0D3D7DADEE0DFD9D8E4E7DFE1E2E1E5E4DBDEE7E1
DAE4EEF1F3F3ECE9ECEDECEFEFE9E3E4ECEFDED3DCE3D5BA
9F98AAB4ABB1CDCFAF90858F94775A7AAEB3A09C9281868B
775D4F48464C514C3C3542545E676D63595244363840413B
3034474F4A4F667F8E9093A3AEB2B7A9959692868071543E
3833394441444D44495D61636A6C71808F97ADC5BFAFA394
958D72686C727D7B7587A5B3B6B2A4A6AB8C778594ADC6C0
AEA491766A6B6058647EA3BEB79B8782807C7973717F8F99
A1ACBAC9CCC9D5E4EBE8D8D2E3EBE3E1E3E3E5DCD2DCE9E1
E5EFF4F1ECEAE9E8EAEEF1F5F2E7DDD9DDE0D7D1DCE4D2AD
898397A19BA8C9D2C1B3B4B9AA826882ACAE9C9EA8A6A7A7
92776B635B5D58463B37343C4C524A413C3932344A595040
38353A3D362F395462544C6279889EABAFB3ADA7AB9F8068
60554E56585D604A466275848D7C6D727B8AA6AB958A8476
706761707E8A9A9E9CA9BCBAA6A3A7ADAE8C6D7B96B0BB9D
78736D5A575F62728EA8BBB2927C7E89837072869BAAAFAF
B2B3B7BFBFC1D6E7EAE8DAD0DDE8E1DEE2E6E5DAD3DFE8E4
F2F8F9F2E8E4E5E3E5EBF1F1EADED3CFD2DADEDEE3E5D2A9
888B9B927C80969E9796A4B3AB8E7C879A937B7C96A5A6A1
8F7B7B7C767974646468584D5451494B4F4E4F6187A19581
7C746C6E674A3B4E61584B4D4F4F5A708DA3A3A7B9BDB2A7
9F938B90949D9D84839FB0BEC6B5A2968D97A1845C607478
797B89A0A6A6AAA59D9EA28D70798C929F998895A9AFA172
4A4E5C5B616E7C99B2BCB7956B65809A998990ADC3C7BDB7
B5ADA8AFB5C0D7E4E1E1DDD7DCE1D9D6E0E8E6DCDDEAEFEE
EBECEDECE5E3E4E3E7F0F4EEE6DFDAD7D8E0E7E8E5E1D1B1
9CA9B196736E7670625C6A838F86797B83785E5567787A75
6963728897A4A59A989885737071788A95908A93AEC1BCB6
BAB3AAB2B498808A9FA1907B6652413C537075788FA4B1B9
B4ABB1BBBEC8C8B4BACFCDC8CBC6B597858F93765B6E919F
A5AEB9C2BEB5A58771727969607C8B8696A1999CA0988767
4E5468788998A1AFB2A49274576189A7ACA9B1C4CFC8B6AA
A49C9BA6B1BDD3DFDBDBE0E2E2DDD3D4E3EDE4D8DDE9ECEB
E1DFE2E4E6EAECECEEF4F2E8E2E4E5E2E1E1E1E1E2E3DBC9
BFCBCDB2958D89715240435A75796C6C75705E4E49505756
52545F7895A8B1B7B6ADA1938D99AFC0C8C0B0AEBBBEBABB
B9AFACBBC9C2B4B6C5C9B8A8A0947E645D665B474C5E758F
938C9BA9A7A9A8A2B4C2B2A4A2A7A38B8290979493A4BDC0
B8B3A799918D806554647B7984ABB49F9A94857E7A767A80
838794A6B4B6AA9D8D776A615B7094A6ADB9C1BEB7ACA097
8F8993A9B9C3D2DEDCD9DEE6E5DBD2D8E9EEE0D5D6DEE3E4
E6E9E9E6ECF4F5F3F1EEE7DFDDE2E5E4E6E3DAD6DDE5E5DF
DADAD5C9BEBAB295715C566580846B5B5E62645E4D495250
4F535256676C70889FABB7B6AEB0B1ACB2B2A2A0ABA9A098
897B7B848E8D868CA1ADA9ACB6B7B2A8A2A08D6C574E5465
6458606A61544D597A8A83848486949DA5B0B7BFC1BFBEB0
9B846856545B676F7890A69E9BB8C6AC8B7366686C7184A3
BABDC0C7C6B390766A616168728BA19EA0B8BEA4887F878F
8B899CB9CDD4D7DCDCD6D9E3E3D9D4DAE4E5DEDDDEDDE0E4
E9F3F1E8EEF6F5F4F2EAE3E2E4E6E3E1EAEDDFD5DCE1DEDE
DBCCC3C8CCCBC6B7A4958B8D9C9B7D63606A7B7F6C595146
434E4E484A4A4B638397A2A29A8E7D7784866E5F676F6C62
554D4C50534B3F4558646C7E8F9699A1ACB4B2AC9E8A7C70
61595C60563C22233E516284938C97ACB2B3BEC4BBAA9583
786A5F65717A8AA3B7C0BC9F80889E8F6F5F647A8F96A4C0
D4D1C7C1B89D75636A70778395ABAF988C9FA6896A657D95
9AA1BBD3DEDDD6D7DAD7DBE3E2D9D4D6DADADEE9ECE4E2E3
E1EAEBE3E7ECEBEFEFE5DFE6EFF0E5DDE8F1E8E1E5E1D3CD
C5B1A9B7C1B9B1B2B8B8B2ADB0AF9E8B8995A1A497816D5F
5E6768564849515B6866554F554D4350635E46353A484636
323B465661553E373B3C434E56595555677E95B2C2BEB19E
93989790887251424E60769FBDB5A9A48E808D9285786967
7B8A97B0C0BCB4B8C3BBA07D5F61767D7D8390A7BCBDBFCD
D2C2A896938464627F9299A6B2B8AE8E7678807C75788DA4
AEC0DBE2D8D0CBD1DADCE0E5E1D7D0CFD6DCE3ECEDE6E3E0
E0E2E5E3E3E3E4E9E8DCD6E0F0F5E9DDE0E8E8ECEEDFC5B2
A28E87969F92848DA3AFB5BCC3C5BCAEA8A8A7A9B0AB9D9A
9EA097764D3D4043453E333C463830455656575C6164573F
3B52708D9E947B70757A746250463C3440566A859FACB0B3
BBC3BFB7B2AB9B929FAFAFB8CFD2BFA2755761685E606B7C
9DBBCCDAD7BDA0929595806B6C778091ABBBC1C8C7BBB8BE
B9A28370787C69698EAFBBC1B8A2917E695F6981959DA7B5
C1D2DED1C0BEC7D2DADADCE0DDD7D1D0DDEAECE9E6E6E8E5
E6E3E9EBE6E3E7E9E5DFDCE2EFF6EFE5E2E0E3EAE8D4B69B
8674696B716C657082888EA0B0B4B1ACA7A29897A7B0ADB5
C0BFB49C775A53524B444F686B56546E828B9AA49F989486
7A85A0B2BDC1B3A7B0B8A99385838681756B5E5766788297
A6A0A3B4BCB8B0B0C4D5C7B8C3CFCBB68C70808C808AA3A9
B1C6CFCAB28A747074858A8599ACA8AFC4C9C9C4AD949096
9282726E81968A7B90B4C8C7A77C6C6F6D697593AAAEB3C2
D1D3C4B2B2C2D2D7D5D3D7DDE0E3E3E0E9F4EFE4E0E5EBEC
EAE4E9EBE4E3ECECE6E9EEEEEFF1F0F0ECE4E4EAE5D5BDA3
8F82705F5B5C5B6066605E6A75777B869295887C848F939D
AAA9A19F9685838A7F6F7D999C9098ABB6BBC2C0B0A7B0B1
9B97A6A5A4B8BFB2B1B0A7ABB9C2C9C6B39E866D68655E6D
75626686928A8791ADBEB1A1A8B3BABCADA8C4CEBCC1C9AE
989E9F99846A7285899EB3B0BED1C9C6CBBCAFA5886B6672
7A7A7D89A1B4A78884A1BAB38D635B6D7E8B9BACB2AEB3CA
D9CAA9A2BDDAE1D8D2D7E0E5E8F0F6F2F2F3EADDDCE2E8ED
EDE5E3E4DBDCEAECE4E9F3F3ECE7E9EEEEEAEAEDEAE2D5C2
B4AD9B8274706862616162635D5658626D72665556616468
74766F71746E7693A19BA1B4B8AFADAAA2A2AAA8998C8C85
706E796D617892948B838499B3BEBBB9BCC1C0B8AB8E716D
6A5855615E55576378898078858A888F92A4CACDBABDB186
6E7070757D85A4BAB2B9CBC6C8D3CCC5C0A483766C5D6175
86909CADBEBFA98B8092A191725C607992A7B7BCB8B2BACD
D6C0A4ACD1E8E7DCDAE5EEEEEDEEF2F2F0EEE3D6D6E1E8EE
F1E9E5E6DEDCE7E9DFDFEAEFE7DEDCDFE3E7E9E8E7E5E0D9
D4CDBDABA0998C828592998E7B726F665B53494248535049
4E54514F4C4345648894939592857B7770717C7D6E625747
3F495249393D535B50474B556C88929AB0BDC0D0D7C2AA9C
8D807F7A6D6155433F4D5156737E6F645B68898D8A948973
72747486A1BCD7DAC3BFC8BEB3B2A799927A5B5B6B74899F
A2A6B2C0CABFA6928F9890705A5F758FA0A9B2B7B4B5BFC8
C9BFB6C4D8E0E2E2E5EBEDEDECE5DFE2E9EBE4D7D8E6EDEF
ECEDEDF2EFE7E8E8DFD9E0E8E3D9D5D5DBE5E7E2E2E4E3E5
E3CFB8B0B3B1A69EA7BEC7B5A0A2A89575605B5E68706C5F
58544C494A40343D586A6E6E6653474C4C4A555B524E4C48
4E5F6C71695850504E53533E375165748B8B849CB9BEC2C6
B9AFB3AEA39C87614B535B628097917D615662687484868C
9B9C9BAEC6D1D3C9B7B8BBA0847C766A67696C7E93A0B8C1
ADA1A3AEBBB9AA9E9D997F5D587393A4A09499A8A8A7AEB0
B7C6D6E0D9D1D9E1E3E2E1E5EBE3D6D9E2E8E7E0E0EBEAE6
E4EEF0F7F9F2EEEBE4DEE0E6E6E2E0E0E2E6E4E1E5E7E3E3
D9B7989CB2B6A79CA4BAC2AD9BA9BEB4937E7F86888E9693
86715B58615C4D4A4F545B5D523E343B403F516D7577848F
949CA5ACAB9A837C8B9D977358596166675F59677C899CBD
CCC9CAC4BFC6BEA59494989AA6B9C1B89D877F80909D9FA7
B6BCBBC8D6C3A79B959FA179525566676780A6BFC1BBBEB7
9C89828BA3B6B6A69486736A7B99AAA48D7B8AA4A2959196
A7CBEDF1DBCED4DCDAD9DCE3EDE9E1E1E1E4E7E5E7E7DBD7
E4F1EFEEF2F0EFEEECE8E6E8EBEEF1F2EDE4DDDFE6E4D7CA
B99B8494B8BCA38D8C989C87737F9B9A827C8C918991A8B7
B6A38C8C968C7B766F67665E4D424253676F81A2ACA2ADC1
C3C4C8C8C8C4B4AEBBBEAA98908E94907969675F58555E86
A9B1B7BBC0CDCDC5C1C0C7CFCBC8CCCEC9C1B1A4B0BCB6B2
BECFCBC6C8A97E6F676D765F4A60838B859BC3D8D0B59B87
7B79798199B0B29B827A8293A5AAA1907B748BA7A7978F97
A9CBEAE8D6D2D9DEDCDCE3EBF0EFEFECE2E1E4E6EBE3D5D4
E9F1ECE6E4E6E8E8EAEDEBE7E8EBECEFECDFDADFE2DCC9B4
A59B93A1BEBA977B7071766D5D667E745C6883837786A6C0
CCC5BBC3C7B69E94979FA08F7B707085A0AAAFBFC0AEAFBF
C4C5C9C9C8CCC8CBD5CAB3B1B3AFB6B8A08F8E7C604A4055
67687FA5BFC6BAB6C0CAD4D8CBB3ADBED3E1D2B2B1C1C1BD
C6D4C4A18E745B544A495D6D7B97B3B8ACB0C0CBC49F735B
6180969591918C7E7A8BA4AFA28C83868782899DA9AAACB3
BCCDDBD3CBD3DDE6E8E3E8F0EEECF1EDE2E0E2E7F0EADEDE
E5E7E4E0DDE1E5E2E6EDEFE9E5E3DFE1E3DEE2E5DFD6C4AE
A5ABA8A5AEA3836B605A60676474896F4D617B706C8AACC4
CFCAC8CECCBEA695A5C7CDBCADA4A4B4C1BCB5BBC3C3C2C8
C9BBA9A09EA3B1C6D2CBC2C6C7C5CCCDBAACB1AE977A6A66
4F375698C6C19A879EC2D0C9B89B8A9AB4D1D7B7AAB9C4C1
B6AE9C73564F555F5A556A92B2C0C7C8C1B6AAB0B18E6856
6398BCA6816D697288A5B3A17765809FA38A7381A3BAC5C6
CAD7DBD0CACFD7E5EFE7E8F0E8E5EDEBE4E1E0E6F0EFE4E0
E3E5E2E1E2EAF1ECEAEEF2F0ECEAE4DFDCDDE9EBDFD5C5AB
9FA59C88858273675F575B68708594704B5E726A759AB1B5
B6B3B7B5A89E8D7D93BDC7B8B0B0B8BFB29D9396A4ABA7AD
B6A6856F666E8AA6ADA8A9ACB2C6D7D1B9ACBAC8BBA49E9A
785C72A3C5B8805D7DBAD2C6BAA3877B7B99C0BCADB1B2A3
8067615A5F7388948F868DA2B1AFAFB9B79B8190A6957D77
84B2C89D6F667591AAB5A986636CA0BFAB7B5C72A3BFC6C4
C9DFE8DED7CFCDDEEDE8E7EEE6E4EFF0E9E5E1E6EDEBE1DE
EEF3EFECEFF7FDFAF2EDF0F2F0F3EEE1D6D9EAEDE4DDCDB4
A29C896D686F716C6055535E6977795B445567697A989A86
7D838E87746C67647494A7A3979293886E5E5D66706B5F67
797A6C5B4C5167787C838A837D92AFAF9995ABB7AC9D9CA0
97929C9C9A96745B7DB4C3B5B2AF9F846674A9BCAB94806F
574541598DB7C9CCBFB6AD947C788FB1AB795D81B4B6A198
9EB5B280637598BAC7BEA78C8196BBC29B726886B3C6C6C3
C5DAEAE6E1D8D1DDECE8E4E9E8E9F5F4ECEAE8EBF0EBE4E6
F4FAF5F2F2F1F2F5F3EDF0F2EEEDEADFD4D8E7EAE7E5DBCA
BFB69F82787F88846F5B51565F5E54494B59605F65767661
5861675C4D4F606D6869808774655E50474C4E5156504C51
4D484D4E4C56594D4A5A6C655054717B6F7899AEB3AB9687
7F849080707A7B7581908A7E899DA6997673A2BEA473555B
6E716378B5D9E0DDCBC2AF764D5B90BEA968578DCAD2B69E
94988E716F90B1C3C7C2B4ABADB3BAB2968995AFC7D0D4D1
C7CFDFE1E1E1DEE4EEE8E1E7EBECF2F0E9ECEDEFF2F0EBEC
F0F0EBE9E5DEDCE4ECECEFF1ECE7E2DFDDDEE4E6E8E9E0D8
D7D6C8B1A29CA09F8C776E747A6D5E627275695749505D5C
5A5F5F554A51708776616B7160514B4E667E776559556368
4E3740546C7D6D47303B5A665247504F44588CBBCDBA9681
76768B928A919C9A89735F5A6F869093847FA5C3AC78607D
ABB8A7ADC9CAC5CBC1B290584D7AB2CAA56F6FA0C5C0AA90
7B7A7E869CB4B7AAABB5B6B9BCB4AFAEABB1C1CFCFD1DDDB
CDCDD7DCDCE4E7E7ECE8E3EBECE3E2E4E6ECEEECEBEFEDEA
F1ECE4E4DED8D9DEE6E7E5E9EBE4DEE4E9E3E1E5ECECE1D9
D9DDD7C9B9A49899958D8E9BA0958F959E98836A5451606D
6D656866565269807B6F6B61554F4F628BABAD99807A8B92
7C64647E9EA3845A3E4777978E7F6C50455F95C1BA8E798E
9FA1B0BDB9B4BEC6B2947C778D99929CA2A2B3C2BBA497B0
D3D7C6BEB2928FB4C8B2785174B3CCB9948898AEAB928986
7C7F91AFCAC9A7868DA5ADAFB0A8A9B8C7CDD4D9CEC9D4D4
CED1D7D9DCE7EAE6E6E7EAEFEBD7D0DEE7ECF0E9E4E9ECEB
F2EDE7EAE9E5E9E8E6E4DDE3EBE3DAE3EAE1DEE5EBEAE3DD
DBD9CFC2B9A38B8B949598A1A09EA8AEACA9A19585787C88
7C6267796D58575F6B7D7B645859627A96ACBBB69E98AEBF
B8A398ADC7BE9D806D76A3BFBEBBAB928D9DB8C29D6E76A8
C8CBCACCC9C5D1E3DCC6B3ACBEC1B1BAC9C9C2B8C2CDC5C9
D8CFB49C7D5B6BAFD9C1826DA2D1BD87718FAFB5A281788B
99A4B4CFDCC2968092AAACA5A7A9ADC1D3D2D2D6CCC5C7C9
CED5D5D2DEEDEAE4E2E8F1F4EDD7D0E2E5E9F1E9E0E1E5EC
EBE6E5F0F4EFF1EEE7E1DCE2EBE3DBE3E7E0E2E9E7E2E3E6
E5DDC6B6B8AE948D99A0A09B8E88949A9CA7B6BCAE97919A
8861668C947C66585E819A8E7A757B828289A1AA9892ACCA
D1C3BACAD9CDB9ACA5ABBFC7C3C6C8C8CDD4D6C39F8FA2C3
D6D8D4CFCDCBD4E3DED0CBCCD2CBBCC4D1D0C5B8C1CABAB4
C3C09B70534C74B6CCB49A9FC3CDA1665D8BB1B8AF968799
B5C2C8D2CEB19DA0AFBBB1A6B3BFBCC6D2CDCFD4D0CAC4C8
D4D9D2CDDFF0EAE3E6EFF7F8F3E2DFE7DCDEECE8DFDBDFE9
EFE2DFEDF3ECEBECE6DCDAE4ECE7E4E7E4E0ECF4EAE0E1E5
E8E0C6B4BAB598848DA0A89C816C6D78899FB3B7A2898CA4
9F7A6E8A9A8F82715E6D95A29593927A595779989B97A9C5
CCC4C7CFCCC8C9C4C0C5CCD1D0C7C0BCB9C4D1C0ABB2C0CC
D5D9DAD4CCC7C5C5C1C3D3DDD7C5B9C1CBCED1CEC2A38488
AABC9B67506197BBA28BA3C4D4C9A78686A8C1C2BBAEA3AD
C3CBC3BCB0A5B5C2C0BEB0B0CAD9D0CBD3D0D3DAD7D2CBCE
DCE2D9D3E0ECE7E2ECF4F5F6EFE8ECE9DADAE9E8E1E1E7F1
F6E3D8E4EEE9E7EEECDEDDEBF2EFEDEADFDDEFFAF0E3DCD8
DCE0D2C1BEB29174748A9C977D635C6A808D8F836E647BA5
B59D817B7875868D6F5D74878DA2AE8D5C506B8FA4A9B4C5
C5BBBAB09EA9C6C9BDBDC8D8E1D2B6937587B4BFB9C3C9CE
D4D1CECBCDCCB59A9AB9DAE6DECDC0C3CCD8E7EBCE947282
ACCBBD917C91BCC18C769EC8D6D0C7C0C2CFD5CCC2BFBFC4
CAC6B7A7A0ACCAD1C7C3BCC3D7DED5D2DAD9D8E0DDD9D8D7
DDE7E4DFE3E6E3E2EEF0EDEFE6E7F1F0E9E6EAE7E5ECF3F9
F0E2D6DFECE8E4EFF1E4E2F2FAF3ECE7DFE2F2FBF5E8D9CD
D4E5E4D6C8B9A1897A777F857F76757D837D6D5F5A627B9E
B3AFA08F79738FA48F726A6A7599B9B1968C93A1B0BBC0C7
C9BEA8886A78A7B7ACB0C4D2D5CFBB926A78B1D1D1D3D8DE
DBCCBFC0D5E0BA8A8FBEDCDEDBD4CACAD3E2EFEFDAB39DAB
C5DBDCC4B6C0D1C6A091A9C4D0D6DBDCDADBD8D1D1D4D8DA
D1C6BBABAFC7D8D7D2D8DCDBD9D0C9D3DEDDDBE1E2E1E9E1
D6E2E9E5E5E3E4EAEBE6E6ECE8E9F2F7F7F2E8E1E4EFF1F1
E5E4E0E4EDE9E0EAEDE0DAEAF7EEE2E1E7F0F9FEFAEEDDCF
D6E9EEE4D5CCC7BFA582767F8994A1A79E8C78707D8D9AA8
AEB0B5B4A39FB5C1B29A7F6F7CA2C5D3D0CAC4BCBCC0BAB6
C0C4B2957A7EA2B7B2BCD4D5C8CBD1C0A5A2C0DBDBD9E0E5
E0D5C8C0D4E7CEABB4D6DED5D4D3D1D7DBE3E8E1DCD6CECF
D1D4D7D2CFD3CFC6BEC0CCD2CDD1DDE2E0DFDEDEE3E3E3E5
DAD4D2C5CDE3E1DADAE3EFEADFCCC2CFD8DCDFE2E4E6F3E9
D2DDEAE5E5E6EAF3EADEE6F4F5EEF0F2F4EFE0DBE5EEE8E2
E4EBEEEBEEECE4ECEEDFD3DFF2EBDADBE8F1F3F9F8EEE1D4
D6E1E7E7E2DEE2E6D2A8969DA6B0BFC8BEADA0A0B2BEC1C3
BEB8BFC9C5C5D2D4C8BDADA3B3CFDFE3E0D7CFC8C0B49D8C
98B6C7C5B5ADBCCED0D6E6E2CFD0E0E3D4C5C4CED3D4D6D7
D6DDDECDC7D2D5D3DFEAE6DFDBD5D9E1DDDCE2E0E0E3DED7
CEC9CCD1DBDFD4C9CBD6E3E0CFCDD9E0E1E4E5E8E8DDDCE2
DEE4EBE6E9F3EBE0DBDCE3E6E7DBCFD0CFD9E2E2E0E5F3EA
D7DDE9E7E5EBF2F4EBE0ECFFFCF0EFEDEEEBDEE0ECF0E7DF
EBF1F4EDEBEDE8EDF0E6DAE1F3EEDBD8E3E6E5EDF0EAE3DA
D6D7DCE6E9E6E3E7E2CDC4C8C7C3C6D0CFC4C1C9D7D7D4D8
D7D0CFD7D7D2D7D6CAC9D0D5DDE7E2D5D1CDCED6D2BB9C80
7A9DCAD8CAB9B9CAD7D9DDE1D9D6DDDFD8D1C8C6D3DCD6CD
C9D4E6DBC2C0CFDCE4E5E6E7E1DADFE4DCD7DFE8E4DBD8D7
D3D3D6DAE5ECE3D4CED3DDDBD6D7DBD9D9DEE2EAE5D4D6DB
D9E3F1F6F2F0EBE2DFDAD2D8E3E2DED8D3D9DEDCD8E1EEE9
DFDEE6ECEBF3F6F1EDE7F1FEF2E9EFEFF0ECE4EDF6F6ECE6
F3F6F3E8E5E2DEE1E5E5E1E6F3EEE0DDE3E5E2EBF0EBE9E4
DED8D9E2E4E0D8D9E2E4E2DDD6CDC8D4DBD3CFD5DCD6D2DC
E2DED5D4D6D4DBDDCEC4CCD4D7DEDED4CFCBCAD7DCCCB99E
8090C1DAD3C7BFC7D3CCC8D5DEDAD6CEC9CECCC7D6E5E2D7
C9C5D8E0D3D0D9DEDDDADCDDD9DAE0E2DAD4DAE5DED0D2DB
DBDEDCD4D8E0E1DBD3D4D4D4E1ECE5DAD9DFE2E8E5D9D9DC
D5D7E6EDE2DBDAD9E1E1D2D3D7D9DDDEE0E0DCD5D4DFE9ED
E8DFE5F1F3F3F2EFEBE8F0F3E6E4EBEDEBE7EAF5FCF7EDEE
F3F4EAE2E1D9D6D9DDE2E3E8F0ECE7E2E1E4E2E9EEEAE8E6
E4DEDEE1DEDDD9D6E0EAE8DBD7D7D1D6DEDAD2D4DCDAD6DC
DFDCD4CECDD2DCE0D6C7C2C8CDD6DEDBD5CFCED8DDD5CEBF
A3A3C3DBDCD5CED1D5CCC7D5E1E0D5C7C3CBD0D0D3D7DEE1
D5C9D2E0E4E4E4E3DED7D4D3D4D7DBD9D5D3DAE2DFD7DADF
DBD6D0CBCCD3D9DAD7D7D6D6E4EDE9DFDFE3E0DDDFE0DFE3
DCD4DEE1D4D1D5D8E0E2DAD9D7D6D7DDE8E5DCD4D8E1E4F0
EFE5EBF4F3E4E2E8E1E3F0EEEBECE6E3DEDFEBF0F4EDE4ED
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 175}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 89, 1, 52, "Section",
      CellTags->"Contents"],
    Cell[1801, 52, 448, 14, 64, "Contents",
      CellTags->"Contents"]},
  "S2.2.0"->{
    Cell[2252, 68, 96, 1, 52, "Section",
      CellTags->{"S2.2.0", "0.1"}],
    Cell[2351, 71, 461, 9, 65, "Text",
      CellTags->{"S2.2.0", "0.2"}]},
  "0.1"->{
    Cell[2252, 68, 96, 1, 52, "Section",
      CellTags->{"S2.2.0", "0.1"}]},
  "0.2"->{
    Cell[2351, 71, 461, 9, 65, "Text",
      CellTags->{"S2.2.0", "0.2"}]},
  "S2.2.1"->{
    Cell[2815, 82, 99, 1, 36, "Subsection",
      CellTags->{"S2.2.1", "1.1"}],
    Cell[2917, 85, 254, 6, 37, "Text",
      CellTags->{"S2.2.1", "1.2"}],
    Cell[3174, 93, 77, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.3"}],
    Cell[3254, 96, 93, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[3350, 100, 140, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.4"}],
    Cell[3493, 106, 291, 8, 113, "Input",
      CellTags->"S2.2.1"],
    Cell[3787, 116, 90, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.5"}],
    Cell[3902, 121, 80, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[3985, 125, 91, 3, 20, "Output",
      CellTags->"S2.2.1"],
    Cell[4091, 131, 304, 8, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.6"}],
    Cell[4420, 143, 186, 6, 62, "Input",
      CellTags->"S2.2.1"],
    Cell[4609, 151, 91, 3, 20, "Output",
      CellTags->"S2.2.1"],
    Cell[4715, 157, 138, 4, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.7"}],
    Cell[4878, 165, 100, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[4981, 169, 139046, 3254, 70, 138973, 3251, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[144042, 3426, 311, 8, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.8"}],
    Cell[144378, 3438, 130, 5, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[144511, 3445, 324, 6, 70, "Output",
      CellTags->"S2.2.1"],
    Cell[144850, 3454, 146, 5, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.9"}],
    Cell[144999, 3461, 139, 5, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[145141, 3468, 243, 5, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.10"}],
    Cell[145409, 3477, 84, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[145496, 3481, 132, 3, 70, "Output",
      CellTags->"S2.2.1"],
    Cell[145643, 3487, 1373, 36, 70, "Text",
      CellTags->{"S2.2.1", "1.11"}],
    Cell[147019, 3525, 451, 9, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.12"}],
    Cell[147495, 3538, 117, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[147615, 3542, 939, 70, 70, 866, 67, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[148569, 3615, 272, 6, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.13"}],
    Cell[148866, 3625, 91, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[148960, 3629, 139360, 3285, 70, 139287, 3282, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[288335, 6917, 162, 4, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.14"}],
    Cell[288522, 6925, 108, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[288633, 6929, 8063, 580, 70, 7990, 577, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[296711, 7512, 721, 19, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.15"}],
    Cell[297457, 7535, 173, 6, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[297633, 7543, 24099, 1738, 70, 24026, 1735, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[321747, 9284, 96, 1, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.16"}],
    Cell[321868, 9289, 173, 6, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[322044, 9297, 42918, 2122, 70, 42845, 2119, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[364977, 11422, 1611, 36, 70, "Text",
      CellTags->{"S2.2.1", "1.17"}],
    Cell[366591, 11460, 480, 15, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.18"}],
    Cell[367074, 11477, 171, 6, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[367248, 11485, 213, 7, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.19"}],
    Cell[367486, 11496, 102, 2, 70, "Input",
      CellTags->"S2.2.1"],
    Cell[367591, 11500, 139046, 3254, 70, 138973, 3251, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[506652, 14757, 773, 20, 76, "MathCaption",
      CellTags->{"S2.2.1", "1.20"}],
    Cell[507428, 14779, 163, 6, 62, "Input",
      CellTags->"S2.2.1"],
    Cell[507594, 14787, 128, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.21"}],
    Cell[507747, 14795, 98, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[507848, 14799, 139046, 3254, 186, 138973, 3251, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[646909, 18056, 806, 19, 85, "MathCaption",
      CellTags->{"S2.2.1", "1.22"}],
    Cell[647740, 18079, 105, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[647848, 18083, 139046, 3254, 186, 138973, 3251, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[786909, 21340, 117, 2, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.23"}],
    Cell[787029, 21344, 146, 5, 45, "Input",
      CellTags->"S2.2.1"],
    Cell[787178, 21351, 163, 4, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.24"}],
    Cell[787366, 21359, 110, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[787479, 21363, 1175, 94, 186, 1102, 91, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[788669, 21460, 361, 7, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.25"}],
    Cell[789055, 21471, 91, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[789149, 21475, 139596, 3309, 186, 139523, 3306, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[928760, 24787, 154, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.26"}],
    Cell[928917, 24793, 217, 7, 79, "Input",
      CellTags->"S2.2.1"],
    Cell[929137, 24802, 322, 6, 56, "MathCaption",
      CellTags->{"S2.2.1", "1.27"}],
    Cell[929484, 24812, 481, 12, 198, "Input",
      CellTags->"S2.2.1"],
    Cell[929968, 24826, 83550, 5370, 186, 83477, 5367, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.1"],
    Cell[1013533, 30199, 328, 6, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.28"}],
    Cell[1013864, 30207, 160, 6, 62, "Input",
      CellTags->"S2.2.1"],
    Cell[1014027, 30215, 171, 4, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.29"}],
    Cell[1014223, 30223, 98, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[1014324, 30227, 183618, 3806, 186, 138973, 3251, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"S2.2.1"],
    Cell[1197957, 34036, 95, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.30"}],
    Cell[1198077, 34041, 132, 5, 45, "Input",
      CellTags->"S2.2.1"],
    Cell[1198212, 34048, 104, 3, 20, "Output",
      CellTags->"S2.2.1"],
    Cell[1198331, 34054, 193, 5, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.31"}],
    Cell[1198549, 34063, 84, 2, 28, "Input",
      CellTags->"S2.2.1"],
    Cell[1198636, 34067, 104, 3, 20, "Output",
      CellTags->"S2.2.1"]},
  "1.1"->{
    Cell[2815, 82, 99, 1, 36, "Subsection",
      CellTags->{"S2.2.1", "1.1"}]},
  "1.2"->{
    Cell[2917, 85, 254, 6, 37, "Text",
      CellTags->{"S2.2.1", "1.2"}]},
  "1.3"->{
    Cell[3174, 93, 77, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.3"}]},
  "1.4"->{
    Cell[3350, 100, 140, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.4"}]},
  "1.5"->{
    Cell[3787, 116, 90, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.5"}]},
  "1.6"->{
    Cell[4091, 131, 304, 8, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.6"}]},
  "1.7"->{
    Cell[4715, 157, 138, 4, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.7"}]},
  "1.8"->{
    Cell[144042, 3426, 311, 8, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.8"}]},
  "1.9"->{
    Cell[144850, 3454, 146, 5, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.9"}]},
  "1.10"->{
    Cell[145141, 3468, 243, 5, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.10"}]},
  "1.11"->{
    Cell[145643, 3487, 1373, 36, 70, "Text",
      CellTags->{"S2.2.1", "1.11"}]},
  "1.12"->{
    Cell[147019, 3525, 451, 9, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.12"}]},
  "1.13"->{
    Cell[148569, 3615, 272, 6, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.13"}]},
  "1.14"->{
    Cell[288335, 6917, 162, 4, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.14"}]},
  "1.15"->{
    Cell[296711, 7512, 721, 19, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.15"}]},
  "1.16"->{
    Cell[321747, 9284, 96, 1, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.16"}]},
  "1.17"->{
    Cell[364977, 11422, 1611, 36, 70, "Text",
      CellTags->{"S2.2.1", "1.17"}]},
  "1.18"->{
    Cell[366591, 11460, 480, 15, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.18"}]},
  "1.19"->{
    Cell[367248, 11485, 213, 7, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.19"}]},
  "1.20"->{
    Cell[506652, 14757, 773, 20, 76, "MathCaption",
      CellTags->{"S2.2.1", "1.20"}]},
  "1.21"->{
    Cell[507594, 14787, 128, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.21"}]},
  "1.22"->{
    Cell[646909, 18056, 806, 19, 85, "MathCaption",
      CellTags->{"S2.2.1", "1.22"}]},
  "1.23"->{
    Cell[786909, 21340, 117, 2, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.23"}]},
  "1.24"->{
    Cell[787178, 21351, 163, 4, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.24"}]},
  "1.25"->{
    Cell[788669, 21460, 361, 7, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.25"}]},
  "1.26"->{
    Cell[928760, 24787, 154, 4, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.26"}]},
  "1.27"->{
    Cell[929137, 24802, 322, 6, 56, "MathCaption",
      CellTags->{"S2.2.1", "1.27"}]},
  "1.28"->{
    Cell[1013533, 30199, 328, 6, 70, "MathCaption",
      CellTags->{"S2.2.1", "1.28"}]},
  "1.29"->{
    Cell[1014027, 30215, 171, 4, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.29"}]},
  "1.30"->{
    Cell[1197957, 34036, 95, 1, 28, "MathCaption",
      CellTags->{"S2.2.1", "1.30"}]},
  "1.31"->{
    Cell[1198331, 34054, 193, 5, 42, "MathCaption",
      CellTags->{"S2.2.1", "1.31"}]},
  "S2.2.2"->{
    Cell[1198755, 34073, 114, 2, 36, "Subsection",
      CellTags->{"S2.2.2", "2.1"}],
    Cell[1198872, 34077, 202, 6, 37, "Text",
      CellTags->{"S2.2.2", "2.2"}],
    Cell[1199077, 34085, 77, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.3"}],
    Cell[1199157, 34088, 93, 2, 28, "Input",
      CellTags->"S2.2.2"],
    Cell[1199253, 34092, 216, 7, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.4"}],
    Cell[1199494, 34103, 156, 5, 62, "Input",
      CellTags->"S2.2.2"],
    Cell[1199653, 34110, 91, 3, 20, "Output",
      CellTags->"S2.2.2"],
    Cell[1199759, 34116, 97, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.5"}],
    Cell[1199881, 34121, 100, 2, 28, "Input",
      CellTags->"S2.2.2"],
    Cell[1199984, 34125, 99933, 2427, 186, 99860, 2424, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.2"],
    Cell[1299932, 36555, 162, 4, 42, "MathCaption",
      CellTags->{"S2.2.2", "2.6"}],
    Cell[1300097, 36561, 114, 2, 28, "Input",
      CellTags->"S2.2.2"],
    Cell[1300214, 36565, 117, 2, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.7"}],
    Cell[1300334, 36569, 160, 5, 45, "Input",
      CellTags->"S2.2.2"],
    Cell[1300497, 36576, 102, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.8"}],
    Cell[1300624, 36581, 87, 2, 28, "Input",
      CellTags->"S2.2.2"],
    Cell[1300714, 36585, 98767, 2326, 186, 98694, 2323, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.2"],
    Cell[1399496, 38914, 128, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.9"}],
    Cell[1399627, 38920, 191, 6, 70, "Input",
      CellTags->"S2.2.2"],
    Cell[1399821, 38928, 242, 5, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.10"}],
    Cell[1400088, 38937, 374, 10, 70, "Input",
      CellTags->"S2.2.2"],
    Cell[1400465, 38949, 131986, 8466, 70, 131913, 8463, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.2"],
    Cell[1532466, 47418, 128, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.11"}],
    Cell[1532619, 47426, 84, 2, 70, "Input",
      CellTags->"S2.2.2"],
    Cell[1532706, 47430, 103, 3, 70, "Output",
      CellTags->"S2.2.2"],
    Cell[1532824, 47436, 106, 1, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.12"}],
    Cell[1532933, 47439, 167, 5, 70, "Input",
      CellTags->"S2.2.2"],
    Cell[1533103, 47446, 140, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.13"}],
    Cell[1533268, 47454, 98, 2, 70, "Input",
      CellTags->"S2.2.2"],
    Cell[1533369, 47458, 99933, 2427, 70, 99860, 2424, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S2.2.2"]},
  "2.1"->{
    Cell[1198755, 34073, 114, 2, 36, "Subsection",
      CellTags->{"S2.2.2", "2.1"}]},
  "2.2"->{
    Cell[1198872, 34077, 202, 6, 37, "Text",
      CellTags->{"S2.2.2", "2.2"}]},
  "2.3"->{
    Cell[1199077, 34085, 77, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.3"}]},
  "2.4"->{
    Cell[1199253, 34092, 216, 7, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.4"}]},
  "2.5"->{
    Cell[1199759, 34116, 97, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.5"}]},
  "2.6"->{
    Cell[1299932, 36555, 162, 4, 42, "MathCaption",
      CellTags->{"S2.2.2", "2.6"}]},
  "2.7"->{
    Cell[1300214, 36565, 117, 2, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.7"}]},
  "2.8"->{
    Cell[1300497, 36576, 102, 1, 28, "MathCaption",
      CellTags->{"S2.2.2", "2.8"}]},
  "2.9"->{
    Cell[1399496, 38914, 128, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.9"}]},
  "2.10"->{
    Cell[1399821, 38928, 242, 5, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.10"}]},
  "2.11"->{
    Cell[1532466, 47418, 128, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.11"}]},
  "2.12"->{
    Cell[1532824, 47436, 106, 1, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.12"}]},
  "2.13"->{
    Cell[1533103, 47446, 140, 4, 70, "MathCaption",
      CellTags->{"S2.2.2", "2.13"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 1634162, 49910},
  {"S2.2.0", 1634320, 49915},
  {"0.1", 1634484, 49920},
  {"0.2", 1634573, 49923},
  {"S2.2.1", 1634663, 49926},
  {"1.1", 1641699, 50106},
  {"1.2", 1641791, 50109},
  {"1.3", 1641878, 50112},
  {"1.4", 1641971, 50115},
  {"1.5", 1642066, 50118},
  {"1.6", 1642160, 50121},
  {"1.7", 1642255, 50124},
  {"1.8", 1642350, 50127},
  {"1.9", 1642448, 50130},
  {"1.10", 1642547, 50133},
  {"1.11", 1642647, 50136},
  {"1.12", 1642742, 50139},
  {"1.13", 1642842, 50142},
  {"1.14", 1642942, 50145},
  {"1.15", 1643042, 50148},
  {"1.16", 1643143, 50151},
  {"1.17", 1643242, 50154},
  {"1.18", 1643338, 50157},
  {"1.19", 1643440, 50160},
  {"1.20", 1643541, 50163},
  {"1.21", 1643643, 50166},
  {"1.22", 1643744, 50169},
  {"1.23", 1643846, 50172},
  {"1.24", 1643947, 50175},
  {"1.25", 1644048, 50178},
  {"1.26", 1644149, 50181},
  {"1.27", 1644250, 50184},
  {"1.28", 1644351, 50187},
  {"1.29", 1644453, 50190},
  {"1.30", 1644555, 50193},
  {"1.31", 1644656, 50196},
  {"S2.2.2", 1644760, 50199},
  {"2.1", 1647497, 50268},
  {"2.2", 1647596, 50271},
  {"2.3", 1647689, 50274},
  {"2.4", 1647788, 50277},
  {"2.5", 1647888, 50280},
  {"2.6", 1647987, 50283},
  {"2.7", 1648087, 50286},
  {"2.8", 1648187, 50289},
  {"2.9", 1648287, 50292},
  {"2.10", 1648388, 50295},
  {"2.11", 1648490, 50298},
  {"2.12", 1648592, 50301},
  {"2.13", 1648694, 50304}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 89, 1, 52, "Section",
  CellTags->"Contents"],
Cell[1801, 52, 448, 14, 64, "Contents",
  CellTags->"Contents"],
Cell[2252, 68, 96, 1, 52, "Section",
  CellTags->{"S2.2.0", "0.1"}],
Cell[2351, 71, 461, 9, 65, "Text",
  CellTags->{"S2.2.0", "0.2"}],
Cell[2815, 82, 99, 1, 36, "Subsection",
  CellTags->{"S2.2.1", "1.1"}],
Cell[2917, 85, 254, 6, 37, "Text",
  CellTags->{"S2.2.1", "1.2"}],
Cell[3174, 93, 77, 1, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.3"}],
Cell[3254, 96, 93, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[3350, 100, 140, 4, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.4"}],
Cell[3493, 106, 291, 8, 113, "Input",
  CellTags->"S2.2.1"],
Cell[3787, 116, 90, 1, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.5"}],

Cell[CellGroupData[{
Cell[3902, 121, 80, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[3985, 125, 91, 3, 20, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[4091, 131, 304, 8, 42, "MathCaption",
  CellTags->{"S2.2.1", "1.6"}],

Cell[CellGroupData[{
Cell[4420, 143, 186, 6, 62, "Input",
  CellTags->"S2.2.1"],
Cell[4609, 151, 91, 3, 20, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[4715, 157, 138, 4, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.7"}],

Cell[CellGroupData[{
Cell[4878, 165, 100, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[4981, 169, 139046, 3254, 70, 138973, 3251, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[144042, 3426, 311, 8, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.8"}],

Cell[CellGroupData[{
Cell[144378, 3438, 130, 5, 70, "Input",
  CellTags->"S2.2.1"],
Cell[144511, 3445, 324, 6, 70, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[144850, 3454, 146, 5, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.9"}],
Cell[144999, 3461, 139, 5, 70, "Input",
  CellTags->"S2.2.1"],
Cell[145141, 3468, 243, 5, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.10"}],

Cell[CellGroupData[{
Cell[145409, 3477, 84, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[145496, 3481, 132, 3, 70, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[145643, 3487, 1373, 36, 70, "Text",
  CellTags->{"S2.2.1", "1.11"}],
Cell[147019, 3525, 451, 9, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.12"}],

Cell[CellGroupData[{
Cell[147495, 3538, 117, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[147615, 3542, 939, 70, 70, 866, 67, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[148569, 3615, 272, 6, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.13"}],

Cell[CellGroupData[{
Cell[148866, 3625, 91, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[148960, 3629, 139360, 3285, 70, 139287, 3282, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[288335, 6917, 162, 4, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.14"}],

Cell[CellGroupData[{
Cell[288522, 6925, 108, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[288633, 6929, 8063, 580, 70, 7990, 577, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[296711, 7512, 721, 19, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.15"}],

Cell[CellGroupData[{
Cell[297457, 7535, 173, 6, 70, "Input",
  CellTags->"S2.2.1"],
Cell[297633, 7543, 24099, 1738, 70, 24026, 1735, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[321747, 9284, 96, 1, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.16"}],

Cell[CellGroupData[{
Cell[321868, 9289, 173, 6, 70, "Input",
  CellTags->"S2.2.1"],
Cell[322044, 9297, 42918, 2122, 70, 42845, 2119, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[364977, 11422, 1611, 36, 70, "Text",
  CellTags->{"S2.2.1", "1.17"}],
Cell[366591, 11460, 480, 15, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.18"}],
Cell[367074, 11477, 171, 6, 70, "Input",
  CellTags->"S2.2.1"],
Cell[367248, 11485, 213, 7, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.19"}],

Cell[CellGroupData[{
Cell[367486, 11496, 102, 2, 70, "Input",
  CellTags->"S2.2.1"],
Cell[367591, 11500, 139046, 3254, 70, 138973, 3251, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[506652, 14757, 773, 20, 76, "MathCaption",
  CellTags->{"S2.2.1", "1.20"}],
Cell[507428, 14779, 163, 6, 62, "Input",
  CellTags->"S2.2.1"],
Cell[507594, 14787, 128, 4, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.21"}],

Cell[CellGroupData[{
Cell[507747, 14795, 98, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[507848, 14799, 139046, 3254, 186, 138973, 3251, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[646909, 18056, 806, 19, 85, "MathCaption",
  CellTags->{"S2.2.1", "1.22"}],

Cell[CellGroupData[{
Cell[647740, 18079, 105, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[647848, 18083, 139046, 3254, 186, 138973, 3251, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[786909, 21340, 117, 2, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.23"}],
Cell[787029, 21344, 146, 5, 45, "Input",
  CellTags->"S2.2.1"],
Cell[787178, 21351, 163, 4, 42, "MathCaption",
  CellTags->{"S2.2.1", "1.24"}],

Cell[CellGroupData[{
Cell[787366, 21359, 110, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[787479, 21363, 1175, 94, 186, 1102, 91, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[788669, 21460, 361, 7, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.25"}],

Cell[CellGroupData[{
Cell[789055, 21471, 91, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[789149, 21475, 139596, 3309, 186, 139523, 3306, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[928760, 24787, 154, 4, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.26"}],
Cell[928917, 24793, 217, 7, 79, "Input",
  CellTags->"S2.2.1"],
Cell[929137, 24802, 322, 6, 56, "MathCaption",
  CellTags->{"S2.2.1", "1.27"}],

Cell[CellGroupData[{
Cell[929484, 24812, 481, 12, 198, "Input",
  CellTags->"S2.2.1"],
Cell[929968, 24826, 83550, 5370, 186, 83477, 5367, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[1013533, 30199, 328, 6, 70, "MathCaption",
  CellTags->{"S2.2.1", "1.28"}],
Cell[1013864, 30207, 160, 6, 62, "Input",
  CellTags->"S2.2.1"],
Cell[1014027, 30215, 171, 4, 42, "MathCaption",
  CellTags->{"S2.2.1", "1.29"}],

Cell[CellGroupData[{
Cell[1014223, 30223, 98, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[1014324, 30227, 183618, 3806, 186, 138973, 3251, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[1197957, 34036, 95, 1, 28, "MathCaption",
  CellTags->{"S2.2.1", "1.30"}],

Cell[CellGroupData[{
Cell[1198077, 34041, 132, 5, 45, "Input",
  CellTags->"S2.2.1"],
Cell[1198212, 34048, 104, 3, 20, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[1198331, 34054, 193, 5, 42, "MathCaption",
  CellTags->{"S2.2.1", "1.31"}],

Cell[CellGroupData[{
Cell[1198549, 34063, 84, 2, 28, "Input",
  CellTags->"S2.2.1"],
Cell[1198636, 34067, 104, 3, 20, "Output",
  CellTags->"S2.2.1"]
}, Open  ]],
Cell[1198755, 34073, 114, 2, 36, "Subsection",
  CellTags->{"S2.2.2", "2.1"}],
Cell[1198872, 34077, 202, 6, 37, "Text",
  CellTags->{"S2.2.2", "2.2"}],
Cell[1199077, 34085, 77, 1, 28, "MathCaption",
  CellTags->{"S2.2.2", "2.3"}],
Cell[1199157, 34088, 93, 2, 28, "Input",
  CellTags->"S2.2.2"],
Cell[1199253, 34092, 216, 7, 28, "MathCaption",
  CellTags->{"S2.2.2", "2.4"}],

Cell[CellGroupData[{
Cell[1199494, 34103, 156, 5, 62, "Input",
  CellTags->"S2.2.2"],
Cell[1199653, 34110, 91, 3, 20, "Output",
  CellTags->"S2.2.2"]
}, Open  ]],
Cell[1199759, 34116, 97, 1, 28, "MathCaption",
  CellTags->{"S2.2.2", "2.5"}],

Cell[CellGroupData[{
Cell[1199881, 34121, 100, 2, 28, "Input",
  CellTags->"S2.2.2"],
Cell[1199984, 34125, 99933, 2427, 186, 99860, 2424, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],
Cell[1299932, 36555, 162, 4, 42, "MathCaption",
  CellTags->{"S2.2.2", "2.6"}],
Cell[1300097, 36561, 114, 2, 28, "Input",
  CellTags->"S2.2.2"],
Cell[1300214, 36565, 117, 2, 28, "MathCaption",
  CellTags->{"S2.2.2", "2.7"}],
Cell[1300334, 36569, 160, 5, 45, "Input",
  CellTags->"S2.2.2"],
Cell[1300497, 36576, 102, 1, 28, "MathCaption",
  CellTags->{"S2.2.2", "2.8"}],

Cell[CellGroupData[{
Cell[1300624, 36581, 87, 2, 28, "Input",
  CellTags->"S2.2.2"],
Cell[1300714, 36585, 98767, 2326, 186, 98694, 2323, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],
Cell[1399496, 38914, 128, 4, 70, "MathCaption",
  CellTags->{"S2.2.2", "2.9"}],
Cell[1399627, 38920, 191, 6, 70, "Input",
  CellTags->"S2.2.2"],
Cell[1399821, 38928, 242, 5, 70, "MathCaption",
  CellTags->{"S2.2.2", "2.10"}],

Cell[CellGroupData[{
Cell[1400088, 38937, 374, 10, 70, "Input",
  CellTags->"S2.2.2"],
Cell[1400465, 38949, 131986, 8466, 70, 131913, 8463, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]],
Cell[1532466, 47418, 128, 4, 70, "MathCaption",
  CellTags->{"S2.2.2", "2.11"}],

Cell[CellGroupData[{
Cell[1532619, 47426, 84, 2, 70, "Input",
  CellTags->"S2.2.2"],
Cell[1532706, 47430, 103, 3, 70, "Output",
  CellTags->"S2.2.2"]
}, Open  ]],
Cell[1532824, 47436, 106, 1, 70, "MathCaption",
  CellTags->{"S2.2.2", "2.12"}],
Cell[1532933, 47439, 167, 5, 70, "Input",
  CellTags->"S2.2.2"],
Cell[1533103, 47446, 140, 4, 70, "MathCaption",
  CellTags->{"S2.2.2", "2.13"}],

Cell[CellGroupData[{
Cell[1533268, 47454, 98, 2, 70, "Input",
  CellTags->"S2.2.2"],
Cell[1533369, 47458, 99933, 2427, 70, 99860, 2424, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S2.2.2"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

