(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    805861,      34730]*)
(*NotebookOutlinePosition[    845686,      35869]*)
(*  CellTagsIndexPosition[    841991,      35728]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["3.1 Filters and Wavelets", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["3.1.1 Filters",
    ButtonData:>{"Wavelets 3.1.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.1.2 Scaling Functions, Wavelets, and Wavelet Packets",
    ButtonData:>{"Wavelets 3.1.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.1.3 Viewing Details of ",
    ButtonData:>{"Wavelets 3.1.3"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Phi]",
    ButtonData:>{"Wavelets 3.1.3"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[", ",
    ButtonData:>{"Wavelets 3.1.3"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Psi]",
    ButtonData:>{"Wavelets 3.1.3"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[", and w",
    ButtonData:>{"Wavelets 3.1.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.1.4 Derivatives of ",
    ButtonData:>{"Wavelets 3.1.4"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Phi]",
    ButtonData:>{"Wavelets 3.1.4"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox[" and ",
    ButtonData:>{"Wavelets 3.1.4"},
    ButtonStyle->"AddOnsLink"],
  ButtonBox["\[Psi]",
    ButtonData:>{"Wavelets 3.1.4"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["3.1 Filters and Wavelets", "Section",
  CellTags->{"S3.1.0", "0.1"}],

Cell["3.1.1 Filters", "Subsection",
  CellTags->{"S3.1.1", "1.1"}],

Cell[TextData[{
  "Wavelets are basis functions in function space. All the functions of the \
basis ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\[Psi]\_\(j  k\)\) \((t)\) = \(2\^\(j/2\)\) \[Psi] \((
            \(2\^j\) t - k)\)}\_\(j  k\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " are derived from a single function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", called the basic wavelet or mother wavelet, by translations and \
dilations. The basic wavelet in turn can be derived from a scaling function ",
  
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " of a multiresolution analysis through the wavelet equation, "
}], "Text",
  CellTags->{"S3.1.1", "1.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Psi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), "\[Phi]", \((2  t - k)\), ","}],
       TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.1.1", "1.3"}],

Cell[TextData[{
  "where the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " satisfies the dilation equation "
}], "Text",
  CellTags->{"S3.1.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), "\[Phi]", \((2  t - k)\)}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.1.1", "1.5"}],

Cell[TextData[{
  "and the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " are related to ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " through "
}], "Text",
  CellTags->{"S3.1.1", "1.6"}],

Cell[BoxData[
    \(TraditionalForm\`g\_k = \(\((\(-1\))\)\^k\) h\_\(1 - k\).\)], 
  "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.1.1", "1.7"}],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " are used in wavelet transforms and they are called filter coefficients or \
simply filters. The filter ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " corresponds to a lowpass filter; ",
  Cell[BoxData[
      \(TraditionalForm\`{g\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", to a highpass filter. Their Fourier transforms "
}], "Text",
  CellTags->{"S3.1.1", "1.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{"H", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\/\@2\), \(e\^\(-i  k  \[Omega]\)\),
         "   ", \(" and "\), "   ", "G", \((\[Omega])\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\/\@2\), 
        \(e\^\(-i  k  \[Omega]\)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.1.1", "1.9"}],

Cell[TextData[{
  "are called frequency response functions or transfer functions. \n\
Daubechies first constructed a family of orthogonal wavelets with finite \
support. In this case, the number of nonzero filter coefficients is finite \
and ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is called a finite impulse response (FIR) filter. The ",
  Cell[BoxData[
      \(TraditionalForm\`N\^th\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " order Daubechies wavelet or Daubechies filter is characterized by the \
vanishing of the first ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " moments of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", that is, "
}], "Text",
  CellTags->{"S3.1.1", "1.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(t\^l\), "\[Psi]", \((
        t)\), 
        StyleBox[\("dt"\),
          "TI"], "=", \(0\ \ \ \), \("for"\), "   ", "l", "=", "0", ",", "1", 
        ",", "\[Ellipsis]", ",", "N", "-", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S3.1.1", "1.11"}],

Cell[TextData[{
  "Daubechies filter of order 1 is also called the Haar filter. There are two \
different kinds of Daubechies filters resulting from the choice of different \
phases for the response function ",
  Cell[BoxData[
      \(TraditionalForm\`H \((\[Omega])\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ": Daubechies' extremal phase filter called \"Daubechies filter\" and \
Daubechies' least asymmetric filter referred to as the \"least asymmetric \
filter\". In the case of coiflet filters, additional moment conditions are \
imposed on the scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ": "
}], "Text",
  CellTags->{"S3.1.1", "1.12"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "\[Phi]", \((t)\), " ", 
        
        StyleBox[\("dt"\),
          "TI"], "=", \(1\ \ \ \), \("and"\), "   ", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), \(t\^l\), "\[Phi]", 
        \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "=", \(0\ \ \ \), \("for"\), "   ", "l", "=", "1", ",", "2", 
        ",", "\[Ellipsis]", ",", "N", "-", "1."}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S3.1.1", "1.13"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is referred to as the order of the coiflet filter. Note that for the \
coiflet filter ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " has to be even. "
}], "Text",
  CellTags->{"S3.1.1", "1.14"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"HaarFilter[]\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", \("compute the Haar filter "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"DaubechiesFilter[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("compute Daubechies filter of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"DaubechiesFilter[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"compute Daubechies filter with working precision \
\\!\\(\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"LeastAsymmetricFilter[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                  \("compute the least asymmetric filter of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"LeastAsymmetricFilter[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"compute the least asymmetric filter with working precision \\!\\(\
\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CoifletFilter[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("compute the coiflet filter of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CoifletFilter[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"compute the coiflet filter with working precision \
\\!\\(\\*StyleBox[\\\"\\\\\\\"prec\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.1", "1.15"}],

Cell["Generating Daubechies filters.", "Caption",
  CellTags->"S3.1.1"],

Cell[TextData[{
  "The output of these filter functions is of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`{{h\_\(-m\), h\_\(-m + 1\), \[Ellipsis], h\_\(-m + L - 1\)}, -m}\)], 
    "InlineFormula",
    CellTags->"S3.1.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m \[GreaterEqual] 0\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is the starting index, and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is the length of the filter. For Daubechies and least asymmetric filters, \
",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L = 2  N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", whereas for coiflet filters ",
  Cell[BoxData[
      \(TraditionalForm\`m = N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L = 3  N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ". The following examples illustrate their usage. "
}], "Text",
  CellTags->{"S3.1.1", "1.16"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S3.1.1", "1.17"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S3.1.1"],

Cell["This computes the Haar filter.", "MathCaption",
  CellTags->{"S3.1.1", "1.18"}],

Cell[CellGroupData[{

Cell["HaarFilter[]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{1\/\@2, 1\/\@2}, 0}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
Note that the Haar filter is the same as Daubechies filter of order \
1.\
\>", "MathCaption",
  CellTags->{"S3.1.1", "1.19"}],

Cell[CellGroupData[{

Cell["DaubechiesFilter[1]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{0.70710678118654755`, 0.70710678118654755`}, 0}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
This gives Daubechies filter of order 5. The second argument \
specifies the working precision used in calculating the filter.\
\>", 
  "MathCaption",
  CellTags->{"S3.1.1", "1.20"}],

Cell[CellGroupData[{

Cell["DaubechiesFilter[5, 18]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{0.16010239797419291448072378`14.4936, 
        0.60382926979718967054011811`14.4843, 
        0.72430852843777292772807082`14.4453, 
        0.13842814590132073150539718`14.0577, 
        \(-0.24229488706638203186257048`14.0852\), 
        \(-0.03224486958463837464847912`13.3997\), 
        0.0775714938400457135231305`13.9018, 
        \(-0.00624149021279827427419052`13.3294\), 
        \(-0.012580751999081999468509742`14.1089\), 
        0.0033357252854737712779981839`14.3209}, 0}\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
The actual precision is usually lower than the working precision.\
\
\>", "MathCaption",
  CellTags->{"S3.1.1", "1.21"}],

Cell[CellGroupData[{

Cell["Precision[%]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \(13\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
This gives the least asymmetric filter of order 11. When the second \
argument is omitted, machine precision is used in the calculation.\
\>", 
  "MathCaption",
  CellTags->{"S3.1.1", "1.22"}],

Cell[CellGroupData[{

Cell["LeastAsymmetricFilter[11]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{0.000489263610262602277`, 0.000110535097619248978`, 
        \(-0.00638960366660271894`\), \(-0.00200347190033477629`\), 
        0.0430001906817625112`, 0.0352667595647797238`, 
        \(-0.144602343708157476`\), \(-0.204654794504707426`\), 
        0.237689909038710611`, 0.730343549085128351`, 0.572022978015712091`, 
        0.0971983944666316013`, \(-0.0228326510175706154`\), 
        0.0699767996136733128`, 0.0370374159810025282`, 
        \(-0.0240808415946222753`\), \(-0.00985793482833556389`\), 
        0.00651249567493566949`, 0.000588352735492576162`, 
        \(-0.00173436626725683389`\), \(-0.0000387956557278596481`\), 
        0.000171721950699900833`}, 0}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
Coiflet filter of order 2 is calculated using the default machine \
precision. \
\>", "MathCaption",
  CellTags->{"S3.1.1", "1.23"}],

Cell[CellGroupData[{

Cell["CoifletFilter[2]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{\(-0.0727326195687134902`\), 0.337897662513668795`, 
        0.852572020323974655`, 0.384864846752483646`, 
        \(-0.0727326195687134902`\), \(-0.015655728079604958`\)}, \(-2\)}\)], 
  "Output",
  CellLabel->"Out[7]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
This displays the above filter coefficients with more digits. Note \
that to get more reliable digits one should give a higher working \
precision.\
\>", "MathCaption",
  CellTags->{"S3.1.1", "1.24"}],

Cell[CellGroupData[{

Cell["MapAt[N[#, 12]&, %, {1}]", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"-", 
              StyleBox["0.0727326195687134902`",
                StyleBoxAutoDelete->True,
                PrintPrecision->12]}], ",", 
            StyleBox["0.337897662513668795`",
              StyleBoxAutoDelete->True,
              PrintPrecision->12], ",", 
            StyleBox["0.852572020323974655`",
              StyleBoxAutoDelete->True,
              PrintPrecision->12], ",", 
            StyleBox["0.384864846752483646`",
              StyleBoxAutoDelete->True,
              PrintPrecision->12], ",", 
            RowBox[{"-", 
              StyleBox["0.0727326195687134902`",
                StyleBoxAutoDelete->True,
                PrintPrecision->12]}], ",", 
            RowBox[{"-", 
              StyleBox["0.015655728079604958`",
                StyleBoxAutoDelete->True,
                PrintPrecision->12]}]}], "}"}], ",", \(-2\)}], "}"}]], 
  "Output",
  CellLabel->"Out[8]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " For large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", it is important to increase the working precision in order to obtain \
correct results. \n",
  StyleBox["Warning:", "TB"],
  " For large ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", the above filter functions can run into numerical difficulties. \nThere \
are other ways of generating orthogonal wavelets or scaling functions. For \
example, the Battle\[Hyphen]Lemari\[EAcute] family of wavelets is obtained by \
applying an orthogonalization procedure to ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "\[Hyphen]spline functions. For simplicity, we will refer to \
Battle\[Hyphen]Lemari\[EAcute] wavelets as spline wavelets and to the \
corresponding filters as spline filters. The spline scaling function of order \
",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " corresponds to an orthogonalized ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ". The orthogonalization procedure renders the spline wavelets noncompactly \
supported and, therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " has an infinite number of nonzero coefficients and it is called an \
infinite impulse response (IIR) filter. One can also build localized wavelets \
in Fourier space. The Shannon wavelet is the equivalent of the Haar wavelet \
in Fourier space. Due to discontinuities in frequency space, the wavelet \
decays slowly in time. Meyer wavelets smooth out the discontinuity of the \
Shannon wavelet using a smooth interpolating function. The Meyer wavelet of \
order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " has ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " continuous derivatives in Fourier space; it also has infinite support in \
the time domain and the number of nonzero filter coefficients is infinite. "
}], "Text",
  CellTags->{"S3.1.1", "1.25"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ShannonFilter[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"kmax\\\\\\\"\\\", \\\"TI\\\"]\
\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                  \("give the Shannon filter starting from index "\), 
                    StyleBox[
                      RowBox[{"-", 
                        StyleBox[\("kmax"\),
                          "TI"]}],
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MeyerFilter[\\\\\\\"\\\",\
 \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\
\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\
\"\\\\\\\"kmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\
\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give Meyer filter of order "\), 
                    StyleBox["n",
                      "InlineFormula"]}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SplineFilter[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"kmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give spline filter of order "\), 
                    StyleBox["n",
                      "InlineFormula"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.1", "1.26"}],

Cell["Generating IIR filters.", "Caption",
  CellTags->"S3.1.1"],

Cell[TextData[{
  "The argument ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  " indicates the index of the coefficient where we truncate the IIR filter. \
The output of the above filter functions is again of the form ",
  Cell[BoxData[
      \(TraditionalForm
      \`{{h\_\(-m\), h\_\(-m + 1\), \[Ellipsis], h\_\(-m + L - 1\)}, -m}\)], 
    "InlineFormula",
    CellTags->"S3.1.1"],
  ". The starting index ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  " and the filter length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", 
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  " for Shannon and Meyer filters as well as for spline filters of odd order \
and is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", 
          StyleBox[\("kmax"\),
            "TI"], "+", "2"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  " for spline filters of even order. "
}], "Text",
  CellTags->{"S3.1.1", "1.27"}],

Cell[TextData[{
  "This gives the Shannon filter ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(-3\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`3\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.1", "1.28"}],

Cell[CellGroupData[{

Cell["ShannonFilter[3]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{\(-\(\@2\/\(3\ \[Pi]\)\)\), 0, \@2\/\[Pi], 1\/\@2, \@2\/\[Pi], 0, 
        \(-\(\@2\/\(3\ \[Pi]\)\)\)}, \(-3\)}\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell[TextData[{
  "The Meyer filter ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " of order 4 is calculated for ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(-4\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`4\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.1", "1.29"}],

Cell[CellGroupData[{

Cell["MeyerFilter[4, 4]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{0.0284836659436650663`, \(-0.135764653892920694`\), 
        \(-0.0318664874248328766`\), 0.44520268580124469`, 
        0.740178723984433073`, 0.44520268580124469`, 
        \(-0.0318664874248328766`\), \(-0.135764653892920694`\), 
        0.0284836659436650663`}, \(-4\)}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell[TextData[{
  "Here is the Battle\[Hyphen]Lemari\[EAcute] filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`N = 6\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " calculated to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "3"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  ". Note that for even ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", the filter coefficients are calculated up to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.1", "1.30"}],

Cell[CellGroupData[{

Cell["SplineFilter[6, 3]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{\(-0.0578842373318419589`\), \(-0.139930088752363124`\), 
        0.18259174104975159`, 0.658910732598087722`, 0.658910732598087722`, 
        0.18259174104975159`, \(-0.139930088752363124`\), 
        \(-0.0578842373318419589`\)}, \(-3\)}\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell[TextData[{
  "Biorthogonal wavelets do not constitute an orthogonal basis. In addition \
to the filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", a dual filter ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is needed to perform wavelet decomposition. Commonly used biorthogonal \
wavelets are biorthogonal spline wavelets. The order of a biorthogonal spline \
filter is specified by two numbers ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ", and they should be both even or both odd. The dual scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(N\&~\) - 1\)], "InlineFormula",
    CellTags->"S3.1.1"],
  ". "
}], "Text",
  CellTags->{"S3.1.1", "1.31"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BiorthogonalSplineFilter[\
\\\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"nt\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\
\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                  \("give the biorthogonal spline filter of order "\), 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{"n", ",", 
                          StyleBox[\("nt"\),
                            "TI"]}], "}"}],
                      "InlineFormula"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.1", "1.32"}],

Cell["Biorthogonal spline filter.", "Caption",
  CellTags->"S3.1.1"],

Cell[TextData[{
  "The output of ",
  StyleBox["BiorthogonalSplineFilter", "MR"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`{h, \(h\&~\)}\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " have the form of the output of an orthogonal filter. "
}], "Text",
  CellTags->{"S3.1.1", "1.33"}],

Cell[TextData[{
  "The output consists of two filters ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " and\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.1", "1.34"}],

Cell[CellGroupData[{

Cell["BiorthogonalSplineFilter[1, 3]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{{\(-\(1\/\(2\ \@2\)\)\), 3\/\(2\ \@2\), 3\/\(2\ \@2\), 
          \(-\(1\/\(2\ \@2\)\)\)}, 
        \(-1\)}, {{1\/\(4\ \@2\), 3\/\(4\ \@2\), 3\/\(4\ \@2\), 
          1\/\(4\ \@2\)}, \(-1\)}}\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["\<\
This gives the approximate values of the filter coefficients.\
\>", 
  "MathCaption",
  CellTags->{"S3.1.1", "1.35"}],

Cell[CellGroupData[{

Cell["MapAt[N, #, {1}]& /@ %", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{{\(-0.353553390593273775`\), 1.06066017177982141`, 
          1.06066017177982141`, \(-0.353553390593273775`\)}, 
        \(-1\)}, {{0.176776695296636887`, 0.530330085889910662`, 
          0.530330085889910662`, 0.176776695296636887`}, \(-1\)}}\)], "Output",\

  CellLabel->"Out[13]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell[TextData[{
  "To get the highpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " (see (",
  ButtonBox["1.3",
    ButtonData:>{"Wavelets 3.1.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  ")), we can use the function ",
  StyleBox["HighpassFilter", "MR"],
  ". "
}], "Text",
  CellTags->{"S3.1.1", "1.36"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"HighpassFilter[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"h\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                  \("give the highpass filter from the lowpass filter "\), 
                    StyleBox["h",
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.1", "1.37"}],

Cell["Getting highpass filter.", "Caption",
  CellTags->"S3.1.1"],

Cell[TextData[{
  "This gives the highpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S3.1.1"],
  " for the coiflet filter of order 4."
}], "MathCaption",
  CellTags->{"S3.1.1", "1.38"}],

Cell[CellGroupData[{

Cell["HighpassFilter[CoifletFilter[4]]", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S3.1.1"],

Cell[BoxData[
    \({{\(-0.00072054944554090019`\), 0.001823208870779224`, 
        0.00561143481910879504`, \(-0.0236801719465515336`\), 
        \(-0.059434418645185385`\), 0.0764885990784138769`, 
        0.417005184421267749`, \(-0.812723635450272219`\), 
        0.386110066824111299`, 0.067372554724517748`, 
        \(-0.0414649367872140217`\), \(-0.0163873364634346359`\)}, \(-6\)}\)],
   "Output",
  CellLabel->"Out[14]= ",
  CellTags->"S3.1.1"]
}, Open  ]],

Cell["3.1.2 Scaling Functions, Wavelets, and Wavelet Packets", "Subsection",
  CellTags->{"S3.1.2", "2.1"}],

Cell[TextData[{
  "When the (lowpass) filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " is an FIR filter, the values of the scaling function at the dyadic points \
can be obtained using the dilation equation (",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 3.1.1", "1.5"},
    ButtonStyle->"AddOnsLink"],
  "). The scaling function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and the basic wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " are the two lowest\[Hyphen]order functions of a family of functions \
generated by the recursions "
}], "Text",
  CellTags->{"S3.1.2", "2.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(w\_\(2  n\)\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), \(w\_n\), \((2  t - k)\), ","}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.1.2", "2.3"}],

Cell["and ", "Text",
  CellTags->{"S3.1.2", "2.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(w\_\(2  n + 1\)\), \((t)\), "=", \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), \(w\_n\), \((2  t - k)\), "."}],
       TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.1.2", "2.5"}],

Cell[TextData[{
  "These functions are called wavelet packets. Different combinations of ",
  Cell[BoxData[
      \(TraditionalForm\`{\(2\^\(j/2\)\) \(w\_n\) \((\(2\^j\) t - k)\)}\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  " can form different orthonormal bases. Clearly, the scaling function \
corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_0\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "; the basic wavelet, to ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_1\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.6"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ScalingFunction[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"jmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                  "\<\"compute scaling function using filter \
\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \\\"TI\\\"]\\) to scale \
\"\>", 
                    StyleBox[
                      RowBox[{"1", "/", 
                        SuperscriptBox["2", 
                          StyleBox[\("jmax"\),
                            "TI"]]}],
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Wavelet[\\\\\\\"\\\", \\\
\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"jmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("compute basic wavelet "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WaveletPacket[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"jmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("compute wavelet packet "\), 
                    StyleBox[\(w\_n\),
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.7"}],

Cell["Scaling function, wavelet, and wavelet packet.", "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "The argument ",
  StyleBox["filter", "TI"],
  " in the above functions is the lowpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". The output of these functions is a list of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"k", "/", 
            SuperscriptBox["2", 
              StyleBox[\("jmax"\),
                "TI"]], ",", \(w\_n\), 
            RowBox[{"(", 
              RowBox[{"k", "/", 
                SuperscriptBox["2", 
                  StyleBox[\("jmax"\),
                    "TI"]]}], ")"}]}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " is an integer and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            StyleBox[\("jmax"\),
              "TI"]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  " lies within the support of ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". (Note that when ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("jmax"\),
            "TI"], "\[LessEqual]", \(log\_2\), "n"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  ", ",
  StyleBox["jmax", "TI"],
  " is replaced by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(log\_2\) n]\)\) + 1\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([x]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " is the integer part of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ".) "
}], "Text",
  CellTags->{"S3.1.2", "2.8"}],

Cell["This is the Daubechies filter of order 2.", "MathCaption",
  CellTags->{"S3.1.2", "2.9"}],

Cell[CellGroupData[{

Cell["d2 = DaubechiesFilter[2]", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S3.1.2"],

Cell[BoxData[
    \({{0.482962913144534056`, 0.836516303737807831`, 0.224143868042013361`, 
        \(-0.129409522551260369`\)}, 0}\)], "Output",
  CellLabel->"Out[15]= ",
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This generates the values of the basic wavelet at the dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^5\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.10"}],

Cell["psilist = Wavelet[d2, 5];", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S3.1.2"],

Cell[TextData[{
  StyleBox["psilist", "MR"],
  " contains a list of ",
  Cell[BoxData[
      \(TraditionalForm\`{k/2\^5, \[Psi] \((k/2\^5)\)}\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " runs through the integers such that ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^5\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " lies within the support ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-1\), 2]\)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.11"}],

Cell[CellGroupData[{

Cell["Short[psilist]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S3.1.2"],

Cell[BoxData[
    TagBox[\({{\(-1\), 0.`}, \[LeftSkeleton]95\[RightSkeleton], {2, 0}}\),
      Short]], "Output",
  CellLabel->"Out[17]//Short= ",
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This shows the wavelet. We can, of course, use the option ",
  StyleBox["PlotJoined", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  " to make the graph of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " continuous."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.12"}],

Cell[CellGroupData[{

Cell["ListPlot[psilist, AxesLabel -> {\"t\", \"psi(t)\"}]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.274246 0.18999 [
[.02381 .26175 -6 -9 ]
[.02381 .26175 6 0 ]
[.18254 .26175 -12 -9 ]
[.18254 .26175 12 0 ]
[.5 .26175 -9 -9 ]
[.5 .26175 9 0 ]
[.65873 .26175 -3 -9 ]
[.65873 .26175 3 0 ]
[.81746 .26175 -9 -9 ]
[.81746 .26175 9 0 ]
[.97619 .26175 -3 -9 ]
[.97619 .26175 3 0 ]
[1.025 .27425 0 -4.5 ]
[1.025 .27425 6 4.5 ]
[.32877 .08426 -12 -4.5 ]
[.32877 .08426 0 4.5 ]
[.32877 .17925 -24 -4.5 ]
[.32877 .17925 0 4.5 ]
[.32877 .36924 -18 -4.5 ]
[.32877 .36924 0 4.5 ]
[.32877 .46424 -6 -4.5 ]
[.32877 .46424 0 4.5 ]
[.32877 .55923 -18 -4.5 ]
[.32877 .55923 0 4.5 ]
[.34127 .64303 -18 0 ]
[.34127 .64303 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27425 m
.02381 .2805 L
s
[(-1)] .02381 .26175 0 1 Mshowa
.18254 .27425 m
.18254 .2805 L
s
[(-0.5)] .18254 .26175 0 1 Mshowa
.5 .27425 m
.5 .2805 L
s
[(0.5)] .5 .26175 0 1 Mshowa
.65873 .27425 m
.65873 .2805 L
s
[(1)] .65873 .26175 0 1 Mshowa
.81746 .27425 m
.81746 .2805 L
s
[(1.5)] .81746 .26175 0 1 Mshowa
.97619 .27425 m
.97619 .2805 L
s
[(2)] .97619 .26175 0 1 Mshowa
.125 Mabswid
.05556 .27425 m
.05556 .278 L
s
.0873 .27425 m
.0873 .278 L
s
.11905 .27425 m
.11905 .278 L
s
.15079 .27425 m
.15079 .278 L
s
.21429 .27425 m
.21429 .278 L
s
.24603 .27425 m
.24603 .278 L
s
.27778 .27425 m
.27778 .278 L
s
.30952 .27425 m
.30952 .278 L
s
.37302 .27425 m
.37302 .278 L
s
.40476 .27425 m
.40476 .278 L
s
.43651 .27425 m
.43651 .278 L
s
.46825 .27425 m
.46825 .278 L
s
.53175 .27425 m
.53175 .278 L
s
.56349 .27425 m
.56349 .278 L
s
.59524 .27425 m
.59524 .278 L
s
.62698 .27425 m
.62698 .278 L
s
.69048 .27425 m
.69048 .278 L
s
.72222 .27425 m
.72222 .278 L
s
.75397 .27425 m
.75397 .278 L
s
.78571 .27425 m
.78571 .278 L
s
.84921 .27425 m
.84921 .278 L
s
.88095 .27425 m
.88095 .278 L
s
.9127 .27425 m
.9127 .278 L
s
.94444 .27425 m
.94444 .278 L
s
.25 Mabswid
0 .27425 m
1 .27425 L
s
[(t)] 1.025 .27425 -1 0 Mshowa
.34127 .08426 m
.34752 .08426 L
s
[(-1)] .32877 .08426 1 0 Mshowa
.34127 .17925 m
.34752 .17925 L
s
[(-0.5)] .32877 .17925 1 0 Mshowa
.34127 .36924 m
.34752 .36924 L
s
[(0.5)] .32877 .36924 1 0 Mshowa
.34127 .46424 m
.34752 .46424 L
s
[(1)] .32877 .46424 1 0 Mshowa
.34127 .55923 m
.34752 .55923 L
s
[(1.5)] .32877 .55923 1 0 Mshowa
.125 Mabswid
.34127 .10326 m
.34502 .10326 L
s
.34127 .12225 m
.34502 .12225 L
s
.34127 .14125 m
.34502 .14125 L
s
.34127 .16025 m
.34502 .16025 L
s
.34127 .19825 m
.34502 .19825 L
s
.34127 .21725 m
.34502 .21725 L
s
.34127 .23625 m
.34502 .23625 L
s
.34127 .25525 m
.34502 .25525 L
s
.34127 .29325 m
.34502 .29325 L
s
.34127 .31224 m
.34502 .31224 L
s
.34127 .33124 m
.34502 .33124 L
s
.34127 .35024 m
.34502 .35024 L
s
.34127 .38824 m
.34502 .38824 L
s
.34127 .40724 m
.34502 .40724 L
s
.34127 .42624 m
.34502 .42624 L
s
.34127 .44524 m
.34502 .44524 L
s
.34127 .48324 m
.34502 .48324 L
s
.34127 .50223 m
.34502 .50223 L
s
.34127 .52123 m
.34502 .52123 L
s
.34127 .54023 m
.34502 .54023 L
s
.34127 .06526 m
.34502 .06526 L
s
.34127 .04626 m
.34502 .04626 L
s
.34127 .02726 m
.34502 .02726 L
s
.34127 .00826 m
.34502 .00826 L
s
.34127 .57823 m
.34502 .57823 L
s
.34127 .59723 m
.34502 .59723 L
s
.34127 .61623 m
.34502 .61623 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi\\(t\\))] .34127 .64303 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .27425 Mdot
.03373 .26391 Mdot
.04365 .25911 Mdot
.05357 .25634 Mdot
.06349 .25209 Mdot
.07341 .2508 Mdot
.08333 .24803 Mdot
.09325 .24472 Mdot
.10317 .2418 Mdot
.1131 .24161 Mdot
.12302 .23992 Mdot
.13294 .2377 Mdot
.14286 .23587 Mdot
.15278 .23324 Mdot
.1627 .23102 Mdot
.17262 .22894 Mdot
.18254 .22675 Mdot
.19246 .22735 Mdot
.20238 .22646 Mdot
.2123 .22503 Mdot
.22222 .22399 Mdot
.23214 .22216 Mdot
.24206 .22073 Mdot
.25198 .21945 Mdot
.2619 .21806 Mdot
.27183 .21594 Mdot
.28175 .21421 Mdot
.29167 .21264 Mdot
.30159 .21095 Mdot
.31151 .20948 Mdot
.32143 .20791 Mdot
.33135 .20629 Mdot
.34127 .20471 Mdot
.35119 .2954 Mdot
.36111 .33664 Mdot
.37103 .35978 Mdot
.38095 .39617 Mdot
.39087 .40606 Mdot
.40079 .4292 Mdot
.41071 .45718 Mdot
.42063 .48162 Mdot
.43056 .48181 Mdot
.44048 .49524 Mdot
.4504 .51353 Mdot
.46032 .52827 Mdot
.47024 .5501 Mdot
.48016 .56839 Mdot
.49008 .58538 Mdot
.5 .60332 Mdot
.50992 .43101 Mdot
.51984 .36059 Mdot
.52976 .32746 Mdot
.53968 .26703 Mdot
.5496 .2612 Mdot
.55952 .22807 Mdot
.56944 .18495 Mdot
.57937 .14914 Mdot
.58929 .16329 Mdot
.59921 .15015 Mdot
.60913 .12701 Mdot
.61905 .11119 Mdot
.62897 .08073 Mdot
.63889 .0576 Mdot
.64881 .03714 Mdot
.65873 .01472 Mdot
.66865 .13653 Mdot
.67857 .18119 Mdot
.68849 .19761 Mdot
.69841 .2347 Mdot
.70833 .23045 Mdot
.71825 .24687 Mdot
.72817 .27086 Mdot
.7381 .2893 Mdot
.74802 .26991 Mdot
.75794 .2712 Mdot
.76786 .28005 Mdot
.77778 .28337 Mdot
.7877 .29776 Mdot
.79762 .30661 Mdot
.80754 .31343 Mdot
.81746 .32174 Mdot
.82738 .29128 Mdot
.8373 .28148 Mdot
.84722 .27926 Mdot
.85714 .27149 Mdot
.86706 .2748 Mdot
.87698 .27258 Mdot
.8869 .26832 Mdot
.89683 .26555 Mdot
.90675 .27292 Mdot
.91667 .27475 Mdot
.92659 .27455 Mdot
.93651 .27584 Mdot
.94643 .27415 Mdot
.95635 .27396 Mdot
.96627 .2743 Mdot
.97619 .27425 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "A continuous scaling function or wavelet or wavelet packet can be obtained \
by linearly interpolating the function values at dyadic points. This is \
accomplished by setting the option ",
  StyleBox["Interpolation", "MR"],
  " to ",
  StyleBox["True", "MR"],
  ". The default setting for this option is ",
  StyleBox["False", "MR"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.13"}],

Cell[TextData[{
  "The output is an ",
  StyleBox["InterpolatingFunction", "MR"],
  " object. The domain of interpolation is by default ",
  Cell[BoxData[
      \(TraditionalForm\`{\(-100\), 100}\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.14"}],

Cell[CellGroupData[{

Cell["psi = Wavelet[d2, 5, Interpolation -> True]", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S3.1.2"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{\(-100.`\), 100.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[19]= ",
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This gives the linearly interpolated value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0.50007\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.15"}],

Cell[CellGroupData[{

Cell["psi[0.50007]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S3.1.2"],

Cell[BoxData[
    \(1.73001930467097579`\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "Using the interpolated ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", we can plot the dilated and translated wavelets as well as the basic \
wavelet."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.16"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{psi[t], psi[2t-3]}, {t, -1, 3}, PlotRange -> All,
PlotLabel -> \"psi(t) and psi(2t-3)\"]\
\>", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.274311 0.190042 [
[.02381 .26181 -6 -9 ]
[.02381 .26181 6 0 ]
[.5 .26181 -3 -9 ]
[.5 .26181 3 0 ]
[.7381 .26181 -3 -9 ]
[.7381 .26181 3 0 ]
[.97619 .26181 -3 -9 ]
[.97619 .26181 3 0 ]
[.2494 .08427 -12 -4.5 ]
[.2494 .08427 0 4.5 ]
[.2494 .17929 -24 -4.5 ]
[.2494 .17929 0 4.5 ]
[.2494 .36933 -18 -4.5 ]
[.2494 .36933 0 4.5 ]
[.2494 .46435 -6 -4.5 ]
[.2494 .46435 0 4.5 ]
[.2494 .55937 -18 -4.5 ]
[.2494 .55937 0 4.5 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27431 m
.02381 .28056 L
s
[(-1)] .02381 .26181 0 1 Mshowa
.5 .27431 m
.5 .28056 L
s
[(1)] .5 .26181 0 1 Mshowa
.7381 .27431 m
.7381 .28056 L
s
[(2)] .7381 .26181 0 1 Mshowa
.97619 .27431 m
.97619 .28056 L
s
[(3)] .97619 .26181 0 1 Mshowa
.125 Mabswid
.07143 .27431 m
.07143 .27806 L
s
.11905 .27431 m
.11905 .27806 L
s
.16667 .27431 m
.16667 .27806 L
s
.21429 .27431 m
.21429 .27806 L
s
.30952 .27431 m
.30952 .27806 L
s
.35714 .27431 m
.35714 .27806 L
s
.40476 .27431 m
.40476 .27806 L
s
.45238 .27431 m
.45238 .27806 L
s
.54762 .27431 m
.54762 .27806 L
s
.59524 .27431 m
.59524 .27806 L
s
.64286 .27431 m
.64286 .27806 L
s
.69048 .27431 m
.69048 .27806 L
s
.78571 .27431 m
.78571 .27806 L
s
.83333 .27431 m
.83333 .27806 L
s
.88095 .27431 m
.88095 .27806 L
s
.92857 .27431 m
.92857 .27806 L
s
.25 Mabswid
0 .27431 m
1 .27431 L
s
.2619 .08427 m
.26815 .08427 L
s
[(-1)] .2494 .08427 1 0 Mshowa
.2619 .17929 m
.26815 .17929 L
s
[(-0.5)] .2494 .17929 1 0 Mshowa
.2619 .36933 m
.26815 .36933 L
s
[(0.5)] .2494 .36933 1 0 Mshowa
.2619 .46435 m
.26815 .46435 L
s
[(1)] .2494 .46435 1 0 Mshowa
.2619 .55937 m
.26815 .55937 L
s
[(1.5)] .2494 .55937 1 0 Mshowa
.125 Mabswid
.2619 .10327 m
.26565 .10327 L
s
.2619 .12228 m
.26565 .12228 L
s
.2619 .14128 m
.26565 .14128 L
s
.2619 .16029 m
.26565 .16029 L
s
.2619 .19829 m
.26565 .19829 L
s
.2619 .2173 m
.26565 .2173 L
s
.2619 .2363 m
.26565 .2363 L
s
.2619 .25531 m
.26565 .25531 L
s
.2619 .29332 m
.26565 .29332 L
s
.2619 .31232 m
.26565 .31232 L
s
.2619 .33132 m
.26565 .33132 L
s
.2619 .35033 m
.26565 .35033 L
s
.2619 .38834 m
.26565 .38834 L
s
.2619 .40734 m
.26565 .40734 L
s
.2619 .42634 m
.26565 .42634 L
s
.2619 .44535 m
.26565 .44535 L
s
.2619 .48336 m
.26565 .48336 L
s
.2619 .50236 m
.26565 .50236 L
s
.2619 .52137 m
.26565 .52137 L
s
.2619 .54037 m
.26565 .54037 L
s
.2619 .06527 m
.26565 .06527 L
s
.2619 .04626 m
.26565 .04626 L
s
.2619 .02726 m
.26565 .02726 L
s
.2619 .00825 m
.26565 .00825 L
s
.2619 .57838 m
.26565 .57838 L
s
.2619 .59738 m
.26565 .59738 L
s
.2619 .61639 m
.26565 .61639 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
[(psi\\(t\\) and psi\\(2t-3\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .27431 m
.02846 .26785 L
.02952 .26637 L
.03068 .26476 L
.03178 .26363 L
.03279 .26298 L
.03527 .26138 L
.03754 .25992 L
.04 .25868 L
.04262 .25771 L
.06244 .25033 L
.10458 .23807 L
.12434 .23216 L
.13298 .22967 L
.13755 .22836 L
.14005 .22763 L
.14128 .22726 L
.14241 .22693 L
.14371 .22687 L
.1444 .22692 L
.14512 .22698 L
.14757 .22718 L
.14868 .22727 L
.14986 .22736 L
.15115 .2273 L
.15237 .22715 L
.16182 .22572 L
.1827 .22171 L
.20251 .21807 L
.22406 .21282 L
.2341 .21062 L
.24476 .20843 L
.25386 .20647 L
.25636 .20594 L
.25904 .20536 L
.26028 .2051 L
.26158 .20482 L
.26269 .21437 L
.26391 .22919 L
.26644 .26011 L
.26778 .27639 L
.26851 .2853 L
.26919 .29363 L
.27043 .30149 L
.27179 .30903 L
.27418 .3223 L
.27529 .32842 L
.27649 .3351 L
.27763 .33935 L
.27868 .34263 L
Mistroke
.28121 .35049 L
.28352 .35767 L
.30447 .42284 L
.34365 .51342 L
.35396 .53654 L
.3651 .56616 L
.37022 .57802 L
.37562 .59062 L
.37785 .59599 L
.37907 .59894 L
.38023 .60174 L
.38089 .60332 L
.3816 .58845 L
.38285 .55957 L
.38529 .50309 L
.38763 .44883 L
.38894 .4259 L
.39015 .41448 L
.39471 .37131 L
.39588 .36047 L
.39713 .3549 L
.3985 .3488 L
.39977 .34313 L
.4051 .31271 L
.42612 .22508 L
.43111 .19614 L
.43639 .16884 L
.43915 .15557 L
.4399 .15193 L
.44071 .14962 L
.44148 .15108 L
.44218 .15241 L
.44494 .15767 L
.44616 .15999 L
.44681 .16122 L
.44751 .16255 L
.44875 .16186 L
.44991 .15981 L
.45246 .15529 L
.45786 .1424 L
.46767 .11667 L
.48769 .05054 L
.49255 .03715 L
.49523 .02909 L
.49776 .02148 L
.49919 .01715 L
.5 .01472 L
.50074 .02691 L
.50346 .07142 L
.50489 .09474 L
Mistroke
.50624 .11689 L
.50745 .13664 L
.50814 .14076 L
.50878 .14459 L
.51344 .17259 L
.51469 .1801 L
.51587 .18341 L
.51723 .18641 L
.51846 .18912 L
.52057 .1938 L
.52173 .19635 L
.52281 .20009 L
.52398 .20592 L
.52526 .21232 L
.52752 .22357 L
.5288 .22996 L
.52952 .23357 L
.53019 .23451 L
.53142 .23381 L
.53273 .23306 L
.53501 .23175 L
.5363 .23102 L
.53748 .23111 L
.53875 .23392 L
.5401 .23689 L
.54255 .24231 L
.54815 .25823 L
.55306 .27335 L
.55548 .27934 L
.5577 .28486 L
.55895 .28795 L
.56027 .28743 L
.56095 .28564 L
.56159 .28398 L
.56305 .28018 L
.56424 .27707 L
.56554 .27369 L
.56677 .27049 L
.56791 .27014 L
.56908 .27034 L
.57015 .27053 L
.5713 .27073 L
.57254 .27094 L
.57367 .27114 L
.57472 .27163 L
.57571 .27282 L
.57676 .27407 L
.58628 .28209 L
.5875 .28264 L
.58815 .28293 L
Mistroke
.58884 .28323 L
.5901 .285 L
.59126 .28725 L
.59579 .29602 L
.59829 .29969 L
.60063 .30248 L
.60597 .30834 L
.6105 .3125 L
.61481 .31709 L
.61718 .31974 L
.61783 .32047 L
.61853 .32124 L
.61978 .31884 L
.621 .31381 L
.62216 .30908 L
.62432 .30022 L
.62548 .29547 L
.62673 .29103 L
.6279 .28949 L
.62897 .28808 L
.63162 .28458 L
.63279 .28305 L
.63408 .28151 L
.63531 .28114 L
.63661 .28075 L
.63794 .28035 L
.63937 .27992 L
.64003 .27972 L
.64072 .27952 L
.64196 .27871 L
.64312 .2775 L
.64439 .27617 L
.64677 .27369 L
.64794 .27247 L
.64901 .27165 L
.65026 .2722 L
.6516 .2728 L
.65396 .27385 L
.65495 .27429 L
.65601 .27476 L
.65719 .27459 L
.65828 .27426 L
.66068 .27354 L
.66286 .27289 L
.66417 .27237 L
.6654 .27166 L
.66811 .27011 L
.67298 .2677 L
.67557 .26674 L
.67698 .26621 L
Mistroke
.67829 .26572 L
.67898 .26602 L
.67972 .26675 L
.68128 .2683 L
.68402 .27102 L
.68528 .27226 L
.68592 .27289 L
.68661 .27313 L
.68808 .27349 L
.68943 .27383 L
.69189 .27443 L
.69257 .2746 L
.69328 .27477 L
.69454 .27479 L
.69577 .27475 L
.69691 .27472 L
.69826 .27469 L
.69949 .27465 L
.70064 .27462 L
.70173 .27476 L
.70412 .27518 L
.70636 .27556 L
.70762 .27578 L
.70876 .27581 L
.70941 .27566 L
.71012 .2755 L
.7114 .27521 L
.71386 .27465 L
.71451 .27451 L
.7152 .27435 L
.71646 .2742 L
.71777 .27417 L
.71921 .27413 L
.72047 .27409 L
.7218 .27406 L
.72293 .27403 L
.72417 .27406 L
.72654 .27417 L
.72879 .27428 L
.73003 .27434 L
.73073 .27436 L
.73137 .27436 L
.73373 .27434 L
.73596 .27433 L
.73705 .27432 L
.73805 .27431 L
.7391 .27431 L
.74023 .27431 L
.74263 .27431 L
.78235 .27431 L
Mistroke
.82055 .27431 L
.8612 .27431 L
.90034 .27431 L
.94193 .27431 L
.97619 .27431 L
Mfstroke
.02381 .27431 m
.06244 .27431 L
.10458 .27431 L
.14415 .27431 L
.18221 .27431 L
.22272 .27431 L
.26171 .27431 L
.30316 .27431 L
.34309 .27431 L
.3815 .27431 L
.42237 .27431 L
.46172 .27431 L
.48147 .27431 L
.49012 .27431 L
.49468 .27431 L
.49719 .27431 L
.49842 .27431 L
.49955 .27431 L
.50085 .27194 L
.50154 .27004 L
.50226 .26804 L
.50353 .26451 L
.50471 .26269 L
.507 .25975 L
.50821 .2586 L
.5095 .25764 L
.51896 .25059 L
.53984 .2384 L
.54945 .23265 L
.55471 .2296 L
.55729 .22812 L
.55842 .22745 L
.55965 .22682 L
.5609 .22702 L
.56221 .22723 L
.5629 .22734 L
.56364 .2273 L
.56434 .22714 L
.56497 .22699 L
.57084 .22503 L
.5812 .22103 L
.59103 .21711 L
.6017 .21212 L
.60659 .21005 L
.61176 .20789 L
.61618 .20597 L
.61739 .20546 L
.6187 .2049 L
.61992 .22611 L
.62105 .25347 L
Mistroke
.62234 .285 L
.62355 .3042 L
.62465 .31631 L
.62583 .32939 L
.62712 .34064 L
.62848 .34911 L
.63092 .3668 L
.64007 .42121 L
.64254 .43808 L
.64522 .45813 L
.64644 .46619 L
.64775 .47475 L
.64886 .48175 L
.65008 .48181 L
.65148 .48188 L
.65226 .48191 L
.65298 .48356 L
.65361 .48584 L
.6543 .48834 L
.6557 .49337 L
.66081 .51697 L
.66574 .54044 L
.67101 .56793 L
.67356 .57965 L
.67598 .59095 L
.67703 .59603 L
.67814 .60139 L
.67936 .56693 L
.68048 .51487 L
.6816 .46302 L
.68266 .42407 L
.68389 .40091 L
.685 .37977 L
.68598 .36122 L
.68703 .35165 L
.68817 .34147 L
.68923 .33205 L
.69883 .24649 L
.70339 .19922 L
.70587 .17288 L
.70708 .16121 L
.70818 .1506 L
.7094 .15323 L
.7107 .15817 L
.71138 .16075 L
.71211 .16312 L
.71281 .16067 L
.71345 .1584 L
.71828 .13461 L
.72708 .07983 L
Mistroke
.73194 .05055 L
.73433 .03739 L
.73655 .02403 L
.73772 .01698 L
.73897 .04324 L
.73968 .06658 L
.74035 .08856 L
.7416 .12963 L
.74276 .14791 L
.74383 .16069 L
.74507 .17561 L
.74623 .18428 L
.74724 .18876 L
.74833 .19356 L
.74954 .20044 L
.75063 .2114 L
.75178 .22283 L
.75303 .2347 L
.7542 .23336 L
.75529 .23211 L
.75647 .23076 L
.75774 .23512 L
.76005 .24529 L
.76529 .27666 L
.76669 .2836 L
.768 .28865 L
.76865 .28522 L
.76935 .28157 L
.77007 .27785 L
.77084 .27383 L
.77155 .27011 L
.77221 .2702 L
.7735 .27064 L
.77468 .27105 L
.77592 .27274 L
.77713 .27563 L
.77845 .27877 L
.7797 .28073 L
.78086 .28176 L
.782 .28278 L
.78304 .28461 L
.78424 .28924 L
.78537 .2936 L
.78791 .30128 L
.79024 .3068 L
.79297 .3118 L
.79551 .31711 L
.79657 .31947 L
.79756 .3217 L
.79872 .31284 L
Mistroke
.79976 .30426 L
.80085 .29537 L
.802 .28961 L
.80326 .28629 L
.80442 .28322 L
.80554 .28126 L
.80673 .28055 L
.80777 .27993 L
.8089 .27908 L
.81022 .27632 L
.81147 .2737 L
.81269 .27173 L
.81383 .27274 L
.81511 .27388 L
.81576 .27446 L
.81647 .27472 L
.81773 .27397 L
.8189 .27327 L
.81961 .27284 L
.82028 .27225 L
.82155 .2708 L
.82439 .26785 L
.82559 .26695 L
.82686 .266 L
.82795 .26675 L
.82915 .26913 L
.83044 .27168 L
.83116 .27302 L
.83183 .27334 L
.83304 .27394 L
.83434 .27458 L
.83551 .27478 L
.83658 .27472 L
.83765 .27466 L
.83867 .27466 L
.83985 .27507 L
.84094 .27545 L
.84213 .27586 L
.8434 .27539 L
.84452 .27488 L
.84559 .2744 L
.84682 .27417 L
.84794 .27411 L
.84918 .27405 L
.84988 .27404 L
.85053 .2741 L
.85168 .2742 L
.85294 .27432 L
.85423 .27435 L
.85494 .27434 L
Mistroke
.8556 .27433 L
.85677 .27432 L
.85803 .27431 L
.85874 .27431 L
.85951 .27431 L
.86091 .27431 L
.86353 .27431 L
.8735 .27431 L
.89211 .27431 L
.93294 .27431 L
.97224 .27431 L
.97619 .27431 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell["\<\
This gives the interpolated least asymmetric scaling function of \
order 4.\
\>", "MathCaption",
  CellTags->{"S3.1.2", "2.17"}],

Cell["\<\
phi = ScalingFunction[LeastAsymmetricFilter[4], 7,
Interpolation -> True];\
\>", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S3.1.2"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((2  t - 1)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " are plotted here."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.18"}],

Cell[CellGroupData[{

Cell["\<\
Plot[{phi[t], phi[2t-1]}, {t, 0, 7},
PlotStyle -> {GrayLevel[0], GrayLevel[0.5]},
PlotRange -> All, PlotLabel -> \"phi(2t-1) and phi(t)\"]\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0918505 0.422594 [
[.15986 .07935 -3 -9 ]
[.15986 .07935 3 0 ]
[.29592 .07935 -3 -9 ]
[.29592 .07935 3 0 ]
[.43197 .07935 -3 -9 ]
[.43197 .07935 3 0 ]
[.56803 .07935 -3 -9 ]
[.56803 .07935 3 0 ]
[.70408 .07935 -3 -9 ]
[.70408 .07935 3 0 ]
[.84014 .07935 -3 -9 ]
[.84014 .07935 3 0 ]
[.97619 .07935 -3 -9 ]
[.97619 .07935 3 0 ]
[.01131 .00733 -24 -4.5 ]
[.01131 .00733 0 4.5 ]
[.01131 .17637 -18 -4.5 ]
[.01131 .17637 0 4.5 ]
[.01131 .26089 -18 -4.5 ]
[.01131 .26089 0 4.5 ]
[.01131 .34541 -18 -4.5 ]
[.01131 .34541 0 4.5 ]
[.01131 .42993 -18 -4.5 ]
[.01131 .42993 0 4.5 ]
[.01131 .51444 -6 -4.5 ]
[.01131 .51444 0 4.5 ]
[.01131 .59896 -18 -4.5 ]
[.01131 .59896 0 4.5 ]
[.5 .63053 -60 0 ]
[.5 .63053 60 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15986 .09185 m
.15986 .0981 L
s
[(1)] .15986 .07935 0 1 Mshowa
.29592 .09185 m
.29592 .0981 L
s
[(2)] .29592 .07935 0 1 Mshowa
.43197 .09185 m
.43197 .0981 L
s
[(3)] .43197 .07935 0 1 Mshowa
.56803 .09185 m
.56803 .0981 L
s
[(4)] .56803 .07935 0 1 Mshowa
.70408 .09185 m
.70408 .0981 L
s
[(5)] .70408 .07935 0 1 Mshowa
.84014 .09185 m
.84014 .0981 L
s
[(6)] .84014 .07935 0 1 Mshowa
.97619 .09185 m
.97619 .0981 L
s
[(7)] .97619 .07935 0 1 Mshowa
.125 Mabswid
.05102 .09185 m
.05102 .0956 L
s
.07823 .09185 m
.07823 .0956 L
s
.10544 .09185 m
.10544 .0956 L
s
.13265 .09185 m
.13265 .0956 L
s
.18707 .09185 m
.18707 .0956 L
s
.21429 .09185 m
.21429 .0956 L
s
.2415 .09185 m
.2415 .0956 L
s
.26871 .09185 m
.26871 .0956 L
s
.32313 .09185 m
.32313 .0956 L
s
.35034 .09185 m
.35034 .0956 L
s
.37755 .09185 m
.37755 .0956 L
s
.40476 .09185 m
.40476 .0956 L
s
.45918 .09185 m
.45918 .0956 L
s
.48639 .09185 m
.48639 .0956 L
s
.51361 .09185 m
.51361 .0956 L
s
.54082 .09185 m
.54082 .0956 L
s
.59524 .09185 m
.59524 .0956 L
s
.62245 .09185 m
.62245 .0956 L
s
.64966 .09185 m
.64966 .0956 L
s
.67687 .09185 m
.67687 .0956 L
s
.73129 .09185 m
.73129 .0956 L
s
.7585 .09185 m
.7585 .0956 L
s
.78571 .09185 m
.78571 .0956 L
s
.81293 .09185 m
.81293 .0956 L
s
.86735 .09185 m
.86735 .0956 L
s
.89456 .09185 m
.89456 .0956 L
s
.92177 .09185 m
.92177 .0956 L
s
.94898 .09185 m
.94898 .0956 L
s
.25 Mabswid
0 .09185 m
1 .09185 L
s
.02381 .00733 m
.03006 .00733 L
s
[(-0.2)] .01131 .00733 1 0 Mshowa
.02381 .17637 m
.03006 .17637 L
s
[(0.2)] .01131 .17637 1 0 Mshowa
.02381 .26089 m
.03006 .26089 L
s
[(0.4)] .01131 .26089 1 0 Mshowa
.02381 .34541 m
.03006 .34541 L
s
[(0.6)] .01131 .34541 1 0 Mshowa
.02381 .42993 m
.03006 .42993 L
s
[(0.8)] .01131 .42993 1 0 Mshowa
.02381 .51444 m
.03006 .51444 L
s
[(1)] .01131 .51444 1 0 Mshowa
.02381 .59896 m
.03006 .59896 L
s
[(1.2)] .01131 .59896 1 0 Mshowa
.125 Mabswid
.02381 .02846 m
.02756 .02846 L
s
.02381 .04959 m
.02756 .04959 L
s
.02381 .07072 m
.02756 .07072 L
s
.02381 .11298 m
.02756 .11298 L
s
.02381 .13411 m
.02756 .13411 L
s
.02381 .15524 m
.02756 .15524 L
s
.02381 .1975 m
.02756 .1975 L
s
.02381 .21863 m
.02756 .21863 L
s
.02381 .23976 m
.02756 .23976 L
s
.02381 .28202 m
.02756 .28202 L
s
.02381 .30315 m
.02756 .30315 L
s
.02381 .32428 m
.02756 .32428 L
s
.02381 .36654 m
.02756 .36654 L
s
.02381 .38767 m
.02756 .38767 L
s
.02381 .4088 m
.02756 .4088 L
s
.02381 .45106 m
.02756 .45106 L
s
.02381 .47219 m
.02756 .47219 L
s
.02381 .49331 m
.02756 .49331 L
s
.02381 .53557 m
.02756 .53557 L
s
.02381 .5567 m
.02756 .5567 L
s
.02381 .57783 m
.02756 .57783 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi\\(2t-1\\) and phi\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .09185 m
.02499 .09185 L
.02605 .09185 L
.02729 .09185 L
.02846 .09185 L
.02954 .09185 L
.03053 .09185 L
.03163 .09185 L
.03279 .09185 L
.03394 .09185 L
.03504 .09185 L
.03631 .09184 L
.03746 .09184 L
.03874 .09184 L
.03946 .09184 L
.04012 .09184 L
.04133 .09185 L
.04262 .09187 L
.04387 .09188 L
.04519 .09189 L
.04588 .09189 L
.04664 .0919 L
.04797 .09191 L
.05041 .09192 L
.05111 .09193 L
.05177 .09193 L
.05302 .09193 L
.05423 .09193 L
.05535 .09192 L
.05658 .09191 L
.05789 .09188 L
.05901 .09183 L
.06006 .09177 L
.06244 .09165 L
.06374 .09159 L
.06511 .09153 L
.06642 .09147 L
.0676 .09145 L
.07019 .09138 L
.07302 .09131 L
.07547 .09124 L
.07681 .0912 L
.07807 .09116 L
.07914 .09114 L
.08028 .09113 L
.08156 .09113 L
.08272 .09113 L
.08341 .09113 L
.08405 .09112 L
.08474 .09112 L
Mistroke
.08549 .09112 L
.0862 .09114 L
.08687 .09116 L
.08812 .0912 L
.08883 .09123 L
.08958 .09127 L
.09023 .09133 L
.09093 .09139 L
.09168 .09149 L
.09238 .09163 L
.09397 .09202 L
.09948 .09336 L
.10458 .09447 L
.10713 .09503 L
.10838 .09527 L
.10953 .09543 L
.11073 .09556 L
.11203 .09571 L
.11478 .09602 L
.12586 .09728 L
.12832 .09771 L
.13095 .09811 L
.13222 .09828 L
.13343 .09842 L
.13451 .09851 L
.13567 .09855 L
.13692 .09858 L
.13824 .0986 L
.13937 .09861 L
.14061 .09861 L
.14131 .0986 L
.14195 .09859 L
.14269 .09858 L
.14339 .09861 L
.14464 .09866 L
.14534 .09867 L
.14599 .09867 L
.14717 .09864 L
.1484 .09852 L
.15062 .09823 L
.15177 .09805 L
.153 .09785 L
.1537 .0977 L
.15435 .09753 L
.1556 .09715 L
.15669 .0968 L
.15783 .09629 L
.15909 .0956 L
.16025 .09464 L
.16463 .0897 L
Mistroke
.17456 .07848 L
.18523 .06752 L
.19046 .06212 L
.19171 .06097 L
.19304 .05983 L
.1943 .05897 L
.19544 .05838 L
.1999 .05613 L
.20478 .05362 L
.22308 .04408 L
.23324 .03645 L
.23879 .0321 L
.2415 .03027 L
.24268 .02952 L
.24397 .02881 L
.24514 .02833 L
.24624 .0281 L
.24839 .0277 L
.24956 .02752 L
.25083 .02731 L
.25203 .02718 L
.25312 .02708 L
.25544 .02694 L
.25668 .02688 L
.25799 .02688 L
.25928 .02693 L
.26047 .02695 L
.26177 .02689 L
.2625 .02668 L
.26317 .02647 L
.26441 .02612 L
.26558 .02588 L
.26679 .02571 L
.26743 .02567 L
.26813 .02565 L
.26935 .02566 L
.27051 .02586 L
.27156 .02629 L
.27269 .02683 L
.27805 .03018 L
.28061 .03185 L
.28186 .03282 L
.28301 .03389 L
.2853 .0368 L
.28778 .0405 L
.29209 .04886 L
.29433 .05495 L
.2956 .05944 L
.29678 .06533 L
.30174 .09329 L
Mistroke
.34072 .30366 L
.36058 .39892 L
.38215 .48834 L
.39222 .52094 L
.40291 .55713 L
.41202 .58293 L
.41452 .58837 L
.41721 .59408 L
.41851 .59642 L
.41975 .59823 L
.42207 .60067 L
.42331 .60165 L
.42397 .60221 L
.42466 .60278 L
.42593 .60332 L
.42709 .60325 L
.42822 .60289 L
.42927 .60214 L
.43042 .60062 L
.43165 .59789 L
.43296 .59218 L
.43439 .58475 L
.43699 .57076 L
.44187 .5436 L
.46025 .43965 L
.50102 .23249 L
.52126 .1604 L
.54027 .09086 L
.54912 .0583 L
.55843 .031 L
.56079 .02523 L
.56331 .01999 L
.56476 .01747 L
.56607 .01577 L
.56671 .01513 L
.5674 .01472 L
.56865 .01515 L
.56977 .01647 L
.57101 .01801 L
.57352 .0214 L
.57801 .02798 L
.59908 .05913 L
.61834 .08081 L
.62786 .09459 L
.63047 .09767 L
.6319 .09918 L
.63325 .10057 L
.63451 .10164 L
.63517 .1021 L
.63587 .10246 L
Mistroke
.63711 .10245 L
.63825 .10228 L
.64726 .10108 L
.64974 .10078 L
.65039 .10067 L
.65109 .10056 L
.65238 .1004 L
.65368 .10035 L
.65488 .10037 L
.65598 .10038 L
.65715 .1004 L
.65829 .10044 L
.65954 .10048 L
.66084 .10052 L
.66205 .10045 L
.66316 .10032 L
.66436 .10024 L
.6655 .10021 L
.66654 .10022 L
.66779 .10031 L
.66911 .10051 L
.67021 .10091 L
.67143 .10174 L
.67665 .10522 L
.68121 .10782 L
.68373 .10914 L
.68611 .11032 L
.68832 .1111 L
.69073 .11175 L
.69494 .11263 L
.69727 .1132 L
.69849 .11344 L
.69978 .11364 L
.70091 .11375 L
.70215 .11378 L
.70327 .11373 L
.70432 .11351 L
.70497 .11324 L
.70567 .11293 L
.70694 .11237 L
.70933 .11127 L
.71468 .10875 L
.73568 .09983 L
.75552 .09261 L
.76035 .09073 L
.76553 .08905 L
.76706 .08866 L
.7685 .08831 L
.76919 .08816 L
.76991 .08803 L
Mistroke
.77122 .08785 L
.77191 .08781 L
.77256 .08786 L
.77377 .08803 L
.77655 .08847 L
.78632 .09001 L
.79664 .09125 L
.80089 .09186 L
.80323 .09215 L
.80438 .09227 L
.80545 .09236 L
.8067 .0924 L
.80736 .09238 L
.80806 .09237 L
.80929 .09235 L
.81045 .09232 L
.81151 .09231 L
.81266 .0923 L
.81395 .09227 L
.81511 .09226 L
.81635 .09226 L
.81751 .09226 L
.81874 .09225 L
.81943 .09224 L
.82007 .09224 L
.82114 .09223 L
.82232 .09223 L
.82354 .09227 L
.82469 .09235 L
.82728 .0925 L
.82974 .09262 L
.83109 .09268 L
.83186 .09271 L
.83257 .09273 L
.83516 .09278 L
.83649 .0928 L
.83719 .09282 L
.83792 .09283 L
.83857 .09283 L
.83928 .09283 L
.84052 .09281 L
.84174 .09276 L
.84304 .09271 L
.84538 .09261 L
.85626 .0922 L
.86646 .09186 L
.86926 .09177 L
.87079 .09172 L
.87223 .09169 L
.87344 .09167 L
Mistroke
.87476 .09167 L
.8755 .09168 L
.87621 .09169 L
.87755 .09171 L
.8822 .09178 L
.88717 .09183 L
.88864 .09185 L
.88936 .09186 L
.89003 .09187 L
.89127 .09188 L
.89193 .09187 L
.89262 .09187 L
.89378 .09187 L
.89503 .09187 L
.89575 .09187 L
.8964 .09187 L
.89768 .09187 L
.90245 .09188 L
.90358 .09189 L
.90478 .09189 L
.9058 .09189 L
.90692 .09189 L
.90809 .09189 L
.90917 .09189 L
.91159 .09188 L
.91675 .09186 L
.92196 .09185 L
.92268 .09185 L
.92346 .09184 L
.92419 .09184 L
.92487 .09184 L
.92616 .09184 L
.92681 .09184 L
.92753 .09185 L
.93001 .09185 L
.93138 .09185 L
.93268 .09185 L
.93388 .09185 L
.9352 .09185 L
.93639 .09185 L
.9375 .09185 L
.93878 .09185 L
.93947 .09185 L
.94012 .09185 L
.94127 .09185 L
.94253 .09185 L
.94323 .09185 L
.9439 .09185 L
.94515 .09185 L
.94796 .09185 L
Mistroke
.94915 .09185 L
.95041 .09185 L
.95148 .09185 L
.95267 .09185 L
.95395 .09185 L
.95461 .09185 L
.95532 .09185 L
.95661 .09185 L
.9578 .09185 L
.95895 .09185 L
.96 .09185 L
.96113 .09185 L
.96235 .09185 L
.96349 .09185 L
.96453 .09185 L
.96553 .09185 L
.96659 .09185 L
.96772 .09185 L
.96879 .09185 L
.97003 .09185 L
.97116 .09185 L
.97241 .09185 L
.97311 .09185 L
.97376 .09185 L
.97494 .09185 L
.97619 .09185 L
Mfstroke
.5 g
.02381 .09185 m
.04262 .09185 L
.06244 .09185 L
.07216 .09185 L
.08255 .09185 L
.08562 .09185 L
.08852 .09185 L
.08979 .09185 L
.09113 .09185 L
.09183 .09185 L
.0926 .09185 L
.0933 .09185 L
.09396 .09185 L
.09461 .09185 L
.09533 .09185 L
.09663 .09185 L
.09791 .09184 L
.09907 .09184 L
.09979 .09184 L
.10046 .09185 L
.10116 .09186 L
.10193 .09188 L
.1026 .09189 L
.10331 .0919 L
.10458 .09191 L
.1058 .09193 L
.10649 .09193 L
.10713 .09193 L
.1083 .09191 L
.10954 .09182 L
.11171 .0916 L
.11285 .0915 L
.11406 .09143 L
.11536 .09137 L
.11655 .09131 L
.11768 .09124 L
.11889 .09117 L
.12021 .09113 L
.12143 .09113 L
.12218 .09112 L
.12289 .09113 L
.12353 .09117 L
.12422 .09121 L
.12536 .09138 L
.12642 .09178 L
.12885 .09295 L
.13141 .09413 L
.13254 .09461 L
.13376 .09513 L
.13489 .09547 L
Mistroke
.13593 .0957 L
.138 .09617 L
.14255 .0972 L
.14503 .09801 L
.14628 .09833 L
.14698 .09848 L
.14764 .09854 L
.14837 .09858 L
.14903 .0986 L
.14979 .09861 L
.15051 .0986 L
.15177 .09863 L
.15248 .09867 L
.15315 .09866 L
.15434 .09847 L
.15566 .0981 L
.15694 .09762 L
.15767 .09719 L
.15833 .09675 L
.15944 .09564 L
.16066 .09331 L
.16311 .08773 L
.16772 .07733 L
.1727 .0672 L
.18173 .05425 L
.1871 .04863 L
.18945 .04603 L
.19203 .0435 L
.19438 .04034 L
.19658 .03641 L
.19888 .03273 L
.20009 .03107 L
.20138 .02939 L
.20205 .02869 L
.20279 .0282 L
.2041 .02771 L
.20474 .02751 L
.20542 .02729 L
.20667 .02706 L
.2079 .02692 L
.20919 .02691 L
.21029 .02696 L
.2115 .02648 L
.21217 .02611 L
.21289 .02581 L
.21421 .02565 L
.215 .02578 L
.21573 .02631 L
.21711 .02772 L
.21966 .03112 L
Mistroke
.22094 .03295 L
.22167 .03442 L
.22235 .03616 L
.22357 .03975 L
.22487 .04403 L
.22613 .04957 L
.22727 .05602 L
.22838 .06594 L
.22959 .07941 L
.23177 .10471 L
.2419 .22032 L
.2602 .39871 L
.27052 .48501 L
.28016 .5482 L
.28286 .56697 L
.28541 .58039 L
.2879 .59147 L
.28899 .59578 L
.2902 .59916 L
.29144 .60142 L
.29275 .60331 L
.29344 .60327 L
.29418 .60277 L
.29488 .60143 L
.29552 .59913 L
.29621 .59417 L
.29685 .58766 L
.2983 .5721 L
.30122 .5397 L
.31997 .33926 L
.34029 .16226 L
.35141 .08018 L
.35629 .04665 L
.35887 .03234 L
.3603 .02536 L
.36165 .01976 L
.36292 .01587 L
.36363 .01472 L
.3643 .01524 L
.36547 .01808 L
.36671 .02146 L
.37144 .03594 L
.38181 .06519 L
.39213 .0899 L
.39496 .09721 L
.39638 .10024 L
.39719 .10163 L
.39794 .10253 L
.39863 .10241 L
.39929 .10222 L
Mistroke
.40052 .10181 L
.40328 .10111 L
.40454 .10089 L
.40572 .10049 L
.40695 .10035 L
.4076 .10038 L
.40831 .10039 L
.40955 .10047 L
.41073 .10052 L
.41179 .10026 L
.41295 .10021 L
.41367 .10028 L
.41434 .10045 L
.41559 .10166 L
.4184 .10541 L
.42102 .10831 L
.4223 .10966 L
.42346 .11072 L
.42461 .11139 L
.42571 .11194 L
.42811 .11297 L
.4293 .11348 L
.43056 .11376 L
.43121 .11377 L
.43194 .11362 L
.43322 .11253 L
.44353 .10344 L
.45253 .09618 L
.45743 .09283 L
.462 .08947 L
.4632 .08879 L
.46433 .08824 L
.46563 .08784 L
.46682 .08803 L
.46813 .08845 L
.46935 .08884 L
.47209 .08966 L
.47687 .09095 L
.4792 .09152 L
.48134 .09211 L
.48253 .09235 L
.48366 .09238 L
.48486 .09233 L
.48616 .0923 L
.48685 .09228 L
.48749 .09226 L
.48824 .09226 L
.48891 .09226 L
.49013 .09223 L
.49082 .09223 L
Mistroke
.49147 .09225 L
.49277 .09241 L
.49415 .09256 L
.49534 .09267 L
.49662 .09274 L
.49734 .09277 L
.49812 .0928 L
.49886 .09282 L
.49954 .09283 L
.50082 .09276 L
.50147 .09271 L
.50219 .09265 L
.50712 .09228 L
.5123 .09192 L
.51445 .09178 L
.51564 .09171 L
.51673 .09167 L
.51802 .09169 L
.51924 .09173 L
.52157 .09179 L
.5241 .09185 L
.52538 .09187 L
.5261 .09187 L
.52678 .09187 L
.52799 .09187 L
.5291 .09187 L
.53038 .09188 L
.53159 .09189 L
.53289 .09189 L
.53355 .09189 L
.53428 .09189 L
.53557 .09188 L
.53678 .09188 L
.53971 .09186 L
.54044 .09185 L
.54114 .09185 L
.54243 .09184 L
.54352 .09184 L
.5447 .09185 L
.54595 .09185 L
.54712 .09185 L
.5483 .09185 L
.54961 .09185 L
.55026 .09185 L
.55097 .09185 L
.55224 .09185 L
.55357 .09185 L
.55427 .09185 L
.55501 .09185 L
.55573 .09185 L
Mistroke
.55638 .09185 L
.55764 .09185 L
.55887 .09185 L
.56019 .09185 L
.56143 .09185 L
.56258 .09185 L
.56365 .09185 L
.5648 .09185 L
.56588 .09185 L
.56687 .09185 L
.56803 .09185 L
.56929 .09185 L
.57158 .09185 L
.58108 .09185 L
.62187 .09185 L
.66114 .09185 L
.6989 .09185 L
.73911 .09185 L
.7778 .09185 L
.81895 .09185 L
.85858 .09185 L
.8967 .09185 L
.93727 .09185 L
.97619 .09185 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell["This gives the coiflet filter of order 10.", "MathCaption",
  CellTags->{"S3.1.2", "2.19"}],

Cell["c10 = CoifletFilter[10];", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "Note that ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_0\) \((t)\) = \[Phi] \((t)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.20"}],

Cell["phi = WaveletPacket[0, c10, 7, Interpolation -> True];", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S3.1.2"],

Cell["\<\
In this and the following two graphs we plot the first three \
wavelet packets generated from the coiflet filter of order 10.\
\>", 
  "MathCaption",
  CellTags->{"S3.1.2", "2.21"}],

Cell[CellGroupData[{

Cell["\<\
Plot[phi[t], {t, -5, 5},  PlotRange -> All,
Frame -> True, Axes -> False,
PlotLabel -> \"w_0(t)\"]\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0952381 0.104906 0.452926 [
[.11905 -0.0125 -6 -9 ]
[.11905 -0.0125 6 0 ]
[.30952 -0.0125 -6 -9 ]
[.30952 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69048 -0.0125 -3 -9 ]
[.69048 -0.0125 3 0 ]
[.88095 -0.0125 -3 -9 ]
[.88095 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01432 -24 -4.5 ]
[-0.0125 .01432 0 4.5 ]
[-0.0125 .10491 -6 -4.5 ]
[-0.0125 .10491 0 4.5 ]
[-0.0125 .19549 -18 -4.5 ]
[-0.0125 .19549 0 4.5 ]
[-0.0125 .28608 -18 -4.5 ]
[-0.0125 .28608 0 4.5 ]
[-0.0125 .37666 -18 -4.5 ]
[-0.0125 .37666 0 4.5 ]
[-0.0125 .46725 -18 -4.5 ]
[-0.0125 .46725 0 4.5 ]
[-0.0125 .55783 -6 -4.5 ]
[-0.0125 .55783 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 0 m
.11905 .00625 L
s
[(-4)] .11905 -0.0125 0 1 Mshowa
.30952 0 m
.30952 .00625 L
s
[(-2)] .30952 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69048 0 m
.69048 .00625 L
s
[(2)] .69048 -0.0125 0 1 Mshowa
.88095 0 m
.88095 .00625 L
s
[(4)] .88095 -0.0125 0 1 Mshowa
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01432 m
.00625 .01432 L
s
[(-0.2)] -0.0125 .01432 1 0 Mshowa
0 .10491 m
.00625 .10491 L
s
[(0)] -0.0125 .10491 1 0 Mshowa
0 .19549 m
.00625 .19549 L
s
[(0.2)] -0.0125 .19549 1 0 Mshowa
0 .28608 m
.00625 .28608 L
s
[(0.4)] -0.0125 .28608 1 0 Mshowa
0 .37666 m
.00625 .37666 L
s
[(0.6)] -0.0125 .37666 1 0 Mshowa
0 .46725 m
.00625 .46725 L
s
[(0.8)] -0.0125 .46725 1 0 Mshowa
0 .55783 m
.00625 .55783 L
s
[(1)] -0.0125 .55783 1 0 Mshowa
.125 Mabswid
0 .03697 m
.00375 .03697 L
s
0 .05961 m
.00375 .05961 L
s
0 .08226 m
.00375 .08226 L
s
0 .12755 m
.00375 .12755 L
s
0 .1502 m
.00375 .1502 L
s
0 .17285 m
.00375 .17285 L
s
0 .21814 m
.00375 .21814 L
s
0 .24078 m
.00375 .24078 L
s
0 .26343 m
.00375 .26343 L
s
0 .30872 m
.00375 .30872 L
s
0 .33137 m
.00375 .33137 L
s
0 .35402 m
.00375 .35402 L
s
0 .39931 m
.00375 .39931 L
s
0 .42195 m
.00375 .42195 L
s
0 .4446 m
.00375 .4446 L
s
0 .48989 m
.00375 .48989 L
s
0 .51254 m
.00375 .51254 L
s
0 .53519 m
.00375 .53519 L
s
0 .58048 m
.00375 .58048 L
s
0 .60313 m
.00375 .60313 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.11905 .61178 m
.11905 .61803 L
s
.30952 .61178 m
.30952 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.69048 .61178 m
.69048 .61803 L
s
.88095 .61178 m
.88095 .61803 L
s
.125 Mabswid
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.07143 .61428 m
.07143 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01432 m
1 .01432 L
s
.99375 .10491 m
1 .10491 L
s
.99375 .19549 m
1 .19549 L
s
.99375 .28608 m
1 .28608 L
s
.99375 .37666 m
1 .37666 L
s
.99375 .46725 m
1 .46725 L
s
.99375 .55783 m
1 .55783 L
s
.125 Mabswid
.99625 .03697 m
1 .03697 L
s
.99625 .05961 m
1 .05961 L
s
.99625 .08226 m
1 .08226 L
s
.99625 .12755 m
1 .12755 L
s
.99625 .1502 m
1 .1502 L
s
.99625 .17285 m
1 .17285 L
s
.99625 .21814 m
1 .21814 L
s
.99625 .24078 m
1 .24078 L
s
.99625 .26343 m
1 .26343 L
s
.99625 .30872 m
1 .30872 L
s
.99625 .33137 m
1 .33137 L
s
.99625 .35402 m
1 .35402 L
s
.99625 .39931 m
1 .39931 L
s
.99625 .42195 m
1 .42195 L
s
.99625 .4446 m
1 .4446 L
s
.99625 .48989 m
1 .48989 L
s
.99625 .51254 m
1 .51254 L
s
.99625 .53519 m
1 .53519 L
s
.99625 .58048 m
1 .58048 L
s
.99625 .60313 m
1 .60313 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(w_0\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .10481 m
.02846 .10479 L
.03279 .10477 L
.03523 .10476 L
.03754 .10475 L
.03881 .10474 L
.0402 .10474 L
.04146 .10474 L
.04262 .10473 L
.04376 .10473 L
.04498 .10473 L
.04614 .10473 L
.0472 .10474 L
.04843 .10474 L
.04913 .10474 L
.04978 .10474 L
.05224 .10476 L
.05358 .10476 L
.05483 .10478 L
.05718 .1048 L
.05969 .10483 L
.06244 .10487 L
.06757 .10498 L
.07299 .10513 L
.08269 .1055 L
.08857 .10573 L
.09414 .10593 L
.09914 .10607 L
.10197 .10612 L
.10458 .10616 L
.1069 .10619 L
.10796 .1062 L
.10908 .10621 L
.11032 .10621 L
.11146 .10622 L
.11269 .10622 L
.11339 .10622 L
.11404 .10622 L
.11535 .10622 L
.11659 .10621 L
.1177 .10621 L
.1189 .1062 L
.12021 .10619 L
.1216 .10617 L
.12409 .10613 L
.12657 .10608 L
.12923 .10601 L
.13405 .10583 L
.13977 .10553 L
.145 .10517 L
Mistroke
.14979 .10478 L
.15488 .10426 L
.16403 .10301 L
.17483 .10098 L
.18476 .09903 L
.18978 .09823 L
.19231 .09792 L
.19508 .09765 L
.19653 .09754 L
.19786 .09746 L
.1986 .09743 L
.19939 .0974 L
.20015 .09738 L
.20084 .09736 L
.20208 .09735 L
.20279 .09736 L
.20345 .09737 L
.20415 .09738 L
.20478 .0974 L
.20548 .09743 L
.20622 .09746 L
.20749 .09754 L
.20864 .09763 L
.21122 .09791 L
.21361 .09825 L
.21586 .09866 L
.22092 .09985 L
.2264 .10156 L
.24631 .11037 L
.26737 .12246 L
.27683 .12777 L
.27956 .129 L
.28214 .12998 L
.28446 .1307 L
.28576 .13102 L
.28698 .13127 L
.28804 .13144 L
.28918 .13157 L
.29044 .13166 L
.2916 .13168 L
.29274 .13164 L
.29398 .13153 L
.29529 .13134 L
.2965 .1311 L
.29873 .13047 L
.30076 .12968 L
.3031 .12851 L
.30531 .12713 L
.30993 .12335 L
.31502 .11779 L
Mistroke
.3253 .10279 L
.34374 .07 L
.3537 .05258 L
.36317 .03814 L
.36838 .03198 L
.37134 .02936 L
.37275 .02836 L
.37408 .02759 L
.37529 .02702 L
.37661 .02656 L
.37781 .0263 L
.37891 .02619 L
.3801 .02621 L
.38141 .02643 L
.38207 .02661 L
.38278 .02685 L
.38405 .02745 L
.38527 .02822 L
.38662 .02929 L
.38934 .03219 L
.39187 .0358 L
.39423 .04004 L
.39956 .05275 L
.40531 .07175 L
.41581 .12068 L
.42543 .17889 L
.44597 .32647 L
.46508 .46551 L
.47456 .52363 L
.48352 .56667 L
.48847 .58412 L
.49126 .59166 L
.49383 .59702 L
.496 .60029 L
.49723 .60163 L
.49839 .60254 L
.4996 .60311 L
.50071 .60332 L
.50199 .60313 L
.5032 .60257 L
.50446 .60161 L
.50516 .60089 L
.50581 .60011 L
.50826 .59626 L
.51048 .59151 L
.51283 .58525 L
.51771 .56842 L
.52307 .5446 L
.54147 .43032 L
.56267 .26851 L
Mistroke
.58197 .13236 L
.59157 .07963 L
.59699 .05659 L
.602 .04003 L
.60638 .02919 L
.60886 .02446 L
.6112 .02092 L
.61245 .01935 L
.61365 .01809 L
.61473 .01712 L
.61589 .01628 L
.61715 .01558 L
.61831 .01511 L
.61902 .01491 L
.61969 .01479 L
.62095 .01472 L
.62211 .01481 L
.62335 .01509 L
.62453 .01552 L
.6256 .01605 L
.62822 .01785 L
.6307 .02019 L
.63564 .02648 L
.64102 .03527 L
.65949 .0732 L
.67886 .11405 L
.68417 .12321 L
.68989 .13124 L
.69253 .13418 L
.6953 .13676 L
.6979 .13869 L
.70026 .14005 L
.70141 .14059 L
.70267 .14107 L
.70375 .14142 L
.70495 .14171 L
.70622 .14194 L
.70691 .14202 L
.70756 .14207 L
.70872 .1421 L
.70996 .14205 L
.71112 .14193 L
.71239 .14171 L
.71358 .14144 L
.71468 .14112 L
.719 .13935 L
.72168 .13788 L
.72421 .13626 L
.72893 .13274 L
.73951 .12361 L
Mistroke
.75792 .10831 L
.76836 .10084 L
.77346 .09769 L
.7781 .09527 L
.78305 .0932 L
.78774 .09179 L
.79031 .09124 L
.79269 .09088 L
.79393 .09074 L
.7953 .09063 L
.79599 .09059 L
.79673 .09056 L
.79743 .09054 L
.79807 .09053 L
.7993 .09054 L
.80061 .09058 L
.80185 .09065 L
.80298 .09074 L
.8043 .09087 L
.80574 .09106 L
.80834 .09149 L
.81396 .09281 L
.81914 .09438 L
.83953 .10146 L
.84949 .10422 L
.85859 .10623 L
.86308 .10706 L
.86798 .10782 L
.8726 .1084 L
.87688 .1088 L
.87921 .10897 L
.8814 .1091 L
.8838 .10921 L
.88515 .10926 L
.88639 .10929 L
.88761 .10931 L
.88875 .10933 L
.88999 .10933 L
.89069 .10933 L
.89132 .10933 L
.8926 .10932 L
.89332 .10931 L
.89399 .1093 L
.89521 .10927 L
.89651 .10924 L
.89903 .10914 L
.90143 .10902 L
.90593 .10872 L
.91077 .1083 L
.91605 .10776 L
Mistroke
.93436 .10584 L
.94468 .10504 L
.95403 .10451 L
.95922 .10429 L
.96195 .10419 L
.96484 .1041 L
.96736 .10404 L
.97013 .10399 L
.97501 .10392 L
.97619 .1039 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_1\) \((t)\) = \[Psi] \((t)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  ". Note that we only plot the wavelet on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-5\), 5]\)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.22"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[WaveletPacket[1, c10, 6],
PlotRange -> {{-5, 5}, All},
PlotJoined -> True, Frame -> True, Axes -> False,
PlotLabel -> \"w_1(t)\"]\
\>", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.365713 0.271199 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09451 -12 -4.5 ]
[-0.0125 .09451 0 4.5 ]
[-0.0125 .23011 -24 -4.5 ]
[-0.0125 .23011 0 4.5 ]
[-0.0125 .36571 -6 -4.5 ]
[-0.0125 .36571 0 4.5 ]
[-0.0125 .50131 -18 -4.5 ]
[-0.0125 .50131 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09451 m
.00625 .09451 L
s
[(-1)] -0.0125 .09451 1 0 Mshowa
0 .23011 m
.00625 .23011 L
s
[(-0.5)] -0.0125 .23011 1 0 Mshowa
0 .36571 m
.00625 .36571 L
s
[(0)] -0.0125 .36571 1 0 Mshowa
0 .50131 m
.00625 .50131 L
s
[(0.5)] -0.0125 .50131 1 0 Mshowa
.125 Mabswid
0 .12163 m
.00375 .12163 L
s
0 .14875 m
.00375 .14875 L
s
0 .17587 m
.00375 .17587 L
s
0 .20299 m
.00375 .20299 L
s
0 .25723 m
.00375 .25723 L
s
0 .28435 m
.00375 .28435 L
s
0 .31147 m
.00375 .31147 L
s
0 .33859 m
.00375 .33859 L
s
0 .39283 m
.00375 .39283 L
s
0 .41995 m
.00375 .41995 L
s
0 .44707 m
.00375 .44707 L
s
0 .47419 m
.00375 .47419 L
s
0 .06739 m
.00375 .06739 L
s
0 .04027 m
.00375 .04027 L
s
0 .01315 m
.00375 .01315 L
s
0 .52843 m
.00375 .52843 L
s
0 .55555 m
.00375 .55555 L
s
0 .58267 m
.00375 .58267 L
s
0 .60979 m
.00375 .60979 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.1 .61178 m
.1 .61803 L
s
.3 .61178 m
.3 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7 .61178 m
.7 .61803 L
s
.9 .61178 m
.9 .61803 L
s
.125 Mabswid
.15 .61428 m
.15 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09451 m
1 .09451 L
s
.99375 .23011 m
1 .23011 L
s
.99375 .36571 m
1 .36571 L
s
.99375 .50131 m
1 .50131 L
s
.125 Mabswid
.99625 .12163 m
1 .12163 L
s
.99625 .14875 m
1 .14875 L
s
.99625 .17587 m
1 .17587 L
s
.99625 .20299 m
1 .20299 L
s
.99625 .25723 m
1 .25723 L
s
.99625 .28435 m
1 .28435 L
s
.99625 .31147 m
1 .31147 L
s
.99625 .33859 m
1 .33859 L
s
.99625 .39283 m
1 .39283 L
s
.99625 .41995 m
1 .41995 L
s
.99625 .44707 m
1 .44707 L
s
.99625 .47419 m
1 .47419 L
s
.99625 .06739 m
1 .06739 L
s
.99625 .04027 m
1 .04027 L
s
.99625 .01315 m
1 .01315 L
s
.99625 .52843 m
1 .52843 L
s
.99625 .55555 m
1 .55555 L
s
.99625 .58267 m
1 .58267 L
s
.99625 .60979 m
1 .60979 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(w_1\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36547 m
.00156 .36548 L
.00312 .3655 L
.00469 .36551 L
.00625 .36552 L
.00781 .36554 L
.00937 .36555 L
.01094 .36557 L
.0125 .36559 L
.01406 .36561 L
.01562 .36563 L
.01719 .36566 L
.01875 .36568 L
.02031 .3657 L
.02187 .36573 L
.02344 .36575 L
.025 .36578 L
.02656 .36581 L
.02812 .36584 L
.02969 .36587 L
.03125 .3659 L
.03281 .36593 L
.03437 .36596 L
.03594 .36599 L
.0375 .36602 L
.03906 .36606 L
.04062 .36609 L
.04219 .36613 L
.04375 .36616 L
.04531 .3662 L
.04687 .36624 L
.04844 .36628 L
.05 .36632 L
.05156 .36636 L
.05312 .3664 L
.05469 .36644 L
.05625 .36648 L
.05781 .36652 L
.05937 .36656 L
.06094 .3666 L
.0625 .36664 L
.06406 .36668 L
.06562 .36672 L
.06719 .36675 L
.06875 .36678 L
.07031 .36681 L
.07187 .36684 L
.07344 .36686 L
.075 .36688 L
.07656 .3669 L
Mistroke
.07812 .36691 L
.07969 .36692 L
.08125 .36692 L
.08281 .36693 L
.08437 .36692 L
.08594 .36692 L
.0875 .36691 L
.08906 .36689 L
.09062 .36687 L
.09219 .36685 L
.09375 .36682 L
.09531 .36679 L
.09687 .36675 L
.09844 .3667 L
.1 .36666 L
.10156 .3666 L
.10312 .36654 L
.10469 .36648 L
.10625 .36641 L
.10781 .36634 L
.10937 .36626 L
.11094 .36618 L
.1125 .36609 L
.11406 .366 L
.11562 .3659 L
.11719 .3658 L
.11875 .3657 L
.12031 .36559 L
.12187 .36549 L
.12344 .36537 L
.125 .36526 L
.12656 .36514 L
.12812 .36502 L
.12969 .3649 L
.13125 .36478 L
.13281 .36466 L
.13437 .36453 L
.13594 .3644 L
.1375 .36427 L
.13906 .36414 L
.14062 .36401 L
.14219 .36387 L
.14375 .36374 L
.14531 .3636 L
.14687 .36346 L
.14844 .36333 L
.15 .36319 L
.15156 .36305 L
.15312 .36291 L
.15469 .36277 L
Mistroke
.15625 .36264 L
.15781 .3625 L
.15937 .36237 L
.16094 .36225 L
.1625 .36213 L
.16406 .36201 L
.16562 .3619 L
.16719 .3618 L
.16875 .3617 L
.17031 .36161 L
.17187 .36153 L
.17344 .36146 L
.175 .3614 L
.17656 .36135 L
.17812 .36132 L
.17969 .36129 L
.18125 .36128 L
.18281 .36127 L
.18437 .36128 L
.18594 .36131 L
.1875 .36135 L
.18906 .3614 L
.19062 .36146 L
.19219 .36154 L
.19375 .36163 L
.19531 .36174 L
.19687 .36187 L
.19844 .36201 L
.2 .36216 L
.20156 .36233 L
.20312 .36252 L
.20469 .36272 L
.20625 .36294 L
.20781 .36317 L
.20937 .36342 L
.21094 .36368 L
.2125 .36395 L
.21406 .36424 L
.21562 .36454 L
.21719 .36486 L
.21875 .36518 L
.22031 .36552 L
.22187 .36586 L
.22344 .36622 L
.225 .36659 L
.22656 .36696 L
.22812 .36734 L
.22969 .36772 L
.23125 .36812 L
.23281 .36852 L
Mistroke
.23437 .36892 L
.23594 .36934 L
.2375 .36975 L
.23906 .37017 L
.24062 .3706 L
.24219 .37103 L
.24375 .37146 L
.24531 .37189 L
.24687 .37232 L
.24844 .37275 L
.25 .37319 L
.25156 .37362 L
.25312 .37405 L
.25469 .37447 L
.25625 .37489 L
.25781 .3753 L
.25937 .3757 L
.26094 .3761 L
.2625 .37648 L
.26406 .37685 L
.26562 .37721 L
.26719 .37755 L
.26875 .37787 L
.27031 .37818 L
.27187 .37846 L
.27344 .37872 L
.275 .37895 L
.27656 .37916 L
.27812 .37935 L
.27969 .3795 L
.28125 .37962 L
.28281 .37972 L
.28437 .37978 L
.28594 .37981 L
.2875 .3798 L
.28906 .37976 L
.29062 .37967 L
.29219 .37956 L
.29375 .3794 L
.29531 .37921 L
.29687 .37899 L
.29844 .37872 L
.3 .37842 L
.30156 .37808 L
.30312 .3777 L
.30469 .37729 L
.30625 .37683 L
.30781 .37632 L
.30937 .37577 L
.31094 .37518 L
Mistroke
.3125 .37454 L
.31406 .37385 L
.31562 .37312 L
.31719 .37234 L
.31875 .37151 L
.32031 .37063 L
.32187 .36971 L
.32344 .36874 L
.325 .36773 L
.32656 .36667 L
.32812 .36557 L
.32969 .36443 L
.33125 .36326 L
.33281 .36207 L
.33437 .36085 L
.33594 .35962 L
.3375 .35839 L
.33906 .35715 L
.34062 .35591 L
.34219 .35467 L
.34375 .35343 L
.34531 .35219 L
.34687 .35096 L
.34844 .34973 L
.35 .3485 L
.35156 .34728 L
.35312 .34608 L
.35469 .3449 L
.35625 .34375 L
.35781 .34264 L
.35937 .34156 L
.36094 .34053 L
.3625 .33955 L
.36406 .33861 L
.36562 .33773 L
.36719 .33692 L
.36875 .33619 L
.37031 .33554 L
.37187 .33498 L
.37344 .33452 L
.375 .33417 L
.37656 .33393 L
.37812 .33379 L
.37969 .33373 L
.38125 .33373 L
.38281 .33377 L
.38437 .33384 L
.38594 .33392 L
.3875 .33398 L
.38906 .33401 L
Mistroke
.39062 .33401 L
.39219 .33397 L
.39375 .33388 L
.39531 .33375 L
.39687 .33356 L
.39844 .33332 L
.4 .33301 L
.40156 .33263 L
.40312 .33219 L
.40469 .3317 L
.40625 .33115 L
.40781 .33057 L
.40937 .32998 L
.41094 .32939 L
.4125 .32883 L
.41406 .32833 L
.41562 .32788 L
.41719 .32746 L
.41875 .3271 L
.42031 .32677 L
.42187 .32648 L
.42344 .32623 L
.425 .32604 L
.42656 .3259 L
.42812 .32588 L
.42969 .32602 L
.43125 .32639 L
.43281 .32706 L
.43437 .32808 L
.43594 .32949 L
.4375 .33133 L
.43906 .33368 L
.44062 .33655 L
.44219 .34 L
.44375 .34404 L
.44531 .34869 L
.44687 .354 L
.44844 .36 L
.45 .36671 L
.45156 .37412 L
.45312 .38221 L
.45469 .39093 L
.45625 .40021 L
.45781 .40999 L
.45937 .42018 L
.46094 .4307 L
.4625 .44145 L
.46406 .45233 L
.46562 .46329 L
.46719 .47431 L
Mistroke
.46875 .48534 L
.47031 .49633 L
.47187 .50723 L
.47344 .51797 L
.475 .52849 L
.47656 .5387 L
.47812 .5485 L
.47969 .55775 L
.48125 .56632 L
.48281 .57406 L
.48437 .58088 L
.48594 .58667 L
.4875 .59134 L
.48906 .59478 L
.49062 .59688 L
.49219 .59753 L
.49375 .59663 L
.49531 .59411 L
.49687 .58987 L
.49844 .58382 L
.5 .5759 L
.50156 .56608 L
.50313 .55441 L
.50469 .54099 L
.50625 .52593 L
.50781 .50935 L
.50938 .4914 L
.51094 .47222 L
.5125 .45199 L
.51406 .43088 L
.51563 .409 L
.51719 .38644 L
.51875 .36332 L
.52031 .33973 L
.52188 .31582 L
.52344 .29175 L
.525 .26766 L
.52656 .2437 L
.52813 .22006 L
.52969 .1969 L
.53125 .17442 L
.53281 .15281 L
.53438 .13222 L
.53594 .11277 L
.5375 .0946 L
.53906 .07786 L
.54063 .06272 L
.54219 .04936 L
.54375 .03795 L
.54531 .02864 L
Mistroke
.54688 .02157 L
.54844 .01689 L
.55 .01472 L
.55156 .01511 L
.55313 .01804 L
.55469 .02342 L
.55625 .03113 L
.55781 .04103 L
.55938 .05299 L
.56094 .06687 L
.5625 .08248 L
.56406 .09965 L
.56563 .11824 L
.56719 .13813 L
.56875 .15918 L
.57031 .18127 L
.57188 .20422 L
.57344 .22783 L
.575 .25192 L
.57656 .27632 L
.57813 .30086 L
.57969 .32539 L
.58125 .34973 L
.58281 .37373 L
.58438 .39726 L
.58594 .42021 L
.5875 .44247 L
.58906 .46392 L
.59063 .48438 L
.59219 .50367 L
.59375 .52162 L
.59531 .53807 L
.59688 .55286 L
.59844 .56587 L
.6 .57698 L
.60156 .58609 L
.60313 .59322 L
.60469 .59842 L
.60625 .60175 L
.60781 .60332 L
.60938 .6032 L
.61094 .60147 L
.6125 .59825 L
.61406 .59365 L
.61563 .58778 L
.61719 .58075 L
.61875 .57265 L
.62031 .56358 L
.62188 .55369 L
.62344 .54312 L
Mistroke
.625 .53203 L
.62656 .52053 L
.62813 .50873 L
.62969 .4967 L
.63125 .48453 L
.63281 .47231 L
.63438 .46007 L
.63594 .44788 L
.6375 .43579 L
.63906 .42384 L
.64063 .41214 L
.64219 .40081 L
.64375 .38994 L
.64531 .37964 L
.64688 .37 L
.64844 .36108 L
.65 .35297 L
.65156 .34571 L
.65313 .33931 L
.65469 .33375 L
.65625 .329 L
.65781 .32501 L
.65938 .32177 L
.66094 .31925 L
.6625 .31739 L
.66406 .31616 L
.66563 .31549 L
.66719 .31533 L
.66875 .31563 L
.67031 .31632 L
.67188 .31734 L
.67344 .31859 L
.675 .32002 L
.67656 .32155 L
.67813 .32315 L
.67969 .3248 L
.68125 .3265 L
.68281 .32822 L
.68438 .32996 L
.68594 .33171 L
.6875 .33349 L
.68906 .33528 L
.69063 .33705 L
.69219 .33877 L
.69375 .34041 L
.69531 .34194 L
.69688 .34332 L
.69844 .34456 L
.7 .34562 L
.70156 .34651 L
Mistroke
.70313 .34722 L
.70469 .34776 L
.70625 .34814 L
.70781 .34837 L
.70938 .34846 L
.71094 .34841 L
.7125 .34824 L
.71406 .34795 L
.71563 .34756 L
.71719 .34712 L
.71875 .34663 L
.72031 .34612 L
.72188 .34563 L
.72344 .34519 L
.725 .34481 L
.72656 .34453 L
.72813 .34436 L
.72969 .34428 L
.73125 .34429 L
.73281 .3444 L
.73438 .34458 L
.73594 .34485 L
.7375 .34519 L
.73906 .34559 L
.74063 .34605 L
.74219 .34658 L
.74375 .34717 L
.74531 .34783 L
.74688 .34855 L
.74844 .34932 L
.75 .35014 L
.75156 .35101 L
.75313 .35192 L
.75469 .35287 L
.75625 .35385 L
.75781 .35486 L
.75938 .3559 L
.76094 .35697 L
.7625 .35806 L
.76406 .35917 L
.76563 .3603 L
.76719 .36143 L
.76875 .36255 L
.77031 .36366 L
.77188 .36474 L
.77344 .36579 L
.775 .3668 L
.77656 .36776 L
.77813 .36866 L
.77969 .3695 L
Mistroke
.78125 .3703 L
.78281 .37104 L
.78438 .37172 L
.78594 .37235 L
.7875 .37293 L
.78906 .37346 L
.79063 .37394 L
.79219 .37436 L
.79375 .37474 L
.79531 .37507 L
.79688 .37535 L
.79844 .37558 L
.8 .37578 L
.80156 .37594 L
.80313 .37606 L
.80469 .37614 L
.80625 .37619 L
.80781 .3762 L
.80938 .37618 L
.81094 .37613 L
.8125 .37604 L
.81406 .37592 L
.81563 .37577 L
.81719 .37559 L
.81875 .37538 L
.82031 .37516 L
.82188 .37491 L
.82344 .37465 L
.825 .37437 L
.82656 .37408 L
.82813 .37378 L
.82969 .37346 L
.83125 .37315 L
.83281 .37282 L
.83438 .37249 L
.83594 .37216 L
.8375 .37183 L
.83906 .3715 L
.84063 .37117 L
.84219 .37084 L
.84375 .37052 L
.84531 .3702 L
.84688 .36989 L
.84844 .36958 L
.85 .36929 L
.85156 .369 L
.85313 .36872 L
.85469 .36844 L
.85625 .36818 L
.85781 .36793 L
Mistroke
.85938 .36769 L
.86094 .36745 L
.8625 .36723 L
.86406 .36701 L
.86563 .36681 L
.86719 .36661 L
.86875 .36643 L
.87031 .36625 L
.87188 .36608 L
.87344 .36592 L
.875 .36577 L
.87656 .36562 L
.87813 .36548 L
.87969 .36535 L
.88125 .36522 L
.88281 .3651 L
.88438 .36499 L
.88594 .36488 L
.8875 .36478 L
.88906 .36469 L
.89063 .36461 L
.89219 .36453 L
.89375 .36445 L
.89531 .36439 L
.89688 .36433 L
.89844 .36427 L
.9 .36422 L
.90156 .36418 L
.90313 .36414 L
.90469 .3641 L
.90625 .36407 L
.90781 .36405 L
.90938 .36403 L
.91094 .36401 L
.9125 .364 L
.91406 .36399 L
.91563 .36399 L
.91719 .364 L
.91875 .364 L
.92031 .36402 L
.92188 .36403 L
.92344 .36405 L
.925 .36408 L
.92656 .36411 L
.92813 .36415 L
.92969 .36419 L
.93125 .36423 L
.93281 .36428 L
.93438 .36433 L
.93594 .36438 L
Mistroke
.9375 .36444 L
.93906 .36449 L
.94063 .36455 L
.94219 .36461 L
.94375 .36466 L
.94531 .36472 L
.94688 .36478 L
.94844 .36484 L
.95 .36489 L
.95156 .36495 L
.95313 .365 L
.95469 .36505 L
.95625 .3651 L
.95781 .36515 L
.95938 .36519 L
.96094 .36524 L
.9625 .36528 L
.96406 .36532 L
.96563 .36536 L
.96719 .3654 L
.96875 .36543 L
.97031 .36547 L
.97188 .3655 L
.97344 .36553 L
.975 .36556 L
.97656 .36559 L
.97813 .36561 L
.97969 .36564 L
.98125 .36566 L
.98281 .36568 L
.98438 .3657 L
.98594 .36572 L
.9875 .36573 L
.98906 .36575 L
.99063 .36576 L
.99219 .36577 L
.99375 .36579 L
.99531 .3658 L
.99688 .36581 L
.99844 .36582 L
1 .36582 L
Mfstroke
1 .36582 m
1 .36582 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is the wavelet packet ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_2\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.23"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[WaveletPacket[2, c10, 6],
PlotRange -> {{-5, 5}, All},
PlotJoined -> True, Frame -> True, Axes -> False,
PlotLabel -> \"w_2(t)\"]\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.322814 0.214026 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00178 -24 -4.5 ]
[-0.0125 .00178 0 4.5 ]
[-0.0125 .10879 -12 -4.5 ]
[-0.0125 .10879 0 4.5 ]
[-0.0125 .2158 -24 -4.5 ]
[-0.0125 .2158 0 4.5 ]
[-0.0125 .32281 -6 -4.5 ]
[-0.0125 .32281 0 4.5 ]
[-0.0125 .42983 -18 -4.5 ]
[-0.0125 .42983 0 4.5 ]
[-0.0125 .53684 -6 -4.5 ]
[-0.0125 .53684 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -18 0 ]
[.5 .63053 18 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00178 m
.00625 .00178 L
s
[(-1.5)] -0.0125 .00178 1 0 Mshowa
0 .10879 m
.00625 .10879 L
s
[(-1)] -0.0125 .10879 1 0 Mshowa
0 .2158 m
.00625 .2158 L
s
[(-0.5)] -0.0125 .2158 1 0 Mshowa
0 .32281 m
.00625 .32281 L
s
[(0)] -0.0125 .32281 1 0 Mshowa
0 .42983 m
.00625 .42983 L
s
[(0.5)] -0.0125 .42983 1 0 Mshowa
0 .53684 m
.00625 .53684 L
s
[(1)] -0.0125 .53684 1 0 Mshowa
.125 Mabswid
0 .02318 m
.00375 .02318 L
s
0 .04458 m
.00375 .04458 L
s
0 .06598 m
.00375 .06598 L
s
0 .08739 m
.00375 .08739 L
s
0 .13019 m
.00375 .13019 L
s
0 .15159 m
.00375 .15159 L
s
0 .173 m
.00375 .173 L
s
0 .1944 m
.00375 .1944 L
s
0 .2372 m
.00375 .2372 L
s
0 .25861 m
.00375 .25861 L
s
0 .28001 m
.00375 .28001 L
s
0 .30141 m
.00375 .30141 L
s
0 .34422 m
.00375 .34422 L
s
0 .36562 m
.00375 .36562 L
s
0 .38702 m
.00375 .38702 L
s
0 .40842 m
.00375 .40842 L
s
0 .45123 m
.00375 .45123 L
s
0 .47263 m
.00375 .47263 L
s
0 .49403 m
.00375 .49403 L
s
0 .51544 m
.00375 .51544 L
s
0 .55824 m
.00375 .55824 L
s
0 .57965 m
.00375 .57965 L
s
0 .60105 m
.00375 .60105 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.1 .61178 m
.1 .61803 L
s
.3 .61178 m
.3 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7 .61178 m
.7 .61803 L
s
.9 .61178 m
.9 .61803 L
s
.125 Mabswid
.15 .61428 m
.15 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00178 m
1 .00178 L
s
.99375 .10879 m
1 .10879 L
s
.99375 .2158 m
1 .2158 L
s
.99375 .32281 m
1 .32281 L
s
.99375 .42983 m
1 .42983 L
s
.99375 .53684 m
1 .53684 L
s
.125 Mabswid
.99625 .02318 m
1 .02318 L
s
.99625 .04458 m
1 .04458 L
s
.99625 .06598 m
1 .06598 L
s
.99625 .08739 m
1 .08739 L
s
.99625 .13019 m
1 .13019 L
s
.99625 .15159 m
1 .15159 L
s
.99625 .173 m
1 .173 L
s
.99625 .1944 m
1 .1944 L
s
.99625 .2372 m
1 .2372 L
s
.99625 .25861 m
1 .25861 L
s
.99625 .28001 m
1 .28001 L
s
.99625 .30141 m
1 .30141 L
s
.99625 .34422 m
1 .34422 L
s
.99625 .36562 m
1 .36562 L
s
.99625 .38702 m
1 .38702 L
s
.99625 .40842 m
1 .40842 L
s
.99625 .45123 m
1 .45123 L
s
.99625 .47263 m
1 .47263 L
s
.99625 .49403 m
1 .49403 L
s
.99625 .51544 m
1 .51544 L
s
.99625 .55824 m
1 .55824 L
s
.99625 .57965 m
1 .57965 L
s
.99625 .60105 m
1 .60105 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
[(w_2\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .32278 m
.00156 .32279 L
.00312 .32279 L
.00469 .3228 L
.00625 .3228 L
.00781 .32281 L
.00937 .32282 L
.01094 .32282 L
.0125 .32283 L
.01406 .32284 L
.01562 .32284 L
.01719 .32285 L
.01875 .32285 L
.02031 .32285 L
.02187 .32286 L
.02344 .32286 L
.025 .32286 L
.02656 .32286 L
.02812 .32286 L
.02969 .32286 L
.03125 .32285 L
.03281 .32285 L
.03437 .32284 L
.03594 .32284 L
.0375 .32283 L
.03906 .32283 L
.04062 .32282 L
.04219 .32282 L
.04375 .32281 L
.04531 .3228 L
.04687 .32279 L
.04844 .32278 L
.05 .32276 L
.05156 .32275 L
.05312 .32273 L
.05469 .32271 L
.05625 .32269 L
.05781 .32267 L
.05937 .32265 L
.06094 .32263 L
.0625 .32261 L
.06406 .32259 L
.06562 .32258 L
.06719 .32257 L
.06875 .32257 L
.07031 .32257 L
.07187 .32259 L
.07344 .32261 L
.075 .32264 L
.07656 .32268 L
Mistroke
.07812 .32273 L
.07969 .32278 L
.08125 .32285 L
.08281 .32291 L
.08437 .32298 L
.08594 .32305 L
.0875 .32312 L
.08906 .32318 L
.09062 .32324 L
.09219 .32329 L
.09375 .32334 L
.09531 .32337 L
.09687 .32339 L
.09844 .32339 L
.1 .32338 L
.10156 .32335 L
.10312 .3233 L
.10469 .32324 L
.10625 .32317 L
.10781 .32308 L
.10937 .323 L
.11094 .3229 L
.1125 .32281 L
.11406 .32272 L
.11562 .32263 L
.11719 .32254 L
.11875 .32246 L
.12031 .32239 L
.12187 .32232 L
.12344 .32226 L
.125 .32221 L
.12656 .32218 L
.12812 .32216 L
.12969 .32215 L
.13125 .32215 L
.13281 .32216 L
.13437 .32218 L
.13594 .32221 L
.1375 .32224 L
.13906 .32228 L
.14062 .32232 L
.14219 .32238 L
.14375 .32244 L
.14531 .32252 L
.14687 .32262 L
.14844 .32273 L
.15 .32287 L
.15156 .32302 L
.15312 .32318 L
.15469 .32336 L
Mistroke
.15625 .32354 L
.15781 .32372 L
.15937 .3239 L
.16094 .32407 L
.1625 .32423 L
.16406 .32439 L
.16562 .32451 L
.16719 .32461 L
.16875 .32467 L
.17031 .32468 L
.17187 .32464 L
.17344 .32454 L
.175 .32436 L
.17656 .32412 L
.17812 .32382 L
.17969 .32346 L
.18125 .32306 L
.18281 .32263 L
.18437 .32218 L
.18594 .32172 L
.1875 .32127 L
.18906 .32083 L
.19062 .32042 L
.19219 .32005 L
.19375 .31973 L
.19531 .31947 L
.19687 .31929 L
.19844 .31919 L
.2 .31919 L
.20156 .3193 L
.20312 .3195 L
.20469 .3198 L
.20625 .32016 L
.20781 .32059 L
.20937 .32107 L
.21094 .32158 L
.2125 .3221 L
.21406 .32263 L
.21562 .32315 L
.21719 .32366 L
.21875 .32416 L
.22031 .32464 L
.22187 .32509 L
.22344 .32551 L
.225 .32587 L
.22656 .32618 L
.22812 .32643 L
.22969 .32663 L
.23125 .32677 L
.23281 .32685 L
Mistroke
.23437 .32688 L
.23594 .32686 L
.2375 .32681 L
.23906 .32673 L
.24062 .32661 L
.24219 .32642 L
.24375 .32616 L
.24531 .32581 L
.24687 .32537 L
.24844 .32482 L
.25 .32417 L
.25156 .32341 L
.25312 .32256 L
.25469 .32164 L
.25625 .32067 L
.25781 .3197 L
.25937 .31872 L
.26094 .31776 L
.2625 .31683 L
.26406 .31596 L
.26562 .31518 L
.26719 .31453 L
.26875 .31406 L
.27031 .31378 L
.27187 .31375 L
.27344 .31398 L
.275 .31451 L
.27656 .31536 L
.27812 .3165 L
.27969 .31788 L
.28125 .31946 L
.28281 .32118 L
.28437 .323 L
.28594 .32489 L
.2875 .32679 L
.28906 .32864 L
.29062 .33042 L
.29219 .33205 L
.29375 .33351 L
.29531 .33477 L
.29687 .33576 L
.29844 .33644 L
.3 .33676 L
.30156 .3367 L
.30312 .33627 L
.30469 .33551 L
.30625 .33445 L
.30781 .33316 L
.30937 .33166 L
.31094 .33001 L
Mistroke
.3125 .32827 L
.31406 .3265 L
.31562 .3247 L
.31719 .3229 L
.31875 .32108 L
.32031 .31927 L
.32187 .31748 L
.32344 .31577 L
.325 .31414 L
.32656 .31262 L
.32812 .31124 L
.32969 .30999 L
.33125 .30891 L
.33281 .30801 L
.33437 .30727 L
.33594 .30669 L
.3375 .30625 L
.33906 .30594 L
.34062 .30583 L
.34219 .30598 L
.34375 .30645 L
.34531 .30731 L
.34687 .30859 L
.34844 .31032 L
.35 .31254 L
.35156 .31526 L
.35312 .31842 L
.35469 .32192 L
.35625 .32567 L
.35781 .32954 L
.35937 .33347 L
.36094 .3374 L
.3625 .34124 L
.36406 .34492 L
.36562 .34828 L
.36719 .35119 L
.36875 .35355 L
.37031 .35524 L
.37187 .35612 L
.37344 .35609 L
.375 .35502 L
.37656 .35286 L
.37812 .3497 L
.37969 .34568 L
.38125 .34094 L
.38281 .33567 L
.38437 .33 L
.38594 .32407 L
.3875 .31807 L
.38906 .31215 L
Mistroke
.39062 .30645 L
.39219 .30107 L
.39375 .29608 L
.39531 .29156 L
.39687 .28768 L
.39844 .28458 L
.4 .2824 L
.40156 .28122 L
.40312 .28099 L
.40469 .28164 L
.40625 .28309 L
.40781 .28525 L
.40937 .28798 L
.41094 .29114 L
.4125 .29456 L
.41406 .29812 L
.41562 .30187 L
.41719 .30594 L
.41875 .31043 L
.42031 .31545 L
.42187 .321 L
.42344 .327 L
.425 .33347 L
.42656 .34035 L
.42812 .34757 L
.42969 .355 L
.43125 .36244 L
.43281 .36969 L
.43437 .37673 L
.43594 .38354 L
.4375 .3901 L
.43906 .39627 L
.44062 .4016 L
.44219 .40554 L
.44375 .40764 L
.44531 .40743 L
.44687 .40457 L
.44844 .39881 L
.45 .38985 L
.45156 .37757 L
.45312 .36224 L
.45469 .34433 L
.45625 .32449 L
.45781 .30339 L
.45937 .28138 L
.46094 .25879 L
.4625 .23608 L
.46406 .21385 L
.46562 .19307 L
.46719 .17485 L
Mistroke
.46875 .16006 L
.47031 .14959 L
.47187 .14433 L
.47344 .14501 L
.475 .15234 L
.47656 .1667 L
.47812 .18763 L
.47969 .21428 L
.48125 .24555 L
.48281 .28021 L
.48437 .3175 L
.48594 .35667 L
.4875 .39669 L
.48906 .43643 L
.49062 .47441 L
.49219 .50904 L
.49375 .53908 L
.49531 .56328 L
.49687 .58023 L
.49844 .5887 L
.5 .58753 L
.50156 .57608 L
.50313 .55491 L
.50469 .52516 L
.50625 .48827 L
.50781 .44581 L
.50938 .39896 L
.51094 .34883 L
.5125 .29695 L
.51406 .24492 L
.51563 .19448 L
.51719 .14744 L
.51875 .1052 L
.52031 .06915 L
.52188 .04103 L
.52344 .02241 L
.525 .01472 L
.52656 .01876 L
.52813 .03401 L
.52969 .05925 L
.53125 .09302 L
.53281 .13366 L
.53438 .17982 L
.53594 .23016 L
.5375 .28295 L
.53906 .33639 L
.54063 .38882 L
.54219 .43855 L
.54375 .48434 L
.54531 .52492 L
Mistroke
.54688 .55857 L
.54844 .58369 L
.55 .59889 L
.55156 .60332 L
.55313 .59739 L
.55469 .58213 L
.55625 .55874 L
.55781 .52864 L
.55938 .49308 L
.56094 .45331 L
.5625 .41097 L
.56406 .36767 L
.56563 .32472 L
.56719 .28331 L
.56875 .24434 L
.57031 .20871 L
.57188 .17777 L
.57344 .15283 L
.575 .13498 L
.57656 .1249 L
.57813 .12237 L
.57969 .1267 L
.58125 .13714 L
.58281 .15278 L
.58438 .17266 L
.58594 .19585 L
.5875 .2211 L
.58906 .24729 L
.59063 .27364 L
.59219 .29953 L
.59375 .32452 L
.59531 .34817 L
.59688 .3697 L
.59844 .38827 L
.6 .40327 L
.60156 .4143 L
.60313 .42139 L
.60469 .42487 L
.60625 .42503 L
.60781 .42225 L
.60938 .41707 L
.61094 .41003 L
.6125 .4018 L
.61406 .39298 L
.61563 .38382 L
.61719 .37445 L
.61875 .36493 L
.62031 .35532 L
.62188 .34587 L
.62344 .33689 L
Mistroke
.625 .32856 L
.62656 .32102 L
.62813 .31429 L
.62969 .30836 L
.63125 .30325 L
.63281 .29896 L
.63438 .29531 L
.63594 .29215 L
.6375 .28926 L
.63906 .28651 L
.64063 .28396 L
.64219 .28178 L
.64375 .2801 L
.64531 .27906 L
.64688 .27876 L
.64844 .27924 L
.65 .28061 L
.65156 .28293 L
.65313 .28614 L
.65469 .29014 L
.65625 .29477 L
.65781 .29989 L
.65938 .30543 L
.66094 .31135 L
.6625 .31757 L
.66406 .32399 L
.66563 .33043 L
.66719 .33669 L
.66875 .34263 L
.67031 .34806 L
.67188 .35279 L
.67344 .35664 L
.675 .35942 L
.67656 .36101 L
.67813 .36144 L
.67969 .36081 L
.68125 .35923 L
.68281 .35685 L
.68438 .35377 L
.68594 .3501 L
.6875 .346 L
.68906 .3416 L
.69063 .33702 L
.69219 .33237 L
.69375 .32772 L
.69531 .32314 L
.69688 .31878 L
.69844 .31478 L
.7 .31125 L
.70156 .30829 L
Mistroke
.70313 .3059 L
.70469 .30405 L
.70625 .30273 L
.70781 .30188 L
.70938 .30144 L
.71094 .30136 L
.7125 .30155 L
.71406 .30193 L
.71563 .3025 L
.71719 .30328 L
.71875 .30429 L
.72031 .30555 L
.72188 .30704 L
.72344 .30873 L
.725 .31062 L
.72656 .31267 L
.72813 .31488 L
.72969 .31719 L
.73125 .31958 L
.73281 .32198 L
.73438 .3244 L
.73594 .32682 L
.7375 .32925 L
.73906 .33164 L
.74063 .33395 L
.74219 .33608 L
.74375 .33797 L
.74531 .33955 L
.74688 .34076 L
.74844 .34154 L
.75 .34182 L
.75156 .34158 L
.75313 .34083 L
.75469 .33963 L
.75625 .33803 L
.75781 .33612 L
.75938 .33394 L
.76094 .33154 L
.7625 .32897 L
.76406 .32632 L
.76563 .32364 L
.76719 .32102 L
.76875 .3185 L
.77031 .31615 L
.77188 .31405 L
.77344 .31227 L
.775 .31089 L
.77656 .30994 L
.77813 .30942 L
.77969 .3093 L
Mistroke
.78125 .30955 L
.78281 .3101 L
.78438 .31093 L
.78594 .31197 L
.7875 .31319 L
.78906 .3145 L
.79063 .31589 L
.79219 .31733 L
.79375 .3188 L
.79531 .32028 L
.79688 .32172 L
.79844 .32309 L
.8 .32435 L
.80156 .32548 L
.80313 .32646 L
.80469 .3273 L
.80625 .32801 L
.80781 .32858 L
.80938 .32903 L
.81094 .32939 L
.8125 .32968 L
.81406 .32991 L
.81563 .33007 L
.81719 .33016 L
.81875 .33014 L
.82031 .33002 L
.82188 .32978 L
.82344 .32942 L
.825 .32893 L
.82656 .32832 L
.82813 .3276 L
.82969 .32678 L
.83125 .32588 L
.83281 .32493 L
.83438 .32394 L
.83594 .32291 L
.8375 .32186 L
.83906 .3208 L
.84063 .31977 L
.84219 .31879 L
.84375 .31789 L
.84531 .3171 L
.84688 .31646 L
.84844 .31598 L
.85 .3157 L
.85156 .31563 L
.85313 .31577 L
.85469 .3161 L
.85625 .31658 L
.85781 .3172 L
Mistroke
.85938 .31794 L
.86094 .31877 L
.8625 .31967 L
.86406 .32061 L
.86563 .32157 L
.86719 .32251 L
.86875 .32343 L
.87031 .32429 L
.87188 .32508 L
.87344 .32577 L
.875 .32632 L
.87656 .32672 L
.87813 .32698 L
.87969 .3271 L
.88125 .3271 L
.88281 .32699 L
.88438 .32678 L
.88594 .3265 L
.8875 .32617 L
.88906 .32579 L
.89063 .3254 L
.89219 .32498 L
.89375 .32455 L
.89531 .32411 L
.89688 .32367 L
.89844 .32325 L
.9 .32286 L
.90156 .3225 L
.90313 .32218 L
.90469 .32189 L
.90625 .32164 L
.90781 .32142 L
.90938 .32124 L
.91094 .32108 L
.9125 .32094 L
.91406 .32082 L
.91563 .32071 L
.91719 .32062 L
.91875 .32057 L
.92031 .32055 L
.92188 .32058 L
.92344 .32064 L
.925 .32075 L
.92656 .32091 L
.92813 .32111 L
.92969 .32135 L
.93125 .32162 L
.93281 .32191 L
.93438 .32222 L
.93594 .32254 L
Mistroke
.9375 .32288 L
.93906 .32322 L
.94063 .32356 L
.94219 .32389 L
.94375 .32419 L
.94531 .32446 L
.94688 .32468 L
.94844 .32485 L
.95 .32496 L
.95156 .325 L
.95313 .32498 L
.95469 .3249 L
.95625 .32476 L
.95781 .32458 L
.95938 .32436 L
.96094 .32412 L
.9625 .32385 L
.96406 .32356 L
.96563 .32328 L
.96719 .32299 L
.96875 .32271 L
.97031 .32245 L
.97188 .32221 L
.97344 .322 L
.975 .32183 L
.97656 .32171 L
.97813 .32163 L
.97969 .32159 L
.98125 .32159 L
.98281 .32163 L
.98438 .32169 L
.98594 .32177 L
.9875 .32187 L
.98906 .32198 L
.99063 .32209 L
.99219 .32221 L
.99375 .32233 L
.99531 .32246 L
.99688 .32258 L
.99844 .3227 L
1 .32281 L
Mfstroke
1 .32281 m
1 .32281 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell["\<\
A two\[Hyphen]dimensional wavelet or scaling function is simply the \
product of two one\[Hyphen]dimensional functions. This is the coiflet scaling \
function of order 10 in two dimensions.\
\>", "MathCaption",
  CellTags->{"S3.1.2", "2.24"}],

Cell[CellGroupData[{

Cell["\<\
Plot3D[Evaluate[phi[x] phi[y]], {x, -4, 4}, {y, -4, 4},
PlotPoints -> 70, PlotRange -> All, Boxed -> False,
Axes -> False]\
\>", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.30717e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.661 .744 .911 r
.39964 .62885 .4041 .63292 .41158 .63072 .40714 .62663 Metetra
.661 .744 .911 r
.40714 .62663 .41158 .63072 .41908 .62851 .41465 .62441 Metetra
.661 .744 .911 r
.41465 .62441 .41908 .62851 .42661 .62629 .42219 .62218 Metetra
.662 .744 .911 r
.42219 .62218 .42661 .62629 .43415 .62406 .42975 .61994 Metetra
.662 .744 .911 r
.42975 .61994 .43415 .62406 .44172 .62182 .43732 .6177 Metetra
.662 .744 .912 r
.43732 .6177 .44172 .62182 .4493 .61958 .44492 .61544 Metetra
.662 .744 .912 r
.44492 .61544 .4493 .61958 .45691 .61734 .45255 .61319 Metetra
.661 .744 .912 r
.45255 .61319 .45691 .61734 .46454 .61509 .46019 .61093 Metetra
.661 .744 .912 r
.46019 .61093 .46454 .61509 .47219 .61284 .46785 .60867 Metetra
.661 .744 .912 r
.46785 .60867 .47219 .61284 .47986 .61059 .47554 .6064 Metetra
.661 .744 .912 r
.47554 .6064 .47986 .61059 .48756 .60834 .48325 .60413 Metetra
.661 .744 .912 r
.48325 .60413 .48756 .60834 .49527 .60608 .49097 .60186 Metetra
.661 .744 .912 r
.49097 .60186 .49527 .60608 .50301 .60382 .49873 .59958 Metetra
.661 .744 .911 r
.49873 .59958 .50301 .60382 .51077 .60155 .5065 .5973 Metetra
.661 .743 .911 r
.5065 .5973 .51077 .60155 .51855 .59927 .51429 .59501 Metetra
.661 .743 .911 r
.51429 .59501 .51855 .59927 .52635 .59697 .52211 .5927 Metetra
.662 .744 .911 r
.52211 .5927 .52635 .59697 .53418 .59465 .52995 .59037 Metetra
.663 .744 .911 r
.52995 .59037 .53418 .59465 .54202 .59231 .53782 .58802 Metetra
.663 .744 .911 r
.53782 .58802 .54202 .59231 .54989 .58994 .5457 .58565 Metetra
.663 .745 .911 r
.5457 .58565 .54989 .58994 .55779 .58756 .55361 .58327 Metetra
.663 .746 .911 r
.55361 .58327 .55779 .58756 .5657 .58517 .56154 .58088 Metetra
.663 .746 .912 r
.56154 .58088 .5657 .58517 .57364 .58278 .56949 .57849 Metetra
.662 .747 .913 r
.56949 .57849 .57364 .58278 .5816 .5804 .57746 .57611 Metetra
.661 .747 .913 r
.57746 .57611 .5816 .5804 .58958 .57805 .58546 .57374 Metetra
.66 .746 .914 r
.58546 .57374 .58958 .57805 .59759 .57573 .59348 .5714 Metetra
.658 .745 .914 r
.59348 .5714 .59759 .57573 .60562 .57346 .60153 .56909 Metetra
.656 .743 .914 r
.60153 .56909 .60562 .57346 .61368 .57124 .6096 .56683 Metetra
.654 .741 .914 r
.6096 .56683 .61368 .57124 .62176 .56906 .6177 .56458 Metetra
.653 .739 .912 r
.6177 .56458 .62176 .56906 .62986 .5669 .62582 .56236 Metetra
.653 .736 .911 r
.62582 .56236 .62986 .5669 .638 .56474 .63396 .56013 Metetra
.654 .734 .908 r
.63396 .56013 .638 .56474 .64615 .56257 .64213 .5579 Metetra
.655 .732 .906 r
.64213 .5579 .64615 .56257 .65433 .56037 .65033 .55563 Metetra
.656 .73 .904 r
.65033 .55563 .65433 .56037 .66254 .55812 .65854 .55333 Metetra
.659 .729 .902 r
.65854 .55333 .66254 .55812 .67076 .55579 .66678 .55096 Metetra
.662 .729 .9 r
.66678 .55096 .67076 .55579 .67901 .55337 .67505 .54853 Metetra
.664 .73 .899 r
.67505 .54853 .67901 .55337 .68727 .55085 .68333 .54602 Metetra
.667 .732 .898 r
.68333 .54602 .68727 .55085 .69556 .54826 .69163 .54345 Metetra
.668 .734 .899 r
.69163 .54345 .69556 .54826 .70386 .54561 .69996 .54083 Metetra
.669 .737 .9 r
.69996 .54083 .70386 .54561 .71219 .54292 .70831 .53818 Metetra
.67 .739 .902 r
.70831 .53818 .71219 .54292 .72054 .54021 .71668 .53552 Metetra
.67 .742 .904 r
.71668 .53552 .72054 .54021 .72892 .5375 .72507 .53285 Metetra
.669 .744 .907 r
.72507 .53285 .72892 .5375 .73732 .53481 .73349 .5302 Metetra
.667 .746 .909 r
.73349 .5302 .73732 .53481 .74575 .53216 .74194 .52757 Metetra
.665 .747 .911 r
.74194 .52757 .74575 .53216 .7542 .52956 .75041 .52498 Metetra
.663 .747 .913 r
.75041 .52498 .7542 .52956 .76268 .52701 .75892 .52243 Metetra
.661 .747 .914 r
.75892 .52243 .76268 .52701 .7712 .5245 .76745 .51991 Metetra
.66 .746 .914 r
.76745 .51991 .7712 .5245 .77974 .52202 .776 .51741 Metetra
.659 .746 .914 r
.776 .51741 .77974 .52202 .7883 .51956 .78459 .51492 Metetra
.659 .745 .914 r
.78459 .51492 .7883 .51956 .7969 .5171 .7932 .51243 Metetra
.659 .744 .913 r
.7932 .51243 .7969 .5171 .80552 .51463 .80184 .50993 Metetra
.659 .744 .912 r
.80184 .50993 .80552 .51463 .81416 .51215 .8105 .50742 Metetra
.66 .743 .912 r
.8105 .50742 .81416 .51215 .82284 .50964 .81919 .50488 Metetra
.661 .743 .911 r
.81919 .50488 .82284 .50964 .83153 .5071 .8279 .50232 Metetra
.661 .743 .911 r
.8279 .50232 .83153 .5071 .84025 .50453 .83664 .49974 Metetra
.662 .743 .91 r
.83664 .49974 .84025 .50453 .84899 .50193 .8454 .49713 Metetra
.662 .744 .911 r
.8454 .49713 .84899 .50193 .85776 .49932 .85419 .49451 Metetra
.662 .744 .911 r
.85419 .49451 .85776 .49932 .86655 .4967 .863 .49189 Metetra
.662 .744 .911 r
.863 .49189 .86655 .4967 .87538 .49408 .87184 .48925 Metetra
.662 .744 .911 r
.87184 .48925 .87538 .49408 .88422 .49145 .88071 .48661 Metetra
.662 .745 .911 r
.88071 .48661 .88422 .49145 .8931 .48881 .88961 .48397 Metetra
.662 .745 .912 r
.88961 .48397 .8931 .48881 .902 .48618 .89853 .48133 Metetra
.661 .745 .912 r
.89853 .48133 .902 .48618 .91093 .48355 .90748 .47868 Metetra
.661 .745 .912 r
.90748 .47868 .91093 .48355 .91989 .48092 .91646 .47603 Metetra
.661 .744 .912 r
.91646 .47603 .91989 .48092 .92888 .47828 .92547 .47338 Metetra
.661 .744 .912 r
.92547 .47338 .92888 .47828 .9379 .47564 .9345 .47071 Metetra
.661 .744 .912 r
.9345 .47071 .9379 .47564 .94694 .47298 .94356 .46804 Metetra
.661 .744 .912 r
.94356 .46804 .94694 .47298 .95601 .47032 .95265 .46536 Metetra
.661 .744 .912 r
.95265 .46536 .95601 .47032 .9651 .46764 .96177 .46267 Metetra
.661 .744 .911 r
.96177 .46267 .9651 .46764 .97423 .46496 .97092 .45997 Metetra
.661 .744 .911 r
.39516 .62475 .39964 .62885 .40714 .62663 .40267 .62252 Metetra
.661 .744 .911 r
.40267 .62252 .40714 .62663 .41465 .62441 .4102 .62029 Metetra
.661 .744 .911 r
.4102 .62029 .41465 .62441 .42219 .62218 .41775 .61805 Metetra
.661 .744 .912 r
.41775 .61805 .42219 .62218 .42975 .61994 .42532 .6158 Metetra
.661 .744 .912 r
.42532 .6158 .42975 .61994 .43732 .6177 .43291 .61355 Metetra
.661 .745 .912 r
.43291 .61355 .43732 .6177 .44492 .61544 .44052 .61129 Metetra
.661 .745 .912 r
.44052 .61129 .44492 .61544 .45255 .61319 .44816 .60902 Metetra
.661 .745 .912 r
.44816 .60902 .45255 .61319 .46019 .61093 .45581 .60675 Metetra
.661 .745 .912 r
.45581 .60675 .46019 .61093 .46785 .60867 .46349 .60447 Metetra
.661 .745 .912 r
.46349 .60447 .46785 .60867 .47554 .6064 .47119 .60219 Metetra
.661 .744 .912 r
.47119 .60219 .47554 .6064 .48325 .60413 .47891 .59991 Metetra
.661 .744 .912 r
.47891 .59991 .48325 .60413 .49097 .60186 .48666 .59762 Metetra
.661 .744 .911 r
.48666 .59762 .49097 .60186 .49873 .59958 .49442 .59532 Metetra
.661 .743 .911 r
.49442 .59532 .49873 .59958 .5065 .5973 .50221 .59301 Metetra
.661 .743 .911 r
.50221 .59301 .5065 .5973 .51429 .59501 .51002 .5907 Metetra
.661 .743 .91 r
.51002 .5907 .51429 .59501 .52211 .5927 .51785 .58838 Metetra
.662 .743 .91 r
.51785 .58838 .52211 .5927 .52995 .59037 .52571 .58604 Metetra
.662 .743 .91 r
.52571 .58604 .52995 .59037 .53782 .58802 .53358 .5837 Metetra
.662 .744 .911 r
.53358 .5837 .53782 .58802 .5457 .58565 .54148 .58134 Metetra
.662 .745 .912 r
.54148 .58134 .5457 .58565 .55361 .58327 .54941 .57897 Metetra
.662 .746 .912 r
.54941 .57897 .55361 .58327 .56154 .58088 .55735 .57659 Metetra
.662 .747 .913 r
.55735 .57659 .56154 .58088 .56949 .57849 .56532 .57421 Metetra
.662 .748 .914 r
.56532 .57421 .56949 .57849 .57746 .57611 .57331 .57183 Metetra
.661 .749 .915 r
.57331 .57183 .57746 .57611 .58546 .57374 .58132 .56945 Metetra
.66 .748 .915 r
.58132 .56945 .58546 .57374 .59348 .5714 .58936 .56708 Metetra
.66 .747 .915 r
.58936 .56708 .59348 .5714 .60153 .56909 .59742 .56472 Metetra
.659 .745 .914 r
.59742 .56472 .60153 .56909 .6096 .56683 .60551 .56238 Metetra
.658 .742 .912 r
.60551 .56238 .6096 .56683 .6177 .56458 .61362 .56004 Metetra
.658 .738 .909 r
.61362 .56004 .6177 .56458 .62582 .56236 .62175 .5577 Metetra
.658 .734 .905 r
.62175 .5577 .62582 .56236 .63396 .56013 .62991 .55536 Metetra
.658 .729 .902 r
.62991 .55536 .63396 .56013 .64213 .5579 .63809 .55301 Metetra
.659 .725 .898 r
.63809 .55301 .64213 .5579 .65033 .55563 .64629 .55064 Metetra
.66 .722 .895 r
.64629 .55064 .65033 .55563 .65854 .55333 .65452 .54826 Metetra
.66 .719 .892 r
.65452 .54826 .65854 .55333 .66678 .55096 .66278 .54584 Metetra
.662 .718 .89 r
.66278 .54584 .66678 .55096 .67505 .54853 .67105 .54339 Metetra
.663 .718 .89 r
.67105 .54339 .67505 .54853 .68333 .54602 .67935 .5409 Metetra
.664 .72 .891 r
.67935 .5409 .68333 .54602 .69163 .54345 .68767 .53838 Metetra
.665 .723 .893 r
.68767 .53838 .69163 .54345 .69996 .54083 .69602 .53584 Metetra
.665 .727 .895 r
.69602 .53584 .69996 .54083 .70831 .53818 .70439 .53328 Metetra
.665 .731 .899 r
.70439 .53328 .70831 .53818 .71668 .53552 .71278 .5307 Metetra
.665 .736 .902 r
.71278 .5307 .71668 .53552 .72507 .53285 .7212 .52813 Metetra
.665 .74 .906 r
.7212 .52813 .72507 .53285 .73349 .5302 .72964 .52555 Metetra
.664 .744 .91 r
.72964 .52555 .73349 .5302 .74194 .52757 .73811 .52298 Metetra
.663 .747 .913 r
.73811 .52298 .74194 .52757 .75041 .52498 .74661 .52043 Metetra
.662 .749 .914 r
.74661 .52043 .75041 .52498 .75892 .52243 .75513 .51788 Metetra
.661 .749 .915 r
.75513 .51788 .75892 .52243 .76745 .51991 .76368 .51535 Metetra
.661 .749 .916 r
.76368 .51535 .76745 .51991 .776 .51741 .77225 .51282 Metetra
.66 .748 .915 r
.77225 .51282 .776 .51741 .78459 .51492 .78085 .51029 Metetra
.66 .747 .914 r
.78085 .51029 .78459 .51492 .7932 .51243 .78948 .50775 Metetra
.66 .746 .913 r
.78948 .50775 .7932 .51243 .80184 .50993 .79813 .50521 Metetra
.66 .744 .912 r
.79813 .50521 .80184 .50993 .8105 .50742 .80681 .50265 Metetra
.661 .743 .911 r
.80681 .50265 .8105 .50742 .81919 .50488 .81552 .50009 Metetra
.661 .742 .91 r
.81552 .50009 .81919 .50488 .8279 .50232 .82425 .4975 Metetra
.662 .742 .91 r
.82425 .4975 .8279 .50232 .83664 .49974 .833 .4949 Metetra
.662 .742 .91 r
.833 .4949 .83664 .49974 .8454 .49713 .84179 .49229 Metetra
.662 .743 .91 r
.84179 .49229 .8454 .49713 .85419 .49451 .85059 .48967 Metetra
.662 .743 .91 r
.85059 .48967 .85419 .49451 .863 .49189 .85943 .48704 Metetra
.662 .744 .911 r
.85943 .48704 .863 .49189 .87184 .48925 .86829 .4844 Metetra
.662 .744 .911 r
.86829 .4844 .87184 .48925 .88071 .48661 .87718 .48176 Metetra
.662 .745 .912 r
.87718 .48176 .88071 .48661 .88961 .48397 .8861 .47911 Metetra
.661 .745 .912 r
.8861 .47911 .88961 .48397 .89853 .48133 .89504 .47645 Metetra
.661 .745 .912 r
.89504 .47645 .89853 .48133 .90748 .47868 .90401 .47379 Metetra
.661 .745 .912 r
.90401 .47379 .90748 .47868 .91646 .47603 .91301 .47112 Metetra
.661 .745 .912 r
.91301 .47112 .91646 .47603 .92547 .47338 .92204 .46845 Metetra
.661 .745 .912 r
.92204 .46845 .92547 .47338 .9345 .47071 .93109 .46577 Metetra
.661 .744 .912 r
.93109 .46577 .9345 .47071 .94356 .46804 .94017 .46308 Metetra
.661 .744 .912 r
.94017 .46308 .94356 .46804 .95265 .46536 .94928 .46038 Metetra
.661 .744 .911 r
.94928 .46038 .95265 .46536 .96177 .46267 .95842 .45767 Metetra
.661 .744 .911 r
.95842 .45767 .96177 .46267 .97092 .45997 .96759 .45495 Metetra
.661 .744 .911 r
.39066 .62063 .39516 .62475 .40267 .62252 .39818 .61839 Metetra
.661 .744 .911 r
.39818 .61839 .40267 .62252 .4102 .62029 .40572 .61615 Metetra
.661 .744 .912 r
.40572 .61615 .4102 .62029 .41775 .61805 .41328 .6139 Metetra
.661 .744 .912 r
.41328 .6139 .41775 .61805 .42532 .6158 .42086 .61164 Metetra
.661 .744 .912 r
.42086 .61164 .42532 .6158 .43291 .61355 .42847 .60938 Metetra
.661 .745 .912 r
.42847 .60938 .43291 .61355 .44052 .61129 .4361 .60711 Metetra
.661 .745 .912 r
.4361 .60711 .44052 .61129 .44816 .60902 .44375 .60484 Metetra
.661 .745 .912 r
.44375 .60484 .44816 .60902 .45581 .60675 .45142 .60255 Metetra
.661 .745 .912 r
.45142 .60255 .45581 .60675 .46349 .60447 .45911 .60026 Metetra
.661 .745 .912 r
.45911 .60026 .46349 .60447 .47119 .60219 .46682 .59796 Metetra
.662 .744 .912 r
.46682 .59796 .47119 .60219 .47891 .59991 .47456 .59566 Metetra
.662 .744 .911 r
.47456 .59566 .47891 .59991 .48666 .59762 .48231 .59334 Metetra
.662 .744 .911 r
.48231 .59334 .48666 .59762 .49442 .59532 .49009 .59102 Metetra
.662 .743 .911 r
.49009 .59102 .49442 .59532 .50221 .59301 .4979 .5887 Metetra
.662 .743 .91 r
.4979 .5887 .50221 .59301 .51002 .5907 .50572 .58636 Metetra
.661 .742 .91 r
.50572 .58636 .51002 .5907 .51785 .58838 .51357 .58403 Metetra
.661 .742 .91 r
.51357 .58403 .51785 .58838 .52571 .58604 .52144 .58169 Metetra
.661 .743 .91 r
.52144 .58169 .52571 .58604 .53358 .5837 .52933 .57935 Metetra
.661 .743 .911 r
.52933 .57935 .53358 .5837 .54148 .58134 .53724 .57701 Metetra
.661 .745 .912 r
.53724 .57701 .54148 .58134 .54941 .57897 .54518 .57466 Metetra
.661 .746 .914 r
.54518 .57466 .54941 .57897 .55735 .57659 .55314 .5723 Metetra
.661 .748 .915 r
.55314 .5723 .55735 .57659 .56532 .57421 .56112 .56994 Metetra
.661 .749 .916 r
.56112 .56994 .56532 .57421 .57331 .57183 .56913 .56757 Metetra
.661 .75 .916 r
.56913 .56757 .57331 .57183 .58132 .56945 .57716 .56518 Metetra
.662 .75 .916 r
.57716 .56518 .58132 .56945 .58936 .56708 .58521 .56277 Metetra
.662 .75 .915 r
.58521 .56277 .58936 .56708 .59742 .56472 .59329 .56034 Metetra
.663 .747 .913 r
.59329 .56034 .59742 .56472 .60551 .56238 .60139 .55789 Metetra
.664 .743 .909 r
.60139 .55789 .60551 .56238 .61362 .56004 .60951 .55542 Metetra
.664 .738 .905 r
.60951 .55542 .61362 .56004 .62175 .5577 .61766 .55293 Metetra
.665 .732 .9 r
.61766 .55293 .62175 .5577 .62991 .55536 .62582 .55044 Metetra
.664 .726 .895 r
.62582 .55044 .62991 .55536 .63809 .55301 .63402 .54794 Metetra
.664 .72 .891 r
.63402 .54794 .63809 .55301 .64629 .55064 .64223 .54544 Metetra
.663 .715 .887 r
.64223 .54544 .64629 .55064 .65452 .54826 .65047 .54294 Metetra
.663 .711 .884 r
.65047 .54294 .65452 .54826 .66278 .54584 .65874 .54046 Metetra
.662 .709 .883 r
.65874 .54046 .66278 .54584 .67105 .54339 .66703 .53799 Metetra
.661 .708 .883 r
.66703 .53799 .67105 .54339 .67935 .5409 .67534 .53553 Metetra
.66 .71 .885 r
.67534 .53553 .67935 .5409 .68767 .53838 .68369 .53309 Metetra
.659 .713 .888 r
.68369 .53309 .68767 .53838 .69602 .53584 .69205 .53065 Metetra
.659 .718 .892 r
.69205 .53065 .69602 .53584 .70439 .53328 .70044 .52822 Metetra
.659 .724 .897 r
.70044 .52822 .70439 .53328 .71278 .5307 .70886 .52578 Metetra
.659 .73 .902 r
.70886 .52578 .71278 .5307 .7212 .52813 .71731 .52333 Metetra
.659 .736 .907 r
.71731 .52333 .7212 .52813 .72964 .52555 .72577 .52087 Metetra
.659 .742 .911 r
.72577 .52087 .72964 .52555 .73811 .52298 .73427 .51838 Metetra
.66 .747 .914 r
.73427 .51838 .73811 .52298 .74661 .52043 .74278 .51588 Metetra
.66 .75 .916 r
.74278 .51588 .74661 .52043 .75513 .51788 .75132 .51335 Metetra
.661 .751 .917 r
.75132 .51335 .75513 .51788 .76368 .51535 .75989 .5108 Metetra
.661 .751 .917 r
.75989 .5108 .76368 .51535 .77225 .51282 .76848 .50823 Metetra
.662 .75 .916 r
.76848 .50823 .77225 .51282 .78085 .51029 .7771 .50565 Metetra
.662 .749 .915 r
.7771 .50565 .78085 .51029 .78948 .50775 .78574 .50306 Metetra
.662 .747 .913 r
.78574 .50306 .78948 .50775 .79813 .50521 .79441 .50046 Metetra
.662 .745 .912 r
.79441 .50046 .79813 .50521 .80681 .50265 .8031 .49785 Metetra
.662 .743 .91 r
.8031 .49785 .80681 .50265 .81552 .50009 .81183 .49525 Metetra
.662 .742 .91 r
.81183 .49525 .81552 .50009 .82425 .4975 .82057 .49264 Metetra
.661 .741 .909 r
.82057 .49264 .82425 .4975 .833 .4949 .82935 .49003 Metetra
.661 .741 .909 r
.82935 .49003 .833 .4949 .84179 .49229 .83815 .48741 Metetra
.661 .742 .91 r
.83815 .48741 .84179 .49229 .85059 .48967 .84698 .48479 Metetra
.661 .743 .91 r
.84698 .48479 .85059 .48967 .85943 .48704 .85583 .48216 Metetra
.661 .743 .911 r
.85583 .48216 .85943 .48704 .86829 .4844 .86472 .47952 Metetra
.661 .744 .911 r
.86472 .47952 .86829 .4844 .87718 .48176 .87363 .47688 Metetra
.661 .745 .912 r
.87363 .47688 .87718 .48176 .8861 .47911 .88256 .47422 Metetra
.661 .745 .912 r
.88256 .47422 .8861 .47911 .89504 .47645 .89153 .47156 Metetra
.661 .745 .912 r
.89153 .47156 .89504 .47645 .90401 .47379 .90052 .46888 Metetra
.661 .745 .912 r
.90052 .46888 .90401 .47379 .91301 .47112 .90954 .4662 Metetra
.661 .745 .912 r
.90954 .4662 .91301 .47112 .92204 .46845 .91858 .4635 Metetra
.661 .745 .912 r
.91858 .4635 .92204 .46845 .93109 .46577 .92766 .4608 Metetra
.661 .745 .912 r
.92766 .4608 .93109 .46577 .94017 .46308 .93676 .45808 Metetra
.661 .744 .912 r
.93676 .45808 .94017 .46308 .94928 .46038 .94589 .45536 Metetra
.661 .744 .911 r
.94589 .45536 .94928 .46038 .95842 .45767 .95505 .45264 Metetra
.661 .744 .911 r
.95505 .45264 .95842 .45767 .96759 .45495 .96424 .4499 Metetra
.661 .744 .911 r
.38613 .61649 .39066 .62063 .39818 .61839 .39366 .61424 Metetra
.661 .744 .911 r
.39366 .61424 .39818 .61839 .40572 .61615 .40122 .61199 Metetra
.661 .744 .912 r
.40122 .61199 .40572 .61615 .41328 .6139 .40879 .60973 Metetra
.661 .744 .912 r
.40879 .60973 .41328 .6139 .42086 .61164 .41639 .60746 Metetra
.661 .744 .912 r
.41639 .60746 .42086 .61164 .42847 .60938 .42401 .60519 Metetra
.661 .745 .912 r
.42401 .60519 .42847 .60938 .4361 .60711 .43165 .60292 Metetra
.661 .745 .912 r
.43165 .60292 .4361 .60711 .44375 .60484 .43931 .60063 Metetra
.661 .745 .912 r
.43931 .60063 .44375 .60484 .45142 .60255 .44699 .59834 Metetra
.662 .745 .912 r
.44699 .59834 .45142 .60255 .45911 .60026 .4547 .59603 Metetra
.662 .745 .912 r
.4547 .59603 .45911 .60026 .46682 .59796 .46243 .59371 Metetra
.662 .745 .911 r
.46243 .59371 .46682 .59796 .47456 .59566 .47018 .59138 Metetra
.662 .744 .911 r
.47018 .59138 .47456 .59566 .48231 .59334 .47795 .58905 Metetra
.662 .744 .911 r
.47795 .58905 .48231 .59334 .49009 .59102 .48575 .5867 Metetra
.662 .743 .91 r
.48575 .5867 .49009 .59102 .4979 .5887 .49356 .58434 Metetra
.662 .742 .91 r
.49356 .58434 .4979 .5887 .50572 .58636 .5014 .58199 Metetra
.662 .742 .909 r
.5014 .58199 .50572 .58636 .51357 .58403 .50926 .57964 Metetra
.661 .741 .91 r
.50926 .57964 .51357 .58403 .52144 .58169 .51715 .5773 Metetra
.66 .742 .911 r
.51715 .5773 .52144 .58169 .52933 .57935 .52505 .57497 Metetra
.659 .743 .912 r
.52505 .57497 .52933 .57935 .53724 .57701 .53298 .57266 Metetra
.659 .744 .913 r
.53298 .57266 .53724 .57701 .54518 .57466 .54093 .57034 Metetra
.658 .746 .915 r
.54093 .57034 .54518 .57466 .55314 .5723 .54891 .56802 Metetra
.659 .748 .916 r
.54891 .56802 .55314 .5723 .56112 .56994 .55691 .56568 Metetra
.659 .75 .917 r
.55691 .56568 .56112 .56994 .56913 .56757 .56493 .56332 Metetra
.661 .752 .918 r
.56493 .56332 .56913 .56757 .57716 .56518 .57298 .56092 Metetra
.663 .753 .917 r
.57298 .56092 .57716 .56518 .58521 .56277 .58105 .55847 Metetra
.666 .752 .915 r
.58105 .55847 .58521 .56277 .59329 .56034 .58914 .55595 Metetra
.669 .75 .911 r
.58914 .55595 .59329 .56034 .60139 .55789 .59725 .55337 Metetra
.671 .745 .906 r
.59725 .55337 .60139 .55789 .60951 .55542 .60538 .55073 Metetra
.672 .738 .9 r
.60538 .55073 .60951 .55542 .61766 .55293 .61354 .54806 Metetra
.672 .731 .894 r
.61354 .54806 .61766 .55293 .62582 .55044 .62172 .54537 Metetra
.672 .723 .888 r
.62172 .54537 .62582 .55044 .63402 .54794 .62992 .54267 Metetra
.67 .716 .883 r
.62992 .54267 .63402 .54794 .64223 .54544 .63814 .54 Metetra
.668 .709 .878 r
.63814 .54 .64223 .54544 .65047 .54294 .64639 .53737 Metetra
.665 .703 .875 r
.64639 .53737 .65047 .54294 .65874 .54046 .65467 .5348 Metetra
.661 .699 .875 r
.65467 .5348 .65874 .54046 .66703 .53799 .66297 .53231 Metetra
.658 .698 .876 r
.66297 .53231 .66703 .53799 .67534 .53553 .67131 .5299 Metetra
.655 .699 .879 r
.67131 .5299 .67534 .53553 .68369 .53309 .67967 .52756 Metetra
.653 .703 .883 r
.67967 .52756 .68369 .53309 .69205 .53065 .68806 .52527 Metetra
.652 .708 .889 r
.68806 .52527 .69205 .53065 .70044 .52822 .69647 .523 Metetra
.651 .715 .895 r
.69647 .523 .70044 .52822 .70886 .52578 .70492 .52074 Metetra
.651 .723 .901 r
.70492 .52074 .70886 .52578 .71731 .52333 .71339 .51846 Metetra
.652 .731 .907 r
.71339 .51846 .71731 .52333 .72577 .52087 .72188 .51615 Metetra
.654 .739 .913 r
.72188 .51615 .72577 .52087 .73427 .51838 .7304 .51378 Metetra
.656 .746 .916 r
.7304 .51378 .73427 .51838 .74278 .51588 .73894 .51134 Metetra
.659 .751 .918 r
.73894 .51134 .74278 .51588 .75132 .51335 .7475 .50883 Metetra
.661 .753 .919 r
.7475 .50883 .75132 .51335 .75989 .5108 .75609 .50627 Metetra
.663 .754 .918 r
.75609 .50627 .75989 .5108 .76848 .50823 .76469 .50366 Metetra
.664 .753 .916 r
.76469 .50366 .76848 .50823 .7771 .50565 .77333 .50101 Metetra
.664 .751 .915 r
.77333 .50101 .7771 .50565 .78574 .50306 .78198 .49836 Metetra
.664 .748 .913 r
.78198 .49836 .78574 .50306 .79441 .50046 .79067 .49569 Metetra
.664 .746 .911 r
.79067 .49569 .79441 .50046 .8031 .49785 .79938 .49302 Metetra
.663 .744 .91 r
.79938 .49302 .8031 .49785 .81183 .49525 .80811 .49037 Metetra
.662 .742 .909 r
.80811 .49037 .81183 .49525 .82057 .49264 .81688 .48773 Metetra
.661 .741 .909 r
.81688 .48773 .82057 .49264 .82935 .49003 .82567 .4851 Metetra
.661 .74 .909 r
.82567 .4851 .82935 .49003 .83815 .48741 .83449 .48249 Metetra
.66 .741 .91 r
.83449 .48249 .83815 .48741 .84698 .48479 .84334 .47987 Metetra
.66 .742 .91 r
.84334 .47987 .84698 .48479 .85583 .48216 .85222 .47725 Metetra
.66 .743 .911 r
.85222 .47725 .85583 .48216 .86472 .47952 .86112 .47462 Metetra
.66 .744 .912 r
.86112 .47462 .86472 .47952 .87363 .47688 .87006 .47197 Metetra
.661 .745 .912 r
.87006 .47197 .87363 .47688 .88256 .47422 .87901 .46932 Metetra
.661 .745 .913 r
.87901 .46932 .88256 .47422 .89153 .47156 .888 .46664 Metetra
.661 .746 .913 r
.888 .46664 .89153 .47156 .90052 .46888 .89701 .46395 Metetra
.662 .746 .913 r
.89701 .46395 .90052 .46888 .90954 .4662 .90605 .46124 Metetra
.662 .746 .912 r
.90605 .46124 .90954 .4662 .91858 .4635 .91511 .45853 Metetra
.662 .745 .912 r
.91511 .45853 .91858 .4635 .92766 .4608 .92421 .4558 Metetra
.662 .745 .912 r
.92421 .4558 .92766 .4608 .93676 .45808 .93333 .45306 Metetra
.662 .745 .912 r
.93333 .45306 .93676 .45808 .94589 .45536 .94248 .45032 Metetra
.662 .744 .911 r
.94248 .45032 .94589 .45536 .95505 .45264 .95166 .44757 Metetra
.662 .744 .911 r
.95166 .44757 .95505 .45264 .96424 .4499 .96087 .44482 Metetra
.661 .744 .911 r
.38158 .61233 .38613 .61649 .39366 .61424 .38912 .61007 Metetra
.661 .744 .911 r
.38912 .61007 .39366 .61424 .40122 .61199 .39669 .6078 Metetra
.661 .744 .912 r
.39669 .6078 .40122 .61199 .40879 .60973 .40428 .60553 Metetra
.661 .744 .912 r
.40428 .60553 .40879 .60973 .41639 .60746 .41189 .60326 Metetra
.661 .744 .912 r
.41189 .60326 .41639 .60746 .42401 .60519 .41952 .60098 Metetra
.661 .745 .912 r
.41952 .60098 .42401 .60519 .43165 .60292 .42718 .5987 Metetra
.661 .745 .912 r
.42718 .5987 .43165 .60292 .43931 .60063 .43485 .59641 Metetra
.661 .745 .912 r
.43485 .59641 .43931 .60063 .44699 .59834 .44255 .5941 Metetra
.662 .745 .912 r
.44255 .5941 .44699 .59834 .4547 .59603 .45027 .59178 Metetra
.662 .745 .912 r
.45027 .59178 .4547 .59603 .46243 .59371 .45801 .58944 Metetra
.663 .745 .911 r
.45801 .58944 .46243 .59371 .47018 .59138 .46578 .58709 Metetra
.663 .744 .911 r
.46578 .58709 .47018 .59138 .47795 .58905 .47356 .58472 Metetra
.663 .744 .91 r
.47356 .58472 .47795 .58905 .48575 .5867 .48137 .58234 Metetra
.663 .743 .909 r
.48137 .58234 .48575 .5867 .49356 .58434 .4892 .57996 Metetra
.663 .742 .909 r
.4892 .57996 .49356 .58434 .5014 .58199 .49706 .57758 Metetra
.662 .741 .909 r
.49706 .57758 .5014 .58199 .50926 .57964 .50493 .57522 Metetra
.66 .741 .91 r
.50493 .57522 .50926 .57964 .51715 .5773 .51283 .57288 Metetra
.658 .741 .911 r
.51283 .57288 .51715 .5773 .52505 .57497 .52075 .57057 Metetra
.657 .742 .913 r
.52075 .57057 .52505 .57497 .53298 .57266 .5287 .56829 Metetra
.656 .744 .914 r
.5287 .56829 .53298 .57266 .54093 .57034 .53666 .56601 Metetra
.656 .746 .916 r
.53666 .56601 .54093 .57034 .54891 .56802 .54466 .56373 Metetra
.656 .749 .918 r
.54466 .56373 .54891 .56802 .55691 .56568 .55267 .56143 Metetra
.658 .751 .919 r
.55267 .56143 .55691 .56568 .56493 .56332 .56071 .55908 Metetra
.661 .754 .919 r
.56071 .55908 .56493 .56332 .57298 .56092 .56877 .55667 Metetra
.665 .755 .917 r
.56877 .55667 .57298 .56092 .58105 .55847 .57685 .55417 Metetra
.67 .755 .914 r
.57685 .55417 .58105 .55847 .58914 .55595 .58496 .55155 Metetra
.675 .752 .909 r
.58496 .55155 .58914 .55595 .59725 .55337 .59309 .54881 Metetra
.679 .747 .902 r
.59309 .54881 .59725 .55337 .60538 .55073 .60123 .54598 Metetra
.681 .739 .895 r
.60123 .54598 .60538 .55073 .61354 .54806 .6094 .54308 Metetra
.681 .731 .888 r
.6094 .54308 .61354 .54806 .62172 .54537 .61759 .54015 Metetra
.68 .721 .881 r
.61759 .54015 .62172 .54537 .62992 .54267 .62579 .53722 Metetra
.677 .712 .875 r
.62579 .53722 .62992 .54267 .63814 .54 .63403 .53434 Metetra
.673 .704 .87 r
.63403 .53434 .63814 .54 .64639 .53737 .64229 .53155 Metetra
.667 .696 .868 r
.64229 .53155 .64639 .53737 .65467 .5348 .65057 .52888 Metetra
.661 .691 .867 r
.65057 .52888 .65467 .5348 .66297 .53231 .65889 .52637 Metetra
.654 .688 .869 r
.65889 .52637 .66297 .53231 .67131 .5299 .66724 .52402 Metetra
.649 .689 .874 r
.66724 .52402 .67131 .5299 .67967 .52756 .67562 .52181 Metetra
.645 .692 .879 r
.67562 .52181 .67967 .52756 .68806 .52527 .68403 .51969 Metetra
.642 .698 .886 r
.68403 .51969 .68806 .52527 .69647 .523 .69248 .51763 Metetra
.641 .706 .894 r
.69248 .51763 .69647 .523 .70492 .52074 .70095 .51558 Metetra
.641 .716 .902 r
.70095 .51558 .70492 .52074 .71339 .51846 .70944 .51351 Metetra
.643 .726 .909 r
.70944 .51351 .71339 .51846 .72188 .51615 .71797 .51139 Metetra
.646 .736 .915 r
.71797 .51139 .72188 .51615 .7304 .51378 .72651 .50916 Metetra
.651 .745 .918 r
.72651 .50916 .7304 .51378 .73894 .51134 .73508 .50681 Metetra
.656 .752 .92 r
.73508 .50681 .73894 .51134 .7475 .50883 .74366 .50434 Metetra
.661 .755 .92 r
.74366 .50434 .7475 .50883 .75609 .50627 .75226 .50175 Metetra
.664 .756 .919 r
.75226 .50175 .75609 .50627 .76469 .50366 .76089 .49909 Metetra
.666 .755 .917 r
.76089 .49909 .76469 .50366 .77333 .50101 .76953 .49638 Metetra
.667 .753 .915 r
.76953 .49638 .77333 .50101 .78198 .49836 .77821 .49364 Metetra
.667 .75 .912 r
.77821 .49364 .78198 .49836 .79067 .49569 .7869 .49089 Metetra
.667 .747 .91 r
.7869 .49089 .79067 .49569 .79938 .49302 .79562 .48815 Metetra
.665 .744 .909 r
.79562 .48815 .79938 .49302 .80811 .49037 .80438 .48544 Metetra
.663 .741 .908 r
.80438 .48544 .80811 .49037 .81688 .48773 .81316 .48277 Metetra
.661 .74 .908 r
.81316 .48277 .81688 .48773 .82567 .4851 .82197 .48013 Metetra
.66 .739 .909 r
.82197 .48013 .82567 .4851 .83449 .48249 .83081 .47752 Metetra
.659 .74 .909 r
.83081 .47752 .83449 .48249 .84334 .47987 .83969 .47492 Metetra
.659 .741 .91 r
.83969 .47492 .84334 .47987 .85222 .47725 .84859 .4723 Metetra
.659 .742 .911 r
.84859 .4723 .85222 .47725 .86112 .47462 .85751 .46968 Metetra
.659 .743 .912 r
.85751 .46968 .86112 .47462 .87006 .47197 .86646 .46704 Metetra
.66 .744 .913 r
.86646 .46704 .87006 .47197 .87901 .46932 .87544 .46439 Metetra
.661 .745 .913 r
.87544 .46439 .87901 .46932 .888 .46664 .88445 .46171 Metetra
.661 .746 .913 r
.88445 .46171 .888 .46664 .89701 .46395 .89348 .459 Metetra
.662 .746 .913 r
.89348 .459 .89701 .46395 .90605 .46124 .90254 .45627 Metetra
.662 .746 .912 r
.90254 .45627 .90605 .46124 .91511 .45853 .91162 .45353 Metetra
.662 .746 .912 r
.91162 .45353 .91511 .45853 .92421 .4558 .92074 .45077 Metetra
.662 .745 .912 r
.92074 .45077 .92421 .4558 .93333 .45306 .92988 .44801 Metetra
.662 .745 .911 r
.92988 .44801 .93333 .45306 .94248 .45032 .93905 .44525 Metetra
.662 .744 .911 r
.93905 .44525 .94248 .45032 .95166 .44757 .94825 .44248 Metetra
.662 .744 .911 r
.94825 .44248 .95166 .44757 .96087 .44482 .95748 .43971 Metetra
.661 .744 .911 r
.377 .60815 .38158 .61233 .38912 .61007 .38456 .60587 Metetra
.661 .744 .912 r
.38456 .60587 .38912 .61007 .39669 .6078 .39214 .6036 Metetra
.661 .744 .912 r
.39214 .6036 .39669 .6078 .40428 .60553 .39974 .60132 Metetra
.661 .744 .912 r
.39974 .60132 .40428 .60553 .41189 .60326 .40737 .59904 Metetra
.661 .744 .912 r
.40737 .59904 .41189 .60326 .41952 .60098 .41501 .59675 Metetra
.66 .744 .912 r
.41501 .59675 .41952 .60098 .42718 .5987 .42268 .59446 Metetra
.661 .745 .912 r
.42268 .59446 .42718 .5987 .43485 .59641 .43037 .59216 Metetra
.661 .745 .912 r
.43037 .59216 .43485 .59641 .44255 .5941 .43808 .58984 Metetra
.662 .745 .912 r
.43808 .58984 .44255 .5941 .45027 .59178 .44582 .58751 Metetra
.663 .745 .911 r
.44582 .58751 .45027 .59178 .45801 .58944 .45357 .58514 Metetra
.663 .745 .911 r
.45357 .58514 .45801 .58944 .46578 .58709 .46135 .58277 Metetra
.664 .745 .91 r
.46135 .58277 .46578 .58709 .47356 .58472 .46915 .58037 Metetra
.664 .744 .91 r
.46915 .58037 .47356 .58472 .48137 .58234 .47698 .57797 Metetra
.664 .743 .909 r
.47698 .57797 .48137 .58234 .4892 .57996 .48482 .57556 Metetra
.663 .742 .909 r
.48482 .57556 .4892 .57996 .49706 .57758 .49269 .57315 Metetra
.662 .741 .909 r
.49269 .57315 .49706 .57758 .50493 .57522 .50058 .57078 Metetra
.659 .741 .91 r
.50058 .57078 .50493 .57522 .51283 .57288 .50849 .56844 Metetra
.657 .741 .911 r
.50849 .56844 .51283 .57288 .52075 .57057 .51643 .56615 Metetra
.655 .741 .913 r
.51643 .56615 .52075 .57057 .5287 .56829 .52439 .5639 Metetra
.653 .743 .915 r
.52439 .5639 .5287 .56829 .53666 .56601 .53237 .56166 Metetra
.653 .745 .917 r
.53237 .56166 .53666 .56601 .54466 .56373 .54038 .55941 Metetra
.654 .748 .919 r
.54038 .55941 .54466 .56373 .55267 .56143 .54841 .55714 Metetra
.656 .75 .919 r
.54841 .55714 .55267 .56143 .56071 .55908 .55646 .55481 Metetra
.661 .753 .919 r
.55646 .55481 .56071 .55908 .56877 .55667 .56454 .55239 Metetra
.667 .755 .916 r
.56454 .55239 .56877 .55667 .57685 .55417 .57264 .54984 Metetra
.674 .755 .912 r
.57264 .54984 .57685 .55417 .58496 .55155 .58076 .54712 Metetra
.681 .754 .906 r
.58076 .54712 .58496 .55155 .59309 .54881 .5889 .54423 Metetra
.686 .749 .899 r
.5889 .54423 .59309 .54881 .60123 .54598 .59706 .54121 Metetra
.689 .742 .892 r
.59706 .54121 .60123 .54598 .6094 .54308 .60524 .5381 Metetra
.689 .734 .885 r
.60524 .5381 .6094 .54308 .61759 .54015 .61343 .53494 Metetra
.688 .725 .879 r
.61343 .53494 .61759 .54015 .62579 .53722 .62165 .5318 Metetra
.684 .716 .874 r
.62165 .5318 .62579 .53722 .63403 .53434 .6299 .52872 Metetra
.678 .708 .87 r
.6299 .52872 .63403 .53434 .64229 .53155 .63816 .52578 Metetra
.671 .7 .869 r
.63816 .52578 .64229 .53155 .65057 .52888 .64646 .52301 Metetra
.661 .694 .87 r
.64646 .52301 .65057 .52888 .65889 .52637 .65479 .52048 Metetra
.652 .69 .873 r
.65479 .52048 .65889 .52637 .66724 .52402 .66316 .51819 Metetra
.644 .689 .878 r
.66316 .51819 .66724 .52402 .67562 .52181 .67156 .51609 Metetra
.638 .692 .884 r
.67156 .51609 .67562 .52181 .68403 .51969 .67999 .51414 Metetra
.633 .697 .891 r
.67999 .51414 .68403 .51969 .69248 .51763 .68846 .51227 Metetra
.631 .704 .898 r
.68846 .51227 .69248 .51763 .70095 .51558 .69696 .51043 Metetra
.631 .713 .906 r
.69696 .51043 .70095 .51558 .70944 .51351 .70548 .50856 Metetra
.634 .723 .912 r
.70548 .50856 .70944 .51351 .71797 .51139 .71403 .50661 Metetra
.639 .734 .917 r
.71403 .50661 .71797 .51139 .72651 .50916 .7226 .50452 Metetra
.647 .743 .92 r
.7226 .50452 .72651 .50916 .73508 .50681 .73119 .50225 Metetra
.655 .75 .92 r
.73119 .50225 .73508 .50681 .74366 .50434 .7398 .4998 Metetra
.661 .755 .919 r
.7398 .4998 .74366 .50434 .75226 .50175 .74842 .4972 Metetra
.666 .756 .918 r
.74842 .4972 .75226 .50175 .76089 .49909 .75706 .49449 Metetra
.669 .756 .916 r
.75706 .49449 .76089 .49909 .76953 .49638 .76572 .49171 Metetra
.67 .754 .913 r
.76572 .49171 .76953 .49638 .77821 .49364 .77441 .4889 Metetra
.67 .751 .911 r
.77441 .4889 .77821 .49364 .7869 .49089 .78312 .48607 Metetra
.669 .748 .909 r
.78312 .48607 .7869 .49089 .79562 .48815 .79185 .48326 Metetra
.667 .745 .908 r
.79185 .48326 .79562 .48815 .80438 .48544 .80062 .4805 Metetra
.664 .742 .908 r
.80062 .4805 .80438 .48544 .81316 .48277 .80942 .47779 Metetra
.661 .74 .908 r
.80942 .47779 .81316 .48277 .82197 .48013 .81825 .47514 Metetra
.659 .739 .909 r
.81825 .47514 .82197 .48013 .83081 .47752 .82712 .47253 Metetra
.658 .74 .91 r
.82712 .47253 .83081 .47752 .83969 .47492 .83601 .46993 Metetra
.658 .741 .911 r
.83601 .46993 .83969 .47492 .84859 .4723 .84493 .46733 Metetra
.658 .742 .912 r
.84493 .46733 .84859 .4723 .85751 .46968 .85388 .46472 Metetra
.659 .743 .912 r
.85388 .46472 .85751 .46968 .86646 .46704 .86285 .46209 Metetra
.659 .744 .913 r
.86285 .46209 .86646 .46704 .87544 .46439 .87185 .45943 Metetra
.66 .745 .913 r
.87185 .45943 .87544 .46439 .88445 .46171 .88088 .45674 Metetra
.661 .746 .913 r
.88088 .45674 .88445 .46171 .89348 .459 .88993 .45402 Metetra
.662 .746 .913 r
.88993 .45402 .89348 .459 .90254 .45627 .89901 .45127 Metetra
.663 .746 .912 r
.89901 .45127 .90254 .45627 .91162 .45353 .90812 .4485 Metetra
.663 .746 .912 r
.90812 .4485 .91162 .45353 .92074 .45077 .91725 .44572 Metetra
.663 .745 .912 r
.91725 .44572 .92074 .45077 .92988 .44801 .92641 .44293 Metetra
.662 .745 .911 r
.92641 .44293 .92988 .44801 .93905 .44525 .9356 .44015 Metetra
.662 .744 .911 r
.9356 .44015 .93905 .44525 .94825 .44248 .94482 .43736 Metetra
.662 .744 .911 r
.94482 .43736 .94825 .44248 .95748 .43971 .95407 .43457 Metetra
.661 .744 .912 r
.3724 .60394 .377 .60815 .38456 .60587 .37997 .60166 Metetra
.661 .744 .912 r
.37997 .60166 .38456 .60587 .39214 .6036 .38757 .59937 Metetra
.661 .744 .912 r
.38757 .59937 .39214 .6036 .39974 .60132 .39519 .59708 Metetra
.661 .744 .912 r
.39519 .59708 .39974 .60132 .40737 .59904 .40282 .59479 Metetra
.66 .744 .912 r
.40282 .59479 .40737 .59904 .41501 .59675 .41048 .5925 Metetra
.66 .744 .912 r
.41048 .5925 .41501 .59675 .42268 .59446 .41816 .5902 Metetra
.661 .745 .912 r
.41816 .5902 .42268 .59446 .43037 .59216 .42587 .58789 Metetra
.661 .745 .912 r
.42587 .58789 .43037 .59216 .43808 .58984 .43359 .58556 Metetra
.662 .745 .912 r
.43359 .58556 .43808 .58984 .44582 .58751 .44134 .5832 Metetra
.663 .745 .911 r
.44134 .5832 .44582 .58751 .45357 .58514 .44911 .58082 Metetra
.664 .745 .911 r
.44911 .58082 .45357 .58514 .46135 .58277 .4569 .57843 Metetra
.664 .745 .91 r
.4569 .57843 .46135 .58277 .46915 .58037 .46472 .57601 Metetra
.664 .744 .91 r
.46472 .57601 .46915 .58037 .47698 .57797 .47256 .57359 Metetra
.664 .744 .909 r
.47256 .57359 .47698 .57797 .48482 .57556 .48042 .57115 Metetra
.664 .743 .909 r
.48042 .57115 .48482 .57556 .49269 .57315 .4883 .56873 Metetra
.662 .743 .91 r
.4883 .56873 .49269 .57315 .50058 .57078 .49621 .56634 Metetra
.659 .742 .911 r
.49621 .56634 .50058 .57078 .50849 .56844 .50413 .56399 Metetra
.656 .741 .913 r
.50413 .56399 .50849 .56844 .51643 .56615 .51208 .56171 Metetra
.653 .741 .914 r
.51208 .56171 .51643 .56615 .52439 .5639 .52006 .55947 Metetra
.652 .742 .916 r
.52006 .55947 .52439 .5639 .53237 .56166 .52806 .55725 Metetra
.652 .743 .917 r
.52806 .55725 .53237 .56166 .54038 .55941 .53608 .55502 Metetra
.653 .745 .917 r
.53608 .55502 .54038 .55941 .54841 .55714 .54412 .55276 Metetra
.656 .747 .917 r
.54412 .55276 .54841 .55714 .55646 .55481 .55219 .55044 Metetra
.661 .749 .916 r
.55219 .55044 .55646 .55481 .56454 .55239 .56029 .54801 Metetra
.668 .752 .913 r
.56029 .54801 .56454 .55239 .57264 .54984 .5684 .54542 Metetra
.676 .753 .909 r
.5684 .54542 .57264 .54984 .58076 .54712 .57654 .54264 Metetra
.685 .753 .903 r
.57654 .54264 .58076 .54712 .5889 .54423 .58469 .53966 Metetra
.691 .751 .898 r
.58469 .53966 .5889 .54423 .59706 .54121 .59287 .53651 Metetra
.694 .748 .893 r
.59287 .53651 .59706 .54121 .60524 .5381 .60106 .53326 Metetra
.695 .743 .888 r
.60106 .53326 .60524 .5381 .61343 .53494 .60927 .52997 Metetra
.694 .737 .885 r
.60927 .52997 .61343 .53494 .62165 .5318 .6175 .52669 Metetra
.69 .731 .882 r
.6175 .52669 .62165 .5318 .6299 .52872 .62576 .52349 Metetra
.683 .725 .881 r
.62576 .52349 .6299 .52872 .63816 .52578 .63404 .52044 Metetra
.674 .719 .882 r
.63404 .52044 .63816 .52578 .64646 .52301 .64235 .51761 Metetra
.663 .713 .885 r
.64235 .51761 .64646 .52301 .65479 .52048 .65069 .51506 Metetra
.65 .708 .889 r
.65069 .51506 .65479 .52048 .66316 .51819 .65907 .5128 Metetra
.64 .706 .894 r
.65907 .5128 .66316 .51819 .67156 .51609 .66749 .51077 Metetra
.632 .706 .899 r
.66749 .51077 .67156 .51609 .67999 .51414 .67595 .50891 Metetra
.626 .708 .905 r
.67595 .50891 .67999 .51414 .68846 .51227 .68444 .50716 Metetra
.624 .712 .91 r
.68444 .50716 .68846 .51227 .69696 .51043 .69295 .50543 Metetra
.624 .718 .914 r
.69295 .50543 .69696 .51043 .70548 .50856 .7015 .50367 Metetra
.628 .725 .917 r
.7015 .50367 .70548 .50856 .71403 .50661 .71008 .50182 Metetra
.635 .733 .919 r
.71008 .50182 .71403 .50661 .7226 .50452 .71867 .49981 Metetra
.644 .741 .919 r
.71867 .49981 .7226 .50452 .73119 .50225 .72728 .49758 Metetra
.654 .747 .918 r
.72728 .49758 .73119 .50225 .7398 .4998 .7359 .49514 Metetra
.661 .751 .916 r
.7359 .49514 .7398 .4998 .74842 .4972 .74454 .49253 Metetra
.667 .752 .914 r
.74454 .49253 .74842 .4972 .75706 .49449 .7532 .48979 Metetra
.67 .753 .912 r
.7532 .48979 .75706 .49449 .76572 .49171 .76188 .48696 Metetra
.672 .752 .911 r
.76188 .48696 .76572 .49171 .77441 .4889 .77058 .48409 Metetra
.672 .75 .91 r
.77058 .48409 .77441 .4889 .78312 .48607 .77931 .48122 Metetra
.671 .748 .909 r
.77931 .48122 .78312 .48607 .79185 .48326 .78806 .47836 Metetra
.668 .746 .908 r
.78806 .47836 .79185 .48326 .80062 .4805 .79685 .47556 Metetra
.664 .743 .909 r
.79685 .47556 .80062 .4805 .80942 .47779 .80566 .47283 Metetra
.661 .742 .91 r
.80566 .47283 .80942 .47779 .81825 .47514 .81452 .47016 Metetra
.659 .741 .91 r
.81452 .47016 .81825 .47514 .82712 .47253 .8234 .46754 Metetra
.657 .741 .911 r
.8234 .46754 .82712 .47253 .83601 .46993 .83231 .46495 Metetra
.657 .741 .912 r
.83231 .46495 .83601 .46993 .84493 .46733 .84125 .46235 Metetra
.658 .742 .912 r
.84125 .46235 .84493 .46733 .85388 .46472 .85022 .45973 Metetra
.658 .743 .912 r
.85022 .45973 .85388 .46472 .86285 .46209 .85922 .45709 Metetra
.659 .744 .913 r
.85922 .45709 .86285 .46209 .87185 .45943 .86824 .45443 Metetra
.66 .745 .913 r
.86824 .45443 .87185 .45943 .88088 .45674 .87729 .45173 Metetra
.661 .745 .912 r
.87729 .45173 .88088 .45674 .88993 .45402 .88636 .44899 Metetra
.662 .746 .912 r
.88636 .44899 .88993 .45402 .89901 .45127 .89546 .44622 Metetra
.663 .746 .912 r
.89546 .44622 .89901 .45127 .90812 .4485 .90458 .44343 Metetra
.663 .746 .911 r
.90458 .44343 .90812 .4485 .91725 .44572 .91374 .44063 Metetra
.663 .745 .911 r
.91374 .44063 .91725 .44572 .92641 .44293 .92292 .43782 Metetra
.662 .745 .911 r
.92292 .43782 .92641 .44293 .9356 .44015 .93213 .43502 Metetra
.662 .744 .911 r
.93213 .43502 .9356 .44015 .94482 .43736 .94137 .43221 Metetra
.662 .744 .911 r
.94137 .43221 .94482 .43736 .95407 .43457 .95064 .4294 Metetra
.661 .744 .912 r
.36778 .59972 .3724 .60394 .37997 .60166 .37536 .59742 Metetra
.661 .744 .912 r
.37536 .59742 .37997 .60166 .38757 .59937 .38297 .59512 Metetra
.661 .744 .912 r
.38297 .59512 .38757 .59937 .39519 .59708 .3906 .59282 Metetra
.661 .744 .912 r
.3906 .59282 .39519 .59708 .40282 .59479 .39825 .59052 Metetra
.66 .744 .912 r
.39825 .59052 .40282 .59479 .41048 .5925 .40593 .58821 Metetra
.66 .744 .912 r
.40593 .58821 .41048 .5925 .41816 .5902 .41362 .5859 Metetra
.661 .744 .912 r
.41362 .5859 .41816 .5902 .42587 .58789 .42134 .58358 Metetra
.661 .744 .912 r
.42134 .58358 .42587 .58789 .43359 .58556 .42908 .58123 Metetra
.662 .744 .911 r
.42908 .58123 .43359 .58556 .44134 .5832 .43684 .57887 Metetra
.663 .745 .911 r
.43684 .57887 .44134 .5832 .44911 .58082 .44463 .57648 Metetra
.664 .745 .911 r
.44463 .57648 .44911 .58082 .4569 .57843 .45243 .57407 Metetra
.664 .745 .91 r
.45243 .57407 .4569 .57843 .46472 .57601 .46026 .57164 Metetra
.664 .745 .91 r
.46026 .57164 .46472 .57601 .47256 .57359 .46812 .5692 Metetra
.664 .745 .91 r
.46812 .5692 .47256 .57359 .48042 .57115 .47599 .56675 Metetra
.664 .745 .911 r
.47599 .56675 .48042 .57115 .4883 .56873 .48389 .56432 Metetra
.662 .744 .911 r
.48389 .56432 .4883 .56873 .49621 .56634 .49181 .56191 Metetra
.659 .744 .913 r
.49181 .56191 .49621 .56634 .50413 .56399 .49975 .55956 Metetra
.656 .743 .914 r
.49975 .55956 .50413 .56399 .51208 .56171 .50771 .55726 Metetra
.653 .742 .915 r
.50771 .55726 .51208 .56171 .52006 .55947 .5157 .55501 Metetra
.652 .742 .915 r
.5157 .55501 .52006 .55947 .52806 .55725 .52372 .55277 Metetra
.652 .741 .915 r
.52372 .55277 .52806 .55725 .53608 .55502 .53175 .55053 Metetra
.653 .742 .915 r
.53175 .55053 .53608 .55502 .54412 .55276 .53982 .54826 Metetra
.656 .743 .914 r
.53982 .54826 .54412 .55276 .55219 .55044 .5479 .54592 Metetra
.661 .744 .912 r
.5479 .54592 .55219 .55044 .56029 .54801 .55601 .54348 Metetra
.668 .746 .909 r
.55601 .54348 .56029 .54801 .5684 .54542 .56414 .54088 Metetra
.676 .748 .906 r
.56414 .54088 .5684 .54542 .57654 .54264 .57229 .53808 Metetra
.684 .751 .902 r
.57229 .53808 .57654 .54264 .58469 .53966 .58046 .53509 Metetra
.691 .753 .899 r
.58046 .53509 .58469 .53966 .59287 .53651 .58865 .53193 Metetra
.694 .754 .898 r
.58865 .53193 .59287 .53651 .60106 .53326 .59686 .52868 Metetra
.696 .755 .897 r
.59686 .52868 .60106 .53326 .60927 .52997 .60509 .52537 Metetra
.695 .755 .897 r
.60509 .52537 .60927 .52997 .6175 .52669 .61334 .52208 Metetra
.692 .754 .899 r
.61334 .52208 .6175 .52669 .62576 .52349 .62161 .51887 Metetra
.685 .752 .902 r
.62161 .51887 .62576 .52349 .63404 .52044 .62991 .51581 Metetra
.676 .749 .907 r
.62991 .51581 .63404 .52044 .64235 .51761 .63824 .51297 Metetra
.663 .745 .912 r
.63824 .51297 .64235 .51761 .65069 .51506 .6466 .51041 Metetra
.649 .741 .916 r
.6466 .51041 .65069 .51506 .65907 .5128 .655 .50813 Metetra
.637 .737 .92 r
.655 .50813 .65907 .5128 .66749 .51077 .66343 .50609 Metetra
.628 .733 .923 r
.66343 .50609 .66749 .51077 .67595 .50891 .67191 .50421 Metetra
.622 .731 .924 r
.67191 .50421 .67595 .50891 .68444 .50716 .68041 .50244 Metetra
.621 .73 .925 r
.68041 .50244 .68444 .50716 .69295 .50543 .68895 .50069 Metetra
.622 .73 .924 r
.68895 .50069 .69295 .50543 .7015 .50367 .69751 .49892 Metetra
.627 .732 .923 r
.69751 .49892 .7015 .50367 .71008 .50182 .7061 .49705 Metetra
.634 .735 .92 r
.7061 .49705 .71008 .50182 .71867 .49981 .71471 .49502 Metetra
.645 .738 .917 r
.71471 .49502 .71867 .49981 .72728 .49758 .72334 .49277 Metetra
.654 .742 .914 r
.72334 .49277 .72728 .49758 .7359 .49514 .73198 .49032 Metetra
.662 .744 .911 r
.73198 .49032 .7359 .49514 .74454 .49253 .74064 .48769 Metetra
.667 .746 .909 r
.74064 .48769 .74454 .49253 .7532 .48979 .74932 .48493 Metetra
.67 .747 .908 r
.74932 .48493 .7532 .48979 .76188 .48696 .75801 .48209 Metetra
.672 .748 .908 r
.75801 .48209 .76188 .48696 .77058 .48409 .76673 .47921 Metetra
.672 .748 .908 r
.76673 .47921 .77058 .48409 .77931 .48122 .77548 .47632 Metetra
.671 .748 .908 r
.77548 .47632 .77931 .48122 .78806 .47836 .78425 .47345 Metetra
.668 .747 .909 r
.78425 .47345 .78806 .47836 .79685 .47556 .79306 .47063 Metetra
.664 .745 .911 r
.79306 .47063 .79685 .47556 .80566 .47283 .80189 .46789 Metetra
.661 .744 .912 r
.80189 .46789 .80566 .47283 .81452 .47016 .81076 .46521 Metetra
.659 .743 .912 r
.81076 .46521 .81452 .47016 .8234 .46754 .81967 .46258 Metetra
.657 .743 .913 r
.81967 .46258 .8234 .46754 .83231 .46495 .8286 .45996 Metetra
.657 .743 .913 r
.8286 .45996 .83231 .46495 .84125 .46235 .83756 .45735 Metetra
.658 .743 .913 r
.83756 .45735 .84125 .46235 .85022 .45973 .84655 .45471 Metetra
.658 .743 .913 r
.84655 .45471 .85022 .45973 .85922 .45709 .85556 .45206 Metetra
.659 .743 .912 r
.85556 .45206 .85922 .45709 .86824 .45443 .86461 .44938 Metetra
.66 .744 .912 r
.86461 .44938 .86824 .45443 .87729 .45173 .87367 .44667 Metetra
.661 .744 .912 r
.87367 .44667 .87729 .45173 .88636 .44899 .88277 .44391 Metetra
.662 .745 .911 r
.88277 .44391 .88636 .44899 .89546 .44622 .89189 .44113 Metetra
.663 .745 .911 r
.89189 .44113 .89546 .44622 .90458 .44343 .90103 .43832 Metetra
.663 .745 .911 r
.90103 .43832 .90458 .44343 .91374 .44063 .9102 .4355 Metetra
.663 .745 .911 r
.9102 .4355 .91374 .44063 .92292 .43782 .91941 .43268 Metetra
.662 .745 .911 r
.91941 .43268 .92292 .43782 .93213 .43502 .92864 .42986 Metetra
.662 .745 .911 r
.92864 .42986 .93213 .43502 .94137 .43221 .9379 .42704 Metetra
.662 .744 .911 r
.9379 .42704 .94137 .43221 .95064 .4294 .94719 .42421 Metetra
.661 .744 .912 r
.36313 .59547 .36778 .59972 .37536 .59742 .37073 .59316 Metetra
.661 .744 .912 r
.37073 .59316 .37536 .59742 .38297 .59512 .37835 .59085 Metetra
.661 .744 .912 r
.37835 .59085 .38297 .59512 .3906 .59282 .38599 .58854 Metetra
.661 .744 .912 r
.38599 .58854 .3906 .59282 .39825 .59052 .39366 .58622 Metetra
.661 .744 .912 r
.39366 .58622 .39825 .59052 .40593 .58821 .40135 .5839 Metetra
.661 .744 .912 r
.40135 .5839 .40593 .58821 .41362 .5859 .40905 .58157 Metetra
.661 .744 .911 r
.40905 .58157 .41362 .5859 .42134 .58358 .41679 .57923 Metetra
.661 .744 .911 r
.41679 .57923 .42134 .58358 .42908 .58123 .42454 .57688 Metetra
.662 .744 .911 r
.42454 .57688 .42908 .58123 .43684 .57887 .43232 .5745 Metetra
.663 .744 .911 r
.43232 .5745 .43684 .57887 .44463 .57648 .44012 .5721 Metetra
.663 .745 .911 r
.44012 .5721 .44463 .57648 .45243 .57407 .44794 .56969 Metetra
.663 .745 .911 r
.44794 .56969 .45243 .57407 .46026 .57164 .45578 .56726 Metetra
.664 .746 .911 r
.45578 .56726 .46026 .57164 .46812 .5692 .46365 .56482 Metetra
.664 .746 .912 r
.46365 .56482 .46812 .5692 .47599 .56675 .47154 .56238 Metetra
.663 .747 .912 r
.47154 .56238 .47599 .56675 .48389 .56432 .47945 .55994 Metetra
.661 .747 .913 r
.47945 .55994 .48389 .56432 .49181 .56191 .48738 .55752 Metetra
.659 .746 .914 r
.48738 .55752 .49181 .56191 .49975 .55956 .49534 .55514 Metetra
.657 .745 .915 r
.49534 .55514 .49975 .55956 .50771 .55726 .50332 .55281 Metetra
.655 .743 .915 r
.50332 .55281 .50771 .55726 .5157 .55501 .51133 .55051 Metetra
.654 .741 .914 r
.51133 .55051 .5157 .55501 .52372 .55277 .51935 .54822 Metetra
.654 .74 .912 r
.51935 .54822 .52372 .55277 .53175 .55053 .52741 .54592 Metetra
.655 .738 .911 r
.52741 .54592 .53175 .55053 .53982 .54826 .53548 .54361 Metetra
.657 .737 .909 r
.53548 .54361 .53982 .54826 .5479 .54592 .54358 .54123 Metetra
.661 .738 .906 r
.54358 .54123 .5479 .54592 .55601 .54348 .55171 .53877 Metetra
.667 .739 .904 r
.55171 .53877 .55601 .54348 .56414 .54088 .55985 .53619 Metetra
.673 .742 .903 r
.55985 .53619 .56414 .54088 .57229 .53808 .56802 .53345 Metetra
.68 .747 .902 r
.56802 .53345 .57229 .53808 .58046 .53509 .57621 .53054 Metetra
.685 .753 .903 r
.57621 .53054 .58046 .53509 .58865 .53193 .58442 .52751 Metetra
.689 .76 .906 r
.58442 .52751 .58865 .53193 .59686 .52868 .59265 .5244 Metetra
.69 .768 .911 r
.59265 .5244 .59686 .52868 .60509 .52537 .6009 .52124 Metetra
.69 .776 .917 r
.6009 .52124 .60509 .52537 .61334 .52208 .60917 .5181 Metetra
.686 .782 .924 r
.60917 .5181 .61334 .52208 .62161 .51887 .61747 .51502 Metetra
.68 .788 .931 r
.61747 .51502 .62161 .51887 .62991 .51581 .62579 .51205 Metetra
.67 .791 .939 r
.62579 .51205 .62991 .51581 .63824 .51297 .63414 .50926 Metetra
.658 .79 .945 r
.63414 .50926 .63824 .51297 .6466 .51041 .64252 .50669 Metetra
.644 .786 .95 r
.64252 .50669 .6466 .51041 .655 .50813 .65094 .50434 Metetra
.634 .78 .951 r
.65094 .50434 .655 .50813 .66343 .50609 .65939 .50218 Metetra
.627 .772 .95 r
.65939 .50218 .66343 .50609 .67191 .50421 .66787 .50015 Metetra
.624 .764 .946 r
.66787 .50015 .67191 .50421 .68041 .50244 .67638 .4982 Metetra
.624 .756 .941 r
.67638 .4982 .68041 .50244 .68895 .50069 .68493 .49628 Metetra
.628 .749 .934 r
.68493 .49628 .68895 .50069 .69751 .49892 .6935 .49432 Metetra
.633 .743 .927 r
.6935 .49432 .69751 .49892 .7061 .49705 .7021 .49229 Metetra
.64 .739 .92 r
.7021 .49229 .7061 .49705 .71471 .49502 .71073 .49013 Metetra
.648 .736 .914 r
.71073 .49013 .71471 .49502 .72334 .49277 .71937 .4878 Metetra
.656 .736 .909 r
.71937 .4878 .72334 .49277 .73198 .49032 .72802 .4853 Metetra
.662 .737 .905 r
.72802 .4853 .73198 .49032 .74064 .48769 .7367 .48266 Metetra
.666 .738 .904 r
.7367 .48266 .74064 .48769 .74932 .48493 .7454 .47991 Metetra
.668 .74 .904 r
.7454 .47991 .74932 .48493 .75801 .48209 .75412 .47709 Metetra
.67 .743 .905 r
.75412 .47709 .75801 .48209 .76673 .47921 .76286 .47425 Metetra
.67 .745 .907 r
.76286 .47425 .76673 .47921 .77548 .47632 .77163 .47139 Metetra
.669 .746 .909 r
.77163 .47139 .77548 .47632 .78425 .47345 .78042 .46855 Metetra
.666 .747 .911 r
.78042 .46855 .78425 .47345 .79306 .47063 .78925 .46574 Metetra
.664 .748 .913 r
.78925 .46574 .79306 .47063 .80189 .46789 .79811 .463 Metetra
.661 .747 .914 r
.79811 .463 .80189 .46789 .81076 .46521 .80699 .4603 Metetra
.659 .747 .915 r
.80699 .4603 .81076 .46521 .81967 .46258 .81592 .45764 Metetra
.658 .746 .915 r
.81592 .45764 .81967 .46258 .8286 .45996 .82487 .45499 Metetra
.658 .745 .914 r
.82487 .45499 .8286 .45996 .83756 .45735 .83385 .45234 Metetra
.658 .744 .913 r
.83385 .45234 .83756 .45735 .84655 .45471 .84285 .44968 Metetra
.659 .743 .913 r
.84285 .44968 .84655 .45471 .85556 .45206 .85189 .44699 Metetra
.659 .743 .912 r
.85189 .44699 .85556 .45206 .86461 .44938 .86095 .44429 Metetra
.66 .743 .911 r
.86095 .44429 .86461 .44938 .87367 .44667 .87004 .44155 Metetra
.661 .743 .911 r
.87004 .44155 .87367 .44667 .88277 .44391 .87915 .43878 Metetra
.662 .743 .91 r
.87915 .43878 .88277 .44391 .89189 .44113 .88829 .43598 Metetra
.663 .744 .91 r
.88829 .43598 .89189 .44113 .90103 .43832 .89746 .43317 Metetra
.663 .744 .911 r
.89746 .43317 .90103 .43832 .9102 .4355 .90665 .43034 Metetra
.662 .744 .911 r
.90665 .43034 .9102 .4355 .91941 .43268 .91588 .42751 Metetra
.662 .745 .911 r
.91588 .42751 .91941 .43268 .92864 .42986 .92513 .42468 Metetra
.662 .745 .911 r
.92513 .42468 .92864 .42986 .9379 .42704 .93441 .42184 Metetra
.662 .745 .912 r
.93441 .42184 .9379 .42704 .94719 .42421 .94373 .419 Metetra
.661 .744 .912 r
.35846 .59121 .36313 .59547 .37073 .59316 .36607 .58889 Metetra
.661 .744 .912 r
.36607 .58889 .37073 .59316 .37835 .59085 .37371 .58656 Metetra
.661 .744 .912 r
.37371 .58656 .37835 .59085 .38599 .58854 .38136 .58423 Metetra
.661 .744 .912 r
.38136 .58423 .38599 .58854 .39366 .58622 .38904 .58189 Metetra
.661 .744 .911 r
.38904 .58189 .39366 .58622 .40135 .5839 .39674 .57955 Metetra
.661 .744 .911 r
.39674 .57955 .40135 .5839 .40905 .58157 .40446 .5772 Metetra
.661 .743 .911 r
.40446 .5772 .40905 .58157 .41679 .57923 .41221 .57485 Metetra
.661 .743 .911 r
.41221 .57485 .41679 .57923 .42454 .57688 .41998 .57248 Metetra
.662 .743 .91 r
.41998 .57248 .42454 .57688 .43232 .5745 .42777 .5701 Metetra
.662 .743 .91 r
.42777 .5701 .43232 .5745 .44012 .5721 .43558 .5677 Metetra
.662 .744 .911 r
.43558 .5677 .44012 .5721 .44794 .56969 .44342 .56529 Metetra
.662 .745 .911 r
.44342 .56529 .44794 .56969 .45578 .56726 .45128 .56288 Metetra
.662 .746 .912 r
.45128 .56288 .45578 .56726 .46365 .56482 .45916 .56045 Metetra
.662 .747 .913 r
.45916 .56045 .46365 .56482 .47154 .56238 .46706 .55801 Metetra
.662 .748 .914 r
.46706 .55801 .47154 .56238 .47945 .55994 .47499 .55558 Metetra
.661 .749 .915 r
.47499 .55558 .47945 .55994 .48738 .55752 .48294 .55315 Metetra
.66 .749 .916 r
.48294 .55315 .48738 .55752 .49534 .55514 .49091 .55074 Metetra
.659 .747 .915 r
.49091 .55074 .49534 .55514 .50332 .55281 .4989 .54835 Metetra
.658 .745 .914 r
.4989 .54835 .50332 .55281 .51133 .55051 .50692 .54597 Metetra
.658 .742 .912 r
.50692 .54597 .51133 .55051 .51935 .54822 .51497 .54359 Metetra
.658 .738 .909 r
.51497 .54359 .51935 .54822 .52741 .54592 .52303 .5412 Metetra
.659 .735 .906 r
.52303 .5412 .52741 .54592 .53548 .54361 .53113 .5388 Metetra
.66 .733 .904 r
.53113 .5388 .53548 .54361 .54358 .54123 .53924 .53637 Metetra
.661 .731 .901 r
.53924 .53637 .54358 .54123 .55171 .53877 .54738 .53389 Metetra
.664 .732 .9 r
.54738 .53389 .55171 .53877 .55985 .53619 .55554 .53135 Metetra
.667 .735 .901 r
.55554 .53135 .55985 .53619 .56802 .53345 .56373 .52873 Metetra
.671 .742 .904 r
.56373 .52873 .56802 .53345 .57621 .53054 .57194 .52602 Metetra
.673 .752 .91 r
.57194 .52602 .57621 .53054 .58442 .52751 .58017 .52325 Metetra
.675 .765 .919 r
.58017 .52325 .58442 .52751 .59265 .5244 .58842 .52043 Metetra
.675 .78 .929 r
.58842 .52043 .59265 .5244 .6009 .52124 .5967 .51759 Metetra
.673 .796 .94 r
.5967 .51759 .6009 .52124 .60917 .5181 .605 .51474 Metetra
.668 .811 .952 r
.605 .51474 .60917 .5181 .61747 .51502 .61332 .51193 Metetra
.661 .825 .962 r
.61332 .51193 .61747 .51502 .62579 .51205 .62167 .50917 Metetra
.651 .834 .971 r
.62167 .50917 .62579 .51205 .63414 .50926 .63005 .50649 Metetra
.641 .838 .976 r
.63005 .50649 .63414 .50926 .64252 .50669 .63845 .50392 Metetra
.633 .836 .979 r
.63845 .50392 .64252 .50669 .65094 .50434 .64688 .50145 Metetra
.629 .829 .977 r
.64688 .50145 .65094 .50434 .65939 .50218 .65535 .49907 Metetra
.63 .817 .972 r
.65535 .49907 .65939 .50218 .66787 .50015 .66384 .49675 Metetra
.633 .803 .964 r
.66384 .49675 .66787 .50015 .67638 .4982 .67236 .49446 Metetra
.637 .787 .954 r
.67236 .49446 .67638 .4982 .68493 .49628 .68091 .49218 Metetra
.642 .771 .942 r
.68091 .49218 .68493 .49628 .6935 .49432 .68949 .48989 Metetra
.646 .757 .929 r
.68949 .48989 .6935 .49432 .7021 .49229 .69809 .48755 Metetra
.651 .744 .918 r
.69809 .48755 .7021 .49229 .71073 .49013 .70671 .48515 Metetra
.655 .736 .909 r
.70671 .48515 .71073 .49013 .71937 .4878 .71536 .48265 Metetra
.659 .731 .903 r
.71536 .48265 .71937 .4878 .72802 .4853 .72404 .48007 Metetra
.662 .729 .9 r
.72404 .48007 .72802 .4853 .7367 .48266 .73273 .47742 Metetra
.664 .73 .899 r
.73273 .47742 .7367 .48266 .7454 .47991 .74145 .47471 Metetra
.665 .733 .9 r
.74145 .47471 .7454 .47991 .75412 .47709 .75019 .47196 Metetra
.665 .737 .903 r
.75019 .47196 .75412 .47709 .76286 .47425 .75896 .46919 Metetra
.666 .741 .906 r
.75896 .46919 .76286 .47425 .77163 .47139 .76775 .46642 Metetra
.665 .745 .909 r
.76775 .46642 .77163 .47139 .78042 .46855 .77657 .46364 Metetra
.664 .748 .913 r
.77657 .46364 .78042 .46855 .78925 .46574 .78542 .46088 Metetra
.662 .75 .915 r
.78542 .46088 .78925 .46574 .79811 .463 .7943 .45815 Metetra
.661 .751 .917 r
.7943 .45815 .79811 .463 .80699 .4603 .80321 .45544 Metetra
.66 .75 .917 r
.80321 .45544 .80699 .4603 .81592 .45764 .81215 .45273 Metetra
.66 .749 .916 r
.81215 .45273 .81592 .45764 .82487 .45499 .82112 .45004 Metetra
.66 .747 .915 r
.82112 .45004 .82487 .45499 .83385 .45234 .83011 .44733 Metetra
.66 .746 .914 r
.83011 .44733 .83385 .45234 .84285 .44968 .83914 .44461 Metetra
.66 .744 .912 r
.83914 .44461 .84285 .44968 .85189 .44699 .84819 .44188 Metetra
.66 .743 .911 r
.84819 .44188 .85189 .44699 .86095 .44429 .85727 .43914 Metetra
.661 .742 .91 r
.85727 .43914 .86095 .44429 .87004 .44155 .86637 .43637 Metetra
.661 .742 .91 r
.86637 .43637 .87004 .44155 .87915 .43878 .87551 .43359 Metetra
.662 .742 .91 r
.87551 .43359 .87915 .43878 .88829 .43598 .88467 .43078 Metetra
.662 .742 .91 r
.88467 .43078 .88829 .43598 .89746 .43317 .89386 .42797 Metetra
.662 .743 .91 r
.89386 .42797 .89746 .43317 .90665 .43034 .90308 .42514 Metetra
.662 .744 .911 r
.90308 .42514 .90665 .43034 .91588 .42751 .91232 .42231 Metetra
.662 .744 .911 r
.91232 .42231 .91588 .42751 .92513 .42468 .9216 .41947 Metetra
.662 .745 .912 r
.9216 .41947 .92513 .42468 .93441 .42184 .93091 .41662 Metetra
.662 .745 .912 r
.93091 .41662 .93441 .42184 .94373 .419 .94024 .41377 Metetra
.661 .745 .912 r
.35376 .58692 .35846 .59121 .36607 .58889 .36139 .58459 Metetra
.661 .745 .912 r
.36139 .58459 .36607 .58889 .37371 .58656 .36904 .58225 Metetra
.661 .744 .912 r
.36904 .58225 .37371 .58656 .38136 .58423 .37671 .5799 Metetra
.661 .744 .911 r
.37671 .5799 .38136 .58423 .38904 .58189 .3844 .57754 Metetra
.662 .744 .911 r
.3844 .57754 .38904 .58189 .39674 .57955 .39211 .57518 Metetra
.662 .743 .911 r
.39211 .57518 .39674 .57955 .40446 .5772 .39985 .57281 Metetra
.662 .743 .91 r
.39985 .57281 .40446 .5772 .41221 .57485 .40761 .57043 Metetra
.661 .743 .91 r
.40761 .57043 .41221 .57485 .41998 .57248 .41539 .56805 Metetra
.661 .743 .91 r
.41539 .56805 .41998 .57248 .42777 .5701 .4232 .56566 Metetra
.661 .743 .911 r
.4232 .56566 .42777 .5701 .43558 .5677 .43102 .56327 Metetra
.661 .744 .911 r
.43102 .56327 .43558 .5677 .44342 .56529 .43887 .56088 Metetra
.661 .745 .912 r
.43887 .56088 .44342 .56529 .45128 .56288 .44674 .55848 Metetra
.661 .746 .913 r
.44674 .55848 .45128 .56288 .45916 .56045 .45464 .55607 Metetra
.661 .748 .914 r
.45464 .55607 .45916 .56045 .46706 .55801 .46256 .55366 Metetra
.661 .749 .916 r
.46256 .55366 .46706 .55801 .47499 .55558 .4705 .55123 Metetra
.661 .75 .916 r
.4705 .55123 .47499 .55558 .48294 .55315 .47846 .5488 Metetra
.661 .751 .916 r
.47846 .5488 .48294 .55315 .49091 .55074 .48645 .54634 Metetra
.662 .749 .915 r
.48645 .54634 .49091 .55074 .4989 .54835 .49446 .54387 Metetra
.663 .747 .913 r
.49446 .54387 .4989 .54835 .50692 .54597 .5025 .54139 Metetra
.663 .743 .909 r
.5025 .54139 .50692 .54597 .51497 .54359 .51056 .53889 Metetra
.663 .738 .906 r
.51056 .53889 .51497 .54359 .52303 .5412 .51864 .53639 Metetra
.663 .734 .902 r
.51864 .53639 .52303 .5412 .53113 .5388 .52675 .53388 Metetra
.662 .73 .899 r
.52675 .53388 .53113 .5388 .53924 .53637 .53488 .53137 Metetra
.662 .727 .898 r
.53488 .53137 .53924 .53637 .54738 .53389 .54303 .52888 Metetra
.661 .726 .898 r
.54303 .52888 .54738 .53389 .55554 .53135 .55121 .5264 Metetra
.659 .729 .901 r
.55121 .5264 .55554 .53135 .56373 .52873 .55941 .52394 Metetra
.658 .736 .908 r
.55941 .52394 .56373 .52873 .57194 .52602 .56764 .5215 Metetra
.656 .748 .918 r
.56764 .5215 .57194 .52602 .58017 .52325 .57589 .51908 Metetra
.654 .765 .931 r
.57589 .51908 .58017 .52325 .58842 .52043 .58417 .51667 Metetra
.65 .785 .946 r
.58417 .51667 .58842 .52043 .5967 .51759 .59248 .51426 Metetra
.644 .806 .961 r
.59248 .51426 .5967 .51759 .605 .51474 .60081 .51184 Metetra
.636 .828 .974 r
.60081 .51184 .605 .51474 .61332 .51193 .60916 .50939 Metetra
.627 .847 .984 r
.60916 .50939 .61332 .51193 .62167 .50917 .61754 .50691 Metetra
.619 .861 .989 r
.61754 .50691 .62167 .50917 .63005 .50649 .62594 .50439 Metetra
.616 .869 .99 r
.62594 .50439 .63005 .50649 .63845 .50392 .63437 .50182 Metetra
.619 .871 .99 r
.63437 .50182 .63845 .50392 .64688 .50145 .64283 .49919 Metetra
.628 .866 .987 r
.64283 .49919 .64688 .50145 .65535 .49907 .6513 .49651 Metetra
.64 .853 .981 r
.6513 .49651 .65535 .49907 .66384 .49675 .6598 .4938 Metetra
.651 .835 .971 r
.6598 .4938 .66384 .49675 .67236 .49446 .66833 .49107 Metetra
.659 .813 .958 r
.66833 .49107 .67236 .49446 .68091 .49218 .67687 .48832 Metetra
.663 .791 .942 r
.67687 .48832 .68091 .49218 .68949 .48989 .68545 .48556 Metetra
.665 .769 .927 r
.68545 .48556 .68949 .48989 .69809 .48755 .69405 .48281 Metetra
.665 .751 .914 r
.69405 .48281 .69809 .48755 .70671 .48515 .70268 .48008 Metetra
.664 .737 .904 r
.70268 .48008 .70671 .48515 .71536 .48265 .71133 .47737 Metetra
.663 .728 .898 r
.71133 .47737 .71536 .48265 .72404 .48007 .72002 .47469 Metetra
.662 .724 .896 r
.72002 .47469 .72404 .48007 .73273 .47742 .72873 .47203 Metetra
.661 .724 .896 r
.72873 .47203 .73273 .47742 .74145 .47471 .73747 .46937 Metetra
.66 .727 .899 r
.73747 .46937 .74145 .47471 .75019 .47196 .74624 .46672 Metetra
.66 .731 .902 r
.74624 .46672 .75019 .47196 .75896 .46919 .75503 .46407 Metetra
.66 .737 .907 r
.75503 .46407 .75896 .46919 .76775 .46642 .76385 .46141 Metetra
.66 .742 .911 r
.76385 .46141 .76775 .46642 .77657 .46364 .7727 .45873 Metetra
.66 .747 .915 r
.7727 .45873 .77657 .46364 .78542 .46088 .78158 .45604 Metetra
.661 .751 .917 r
.78158 .45604 .78542 .46088 .7943 .45815 .79048 .45333 Metetra
.661 .753 .918 r
.79048 .45333 .7943 .45815 .80321 .45544 .79941 .45059 Metetra
.661 .753 .918 r
.79941 .45059 .80321 .45544 .81215 .45273 .80837 .44784 Metetra
.662 .752 .917 r
.80837 .44784 .81215 .45273 .82112 .45004 .81735 .44508 Metetra
.662 .749 .915 r
.81735 .44508 .82112 .45004 .83011 .44733 .82636 .4423 Metetra
.662 .747 .913 r
.82636 .4423 .83011 .44733 .83914 .44461 .8354 .43952 Metetra
.662 .745 .912 r
.8354 .43952 .83914 .44461 .84819 .44188 .84447 .43674 Metetra
.662 .743 .91 r
.84447 .43674 .84819 .44188 .85727 .43914 .85356 .43394 Metetra
.662 .742 .909 r
.85356 .43394 .85727 .43914 .86637 .43637 .86269 .43115 Metetra
.661 .741 .909 r
.86269 .43115 .86637 .43637 .87551 .43359 .87184 .42834 Metetra
.661 .741 .909 r
.87184 .42834 .87551 .43359 .88467 .43078 .88103 .42554 Metetra
.661 .741 .909 r
.88103 .42554 .88467 .43078 .89386 .42797 .89024 .42272 Metetra
.661 .742 .91 r
.89024 .42272 .89386 .42797 .90308 .42514 .89948 .4199 Metetra
.661 .743 .911 r
.89948 .4199 .90308 .42514 .91232 .42231 .90875 .41707 Metetra
.661 .744 .911 r
.90875 .41707 .91232 .42231 .9216 .41947 .91805 .41423 Metetra
.661 .745 .912 r
.91805 .41423 .9216 .41947 .93091 .41662 .92738 .41138 Metetra
.661 .745 .912 r
.92738 .41138 .93091 .41662 .94024 .41377 .93674 .40851 Metetra
.661 .745 .912 r
.34904 .58262 .35376 .58692 .36139 .58459 .35668 .58027 Metetra
.662 .745 .912 r
.35668 .58027 .36139 .58459 .36904 .58225 .36434 .57791 Metetra
.662 .744 .912 r
.36434 .57791 .36904 .58225 .37671 .5799 .37203 .57554 Metetra
.662 .744 .911 r
.37203 .57554 .37671 .5799 .3844 .57754 .37973 .57317 Metetra
.662 .744 .911 r
.37973 .57317 .3844 .57754 .39211 .57518 .38746 .57078 Metetra
.662 .743 .91 r
.38746 .57078 .39211 .57518 .39985 .57281 .39521 .56838 Metetra
.662 .743 .91 r
.39521 .56838 .39985 .57281 .40761 .57043 .40299 .56598 Metetra
.661 .742 .91 r
.40299 .56598 .40761 .57043 .41539 .56805 .41078 .56359 Metetra
.661 .742 .91 r
.41078 .56359 .41539 .56805 .4232 .56566 .4186 .5612 Metetra
.66 .742 .911 r
.4186 .5612 .4232 .56566 .43102 .56327 .42644 .55882 Metetra
.66 .743 .912 r
.42644 .55882 .43102 .56327 .43887 .56088 .4343 .55644 Metetra
.659 .744 .913 r
.4343 .55644 .43887 .56088 .44674 .55848 .44219 .55406 Metetra
.659 .746 .914 r
.44219 .55406 .44674 .55848 .45464 .55607 .4501 .55168 Metetra
.659 .748 .916 r
.4501 .55168 .45464 .55607 .46256 .55366 .45803 .54929 Metetra
.659 .75 .917 r
.45803 .54929 .46256 .55366 .4705 .55123 .46599 .54688 Metetra
.661 .751 .917 r
.46599 .54688 .4705 .55123 .47846 .5488 .47397 .54444 Metetra
.663 .752 .916 r
.47397 .54444 .47846 .5488 .48645 .54634 .48197 .54194 Metetra
.665 .751 .914 r
.48197 .54194 .48645 .54634 .49446 .54387 .49 .53939 Metetra
.668 .748 .911 r
.49 .53939 .49446 .54387 .5025 .54139 .49805 .53678 Metetra
.668 .744 .907 r
.49805 .53678 .5025 .54139 .51056 .53889 .50613 .53415 Metetra
.668 .739 .903 r
.50613 .53415 .51056 .53889 .51864 .53639 .51422 .53151 Metetra
.668 .734 .899 r
.51422 .53151 .51864 .53639 .52675 .53388 .52234 .52889 Metetra
.665 .729 .897 r
.52234 .52889 .52675 .53388 .53488 .53137 .53049 .5263 Metetra
.662 .725 .896 r
.53049 .5263 .53488 .53137 .54303 .52888 .53866 .52378 Metetra
.657 .723 .897 r
.53866 .52378 .54303 .52888 .55121 .5264 .54685 .52137 Metetra
.65 .724 .903 r
.54685 .52137 .55121 .5264 .55941 .52394 .55507 .5191 Metetra
.642 .73 .912 r
.55507 .5191 .55941 .52394 .56764 .5215 .56332 .51698 Metetra
.634 .742 .926 r
.56332 .51698 .56764 .5215 .57589 .51908 .57159 .51497 Metetra
.626 .76 .942 r
.57159 .51497 .57589 .51908 .58417 .51667 .5799 .51302 Metetra
.617 .781 .96 r
.5799 .51302 .58417 .51667 .59248 .51426 .58823 .5111 Metetra
.607 .806 .976 r
.58823 .5111 .59248 .51426 .60081 .51184 .59659 .50916 Metetra
.596 .83 .988 r
.59659 .50916 .60081 .51184 .60916 .50939 .60498 .50714 Metetra
.587 .852 .994 r
.60498 .50714 .60916 .50939 .61754 .50691 .61339 .50499 Metetra
.585 .869 .994 r
.61339 .50499 .61754 .50691 .62594 .50439 .62183 .50265 Metetra
.595 .882 .992 r
.62183 .50265 .62594 .50439 .63437 .50182 .63028 .50008 Metetra
.614 .89 .989 r
.63028 .50008 .63437 .50182 .64283 .49919 .63875 .49727 Metetra
.638 .888 .986 r
.63875 .49727 .64283 .49919 .6513 .49651 .64724 .49426 Metetra
.66 .877 .979 r
.64724 .49426 .6513 .49651 .6598 .4938 .65575 .4911 Metetra
.677 .857 .968 r
.65575 .4911 .6598 .4938 .66833 .49107 .66427 .48785 Metetra
.686 .832 .953 r
.66427 .48785 .66833 .49107 .67687 .48832 .67282 .48456 Metetra
.688 .805 .937 r
.67282 .48456 .67687 .48832 .68545 .48556 .68139 .48129 Metetra
.686 .779 .922 r
.68139 .48129 .68545 .48556 .69405 .48281 .68999 .47807 Metetra
.681 .757 .909 r
.68999 .47807 .69405 .48281 .70268 .48008 .69862 .47496 Metetra
.674 .739 .9 r
.69862 .47496 .70268 .48008 .71133 .47737 .70728 .47201 Metetra
.667 .727 .895 r
.70728 .47201 .71133 .47737 .72002 .47469 .71597 .46921 Metetra
.661 .721 .893 r
.71597 .46921 .72002 .47469 .72873 .47203 .7247 .46654 Metetra
.657 .72 .895 r
.7247 .46654 .72873 .47203 .73747 .46937 .73347 .46395 Metetra
.655 .722 .898 r
.73347 .46395 .73747 .46937 .74624 .46672 .74226 .46141 Metetra
.654 .727 .903 r
.74226 .46141 .74624 .46672 .75503 .46407 .75108 .45889 Metetra
.653 .733 .908 r
.75108 .45889 .75503 .46407 .76385 .46141 .75993 .45636 Metetra
.654 .74 .913 r
.75993 .45636 .76385 .46141 .7727 .45873 .76881 .45381 Metetra
.656 .746 .916 r
.76881 .45381 .7727 .45873 .78158 .45604 .77771 .45119 Metetra
.659 .751 .919 r
.77771 .45119 .78158 .45604 .79048 .45333 .78664 .4485 Metetra
.661 .754 .919 r
.78664 .4485 .79048 .45333 .79941 .45059 .79559 .44575 Metetra
.663 .755 .918 r
.79559 .44575 .79941 .45059 .80837 .44784 .80456 .44294 Metetra
.664 .754 .917 r
.80456 .44294 .80837 .44784 .81735 .44508 .81356 .44011 Metetra
.664 .751 .915 r
.81356 .44011 .81735 .44508 .82636 .4423 .82259 .43726 Metetra
.664 .748 .913 r
.82259 .43726 .82636 .4423 .8354 .43952 .83164 .43441 Metetra
.664 .746 .911 r
.83164 .43441 .8354 .43952 .84447 .43674 .84072 .43156 Metetra
.663 .744 .91 r
.84072 .43156 .84447 .43674 .85356 .43394 .84984 .42871 Metetra
.662 .742 .909 r
.84984 .42871 .85356 .43394 .86269 .43115 .85898 .42588 Metetra
.662 .741 .909 r
.85898 .42588 .86269 .43115 .87184 .42834 .86816 .42306 Metetra
.661 .74 .909 r
.86816 .42306 .87184 .42834 .88103 .42554 .87736 .42025 Metetra
.66 .741 .909 r
.87736 .42025 .88103 .42554 .89024 .42272 .8866 .41744 Metetra
.66 .742 .91 r
.8866 .41744 .89024 .42272 .89948 .4199 .89586 .41463 Metetra
.66 .743 .911 r
.89586 .41463 .89948 .4199 .90875 .41707 .90516 .4118 Metetra
.661 .744 .912 r
.90516 .4118 .90875 .41707 .91805 .41423 .91448 .40896 Metetra
.661 .744 .912 r
.91448 .40896 .91805 .41423 .92738 .41138 .92383 .4061 Metetra
.661 .745 .912 r
.92383 .4061 .92738 .41138 .93674 .40851 .93321 .40323 Metetra
.662 .745 .912 r
.34429 .57829 .34904 .58262 .35668 .58027 .35195 .57593 Metetra
.662 .745 .912 r
.35195 .57593 .35668 .58027 .36434 .57791 .35962 .57355 Metetra
.662 .745 .911 r
.35962 .57355 .36434 .57791 .37203 .57554 .36732 .57117 Metetra
.662 .744 .911 r
.36732 .57117 .37203 .57554 .37973 .57317 .37504 .56877 Metetra
.663 .744 .911 r
.37504 .56877 .37973 .57317 .38746 .57078 .38278 .56635 Metetra
.663 .744 .91 r
.38278 .56635 .38746 .57078 .39521 .56838 .39055 .56393 Metetra
.662 .743 .91 r
.39055 .56393 .39521 .56838 .40299 .56598 .39834 .56151 Metetra
.661 .742 .91 r
.39834 .56151 .40299 .56598 .41078 .56359 .40615 .5591 Metetra
.66 .742 .91 r
.40615 .5591 .41078 .56359 .4186 .5612 .41398 .55671 Metetra
.659 .742 .911 r
.41398 .55671 .4186 .5612 .42644 .55882 .42183 .55434 Metetra
.658 .743 .912 r
.42183 .55434 .42644 .55882 .4343 .55644 .42971 .55198 Metetra
.657 .744 .914 r
.42971 .55198 .4343 .55644 .44219 .55406 .43761 .54962 Metetra
.657 .745 .915 r
.43761 .54962 .44219 .55406 .4501 .55168 .44553 .54727 Metetra
.657 .747 .917 r
.44553 .54727 .4501 .55168 .45803 .54929 .45348 .54492 Metetra
.658 .75 .918 r
.45348 .54492 .45803 .54929 .46599 .54688 .46145 .54253 Metetra
.661 .752 .918 r
.46145 .54253 .46599 .54688 .47397 .54444 .46944 .54007 Metetra
.665 .753 .916 r
.46944 .54007 .47397 .54444 .48197 .54194 .47746 .53752 Metetra
.669 .753 .913 r
.47746 .53752 .48197 .54194 .49 .53939 .48551 .53488 Metetra
.673 .75 .909 r
.48551 .53488 .49 .53939 .49805 .53678 .49358 .53214 Metetra
.674 .746 .904 r
.49358 .53214 .49805 .53678 .50613 .53415 .50167 .52937 Metetra
.674 .74 .9 r
.50167 .52937 .50613 .53415 .51422 .53151 .50978 .52659 Metetra
.672 .734 .896 r
.50978 .52659 .51422 .53151 .52234 .52889 .51792 .52383 Metetra
.669 .728 .894 r
.51792 .52383 .52234 .52889 .53049 .5263 .52608 .52115 Metetra
.662 .723 .894 r
.52608 .52115 .53049 .5263 .53866 .52378 .53426 .51861 Metetra
.653 .72 .898 r
.53426 .51861 .53866 .52378 .54685 .52137 .54247 .51629 Metetra
.64 .719 .905 r
.54247 .51629 .54685 .52137 .55507 .5191 .55071 .51422 Metetra
.624 .723 .918 r
.55071 .51422 .55507 .5191 .56332 .51698 .55897 .51244 Metetra
.609 .734 .934 r
.55897 .51244 .56332 .51698 .57159 .51497 .56727 .51088 Metetra
.593 .751 .953 r
.56727 .51088 .57159 .51497 .5799 .51302 .5756 .50945 Metetra
.576 .772 .972 r
.5756 .50945 .5799 .51302 .58823 .5111 .58396 .50807 Metetra
.559 .797 .988 r
.58396 .50807 .58823 .5111 .59659 .50916 .59235 .50666 Metetra
.545 .822 .997 r
.59235 .50666 .59659 .50916 .60498 .50714 .60077 .50511 Metetra
.539 .846 .999 r
.60077 .50511 .60498 .50714 .61339 .50499 .60922 .50332 Metetra
.547 .869 .994 r
.60922 .50332 .61339 .50499 .62183 .50265 .61768 .50118 Metetra
.575 .889 .989 r
.61768 .50118 .62183 .50265 .63028 .50008 .62616 .49861 Metetra
.614 .904 .985 r
.62616 .49861 .63028 .50008 .63875 .49727 .63466 .4956 Metetra
.654 .906 .981 r
.63466 .4956 .63875 .49727 .64724 .49426 .64316 .49223 Metetra
.685 .895 .973 r
.64316 .49223 .64724 .49426 .65575 .4911 .65167 .48858 Metetra
.705 .874 .961 r
.65167 .48858 .65575 .4911 .66427 .48785 .6602 .48477 Metetra
.714 .846 .945 r
.6602 .48477 .66427 .48785 .67282 .48456 .66875 .48089 Metetra
.714 .816 .929 r
.66875 .48089 .67282 .48456 .68139 .48129 .67732 .47704 Metetra
.708 .788 .914 r
.67732 .47704 .68139 .48129 .68999 .47807 .68591 .47331 Metetra
.697 .762 .902 r
.68591 .47331 .68999 .47807 .69862 .47496 .69454 .4698 Metetra
.684 .742 .895 r
.69454 .4698 .69862 .47496 .70728 .47201 .7032 .46658 Metetra
.671 .727 .892 r
.7032 .46658 .70728 .47201 .71597 .46921 .71191 .46366 Metetra
.661 .719 .892 r
.71191 .46366 .71597 .46921 .7247 .46654 .72065 .46097 Metetra
.654 .717 .895 r
.72065 .46097 .7247 .46654 .73347 .46395 .72944 .45846 Metetra
.649 .718 .899 r
.72944 .45846 .73347 .46395 .74226 .46141 .73826 .45604 Metetra
.647 .723 .904 r
.73826 .45604 .74226 .46141 .75108 .45889 .74711 .45367 Metetra
.646 .73 .91 r
.74711 .45367 .75108 .45889 .75993 .45636 .75599 .45129 Metetra
.647 .737 .915 r
.75599 .45129 .75993 .45636 .76881 .45381 .7649 .44886 Metetra
.651 .745 .918 r
.7649 .44886 .76881 .45381 .77771 .45119 .77383 .44633 Metetra
.657 .751 .92 r
.77383 .44633 .77771 .45119 .78664 .4485 .78278 .44367 Metetra
.661 .755 .92 r
.78278 .44367 .78664 .4485 .79559 .44575 .79175 .4409 Metetra
.665 .756 .918 r
.79175 .4409 .79559 .44575 .80456 .44294 .80074 .43804 Metetra
.667 .755 .916 r
.80074 .43804 .80456 .44294 .81356 .44011 .80975 .43512 Metetra
.667 .753 .914 r
.80975 .43512 .81356 .44011 .82259 .43726 .81879 .43219 Metetra
.667 .75 .912 r
.81879 .43219 .82259 .43726 .83164 .43441 .82786 .42926 Metetra
.666 .747 .91 r
.82786 .42926 .83164 .43441 .84072 .43156 .83696 .42634 Metetra
.665 .744 .909 r
.83696 .42634 .84072 .43156 .84984 .42871 .84609 .42344 Metetra
.663 .742 .908 r
.84609 .42344 .84984 .42871 .85898 .42588 .85525 .42057 Metetra
.662 .74 .908 r
.85525 .42057 .85898 .42588 .86816 .42306 .86445 .41774 Metetra
.66 .74 .909 r
.86445 .41774 .86816 .42306 .87736 .42025 .87367 .41493 Metetra
.659 .74 .91 r
.87367 .41493 .87736 .42025 .8866 .41744 .88293 .41213 Metetra
.659 .741 .91 r
.88293 .41213 .8866 .41744 .89586 .41463 .89222 .40933 Metetra
.659 .742 .911 r
.89222 .40933 .89586 .41463 .90516 .4118 .90154 .4065 Metetra
.66 .743 .912 r
.90154 .4065 .90516 .4118 .91448 .40896 .91089 .40366 Metetra
.66 .744 .912 r
.91089 .40366 .91448 .40896 .92383 .4061 .92026 .4008 Metetra
.661 .745 .912 r
.92026 .4008 .92383 .4061 .93321 .40323 .92967 .39791 Metetra
.662 .745 .912 r
.33952 .57394 .34429 .57829 .35195 .57593 .34719 .57156 Metetra
.662 .745 .912 r
.34719 .57156 .35195 .57593 .35962 .57355 .35488 .56917 Metetra
.662 .745 .911 r
.35488 .56917 .35962 .57355 .36732 .57117 .36259 .56677 Metetra
.663 .745 .911 r
.36259 .56677 .36732 .57117 .37504 .56877 .37032 .56435 Metetra
.663 .744 .91 r
.37032 .56435 .37504 .56877 .38278 .56635 .37808 .56191 Metetra
.664 .744 .91 r
.37808 .56191 .38278 .56635 .39055 .56393 .38586 .55946 Metetra
.663 .743 .91 r
.38586 .55946 .39055 .56393 .39834 .56151 .39366 .55701 Metetra
.661 .742 .91 r
.39366 .55701 .39834 .56151 .40615 .5591 .40149 .55459 Metetra
.66 .742 .911 r
.40149 .55459 .40615 .5591 .41398 .55671 .40933 .5522 Metetra
.658 .742 .912 r
.40933 .5522 .41398 .55671 .42183 .55434 .4172 .54984 Metetra
.657 .742 .913 r
.4172 .54984 .42183 .55434 .42971 .55198 .42509 .5475 Metetra
.656 .743 .914 r
.42509 .5475 .42971 .55198 .43761 .54962 .433 .54516 Metetra
.655 .745 .916 r
.433 .54516 .43761 .54962 .44553 .54727 .44094 .54284 Metetra
.654 .747 .917 r
.44094 .54284 .44553 .54727 .45348 .54492 .4489 .54051 Metetra
.656 .749 .918 r
.4489 .54051 .45348 .54492 .46145 .54253 .45689 .53814 Metetra
.661 .751 .917 r
.45689 .53814 .46145 .54253 .46944 .54007 .4649 .53567 Metetra
.666 .753 .915 r
.4649 .53567 .46944 .54007 .47746 .53752 .47293 .53308 Metetra
.673 .753 .911 r
.47293 .53308 .47746 .53752 .48551 .53488 .48099 .53034 Metetra
.678 .751 .907 r
.48099 .53034 .48551 .53488 .49358 .53214 .48908 .52748 Metetra
.68 .747 .902 r
.48908 .52748 .49358 .53214 .50167 .52937 .49719 .52457 Metetra
.679 .742 .898 r
.49719 .52457 .50167 .52937 .50978 .52659 .50532 .52164 Metetra
.677 .736 .895 r
.50532 .52164 .50978 .52659 .51792 .52383 .51347 .51876 Metetra
.672 .73 .893 r
.51347 .51876 .51792 .52383 .52608 .52115 .52164 .51599 Metetra
.662 .724 .895 r
.52164 .51599 .52608 .52115 .53426 .51861 .52984 .51343 Metetra
.648 .719 .9 r
.52984 .51343 .53426 .51861 .54247 .51629 .53807 .51119 Metetra
.629 .716 .909 r
.53807 .51119 .54247 .51629 .55071 .51422 .54632 .50932 Metetra
.606 .717 .923 r
.54632 .50932 .55071 .51422 .55897 .51244 .5546 .50787 Metetra
.581 .723 .94 r
.5546 .50787 .55897 .51244 .56727 .51088 .56292 .50675 Metetra
.558 .737 .959 r
.56292 .50675 .56727 .51088 .5756 .50945 .57127 .50581 Metetra
.535 .755 .977 r
.57127 .50581 .5756 .50945 .58396 .50807 .57966 .50496 Metetra
.515 .776 .991 r
.57966 .50496 .58396 .50807 .59235 .50666 .58808 .50407 Metetra
.504 .802 .999 r
.58808 .50407 .59235 .50666 .60077 .50511 .59654 .50297 Metetra
.508 .829 1 r
.59654 .50297 .60077 .50511 .60922 .50332 .60501 .50153 Metetra
.533 .858 .996 r
.60501 .50153 .60922 .50332 .61768 .50118 .61351 .49959 Metetra
.581 .886 .991 r
.61351 .49959 .61768 .50118 .62616 .49861 .62201 .49702 Metetra
.636 .905 .984 r
.62201 .49702 .62616 .49861 .63466 .4956 .63053 .49382 Metetra
.683 .908 .974 r
.63053 .49382 .63466 .4956 .64316 .49223 .63904 .49009 Metetra
.715 .896 .961 r
.63904 .49009 .64316 .49223 .65167 .48858 .64757 .48597 Metetra
.734 .875 .946 r
.64757 .48597 .65167 .48858 .6602 .48477 .6561 .4816 Metetra
.739 .848 .931 r
.6561 .4816 .6602 .48477 .66875 .48089 .66465 .47714 Metetra
.736 .819 .916 r
.66465 .47714 .66875 .48089 .67732 .47704 .67321 .47274 Metetra
.726 .792 .904 r
.67321 .47274 .67732 .47704 .68591 .47331 .6818 .46851 Metetra
.711 .767 .896 r
.6818 .46851 .68591 .47331 .69454 .4698 .69043 .46461 Metetra
.693 .745 .892 r
.69043 .46461 .69454 .4698 .7032 .46658 .6991 .46114 Metetra
.675 .73 .891 r
.6991 .46114 .7032 .46658 .71191 .46366 .70782 .45809 Metetra
.661 .72 .893 r
.70782 .45809 .71191 .46366 .72065 .46097 .71658 .45539 Metetra
.65 .716 .896 r
.71658 .45539 .72065 .46097 .72944 .45846 .72539 .45295 Metetra
.643 .717 .901 r
.72539 .45295 .72944 .45846 .73826 .45604 .73423 .45066 Metetra
.64 .721 .907 r
.73423 .45066 .73826 .45604 .74711 .45367 .74311 .44842 Metetra
.639 .727 .912 r
.74311 .44842 .74711 .45367 .75599 .45129 .75202 .44618 Metetra
.641 .735 .917 r
.75202 .44618 .75599 .45129 .7649 .44886 .76096 .44388 Metetra
.647 .743 .919 r
.76096 .44388 .7649 .44886 .77383 .44633 .76992 .44143 Metetra
.655 .75 .92 r
.76992 .44143 .77383 .44633 .78278 .44367 .77889 .4388 Metetra
.661 .755 .919 r
.77889 .4388 .78278 .44367 .79175 .4409 .78788 .43601 Metetra
.667 .757 .918 r
.78788 .43601 .79175 .4409 .80074 .43804 .79689 .43309 Metetra
.67 .756 .915 r
.79689 .43309 .80074 .43804 .80975 .43512 .80592 .4301 Metetra
.67 .753 .913 r
.80592 .4301 .80975 .43512 .81879 .43219 .81497 .42709 Metetra
.669 .75 .911 r
.81497 .42709 .81879 .43219 .82786 .42926 .82406 .42409 Metetra
.668 .748 .91 r
.82406 .42409 .82786 .42926 .83696 .42634 .83317 .4211 Metetra
.667 .745 .909 r
.83317 .4211 .83696 .42634 .84609 .42344 .84232 .41814 Metetra
.664 .742 .908 r
.84232 .41814 .84609 .42344 .85525 .42057 .8515 .41524 Metetra
.662 .74 .908 r
.8515 .41524 .85525 .42057 .86445 .41774 .86072 .41239 Metetra
.66 .74 .909 r
.86072 .41239 .86445 .41774 .87367 .41493 .86997 .40958 Metetra
.658 .74 .91 r
.86997 .40958 .87367 .41493 .88293 .41213 .87925 .40679 Metetra
.658 .74 .911 r
.87925 .40679 .88293 .41213 .89222 .40933 .88856 .40399 Metetra
.659 .742 .911 r
.88856 .40399 .89222 .40933 .90154 .4065 .89791 .40117 Metetra
.659 .743 .912 r
.89791 .40117 .90154 .4065 .91089 .40366 .90728 .39833 Metetra
.66 .744 .912 r
.90728 .39833 .91089 .40366 .92026 .4008 .91667 .39546 Metetra
.66 .745 .913 r
.91667 .39546 .92026 .4008 .92967 .39791 .9261 .39257 Metetra
.662 .745 .912 r
.33472 .56956 .33952 .57394 .34719 .57156 .3424 .56717 Metetra
.662 .745 .911 r
.3424 .56717 .34719 .57156 .35488 .56917 .35011 .56476 Metetra
.662 .745 .911 r
.35011 .56476 .35488 .56917 .36259 .56677 .35783 .56234 Metetra
.663 .745 .911 r
.35783 .56234 .36259 .56677 .37032 .56435 .36558 .5599 Metetra
.664 .745 .91 r
.36558 .5599 .37032 .56435 .37808 .56191 .37335 .55744 Metetra
.664 .744 .91 r
.37335 .55744 .37808 .56191 .38586 .55946 .38115 .55497 Metetra
.663 .744 .91 r
.38115 .55497 .38586 .55946 .39366 .55701 .38897 .55251 Metetra
.661 .743 .91 r
.38897 .55251 .39366 .55701 .40149 .55459 .3968 .55007 Metetra
.659 .742 .911 r
.3968 .55007 .40149 .55459 .40933 .5522 .40466 .54768 Metetra
.657 .742 .912 r
.40466 .54768 .40933 .5522 .4172 .54984 .41254 .54532 Metetra
.656 .742 .914 r
.41254 .54532 .4172 .54984 .42509 .5475 .42045 .54298 Metetra
.655 .743 .915 r
.42045 .54298 .42509 .5475 .433 .54516 .42837 .54066 Metetra
.653 .744 .916 r
.42837 .54066 .433 .54516 .44094 .54284 .43633 .53835 Metetra
.653 .745 .917 r
.43633 .53835 .44094 .54284 .4489 .54051 .4443 .53604 Metetra
.656 .747 .917 r
.4443 .53604 .4489 .54051 .45689 .53814 .4523 .53367 Metetra
.661 .749 .916 r
.4523 .53367 .45689 .53814 .4649 .53567 .46033 .53119 Metetra
.667 .751 .913 r
.46033 .53119 .4649 .53567 .47293 .53308 .46838 .52856 Metetra
.675 .752 .909 r
.46838 .52856 .47293 .53308 .48099 .53034 .47646 .52576 Metetra
.681 .751 .904 r
.47646 .52576 .48099 .53034 .48908 .52748 .48456 .52281 Metetra
.683 .749 .901 r
.48456 .52281 .48908 .52748 .49719 .52457 .49268 .5198 Metetra
.683 .745 .898 r
.49268 .5198 .49719 .52457 .50532 .52164 .50083 .51678 Metetra
.681 .741 .897 r
.50083 .51678 .50532 .52164 .51347 .51876 .509 .5138 Metetra
.674 .736 .897 r
.509 .5138 .51347 .51876 .52164 .51599 .51719 .51097 Metetra
.662 .73 .9 r
.51719 .51097 .52164 .51599 .52984 .51343 .5254 .5084 Metetra
.645 .725 .906 r
.5254 .5084 .52984 .51343 .53807 .51119 .53364 .50619 Metetra
.621 .719 .916 r
.53364 .50619 .53807 .51119 .54632 .50932 .54191 .50446 Metetra
.592 .714 .929 r
.54191 .50446 .54632 .50932 .5546 .50787 .55021 .50323 Metetra
.563 .714 .943 r
.55021 .50323 .5546 .50787 .56292 .50675 .55854 .50239 Metetra
.539 .719 .956 r
.55854 .50239 .56292 .50675 .57127 .50581 .56692 .50179 Metetra
.519 .728 .969 r
.56692 .50179 .57127 .50581 .57966 .50496 .57533 .50129 Metetra
.509 .743 .979 r
.57533 .50129 .57966 .50496 .58808 .50407 .58377 .50073 Metetra
.515 .765 .987 r
.58377 .50073 .58808 .50407 .59654 .50297 .59225 .49994 Metetra
.537 .792 .992 r
.59225 .49994 .59654 .50297 .60501 .50153 .60075 .49872 Metetra
.577 .82 .991 r
.60075 .49872 .60501 .50153 .61351 .49959 .60927 .49691 Metetra
.63 .846 .982 r
.60927 .49691 .61351 .49959 .62201 .49702 .6178 .49434 Metetra
.68 .86 .967 r
.6178 .49434 .62201 .49702 .63053 .49382 .62633 .491 Metetra
.716 .861 .95 r
.62633 .491 .63053 .49382 .63904 .49009 .63487 .48702 Metetra
.739 .852 .933 r
.63487 .48702 .63904 .49009 .64757 .48597 .6434 .48258 Metetra
.75 .839 .918 r
.6434 .48258 .64757 .48597 .6561 .4816 .65195 .47784 Metetra
.752 .821 .906 r
.65195 .47784 .6561 .4816 .66465 .47714 .6605 .47299 Metetra
.747 .803 .897 r
.6605 .47299 .66465 .47714 .67321 .47274 .66907 .46821 Metetra
.736 .785 .892 r
.66907 .46821 .67321 .47274 .6818 .46851 .67767 .46364 Metetra
.72 .767 .89 r
.67767 .46364 .6818 .46851 .69043 .46461 .68631 .45947 Metetra
.699 .75 .891 r
.68631 .45947 .69043 .46461 .6991 .46114 .69499 .45582 Metetra
.679 .737 .895 r
.69499 .45582 .6991 .46114 .70782 .45809 .70372 .45269 Metetra
.661 .728 .899 r
.70372 .45269 .70782 .45809 .71658 .45539 .7125 .44998 Metetra
.647 .723 .903 r
.7125 .44998 .71658 .45539 .72539 .45295 .72133 .44758 Metetra
.639 .722 .908 r
.72133 .44758 .72539 .45295 .73423 .45066 .7302 .44536 Metetra
.635 .724 .912 r
.7302 .44536 .73423 .45066 .74311 .44842 .7391 .44321 Metetra
.634 .728 .916 r
.7391 .44321 .74311 .44842 .75202 .44618 .74804 .44106 Metetra
.636 .733 .918 r
.74804 .44106 .75202 .44618 .76096 .44388 .757 .43884 Metetra
.644 .74 .919 r
.757 .43884 .76096 .44388 .76992 .44143 .76598 .43644 Metetra
.653 .747 .919 r
.76598 .43644 .76992 .44143 .77889 .4388 .77498 .43383 Metetra
.662 .752 .917 r
.77498 .43383 .77889 .4388 .78788 .43601 .78399 .43101 Metetra
.668 .754 .915 r
.78399 .43101 .78788 .43601 .79689 .43309 .79301 .42805 Metetra
.671 .754 .912 r
.79301 .42805 .79689 .43309 .80592 .4301 .80206 .425 Metetra
.672 .752 .911 r
.80206 .425 .80592 .4301 .81497 .42709 .81113 .42193 Metetra
.671 .75 .91 r
.81113 .42193 .81497 .42709 .82406 .42409 .82023 .41888 Metetra
.67 .748 .909 r
.82023 .41888 .82406 .42409 .83317 .4211 .82937 .41584 Metetra
.668 .746 .909 r
.82937 .41584 .83317 .4211 .84232 .41814 .83853 .41284 Metetra
.665 .743 .909 r
.83853 .41284 .84232 .41814 .8515 .41524 .84773 .40991 Metetra
.662 .742 .909 r
.84773 .40991 .8515 .41524 .86072 .41239 .85697 .40704 Metetra
.659 .741 .91 r
.85697 .40704 .86072 .41239 .86997 .40958 .86624 .40422 Metetra
.657 .74 .911 r
.86624 .40422 .86997 .40958 .87925 .40679 .87555 .40143 Metetra
.657 .741 .912 r
.87555 .40143 .87925 .40679 .88856 .40399 .88488 .39863 Metetra
.658 .742 .912 r
.88488 .39863 .88856 .40399 .89791 .40117 .89425 .39581 Metetra
.659 .743 .912 r
.89425 .39581 .89791 .40117 .90728 .39833 .90364 .39296 Metetra
.659 .744 .912 r
.90364 .39296 .90728 .39833 .91667 .39546 .91306 .39009 Metetra
.66 .744 .912 r
.91306 .39009 .91667 .39546 .9261 .39257 .92251 .38718 Metetra
.662 .744 .911 r
.3299 .56515 .33472 .56956 .3424 .56717 .33759 .56275 Metetra
.662 .744 .911 r
.33759 .56275 .3424 .56717 .35011 .56476 .34531 .56033 Metetra
.662 .745 .911 r
.34531 .56033 .35011 .56476 .35783 .56234 .35305 .5579 Metetra
.663 .745 .911 r
.35305 .5579 .35783 .56234 .36558 .5599 .36081 .55545 Metetra
.664 .745 .91 r
.36081 .55545 .36558 .5599 .37335 .55744 .3686 .55297 Metetra
.664 .745 .91 r
.3686 .55297 .37335 .55744 .38115 .55497 .37641 .55048 Metetra
.663 .745 .911 r
.37641 .55048 .38115 .55497 .38897 .55251 .38424 .54801 Metetra
.661 .744 .911 r
.38424 .54801 .38897 .55251 .3968 .55007 .39209 .54556 Metetra
.659 .744 .912 r
.39209 .54556 .3968 .55007 .40466 .54768 .39997 .54315 Metetra
.657 .743 .913 r
.39997 .54315 .40466 .54768 .41254 .54532 .40786 .54078 Metetra
.655 .743 .914 r
.40786 .54078 .41254 .54532 .42045 .54298 .41578 .53843 Metetra
.654 .742 .914 r
.41578 .53843 .42045 .54298 .42837 .54066 .42372 .5361 Metetra
.653 .742 .915 r
.42372 .5361 .42837 .54066 .43633 .53835 .43169 .53378 Metetra
.653 .742 .915 r
.43169 .53378 .43633 .53835 .4443 .53604 .43967 .53146 Metetra
.656 .743 .914 r
.43967 .53146 .4443 .53604 .4523 .53367 .44769 .52908 Metetra
.661 .745 .912 r
.44769 .52908 .4523 .53367 .46033 .53119 .45573 .52659 Metetra
.668 .747 .909 r
.45573 .52659 .46033 .53119 .46838 .52856 .4638 .52394 Metetra
.675 .749 .906 r
.4638 .52394 .46838 .52856 .47646 .52576 .47189 .52112 Metetra
.681 .75 .903 r
.47189 .52112 .47646 .52576 .48456 .52281 .48001 .51815 Metetra
.684 .75 .902 r
.48001 .51815 .48456 .52281 .49268 .5198 .48815 .51511 Metetra
.684 .75 .901 r
.48815 .51511 .49268 .5198 .50083 .51678 .49631 .51207 Metetra
.681 .749 .902 r
.49631 .51207 .50083 .51678 .509 .5138 .5045 .50907 Metetra
.675 .747 .905 r
.5045 .50907 .509 .5138 .51719 .51097 .51271 .50621 Metetra
.662 .743 .91 r
.51271 .50621 .51719 .51097 .5254 .5084 .52094 .50363 Metetra
.644 .737 .917 r
.52094 .50363 .5254 .5084 .53364 .50619 .52919 .50142 Metetra
.619 .729 .925 r
.52919 .50142 .53364 .50619 .54191 .50446 .53747 .49969 Metetra
.589 .719 .933 r
.53747 .49969 .54191 .50446 .55021 .50323 .54579 .49847 Metetra
.562 .709 .94 r
.54579 .49847 .55021 .50323 .55854 .50239 .55414 .49765 Metetra
.545 .704 .944 r
.55414 .49765 .55854 .50239 .56692 .50179 .56253 .49707 Metetra
.537 .702 .946 r
.56253 .49707 .56692 .50179 .57533 .50129 .57095 .49659 Metetra
.54 .705 .947 r
.57095 .49659 .57533 .50129 .58377 .50073 .57941 .49607 Metetra
.556 .713 .945 r
.57941 .49607 .58377 .50073 .59225 .49994 .5879 .49529 Metetra
.582 .726 .941 r
.5879 .49529 .59225 .49994 .60075 .49872 .59642 .49409 Metetra
.618 .74 .934 r
.59642 .49409 .60075 .49872 .60927 .49691 .60496 .49228 Metetra
.657 .754 .922 r
.60496 .49228 .60927 .49691 .6178 .49434 .61351 .48969 Metetra
.692 .765 .908 r
.61351 .48969 .6178 .49434 .62633 .491 .62206 .48633 Metetra
.717 .771 .896 r
.62206 .48633 .62633 .491 .63487 .48702 .63061 .48231 Metetra
.733 .774 .886 r
.63061 .48231 .63487 .48702 .6434 .48258 .63917 .47782 Metetra
.742 .775 .88 r
.63917 .47782 .6434 .48258 .65195 .47784 .64773 .47302 Metetra
.745 .774 .877 r
.64773 .47302 .65195 .47784 .6605 .47299 .6563 .46812 Metetra
.742 .772 .877 r
.6563 .46812 .6605 .47299 .66907 .46821 .6649 .46328 Metetra
.734 .769 .88 r
.6649 .46328 .66907 .46821 .67767 .46364 .67351 .45866 Metetra
.72 .764 .887 r
.67351 .45866 .67767 .46364 .68631 .45947 .68217 .45444 Metetra
.701 .756 .895 r
.68217 .45444 .68631 .45947 .69499 .45582 .69087 .45076 Metetra
.68 .749 .904 r
.69087 .45076 .69499 .45582 .70372 .45269 .69962 .4476 Metetra
.661 .742 .91 r
.69962 .4476 .70372 .45269 .7125 .44998 .70842 .44488 Metetra
.646 .737 .915 r
.70842 .44488 .7125 .44998 .72133 .44758 .71726 .44247 Metetra
.637 .733 .918 r
.71726 .44247 .72133 .44758 .7302 .44536 .72615 .44024 Metetra
.633 .732 .919 r
.72615 .44024 .7302 .44536 .7391 .44321 .73507 .43809 Metetra
.633 .733 .92 r
.73507 .43809 .7391 .44321 .74804 .44106 .74403 .43594 Metetra
.636 .734 .919 r
.74403 .43594 .74804 .44106 .757 .43884 .75301 .43371 Metetra
.644 .738 .917 r
.75301 .43371 .757 .43884 .76598 .43644 .76201 .4313 Metetra
.654 .742 .915 r
.76201 .4313 .76598 .43644 .77498 .43383 .77103 .42868 Metetra
.662 .745 .912 r
.77103 .42868 .77498 .43383 .78399 .43101 .78006 .42585 Metetra
.668 .748 .91 r
.78006 .42585 .78399 .43101 .79301 .42805 .7891 .42286 Metetra
.672 .749 .909 r
.7891 .42286 .79301 .42805 .80206 .425 .79817 .41979 Metetra
.672 .749 .908 r
.79817 .41979 .80206 .425 .81113 .42193 .80726 .4167 Metetra
.671 .748 .908 r
.80726 .4167 .81113 .42193 .82023 .41888 .81639 .41363 Metetra
.67 .748 .909 r
.81639 .41363 .82023 .41888 .82937 .41584 .82554 .41057 Metetra
.668 .747 .909 r
.82554 .41057 .82937 .41584 .83853 .41284 .83472 .40755 Metetra
.665 .745 .91 r
.83472 .40755 .83853 .41284 .84773 .40991 .84394 .4046 Metetra
.662 .744 .911 r
.84394 .4046 .84773 .40991 .85697 .40704 .8532 .40171 Metetra
.659 .743 .912 r
.8532 .40171 .85697 .40704 .86624 .40422 .8625 .39888 Metetra
.657 .742 .913 r
.8625 .39888 .86624 .40422 .87555 .40143 .87182 .39607 Metetra
.657 .742 .913 r
.87182 .39607 .87555 .40143 .88488 .39863 .88118 .39326 Metetra
.658 .743 .913 r
.88118 .39326 .88488 .39863 .89425 .39581 .89057 .39043 Metetra
.659 .743 .912 r
.89057 .39043 .89425 .39581 .90364 .39296 .89998 .38756 Metetra
.659 .743 .912 r
.89998 .38756 .90364 .39296 .91306 .39009 .90943 .38467 Metetra
.66 .744 .912 r
.90943 .38467 .91306 .39009 .92251 .38718 .9189 .38174 Metetra
.662 .744 .911 r
.32505 .56072 .3299 .56515 .33759 .56275 .33276 .5583 Metetra
.662 .744 .911 r
.33276 .5583 .33759 .56275 .34531 .56033 .34049 .55587 Metetra
.662 .744 .911 r
.34049 .55587 .34531 .56033 .35305 .5579 .34824 .55343 Metetra
.663 .745 .911 r
.34824 .55343 .35305 .5579 .36081 .55545 .35602 .55097 Metetra
.663 .745 .911 r
.35602 .55097 .36081 .55545 .3686 .55297 .36382 .54849 Metetra
.664 .746 .911 r
.36382 .54849 .3686 .55297 .37641 .55048 .37164 .546 Metetra
.663 .746 .912 r
.37164 .546 .37641 .55048 .38424 .54801 .37949 .54352 Metetra
.661 .746 .913 r
.37949 .54352 .38424 .54801 .39209 .54556 .38735 .54106 Metetra
.66 .745 .913 r
.38735 .54106 .39209 .54556 .39997 .54315 .39524 .53863 Metetra
.658 .744 .914 r
.39524 .53863 .39997 .54315 .40786 .54078 .40315 .53623 Metetra
.657 .743 .914 r
.40315 .53623 .40786 .54078 .41578 .53843 .41109 .53384 Metetra
.656 .742 .913 r
.41109 .53384 .41578 .53843 .42372 .5361 .41904 .53147 Metetra
.655 .741 .913 r
.41904 .53147 .42372 .5361 .43169 .53378 .42702 .52911 Metetra
.655 .74 .912 r
.42702 .52911 .43169 .53378 .43967 .53146 .43503 .52674 Metetra
.657 .739 .91 r
.43503 .52674 .43967 .53146 .44769 .52908 .44306 .52433 Metetra
.661 .739 .908 r
.44306 .52433 .44769 .52908 .45573 .52659 .45111 .52182 Metetra
.666 .741 .905 r
.45111 .52182 .45573 .52659 .4638 .52394 .4592 .51919 Metetra
.673 .743 .904 r
.4592 .51919 .4638 .52394 .47189 .52112 .4673 .51641 Metetra
.678 .747 .903 r
.4673 .51641 .47189 .52112 .48001 .51815 .47544 .5135 Metetra
.68 .751 .905 r
.47544 .5135 .48001 .51815 .48815 .51511 .48359 .51054 Metetra
.68 .755 .908 r
.48359 .51054 .48815 .51511 .49631 .51207 .49177 .50757 Metetra
.678 .759 .912 r
.49177 .50757 .49631 .51207 .5045 .50907 .49997 .50464 Metetra
.672 .761 .917 r
.49997 .50464 .5045 .50907 .51271 .50621 .5082 .50183 Metetra
.662 .76 .923 r
.5082 .50183 .51271 .50621 .52094 .50363 .51644 .49923 Metetra
.645 .755 .929 r
.51644 .49923 .52094 .50363 .52919 .50142 .52471 .49694 Metetra
.624 .746 .934 r
.52471 .49694 .52919 .50142 .53747 .49969 .53301 .49504 Metetra
.602 .73 .935 r
.53301 .49504 .53747 .49969 .54579 .49847 .54134 .49356 Metetra
.585 .713 .931 r
.54134 .49356 .54579 .49847 .55414 .49765 .5497 .4924 Metetra
.577 .695 .922 r
.5497 .4924 .55414 .49765 .56253 .49707 .5581 .49144 Metetra
.577 .68 .91 r
.5581 .49144 .56253 .49707 .57095 .49659 .56653 .49057 Metetra
.583 .667 .897 r
.56653 .49057 .57095 .49659 .57941 .49607 .575 .48965 Metetra
.596 .659 .882 r
.575 .48965 .57941 .49607 .5879 .49529 .5835 .48852 Metetra
.612 .655 .868 r
.5835 .48852 .5879 .49529 .59642 .49409 .59202 .48704 Metetra
.632 .656 .855 r
.59202 .48704 .59642 .49409 .60496 .49228 .60056 .48506 Metetra
.654 .661 .844 r
.60056 .48506 .60496 .49228 .61351 .48969 .60912 .48245 Metetra
.674 .669 .837 r
.60912 .48245 .61351 .48969 .62206 .48633 .61769 .4792 Metetra
.691 .679 .834 r
.61769 .4792 .62206 .48633 .63061 .48231 .62627 .47541 Metetra
.704 .691 .835 r
.62627 .47541 .63061 .48231 .63917 .47782 .63485 .47123 Metetra
.713 .704 .84 r
.63485 .47123 .63917 .47782 .64773 .47302 .64344 .46681 Metetra
.719 .718 .848 r
.64344 .46681 .64773 .47302 .6563 .46812 .65205 .46229 Metetra
.721 .732 .859 r
.65205 .46229 .6563 .46812 .6649 .46328 .66067 .45782 Metetra
.719 .745 .872 r
.66067 .45782 .6649 .46328 .67351 .45866 .66932 .45353 Metetra
.71 .756 .888 r
.66932 .45353 .67351 .45866 .68217 .45444 .67801 .44957 Metetra
.695 .762 .904 r
.67801 .44957 .68217 .45444 .69087 .45076 .68674 .44605 Metetra
.676 .764 .917 r
.68674 .44605 .69087 .45076 .69962 .4476 .69551 .44295 Metetra
.66 .762 .925 r
.69551 .44295 .69962 .4476 .70842 .44488 .70433 .4402 Metetra
.647 .757 .93 r
.70433 .4402 .70842 .44488 .71726 .44247 .7132 .43772 Metetra
.639 .752 .93 r
.7132 .43772 .71726 .44247 .72615 .44024 .7221 .43538 Metetra
.637 .746 .927 r
.7221 .43538 .72615 .44024 .73507 .43809 .73103 .4331 Metetra
.637 .741 .924 r
.73103 .4331 .73507 .43809 .74403 .43594 .74 .43082 Metetra
.641 .738 .919 r
.74 .43082 .74403 .43594 .75301 .43371 .74899 .42847 Metetra
.647 .736 .914 r
.74899 .42847 .75301 .43371 .76201 .4313 .75801 .42598 Metetra
.655 .736 .909 r
.75801 .42598 .76201 .4313 .77103 .42868 .76704 .4233 Metetra
.662 .737 .906 r
.76704 .4233 .77103 .42868 .78006 .42585 .77609 .42046 Metetra
.667 .739 .904 r
.77609 .42046 .78006 .42585 .7891 .42286 .78516 .41749 Metetra
.67 .742 .904 r
.78516 .41749 .7891 .42286 .79817 .41979 .79425 .41445 Metetra
.67 .744 .906 r
.79425 .41445 .79817 .41979 .80726 .4167 .80337 .41139 Metetra
.669 .745 .907 r
.80337 .41139 .80726 .4167 .81639 .41363 .81251 .40833 Metetra
.668 .747 .909 r
.81251 .40833 .81639 .41363 .82554 .41057 .82169 .40529 Metetra
.667 .747 .911 r
.82169 .40529 .82554 .41057 .83472 .40755 .8309 .40229 Metetra
.664 .748 .912 r
.8309 .40229 .83472 .40755 .84394 .4046 .84014 .39934 Metetra
.661 .747 .914 r
.84014 .39934 .84394 .4046 .8532 .40171 .84942 .39643 Metetra
.659 .746 .914 r
.84942 .39643 .8532 .40171 .8625 .39888 .85874 .39357 Metetra
.658 .745 .914 r
.85874 .39357 .8625 .39888 .87182 .39607 .86808 .39073 Metetra
.658 .744 .914 r
.86808 .39073 .87182 .39607 .88118 .39326 .87746 .38788 Metetra
.658 .744 .913 r
.87746 .38788 .88118 .39326 .89057 .39043 .88687 .38501 Metetra
.659 .744 .912 r
.88687 .38501 .89057 .39043 .89998 .38756 .89631 .38212 Metetra
.66 .743 .912 r
.89631 .38212 .89998 .38756 .90943 .38467 .90577 .3792 Metetra
.66 .743 .911 r
.90577 .3792 .90943 .38467 .9189 .38174 .91526 .37625 Metetra
.662 .744 .911 r
.32018 .55625 .32505 .56072 .33276 .5583 .3279 .55382 Metetra
.662 .744 .911 r
.3279 .55382 .33276 .5583 .34049 .55587 .33564 .55139 Metetra
.662 .744 .911 r
.33564 .55139 .34049 .55587 .34824 .55343 .34341 .54894 Metetra
.662 .745 .911 r
.34341 .54894 .34824 .55343 .35602 .55097 .3512 .54648 Metetra
.662 .745 .912 r
.3512 .54648 .35602 .55097 .36382 .54849 .35901 .54401 Metetra
.662 .746 .912 r
.35901 .54401 .36382 .54849 .37164 .546 .36685 .54153 Metetra
.662 .747 .913 r
.36685 .54153 .37164 .546 .37949 .54352 .37471 .53905 Metetra
.661 .748 .914 r
.37471 .53905 .37949 .54352 .38735 .54106 .38259 .53658 Metetra
.66 .747 .914 r
.38259 .53658 .38735 .54106 .39524 .53863 .39049 .53411 Metetra
.66 .746 .914 r
.39049 .53411 .39524 .53863 .40315 .53623 .39842 .53166 Metetra
.659 .745 .913 r
.39842 .53166 .40315 .53623 .41109 .53384 .40637 .52922 Metetra
.659 .742 .912 r
.40637 .52922 .41109 .53384 .41904 .53147 .41434 .52677 Metetra
.658 .74 .91 r
.41434 .52677 .41904 .53147 .42702 .52911 .42234 .52433 Metetra
.658 .737 .908 r
.42234 .52433 .42702 .52911 .43503 .52674 .43036 .52188 Metetra
.659 .734 .905 r
.43036 .52188 .43503 .52674 .44306 .52433 .4384 .51941 Metetra
.661 .733 .903 r
.4384 .51941 .44306 .52433 .45111 .52182 .44648 .51688 Metetra
.664 .733 .902 r
.44648 .51688 .45111 .52182 .4592 .51919 .45457 .51428 Metetra
.667 .737 .902 r
.45457 .51428 .4592 .51919 .4673 .51641 .46269 .51161 Metetra
.67 .743 .905 r
.46269 .51161 .4673 .51641 .47544 .5135 .47084 .50887 Metetra
.671 .751 .91 r
.47084 .50887 .47544 .5135 .48359 .51054 .47901 .5061 Metetra
.671 .76 .917 r
.47901 .5061 .48359 .51054 .49177 .50757 .4872 .50333 Metetra
.669 .769 .924 r
.4872 .50333 .49177 .50757 .49997 .50464 .49542 .50056 Metetra
.666 .776 .932 r
.49542 .50056 .49997 .50464 .5082 .50183 .50366 .49786 Metetra
.659 .78 .938 r
.50366 .49786 .5082 .50183 .51644 .49923 .51192 .49525 Metetra
.65 .778 .942 r
.51192 .49525 .51644 .49923 .52471 .49694 .52021 .4928 Metetra
.641 .768 .94 r
.52021 .4928 .52471 .49694 .53301 .49504 .52853 .49054 Metetra
.632 .749 .932 r
.52853 .49054 .53301 .49504 .54134 .49356 .53687 .48849 Metetra
.627 .722 .916 r
.53687 .48849 .54134 .49356 .5497 .4924 .54524 .4866 Metetra
.625 .692 .893 r
.54524 .4866 .5497 .4924 .5581 .49144 .55364 .4848 Metetra
.624 .663 .868 r
.55364 .4848 .5581 .49144 .56653 .49057 .56208 .48303 Metetra
.625 .638 .843 r
.56208 .48303 .56653 .49057 .575 .48965 .57054 .48125 Metetra
.627 .617 .822 r
.57054 .48125 .575 .48965 .5835 .48852 .57903 .47935 Metetra
.63 .603 .804 r
.57903 .47935 .5835 .48852 .59202 .48704 .58755 .47727 Metetra
.635 .594 .791 r
.58755 .47727 .59202 .48704 .60056 .48506 .59609 .47494 Metetra
.642 .592 .783 r
.59609 .47494 .60056 .48506 .60912 .48245 .60465 .47229 Metetra
.65 .595 .78 r
.60465 .47229 .60912 .48245 .61769 .4792 .61323 .4693 Metetra
.658 .604 .783 r
.61323 .4693 .61769 .4792 .62627 .47541 .62183 .46605 Metetra
.666 .618 .792 r
.62183 .46605 .62627 .47541 .63485 .47123 .63044 .4626 Metetra
.674 .637 .805 r
.63044 .4626 .63485 .47123 .64344 .46681 .63907 .45902 Metetra
.681 .66 .823 r
.63907 .45902 .64344 .46681 .65205 .46229 .64773 .45538 Metetra
.686 .686 .844 r
.64773 .45538 .65205 .46229 .66067 .45782 .6564 .45177 Metetra
.689 .715 .869 r
.6564 .45177 .66067 .45782 .66932 .45353 .66511 .44824 Metetra
.687 .743 .894 r
.66511 .44824 .66932 .45353 .67801 .44957 .67384 .44488 Metetra
.679 .766 .917 r
.67384 .44488 .67801 .44957 .68674 .44605 .68261 .44173 Metetra
.668 .781 .934 r
.68261 .44173 .68674 .44605 .69551 .44295 .69141 .43879 Metetra
.657 .786 .943 r
.69141 .43879 .69551 .44295 .70433 .4402 .70025 .43602 Metetra
.65 .783 .945 r
.70025 .43602 .70433 .4402 .7132 .43772 .70913 .43337 Metetra
.647 .775 .941 r
.70913 .43337 .7132 .43772 .7221 .43538 .71804 .4308 Metetra
.647 .765 .934 r
.71804 .4308 .7221 .43538 .73103 .4331 .72698 .42826 Metetra
.649 .754 .926 r
.72698 .42826 .73103 .4331 .74 .43082 .73595 .4257 Metetra
.651 .743 .917 r
.73595 .4257 .74 .43082 .74899 .42847 .74495 .42312 Metetra
.655 .735 .909 r
.74495 .42312 .74899 .42847 .75801 .42598 .75397 .42045 Metetra
.658 .73 .902 r
.75397 .42045 .75801 .42598 .76704 .4233 .76302 .41768 Metetra
.662 .728 .899 r
.76302 .41768 .76704 .4233 .77609 .42046 .77209 .41483 Metetra
.664 .73 .898 r
.77209 .41483 .77609 .42046 .78516 .41749 .78118 .41191 Metetra
.666 .733 .9 r
.78118 .41191 .78516 .41749 .79425 .41445 .7903 .40895 Metetra
.666 .737 .903 r
.7903 .40895 .79425 .41445 .80337 .41139 .79944 .40597 Metetra
.665 .741 .906 r
.79944 .40597 .80337 .41139 .81251 .40833 .80862 .403 Metetra
.665 .745 .91 r
.80862 .403 .81251 .40833 .82169 .40529 .81782 .40002 Metetra
.664 .748 .913 r
.81782 .40002 .82169 .40529 .8309 .40229 .82706 .39706 Metetra
.663 .75 .915 r
.82706 .39706 .8309 .40229 .84014 .39934 .83633 .39412 Metetra
.661 .751 .916 r
.83633 .39412 .84014 .39934 .84942 .39643 .84563 .3912 Metetra
.66 .75 .917 r
.84563 .3912 .84942 .39643 .85874 .39357 .85496 .3883 Metetra
.659 .749 .916 r
.85496 .3883 .85874 .39357 .86808 .39073 .86433 .3854 Metetra
.659 .747 .915 r
.86433 .3854 .86808 .39073 .87746 .38788 .87372 .3825 Metetra
.66 .746 .913 r
.87372 .3825 .87746 .38788 .88687 .38501 .88315 .37957 Metetra
.66 .744 .912 r
.88315 .37957 .88687 .38501 .89631 .38212 .8926 .37664 Metetra
.661 .743 .911 r
.8926 .37664 .89631 .38212 .90577 .3792 .90209 .37368 Metetra
.661 .743 .911 r
.90209 .37368 .90577 .3792 .91526 .37625 .9116 .37071 Metetra
.661 .743 .911 r
.31528 .55175 .32018 .55625 .3279 .55382 .32301 .54932 Metetra
.661 .744 .911 r
.32301 .54932 .3279 .55382 .33564 .55139 .33077 .54687 Metetra
.661 .744 .911 r
.33077 .54687 .33564 .55139 .34341 .54894 .33855 .54443 Metetra
.661 .744 .912 r
.33855 .54443 .34341 .54894 .3512 .54648 .34635 .54198 Metetra
.661 .745 .913 r
.34635 .54198 .3512 .54648 .35901 .54401 .35418 .53952 Metetra
.661 .747 .914 r
.35418 .53952 .35901 .54401 .36685 .54153 .36203 .53706 Metetra
.661 .748 .915 r
.36203 .53706 .36685 .54153 .37471 .53905 .3699 .53459 Metetra
.661 .749 .915 r
.3699 .53459 .37471 .53905 .38259 .53658 .37779 .5321 Metetra
.662 .749 .915 r
.37779 .5321 .38259 .53658 .39049 .53411 .38571 .5296 Metetra
.662 .748 .914 r
.38571 .5296 .39049 .53411 .39842 .53166 .39366 .52708 Metetra
.662 .746 .912 r
.39366 .52708 .39842 .53166 .40637 .52922 .40162 .52455 Metetra
.663 .743 .91 r
.40162 .52455 .40637 .52922 .41434 .52677 .40961 .52201 Metetra
.663 .739 .907 r
.40961 .52201 .41434 .52677 .42234 .52433 .41763 .51946 Metetra
.663 .735 .904 r
.41763 .51946 .42234 .52433 .43036 .52188 .42567 .5169 Metetra
.662 .731 .901 r
.42567 .5169 .43036 .52188 .4384 .51941 .43373 .51434 Metetra
.662 .728 .899 r
.43373 .51434 .4384 .51941 .44648 .51688 .44181 .51179 Metetra
.66 .728 .899 r
.44181 .51179 .44648 .51688 .45457 .51428 .44992 .50926 Metetra
.659 .73 .902 r
.44992 .50926 .45457 .51428 .46269 .51161 .45806 .50675 Metetra
.658 .737 .908 r
.45806 .50675 .46269 .51161 .47084 .50887 .46621 .50426 Metetra
.657 .748 .917 r
.46621 .50426 .47084 .50887 .47901 .5061 .4744 .50177 Metetra
.656 .761 .927 r
.4744 .50177 .47901 .5061 .4872 .50333 .4826 .49927 Metetra
.655 .775 .937 r
.4826 .49927 .4872 .50333 .49542 .50056 .49083 .49676 Metetra
.654 .788 .945 r
.49083 .49676 .49542 .50056 .50366 .49786 .49909 .49421 Metetra
.656 .797 .95 r
.49909 .49421 .50366 .49786 .51192 .49525 .50738 .4916 Metetra
.659 .798 .949 r
.50738 .4916 .51192 .49525 .52021 .4928 .51568 .48892 Metetra
.665 .789 .94 r
.51568 .48892 .52021 .4928 .52853 .49054 .52402 .48615 Metetra
.672 .767 .922 r
.52402 .48615 .52853 .49054 .53687 .48849 .53238 .48328 Metetra
.674 .734 .895 r
.53238 .48328 .53687 .48849 .54524 .4866 .54076 .48034 Metetra
.672 .695 .863 r
.54076 .48034 .54524 .4866 .55364 .4848 .54916 .47734 Metetra
.666 .658 .833 r
.54916 .47734 .55364 .4848 .56208 .48303 .55759 .47432 Metetra
.659 .626 .805 r
.55759 .47432 .56208 .48303 .57054 .48125 .56604 .47129 Metetra
.651 .599 .783 r
.56604 .47129 .57054 .48125 .57903 .47935 .57452 .4683 Metetra
.644 .578 .766 r
.57452 .4683 .57903 .47935 .58755 .47727 .58303 .46538 Metetra
.638 .564 .755 r
.58303 .46538 .58755 .47727 .59609 .47494 .59156 .46254 Metetra
.634 .555 .749 r
.59156 .46254 .59609 .47494 .60465 .47229 .60012 .45983 Metetra
.631 .553 .749 r
.60012 .45983 .60465 .47229 .61323 .4693 .6087 .45725 Metetra
.63 .558 .755 r
.6087 .45725 .61323 .4693 .62183 .46605 .61732 .45477 Metetra
.631 .569 .767 r
.61732 .45477 .62183 .46605 .63044 .4626 .62597 .45236 Metetra
.633 .587 .785 r
.62597 .45236 .63044 .4626 .63907 .45902 .63465 .44999 Metetra
.637 .612 .808 r
.63465 .44999 .63907 .45902 .64773 .45538 .64336 .44763 Metetra
.642 .645 .838 r
.64336 .44763 .64773 .45538 .6564 .45177 .6521 .44525 Metetra
.647 .684 .871 r
.6521 .44525 .6564 .45177 .66511 .44824 .66086 .44282 Metetra
.65 .726 .904 r
.66086 .44282 .66511 .44824 .67384 .44488 .66965 .44032 Metetra
.652 .765 .932 r
.66965 .44032 .67384 .44488 .68261 .44173 .67847 .43771 Metetra
.652 .792 .949 r
.67847 .43771 .68261 .44173 .69141 .43879 .68731 .435 Metetra
.654 .805 .956 r
.68731 .435 .69141 .43879 .70025 .43602 .69617 .43221 Metetra
.657 .806 .954 r
.69617 .43221 .70025 .43602 .70913 .43337 .70506 .42935 Metetra
.661 .797 .947 r
.70506 .42935 .70913 .43337 .71804 .4308 .71397 .42645 Metetra
.664 .782 .937 r
.71397 .42645 .71804 .4308 .72698 .42826 .72291 .42352 Metetra
.665 .766 .925 r
.72291 .42352 .72698 .42826 .73595 .4257 .73188 .42059 Metetra
.665 .75 .913 r
.73188 .42059 .73595 .4257 .74495 .42312 .74087 .41766 Metetra
.664 .736 .903 r
.74087 .41766 .74495 .42312 .75397 .42045 .7499 .41475 Metetra
.663 .726 .896 r
.7499 .41475 .75397 .42045 .76302 .41768 .75896 .41187 Metetra
.661 .722 .894 r
.75896 .41187 .76302 .41768 .77209 .41483 .76804 .40901 Metetra
.66 .722 .894 r
.76804 .40901 .77209 .41483 .78118 .41191 .77716 .40616 Metetra
.66 .725 .898 r
.77716 .40616 .78118 .41191 .7903 .40895 .78631 .40332 Metetra
.66 .731 .902 r
.78631 .40332 .7903 .40895 .79944 .40597 .79549 .40048 Metetra
.66 .737 .907 r
.79549 .40048 .79944 .40597 .80862 .403 .8047 .39762 Metetra
.66 .742 .911 r
.8047 .39762 .80862 .403 .81782 .40002 .81394 .39475 Metetra
.66 .747 .915 r
.81394 .39475 .81782 .40002 .82706 .39706 .8232 .39185 Metetra
.661 .751 .917 r
.8232 .39185 .82706 .39706 .83633 .39412 .8325 .38894 Metetra
.661 .753 .919 r
.8325 .38894 .83633 .39412 .84563 .3912 .84182 .38601 Metetra
.661 .754 .918 r
.84182 .38601 .84563 .3912 .85496 .3883 .85117 .38305 Metetra
.662 .752 .917 r
.85117 .38305 .85496 .3883 .86433 .3854 .86055 .38008 Metetra
.662 .75 .915 r
.86055 .38008 .86433 .3854 .87372 .3825 .86996 .3771 Metetra
.662 .747 .913 r
.86996 .3771 .87372 .3825 .88315 .37957 .87941 .37411 Metetra
.662 .745 .912 r
.87941 .37411 .88315 .37957 .8926 .37664 .88888 .37111 Metetra
.662 .744 .911 r
.88888 .37111 .8926 .37664 .90209 .37368 .89838 .36811 Metetra
.662 .742 .91 r
.89838 .36811 .90209 .37368 .9116 .37071 .90792 .3651 Metetra
.661 .743 .911 r
.31035 .54723 .31528 .55175 .32301 .54932 .3181 .54478 Metetra
.661 .743 .911 r
.3181 .54478 .32301 .54932 .33077 .54687 .32587 .54234 Metetra
.66 .744 .912 r
.32587 .54234 .33077 .54687 .33855 .54443 .33366 .53989 Metetra
.66 .744 .912 r
.33366 .53989 .33855 .54443 .34635 .54198 .34148 .53745 Metetra
.659 .745 .913 r
.34148 .53745 .34635 .54198 .35418 .53952 .34932 .53502 Metetra
.659 .746 .915 r
.34932 .53502 .35418 .53952 .36203 .53706 .35718 .53258 Metetra
.66 .748 .915 r
.35718 .53258 .36203 .53706 .3699 .53459 .36506 .53011 Metetra
.661 .75 .916 r
.36506 .53011 .3699 .53459 .37779 .5321 .37297 .52761 Metetra
.663 .75 .915 r
.37297 .52761 .37779 .5321 .38571 .5296 .38091 .52507 Metetra
.665 .749 .913 r
.38091 .52507 .38571 .5296 .39366 .52708 .38887 .52248 Metetra
.666 .747 .911 r
.38887 .52248 .39366 .52708 .40162 .52455 .39685 .51986 Metetra
.667 .744 .908 r
.39685 .51986 .40162 .52455 .40961 .52201 .40486 .51721 Metetra
.668 .74 .904 r
.40486 .51721 .40961 .52201 .41763 .51946 .4129 .51454 Metetra
.668 .736 .901 r
.4129 .51454 .41763 .51946 .42567 .5169 .42095 .51185 Metetra
.666 .731 .898 r
.42095 .51185 .42567 .5169 .43373 .51434 .42903 .5092 Metetra
.662 .726 .897 r
.42903 .5092 .43373 .51434 .44181 .51179 .43713 .50663 Metetra
.656 .724 .899 r
.43713 .50663 .44181 .51179 .44992 .50926 .44525 .50417 Metetra
.65 .726 .904 r
.44525 .50417 .44992 .50926 .45806 .50675 .45339 .50185 Metetra
.644 .732 .913 r
.45339 .50185 .45806 .50675 .46621 .50426 .46156 .49963 Metetra
.64 .744 .924 r
.46156 .49963 .46621 .50426 .4744 .50177 .46975 .49746 Metetra
.638 .759 .935 r
.46975 .49746 .4744 .50177 .4826 .49927 .47797 .49528 Metetra
.638 .774 .946 r
.47797 .49528 .4826 .49927 .49083 .49676 .48622 .49305 Metetra
.642 .79 .953 r
.48622 .49305 .49083 .49676 .49909 .49421 .49449 .49068 Metetra
.653 .803 .955 r
.49449 .49068 .49909 .49421 .50738 .4916 .5028 .48807 Metetra
.671 .808 .949 r
.5028 .48807 .50738 .4916 .51568 .48892 .51113 .48514 Metetra
.693 .801 .932 r
.51113 .48514 .51568 .48892 .52402 .48615 .51948 .48179 Metetra
.711 .779 .906 r
.51948 .48179 .52402 .48615 .53238 .48328 .52786 .47801 Metetra
.717 .744 .873 r
.52786 .47801 .53238 .48328 .54076 .48034 .53625 .47388 Metetra
.713 .704 .84 r
.53625 .47388 .54076 .48034 .54916 .47734 .54466 .46953 Metetra
.703 .665 .81 r
.54466 .46953 .54916 .47734 .55759 .47432 .55309 .4651 Metetra
.69 .63 .784 r
.55309 .4651 .55759 .47432 .56604 .47129 .56153 .46069 Metetra
.675 .601 .764 r
.56153 .46069 .56604 .47129 .57452 .4683 .57 .45648 Metetra
.661 .577 .75 r
.57 .45648 .57452 .4683 .58303 .46538 .57848 .4526 Metetra
.646 .558 .741 r
.57848 .4526 .58303 .46538 .59156 .46254 .587 .44922 Metetra
.631 .544 .737 r
.587 .44922 .59156 .46254 .60012 .45983 .59555 .44645 Metetra
.617 .535 .739 r
.59555 .44645 .60012 .45983 .6087 .45725 .60415 .44431 Metetra
.607 .535 .747 r
.60415 .44431 .6087 .45725 .61732 .45477 .61279 .44269 Metetra
.599 .541 .761 r
.61279 .44269 .61732 .45477 .62597 .45236 .62147 .44144 Metetra
.594 .555 .781 r
.62147 .44144 .62597 .45236 .63465 .44999 .6302 .44044 Metetra
.591 .579 .808 r
.6302 .44044 .63465 .44999 .64336 .44763 .63896 .43951 Metetra
.592 .613 .842 r
.63896 .43951 .64336 .44763 .6521 .44525 .64776 .43852 Metetra
.595 .655 .879 r
.64776 .43852 .6521 .44525 .66086 .44282 .65659 .43733 Metetra
.603 .706 .916 r
.65659 .43733 .66086 .44282 .66965 .44032 .66544 .4358 Metetra
.618 .756 .944 r
.66544 .4358 .66965 .44032 .67847 .43771 .67431 .43381 Metetra
.635 .793 .958 r
.67431 .43381 .67847 .43771 .68731 .435 .68318 .43136 Metetra
.652 .813 .961 r
.68318 .43136 .68731 .435 .69617 .43221 .69207 .42854 Metetra
.668 .818 .955 r
.69207 .42854 .69617 .43221 .70506 .42935 .70097 .42544 Metetra
.678 .809 .945 r
.70097 .42544 .70506 .42935 .71397 .42645 .70988 .42217 Metetra
.683 .793 .933 r
.70988 .42217 .71397 .42645 .72291 .42352 .71882 .41882 Metetra
.684 .775 .92 r
.71882 .41882 .72291 .42352 .73188 .42059 .72778 .41546 Metetra
.681 .756 .908 r
.72778 .41546 .73188 .42059 .74087 .41766 .73678 .41214 Metetra
.675 .739 .899 r
.73678 .41214 .74087 .41766 .7499 .41475 .7458 .40896 Metetra
.667 .726 .893 r
.7458 .40896 .7499 .41475 .75896 .41187 .75487 .40594 Metetra
.661 .719 .892 r
.75487 .40594 .75896 .41187 .76804 .40901 .76398 .40308 Metetra
.656 .717 .894 r
.76398 .40308 .76804 .40901 .77716 .40616 .77312 .40032 Metetra
.653 .72 .898 r
.77312 .40032 .77716 .40616 .78631 .40332 .7823 .39763 Metetra
.653 .726 .903 r
.7823 .39763 .78631 .40332 .79549 .40048 .79151 .39493 Metetra
.653 .733 .908 r
.79151 .39493 .79549 .40048 .8047 .39762 .80076 .39221 Metetra
.654 .74 .913 r
.80076 .39221 .8047 .39762 .81394 .39475 .81003 .38945 Metetra
.656 .746 .916 r
.81003 .38945 .81394 .39475 .8232 .39185 .81932 .38664 Metetra
.658 .751 .919 r
.81932 .38664 .8232 .39185 .8325 .38894 .82864 .38376 Metetra
.661 .754 .919 r
.82864 .38376 .8325 .38894 .84182 .38601 .83799 .38081 Metetra
.663 .755 .919 r
.83799 .38081 .84182 .38601 .85117 .38305 .84736 .37779 Metetra
.665 .754 .917 r
.84736 .37779 .85117 .38305 .86055 .38008 .85676 .37474 Metetra
.665 .752 .915 r
.85676 .37474 .86055 .38008 .86996 .3771 .86618 .37167 Metetra
.664 .749 .913 r
.86618 .37167 .86996 .3771 .87941 .37411 .87564 .36861 Metetra
.664 .746 .911 r
.87564 .36861 .87941 .37411 .88888 .37111 .88513 .36556 Metetra
.663 .744 .91 r
.88513 .36556 .88888 .37111 .89838 .36811 .89465 .36251 Metetra
.662 .742 .909 r
.89465 .36251 .89838 .36811 .90792 .3651 .90421 .35946 Metetra
.661 .743 .911 r
.3054 .54268 .31035 .54723 .3181 .54478 .31316 .54022 Metetra
.66 .743 .911 r
.31316 .54022 .3181 .54478 .32587 .54234 .32094 .53777 Metetra
.66 .743 .912 r
.32094 .53777 .32587 .54234 .33366 .53989 .32875 .53533 Metetra
.659 .744 .913 r
.32875 .53533 .33366 .53989 .34148 .53745 .33658 .5329 Metetra
.658 .745 .914 r
.33658 .5329 .34148 .53745 .34932 .53502 .34443 .53048 Metetra
.657 .746 .915 r
.34443 .53048 .34932 .53502 .35718 .53258 .3523 .52807 Metetra
.659 .748 .916 r
.3523 .52807 .35718 .53258 .36506 .53011 .3602 .52561 Metetra
.661 .75 .916 r
.3602 .52561 .36506 .53011 .37297 .52761 .36813 .5231 Metetra
.664 .75 .914 r
.36813 .5231 .37297 .52761 .38091 .52507 .37608 .52051 Metetra
.668 .75 .912 r
.37608 .52051 .38091 .52507 .38887 .52248 .38406 .51786 Metetra
.67 .748 .909 r
.38406 .51786 .38887 .52248 .39685 .51986 .39206 .51514 Metetra
.671 .745 .906 r
.39206 .51514 .39685 .51986 .40486 .51721 .40009 .51238 Metetra
.672 .741 .902 r
.40009 .51238 .40486 .51721 .4129 .51454 .40814 .50959 Metetra
.673 .737 .899 r
.40814 .50959 .4129 .51454 .42095 .51185 .41621 .50678 Metetra
.669 .732 .897 r
.41621 .50678 .42095 .51185 .42903 .5092 .42431 .50404 Metetra
.662 .727 .897 r
.42431 .50404 .42903 .5092 .43713 .50663 .43242 .50145 Metetra
.653 .723 .901 r
.43242 .50145 .43713 .50663 .44525 .50417 .44056 .49906 Metetra
.64 .723 .908 r
.44056 .49906 .44525 .50417 .45339 .50185 .44871 .49692 Metetra
.629 .728 .918 r
.44871 .49692 .45339 .50185 .46156 .49963 .45688 .49498 Metetra
.622 .738 .93 r
.45688 .49498 .46156 .49963 .46975 .49746 .46509 .49312 Metetra
.619 .752 .941 r
.46509 .49312 .46975 .49746 .47797 .49528 .47332 .49125 Metetra
.62 .769 .951 r
.47332 .49125 .47797 .49528 .48622 .49305 .48158 .4893 Metetra
.63 .786 .957 r
.48158 .4893 .48622 .49305 .49449 .49068 .48987 .48711 Metetra
.653 .802 .955 r
.48987 .48711 .49449 .49068 .5028 .48807 .49819 .4845 Metetra
.684 .81 .943 r
.49819 .4845 .5028 .48807 .51113 .48514 .50654 .48131 Metetra
.718 .806 .92 r
.50654 .48131 .51113 .48514 .51948 .48179 .51492 .4774 Metetra
.743 .785 .887 r
.51492 .4774 .51948 .48179 .52786 .47801 .52331 .47271 Metetra
.751 .753 .853 r
.52331 .47271 .52786 .47801 .53625 .47388 .53172 .46741 Metetra
.746 .715 .822 r
.53172 .46741 .53625 .47388 .54466 .46953 .54014 .46174 Metetra
.735 .678 .795 r
.54014 .46174 .54466 .46953 .55309 .4651 .54857 .4559 Metetra
.719 .644 .774 r
.54857 .4559 .55309 .4651 .56153 .46069 .55701 .45014 Metetra
.7 .614 .757 r
.55701 .45014 .56153 .46069 .57 .45648 .56546 .44473 Metetra
.679 .588 .746 r
.56546 .44473 .57 .45648 .57848 .4526 .57394 .43993 Metetra
.657 .565 .74 r
.57394 .43993 .57848 .4526 .587 .44922 .58244 .43599 Metetra
.632 .545 .739 r
.58244 .43599 .587 .44922 .59555 .44645 .59099 .43316 Metetra
.608 .531 .742 r
.59099 .43316 .59555 .44645 .60415 .44431 .59959 .43146 Metetra
.586 .524 .752 r
.59959 .43146 .60415 .44431 .61279 .44269 .60825 .43068 Metetra
.567 .525 .767 r
.60825 .43068 .61279 .44269 .62147 .44144 .61696 .43058 Metetra
.551 .533 .789 r
.61696 .43058 .62147 .44144 .6302 .44044 .62573 .43092 Metetra
.54 .553 .817 r
.62573 .43092 .6302 .44044 .63896 .43951 .63455 .4314 Metetra
.533 .584 .852 r
.63455 .4314 .63896 .43951 .64776 .43852 .64341 .43178 Metetra
.534 .627 .89 r
.64341 .43178 .64776 .43852 .65659 .43733 .6523 .43182 Metetra
.549 .683 .927 r
.6523 .43182 .65659 .43733 .66544 .4358 .6612 .43125 Metetra
.581 .741 .952 r
.6612 .43125 .66544 .4358 .67431 .43381 .67012 .42986 Metetra
.619 .787 .962 r
.67012 .42986 .67431 .43381 .68318 .43136 .67903 .42767 Metetra
.653 .813 .96 r
.67903 .42767 .68318 .43136 .69207 .42854 .68794 .42483 Metetra
.68 .82 .951 r
.68794 .42483 .69207 .42854 .70097 .42544 .69685 .42149 Metetra
.695 .813 .938 r
.69685 .42149 .70097 .42544 .70988 .42217 .70577 .41785 Metetra
.701 .798 .925 r
.70577 .41785 .70988 .42217 .71882 .41882 .7147 .41408 Metetra
.701 .78 .913 r
.7147 .41408 .71882 .41882 .72778 .41546 .72366 .41029 Metetra
.696 .761 .902 r
.72366 .41029 .72778 .41546 .73678 .41214 .73265 .4066 Metetra
.685 .742 .895 r
.73265 .4066 .73678 .41214 .7458 .40896 .74168 .40314 Metetra
.672 .728 .892 r
.74168 .40314 .7458 .40896 .75487 .40594 .75076 .4 Metetra
.66 .719 .892 r
.75076 .4 .75487 .40594 .76398 .40308 .75989 .39713 Metetra
.652 .716 .895 r
.75989 .39713 .76398 .40308 .77312 .40032 .76906 .39446 Metetra
.647 .718 .9 r
.76906 .39446 .77312 .40032 .7823 .39763 .77827 .3919 Metetra
.646 .724 .905 r
.77827 .3919 .7823 .39763 .79151 .39493 .78752 .38935 Metetra
.647 .731 .91 r
.78752 .38935 .79151 .39493 .80076 .39221 .79679 .38676 Metetra
.648 .737 .914 r
.79679 .38676 .80076 .39221 .81003 .38945 .80609 .38412 Metetra
.652 .744 .918 r
.80609 .38412 .81003 .38945 .81932 .38664 .81542 .38139 Metetra
.656 .75 .919 r
.81542 .38139 .81932 .38664 .82864 .38376 .82477 .37854 Metetra
.661 .754 .919 r
.82477 .37854 .82864 .38376 .83799 .38081 .83413 .37557 Metetra
.665 .756 .918 r
.83413 .37557 .83799 .38081 .84736 .37779 .84352 .3725 Metetra
.667 .755 .916 r
.84352 .3725 .84736 .37779 .85676 .37474 .85294 .36937 Metetra
.668 .753 .914 r
.85294 .36937 .85676 .37474 .86618 .37167 .86238 .36622 Metetra
.667 .75 .912 r
.86238 .36622 .86618 .37167 .87564 .36861 .87185 .36308 Metetra
.665 .747 .911 r
.87185 .36308 .87564 .36861 .88513 .36556 .88136 .35997 Metetra
.664 .745 .91 r
.88136 .35997 .88513 .36556 .89465 .36251 .8909 .35687 Metetra
.663 .743 .909 r
.8909 .35687 .89465 .36251 .90421 .35946 .90048 .35379 Metetra
.661 .743 .911 r
.30042 .53811 .3054 .54268 .31316 .54022 .30819 .53564 Metetra
.66 .743 .912 r
.30819 .53564 .31316 .54022 .32094 .53777 .31599 .53319 Metetra
.659 .743 .912 r
.31599 .53319 .32094 .53777 .32875 .53533 .32381 .53074 Metetra
.658 .744 .913 r
.32381 .53074 .32875 .53533 .33658 .5329 .33165 .52832 Metetra
.656 .744 .915 r
.33165 .52832 .33658 .5329 .34443 .53048 .33951 .52592 Metetra
.656 .745 .916 r
.33951 .52592 .34443 .53048 .3523 .52807 .3474 .52352 Metetra
.658 .747 .916 r
.3474 .52352 .3523 .52807 .3602 .52561 .35531 .52107 Metetra
.661 .749 .915 r
.35531 .52107 .3602 .52561 .36813 .5231 .36325 .51854 Metetra
.665 .75 .913 r
.36325 .51854 .36813 .5231 .37608 .52051 .37122 .51592 Metetra
.67 .75 .911 r
.37122 .51592 .37608 .52051 .38406 .51786 .37922 .5132 Metetra
.673 .749 .908 r
.37922 .5132 .38406 .51786 .39206 .51514 .38724 .5104 Metetra
.675 .746 .904 r
.38724 .5104 .39206 .51514 .40009 .51238 .39528 .50755 Metetra
.676 .743 .901 r
.39528 .50755 .40009 .51238 .40814 .50959 .40335 .50465 Metetra
.677 .74 .898 r
.40335 .50465 .40814 .50959 .41621 .50678 .41144 .50173 Metetra
.672 .734 .897 r
.41144 .50173 .41621 .50678 .42431 .50404 .41956 .49891 Metetra
.663 .729 .899 r
.41956 .49891 .42431 .50404 .43242 .50145 .42769 .49629 Metetra
.649 .725 .904 r
.42769 .49629 .43242 .50145 .44056 .49906 .43583 .49396 Metetra
.632 .722 .912 r
.43583 .49396 .44056 .49906 .44871 .49692 .44399 .49198 Metetra
.615 .724 .923 r
.44399 .49198 .44871 .49692 .45688 .49498 .45218 .49028 Metetra
.606 .732 .934 r
.45218 .49028 .45688 .49498 .46509 .49312 .46039 .4887 Metetra
.602 .744 .944 r
.46039 .4887 .46509 .49312 .47332 .49125 .46863 .4871 Metetra
.606 .759 .952 r
.46863 .4871 .47332 .49125 .48158 .4893 .47691 .48539 Metetra
.622 .777 .955 r
.47691 .48539 .48158 .4893 .48987 .48711 .48521 .48336 Metetra
.654 .794 .95 r
.48521 .48336 .48987 .48711 .49819 .4845 .49355 .48075 Metetra
.695 .805 .933 r
.49355 .48075 .49819 .4845 .50654 .48131 .50193 .47733 Metetra
.736 .803 .905 r
.50193 .47733 .50654 .48131 .51492 .4774 .51032 .47292 Metetra
.765 .786 .87 r
.51032 .47292 .51492 .4774 .52331 .47271 .51874 .46743 Metetra
.776 .759 .837 r
.51874 .46743 .52331 .47271 .53172 .46741 .52717 .4611 Metetra
.773 .727 .81 r
.52717 .4611 .53172 .46741 .54014 .46174 .5356 .45427 Metetra
.762 .695 .788 r
.5356 .45427 .54014 .46174 .54857 .4559 .54404 .44722 Metetra
.746 .665 .771 r
.54404 .44722 .54857 .4559 .55701 .45014 .55248 .44027 Metetra
.725 .636 .759 r
.55248 .44027 .55701 .45014 .56546 .44473 .56093 .43381 Metetra
.7 .609 .752 r
.56093 .43381 .56546 .44473 .57394 .43993 .5694 .4282 Metetra
.671 .584 .749 r
.5694 .4282 .57394 .43993 .58244 .43599 .5779 .4238 Metetra
.637 .56 .751 r
.5779 .4238 .58244 .43599 .59099 .43316 .58645 .42091 Metetra
.6 .539 .758 r
.58645 .42091 .59099 .43316 .59959 .43146 .59506 .41958 Metetra
.565 .525 .769 r
.59506 .41958 .59959 .43146 .60825 .43068 .60373 .41954 Metetra
.533 .518 .785 r
.60373 .41954 .60825 .43068 .61696 .43058 .61247 .42043 Metetra
.503 .52 .807 r
.61247 .42043 .61696 .43058 .62573 .43092 .62127 .42193 Metetra
.48 .533 .834 r
.62127 .42193 .62573 .43092 .63455 .4314 .63013 .42364 Metetra
.467 .56 .867 r
.63013 .42364 .63455 .4314 .64341 .43178 .63904 .42521 Metetra
.466 .601 .902 r
.63904 .42521 .64341 .43178 .6523 .43182 .64798 .42632 Metetra
.493 .658 .934 r
.64798 .42632 .6523 .43182 .6612 .43125 .65694 .42659 Metetra
.547 .723 .955 r
.65694 .42659 .6612 .43125 .67012 .42986 .66589 .42573 Metetra
.607 .774 .961 r
.66589 .42573 .67012 .42986 .67903 .42767 .67484 .42377 Metetra
.656 .804 .954 r
.67484 .42377 .67903 .42767 .68794 .42483 .68377 .4209 Metetra
.691 .814 .941 r
.68377 .4209 .68794 .42483 .69685 .42149 .69269 .41734 Metetra
.709 .809 .927 r
.69269 .41734 .69685 .42149 .70577 .41785 .70162 .41338 Metetra
.715 .797 .915 r
.70162 .41338 .70577 .41785 .7147 .41408 .71056 .40925 Metetra
.715 .781 .905 r
.71056 .40925 .7147 .41408 .72366 .41029 .71952 .40509 Metetra
.707 .764 .896 r
.71952 .40509 .72366 .41029 .73265 .4066 .72851 .40106 Metetra
.693 .747 .893 r
.72851 .40106 .73265 .4066 .74168 .40314 .73754 .39736 Metetra
.676 .732 .892 r
.73754 .39736 .74168 .40314 .75076 .4 .74664 .3941 Metetra
.66 .722 .895 r
.74664 .3941 .75076 .4 .75989 .39713 .75578 .39122 Metetra
.648 .717 .899 r
.75578 .39122 .75989 .39713 .76906 .39446 .76498 .38863 Metetra
.641 .718 .904 r
.76498 .38863 .76906 .39446 .77827 .3919 .77422 .38619 Metetra
.64 .723 .908 r
.77422 .38619 .77827 .3919 .78752 .38935 .7835 .38377 Metetra
.641 .729 .912 r
.7835 .38377 .78752 .38935 .79679 .38676 .7928 .38129 Metetra
.643 .736 .916 r
.7928 .38129 .79679 .38676 .80609 .38412 .80213 .37874 Metetra
.648 .742 .918 r
.80213 .37874 .80609 .38412 .81542 .38139 .81149 .37608 Metetra
.654 .749 .919 r
.81149 .37608 .81542 .38139 .82477 .37854 .82086 .37325 Metetra
.661 .753 .918 r
.82086 .37325 .82477 .37854 .83413 .37557 .83025 .37027 Metetra
.666 .755 .917 r
.83025 .37027 .83413 .37557 .84352 .3725 .83966 .36715 Metetra
.67 .755 .915 r
.83966 .36715 .84352 .3725 .85294 .36937 .84909 .36395 Metetra
.67 .753 .913 r
.84909 .36395 .85294 .36937 .86238 .36622 .85855 .36072 Metetra
.669 .75 .911 r
.85855 .36072 .86238 .36622 .87185 .36308 .86804 .35752 Metetra
.667 .747 .91 r
.86804 .35752 .87185 .36308 .88136 .35997 .87757 .35434 Metetra
.665 .745 .91 r
.87757 .35434 .88136 .35997 .8909 .35687 .88713 .3512 Metetra
.664 .743 .909 r
.88713 .3512 .8909 .35687 .90048 .35379 .89673 .34809 Metetra
.661 .744 .911 r
.29541 .53352 .30042 .53811 .30819 .53564 .3032 .53104 Metetra
.66 .743 .912 r
.3032 .53104 .30819 .53564 .31599 .53319 .31101 .52858 Metetra
.659 .743 .913 r
.31101 .52858 .31599 .53319 .32381 .53074 .31884 .52613 Metetra
.657 .743 .913 r
.31884 .52613 .32381 .53074 .33165 .52832 .3267 .5237 Metetra
.655 .743 .915 r
.3267 .5237 .33165 .52832 .33951 .52592 .33457 .52131 Metetra
.655 .744 .915 r
.33457 .52131 .33951 .52592 .3474 .52352 .34247 .51892 Metetra
.657 .746 .915 r
.34247 .51892 .3474 .52352 .35531 .52107 .3504 .51647 Metetra
.661 .747 .914 r
.3504 .51647 .35531 .52107 .36325 .51854 .35835 .51393 Metetra
.666 .748 .912 r
.35835 .51393 .36325 .51854 .37122 .51592 .36634 .51128 Metetra
.671 .749 .909 r
.36634 .51128 .37122 .51592 .37922 .5132 .37435 .5085 Metetra
.675 .749 .906 r
.37435 .5085 .37922 .5132 .38724 .5104 .38239 .50564 Metetra
.677 .747 .904 r
.38239 .50564 .38724 .5104 .39528 .50755 .39045 .50273 Metetra
.679 .746 .901 r
.39045 .50273 .39528 .50755 .40335 .50465 .39854 .49975 Metetra
.679 .743 .899 r
.39854 .49975 .40335 .50465 .41144 .50173 .40665 .49676 Metetra
.674 .739 .9 r
.40665 .49676 .41144 .50173 .41956 .49891 .41478 .49388 Metetra
.663 .735 .903 r
.41478 .49388 .41956 .49891 .42769 .49629 .42292 .49124 Metetra
.647 .729 .909 r
.42292 .49124 .42769 .49629 .43583 .49396 .43108 .48895 Metetra
.625 .725 .918 r
.43108 .48895 .43583 .49396 .44399 .49198 .43925 .48706 Metetra
.606 .723 .928 r
.43925 .48706 .44399 .49198 .45218 .49028 .44745 .48551 Metetra
.595 .726 .936 r
.44745 .48551 .45218 .49028 .46039 .4887 .45567 .4841 Metetra
.593 .734 .942 r
.45567 .4841 .46039 .4887 .46863 .4871 .46392 .48268 Metetra
.599 .745 .946 r
.46392 .48268 .46863 .4871 .47691 .48539 .47221 .48111 Metetra
.62 .759 .946 r
.47221 .48111 .47691 .48539 .48521 .48336 .48053 .47918 Metetra
.657 .776 .937 r
.48053 .47918 .48521 .48336 .49355 .48075 .48889 .47656 Metetra
.701 .787 .918 r
.48889 .47656 .49355 .48075 .50193 .47733 .49729 .47299 Metetra
.744 .789 .889 r
.49729 .47299 .50193 .47733 .51032 .47292 .50571 .46825 Metetra
.777 .781 .857 r
.50571 .46825 .51032 .47292 .51874 .46743 .51415 .46225 Metetra
.792 .765 .829 r
.51415 .46225 .51874 .46743 .52717 .4611 .5226 .45525 Metetra
.793 .745 .808 r
.5226 .45525 .52717 .4611 .5356 .45427 .53105 .44767 Metetra
.787 .724 .793 r
.53105 .44767 .5356 .45427 .54404 .44722 .5395 .43983 Metetra
.775 .702 .783 r
.5395 .43983 .54404 .44722 .55248 .44027 .54796 .43211 Metetra
.755 .679 .778 r
.54796 .43211 .55248 .44027 .56093 .43381 .55641 .42498 Metetra
.729 .657 .777 r
.55641 .42498 .56093 .43381 .5694 .4282 .56489 .41885 Metetra
.695 .632 .782 r
.56489 .41885 .5694 .4282 .5779 .4238 .57339 .41413 Metetra
.649 .606 .791 r
.57339 .41413 .5779 .4238 .58645 .42091 .58194 .41121 Metetra
.595 .578 .804 r
.58194 .41121 .58645 .42091 .59506 .41958 .59056 .41011 Metetra
.54 .554 .818 r
.59056 .41011 .59506 .41958 .60373 .41954 .59924 .41053 Metetra
.487 .536 .833 r
.59924 .41053 .60373 .41954 .61247 .42043 .608 .41205 Metetra
.44 .527 .85 r
.608 .41205 .61247 .42043 .62127 .42193 .61683 .4143 Metetra
.406 .531 .87 r
.61683 .4143 .62127 .42193 .63013 .42364 .62572 .41679 Metetra
.391 .55 .893 r
.62572 .41679 .63013 .42364 .63904 .42521 .63467 .41911 Metetra
.401 .586 .917 r
.63467 .41911 .63904 .42521 .64798 .42632 .64364 .42091 Metetra
.45 .642 .939 r
.64364 .42091 .64798 .42632 .65694 .42659 .65264 .42171 Metetra
.528 .706 .952 r
.65264 .42171 .65694 .42659 .66589 .42573 .66163 .42119 Metetra
.604 .754 .95 r
.66163 .42119 .66589 .42573 .67484 .42377 .67059 .41937 Metetra
.66 .782 .939 r
.67059 .41937 .67484 .42377 .68377 .4209 .67955 .41648 Metetra
.697 .793 .924 r
.67955 .41648 .68377 .4209 .69269 .41734 .68849 .41278 Metetra
.716 .793 .912 r
.68849 .41278 .69269 .41734 .70162 .41338 .69743 .4086 Metetra
.723 .786 .903 r
.69743 .4086 .70162 .41338 .71056 .40925 .70638 .40422 Metetra
.722 .777 .896 r
.70638 .40422 .71056 .40925 .71952 .40509 .71535 .39981 Metetra
.715 .765 .892 r
.71535 .39981 .71952 .40509 .72851 .40106 .72435 .39556 Metetra
.699 .752 .893 r
.72435 .39556 .72851 .40106 .73754 .39736 .73339 .39171 Metetra
.678 .739 .896 r
.73339 .39171 .73754 .39736 .74664 .3941 .7425 .38836 Metetra
.66 .729 .901 r
.7425 .38836 .74664 .3941 .75578 .39122 .75167 .38547 Metetra
.645 .724 .906 r
.75167 .38547 .75578 .39122 .76498 .38863 .76089 .38292 Metetra
.636 .722 .91 r
.76089 .38292 .76498 .38863 .77422 .38619 .77015 .38056 Metetra
.635 .725 .913 r
.77015 .38056 .77422 .38619 .7835 .38377 .77946 .37821 Metetra
.637 .73 .915 r
.77946 .37821 .7835 .38377 .7928 .38129 .78879 .37579 Metetra
.64 .735 .917 r
.78879 .37579 .7928 .38129 .80213 .37874 .79815 .3733 Metetra
.645 .74 .918 r
.79815 .3733 .80213 .37874 .81149 .37608 .80753 .37068 Metetra
.653 .746 .917 r
.80753 .37068 .81149 .37608 .82086 .37325 .81693 .36786 Metetra
.661 .75 .916 r
.81693 .36786 .82086 .37325 .83025 .37027 .82634 .36486 Metetra
.667 .752 .914 r
.82634 .36486 .83025 .37027 .83966 .36715 .83577 .36171 Metetra
.671 .753 .912 r
.83577 .36171 .83966 .36715 .84909 .36395 .84522 .35845 Metetra
.672 .752 .911 r
.84522 .35845 .84909 .36395 .85855 .36072 .8547 .35516 Metetra
.67 .75 .91 r
.8547 .35516 .85855 .36072 .86804 .35752 .86421 .35191 Metetra
.668 .747 .91 r
.86421 .35191 .86804 .35752 .87757 .35434 .87375 .3487 Metetra
.666 .746 .91 r
.87375 .3487 .87757 .35434 .88713 .3512 .88334 .34552 Metetra
.664 .744 .91 r
.88334 .34552 .88713 .3512 .89673 .34809 .89295 .34238 Metetra
.661 .744 .912 r
.29037 .52892 .29541 .53352 .3032 .53104 .29818 .52643 Metetra
.66 .744 .912 r
.29818 .52643 .3032 .53104 .31101 .52858 .306 .52395 Metetra
.659 .744 .913 r
.306 .52395 .31101 .52858 .31884 .52613 .31385 .52149 Metetra
.657 .743 .913 r
.31385 .52149 .31884 .52613 .3267 .5237 .32172 .51905 Metetra
.655 .743 .914 r
.32172 .51905 .3267 .5237 .33457 .52131 .32961 .51664 Metetra
.655 .743 .914 r
.32961 .51664 .33457 .52131 .34247 .51892 .33752 .51424 Metetra
.657 .743 .913 r
.33752 .51424 .34247 .51892 .3504 .51647 .34546 .51177 Metetra
.661 .744 .912 r
.34546 .51177 .3504 .51647 .35835 .51393 .35343 .50922 Metetra
.666 .746 .91 r
.35343 .50922 .35835 .51393 .36634 .51128 .36143 .50655 Metetra
.671 .747 .907 r
.36143 .50655 .36634 .51128 .37435 .5085 .36946 .50377 Metetra
.675 .748 .906 r
.36946 .50377 .37435 .5085 .38239 .50564 .37751 .50089 Metetra
.677 .748 .905 r
.37751 .50089 .38239 .50564 .39045 .50273 .38559 .49795 Metetra
.679 .749 .903 r
.38559 .49795 .39045 .50273 .39854 .49975 .39369 .49496 Metetra
.68 .749 .903 r
.39369 .49496 .39854 .49975 .40665 .49676 .40182 .49195 Metetra
.675 .747 .905 r
.40182 .49195 .40665 .49676 .41478 .49388 .40996 .48905 Metetra
.663 .744 .91 r
.40996 .48905 .41478 .49388 .42292 .49124 .41812 .4864 Metetra
.646 .739 .917 r
.41812 .4864 .42292 .49124 .43108 .48895 .4263 .4841 Metetra
.624 .732 .925 r
.4263 .4841 .43108 .48895 .43925 .48706 .43449 .4822 Metetra
.604 .726 .931 r
.43449 .4822 .43925 .48706 .44745 .48551 .44269 .48064 Metetra
.595 .723 .933 r
.44269 .48064 .44745 .48551 .45567 .4841 .45093 .47923 Metetra
.596 .724 .933 r
.45093 .47923 .45567 .4841 .46392 .48268 .4592 .4778 Metetra
.604 .727 .932 r
.4592 .4778 .46392 .48268 .47221 .48111 .4675 .47623 Metetra
.625 .734 .926 r
.4675 .47623 .47221 .48111 .48053 .47918 .47584 .47429 Metetra
.659 .746 .914 r
.47584 .47429 .48053 .47918 .48889 .47656 .48421 .47165 Metetra
.699 .757 .897 r
.48421 .47165 .48889 .47656 .49729 .47299 .49262 .46807 Metetra
.74 .766 .874 r
.49262 .46807 .49729 .47299 .50571 .46825 .50106 .46329 Metetra
.774 .771 .85 r
.50106 .46329 .50571 .46825 .51415 .46225 .50953 .45724 Metetra
.795 .773 .832 r
.50953 .45724 .51415 .46225 .5226 .45525 .518 .45019 Metetra
.806 .773 .822 r
.518 .45019 .5226 .45525 .53105 .44767 .52648 .44255 Metetra
.81 .772 .817 r
.52648 .44255 .53105 .44767 .5395 .43983 .53495 .43465 Metetra
.807 .77 .819 r
.53495 .43465 .5395 .43983 .54796 .43211 .54343 .42688 Metetra
.796 .768 .827 r
.54343 .42688 .54796 .43211 .55641 .42498 .55191 .41969 Metetra
.773 .763 .844 r
.55191 .41969 .55641 .42498 .56489 .41885 .56041 .41351 Metetra
.735 .754 .868 r
.56041 .41351 .56489 .41885 .57339 .41413 .56893 .40876 Metetra
.67 .734 .898 r
.56893 .40876 .57339 .41413 .58194 .41121 .5775 .40582 Metetra
.578 .699 .925 r
.5775 .40582 .58194 .41121 .59056 .41011 .58613 .40472 Metetra
.477 .654 .938 r
.58613 .40472 .59056 .41011 .59924 .41053 .59483 .40515 Metetra
.386 .609 .937 r
.59483 .40515 .59924 .41053 .608 .41205 .6036 .4067 Metetra
.319 .573 .931 r
.6036 .4067 .608 .41205 .61683 .4143 .61244 .40897 Metetra
.294 .56 .928 r
.61244 .40897 .61683 .4143 .62572 .41679 .62134 .41149 Metetra
.309 .571 .932 r
.62134 .41149 .62572 .41679 .63467 .41911 .6303 .41385 Metetra
.357 .6 .94 r
.6303 .41385 .63467 .41911 .64364 .42091 .63929 .41566 Metetra
.44 .646 .945 r
.63929 .41566 .64364 .42091 .65264 .42171 .6483 .41648 Metetra
.535 .694 .941 r
.6483 .41648 .65264 .42171 .66163 .42119 .6573 .41597 Metetra
.611 .727 .928 r
.6573 .41597 .66163 .42119 .67059 .41937 .66629 .41414 Metetra
.663 .747 .913 r
.66629 .41414 .67059 .41937 .67955 .41648 .67526 .41123 Metetra
.696 .758 .9 r
.67526 .41123 .67955 .41648 .68849 .41278 .68423 .40751 Metetra
.713 .764 .892 r
.68423 .40751 .68849 .41278 .69743 .4086 .69319 .4033 Metetra
.72 .765 .889 r
.69319 .4033 .69743 .4086 .70638 .40422 .70216 .39889 Metetra
.72 .765 .888 r
.70216 .39889 .70638 .40422 .71535 .39981 .71115 .39445 Metetra
.715 .763 .89 r
.71115 .39445 .71535 .39981 .72435 .39556 .72017 .39017 Metetra
.7 .757 .897 r
.72017 .39017 .72435 .39556 .73339 .39171 .72924 .38629 Metetra
.679 .75 .905 r
.72924 .38629 .73339 .39171 .7425 .38836 .73836 .38293 Metetra
.66 .743 .911 r
.73836 .38293 .7425 .38836 .75167 .38547 .74755 .38002 Metetra
.644 .737 .916 r
.74755 .38002 .75167 .38547 .76089 .38292 .75679 .37745 Metetra
.635 .733 .919 r
.75679 .37745 .76089 .38292 .77015 .38056 .76608 .37508 Metetra
.634 .733 .919 r
.76608 .37508 .77015 .38056 .77946 .37821 .7754 .37271 Metetra
.637 .734 .919 r
.7754 .37271 .77946 .37821 .78879 .37579 .78475 .37029 Metetra
.64 .735 .918 r
.78475 .37029 .78879 .37579 .79815 .3733 .79414 .36778 Metetra
.645 .738 .916 r
.79414 .36778 .79815 .3733 .80753 .37068 .80354 .36514 Metetra
.653 .741 .914 r
.80354 .36514 .80753 .37068 .81693 .36786 .81296 .36231 Metetra
.661 .745 .912 r
.81296 .36231 .81693 .36786 .82634 .36486 .82239 .3593 Metetra
.667 .747 .91 r
.82239 .3593 .82634 .36486 .83577 .36171 .83184 .35612 Metetra
.671 .749 .909 r
.83184 .35612 .83577 .36171 .84522 .35845 .84131 .35284 Metetra
.672 .749 .908 r
.84131 .35284 .84522 .35845 .8547 .35516 .85081 .34953 Metetra
.67 .748 .909 r
.85081 .34953 .8547 .35516 .86421 .35191 .86035 .34626 Metetra
.668 .747 .91 r
.86035 .34626 .86421 .35191 .87375 .3487 .86992 .34303 Metetra
.666 .746 .91 r
.86992 .34303 .87375 .3487 .88334 .34552 .87952 .33983 Metetra
.664 .745 .911 r
.87952 .33983 .88334 .34552 .89295 .34238 .88916 .33667 Metetra
.661 .745 .912 r
.28531 .52431 .29037 .52892 .29818 .52643 .29313 .5218 Metetra
.66 .744 .912 r
.29313 .5218 .29818 .52643 .306 .52395 .30096 .5193 Metetra
.659 .744 .913 r
.30096 .5193 .306 .52395 .31385 .52149 .30883 .51682 Metetra
.658 .743 .913 r
.30883 .51682 .31385 .52149 .32172 .51905 .31671 .51435 Metetra
.656 .742 .913 r
.31671 .51435 .32172 .51905 .32961 .51664 .32462 .5119 Metetra
.656 .741 .912 r
.32462 .5119 .32961 .51664 .33752 .51424 .33254 .50946 Metetra
.658 .741 .911 r
.33254 .50946 .33752 .51424 .34546 .51177 .3405 .50697 Metetra
.661 .741 .909 r
.3405 .50697 .34546 .51177 .35343 .50922 .34848 .5044 Metetra
.665 .742 .907 r
.34848 .5044 .35343 .50922 .36143 .50655 .3565 .50174 Metetra
.67 .744 .906 r
.3565 .50174 .36143 .50655 .36946 .50377 .36454 .49897 Metetra
.673 .746 .906 r
.36454 .49897 .36946 .50377 .37751 .50089 .3726 .49614 Metetra
.674 .749 .907 r
.3726 .49614 .37751 .50089 .38559 .49795 .3807 .49325 Metetra
.676 .752 .908 r
.3807 .49325 .38559 .49795 .39369 .49496 .38881 .49032 Metetra
.677 .755 .91 r
.38881 .49032 .39369 .49496 .40182 .49195 .39695 .48737 Metetra
.672 .757 .915 r
.39695 .48737 .40182 .49195 .40996 .48905 .40511 .48451 Metetra
.662 .757 .92 r
.40511 .48451 .40996 .48905 .41812 .4864 .41329 .48185 Metetra
.648 .753 .926 r
.41329 .48185 .41812 .4864 .4263 .4841 .42148 .47947 Metetra
.63 .745 .931 r
.42148 .47947 .4263 .4841 .43449 .4822 .42969 .47742 Metetra
.615 .734 .931 r
.42969 .47742 .43449 .4822 .44269 .48064 .43792 .47565 Metetra
.61 .724 .926 r
.43792 .47565 .44269 .48064 .45093 .47923 .44617 .474 Metetra
.612 .715 .918 r
.44617 .474 .45093 .47923 .4592 .4778 .45446 .47233 Metetra
.619 .708 .909 r
.45446 .47233 .4592 .4778 .4675 .47623 .46277 .47055 Metetra
.634 .706 .898 r
.46277 .47055 .4675 .47623 .47584 .47429 .47113 .46845 Metetra
.659 .709 .885 r
.47113 .46845 .47584 .47429 .48421 .47165 .47952 .4658 Metetra
.688 .719 .873 r
.47952 .4658 .48421 .47165 .49262 .46807 .48794 .46236 Metetra
.721 .734 .861 r
.48794 .46236 .49262 .46807 .50106 .46329 .4964 .45794 Metetra
.754 .755 .853 r
.4964 .45794 .50106 .46329 .50953 .45724 .50488 .45249 Metetra
.782 .782 .852 r
.50488 .45249 .50953 .45724 .518 .45019 .51337 .44621 Metetra
.804 .814 .86 r
.51337 .44621 .518 .45019 .52648 .44255 .52187 .43945 Metetra
.82 .853 .873 r
.52187 .43945 .52648 .44255 .53495 .43465 .53038 .43247 Metetra
.826 .897 .891 r
.53038 .43247 .53495 .43465 .54343 .42688 .53889 .42558 Metetra
.809 .941 .914 r
.53889 .42558 .54343 .42688 .55191 .41969 .54741 .41918 Metetra
.75 .971 .928 r
.54741 .41918 .55191 .41969 .56041 .41351 .55595 .4136 Metetra
.617 .954 .914 r
.55595 .4136 .56041 .41351 .56893 .40876 .56451 .40919 Metetra
.394 .852 .845 r
.56451 .40919 .56893 .40876 .5775 .40582 .57311 .40626 Metetra
.157 .698 .748 r
.57311 .40626 .5775 .40582 .58613 .40472 .58177 .40485 Metetra
.58177 .40485 .58613 .40472 .59483 .40515 .59048 .40468 Metetra
0 .538 .723 r
.59048 .40468 .59483 .40515 .6036 .4067 .59926 .40543 Metetra
0 .548 .8 r
.59926 .40543 .6036 .4067 .61244 .40897 .6081 .40676 Metetra
.092 .594 .896 r
.6081 .40676 .61244 .40897 .62134 .41149 .617 .40831 Metetra
.234 .639 .959 r
.617 .40831 .62134 .41149 .6303 .41385 .62594 .4097 Metetra
.368 .665 .972 r
.62594 .4097 .6303 .41385 .63929 .41566 .63492 .41066 Metetra
.482 .68 .953 r
.63492 .41066 .63929 .41566 .6483 .41648 .64392 .4108 Metetra
.568 .69 .923 r
.64392 .4108 .6483 .41648 .6573 .41597 .65292 .40984 Metetra
.625 .698 .897 r
.65292 .40984 .6573 .41597 .66629 .41414 .66192 .4078 Metetra
.661 .705 .88 r
.66192 .4078 .66629 .41414 .67526 .41123 .67091 .40488 Metetra
.685 .715 .872 r
.67091 .40488 .67526 .41123 .68423 .40751 .67989 .40129 Metetra
.699 .725 .87 r
.67989 .40129 .68423 .40751 .69319 .4033 .68889 .39731 Metetra
.706 .736 .875 r
.68889 .39731 .69319 .4033 .70216 .39889 .69789 .39316 Metetra
.708 .747 .882 r
.69789 .39316 .70216 .39889 .71115 .39445 .70692 .38898 Metetra
.705 .757 .892 r
.70692 .38898 .71115 .39445 .72017 .39017 .71598 .38493 Metetra
.694 .763 .905 r
.71598 .38493 .72017 .39017 .72924 .38629 .72508 .38121 Metetra
.676 .764 .917 r
.72508 .38121 .72924 .38629 .73836 .38293 .73423 .3779 Metetra
.659 .761 .925 r
.73423 .3779 .73836 .38293 .74755 .38002 .74344 .37497 Metetra
.646 .756 .929 r
.74344 .37497 .74755 .38002 .75679 .37745 .7527 .37232 Metetra
.638 .75 .929 r
.7527 .37232 .75679 .37745 .76608 .37508 .762 .36981 Metetra
.638 .745 .926 r
.762 .36981 .76608 .37508 .7754 .37271 .77133 .36732 Metetra
.641 .741 .922 r
.77133 .36732 .7754 .37271 .78475 .37029 .7807 .36478 Metetra
.644 .738 .918 r
.7807 .36478 .78475 .37029 .79414 .36778 .79009 .36216 Metetra
.649 .736 .913 r
.79009 .36216 .79414 .36778 .80354 .36514 .79951 .35944 Metetra
.655 .736 .909 r
.79951 .35944 .80354 .36514 .81296 .36231 .80895 .35656 Metetra
.661 .738 .907 r
.80895 .35656 .81296 .36231 .82239 .3593 .8184 .35352 Metetra
.666 .74 .905 r
.8184 .35352 .82239 .3593 .83184 .35612 .82788 .35035 Metetra
.669 .742 .905 r
.82788 .35035 .83184 .35612 .84131 .35284 .83738 .3471 Metetra
.67 .744 .906 r
.83738 .3471 .84131 .35284 .85081 .34953 .8469 .34382 Metetra
.668 .745 .908 r
.8469 .34382 .85081 .34953 .86035 .34626 .85647 .34056 Metetra
.667 .746 .909 r
.85647 .34056 .86035 .34626 .86992 .34303 .86606 .33734 Metetra
.665 .747 .911 r
.86606 .33734 .86992 .34303 .87952 .33983 .87569 .33414 Metetra
.664 .747 .912 r
.87569 .33414 .87952 .33983 .88916 .33667 .88536 .33098 Metetra
.661 .746 .913 r
.28021 .51969 .28531 .52431 .29313 .5218 .28805 .51716 Metetra
.661 .745 .913 r
.28805 .51716 .29313 .5218 .30096 .5193 .2959 .51464 Metetra
.66 .745 .912 r
.2959 .51464 .30096 .5193 .30883 .51682 .30378 .51211 Metetra
.66 .743 .912 r
.30378 .51211 .30883 .51682 .31671 .51435 .31168 .50959 Metetra
.659 .742 .911 r
.31168 .50959 .31671 .51435 .32462 .5119 .3196 .50708 Metetra
.659 .74 .909 r
.3196 .50708 .32462 .5119 .33254 .50946 .32755 .50457 Metetra
.66 .737 .907 r
.32755 .50457 .33254 .50946 .3405 .50697 .33552 .50203 Metetra
.661 .736 .905 r
.33552 .50203 .3405 .50697 .34848 .5044 .34352 .49944 Metetra
.663 .737 .905 r
.34352 .49944 .34848 .5044 .3565 .50174 .35154 .49681 Metetra
.665 .739 .905 r
.35154 .49681 .3565 .50174 .36454 .49897 .35959 .49412 Metetra
.667 .743 .907 r
.35959 .49412 .36454 .49897 .3726 .49614 .36767 .4914 Metetra
.668 .749 .911 r
.36767 .4914 .3726 .49614 .3807 .49325 .37577 .48864 Metetra
.669 .755 .915 r
.37577 .48864 .3807 .49325 .38881 .49032 .3839 .48586 Metetra
.669 .762 .92 r
.3839 .48586 .38881 .49032 .39695 .48737 .39204 .48306 Metetra
.666 .769 .927 r
.39204 .48306 .39695 .48737 .40511 .48451 .40022 .4803 Metetra
.661 .773 .933 r
.40022 .4803 .40511 .48451 .41329 .48185 .40841 .47764 Metetra
.653 .772 .936 r
.40841 .47764 .41329 .48185 .42148 .47947 .41662 .47512 Metetra
.645 .764 .935 r
.41662 .47512 .42148 .47947 .42969 .47742 .42486 .47275 Metetra
.639 .748 .928 r
.42486 .47275 .42969 .47742 .43792 .47565 .43311 .47052 Metetra
.638 .728 .914 r
.43311 .47052 .43792 .47565 .44617 .474 .44139 .46833 Metetra
.639 .708 .897 r
.44139 .46833 .44617 .474 .45446 .47233 .44971 .46614 Metetra
.641 .691 .88 r
.44971 .46614 .45446 .47233 .46277 .47055 .45804 .46389 Metetra
.647 .677 .865 r
.45804 .46389 .46277 .47055 .47113 .46845 .46642 .46147 Metetra
.656 .672 .853 r
.46642 .46147 .47113 .46845 .47952 .4658 .47482 .45878 Metetra
.669 .676 .848 r
.47482 .45878 .47952 .4658 .48794 .46236 .48325 .4557 Metetra
.687 .694 .851 r
.48325 .4557 .48794 .46236 .4964 .45794 .49171 .45213 Metetra
.709 .729 .866 r
.49171 .45213 .4964 .45794 .50488 .45249 .5002 .44805 Metetra
.734 .788 .896 r
.5002 .44805 .50488 .45249 .51337 .44621 .50871 .44355 Metetra
.749 .874 .937 r
.50871 .44355 .51337 .44621 .52187 .43945 .51723 .43881 Metetra
.711 .96 .946 r
.51723 .43881 .52187 .43945 .53038 .43247 .52578 .43395 Metetra
.508 .905 .784 r
.52578 .43395 .53038 .43247 .53889 .42558 .53434 .42914 Metetra
.53434 .42914 .53889 .42558 .54741 .41918 .54291 .42455 Metetra
.084 0 0 r
.54291 .42455 .54741 .41918 .55595 .4136 .55151 .42037 Metetra
.229 0 .006 r
.55151 .42037 .55595 .4136 .56451 .40919 .56013 .41677 Metetra
.313 0 .086 r
.56013 .41677 .56451 .40919 .57311 .40626 .56879 .41389 Metetra
.358 0 .112 r
.56879 .41389 .57311 .40626 .58177 .40485 .57748 .41176 Metetra
.373 0 .09 r
.57748 .41176 .58177 .40485 .59048 .40468 .58622 .41025 Metetra
.357 0 .014 r
.58622 .41025 .59048 .40468 .59926 .40543 .595 .40918 Metetra
.294 0 0 r
.595 .40918 .59926 .40543 .6081 .40676 .60382 .4084 Metetra
.121 0 0 r
.60382 .4084 .6081 .40676 .617 .40831 .61269 .40771 Metetra
.207 .727 .862 r
.61269 .40771 .617 .40831 .62594 .4097 .6216 .40694 Metetra
.472 .794 .999 r
.6216 .40694 .62594 .4097 .63492 .41066 .63054 .40595 Metetra
.579 .739 .952 r
.63054 .40595 .63492 .41066 .64392 .4108 .6395 .40455 Metetra
.621 .692 .895 r
.6395 .40455 .64392 .4108 .65292 .40984 .64848 .4026 Metetra
.642 .669 .861 r
.64848 .4026 .65292 .40984 .66192 .4078 .65747 .40012 Metetra
.656 .663 .845 r
.65747 .40012 .66192 .4078 .67091 .40488 .66647 .3972 Metetra
.666 .668 .842 r
.66647 .3972 .67091 .40488 .67989 .40129 .67549 .39394 Metetra
.674 .681 .849 r
.67549 .39394 .67989 .40129 .68889 .39731 .68452 .39049 Metetra
.68 .7 .862 r
.68452 .39049 .68889 .39731 .69789 .39316 .69358 .38695 Metetra
.683 .722 .879 r
.69358 .38695 .69789 .39316 .70692 .38898 .70266 .38339 Metetra
.684 .746 .898 r
.70266 .38339 .70692 .38898 .71598 .38493 .71177 .37988 Metetra
.678 .767 .918 r
.71177 .37988 .71598 .38493 .72508 .38121 .72092 .37654 Metetra
.668 .781 .934 r
.72092 .37654 .72508 .38121 .73423 .3779 .73011 .37339 Metetra
.658 .786 .942 r
.73011 .37339 .73423 .3779 .74344 .37497 .73934 .37042 Metetra
.651 .782 .944 r
.73934 .37042 .74344 .37497 .7527 .37232 .74861 .36759 Metetra
.648 .774 .94 r
.74861 .36759 .7527 .37232 .762 .36981 .75791 .36483 Metetra
.649 .763 .932 r
.75791 .36483 .762 .36981 .77133 .36732 .76725 .36206 Metetra
.651 .752 .924 r
.76725 .36206 .77133 .36732 .7807 .36478 .77662 .35926 Metetra
.653 .743 .916 r
.77662 .35926 .7807 .36478 .79009 .36216 .78602 .35643 Metetra
.655 .736 .909 r
.78602 .35643 .79009 .36216 .79951 .35944 .79545 .35354 Metetra
.658 .731 .903 r
.79545 .35354 .79951 .35944 .80895 .35656 .8049 .35056 Metetra
.661 .729 .9 r
.8049 .35056 .80895 .35656 .8184 .35352 .81437 .3475 Metetra
.664 .73 .899 r
.81437 .3475 .8184 .35352 .82788 .35035 .82388 .34437 Metetra
.665 .733 .901 r
.82388 .34437 .82788 .35035 .83738 .3471 .8334 .34119 Metetra
.665 .737 .903 r
.8334 .34119 .83738 .3471 .8469 .34382 .84296 .338 Metetra
.665 .741 .907 r
.84296 .338 .8469 .34382 .85647 .34056 .85256 .33482 Metetra
.664 .744 .91 r
.85256 .33482 .85647 .34056 .86606 .33734 .86218 .33164 Metetra
.663 .747 .912 r
.86218 .33164 .86606 .33734 .87569 .33414 .87184 .32847 Metetra
.662 .748 .914 r
.87184 .32847 .87569 .33414 .88536 .33098 .88153 .32531 Metetra
.662 .747 .913 r
.27509 .51506 .28021 .51969 .28805 .51716 .28294 .51251 Metetra
.662 .746 .913 r
.28294 .51251 .28805 .51716 .2959 .51464 .29081 .50995 Metetra
.662 .745 .912 r
.29081 .50995 .2959 .51464 .30378 .51211 .2987 .50738 Metetra
.662 .744 .911 r
.2987 .50738 .30378 .51211 .31168 .50959 .30662 .50479 Metetra
.663 .742 .909 r
.30662 .50479 .31168 .50959 .3196 .50708 .31456 .50218 Metetra
.663 .738 .906 r
.31456 .50218 .3196 .50708 .32755 .50457 .32253 .49957 Metetra
.662 .735 .903 r
.32253 .49957 .32755 .50457 .33552 .50203 .33052 .49695 Metetra
.661 .732 .902 r
.33052 .49695 .33552 .50203 .34352 .49944 .33853 .49435 Metetra
.66 .732 .903 r
.33853 .49435 .34352 .49944 .35154 .49681 .34656 .49177 Metetra
.659 .734 .905 r
.34656 .49177 .35154 .49681 .35959 .49412 .35462 .48921 Metetra
.658 .74 .91 r
.35462 .48921 .35959 .49412 .36767 .4914 .3627 .48667 Metetra
.657 .748 .917 r
.3627 .48667 .36767 .4914 .37577 .48864 .37081 .48412 Metetra
.656 .757 .924 r
.37081 .48412 .37577 .48864 .3839 .48586 .37894 .48159 Metetra
.655 .769 .933 r
.37894 .48159 .3839 .48586 .39204 .48306 .3871 .47904 Metetra
.655 .781 .941 r
.3871 .47904 .39204 .48306 .40022 .4803 .39528 .47646 Metetra
.657 .791 .946 r
.39528 .47646 .40022 .4803 .40841 .47764 .40349 .47381 Metetra
.662 .793 .944 r
.40349 .47381 .40841 .47764 .41662 .47512 .41173 .47106 Metetra
.669 .784 .935 r
.41173 .47106 .41662 .47512 .42486 .47275 .41999 .46819 Metetra
.674 .764 .918 r
.41999 .46819 .42486 .47275 .43311 .47052 .42829 .46523 Metetra
.675 .735 .895 r
.42829 .46523 .43311 .47052 .44139 .46833 .43661 .46222 Metetra
.671 .704 .872 r
.43661 .46222 .44139 .46833 .44971 .46614 .44495 .45921 Metetra
.666 .677 .851 r
.44495 .45921 .44971 .46614 .45804 .46389 .45331 .45622 Metetra
.659 .654 .834 r
.45331 .45622 .45804 .46389 .46642 .46147 .4617 .45332 Metetra
.652 .639 .825 r
.4617 .45332 .46642 .46147 .47482 .45878 .47011 .45058 Metetra
.644 .635 .827 r
.47011 .45058 .47482 .45878 .48325 .4557 .47855 .44807 Metetra
.636 .647 .844 r
.47855 .44807 .48325 .4557 .49171 .45213 .487 .44584 Metetra
.624 .684 .886 r
.487 .44584 .49171 .45213 .5002 .44805 .49549 .44393 Metetra
.592 .765 .962 r
.49549 .44393 .5002 .44805 .50871 .44355 .504 .44226 Metetra
.422 .834 .971 r
.504 .44226 .50871 .44355 .51723 .43881 .51255 .44074 Metetra
.041 0 0 r
.51255 .44074 .51723 .43881 .52578 .43395 .52112 .43927 Metetra
.311 0 0 r
.52112 .43927 .52578 .43395 .53434 .42914 .52973 .43777 Metetra
.401 .003 .164 r
.52973 .43777 .53434 .42914 .54291 .42455 .53838 .43611 Metetra
.435 .075 .253 r
.53838 .43611 .54291 .42455 .55151 .42037 .54706 .43419 Metetra
.445 .107 .297 r
.54706 .43419 .55151 .42037 .56013 .41677 .55576 .43188 Metetra
.443 .115 .313 r
.55576 .43188 .56013 .41677 .56879 .41389 .56449 .4291 Metetra
.431 .105 .31 r
.56449 .4291 .56879 .41389 .57748 .41176 .57324 .42583 Metetra
.408 .075 .286 r
.57324 .42583 .57748 .41176 .58622 .41025 .58201 .42216 Metetra
.367 .017 .233 r
.58201 .42216 .58622 .41025 .595 .40918 .59079 .4182 Metetra
.289 0 .124 r
.59079 .4182 .595 .40918 .60382 .4084 .5996 .41404 Metetra
.114 0 0 r
.5996 .41404 .60382 .4084 .61269 .40771 .60842 .40981 Metetra
.60842 .40981 .61269 .40771 .6216 .40694 .61726 .40561 Metetra
.662 .933 .969 r
.61726 .40561 .6216 .40694 .63054 .40595 .62613 .40155 Metetra
.702 .797 .924 r
.62613 .40155 .63054 .40595 .6395 .40455 .63503 .39773 Metetra
.679 .697 .86 r
.63503 .39773 .6395 .40455 .64848 .4026 .64397 .39424 Metetra
.66 .647 .827 r
.64397 .39424 .64848 .4026 .65747 .40012 .65294 .39106 Metetra
.648 .627 .814 r
.65294 .39106 .65747 .40012 .66647 .3972 .66196 .38815 Metetra
.643 .624 .817 r
.66196 .38815 .66647 .3972 .67549 .39394 .67101 .38542 Metetra
.641 .636 .83 r
.67101 .38542 .67549 .39394 .68452 .39049 .6801 .38281 Metetra
.643 .66 .851 r
.6801 .38281 .68452 .39049 .69358 .38695 .68922 .38024 Metetra
.645 .691 .878 r
.68922 .38024 .69358 .38695 .70266 .38339 .69837 .37766 Metetra
.647 .728 .908 r
.69837 .37766 .70266 .38339 .71177 .37988 .70755 .37503 Metetra
.649 .767 .935 r
.70755 .37503 .71177 .37988 .72092 .37654 .71676 .37229 Metetra
.651 .797 .953 r
.71676 .37229 .72092 .37654 .73011 .37339 .72599 .36941 Metetra
.654 .812 .959 r
.72599 .36941 .73011 .37339 .73934 .37042 .73524 .3664 Metetra
.659 .812 .957 r
.73524 .3664 .73934 .37042 .74861 .36759 .74452 .36329 Metetra
.664 .801 .948 r
.74452 .36329 .74861 .36759 .75791 .36483 .75383 .36012 Metetra
.666 .784 .936 r
.75383 .36012 .75791 .36483 .76725 .36206 .76316 .35693 Metetra
.667 .766 .924 r
.76316 .35693 .76725 .36206 .77662 .35926 .77252 .35375 Metetra
.667 .75 .913 r
.77252 .35375 .77662 .35926 .78602 .35643 .78192 .35058 Metetra
.665 .737 .903 r
.78192 .35058 .78602 .35643 .79545 .35354 .79134 .34743 Metetra
.663 .727 .897 r
.79134 .34743 .79545 .35354 .8049 .35056 .8008 .34431 Metetra
.661 .721 .894 r
.8008 .34431 .8049 .35056 .81437 .3475 .8103 .34123 Metetra
.66 .721 .894 r
.8103 .34123 .81437 .3475 .82388 .34437 .81983 .33817 Metetra
.659 .724 .897 r
.81983 .33817 .82388 .34437 .8334 .34119 .8294 .33513 Metetra
.659 .73 .902 r
.8294 .33513 .8334 .34119 .84296 .338 .83899 .33209 Metetra
.659 .736 .907 r
.83899 .33209 .84296 .338 .85256 .33482 .84862 .32902 Metetra
.66 .742 .911 r
.84862 .32902 .85256 .33482 .86218 .33164 .85828 .32593 Metetra
.66 .746 .914 r
.85828 .32593 .86218 .33164 .87184 .32847 .86797 .32281 Metetra
.661 .749 .916 r
.86797 .32281 .87184 .32847 .88153 .32531 .87769 .31968 Metetra
.662 .747 .913 r
.26994 .51042 .27509 .51506 .28294 .51251 .2778 .50785 Metetra
.663 .747 .913 r
.2778 .50785 .28294 .51251 .29081 .50995 .28569 .50525 Metetra
.664 .746 .911 r
.28569 .50525 .29081 .50995 .2987 .50738 .2936 .50261 Metetra
.666 .745 .909 r
.2936 .50261 .2987 .50738 .30662 .50479 .30153 .49994 Metetra
.668 .742 .906 r
.30153 .49994 .30662 .50479 .31456 .50218 .3095 .49721 Metetra
.668 .738 .902 r
.3095 .49721 .31456 .50218 .32253 .49957 .31748 .49447 Metetra
.666 .733 .9 r
.31748 .49447 .32253 .49957 .33052 .49695 .32549 .49177 Metetra
.661 .729 .899 r
.32549 .49177 .33052 .49695 .33853 .49435 .33352 .48916 Metetra
.656 .727 .902 r
.33352 .48916 .33853 .49435 .34656 .49177 .34156 .48665 Metetra
.65 .729 .907 r
.34156 .48665 .34656 .49177 .35462 .48921 .34963 .48425 Metetra
.646 .735 .914 r
.34963 .48425 .35462 .48921 .3627 .48667 .35771 .48194 Metetra
.642 .745 .923 r
.35771 .48194 .3627 .48667 .37081 .48412 .36582 .47967 Metetra
.638 .756 .934 r
.36582 .47967 .37081 .48412 .37894 .48159 .37395 .47745 Metetra
.634 .771 .945 r
.37395 .47745 .37894 .48159 .3871 .47904 .38211 .47524 Metetra
.639 .788 .954 r
.38211 .47524 .3871 .47904 .39528 .47646 .3903 .47288 Metetra
.653 .804 .955 r
.3903 .47288 .39528 .47646 .40349 .47381 .39852 .47024 Metetra
.675 .81 .948 r
.39852 .47024 .40349 .47381 .41173 .47106 .40679 .46721 Metetra
.698 .802 .929 r
.40679 .46721 .41173 .47106 .41999 .46819 .4151 .46371 Metetra
.713 .777 .903 r
.4151 .46371 .41999 .46819 .42829 .46523 .42344 .45982 Metetra
.712 .741 .874 r
.42344 .45982 .42829 .46523 .43661 .46222 .4318 .45577 Metetra
.704 .704 .848 r
.4318 .45577 .43661 .46222 .44495 .45921 .44018 .45172 Metetra
.691 .671 .826 r
.44018 .45172 .44495 .45921 .45331 .45622 .44858 .4478 Metetra
.673 .642 .811 r
.44858 .4478 .45331 .45622 .4617 .45332 .45699 .44428 Metetra
.648 .619 .806 r
.45699 .44428 .4617 .45332 .47011 .45058 .46541 .44148 Metetra
.616 .603 .814 r
.46541 .44148 .47011 .45058 .47855 .44807 .47384 .43969 Metetra
.568 .597 .842 r
.47384 .43969 .47855 .44807 .487 .44584 .48228 .43919 Metetra
.472 .604 .902 r
.48228 .43919 .487 .44584 .49549 .44393 .49075 .44005 Metetra
.21 .591 .946 r
.49075 .44005 .49549 .44393 .504 .44226 .49925 .44201 Metetra
.346 0 0 r
.49925 .44201 .504 .44226 .51255 .44074 .5078 .44463 Metetra
.547 .056 .042 r
.5078 .44463 .51255 .44074 .52112 .43927 .5164 .44756 Metetra
.566 .163 .236 r
.5164 .44756 .52112 .43927 .52973 .43777 .52507 .45036 Metetra
.555 .198 .319 r
.52507 .45036 .52973 .43777 .53838 .43611 .53379 .45252 Metetra
.535 .207 .358 r
.53379 .45252 .53838 .43611 .54706 .43419 .54255 .45356 Metetra
.51 .199 .375 r
.54255 .45356 .54706 .43419 .55576 .43188 .55136 .45297 Metetra
.478 .177 .377 r
.55136 .45297 .55576 .43188 .56449 .4291 .56018 .45032 Metetra
.437 .143 .366 r
.56018 .45032 .56449 .4291 .57324 .42583 .569 .44556 Metetra
.388 .093 .338 r
.569 .44556 .57324 .42583 .58201 .42216 .57781 .43907 Metetra
.318 .017 .287 r
.57781 .43907 .58201 .42216 .59079 .4182 .5866 .43132 Metetra
.201 0 .185 r
.5866 .43132 .59079 .4182 .5996 .41404 .59538 .42277 Metetra
.59538 .42277 .5996 .41404 .60842 .40981 .60415 .41397 Metetra
.498 .819 .508 r
.60415 .41397 .60842 .40981 .61726 .40561 .61292 .40537 Metetra
.836 .985 .87 r
.61292 .40537 .61726 .40561 .62613 .40155 .62171 .39737 Metetra
.804 .826 .868 r
.62171 .39737 .62613 .40155 .63503 .39773 .63053 .39047 Metetra
.731 .705 .826 r
.63053 .39047 .63503 .39773 .64397 .39424 .63942 .38502 Metetra
.678 .637 .802 r
.63942 .38502 .64397 .39424 .65294 .39106 .64837 .38096 Metetra
.643 .604 .795 r
.64837 .38096 .65294 .39106 .66196 .38815 .65739 .37806 Metetra
.619 .592 .801 r
.65739 .37806 .66196 .38815 .67101 .38542 .66647 .37602 Metetra
.604 .599 .819 r
.66647 .37602 .67101 .38542 .6801 .38281 .67562 .37448 Metetra
.597 .621 .847 r
.67562 .37448 .6801 .38281 .68922 .38024 .68482 .37315 Metetra
.592 .656 .881 r
.68482 .37315 .68922 .38024 .69837 .37766 .69405 .37183 Metetra
.593 .703 .92 r
.69405 .37183 .69837 .37766 .70755 .37503 .70332 .37032 Metetra
.605 .758 .952 r
.70332 .37032 .70755 .37503 .71676 .37229 .71259 .36836 Metetra
.626 .805 .968 r
.71259 .36836 .71676 .37229 .72599 .36941 .72187 .36582 Metetra
.65 .831 .97 r
.72187 .36582 .72599 .36941 .73524 .3664 .73115 .36276 Metetra
.672 .837 .963 r
.73115 .36276 .73524 .3664 .74452 .36329 .74043 .3593 Metetra
.686 .825 .95 r
.74043 .3593 .74452 .36329 .75383 .36012 .74973 .35562 Metetra
.689 .802 .935 r
.74973 .35562 .75383 .36012 .76316 .35693 .75905 .3519 Metetra
.687 .779 .921 r
.75905 .3519 .76316 .35693 .77252 .35375 .7684 .34823 Metetra
.683 .758 .908 r
.7684 .34823 .77252 .35375 .78192 .35058 .77778 .34463 Metetra
.677 .739 .897 r
.77778 .34463 .78192 .35058 .79134 .34743 .7872 .34115 Metetra
.669 .724 .891 r
.7872 .34115 .79134 .34743 .8008 .34431 .79667 .33786 Metetra
.661 .715 .889 r
.79667 .33786 .8008 .34431 .8103 .34123 .80619 .33476 Metetra
.655 .713 .89 r
.80619 .33476 .8103 .34123 .81983 .33817 .81575 .3318 Metetra
.651 .715 .895 r
.81575 .3318 .81983 .33817 .8294 .33513 .82535 .32894 Metetra
.65 .722 .901 r
.82535 .32894 .8294 .33513 .83899 .33209 .83499 .32608 Metetra
.652 .731 .907 r
.83499 .32608 .83899 .33209 .84862 .32902 .84466 .32317 Metetra
.654 .739 .912 r
.84466 .32317 .84862 .32902 .85828 .32593 .85436 .32019 Metetra
.656 .745 .915 r
.85436 .32019 .85828 .32593 .86797 .32281 .86408 .31716 Metetra
.658 .75 .918 r
.86408 .31716 .86797 .32281 .87769 .31968 .87383 .31405 Metetra
.663 .748 .913 r
.26476 .50577 .26994 .51042 .2778 .50785 .27263 .50317 Metetra
.665 .748 .912 r
.27263 .50317 .2778 .50785 .28569 .50525 .28054 .50052 Metetra
.667 .747 .91 r
.28054 .50052 .28569 .50525 .2936 .50261 .28846 .49782 Metetra
.67 .745 .907 r
.28846 .49782 .2936 .50261 .30153 .49994 .29642 .49505 Metetra
.673 .743 .903 r
.29642 .49505 .30153 .49994 .3095 .49721 .30441 .49219 Metetra
.673 .738 .899 r
.30441 .49219 .3095 .49721 .31748 .49447 .31242 .48931 Metetra
.669 .732 .897 r
.31242 .48931 .31748 .49447 .32549 .49177 .32044 .48651 Metetra
.661 .727 .898 r
.32044 .48651 .32549 .49177 .33352 .48916 .32848 .48388 Metetra
.652 .724 .902 r
.32848 .48388 .33352 .48916 .34156 .48665 .33654 .48146 Metetra
.641 .725 .909 r
.33654 .48146 .34156 .48665 .34963 .48425 .3446 .47925 Metetra
.631 .73 .919 r
.3446 .47925 .34963 .48425 .35771 .48194 .35268 .4772 Metetra
.624 .74 .93 r
.35268 .4772 .35771 .48194 .36582 .47967 .36079 .47525 Metetra
.616 .752 .943 r
.36079 .47525 .36582 .47967 .37395 .47745 .36892 .47338 Metetra
.609 .768 .956 r
.36892 .47338 .37395 .47745 .38211 .47524 .37708 .47154 Metetra
.62 .79 .963 r
.37708 .47154 .38211 .47524 .3903 .47288 .38528 .46944 Metetra
.649 .811 .961 r
.38528 .46944 .3903 .47288 .39852 .47024 .39352 .46682 Metetra
.69 .821 .945 r
.39352 .46682 .39852 .47024 .40679 .46721 .40182 .46346 Metetra
.728 .813 .917 r
.40182 .46346 .40679 .46721 .4151 .46371 .41017 .45925 Metetra
.748 .785 .883 r
.41017 .45925 .4151 .46371 .42344 .45982 .41856 .45434 Metetra
.746 .747 .853 r
.41856 .45434 .42344 .45982 .4318 .45577 .42698 .44911 Metetra
.733 .708 .827 r
.42698 .44911 .4318 .45577 .44018 .45172 .43541 .4439 Metetra
.714 .673 .808 r
.43541 .4439 .44018 .45172 .44858 .4478 .44384 .43894 Metetra
.687 .64 .797 r
.44384 .43894 .44858 .4478 .45699 .44428 .45227 .43473 Metetra
.647 .609 .797 r
.45227 .43473 .45699 .44428 .46541 .44148 .4607 .43187 Metetra
.587 .578 .81 r
.4607 .43187 .46541 .44148 .47384 .43969 .46911 .4309 Metetra
.478 .541 .843 r
.46911 .4309 .47384 .43969 .48228 .43919 .47753 .43231 Metetra
.218 .456 .874 r
.47753 .43231 .48228 .43919 .49075 .44005 .48597 .43629 Metetra
0 .161 .618 r
.48597 .43629 .49075 .44005 .49925 .44201 .49445 .44233 Metetra
.697 .17 0 r
.49445 .44233 .49925 .44201 .5078 .44463 .50299 .44965 Metetra
.705 .272 .219 r
.50299 .44965 .5078 .44463 .5164 .44756 .51161 .45757 Metetra
.67 .294 .325 r
.51161 .45757 .5164 .44756 .52507 .45036 .52032 .46531 Metetra
.63 .289 .374 r
.52032 .46531 .52507 .45036 .53379 .45252 .52911 .47186 Metetra
.59 .271 .397 r
.52911 .47186 .53379 .45252 .54255 .45356 .53797 .47632 Metetra
.545 .242 .405 r
.53797 .47632 .54255 .45356 .55136 .45297 .54687 .47772 Metetra
.49 .2 .399 r
.54687 .47772 .55136 .45297 .56018 .45032 .55579 .47523 Metetra
.423 .143 .381 r
.55579 .47523 .56018 .45032 .569 .44556 .5647 .46874 Metetra
.343 .069 .346 r
.5647 .46874 .569 .44556 .57781 .43907 .57356 .45899 Metetra
.233 0 .283 r
.57356 .45899 .57781 .43907 .5866 .43132 .58238 .44689 Metetra
.056 0 .164 r
.58238 .44689 .5866 .43132 .59538 .42277 .59114 .43333 Metetra
.59114 .43333 .59538 .42277 .60415 .41397 .59986 .41931 Metetra
.723 .889 .499 r
.59986 .41931 .60415 .41397 .61292 .40537 .60856 .40573 Metetra
.93 .962 .768 r
.60856 .40573 .61292 .40537 .62171 .39737 .61726 .39331 Metetra
.869 .829 .805 r
.61726 .39331 .62171 .39737 .63053 .39047 .62601 .38296 Metetra
.774 .713 .795 r
.62601 .38296 .63053 .39047 .63942 .38502 .63483 .37531 Metetra
.697 .637 .785 r
.63483 .37531 .63942 .38502 .64837 .38096 .64375 .37028 Metetra
.639 .592 .785 r
.64375 .37028 .64837 .38096 .65739 .37806 .65278 .3674 Metetra
.594 .569 .795 r
.65278 .3674 .65739 .37806 .66647 .37602 .6619 .36612 Metetra
.563 .567 .816 r
.6619 .36612 .66647 .37602 .67562 .37448 .67111 .36578 Metetra
.542 .584 .847 r
.67111 .36578 .67562 .37448 .68482 .37315 .68039 .36583 Metetra
.526 .617 .886 r
.68039 .36583 .68482 .37315 .69405 .37183 .68971 .36593 Metetra
.522 .668 .929 r
.68971 .36593 .69405 .37183 .70332 .37032 .69906 .36568 Metetra
.547 .738 .964 r
.69906 .36568 .70332 .37032 .71259 .36836 .70841 .36459 Metetra
.596 .803 .979 r
.70841 .36459 .71259 .36836 .72187 .36582 .71774 .36243 Metetra
.648 .843 .975 r
.71774 .36243 .72187 .36582 .73115 .36276 .72704 .35932 Metetra
.689 .854 .961 r
.72704 .35932 .73115 .36276 .74043 .3593 .73633 .35547 Metetra
.711 .842 .944 r
.73633 .35547 .74043 .3593 .74973 .35562 .74561 .35121 Metetra
.714 .816 .928 r
.74561 .35121 .74973 .35562 .75905 .3519 .75492 .34691 Metetra
.709 .789 .914 r
.75492 .34691 .75905 .3519 .7684 .34823 .76425 .34269 Metetra
.701 .765 .901 r
.76425 .34269 .7684 .34823 .77778 .34463 .77362 .33861 Metetra
.69 .742 .892 r
.77362 .33861 .77778 .34463 .7872 .34115 .78304 .33477 Metetra
.675 .724 .887 r
.78304 .33477 .7872 .34115 .79667 .33786 .79251 .33129 Metetra
.661 .712 .886 r
.79251 .33129 .79667 .33786 .80619 .33476 .80205 .32816 Metetra
.649 .707 .889 r
.80205 .32816 .80619 .33476 .81575 .3318 .81164 .32532 Metetra
.642 .709 .895 r
.81164 .32532 .81575 .3318 .82535 .32894 .82128 .32266 Metetra
.641 .716 .902 r
.82128 .32266 .82535 .32894 .83499 .32608 .83097 .32002 Metetra
.644 .727 .909 r
.83097 .32002 .83499 .32608 .84466 .32317 .84068 .31728 Metetra
.648 .736 .913 r
.84068 .31728 .84466 .32317 .85436 .32019 .85041 .31443 Metetra
.651 .743 .917 r
.85041 .31443 .85436 .32019 .86408 .31716 .86017 .31148 Metetra
.656 .75 .919 r
.86017 .31148 .86408 .31716 .87383 .31405 .86995 .30842 Metetra
.663 .748 .913 r
.25955 .50109 .26476 .50577 .27263 .50317 .26744 .49846 Metetra
.666 .748 .911 r
.26744 .49846 .27263 .50317 .28054 .50052 .27536 .49577 Metetra
.669 .747 .909 r
.27536 .49577 .28054 .50052 .28846 .49782 .2833 .493 Metetra
.673 .746 .905 r
.2833 .493 .28846 .49782 .29642 .49505 .29128 .49013 Metetra
.678 .744 .9 r
.29128 .49013 .29642 .49505 .30441 .49219 .29929 .48713 Metetra
.679 .739 .896 r
.29929 .48713 .30441 .49219 .31242 .48931 .30732 .48411 Metetra
.673 .733 .895 r
.30732 .48411 .31242 .48931 .32044 .48651 .31537 .48121 Metetra
.661 .726 .898 r
.31537 .48121 .32044 .48651 .32848 .48388 .32342 .47857 Metetra
.647 .722 .903 r
.32342 .47857 .32848 .48388 .33654 .48146 .33148 .47623 Metetra
.63 .721 .913 r
.33148 .47623 .33654 .48146 .3446 .47925 .33955 .47421 Metetra
.615 .725 .924 r
.33955 .47421 .3446 .47925 .35268 .4772 .34763 .47244 Metetra
.604 .734 .936 r
.34763 .47244 .35268 .4772 .36079 .47525 .35574 .47081 Metetra
.59 .745 .95 r
.35574 .47081 .36079 .47525 .36892 .47338 .36386 .46932 Metetra
.581 .76 .964 r
.36386 .46932 .36892 .47338 .37708 .47154 .37202 .46786 Metetra
.599 .786 .97 r
.37202 .46786 .37708 .47154 .38528 .46944 .38022 .46603 Metetra
.647 .813 .963 r
.38022 .46603 .38528 .46944 .39352 .46682 .38848 .46342 Metetra
.705 .826 .94 r
.38848 .46342 .39352 .46682 .40182 .46346 .39682 .45974 Metetra
.755 .817 .901 r
.39682 .45974 .40182 .46346 .41017 .45925 .40521 .45479 Metetra
.778 .789 .862 r
.40521 .45479 .41017 .45925 .41856 .45434 .41366 .4488 Metetra
.774 .751 .832 r
.41366 .4488 .41856 .45434 .42698 .44911 .42213 .44237 Metetra
.759 .713 .81 r
.42213 .44237 .42698 .44911 .43541 .4439 .43061 .43595 Metetra
.736 .678 .794 r
.43061 .43595 .43541 .4439 .44384 .43894 .43909 .42992 Metetra
.702 .644 .788 r
.43909 .42992 .44384 .43894 .45227 .43473 .44755 .425 Metetra
.648 .606 .793 r
.44755 .425 .45227 .43473 .4607 .43187 .45598 .42207 Metetra
.556 .559 .812 r
.45598 .42207 .4607 .43187 .46911 .4309 .46438 .42194 Metetra
.36 .471 .837 r
.46438 .42194 .46911 .4309 .47753 .43231 .47277 .42534 Metetra
0 .221 .743 r
.47277 .42534 .47753 .43231 .48597 .43629 .48116 .43256 Metetra
.702 .187 0 r
.48116 .43256 .48597 .43629 .49445 .44233 .4896 .44286 Metetra
.811 .349 .132 r
.4896 .44286 .49445 .44233 .50299 .44965 .49812 .45509 Metetra
.78 .378 .291 r
.49812 .45509 .50299 .44965 .51161 .45757 .50674 .46829 Metetra
.733 .37 .363 r
.50674 .46829 .51161 .45757 .52032 .46531 .51548 .48126 Metetra
.683 .347 .399 r
.51548 .48126 .52032 .46531 .52911 .47186 .52433 .49251 Metetra
.632 .314 .415 r
.52433 .49251 .52911 .47186 .53797 .47632 .53328 .50064 Metetra
.572 .27 .417 r
.53328 .50064 .53797 .47632 .54687 .47772 .54229 .50419 Metetra
.495 .207 .406 r
.54229 .50419 .54687 .47772 .55579 .47523 .55131 .50186 Metetra
.398 .124 .378 r
.55131 .50186 .55579 .47523 .5647 .46874 .56031 .49351 Metetra
.277 .018 .33 r
.56031 .49351 .5647 .46874 .57356 .45899 .56924 .48027 Metetra
.11 0 .245 r
.56924 .48027 .57356 .45899 .58238 .44689 .57808 .46352 Metetra
0 0 .088 r
.57808 .46352 .58238 .44689 .59114 .43333 .58684 .44462 Metetra
.58684 .44462 .59114 .43333 .59986 .41931 .59552 .42511 Metetra
.876 .915 .515 r
.59552 .42511 .59986 .41931 .60856 .40573 .60416 .40629 Metetra
.969 .919 .696 r
.60416 .40629 .60856 .40573 .61726 .39331 .61278 .38927 Metetra
.906 .82 .751 r
.61278 .38927 .61726 .39331 .62601 .38296 .62145 .37533 Metetra
.809 .721 .768 r
.62145 .37533 .62601 .38296 .63483 .37531 .63022 .36542 Metetra
.717 .643 .775 r
.63022 .36542 .63483 .37531 .64375 .37028 .63912 .35938 Metetra
.637 .588 .782 r
.63912 .35938 .64375 .37028 .65278 .3674 .64815 .35652 Metetra
.569 .552 .796 r
.64815 .35652 .65278 .3674 .6619 .36612 .65731 .35602 Metetra
.516 .538 .817 r
.65731 .35602 .6619 .36612 .67111 .36578 .66658 .35693 Metetra
.477 .546 .849 r
.66658 .35693 .67111 .36578 .68039 .36583 .67593 .35842 Metetra
.446 .573 .888 r
.67593 .35842 .68039 .36583 .68971 .36593 .68534 .35998 Metetra
.436 .624 .931 r
.68534 .35998 .68971 .36593 .69906 .36568 .69478 .36104 Metetra
.48 .707 .97 r
.69478 .36104 .69906 .36568 .70841 .36459 .7042 .36087 Metetra
.566 .794 .985 r
.7042 .36087 .70841 .36459 .71774 .36243 .71358 .3591 Metetra
.648 .847 .976 r
.71358 .3591 .71774 .36243 .72704 .35932 .72291 .35593 Metetra
.708 .863 .956 r
.72291 .35593 .72704 .35932 .73633 .35547 .7322 .35168 Metetra
.736 .851 .934 r
.7322 .35168 .73633 .35547 .74561 .35121 .74147 .34683 Metetra
.738 .825 .918 r
.74147 .34683 .74561 .35121 .75492 .34691 .75076 .3419 Metetra
.729 .796 .905 r
.75076 .3419 .75492 .34691 .76425 .34269 .76008 .33712 Metetra
.719 .771 .894 r
.76008 .33712 .76425 .34269 .77362 .33861 .76943 .33254 Metetra
.702 .747 .886 r
.76943 .33254 .77362 .33861 .78304 .33477 .77884 .32833 Metetra
.681 .726 .884 r
.77884 .32833 .78304 .33477 .79251 .33129 .78832 .32466 Metetra
.661 .711 .885 r
.78832 .32466 .79251 .33129 .80205 .32816 .79788 .3215 Metetra
.644 .704 .89 r
.79788 .3215 .80205 .32816 .81164 .32532 .8075 .31878 Metetra
.633 .703 .897 r
.8075 .31878 .81164 .32532 .82128 .32266 .81719 .31632 Metetra
.63 .711 .904 r
.81719 .31632 .82128 .32266 .83097 .32002 .82692 .31391 Metetra
.635 .722 .911 r
.82692 .31391 .83097 .32002 .84068 .31728 .83667 .31135 Metetra
.641 .733 .915 r
.83667 .31135 .84068 .31728 .85041 .31443 .84644 .30864 Metetra
.646 .741 .918 r
.84644 .30864 .85041 .31443 .86017 .31148 .85624 .30578 Metetra
.653 .749 .92 r
.85624 .30578 .86017 .31148 .86995 .30842 .86605 .30277 Metetra
.664 .748 .913 r
.2543 .49638 .25955 .50109 .26744 .49846 .26221 .49373 Metetra
.668 .748 .911 r
.26221 .49373 .26744 .49846 .27536 .49577 .27015 .49099 Metetra
.672 .748 .908 r
.27015 .49099 .27536 .49577 .2833 .493 .27811 .48815 Metetra
.677 .747 .904 r
.27811 .48815 .2833 .493 .29128 .49013 .28611 .48519 Metetra
.683 .745 .898 r
.28611 .48519 .29128 .49013 .29929 .48713 .29414 .48206 Metetra
.684 .741 .894 r
.29414 .48206 .29929 .48713 .30732 .48411 .3022 .47889 Metetra
.676 .734 .894 r
.3022 .47889 .30732 .48411 .31537 .48121 .31027 .47591 Metetra
.661 .727 .898 r
.31027 .47591 .31537 .48121 .32342 .47857 .31833 .47324 Metetra
.642 .722 .906 r
.31833 .47324 .32342 .47857 .33148 .47623 .3264 .47098 Metetra
.619 .718 .917 r
.3264 .47098 .33148 .47623 .33955 .47421 .33447 .46916 Metetra
.599 .72 .929 r
.33447 .46916 .33955 .47421 .34763 .47244 .34255 .46765 Metetra
.584 .727 .942 r
.34255 .46765 .34763 .47244 .35574 .47081 .35065 .46633 Metetra
.565 .735 .955 r
.35065 .46633 .35574 .47081 .36386 .46932 .35877 .46519 Metetra
.552 .748 .968 r
.35877 .46519 .36386 .46932 .37202 .46786 .36692 .4641 Metetra
.58 .777 .973 r
.36692 .4641 .37202 .46786 .38022 .46603 .37513 .46253 Metetra
.646 .809 .962 r
.37513 .46253 .38022 .46603 .38848 .46342 .38341 .45993 Metetra
.719 .825 .93 r
.38341 .45993 .38848 .46342 .39682 .45974 .39178 .45593 Metetra
.776 .816 .884 r
.39178 .45593 .39682 .45974 .40521 .45479 .40023 .45028 Metetra
.8 .789 .842 r
.40023 .45028 .40521 .45479 .41366 .4488 .40874 .44326 Metetra
.797 .755 .814 r
.40874 .44326 .41366 .4488 .42213 .44237 .41727 .43566 Metetra
.781 .72 .796 r
.41727 .43566 .42213 .44237 .43061 .43595 .4258 .42809 Metetra
.757 .688 .785 r
.4258 .42809 .43061 .43595 .43909 .42992 .43431 .42105 Metetra
.718 .653 .784 r
.43431 .42105 .43909 .42992 .44755 .425 .4428 .41544 Metetra
.65 .611 .797 r
.4428 .41544 .44755 .425 .45598 .42207 .45124 .41245 Metetra
.52 .544 .821 r
.45124 .41245 .45598 .42207 .46438 .42194 .45962 .41313 Metetra
.206 .383 .819 r
.45962 .41313 .46438 .42194 .47277 .42534 .46798 .41842 Metetra
0 0 .525 r
.46798 .41842 .47277 .42534 .48116 .43256 .47632 .42873 Metetra
.825 .355 0 r
.47632 .42873 .48116 .43256 .4896 .44286 .48471 .44313 Metetra
.861 .435 .207 r
.48471 .44313 .4896 .44286 .49812 .45509 .4932 .46013 Metetra
.827 .441 .32 r
.4932 .46013 .49812 .45509 .50674 .46829 .5018 .47845 Metetra
.781 .422 .376 r
.5018 .47845 .50674 .46829 .51548 .48126 .51056 .49655 Metetra
.729 .39 .406 r
.51056 .49655 .51548 .48126 .52433 .49251 .51945 .51243 Metetra
.67 .347 .418 r
.51945 .51243 .52433 .49251 .53328 .50064 .52847 .5242 Metetra
.597 .289 .417 r
.52847 .5242 .53328 .50064 .54229 .50419 .53758 .52988 Metetra
.494 .202 .399 r
.53758 .52988 .54229 .50419 .55131 .50186 .54671 .52772 Metetra
.353 .082 .357 r
.54671 .52772 .55131 .50186 .56031 .49351 .5558 .51752 Metetra
.168 0 .282 r
.5558 .51752 .56031 .49351 .56924 .48027 .5648 .50082 Metetra
0 0 .153 r
.5648 .50082 .56924 .48027 .57808 .46352 .57369 .47948 Metetra
.57369 .47948 .57808 .46352 .58684 .44462 .58245 .45535 Metetra
.772 .807 .323 r
.58245 .45535 .58684 .44462 .59552 .42511 .59112 .43048 Metetra
.959 .906 .538 r
.59112 .43048 .59552 .42511 .60416 .40629 .59971 .4066 Metetra
.982 .878 .652 r
.59971 .4066 .60416 .40629 .61278 .38927 .60828 .38514 Metetra
.926 .808 .71 r
.60828 .38514 .61278 .38927 .62145 .37533 .61688 .36777 Metetra
.837 .73 .746 r
.61688 .36777 .62145 .37533 .63022 .36542 .62561 .35569 Metetra
.736 .655 .77 r
.62561 .35569 .63022 .36542 .63912 .35938 .63448 .34869 Metetra
.637 .592 .787 r
.63448 .34869 .63912 .35938 .64815 .35652 .64352 .34585 Metetra
.543 .542 .803 r
.64352 .34585 .64815 .35652 .65731 .35602 .65272 .3461 Metetra
.462 .512 .824 r
.65272 .3461 .65731 .35602 .66658 .35693 .66204 .3482 Metetra
.401 .507 .851 r
.66204 .3482 .66658 .35693 .67593 .35842 .67146 .35105 Metetra
.352 .522 .885 r
.67146 .35105 .67593 .35842 .68534 .35998 .68094 .35401 Metetra
.339 .57 .925 r
.68094 .35401 .68534 .35998 .69478 .36104 .69046 .35632 Metetra
.41 .669 .967 r
.69046 .35632 .69478 .36104 .7042 .36087 .69996 .35703 Metetra
.539 .778 .986 r
.69996 .35703 .7042 .36087 .71358 .3591 .70938 .35565 Metetra
.653 .843 .973 r
.70938 .35565 .71358 .3591 .72291 .35593 .71874 .35242 Metetra
.726 .862 .946 r
.71874 .35242 .72291 .35593 .7322 .35168 .72803 .34778 Metetra
.758 .852 .921 r
.72803 .34778 .7322 .35168 .74147 .34683 .7373 .34235 Metetra
.758 .827 .906 r
.7373 .34235 .74147 .34683 .75076 .3419 .74657 .33684 Metetra
.747 .8 .895 r
.74657 .33684 .75076 .3419 .76008 .33712 .75588 .33151 Metetra
.734 .775 .886 r
.75588 .33151 .76008 .33712 .76943 .33254 .76522 .32646 Metetra
.714 .752 .882 r
.76522 .32646 .76943 .33254 .77884 .32833 .77463 .32189 Metetra
.687 .73 .882 r
.77463 .32189 .77884 .32833 .78832 .32466 .78412 .31802 Metetra
.661 .713 .886 r
.78412 .31802 .78832 .32466 .79788 .3215 .79369 .31484 Metetra
.639 .703 .893 r
.79369 .31484 .79788 .3215 .8075 .31878 .80335 .31223 Metetra
.623 .7 .9 r
.80335 .31223 .8075 .31878 .81719 .31632 .81307 .30997 Metetra
.62 .707 .908 r
.81307 .30997 .81719 .31632 .82692 .31391 .82284 .30777 Metetra
.627 .719 .913 r
.82284 .30777 .82692 .31391 .83667 .31135 .83263 .30538 Metetra
.635 .73 .917 r
.83263 .30538 .83667 .31135 .84644 .30864 .84245 .3028 Metetra
.642 .739 .92 r
.84245 .3028 .84644 .30864 .85624 .30578 .85227 .30004 Metetra
.65 .747 .921 r
.85227 .30004 .85624 .30578 .86605 .30277 .86212 .29706 Metetra
.664 .748 .912 r
.24904 .49164 .2543 .49638 .26221 .49373 .25696 .48896 Metetra
.669 .748 .91 r
.25696 .48896 .26221 .49373 .27015 .49099 .26491 .48618 Metetra
.674 .748 .907 r
.26491 .48618 .27015 .49099 .27811 .48815 .2729 .48328 Metetra
.68 .748 .902 r
.2729 .48328 .27811 .48815 .28611 .48519 .28091 .48023 Metetra
.688 .747 .897 r
.28091 .48023 .28611 .48519 .29414 .48206 .28897 .47699 Metetra
.689 .743 .893 r
.28897 .47699 .29414 .48206 .3022 .47889 .29705 .4737 Metetra
.679 .737 .894 r
.29705 .4737 .3022 .47889 .31027 .47591 .30513 .47063 Metetra
.661 .73 .9 r
.30513 .47063 .31027 .47591 .31833 .47324 .31321 .46795 Metetra
.638 .723 .909 r
.31321 .46795 .31833 .47324 .3264 .47098 .32129 .46576 Metetra
.609 .717 .921 r
.32129 .46576 .3264 .47098 .33447 .46916 .32936 .46409 Metetra
.584 .715 .934 r
.32936 .46409 .33447 .46916 .34255 .46765 .33744 .46281 Metetra
.565 .719 .945 r
.33744 .46281 .34255 .46765 .35065 .46633 .34554 .46175 Metetra
.542 .724 .958 r
.34554 .46175 .35065 .46633 .35877 .46519 .35366 .46092 Metetra
.529 .734 .969 r
.35366 .46092 .35877 .46519 .36692 .4641 .36181 .46015 Metetra
.567 .764 .971 r
.36181 .46015 .36692 .4641 .37513 .46253 .37002 .45879 Metetra
.647 .799 .956 r
.37002 .45879 .37513 .46253 .38341 .45993 .37832 .45621 Metetra
.73 .816 .918 r
.37832 .45621 .38341 .45993 .39178 .45593 .38672 .45193 Metetra
.79 .809 .868 r
.38672 .45193 .39178 .45593 .40023 .45028 .39522 .44566 Metetra
.815 .786 .825 r
.39522 .44566 .40023 .45028 .40874 .44326 .40378 .43776 Metetra
.813 .758 .801 r
.40378 .43776 .40874 .44326 .41727 .43566 .41237 .42916 Metetra
.799 .729 .787 r
.41237 .42916 .41727 .43566 .4258 .42809 .42095 .42059 Metetra
.776 .702 .781 r
.42095 .42059 .4258 .42809 .43431 .42105 .42951 .41266 Metetra
.735 .67 .787 r
.42951 .41266 .43431 .42105 .4428 .41544 .43802 .40647 Metetra
.654 .625 .808 r
.43802 .40647 .4428 .41544 .45124 .41245 .44647 .40343 Metetra
.479 .537 .839 r
.44647 .40343 .45124 .41245 .45962 .41313 .45484 .40479 Metetra
.018 .277 .775 r
.45484 .40479 .45962 .41313 .46798 .41842 .46316 .41171 Metetra
.658 .213 0 r
.46316 .41171 .46798 .41842 .47632 .42873 .47145 .42469 Metetra
.874 .435 .064 r
.47145 .42469 .47632 .42873 .48471 .44313 .47979 .44264 Metetra
.89 .483 .236 r
.47979 .44264 .48471 .44313 .4932 .46013 .48823 .46377 Metetra
.864 .483 .323 r
.48823 .46377 .4932 .46013 .5018 .47845 .49681 .4866 Metetra
.825 .463 .371 r
.49681 .4866 .5018 .47845 .51056 .49655 .50555 .50921 Metetra
.776 .428 .397 r
.50555 .50921 .51056 .49655 .51945 .51243 .51448 .52918 Metetra
.713 .377 .407 r
.51448 .52918 .51945 .51243 .52847 .5242 .52355 .54419 Metetra
.625 .301 .402 r
.52355 .54419 .52847 .5242 .53758 .52988 .53274 .55177 Metetra
.484 .178 .371 r
.53274 .55177 .53758 .52988 .54671 .52772 .54196 .54975 Metetra
.264 0 .298 r
.54196 .54975 .54671 .52772 .5558 .51752 .55115 .5379 Metetra
0 0 .163 r
.55115 .5379 .5558 .51752 .5648 .50082 .56023 .51811 Metetra
.56023 .51811 .5648 .50082 .57369 .47948 .56917 .49271 Metetra
.752 .773 .272 r
.56917 .49271 .57369 .47948 .58245 .45535 .57796 .46397 Metetra
.936 .871 .449 r
.57796 .46397 .58245 .45535 .59112 .43048 .58663 .4344 Metetra
.993 .877 .561 r
.58663 .4344 .59112 .43048 .59971 .4066 .5952 .40611 Metetra
.982 .842 .63 r
.5952 .40611 .59971 .4066 .60828 .38514 .60373 .38079 Metetra
.935 .795 .682 r
.60373 .38079 .60828 .38514 .61688 .36777 .6123 .36046 Metetra
.859 .739 .73 r
.6123 .36046 .61688 .36777 .62561 .35569 .621 .34652 Metetra
.757 .675 .771 r
.621 .34652 .62561 .35569 .63448 .34869 .62986 .3387 Metetra
.64 .606 .8 r
.62986 .3387 .63448 .34869 .64352 .34585 .63891 .33587 Metetra
.513 .54 .821 r
.63891 .33587 .64352 .34585 .65272 .3461 .64813 .33676 Metetra
.399 .49 .837 r
.64813 .33676 .65272 .3461 .66204 .3482 .6575 .33987 Metetra
.314 .468 .854 r
.6575 .33987 .66204 .3482 .67146 .35105 .66697 .3439 Metetra
.251 .47 .876 r
.66697 .3439 .67146 .35105 .68094 .35401 .67652 .34806 Metetra
.244 .515 .909 r
.67652 .34806 .68094 .35401 .69046 .35632 .68611 .35145 Metetra
.35 .63 .958 r
.68611 .35145 .69046 .35632 .69996 .35703 .69567 .35291 Metetra
.522 .758 .982 r
.69567 .35291 .69996 .35703 .70938 .35565 .70514 .35186 Metetra
.66 .83 .965 r
.70514 .35186 .70938 .35565 .71874 .35242 .71452 .34858 Metetra
.74 .851 .932 r
.71452 .34858 .71874 .35242 .72803 .34778 .72382 .3436 Metetra
.773 .843 .905 r
.72382 .3436 .72803 .34778 .7373 .34235 .73308 .33767 Metetra
.772 .823 .892 r
.73308 .33767 .7373 .34235 .74657 .33684 .74235 .33164 Metetra
.76 .8 .885 r
.74235 .33164 .74657 .33684 .75588 .33151 .75165 .32585 Metetra
.746 .778 .879 r
.75165 .32585 .75588 .33151 .76522 .32646 .76099 .32038 Metetra
.724 .757 .879 r
.76099 .32038 .76522 .32646 .77463 .32189 .7704 .3155 Metetra
.693 .735 .883 r
.7704 .3155 .77463 .32189 .78412 .31802 .77989 .31146 Metetra
.662 .717 .89 r
.77989 .31146 .78412 .31802 .79369 .31484 .78949 .30826 Metetra
.634 .705 .897 r
.78949 .30826 .79369 .31484 .80335 .31223 .79917 .30574 Metetra
.615 .7 .905 r
.79917 .30574 .80335 .31223 .81307 .30997 .80894 .30366 Metetra
.611 .705 .912 r
.80894 .30366 .81307 .30997 .82284 .30777 .81875 .30163 Metetra
.619 .717 .916 r
.81875 .30163 .82284 .30777 .83263 .30538 .82858 .29939 Metetra
.629 .728 .919 r
.82858 .29939 .83263 .30538 .84245 .3028 .83842 .29692 Metetra
.638 .737 .92 r
.83842 .29692 .84245 .3028 .85227 .30004 .84829 .29423 Metetra
.648 .745 .92 r
.84829 .29423 .85227 .30004 .86212 .29706 .85816 .29128 Metetra
.665 .747 .912 r
.24374 .48685 .24904 .49164 .25696 .48896 .25168 .48415 Metetra
.67 .748 .909 r
.25168 .48415 .25696 .48896 .26491 .48618 .25964 .48133 Metetra
.675 .748 .906 r
.25964 .48133 .26491 .48618 .2729 .48328 .26765 .47839 Metetra
.682 .749 .902 r
.26765 .47839 .2729 .48328 .28091 .48023 .27568 .47527 Metetra
.691 .748 .896 r
.27568 .47527 .28091 .48023 .28897 .47699 .28376 .47194 Metetra
.692 .746 .893 r
.28376 .47194 .28897 .47699 .29705 .4737 .29186 .46855 Metetra
.681 .74 .895 r
.29186 .46855 .29705 .4737 .30513 .47063 .29996 .46541 Metetra
.662 .733 .903 r
.29996 .46541 .30513 .47063 .31321 .46795 .30806 .46272 Metetra
.635 .725 .913 r
.30806 .46272 .31321 .46795 .32129 .46576 .31614 .46058 Metetra
.601 .717 .926 r
.31614 .46058 .32129 .46576 .32936 .46409 .32422 .45902 Metetra
.572 .712 .937 r
.32422 .45902 .32936 .46409 .33744 .46281 .3323 .4579 Metetra
.551 .713 .947 r
.3323 .4579 .33744 .46281 .34554 .46175 .3404 .45704 Metetra
.526 .712 .957 r
.3404 .45704 .34554 .46175 .35366 .46092 .34852 .45644 Metetra
.513 .719 .965 r
.34852 .45644 .35366 .46092 .36181 .46015 .35667 .4559 Metetra
.56 .748 .965 r
.35667 .4559 .36181 .46015 .37002 .45879 .36489 .4547 Metetra
.649 .784 .946 r
.36489 .4547 .37002 .45879 .37832 .45621 .37321 .45212 Metetra
.735 .802 .905 r
.37321 .45212 .37832 .45621 .38672 .45193 .38164 .44763 Metetra
.796 .798 .853 r
.38164 .44763 .38672 .45193 .39522 .44566 .39018 .4409 Metetra
.824 .781 .813 r
.39018 .4409 .39522 .44566 .40378 .43776 .39879 .43233 Metetra
.825 .761 .792 r
.39879 .43233 .40378 .43776 .41237 .42916 .40743 .42297 Metetra
.814 .741 .783 r
.40743 .42297 .41237 .42916 .42095 .42059 .41606 .41366 Metetra
.794 .72 .782 r
.41606 .41366 .42095 .42059 .42951 .41266 .42466 .40507 Metetra
.753 .694 .795 r
.42466 .40507 .42951 .41266 .43802 .40647 .4332 .39843 Metetra
.661 .65 .829 r
.4332 .39843 .43802 .40647 .44647 .40343 .44166 .39535 Metetra
.429 .538 .865 r
.44166 .39535 .44647 .40343 .45484 .40479 .45002 .39722 Metetra
0 .159 .699 r
.45002 .39722 .45484 .40479 .46316 .41171 .45831 .40535 Metetra
.765 .318 0 r
.45831 .40535 .46316 .41171 .47145 .42469 .46656 .42032 Metetra
.895 .475 .112 r
.46656 .42032 .47145 .42469 .47979 .44264 .47484 .44092 Metetra
.908 .512 .238 r
.47484 .44092 .47979 .44264 .48823 .46377 .48323 .46518 Metetra
.894 .514 .307 r
.48323 .46518 .48823 .46377 .49681 .4866 .49177 .4914 Metetra
.866 .497 .347 r
.49177 .4914 .49681 .4866 .50555 .50921 .5005 .51744 Metetra
.826 .463 .368 r
.5005 .51744 .50555 .50921 .51448 .52918 .50943 .54054 Metetra
.766 .407 .374 r
.50943 .54054 .51448 .52918 .52355 .54419 .51854 .55802 Metetra
.664 .308 .359 r
.51854 .55802 .52355 .54419 .53274 .55177 .52779 .56706 Metetra
.454 .112 .296 r
.52779 .56706 .53274 .55177 .54196 .54975 .53709 .56515 Metetra
.038 0 .127 r
.53709 .56515 .54196 .54975 .55115 .5379 .54635 .55203 Metetra
.54635 .55203 .55115 .5379 .56023 .51811 .55551 .52987 Metetra
.825 .825 .347 r
.55551 .52987 .56023 .51811 .56917 .49271 .56452 .50135 Metetra
.958 .87 .465 r
.56452 .50135 .56917 .49271 .57796 .46397 .57335 .46909 Metetra
.995 .862 .532 r
.57335 .46909 .57796 .46397 .58663 .4344 .58204 .43596 Metetra
.994 .839 .58 r
.58204 .43596 .58663 .4344 .5952 .40611 .59062 .40433 Metetra
.974 .812 .62 r
.59062 .40433 .5952 .40611 .60373 .38079 .59915 .37613 Metetra
.938 .784 .664 r
.59915 .37613 .60373 .38079 .6123 .36046 .60771 .35358 Metetra
.876 .75 .72 r
.60771 .35358 .6123 .36046 .621 .34652 .61639 .33825 Metetra
.779 .701 .777 r
.61639 .33825 .621 .34652 .62986 .3387 .62526 .32981 Metetra
.644 .632 .824 r
.62526 .32981 .62986 .3387 .63891 .33587 .63431 .32698 Metetra
.479 .548 .849 r
.63431 .32698 .63891 .33587 .64813 .33676 .64356 .32834 Metetra
.325 .473 .854 r
.64356 .32834 .64813 .33676 .6575 .33987 .65296 .3322 Metetra
.217 .431 .855 r
.65296 .3322 .6575 .33987 .66697 .3439 .66248 .3371 Metetra
.151 .421 .862 r
.66248 .3371 .66697 .3439 .67652 .34806 .67208 .34216 Metetra
.164 .468 .891 r
.67208 .34216 .67652 .34806 .68611 .35145 .68173 .34635 Metetra
.311 .597 .947 r
.68173 .34635 .68611 .35145 .69567 .35291 .69133 .34837 Metetra
.517 .736 .973 r
.69133 .34837 .69567 .35291 .70514 .35186 .70083 .34756 Metetra
.666 .809 .952 r
.70083 .34756 .70514 .35186 .71452 .34858 .71024 .34423 Metetra
.748 .831 .915 r
.71024 .34423 .71452 .34858 .72382 .3436 .71955 .33899 Metetra
.781 .828 .889 r
.71955 .33899 .72382 .3436 .73308 .33767 .72882 .33269 Metetra
.78 .813 .879 r
.72882 .33269 .73308 .33767 .74235 .33164 .73809 .32627 Metetra
.769 .796 .875 r
.73809 .32627 .74235 .33164 .75165 .32585 .7474 .32012 Metetra
.754 .78 .874 r
.7474 .32012 .75165 .32585 .76099 .32038 .75674 .31434 Metetra
.731 .762 .877 r
.75674 .31434 .76099 .32038 .7704 .3155 .76615 .30922 Metetra
.698 .742 .885 r
.76615 .30922 .7704 .3155 .77989 .31146 .77566 .30505 Metetra
.662 .724 .895 r
.77566 .30505 .77989 .31146 .78949 .30826 .78528 .30182 Metetra
.63 .71 .904 r
.78528 .30182 .78949 .30826 .79917 .30574 .79499 .29937 Metetra
.608 .703 .911 r
.79499 .29937 .79917 .30574 .80894 .30366 .80479 .29741 Metetra
.604 .706 .916 r
.80479 .29741 .80894 .30366 .81875 .30163 .81463 .29551 Metetra
.613 .717 .919 r
.81463 .29551 .81875 .30163 .82858 .29939 .8245 .29338 Metetra
.624 .726 .92 r
.8245 .29338 .82858 .29939 .83842 .29692 .83437 .29098 Metetra
.635 .735 .92 r
.83437 .29098 .83842 .29692 .84829 .29423 .84427 .28834 Metetra
.647 .743 .919 r
.84427 .28834 .84829 .29423 .85816 .29128 .85417 .28541 Metetra
.665 .746 .911 r
.23841 .48201 .24374 .48685 .25168 .48415 .24636 .47929 Metetra
.67 .747 .908 r
.24636 .47929 .25168 .48415 .25964 .48133 .25435 .47645 Metetra
.676 .748 .905 r
.25435 .47645 .25964 .48133 .26765 .47839 .26237 .47347 Metetra
.683 .749 .901 r
.26237 .47347 .26765 .47839 .27568 .47527 .27042 .47031 Metetra
.692 .75 .896 r
.27042 .47031 .27568 .47527 .28376 .47194 .27852 .46692 Metetra
.694 .749 .894 r
.27852 .46692 .28376 .47194 .29186 .46855 .28664 .46348 Metetra
.683 .745 .898 r
.28664 .46348 .29186 .46855 .29996 .46541 .29476 .4603 Metetra
.662 .738 .907 r
.29476 .4603 .29996 .46541 .30806 .46272 .30287 .45759 Metetra
.632 .73 .918 r
.30287 .45759 .30806 .46272 .31614 .46058 .31096 .45546 Metetra
.596 .72 .93 r
.31096 .45546 .31614 .46058 .32422 .45902 .31905 .45396 Metetra
.565 .712 .94 r
.31905 .45396 .32422 .45902 .3323 .4579 .32714 .45293 Metetra
.544 .708 .947 r
.32714 .45293 .3323 .4579 .3404 .45704 .33524 .45216 Metetra
.52 .703 .954 r
.33524 .45216 .3404 .45704 .34852 .45644 .34337 .45167 Metetra
.51 .705 .959 r
.34337 .45167 .34852 .45644 .35667 .4559 .35153 .45125 Metetra
.561 .731 .955 r
.35153 .45125 .35667 .4559 .36489 .4547 .35976 .45013 Metetra
.651 .764 .932 r
.35976 .45013 .36489 .4547 .37321 .45212 .36809 .44754 Metetra
.736 .783 .89 r
.36809 .44754 .37321 .45212 .38164 .44763 .37654 .44293 Metetra
.796 .784 .841 r
.37654 .44293 .38164 .44763 .39018 .4409 .38511 .43594 Metetra
.826 .776 .805 r
.38511 .43594 .39018 .4409 .39879 .43233 .39377 .42701 Metetra
.832 .765 .788 r
.39377 .42701 .39879 .43233 .40743 .42297 .40245 .41724 Metetra
.826 .754 .784 r
.40245 .41724 .40743 .42297 .41606 .41366 .41112 .40752 Metetra
.81 .743 .789 r
.41112 .40752 .41606 .41366 .42466 .40507 .41975 .39857 Metetra
.771 .727 .812 r
.41975 .39857 .42466 .40507 .4332 .39843 .42832 .39169 Metetra
.669 .69 .861 r
.42832 .39169 .4332 .39843 .44166 .39535 .43679 .38857 Metetra
.366 .55 .902 r
.43679 .38857 .44166 .39535 .45002 .39722 .44515 .3907 Metetra
0 .051 .595 r
.44515 .3907 .45002 .39722 .45831 .40535 .45342 .39948 Metetra
.814 .368 0 r
.45342 .39948 .45831 .40535 .46656 .42032 .46164 .41551 Metetra
.903 .49 .123 r
.46164 .41551 .46656 .42032 .47484 .44092 .46988 .43753 Metetra
.919 .526 .215 r
.46988 .43753 .47484 .44092 .48323 .46518 .47823 .46346 Metetra
.918 .534 .264 r
.47823 .46346 .48323 .46518 .49177 .4914 .48673 .49151 Metetra
.906 .525 .289 r
.48673 .49151 .49177 .4914 .5005 .51744 .49544 .5194 Metetra
.883 .496 .296 r
.49544 .5194 .5005 .51744 .50943 .54054 .50435 .54419 Metetra
.839 .436 .28 r
.50435 .54419 .50943 .54054 .51854 .55802 .51347 .56301 Metetra
.729 .291 .212 r
.51347 .56301 .51854 .55802 .52779 .56706 .52275 .57284 Metetra
.281 0 0 r
.52275 .57284 .52779 .56706 .53709 .56515 .5321 .57098 Metetra
.725 .901 .524 r
.5321 .57098 .53709 .56515 .54635 .55203 .54143 .55716 Metetra
.966 .918 .576 r
.54143 .55716 .54635 .55203 .55551 .52987 .55065 .53369 Metetra
.995 .869 .572 r
.55065 .53369 .55551 .52987 .56452 .50135 .55972 .50348 Metetra
.995 .835 .572 r
.55972 .50348 .56452 .50135 .57335 .46909 .56862 .4693 Metetra
.987 .812 .581 r
.56862 .4693 .57335 .46909 .58204 .43596 .57736 .43423 Metetra
.976 .797 .596 r
.57736 .43423 .58204 .43596 .59062 .40433 .58597 .4008 Metetra
.961 .784 .619 r
.58597 .4008 .59062 .40433 .59915 .37613 .59453 .37104 Metetra
.936 .775 .656 r
.59453 .37104 .59915 .37613 .60771 .35358 .60311 .34729 Metetra
.89 .764 .716 r
.60311 .34729 .60771 .35358 .61639 .33825 .61181 .33121 Metetra
.802 .737 .792 r
.61181 .33121 .61639 .33825 .62526 .32981 .62068 .32242 Metetra
.65 .676 .861 r
.62068 .32242 .62526 .32981 .63431 .32698 .62975 .31959 Metetra
.434 .57 .891 r
.62975 .31959 .63431 .32698 .64356 .32834 .63902 .32119 Metetra
.233 .461 .874 r
.63902 .32119 .64356 .32834 .65296 .3322 .64844 .32545 Metetra
.114 .399 .852 r
.64844 .32545 .65296 .3322 .66248 .3371 .65799 .33081 Metetra
.065 .385 .847 r
.65799 .33081 .66248 .3371 .67208 .34216 .66762 .33633 Metetra
.114 .44 .877 r
.66762 .33633 .67208 .34216 .68173 .34635 .6773 .34095 Metetra
.3 .578 .938 r
.6773 .34095 .68173 .34635 .69133 .34837 .68693 .34325 Metetra
.523 .713 .958 r
.68693 .34325 .69133 .34837 .70083 .34756 .69646 .34256 Metetra
.67 .78 .932 r
.69646 .34256 .70083 .34756 .71024 .34423 .70589 .33921 Metetra
.748 .803 .897 r
.70589 .33921 .71024 .34423 .71955 .33899 .71523 .33382 Metetra
.781 .806 .873 r
.71523 .33382 .71955 .33899 .72882 .33269 .72451 .32731 Metetra
.782 .799 .867 r
.72451 .32731 .72882 .33269 .73809 .32627 .7338 .32067 Metetra
.771 .789 .868 r
.7338 .32067 .73809 .32627 .7474 .32012 .74311 .31432 Metetra
.758 .779 .87 r
.74311 .31432 .7474 .32012 .75674 .31434 .75247 .30836 Metetra
.736 .767 .878 r
.75247 .30836 .75674 .31434 .76615 .30922 .7619 .3031 Metetra
.701 .75 .89 r
.7619 .3031 .76615 .30922 .77566 .30505 .77143 .29886 Metetra
.663 .733 .902 r
.77143 .29886 .77566 .30505 .78528 .30182 .78106 .29561 Metetra
.628 .718 .912 r
.78106 .29561 .78528 .30182 .79499 .29937 .7908 .29318 Metetra
.603 .709 .919 r
.7908 .29318 .79499 .29937 .80479 .29741 .80063 .29127 Metetra
.599 .71 .922 r
.80063 .29127 .80479 .29741 .81463 .29551 .8105 .28944 Metetra
.61 .718 .922 r
.8105 .28944 .81463 .29551 .8245 .29338 .82039 .28735 Metetra
.622 .726 .921 r
.82039 .28735 .8245 .29338 .83437 .29098 .8303 .28498 Metetra
.633 .733 .92 r
.8303 .28498 .83437 .29098 .84427 .28834 .84022 .28236 Metetra
.646 .74 .918 r
.84022 .28236 .84427 .28834 .85417 .28541 .85014 .27943 Metetra
.665 .745 .91 r
.23306 .47712 .23841 .48201 .24636 .47929 .24103 .47438 Metetra
.67 .746 .908 r
.24103 .47438 .24636 .47929 .25435 .47645 .24903 .47153 Metetra
.676 .748 .905 r
.24903 .47153 .25435 .47645 .26237 .47347 .25706 .46854 Metetra
.683 .749 .901 r
.25706 .46854 .26237 .47347 .27042 .47031 .26513 .46537 Metetra
.692 .752 .897 r
.26513 .46537 .27042 .47031 .27852 .46692 .27324 .46196 Metetra
.694 .752 .896 r
.27324 .46196 .27852 .46692 .28664 .46348 .28137 .45851 Metetra
.683 .75 .902 r
.28137 .45851 .28664 .46348 .29476 .4603 .28951 .45531 Metetra
.662 .745 .911 r
.28951 .45531 .29476 .4603 .30287 .45759 .29764 .45259 Metetra
.632 .736 .923 r
.29764 .45259 .30287 .45759 .31096 .45546 .30575 .45044 Metetra
.595 .725 .934 r
.30575 .45044 .31096 .45546 .31905 .45396 .31385 .44892 Metetra
.565 .714 .941 r
.31385 .44892 .31905 .45396 .32714 .45293 .32195 .44787 Metetra
.546 .706 .945 r
.32195 .44787 .32714 .45293 .33524 .45216 .33006 .44707 Metetra
.525 .697 .948 r
.33006 .44707 .33524 .45216 .34337 .45167 .3382 .44656 Metetra
.519 .695 .948 r
.3382 .44656 .34337 .45167 .35153 .45125 .34637 .44612 Metetra
.57 .714 .939 r
.34637 .44612 .35153 .45125 .35976 .45013 .35462 .44498 Metetra
.652 .741 .915 r
.35462 .44498 .35976 .45013 .36809 .44754 .36297 .44237 Metetra
.731 .76 .876 r
.36297 .44237 .36809 .44754 .37654 .44293 .37144 .43775 Metetra
.79 .768 .833 r
.37144 .43775 .37654 .44293 .38511 .43594 .38003 .43076 Metetra
.823 .77 .803 r
.38003 .43076 .38511 .43594 .39377 .42701 .38871 .42183 Metetra
.834 .77 .791 r
.38871 .42183 .39377 .42701 .40245 .41724 .39742 .41207 Metetra
.834 .771 .792 r
.39742 .41207 .40245 .41724 .41112 .40752 .40611 .40236 Metetra
.825 .773 .803 r
.40611 .40236 .41112 .40752 .41975 .39857 .41478 .39341 Metetra
.789 .772 .837 r
.41478 .39341 .41975 .39857 .42832 .39169 .42337 .38653 Metetra
.675 .75 .908 r
.42337 .38653 .42832 .39169 .43679 .38857 .43185 .3834 Metetra
.278 .573 .938 r
.43185 .3834 .43679 .38857 .44515 .3907 .44022 .3855 Metetra
0 0 .488 r
.44022 .3855 .44515 .3907 .45342 .39948 .44849 .39421 Metetra
.83 .379 0 r
.44849 .39421 .45342 .39948 .46164 .41551 .4567 .41016 Metetra
.899 .486 .102 r
.4567 .41016 .46164 .41551 .46988 .43753 .46492 .43208 Metetra
.918 .522 .156 r
.46492 .43208 .46988 .43753 .47823 .46346 .47324 .45789 Metetra
.924 .535 .173 r
.47324 .45789 .47823 .46346 .48673 .49151 .48172 .48581 Metetra
.921 .529 .159 r
.48172 .48581 .48673 .49151 .49544 .5194 .4904 .51358 Metetra
.901 .494 .099 r
.4904 .51358 .49544 .5194 .50435 .54419 .49929 .53825 Metetra
.832 .39 0 r
.49929 .53825 .50435 .54419 .51347 .56301 .5084 .55697 Metetra
0 .016 .544 r
.5084 .55697 .51347 .56301 .52275 .57284 .51767 .56673 Metetra
.605 .711 .919 r
.51767 .56673 .52275 .57284 .5321 .57098 .52704 .56485 Metetra
.868 .77 .751 r
.52704 .56485 .5321 .57098 .54143 .55716 .5364 .55105 Metetra
.918 .76 .67 r
.5364 .55105 .54143 .55716 .55065 .53369 .54568 .52765 Metetra
.935 .752 .631 r
.54568 .52765 .55065 .53369 .55972 .50348 .55481 .49751 Metetra
.942 .749 .613 r
.55481 .49751 .55972 .50348 .56862 .4693 .56377 .46343 Metetra
.945 .749 .607 r
.56377 .46343 .56862 .4693 .57736 .43423 .57257 .42845 Metetra
.945 .752 .611 r
.57257 .42845 .57736 .43423 .58597 .4008 .58126 .39512 Metetra
.942 .757 .625 r
.58126 .39512 .58597 .4008 .59453 .37104 .58987 .36543 Metetra
.931 .768 .657 r
.58987 .36543 .59453 .37104 .60311 .34729 .5985 .34173 Metetra
.901 .781 .72 r
.5985 .34173 .60311 .34729 .61181 .33121 .60724 .32568 Metetra
.824 .786 .816 r
.60724 .32568 .61181 .33121 .62068 .32242 .61614 .3169 Metetra
.653 .743 .916 r
.61614 .3169 .62068 .32242 .62975 .31959 .62523 .31404 Metetra
.368 .608 .942 r
.62523 .31404 .62975 .31959 .63902 .32119 .63451 .31561 Metetra
.121 .456 .886 r
.63451 .31561 .63902 .32119 .64844 .32545 .64395 .31982 Metetra
.016 .382 .844 r
.64395 .31982 .64844 .32545 .65799 .33081 .6535 .32513 Metetra
.009 .374 .84 r
.6535 .32513 .65799 .33081 .66762 .33633 .66314 .33061 Metetra
.106 .44 .878 r
.66314 .33061 .66762 .33633 .6773 .34095 .67282 .33518 Metetra
.322 .576 .932 r
.67282 .33518 .6773 .34095 .68693 .34325 .68247 .33745 Metetra
.538 .69 .938 r
.68247 .33745 .68693 .34325 .69646 .34256 .69202 .33673 Metetra
.67 .747 .908 r
.69202 .33673 .69646 .34256 .70589 .33921 .70147 .33335 Metetra
.741 .771 .877 r
.70147 .33335 .70589 .33921 .71523 .33382 .71083 .32796 Metetra
.772 .78 .859 r
.71083 .32796 .71523 .33382 .72451 .32731 .72014 .32144 Metetra
.776 .781 .857 r
.72014 .32144 .72451 .32731 .7338 .32067 .72946 .31479 Metetra
.768 .78 .862 r
.72946 .31479 .7338 .32067 .74311 .31432 .7388 .30843 Metetra
.758 .777 .869 r
.7388 .30843 .74311 .31432 .75247 .30836 .74819 .30246 Metetra
.736 .771 .881 r
.74819 .30246 .75247 .30836 .7619 .3031 .75764 .29719 Metetra
.702 .76 .897 r
.75764 .29719 .7619 .3031 .77143 .29886 .76719 .29293 Metetra
.663 .745 .911 r
.76719 .29293 .77143 .29886 .78106 .29561 .77685 .28966 Metetra
.627 .73 .921 r
.77685 .28966 .78106 .29561 .7908 .29318 .78661 .28721 Metetra
.601 .719 .927 r
.78661 .28721 .7908 .29318 .80063 .29127 .79645 .28528 Metetra
.598 .716 .927 r
.79645 .28528 .80063 .29127 .8105 .28944 .80635 .28342 Metetra
.61 .722 .925 r
.80635 .28342 .8105 .28944 .82039 .28735 .81626 .28131 Metetra
.622 .727 .922 r
.81626 .28131 .82039 .28735 .8303 .28498 .82619 .27892 Metetra
.633 .732 .919 r
.82619 .27892 .8303 .28498 .84022 .28236 .83613 .27627 Metetra
.646 .738 .916 r
.83613 .27627 .84022 .28236 .85014 .27943 .84609 .27332 Metetra
.665 .744 .909 r
.22768 .47217 .23306 .47712 .24103 .47438 .23566 .46943 Metetra
.67 .745 .907 r
.23566 .46943 .24103 .47438 .24903 .47153 .24367 .46657 Metetra
.675 .747 .905 r
.24367 .46657 .24903 .47153 .25706 .46854 .25172 .46358 Metetra
.682 .749 .902 r
.25172 .46358 .25706 .46854 .26513 .46537 .2598 .46043 Metetra
.691 .753 .899 r
.2598 .46043 .26513 .46537 .27324 .46196 .26792 .45705 Metetra
.693 .755 .899 r
.26792 .45705 .27324 .46196 .28137 .45851 .27607 .45363 Metetra
.682 .754 .906 r
.27607 .45363 .28137 .45851 .28951 .45531 .28422 .45045 Metetra
.662 .751 .916 r
.28422 .45045 .28951 .45531 .29764 .45259 .29236 .44771 Metetra
.633 .743 .927 r
.29236 .44771 .29764 .45259 .30575 .45044 .30049 .44551 Metetra
.599 .731 .937 r
.30049 .44551 .30575 .45044 .31385 .44892 .30861 .4439 Metetra
.572 .718 .941 r
.30861 .4439 .31385 .44892 .32195 .44787 .31673 .44272 Metetra
.556 .707 .941 r
.31673 .44272 .32195 .44787 .33006 .44707 .32487 .44179 Metetra
.539 .696 .941 r
.32487 .44179 .33006 .44707 .3382 .44656 .33302 .44112 Metetra
.537 .688 .937 r
.33302 .44112 .3382 .44656 .34637 .44612 .34121 .44051 Metetra
.582 .7 .923 r
.34121 .44051 .34637 .44612 .35462 .44498 .34948 .43925 Metetra
.653 .72 .898 r
.34948 .43925 .35462 .44498 .36297 .44237 .35784 .43662 Metetra
.722 .739 .864 r
.35784 .43662 .36297 .44237 .37144 .43775 .36632 .4321 Metetra
.779 .753 .83 r
.36632 .4321 .37144 .43775 .38003 .43076 .37493 .42535 Metetra
.814 .764 .806 r
.37493 .42535 .38003 .43076 .38871 .42183 .38362 .41679 Metetra
.831 .776 .8 r
.38362 .41679 .38871 .42183 .39742 .41207 .39233 .40745 Metetra
.837 .79 .806 r
.39233 .40745 .39742 .41207 .40611 .40236 .40104 .39816 Metetra
.833 .806 .824 r
.40104 .39816 .40611 .40236 .41478 .39341 .40972 .38958 Metetra
.801 .824 .869 r
.40972 .38958 .41478 .39341 .42337 .38653 .41833 .38293 Metetra
.67 .82 .955 r
.41833 .38293 .42337 .38653 .43185 .3834 .42684 .3798 Metetra
.179 .595 .941 r
.42684 .3798 .43185 .3834 .44022 .3855 .43523 .38157 Metetra
.568 .035 0 r
.43523 .38157 .44022 .3855 .44849 .39421 .44352 .38954 Metetra
.82 .356 0 r
.44352 .38954 .44849 .39421 .4567 .41016 .45174 .40428 Metetra
.879 .458 .044 r
.45174 .40428 .4567 .41016 .46492 .43208 .45997 .4246 Metetra
.889 .49 .052 r
.45997 .4246 .46492 .43208 .47324 .45789 .4683 .44853 Metetra
.871 .488 .011 r
.4683 .44853 .47324 .45789 .48172 .48581 .47676 .4744 Metetra
.806 .443 0 r
.47676 .4744 .48172 .48581 .4904 .51358 .48542 .50009 Metetra
0 0 .286 r
.48542 .50009 .4904 .51358 .49929 .53825 .49429 .52286 Metetra
0 0 .547 r
.49429 .52286 .49929 .53825 .5084 .55697 .50336 .54007 Metetra
.274 .299 .706 r
.50336 .54007 .5084 .55697 .51767 .56673 .51261 .54893 Metetra
.594 .496 .712 r
.51261 .54893 .51767 .56673 .52704 .56485 .52196 .54696 Metetra
.741 .583 .678 r
.52196 .54696 .52704 .56485 .5364 .55105 .53132 .53389 Metetra
.81 .624 .651 r
.53132 .53389 .5364 .55105 .54568 .52765 .54062 .51188 Metetra
.85 .651 .634 r
.54062 .51188 .54568 .52765 .55481 .49751 .5498 .48358 Metetra
.876 .672 .623 r
.5498 .48358 .55481 .49751 .56377 .46343 .55883 .45157 Metetra
.895 .691 .619 r
.55883 .45157 .56377 .46343 .57257 .42845 .56771 .41869 Metetra
.909 .711 .623 r
.56771 .41869 .57257 .42845 .58126 .39512 .57647 .38731 Metetra
.919 .733 .635 r
.57647 .38731 .58126 .39512 .58987 .36543 .58517 .3593 Metetra
.921 .762 .666 r
.58517 .3593 .58987 .36543 .5985 .34173 .59388 .3369 Metetra
.906 .801 .733 r
.59388 .3369 .5985 .34173 .60724 .32568 .60268 .32164 Metetra
.84 .842 .847 r
.60268 .32164 .60724 .32568 .61614 .3169 .61163 .31319 Metetra
.64 .824 .971 r
.61163 .31319 .61614 .3169 .62523 .31404 .62074 .31031 Metetra
.276 .648 .967 r
.62074 .31031 .62523 .31404 .63451 .31561 .63003 .31157 Metetra
.017 .459 .872 r
.63003 .31157 .63451 .31561 .64395 .31982 .63946 .3153 Metetra
0 .39 .836 r
.63946 .3153 .64395 .31982 .6535 .32513 .64901 .32007 Metetra
.001 .399 .85 r
.64901 .32007 .6535 .32513 .66314 .33061 .65864 .32499 Metetra
.143 .471 .894 r
.65864 .32499 .66314 .33061 .67282 .33518 .66831 .32905 Metetra
.366 .587 .929 r
.66831 .32905 .67282 .33518 .68247 .33745 .67795 .33096 Metetra
.556 .673 .916 r
.67795 .33096 .68247 .33745 .69202 .33673 .68751 .33007 Metetra
.668 .717 .885 r
.68751 .33007 .69202 .33673 .70147 .33335 .69698 .32669 Metetra
.729 .74 .86 r
.69698 .32669 .70147 .33335 .71083 .32796 .70637 .32141 Metetra
.759 .754 .848 r
.70637 .32141 .71083 .32796 .72014 .32144 .71572 .31508 Metetra
.765 .763 .851 r
.71572 .31508 .72014 .32144 .72946 .31479 .72507 .30864 Metetra
.76 .769 .86 r
.72507 .30864 .72946 .31479 .7388 .30843 .73446 .30246 Metetra
.752 .774 .871 r
.73446 .30246 .7388 .30843 .74819 .30246 .74388 .29664 Metetra
.733 .775 .886 r
.74388 .29664 .74819 .30246 .75764 .29719 .75337 .29149 Metetra
.701 .769 .905 r
.75337 .29149 .75764 .29719 .76719 .29293 .76295 .28727 Metetra
.663 .757 .92 r
.76295 .28727 .76719 .29293 .77685 .28966 .77263 .28398 Metetra
.628 .743 .93 r
.77263 .28398 .77685 .28966 .78661 .28721 .78241 .28146 Metetra
.604 .73 .934 r
.78241 .28146 .78661 .28721 .79645 .28528 .79227 .27942 Metetra
.601 .725 .932 r
.79227 .27942 .79645 .28528 .80635 .28342 .80218 .27745 Metetra
.612 .727 .927 r
.80218 .27745 .80635 .28342 .81626 .28131 .81211 .27525 Metetra
.625 .729 .922 r
.81211 .27525 .81626 .28131 .82619 .27892 .82206 .27278 Metetra
.635 .732 .918 r
.82206 .27278 .82619 .27892 .83613 .27627 .83202 .27007 Metetra
.647 .735 .913 r
.83202 .27007 .83613 .27627 .84609 .27332 .84199 .26708 Metetra
.664 .743 .909 r
.22227 .46718 .22768 .47217 .23566 .46943 .23026 .46442 Metetra
.669 .744 .907 r
.23026 .46442 .23566 .46943 .24367 .46657 .23829 .46157 Metetra
.673 .746 .906 r
.23829 .46157 .24367 .46657 .25172 .46358 .24635 .45861 Metetra
.68 .749 .904 r
.24635 .45861 .25172 .46358 .2598 .46043 .25444 .45549 Metetra
.688 .753 .901 r
.25444 .45549 .2598 .46043 .26792 .45705 .26257 .45217 Metetra
.689 .757 .903 r
.26257 .45217 .26792 .45705 .27607 .45363 .27073 .44882 Metetra
.68 .758 .91 r
.27073 .44882 .27607 .45363 .28422 .45045 .27889 .44568 Metetra
.662 .756 .92 r
.27889 .44568 .28422 .45045 .29236 .44771 .28705 .44292 Metetra
.636 .749 .93 r
.28705 .44292 .29236 .44771 .30049 .44551 .2952 .44065 Metetra
.607 .737 .938 r
.2952 .44065 .30049 .44551 .30861 .4439 .30334 .43888 Metetra
.584 .724 .94 r
.30334 .43888 .30861 .4439 .31673 .44272 .31149 .4375 Metetra
.571 .711 .937 r
.31149 .4375 .31673 .44272 .32487 .44179 .31965 .43634 Metetra
.559 .697 .933 r
.31965 .43634 .32487 .44179 .33302 .44112 .32783 .4354 Metetra
.559 .687 .925 r
.32783 .4354 .33302 .44112 .34121 .44051 .33605 .43452 Metetra
.595 .691 .909 r
.33605 .43452 .34121 .44051 .34948 .43925 .34433 .43306 Metetra
.653 .704 .885 r
.34433 .43306 .34948 .43925 .35784 .43662 .35271 .43039 Metetra
.712 .722 .857 r
.35271 .43039 .35784 .43662 .36632 .4321 .3612 .42606 Metetra
.764 .74 .83 r
.3612 .42606 .36632 .4321 .37493 .42535 .3698 .41976 Metetra
.801 .759 .814 r
.3698 .41976 .37493 .42535 .38362 .41679 .37849 .41186 Metetra
.822 .781 .814 r
.37849 .41186 .38362 .41679 .39233 .40745 .3872 .40327 Metetra
.833 .807 .826 r
.3872 .40327 .39233 .40745 .40104 .39816 .39591 .39471 Metetra
.833 .837 .85 r
.39591 .39471 .40104 .39816 .40972 .38958 .40459 .38679 Metetra
.799 .87 .9 r
.40459 .38679 .40972 .38958 .41833 .38293 .41321 .38056 Metetra
.646 .875 .983 r
.41321 .38056 .41833 .38293 .42684 .3798 .42174 .37744 Metetra
.116 .613 .905 r
.42174 .37744 .42684 .3798 .43523 .38157 .43017 .37866 Metetra
.545 0 0 r
.43017 .37866 .43523 .38157 .44352 .38954 .4385 .38534 Metetra
.78 .293 0 r
.4385 .38534 .44352 .38954 .45174 .40428 .44677 .39798 Metetra
.831 .395 0 r
.44677 .39798 .45174 .40428 .45997 .4246 .45504 .41551 Metetra
.801 .406 0 r
.45504 .41551 .45997 .4246 .4683 .44853 .46339 .43617 Metetra
.69 .352 0 r
.46339 .43617 .4683 .44853 .47676 .4744 .47187 .45849 Metetra
0 0 .386 r
.47187 .45849 .47676 .4744 .48542 .50009 .48052 .4806 Metetra
0 0 .541 r
.48052 .4806 .48542 .50009 .49429 .52286 .48936 .50011 Metetra
.182 .187 .628 r
.48936 .50011 .49429 .52286 .50336 .54007 .49839 .51472 Metetra
.419 .337 .657 r
.49839 .51472 .50336 .54007 .51261 .54893 .50759 .52204 Metetra
.582 .441 .655 r
.50759 .52204 .51261 .54893 .52196 .54696 .51691 .51992 Metetra
.682 .508 .644 r
.51691 .51992 .52196 .54696 .53132 .53389 .52625 .50813 Metetra
.744 .552 .635 r
.52625 .50813 .53132 .53389 .54062 .51188 .53555 .48853 Metetra
.787 .586 .629 r
.53555 .48853 .54062 .51188 .5498 .48358 .54475 .46341 Metetra
.821 .616 .626 r
.54475 .46341 .5498 .48358 .55883 .45157 .55383 .43501 Metetra
.849 .645 .627 r
.55383 .43501 .55883 .45157 .56771 .41869 .56279 .40578 Metetra
.873 .676 .634 r
.56279 .40578 .56771 .41869 .57647 .38731 .57165 .37781 Metetra
.894 .712 .649 r
.57165 .37781 .57647 .38731 .58517 .3593 .58044 .35277 Metetra
.908 .758 .683 r
.58044 .35277 .58517 .3593 .59388 .3369 .58924 .33263 Metetra
.904 .821 .755 r
.58924 .33263 .59388 .3369 .60268 .32164 .59811 .31878 Metetra
.839 .894 .878 r
.59811 .31878 .60268 .32164 .61163 .31319 .60711 .31094 Metetra
.597 .881 .992 r
.60711 .31094 .61163 .31319 .62074 .31031 .61626 .30801 Metetra
.194 .668 .935 r
.61626 .30801 .62074 .31031 .63003 .31157 .62555 .30875 Metetra
0 .483 .845 r
.62555 .30875 .63003 .31157 .63946 .3153 .63498 .31166 Metetra
0 .438 .845 r
.63498 .31166 .63946 .3153 .64901 .32007 .64451 .31549 Metetra
.053 .46 .882 r
.64451 .31549 .64901 .32007 .65864 .32499 .65411 .31944 Metetra
.217 .524 .918 r
.65411 .31944 .65864 .32499 .66831 .32905 .66376 .32263 Metetra
.42 .607 .925 r
.66376 .32263 .66831 .32905 .67795 .33096 .67338 .32392 Metetra
.575 .663 .898 r
.67338 .32392 .67795 .33096 .68751 .33007 .68294 .32274 Metetra
.664 .695 .869 r
.68294 .32274 .68751 .33007 .69698 .32669 .69243 .31936 Metetra
.716 .717 .849 r
.69243 .31936 .69698 .32669 .70637 .32141 .70186 .31432 Metetra
.744 .734 .843 r
.70186 .31432 .70637 .32141 .71572 .31508 .71125 .30834 Metetra
.75 .747 .849 r
.71125 .30834 .71572 .31508 .72507 .30864 .72065 .30226 Metetra
.748 .759 .862 r
.72065 .30226 .72507 .30864 .73446 .30246 .73008 .29641 Metetra
.742 .77 .875 r
.73008 .29641 .73446 .30246 .74388 .29664 .73955 .29088 Metetra
.726 .776 .892 r
.73955 .29088 .74388 .29664 .75337 .29149 .74908 .28593 Metetra
.697 .775 .912 r
.74908 .28593 .75337 .29149 .76295 .28727 .7587 .28181 Metetra
.662 .767 .927 r
.7587 .28181 .76295 .28727 .77263 .28398 .76841 .27851 Metetra
.63 .754 .937 r
.76841 .27851 .77263 .28398 .78241 .28146 .7782 .27588 Metetra
.609 .741 .939 r
.7782 .27588 .78241 .28146 .79227 .27942 .78808 .27367 Metetra
.607 .734 .935 r
.78808 .27367 .79227 .27942 .80218 .27745 .79799 .27153 Metetra
.618 .732 .928 r
.79799 .27153 .80218 .27745 .81211 .27525 .80793 .26917 Metetra
.629 .732 .922 r
.80793 .26917 .81211 .27525 .82206 .27278 .81789 .26658 Metetra
.639 .732 .916 r
.81789 .26658 .82206 .27278 .83202 .27007 .82787 .26378 Metetra
.649 .734 .911 r
.82787 .26378 .83202 .27007 .84199 .26708 .83786 .26072 Metetra
.664 .742 .909 r
.21683 .46214 .22227 .46718 .23026 .46442 .22484 .45938 Metetra
.667 .744 .907 r
.22484 .45938 .23026 .46442 .23829 .46157 .23288 .45654 Metetra
.671 .746 .906 r
.23288 .45654 .23829 .46157 .24635 .45861 .24095 .4536 Metetra
.677 .749 .905 r
.24095 .4536 .24635 .45861 .25444 .45549 .24905 .45054 Metetra
.683 .753 .904 r
.24905 .45054 .25444 .45549 .26257 .45217 .25719 .44731 Metetra
.685 .757 .907 r
.25719 .44731 .26257 .45217 .27073 .44882 .26535 .44405 Metetra
.677 .76 .914 r
.26535 .44405 .27073 .44882 .27889 .44568 .27353 .44096 Metetra
.662 .759 .923 r
.27353 .44096 .27889 .44568 .28705 .44292 .2817 .43819 Metetra
.641 .754 .931 r
.2817 .43819 .28705 .44292 .2952 .44065 .28987 .43582 Metetra
.617 .743 .936 r
.28987 .43582 .2952 .44065 .30334 .43888 .29804 .43386 Metetra
.599 .73 .936 r
.29804 .43386 .30334 .43888 .31149 .4375 .30621 .43222 Metetra
.59 .717 .931 r
.30621 .43222 .31149 .4375 .31965 .43634 .31441 .43076 Metetra
.581 .702 .925 r
.31441 .43076 .31965 .43634 .32783 .4354 .32262 .42948 Metetra
.581 .689 .915 r
.32262 .42948 .32783 .4354 .33605 .43452 .33087 .42825 Metetra
.609 .687 .898 r
.33087 .42825 .33605 .43452 .34433 .43306 .33918 .42654 Metetra
.653 .694 .876 r
.33918 .42654 .34433 .43306 .35271 .43039 .34757 .42383 Metetra
.701 .709 .854 r
.34757 .42383 .35271 .43039 .3612 .42606 .35606 .41974 Metetra
.748 .729 .835 r
.35606 .41974 .3612 .42606 .3698 .41976 .36465 .41403 Metetra
.784 .754 .826 r
.36465 .41403 .3698 .41976 .37849 .41186 .37332 .407 Metetra
.807 .784 .832 r
.37332 .407 .37849 .41186 .3872 .40327 .38202 .39939 Metetra
.82 .821 .85 r
.38202 .39939 .3872 .40327 .39591 .39471 .39071 .3918 Metetra
.82 .862 .878 r
.39071 .3918 .39591 .39471 .40459 .38679 .39939 .38473 Metetra
.78 .905 .928 r
.39939 .38473 .40459 .38679 .41321 .38056 .40802 .37907 Metetra
.607 .903 .985 r
.40802 .37907 .41321 .38056 .42174 .37744 .41658 .37597 Metetra
.119 .647 .874 r
.41658 .37597 .42174 .37744 .43017 .37866 .42505 .37645 Metetra
.446 0 0 r
.42505 .37645 .43017 .37866 .4385 .38534 .43344 .38146 Metetra
.688 .17 0 r
.43344 .38146 .4385 .38534 .44677 .39798 .44177 .39137 Metetra
.716 .265 0 r
.44177 .39137 .44677 .39798 .45504 .41551 .45011 .40528 Metetra
0 0 .353 r
.45011 .40528 .45504 .41551 .46339 .43617 .45851 .42173 Metetra
0 0 .479 r
.45851 .42173 .46339 .43617 .47187 .45849 .46703 .43948 Metetra
0 .033 .57 r
.46703 .43948 .47187 .45849 .48052 .4806 .47569 .457 Metetra
.168 .17 .616 r
.47569 .457 .48052 .4806 .48936 .50011 .48451 .47234 Metetra
.345 .274 .632 r
.48451 .47234 .48936 .50011 .49839 .51472 .49351 .48366 Metetra
.476 .355 .635 r
.49351 .48366 .49839 .51472 .50759 .52204 .50266 .48903 Metetra
.576 .42 .632 r
.50266 .48903 .50759 .52204 .51691 .51992 .51191 .48672 Metetra
.649 .47 .628 r
.51191 .48672 .51691 .51992 .52625 .50813 .52121 .47657 Metetra
.7 .509 .626 r
.52121 .47657 .52625 .50813 .53555 .48853 .53049 .46004 Metetra
.74 .542 .626 r
.53049 .46004 .53555 .48853 .54475 .46341 .5397 .43899 Metetra
.775 .575 .628 r
.5397 .43899 .54475 .46341 .55383 .43501 .54882 .4152 Metetra
.806 .608 .634 r
.54882 .4152 .55383 .43501 .56279 .40578 .55784 .39068 Metetra
.836 .647 .646 r
.55784 .39068 .56279 .40578 .57165 .37781 .56679 .36713 Metetra
.866 .694 .667 r
.56679 .36713 .57165 .37781 .58044 .35277 .57568 .34594 Metetra
.89 .755 .707 r
.57568 .34594 .58044 .35277 .58924 .33263 .58458 .32875 Metetra
.893 .84 .786 r
.58458 .32875 .58924 .33263 .59811 .31878 .59353 .31674 Metetra
.817 .932 .907 r
.59353 .31674 .59811 .31878 .60711 .31094 .60259 .3097 Metetra
.536 .898 .97 r
.60259 .3097 .60711 .31094 .61626 .30801 .61177 .30673 Metetra
.162 .683 .882 r
.61177 .30673 .61626 .30801 .62555 .30875 .62107 .30678 Metetra
0 .542 .837 r
.62107 .30678 .62555 .30875 .63498 .31166 .63048 .30863 Metetra
.036 .525 .881 r
.63048 .30863 .63498 .31166 .64451 .31549 .63999 .31123 Metetra
.157 .549 .927 r
.63999 .31123 .64451 .31549 .65411 .31944 .64956 .31393 Metetra
.315 .588 .941 r
.64956 .31393 .65411 .31944 .66376 .32263 .65917 .31599 Metetra
.477 .63 .92 r
.65917 .31599 .66376 .32263 .67338 .32392 .66877 .31648 Metetra
.592 .66 .885 r
.66877 .31648 .67338 .32392 .68294 .32274 .67833 .31493 Metetra
.661 .68 .858 r
.67833 .31493 .68294 .32274 .69243 .31936 .68784 .31157 Metetra
.703 .699 .843 r
.68784 .31157 .69243 .31936 .70186 .31432 .6973 .30682 Metetra
.727 .717 .841 r
.6973 .30682 .70186 .31432 .71125 .30834 .70674 .30132 Metetra
.734 .734 .851 r
.70674 .30132 .71125 .30834 .72065 .30226 .7162 .29571 Metetra
.734 .75 .865 r
.7162 .29571 .72065 .30226 .73008 .29641 .72568 .2903 Metetra
.73 .765 .881 r
.72568 .2903 .73008 .29641 .73955 .29088 .7352 .28515 Metetra
.716 .775 .899 r
.7352 .28515 .73955 .29088 .74908 .28593 .74478 .28048 Metetra
.691 .779 .918 r
.74478 .28048 .74908 .28593 .7587 .28181 .75443 .27648 Metetra
.662 .774 .933 r
.75443 .27648 .7587 .28181 .76841 .27851 .76417 .27316 Metetra
.635 .763 .94 r
.76417 .27316 .76841 .27851 .7782 .27588 .77398 .2704 Metetra
.618 .751 .941 r
.77398 .2704 .7782 .27588 .78808 .27367 .78386 .26798 Metetra
.617 .742 .936 r
.78386 .26798 .78808 .27367 .79799 .27153 .79378 .26561 Metetra
.626 .738 .928 r
.79378 .26561 .79799 .27153 .80793 .26917 .80373 .26307 Metetra
.635 .735 .921 r
.80373 .26307 .80793 .26917 .81789 .26658 .8137 .26033 Metetra
.643 .733 .915 r
.8137 .26033 .81789 .26658 .82787 .26378 .8237 .25741 Metetra
.651 .734 .91 r
.8237 .25741 .82787 .26378 .83786 .26072 .83371 .25428 Metetra
.663 .742 .909 r
.21136 .45706 .21683 .46214 .22484 .45938 .21938 .4543 Metetra
.666 .743 .908 r
.21938 .4543 .22484 .45938 .23288 .45654 .22743 .45147 Metetra
.669 .745 .907 r
.22743 .45147 .23288 .45654 .24095 .4536 .23551 .44857 Metetra
.673 .748 .907 r
.23551 .44857 .24095 .4536 .24905 .45054 .24363 .44557 Metetra
.678 .752 .907 r
.24363 .44557 .24905 .45054 .25719 .44731 .25177 .44245 Metetra
.68 .757 .91 r
.25177 .44245 .25719 .44731 .26535 .44405 .25994 .4393 Metetra
.673 .761 .917 r
.25994 .4393 .26535 .44405 .27353 .44096 .26813 .43627 Metetra
.661 .761 .924 r
.26813 .43627 .27353 .44096 .2817 .43819 .27632 .43349 Metetra
.646 .757 .931 r
.27632 .43349 .2817 .43819 .28987 .43582 .28451 .431 Metetra
.628 .748 .934 r
.28451 .431 .28987 .43582 .29804 .43386 .2927 .42883 Metetra
.615 .736 .932 r
.2927 .42883 .29804 .43386 .30621 .43222 .30091 .4269 Metetra
.609 .723 .926 r
.30091 .4269 .30621 .43222 .31441 .43076 .30914 .42509 Metetra
.603 .707 .918 r
.30914 .42509 .31441 .43076 .32262 .42948 .31739 .42343 Metetra
.603 .693 .906 r
.31739 .42343 .32262 .42948 .33087 .42825 .32567 .4218 Metetra
.622 .686 .889 r
.32567 .4218 .33087 .42825 .33918 .42654 .33401 .4198 Metetra
.654 .689 .871 r
.33401 .4198 .33918 .42654 .34757 .42383 .34241 .41705 Metetra
.69 .7 .854 r
.34241 .41705 .34757 .42383 .35606 .41974 .3509 .41324 Metetra
.729 .72 .842 r
.3509 .41324 .35606 .41974 .36465 .41403 .35948 .40821 Metetra
.761 .748 .841 r
.35948 .40821 .36465 .41403 .37332 .407 .36812 .40216 Metetra
.784 .785 .854 r
.36812 .40216 .37332 .407 .38202 .39939 .37679 .39567 Metetra
.797 .83 .877 r
.37679 .39567 .38202 .39939 .39071 .3918 .38547 .38919 Metetra
.795 .879 .908 r
.38547 .38919 .39071 .3918 .39939 .38473 .39413 .3831 Metetra
.746 .924 .95 r
.39413 .3831 .39939 .38473 .40802 .37907 .40277 .37808 Metetra
.571 .91 .974 r
.40277 .37808 .40802 .37907 .41658 .37597 .41136 .37501 Metetra
.188 .707 .877 r
.41136 .37501 .41658 .37597 .42505 .37645 .41988 .37466 Metetra
.254 0 0 r
.41988 .37466 .42505 .37645 .43344 .38146 .42834 .37776 Metetra
.485 0 0 r
.42834 .37776 .43344 .38146 .44177 .39137 .43676 .38456 Metetra
0 0 .534 r
.43676 .38456 .44177 .39137 .45011 .40528 .44518 .39438 Metetra
0 .047 .614 r
.44518 .39438 .45011 .40528 .45851 .42173 .45366 .40607 Metetra
.019 .134 .644 r
.45366 .40607 .45851 .42173 .46703 .43948 .46223 .4187 Metetra
.203 .211 .645 r
.46223 .4187 .46703 .43948 .47569 .457 .47092 .43111 Metetra
.337 .274 .638 r
.47092 .43111 .47569 .457 .48451 .47234 .47975 .44184 Metetra
.434 .325 .631 r
.47975 .44184 .48451 .47234 .49351 .48366 .48871 .44953 Metetra
.51 .37 .626 r
.48871 .44953 .49351 .48366 .50266 .48903 .4978 .45275 Metetra
.575 .411 .622 r
.4978 .45275 .50266 .48903 .51191 .48672 .50699 .45025 Metetra
.626 .448 .621 r
.50699 .45025 .51191 .48672 .52121 .47657 .51623 .44188 Metetra
.667 .479 .622 r
.51623 .44188 .52121 .47657 .53049 .46004 .52546 .42875 Metetra
.701 .509 .625 r
.52546 .42875 .53049 .46004 .5397 .43899 .53466 .4122 Metetra
.733 .541 .632 r
.53466 .4122 .5397 .43899 .54882 .4152 .5438 .39355 Metetra
.765 .577 .643 r
.5438 .39355 .54882 .4152 .55784 .39068 .55288 .37431 Metetra
.798 .62 .661 r
.55288 .37431 .55784 .39068 .56679 .36713 .5619 .35574 Metetra
.832 .676 .689 r
.5619 .35574 .56679 .36713 .57568 .34594 .57089 .33891 Metetra
.863 .752 .738 r
.57089 .33891 .57568 .34594 .58458 .32875 .57988 .32509 Metetra
.869 .856 .826 r
.57988 .32509 .58458 .32875 .59353 .31674 .58892 .31519 Metetra
.774 .952 .932 r
.58892 .31519 .59353 .31674 .60259 .3097 .59804 .30907 Metetra
.486 .891 .935 r
.59804 .30907 .60259 .3097 .61177 .30673 .60725 .30604 Metetra
.193 .717 .857 r
.60725 .30604 .61177 .30673 .62107 .30678 .61656 .30531 Metetra
.101 .634 .864 r
.61656 .30531 .62107 .30678 .63048 .30863 .62597 .30595 Metetra
.171 .638 .934 r
.62597 .30595 .63048 .30863 .63999 .31123 .63544 .30716 Metetra
.294 .647 .968 r
.63544 .30716 .63999 .31123 .64956 .31393 .64498 .30843 Metetra
.419 .648 .953 r
.64498 .30843 .64956 .31393 .65917 .31599 .65455 .30921 Metetra
.531 .653 .913 r
.65455 .30921 .65917 .31599 .66877 .31648 .66413 .30879 Metetra
.609 .661 .875 r
.66413 .30879 .66877 .31648 .67833 .31493 .67368 .30682 Metetra
.658 .672 .852 r
.67368 .30682 .67833 .31493 .68784 .31157 .68321 .30348 Metetra
.691 .687 .842 r
.68321 .30348 .68784 .31157 .6973 .30682 .69271 .29908 Metetra
.71 .705 .843 r
.69271 .29908 .6973 .30682 .70674 .30132 .7022 .2941 Metetra
.717 .724 .855 r
.7022 .2941 .70674 .30132 .7162 .29571 .71171 .28905 Metetra
.717 .742 .871 r
.71171 .28905 .7162 .29571 .72568 .2903 .72125 .28414 Metetra
.715 .759 .887 r
.72125 .28414 .72568 .2903 .7352 .28515 .73083 .27942 Metetra
.704 .773 .905 r
.73083 .27942 .7352 .28515 .74478 .28048 .74045 .27506 Metetra
.684 .779 .923 r
.74045 .27506 .74478 .28048 .75443 .27648 .75015 .27122 Metetra
.661 .778 .936 r
.75015 .27122 .75443 .27648 .76417 .27316 .75991 .26788 Metetra
.641 .77 .942 r
.75991 .26788 .76417 .27316 .77398 .2704 .76973 .26497 Metetra
.628 .759 .941 r
.76973 .26497 .77398 .2704 .78386 .26798 .77962 .26231 Metetra
.628 .75 .935 r
.77962 .26231 .78386 .26798 .79378 .26561 .78955 .25969 Metetra
.635 .743 .926 r
.78955 .25969 .79378 .26561 .80373 .26307 .7995 .25693 Metetra
.642 .738 .919 r
.7995 .25693 .80373 .26307 .8137 .26033 .80949 .25403 Metetra
.647 .735 .913 r
.80949 .25403 .8137 .26033 .8237 .25741 .81949 .25098 Metetra
.654 .734 .908 r
.81949 .25098 .8237 .25741 .83371 .25428 .82952 .24777 Metetra
.663 .742 .909 r
.20586 .45195 .21136 .45706 .21938 .4543 .2139 .44919 Metetra
.664 .743 .908 r
.2139 .44919 .21938 .4543 .22743 .45147 .22196 .44638 Metetra
.666 .744 .908 r
.22196 .44638 .22743 .45147 .23551 .44857 .23005 .44352 Metetra
.669 .747 .909 r
.23005 .44352 .23551 .44857 .24363 .44557 .23817 .44058 Metetra
.673 .751 .91 r
.23817 .44058 .24363 .44557 .25177 .44245 .24632 .43756 Metetra
.674 .756 .913 r
.24632 .43756 .25177 .44245 .25994 .4393 .2545 .43452 Metetra
.67 .76 .919 r
.2545 .43452 .25994 .4393 .26813 .43627 .26269 .43156 Metetra
.661 .762 .925 r
.26269 .43156 .26813 .43627 .27632 .43349 .2709 .42876 Metetra
.651 .759 .929 r
.2709 .42876 .27632 .43349 .28451 .431 .27911 .42616 Metetra
.639 .752 .93 r
.27911 .42616 .28451 .431 .2927 .42883 .28734 .42377 Metetra
.631 .741 .927 r
.28734 .42377 .2927 .42883 .30091 .4269 .29558 .42154 Metetra
.628 .728 .92 r
.29558 .42154 .30091 .4269 .30914 .42509 .30385 .41939 Metetra
.624 .714 .911 r
.30385 .41939 .30914 .42509 .31739 .42343 .31213 .41733 Metetra
.623 .7 .9 r
.31213 .41733 .31739 .42343 .32567 .4218 .32045 .41529 Metetra
.635 .69 .884 r
.32045 .41529 .32567 .4218 .33401 .4198 .32881 .413 Metetra
.655 .688 .869 r
.32881 .413 .33401 .4198 .34241 .41705 .33723 .4102 Metetra
.68 .696 .858 r
.33723 .4102 .34241 .41705 .3509 .41324 .34572 .40668 Metetra
.709 .714 .853 r
.34572 .40668 .3509 .41324 .35948 .40821 .35428 .40233 Metetra
.735 .743 .858 r
.35428 .40233 .35948 .40821 .36812 .40216 .36288 .3973 Metetra
.754 .783 .877 r
.36288 .3973 .36812 .40216 .37679 .39567 .37152 .39196 Metetra
.763 .831 .905 r
.37152 .39196 .37679 .39567 .38547 .38919 .38017 .38663 Metetra
.756 .883 .936 r
.38017 .38663 .38547 .38919 .39413 .3831 .38883 .38155 Metetra
.704 .924 .966 r
.38883 .38155 .39413 .3831 .40277 .37808 .39747 .37719 Metetra
.559 .908 .969 r
.39747 .37719 .40277 .37808 .41136 .37501 .40609 .37415 Metetra
.31 .787 .919 r
.40609 .37415 .41136 .37501 .41988 .37466 .41466 .37295 Metetra
.042 .585 .844 r
.41466 .37295 .41988 .37466 .42834 .37776 .4232 .37407 Metetra
0 .405 .814 r
.4232 .37407 .42834 .37776 .43676 .38456 .43172 .37769 Metetra
0 .328 .813 r
.43172 .37769 .43676 .38456 .44518 .39438 .44025 .38331 Metetra
.168 .313 .768 r
.44025 .38331 .44518 .39438 .45366 .40607 .44882 .39017 Metetra
.292 .315 .713 r
.44882 .39017 .45366 .40607 .46223 .4187 .45746 .39762 Metetra
.377 .327 .674 r
.45746 .39762 .46223 .4187 .47092 .43111 .46619 .40489 Metetra
.442 .345 .649 r
.46619 .40489 .47092 .43111 .47975 .44184 .47503 .41101 Metetra
.492 .364 .634 r
.47503 .41101 .47975 .44184 .48871 .44953 .48397 .41508 Metetra
.535 .386 .625 r
.48397 .41508 .48871 .44953 .4978 .45275 .49301 .41617 Metetra
.575 .41 .621 r
.49301 .41617 .4978 .45275 .50699 .45025 .50214 .41347 Metetra
.611 .435 .62 r
.50214 .41347 .50699 .45025 .51623 .44188 .5113 .40689 Metetra
.64 .459 .622 r
.5113 .40689 .51623 .44188 .52546 .42875 .52049 .39713 Metetra
.668 .485 .628 r
.52049 .39713 .52546 .42875 .53466 .4122 .52966 .38507 Metetra
.695 .514 .638 r
.52966 .38507 .53466 .4122 .5438 .39355 .53881 .3716 Metetra
.724 .55 .654 r
.53881 .3716 .5438 .39355 .55288 .37431 .54792 .35768 Metetra
.756 .596 .679 r
.54792 .35768 .55288 .37431 .5619 .35574 .55701 .34418 Metetra
.791 .658 .716 r
.55701 .34418 .5619 .35574 .57089 .33891 .56608 .33182 Metetra
.825 .746 .777 r
.56608 .33182 .57089 .33891 .57988 .32509 .57516 .32146 Metetra
.828 .863 .873 r
.57516 .32146 .57988 .32509 .58892 .31519 .58427 .31373 Metetra
.72 .949 .953 r
.58427 .31373 .58892 .31519 .59804 .30907 .59345 .30856 Metetra
.477 .89 .926 r
.59345 .30856 .59804 .30907 .60725 .30604 .6027 .30547 Metetra
.286 .781 .882 r
.6027 .30547 .60725 .30604 .61656 .30531 .61202 .30394 Metetra
.258 .746 .922 r
.61202 .30394 .61656 .30531 .62597 .30595 .62141 .30333 Metetra
.34 .747 .981 r
.62141 .30333 .62597 .30595 .63544 .30716 .63087 .30309 Metetra
.435 .727 .988 r
.63087 .30309 .63544 .30716 .64498 .30843 .64037 .3029 Metetra
.513 .696 .952 r
.64037 .3029 .64498 .30843 .65455 .30921 .64991 .30237 Metetra
.578 .675 .906 r
.64991 .30237 .65455 .30921 .66413 .30879 .65946 .30102 Metetra
.625 .667 .87 r
.65946 .30102 .66413 .30879 .67368 .30682 .66901 .29862 Metetra
.657 .67 .851 r
.66901 .29862 .67368 .30682 .68321 .30348 .67855 .2953 Metetra
.679 .681 .844 r
.67855 .2953 .68321 .30348 .69271 .29908 .68809 .29126 Metetra
.694 .697 .849 r
.68809 .29126 .69271 .29908 .7022 .2941 .69763 .28682 Metetra
.699 .716 .862 r
.69763 .28682 .7022 .2941 .71171 .28905 .7072 .28233 Metetra
.7 .735 .878 r
.7072 .28233 .71171 .28905 .72125 .28414 .71679 .27793 Metetra
.699 .753 .894 r
.71679 .27793 .72125 .28414 .73083 .27942 .72643 .27366 Metetra
.691 .768 .911 r
.72643 .27366 .73083 .27942 .74045 .27506 .7361 .26963 Metetra
.677 .777 .926 r
.7361 .26963 .74045 .27506 .75015 .27122 .74583 .26594 Metetra
.661 .779 .936 r
.74583 .26594 .75015 .27122 .75991 .26788 .75562 .26259 Metetra
.647 .774 .94 r
.75562 .26259 .75991 .26788 .76973 .26497 .76546 .25952 Metetra
.639 .764 .939 r
.76546 .25952 .76973 .26497 .77962 .26231 .77535 .25662 Metetra
.639 .755 .932 r
.77535 .25662 .77962 .26231 .78955 .25969 .78529 .25374 Metetra
.644 .747 .924 r
.78529 .25374 .78955 .25969 .7995 .25693 .79525 .25076 Metetra
.648 .741 .917 r
.79525 .25076 .7995 .25693 .80949 .25403 .80524 .24768 Metetra
.652 .737 .912 r
.80524 .24768 .80949 .25403 .81949 .25098 .81526 .2445 Metetra
.656 .735 .907 r
.81526 .2445 .81949 .25098 .82952 .24777 .82531 .24121 Metetra
.662 .742 .909 r
.20033 .44682 .20586 .45195 .2139 .44919 .20838 .44406 Metetra
.663 .742 .909 r
.20838 .44406 .2139 .44919 .22196 .44638 .21645 .44126 Metetra
.664 .744 .909 r
.21645 .44126 .22196 .44638 .23005 .44352 .22455 .43843 Metetra
.666 .746 .91 r
.22455 .43843 .23005 .44352 .23817 .44058 .23268 .43556 Metetra
.668 .75 .912 r
.23268 .43556 .23817 .44058 .24632 .43756 .24084 .43264 Metetra
.668 .754 .915 r
.24084 .43264 .24632 .43756 .2545 .43452 .24902 .4297 Metetra
.666 .759 .92 r
.24902 .4297 .2545 .43452 .26269 .43156 .25722 .4268 Metetra
.661 .761 .924 r
.25722 .4268 .26269 .43156 .2709 .42876 .26545 .42399 Metetra
.656 .76 .926 r
.26545 .42399 .2709 .42876 .27911 .42616 .27369 .42127 Metetra
.65 .754 .926 r
.27369 .42127 .27911 .42616 .28734 .42377 .28194 .41867 Metetra
.646 .745 .921 r
.28194 .41867 .28734 .42377 .29558 .42154 .29022 .41615 Metetra
.644 .733 .914 r
.29022 .41615 .29558 .42154 .30385 .41939 .29852 .41367 Metetra
.641 .721 .905 r
.29852 .41367 .30385 .41939 .31213 .41733 .30685 .41124 Metetra
.641 .707 .895 r
.30685 .41124 .31213 .41733 .32045 .41529 .3152 .40881 Metetra
.646 .696 .882 r
.3152 .40881 .32045 .41529 .32881 .413 .32359 .40624 Metetra
.656 .691 .871 r
.32359 .40624 .32881 .413 .33723 .4102 .33203 .40339 Metetra
.67 .695 .864 r
.33203 .40339 .33723 .4102 .34572 .40668 .34051 .40015 Metetra
.688 .71 .865 r
.34051 .40015 .34572 .40668 .35428 .40233 .34904 .39646 Metetra
.705 .737 .876 r
.34904 .39646 .35428 .40233 .36288 .3973 .35762 .39239 Metetra
.717 .776 .899 r
.35762 .39239 .36288 .3973 .37152 .39196 .36623 .38814 Metetra
.721 .824 .929 r
.36623 .38814 .37152 .39196 .38017 .38663 .37485 .3839 Metetra
.71 .873 .958 r
.37485 .3839 .38017 .38663 .38883 .38155 .38349 .37979 Metetra
.665 .909 .978 r
.38349 .37979 .38883 .38155 .39747 .37719 .39213 .37607 Metetra
.57 .906 .977 r
.39213 .37607 .39747 .37719 .40609 .37415 .40078 .37305 Metetra
.45 .857 .965 r
.40078 .37305 .40609 .37415 .41466 .37295 .40941 .37104 Metetra
.358 .782 .974 r
.40941 .37104 .41466 .37295 .4232 .37407 .41803 .37027 Metetra
.341 .686 .98 r
.41803 .37027 .4232 .37407 .43172 .37769 .42665 .37085 Metetra
.39 .573 .911 r
.42665 .37085 .43172 .37769 .44025 .38331 .43529 .3725 Metetra
.439 .486 .811 r
.43529 .3725 .44025 .38331 .44882 .39017 .44396 .37479 Metetra
.471 .436 .737 r
.44396 .37479 .44882 .39017 .45746 .39762 .45269 .37739 Metetra
.496 .411 .689 r
.45269 .37739 .45746 .39762 .46619 .40489 .46148 .37987 Metetra
.518 .401 .659 r
.46148 .37987 .46619 .40489 .47503 .41101 .47034 .38171 Metetra
.538 .4 .641 r
.47034 .38171 .47503 .41101 .48397 .41508 .47927 .38245 Metetra
.558 .405 .63 r
.47927 .38245 .48397 .41508 .49301 .41617 .48827 .38159 Metetra
.578 .415 .625 r
.48827 .38159 .49301 .41617 .50214 .41347 .49733 .37871 Metetra
.599 .429 .624 r
.49733 .37871 .50214 .41347 .5113 .40689 .50643 .37375 Metetra
.617 .446 .628 r
.50643 .37375 .5113 .40689 .52049 .39713 .51556 .3671 Metetra
.636 .466 .636 r
.51556 .3671 .52049 .39713 .52966 .38507 .5247 .35921 Metetra
.657 .492 .649 r
.5247 .35921 .52966 .38507 .53881 .3716 .53383 .35054 Metetra
.68 .526 .67 r
.53383 .35054 .53881 .3716 .54792 .35768 .54297 .34161 Metetra
.707 .573 .701 r
.54297 .34161 .54792 .35768 .55701 .34418 .5521 .33288 Metetra
.74 .639 .749 r
.5521 .33288 .55701 .34418 .56608 .33182 .56124 .32475 Metetra
.769 .736 .822 r
.56124 .32475 .56608 .33182 .57516 .32146 .57039 .31769 Metetra
.765 .856 .917 r
.57039 .31769 .57516 .32146 .58427 .31373 .57958 .31204 Metetra
.668 .929 .971 r
.57958 .31204 .58427 .31373 .59345 .30856 .58881 .30777 Metetra
.507 .898 .946 r
.58881 .30777 .59345 .30856 .6027 .30547 .59809 .30463 Metetra
.414 .851 .934 r
.59809 .30463 .6027 .30547 .61202 .30394 .60743 .30233 Metetra
.43 .838 .973 r
.60743 .30233 .61202 .30394 .62141 .30333 .61682 .30052 Metetra
.496 .82 1 r
.61682 .30052 .62141 .30333 .63087 .30309 .62625 .29891 Metetra
.551 .777 .983 r
.62625 .29891 .63087 .30309 .64037 .3029 .63573 .29732 Metetra
.589 .73 .941 r
.63573 .29732 .64037 .3029 .64991 .30237 .64524 .29553 Metetra
.618 .695 .899 r
.64524 .29553 .64991 .30237 .65946 .30102 .65477 .2933 Metetra
.64 .677 .869 r
.65477 .2933 .65946 .30102 .66901 .29862 .66432 .2905 Metetra
.656 .673 .854 r
.66432 .2905 .66901 .29862 .67855 .2953 .67388 .28719 Metetra
.669 .679 .851 r
.67388 .28719 .67855 .2953 .68809 .29126 .68345 .28349 Metetra
.678 .693 .857 r
.68345 .28349 .68809 .29126 .69763 .28682 .69304 .27957 Metetra
.682 .711 .87 r
.69304 .27957 .69763 .28682 .7072 .28233 .70266 .27561 Metetra
.683 .73 .886 r
.70266 .27561 .7072 .28233 .71679 .27793 .71231 .2717 Metetra
.682 .747 .901 r
.71231 .2717 .71679 .27793 .72643 .27366 .72199 .26785 Metetra
.678 .763 .915 r
.72199 .26785 .72643 .27366 .7361 .26963 .73171 .26412 Metetra
.67 .773 .927 r
.73171 .26412 .7361 .26963 .74583 .26594 .74148 .26058 Metetra
.661 .777 .935 r
.74148 .26058 .74583 .26594 .75562 .26259 .7513 .25721 Metetra
.654 .774 .937 r
.7513 .25721 .75562 .26259 .76546 .25952 .76115 .25399 Metetra
.649 .767 .935 r
.76115 .25399 .76546 .25952 .77535 .25662 .77106 .25086 Metetra
.649 .758 .929 r
.77106 .25086 .77535 .25662 .78529 .25374 .781 .24773 Metetra
.652 .75 .922 r
.781 .24773 .78529 .25374 .79525 .25076 .79097 .24455 Metetra
.654 .744 .915 r
.79097 .24455 .79525 .25076 .80524 .24768 .80097 .2413 Metetra
.656 .739 .911 r
.80097 .2413 .80524 .24768 .81526 .2445 .811 .23799 Metetra
.658 .736 .907 r
.811 .23799 .81526 .2445 .82531 .24121 .82107 .23462 Metetra
.661 .742 .91 r
.19477 .44167 .20033 .44682 .20838 .44406 .20283 .4389 Metetra
.662 .742 .91 r
.20283 .4389 .20838 .44406 .21645 .44126 .21091 .43611 Metetra
.662 .743 .91 r
.21091 .43611 .21645 .44126 .22455 .43843 .21903 .43331 Metetra
.662 .745 .912 r
.21903 .43331 .22455 .43843 .23268 .43556 .22716 .43049 Metetra
.663 .748 .913 r
.22716 .43049 .23268 .43556 .24084 .43264 .23533 .42766 Metetra
.663 .752 .916 r
.23533 .42766 .24084 .43264 .24902 .4297 .24352 .42481 Metetra
.663 .756 .92 r
.24352 .42481 .24902 .4297 .25722 .4268 .25173 .42196 Metetra
.661 .759 .922 r
.25173 .42196 .25722 .4268 .26545 .42399 .25997 .41913 Metetra
.66 .759 .923 r
.25997 .41913 .26545 .42399 .27369 .42127 .26823 .41632 Metetra
.659 .755 .921 r
.26823 .41632 .27369 .42127 .28194 .41867 .27651 .41353 Metetra
.658 .748 .916 r
.27651 .41353 .28194 .41867 .29022 .41615 .28482 .41075 Metetra
.657 .738 .909 r
.28482 .41075 .29022 .41615 .29852 .41367 .29316 .40798 Metetra
.656 .727 .902 r
.29316 .40798 .29852 .41367 .30685 .41124 .30152 .40521 Metetra
.655 .715 .892 r
.30152 .40521 .30685 .41124 .3152 .40881 .30991 .40244 Metetra
.656 .704 .883 r
.30991 .40244 .3152 .40881 .32359 .40624 .31833 .39963 Metetra
.658 .697 .875 r
.31833 .39963 .32359 .40624 .33203 .40339 .32678 .39673 Metetra
.661 .698 .873 r
.32678 .39673 .33203 .40339 .34051 .40015 .33526 .39373 Metetra
.667 .708 .878 r
.33526 .39373 .34051 .40015 .34904 .39646 .34378 .39061 Metetra
.673 .73 .893 r
.34378 .39061 .34904 .39646 .35762 .39239 .35233 .38739 Metetra
.677 .765 .917 r
.35233 .38739 .35762 .39239 .36623 .38814 .3609 .38411 Metetra
.675 .807 .945 r
.3609 .38411 .36623 .38814 .37485 .3839 .3695 .38083 Metetra
.664 .849 .971 r
.3695 .38083 .37485 .3839 .38349 .37979 .37813 .37758 Metetra
.637 .883 .986 r
.37813 .37758 .38349 .37979 .39213 .37607 .38677 .37441 Metetra
.597 .896 .988 r
.38677 .37441 .39213 .37607 .40078 .37305 .39544 .37142 Metetra
.571 .889 .989 r
.39544 .37142 .40078 .37305 .40941 .37104 .40412 .36867 Metetra
.578 .861 .996 r
.40412 .36867 .40941 .37104 .41803 .37027 .41283 .36624 Metetra
.6 .79 .971 r
.41283 .36624 .41803 .37027 .42665 .37085 .42155 .36413 Metetra
.608 .682 .894 r
.42155 .36413 .42665 .37085 .43529 .3725 .4303 .36229 Metetra
.6 .587 .809 r
.4303 .36229 .43529 .3725 .44396 .37479 .43908 .3606 Metetra
.59 .521 .745 r
.43908 .3606 .44396 .37479 .45269 .37739 .44789 .35897 Metetra
.583 .479 .701 r
.44789 .35897 .45269 .37739 .46148 .37987 .45674 .3573 Metetra
.579 .452 .671 r
.45674 .3573 .46148 .37987 .47034 .38171 .46563 .35547 Metetra
.578 .437 .652 r
.46563 .35547 .47034 .38171 .47927 .38245 .47457 .35334 Metetra
.58 .429 .641 r
.47457 .35334 .47927 .38245 .48827 .38159 .48354 .35082 Metetra
.584 .427 .635 r
.48354 .35082 .48827 .38159 .49733 .37871 .49255 .34777 Metetra
.589 .431 .634 r
.49255 .34777 .49733 .37871 .50643 .37375 .50159 .34421 Metetra
.596 .439 .639 r
.50159 .34421 .50643 .37375 .51556 .3671 .51066 .34021 Metetra
.605 .453 .649 r
.51066 .34021 .51556 .3671 .5247 .35921 .51976 .3359 Metetra
.617 .474 .666 r
.51976 .3359 .5247 .35921 .53383 .35054 .52888 .33138 Metetra
.631 .505 .691 r
.52888 .33138 .53383 .35054 .54297 .34161 .53802 .32678 Metetra
.65 .551 .73 r
.53802 .32678 .54297 .34161 .5521 .33288 .54719 .32222 Metetra
.673 .619 .786 r
.54719 .32222 .5521 .33288 .56124 .32475 .55638 .3178 Metetra
.694 .716 .866 r
.55638 .3178 .56124 .32475 .57039 .31769 .56559 .31364 Metetra
.687 .829 .951 r
.56559 .31364 .57039 .31769 .57958 .31204 .57484 .30983 Metetra
.628 .897 .986 r
.57484 .30983 .57958 .31204 .58881 .30777 .58412 .30636 Metetra
.56 .904 .975 r
.58412 .30636 .58881 .30777 .59809 .30463 .59343 .30317 Metetra
.541 .895 .976 r
.59343 .30317 .59809 .30463 .60743 .30233 .60279 .30018 Metetra
.572 .882 .992 r
.60279 .30018 .60743 .30233 .61682 .30052 .61217 .29731 Metetra
.61 .849 .989 r
.61217 .29731 .61682 .30052 .62625 .29891 .6216 .29449 Metetra
.634 .8 .962 r
.6216 .29449 .62625 .29891 .63573 .29732 .63106 .29165 Metetra
.645 .751 .926 r
.63106 .29165 .63573 .29732 .64524 .29553 .64055 .28876 Metetra
.65 .712 .893 r
.64055 .28876 .64524 .29553 .65477 .2933 .65007 .28575 Metetra
.653 .689 .871 r
.65007 .28575 .65477 .2933 .66432 .2905 .65962 .28259 Metetra
.656 .68 .861 r
.65962 .28259 .66432 .2905 .67388 .28719 .6692 .27929 Metetra
.66 .682 .86 r
.6692 .27929 .67388 .28719 .68345 .28349 .6788 .27588 Metetra
.663 .693 .868 r
.6788 .27588 .68345 .28349 .69304 .27957 .68843 .27241 Metetra
.665 .709 .88 r
.68843 .27241 .69304 .27957 .70266 .27561 .6981 .26892 Metetra
.666 .726 .894 r
.6981 .26892 .70266 .27561 .71231 .2717 .7078 .26544 Metetra
.667 .742 .907 r
.7078 .26544 .71231 .2717 .72199 .26785 .71753 .26196 Metetra
.666 .757 .918 r
.71753 .26196 .72199 .26785 .73171 .26412 .72729 .2585 Metetra
.663 .768 .927 r
.72729 .2585 .73171 .26412 .74148 .26058 .7371 .25508 Metetra
.661 .773 .932 r
.7371 .25508 .74148 .26058 .7513 .25721 .74694 .2517 Metetra
.659 .772 .933 r
.74694 .2517 .7513 .25721 .76115 .25399 .75681 .24835 Metetra
.658 .767 .93 r
.75681 .24835 .76115 .25399 .77106 .25086 .76673 .24501 Metetra
.658 .76 .925 r
.76673 .24501 .77106 .25086 .781 .24773 .77667 .24166 Metetra
.659 .752 .919 r
.77667 .24166 .781 .24773 .79097 .24455 .78666 .23829 Metetra
.66 .746 .914 r
.78666 .23829 .79097 .24455 .80097 .2413 .79667 .23489 Metetra
.66 .741 .91 r
.79667 .23489 .80097 .2413 .811 .23799 .80672 .23147 Metetra
.661 .738 .907 r
.80672 .23147 .811 .23799 .82107 .23462 .81681 .22802 Metetra
.661 .742 .91 r
.18917 .4365 .19477 .44167 .20283 .4389 .19725 .43372 Metetra
.661 .743 .911 r
.19725 .43372 .20283 .4389 .21091 .43611 .20534 .43094 Metetra
.66 .743 .911 r
.20534 .43094 .21091 .43611 .21903 .43331 .21347 .42816 Metetra
.66 .744 .913 r
.21347 .42816 .21903 .43331 .22716 .43049 .22161 .42538 Metetra
.659 .746 .914 r
.22161 .42538 .22716 .43049 .23533 .42766 .22979 .4226 Metetra
.659 .749 .917 r
.22979 .4226 .23533 .42766 .24352 .42481 .23798 .41982 Metetra
.66 .753 .919 r
.23798 .41982 .24352 .42481 .25173 .42196 .24621 .41701 Metetra
.661 .756 .92 r
.24621 .41701 .25173 .42196 .25997 .41913 .25446 .41416 Metetra
.663 .756 .919 r
.25446 .41416 .25997 .41913 .26823 .41632 .26274 .41127 Metetra
.665 .754 .916 r
.26274 .41127 .26823 .41632 .27651 .41353 .27106 .40833 Metetra
.666 .749 .912 r
.27106 .40833 .27651 .41353 .28482 .41075 .2794 .40536 Metetra
.667 .742 .906 r
.2794 .40536 .28482 .41075 .29316 .40798 .28776 .40235 Metetra
.667 .734 .9 r
.28776 .40235 .29316 .40798 .30152 .40521 .29616 .39932 Metetra
.666 .725 .893 r
.29616 .39932 .30152 .40521 .30991 .40244 .30458 .39628 Metetra
.664 .715 .886 r
.30458 .39628 .30991 .40244 .31833 .39963 .31302 .39327 Metetra
.66 .708 .883 r
.31302 .39327 .31833 .39963 .32678 .39673 .32149 .39034 Metetra
.655 .705 .884 r
.32149 .39034 .32678 .39673 .33526 .39373 .32997 .38752 Metetra
.649 .71 .892 r
.32997 .38752 .33526 .39373 .34378 .39061 .33848 .38484 Metetra
.644 .725 .908 r
.33848 .38484 .34378 .39061 .35233 .38739 .347 .38226 Metetra
.64 .751 .929 r
.347 .38226 .35233 .38739 .3609 .38411 .35556 .37973 Metetra
.636 .782 .952 r
.35556 .37973 .3609 .38411 .3695 .38083 .36414 .37719 Metetra
.629 .815 .972 r
.36414 .37719 .3695 .38083 .37813 .37758 .37276 .37459 Metetra
.624 .846 .984 r
.37276 .37459 .37813 .37758 .38677 .37441 .38141 .37186 Metetra
.63 .868 .987 r
.38141 .37186 .38677 .37441 .39544 .37142 .3901 .36888 Metetra
.653 .875 .981 r
.3901 .36888 .39544 .37142 .40412 .36867 .39883 .36556 Metetra
.688 .857 .963 r
.39883 .36556 .40412 .36867 .41283 .36624 .4076 .36183 Metetra
.713 .804 .922 r
.4076 .36183 .41283 .36624 .42155 .36413 .41642 .35765 Metetra
.712 .727 .862 r
.41642 .35765 .42155 .36413 .4303 .36229 .42526 .35311 Metetra
.694 .652 .803 r
.42526 .35311 .4303 .36229 .43908 .3606 .43413 .34836 Metetra
.673 .59 .755 r
.43413 .34836 .43908 .3606 .44789 .35897 .44303 .34351 Metetra
.652 .544 .719 r
.44303 .34351 .44789 .35897 .45674 .3573 .45194 .33869 Metetra
.634 .509 .693 r
.45194 .33869 .45674 .3573 .46563 .35547 .46087 .33407 Metetra
.619 .484 .675 r
.46087 .33407 .46563 .35547 .47457 .35334 .46981 .32979 Metetra
.606 .465 .664 r
.46981 .32979 .47457 .35334 .48354 .35082 .47877 .326 Metetra
.594 .452 .658 r
.47877 .326 .48354 .35082 .49255 .34777 .48774 .32283 Metetra
.585 .446 .658 r
.48774 .32283 .49255 .34777 .50159 .34421 .49674 .32031 Metetra
.579 .446 .664 r
.49674 .32031 .50159 .34421 .51066 .34021 .50577 .31831 Metetra
.576 .454 .676 r
.50577 .31831 .51066 .34021 .51976 .3359 .51483 .31669 Metetra
.575 .469 .697 r
.51483 .31669 .51976 .3359 .52888 .33138 .52394 .31531 Metetra
.578 .496 .727 r
.52394 .31531 .52888 .33138 .53802 .32678 .53308 .31401 Metetra
.584 .539 .77 r
.53308 .31401 .53802 .32678 .54719 .32222 .54226 .31264 Metetra
.594 .603 .83 r
.54226 .31264 .54719 .32222 .55638 .3178 .55149 .31107 Metetra
.605 .69 .903 r
.55149 .31107 .55638 .3178 .56559 .31364 .56075 .30915 Metetra
.612 .786 .965 r
.56075 .30915 .56559 .31364 .57484 .30983 .57004 .30676 Metetra
.611 .853 .99 r
.57004 .30676 .57484 .30983 .58412 .30636 .57936 .3039 Metetra
.616 .884 .99 r
.57936 .3039 .58412 .30636 .59343 .30317 .58871 .30067 Metetra
.638 .89 .986 r
.58871 .30067 .59343 .30317 .60279 .30018 .59808 .29715 Metetra
.663 .874 .978 r
.59808 .29715 .60279 .30018 .61217 .29731 .60748 .29345 Metetra
.679 .841 .961 r
.60748 .29345 .61217 .29731 .6216 .29449 .6169 .28967 Metetra
.684 .801 .937 r
.6169 .28967 .6216 .29449 .63106 .29165 .62635 .28588 Metetra
.681 .761 .912 r
.62635 .28588 .63106 .29165 .64055 .28876 .63584 .28213 Metetra
.673 .727 .89 r
.63584 .28213 .64055 .28876 .65007 .28575 .64536 .27852 Metetra
.664 .704 .877 r
.64536 .27852 .65007 .28575 .65962 .28259 .65491 .27507 Metetra
.657 .693 .872 r
.65491 .27507 .65962 .28259 .6692 .27929 .66451 .27177 Metetra
.653 .692 .874 r
.66451 .27177 .6692 .27929 .6788 .27588 .67414 .26859 Metetra
.651 .699 .881 r
.67414 .26859 .6788 .27588 .68843 .27241 .68381 .26546 Metetra
.652 .711 .891 r
.68381 .26546 .68843 .27241 .6981 .26892 .69352 .26233 Metetra
.653 .725 .902 r
.69352 .26233 .6981 .26892 .7078 .26544 .70326 .25916 Metetra
.654 .738 .911 r
.70326 .25916 .7078 .26544 .71753 .26196 .71303 .25597 Metetra
.656 .75 .919 r
.71303 .25597 .71753 .26196 .72729 .2585 .72284 .25271 Metetra
.659 .76 .925 r
.72284 .25271 .72729 .2585 .7371 .25508 .73267 .24939 Metetra
.661 .766 .928 r
.73267 .24939 .7371 .25508 .74694 .2517 .74254 .24599 Metetra
.663 .767 .927 r
.74254 .24599 .74694 .2517 .75681 .24835 .75243 .24252 Metetra
.665 .764 .924 r
.75243 .24252 .75681 .24835 .76673 .24501 .76236 .23902 Metetra
.665 .758 .92 r
.76236 .23902 .76673 .24501 .77667 .24166 .77232 .23549 Metetra
.664 .752 .916 r
.77232 .23549 .77667 .24166 .78666 .23829 .78232 .23197 Metetra
.664 .747 .912 r
.78232 .23197 .78666 .23829 .79667 .23489 .79235 .22845 Metetra
.663 .743 .909 r
.79235 .22845 .79667 .23489 .80672 .23147 .80242 .22494 Metetra
.662 .74 .908 r
.80242 .22494 .80672 .23147 .81681 .22802 .81252 .22143 Metetra
.661 .743 .911 r
.18354 .43133 .18917 .4365 .19725 .43372 .19163 .42853 Metetra
.66 .743 .911 r
.19163 .42853 .19725 .43372 .20534 .43094 .19974 .42575 Metetra
.659 .743 .912 r
.19974 .42575 .20534 .43094 .21347 .42816 .20788 .42297 Metetra
.658 .744 .913 r
.20788 .42297 .21347 .42816 .22161 .42538 .21603 .42021 Metetra
.657 .745 .915 r
.21603 .42021 .22161 .42538 .22979 .4226 .22422 .41746 Metetra
.657 .747 .916 r
.22422 .41746 .22979 .4226 .23798 .41982 .23242 .41471 Metetra
.658 .749 .917 r
.23242 .41471 .23798 .41982 .24621 .41701 .24066 .41192 Metetra
.661 .751 .917 r
.24066 .41192 .24621 .41701 .25446 .41416 .24893 .40906 Metetra
.665 .752 .915 r
.24893 .40906 .25446 .41416 .26274 .41127 .25723 .40611 Metetra
.669 .752 .912 r
.25723 .40611 .26274 .41127 .27106 .40833 .26557 .40307 Metetra
.671 .749 .909 r
.26557 .40307 .27106 .40833 .2794 .40536 .27393 .39996 Metetra
.673 .745 .905 r
.27393 .39996 .2794 .40536 .28776 .40235 .28233 .39681 Metetra
.674 .74 .9 r
.28233 .39681 .28776 .40235 .29616 .39932 .29075 .39361 Metetra
.674 .734 .896 r
.29075 .39361 .29616 .39932 .30458 .39628 .2992 .39039 Metetra
.669 .727 .893 r
.2992 .39039 .30458 .39628 .31302 .39327 .30766 .38725 Metetra
.661 .721 .893 r
.30766 .38725 .31302 .39327 .32149 .39034 .31614 .38429 Metetra
.65 .717 .897 r
.31614 .38429 .32149 .39034 .32997 .38752 .32464 .38158 Metetra
.636 .717 .906 r
.32464 .38158 .32997 .38752 .33848 .38484 .33314 .37916 Metetra
.623 .724 .919 r
.33314 .37916 .33848 .38484 .347 .38226 .34166 .37699 Metetra
.615 .738 .933 r
.34166 .37699 .347 .38226 .35556 .37973 .3502 .37492 Metetra
.611 .757 .948 r
.3502 .37492 .35556 .37973 .36414 .37719 .35878 .37283 Metetra
.612 .778 .96 r
.35878 .37283 .36414 .37719 .37276 .37459 .36739 .37064 Metetra
.624 .801 .967 r
.36739 .37064 .37276 .37459 .38141 .37186 .37605 .36817 Metetra
.651 .821 .965 r
.37605 .36817 .38141 .37186 .3901 .36888 .38476 .36519 Metetra
.689 .831 .951 r
.38476 .36519 .3901 .36888 .39883 .36556 .39353 .36151 Metetra
.729 .822 .923 r
.39353 .36151 .39883 .36556 .4076 .36183 .40236 .35696 Metetra
.755 .794 .884 r
.40236 .35696 .4076 .36183 .41642 .35765 .41124 .35147 Metetra
.761 .75 .843 r
.41124 .35147 .41642 .35765 .42526 .35311 .42016 .34525 Metetra
.75 .702 .806 r
.42016 .34525 .42526 .35311 .43413 .34836 .4291 .33859 Metetra
.733 .657 .774 r
.4291 .33859 .43413 .34836 .44303 .34351 .43806 .33174 Metetra
.712 .617 .749 r
.43806 .33174 .44303 .34351 .45194 .33869 .44703 .32497 Metetra
.689 .582 .73 r
.44703 .32497 .45194 .33869 .46087 .33407 .45599 .31862 Metetra
.666 .552 .717 r
.45599 .31862 .46087 .33407 .46981 .32979 .46495 .31301 Metetra
.641 .526 .708 r
.46495 .31301 .46981 .32979 .47877 .326 .47391 .30844 Metetra
.614 .504 .705 r
.47391 .30844 .47877 .326 .48774 .32283 .48287 .3052 Metetra
.587 .487 .708 r
.48287 .3052 .48774 .32283 .49674 .32031 .49185 .3033 Metetra
.564 .479 .717 r
.49185 .3033 .49674 .32031 .50577 .31831 .50085 .30252 Metetra
.545 .478 .732 r
.50085 .30252 .50577 .31831 .51483 .31669 .5099 .30255 Metetra
.528 .487 .755 r
.5099 .30255 .51483 .31669 .52394 .31531 .51899 .3031 Metetra
.515 .509 .787 r
.51899 .3031 .52394 .31531 .53308 .31401 .52813 .30383 Metetra
.508 .545 .829 r
.52813 .30383 .53308 .31401 .54226 .31264 .53733 .30443 Metetra
.509 .597 .877 r
.53733 .30443 .54226 .31264 .55149 .31107 .54658 .30463 Metetra
.527 .667 .926 r
.54658 .30463 .55149 .31107 .56075 .30915 .55587 .3041 Metetra
.564 .743 .961 r
.55587 .3041 .56075 .30915 .57004 .30676 .56519 .30259 Metetra
.609 .802 .974 r
.56519 .30259 .57004 .30676 .57936 .3039 .57455 .30011 Metetra
.651 .835 .971 r
.57455 .30011 .57936 .3039 .58871 .30067 .58392 .29684 Metetra
.683 .843 .96 r
.58392 .29684 .58871 .30067 .59808 .29715 .59331 .29298 Metetra
.702 .834 .945 r
.59331 .29298 .59808 .29715 .60748 .29345 .60272 .28875 Metetra
.709 .813 .93 r
.60272 .28875 .60748 .29345 .6169 .28967 .61216 .28438 Metetra
.708 .789 .914 r
.61216 .28438 .6169 .28967 .62635 .28588 .62162 .27998 Metetra
.701 .764 .901 r
.62162 .27998 .62635 .28588 .63584 .28213 .6311 .27569 Metetra
.688 .74 .891 r
.6311 .27569 .63584 .28213 .64536 .27852 .64063 .27168 Metetra
.672 .722 .887 r
.64063 .27168 .64536 .27852 .65491 .27507 .6502 .26805 Metetra
.658 .711 .887 r
.6502 .26805 .65491 .27507 .66451 .27177 .65982 .26475 Metetra
.649 .707 .89 r
.65982 .26475 .66451 .27177 .67414 .26859 .66948 .26169 Metetra
.643 .71 .896 r
.66948 .26169 .67414 .26859 .68381 .26546 .67918 .25877 Metetra
.643 .718 .903 r
.67918 .25877 .68381 .26546 .69352 .26233 .68892 .25585 Metetra
.644 .727 .909 r
.68892 .25585 .69352 .26233 .70326 .25916 .69869 .25288 Metetra
.646 .736 .915 r
.69869 .25288 .70326 .25916 .71303 .25597 .7085 .24985 Metetra
.65 .745 .919 r
.7085 .24985 .71303 .25597 .72284 .25271 .71834 .24672 Metetra
.656 .753 .921 r
.71834 .24672 .72284 .25271 .73267 .24939 .7282 .24344 Metetra
.661 .758 .922 r
.7282 .24344 .73267 .24939 .74254 .24599 .73809 .24002 Metetra
.666 .759 .92 r
.73809 .24002 .74254 .24599 .75243 .24252 .74801 .23648 Metetra
.669 .758 .918 r
.74801 .23648 .75243 .24252 .76236 .23902 .75795 .23286 Metetra
.669 .755 .915 r
.75795 .23286 .76236 .23902 .77232 .23549 .76793 .22922 Metetra
.668 .751 .913 r
.76793 .22922 .77232 .23549 .78232 .23197 .77795 .2256 Metetra
.666 .747 .911 r
.77795 .2256 .78232 .23197 .79235 .22845 .788 .222 Metetra
.665 .744 .91 r
.788 .222 .79235 .22845 .80242 .22494 .79809 .21842 Metetra
.663 .742 .909 r
.79809 .21842 .80242 .22494 .81252 .22143 .80821 .21486 Metetra
.661 .744 .911 r
.17788 .42613 .18354 .43133 .19163 .42853 .18598 .42333 Metetra
.66 .743 .912 r
.18598 .42333 .19163 .42853 .19974 .42575 .1941 .42053 Metetra
.659 .743 .912 r
.1941 .42053 .19974 .42575 .20788 .42297 .20225 .41775 Metetra
.658 .743 .913 r
.20225 .41775 .20788 .42297 .21603 .42021 .21042 .41498 Metetra
.656 .744 .914 r
.21042 .41498 .21603 .42021 .22422 .41746 .21862 .41224 Metetra
.656 .744 .915 r
.21862 .41224 .22422 .41746 .23242 .41471 .22684 .4095 Metetra
.658 .746 .915 r
.22684 .4095 .23242 .41471 .24066 .41192 .23509 .40671 Metetra
.661 .747 .914 r
.23509 .40671 .24066 .41192 .24893 .40906 .24338 .40383 Metetra
.666 .748 .912 r
.24338 .40383 .24893 .40906 .25723 .40611 .2517 .40084 Metetra
.67 .749 .909 r
.2517 .40084 .25723 .40611 .26557 .40307 .26005 .39775 Metetra
.673 .748 .907 r
.26005 .39775 .26557 .40307 .27393 .39996 .26844 .39458 Metetra
.675 .747 .905 r
.26844 .39458 .27393 .39996 .28233 .39681 .27685 .39135 Metetra
.677 .745 .902 r
.27685 .39135 .28233 .39681 .29075 .39361 .28529 .38806 Metetra
.677 .743 .9 r
.28529 .38806 .29075 .39361 .2992 .39039 .29376 .38476 Metetra
.672 .739 .9 r
.29376 .38476 .2992 .39039 .30766 .38725 .30225 .38156 Metetra
.662 .734 .903 r
.30225 .38156 .30766 .38725 .31614 .38429 .31075 .37857 Metetra
.648 .73 .909 r
.31075 .37857 .31614 .38429 .32464 .38158 .31925 .3759 Metetra
.63 .726 .917 r
.31925 .3759 .32464 .38158 .33314 .37916 .32776 .37359 Metetra
.613 .725 .926 r
.32776 .37359 .33314 .37916 .34166 .37699 .33628 .37158 Metetra
.604 .729 .933 r
.33628 .37158 .34166 .37699 .3502 .37492 .34483 .36969 Metetra
.603 .737 .94 r
.34483 .36969 .3502 .37492 .35878 .37283 .35341 .36779 Metetra
.608 .748 .944 r
.35341 .36779 .35878 .37283 .36739 .37064 .36203 .36576 Metetra
.626 .762 .944 r
.36203 .36576 .36739 .37064 .37605 .36817 .3707 .36339 Metetra
.658 .776 .936 r
.3707 .36339 .37605 .36817 .38476 .36519 .37944 .36041 Metetra
.698 .786 .919 r
.37944 .36041 .38476 .36519 .39353 .36151 .38823 .35656 Metetra
.737 .788 .894 r
.38823 .35656 .39353 .36151 .40236 .35696 .3971 .35164 Metetra
.767 .78 .864 r
.3971 .35164 .40236 .35696 .41124 .35147 .40602 .34558 Metetra
.781 .764 .838 r
.40602 .34558 .41124 .35147 .42016 .34525 .41499 .33862 Metetra
.782 .743 .817 r
.41499 .33862 .42016 .34525 .4291 .33859 .42398 .33113 Metetra
.776 .72 .8 r
.42398 .33113 .4291 .33859 .43806 .33174 .43299 .32339 Metetra
.763 .697 .788 r
.43299 .32339 .43806 .33174 .44703 .32497 .44199 .31577 Metetra
.744 .673 .782 r
.44199 .31577 .44703 .32497 .45599 .31862 .45099 .30868 Metetra
.719 .649 .779 r
.45099 .30868 .45599 .31862 .46495 .31301 .45997 .30248 Metetra
.686 .625 .782 r
.45997 .30248 .46495 .31301 .47391 .30844 .46894 .29757 Metetra
.643 .599 .789 r
.46894 .29757 .47391 .30844 .48287 .3052 .47791 .29427 Metetra
.594 .573 .8 r
.47791 .29427 .48287 .3052 .49185 .3033 .48688 .29264 Metetra
.546 .553 .813 r
.48688 .29264 .49185 .3033 .50085 .30252 .49588 .29237 Metetra
.501 .54 .829 r
.49588 .29237 .50085 .30252 .5099 .30255 .50492 .29309 Metetra
.462 .536 .847 r
.50492 .29309 .5099 .30255 .51899 .3031 .51402 .29447 Metetra
.436 .545 .869 r
.51402 .29447 .51899 .3031 .52813 .30383 .52316 .29607 Metetra
.427 .568 .893 r
.52316 .29607 .52813 .30383 .53733 .30443 .53237 .29751 Metetra
.438 .605 .917 r
.53237 .29751 .53733 .30443 .54658 .30463 .54164 .29847 Metetra
.481 .658 .938 r
.54164 .29847 .54658 .30463 .55587 .3041 .55095 .29853 Metetra
.548 .715 .95 r
.55095 .29853 .55587 .3041 .56519 .30259 .5603 .29738 Metetra
.613 .758 .948 r
.5603 .29738 .56519 .30259 .57455 .30011 .56967 .29506 Metetra
.662 .783 .938 r
.56967 .29506 .57455 .30011 .58392 .29684 .57907 .29176 Metetra
.694 .793 .926 r
.57907 .29176 .58392 .29684 .59331 .29298 .58849 .28774 Metetra
.711 .792 .914 r
.58849 .28774 .59331 .29298 .60272 .28875 .59792 .28327 Metetra
.716 .785 .906 r
.59792 .28327 .60272 .28875 .61216 .28438 .60737 .27862 Metetra
.716 .775 .899 r
.60737 .27862 .61216 .28438 .62162 .27998 .61685 .27395 Metetra
.709 .763 .895 r
.61685 .27395 .62162 .27998 .6311 .27569 .62635 .26941 Metetra
.694 .75 .895 r
.62635 .26941 .6311 .27569 .64063 .27168 .63589 .26523 Metetra
.676 .738 .897 r
.63589 .26523 .64063 .27168 .6502 .26805 .64548 .2615 Metetra
.659 .729 .901 r
.64548 .2615 .6502 .26805 .65982 .26475 .65512 .25819 Metetra
.646 .724 .905 r
.65512 .25819 .65982 .26475 .66948 .26169 .6648 .25518 Metetra
.639 .723 .909 r
.6648 .25518 .66948 .26169 .67918 .25877 .67453 .25233 Metetra
.638 .727 .912 r
.67453 .25233 .67918 .25877 .68892 .25585 .6843 .24949 Metetra
.64 .731 .915 r
.6843 .24949 .68892 .25585 .69869 .25288 .6941 .24659 Metetra
.643 .736 .917 r
.6941 .24659 .69869 .25288 .7085 .24985 .70393 .24362 Metetra
.647 .741 .917 r
.70393 .24362 .7085 .24985 .71834 .24672 .7138 .24053 Metetra
.654 .746 .917 r
.7138 .24053 .71834 .24672 .7282 .24344 .72369 .23726 Metetra
.661 .75 .916 r
.72369 .23726 .7282 .24344 .73809 .24002 .7336 .23382 Metetra
.667 .752 .914 r
.7336 .23382 .73809 .24002 .74801 .23648 .74354 .23023 Metetra
.67 .753 .912 r
.74354 .23023 .74801 .23648 .75795 .23286 .75351 .22655 Metetra
.671 .751 .911 r
.75351 .22655 .75795 .23286 .76793 .22922 .76351 .22285 Metetra
.669 .749 .911 r
.76351 .22285 .76793 .22922 .77795 .2256 .77355 .21917 Metetra
.667 .747 .91 r
.77355 .21917 .77795 .2256 .788 .222 .78362 .21552 Metetra
.666 .745 .91 r
.78362 .21552 .788 .222 .79809 .21842 .79374 .21189 Metetra
.664 .744 .91 r
.79374 .21189 .79809 .21842 .80821 .21486 .80389 .2083 Metetra
.661 .744 .912 r
.17218 .42093 .17788 .42613 .18598 .42333 .18029 .4181 Metetra
.66 .744 .912 r
.18029 .4181 .18598 .42333 .1941 .42053 .18843 .41529 Metetra
.659 .744 .913 r
.18843 .41529 .1941 .42053 .20225 .41775 .1966 .41249 Metetra
.658 .743 .913 r
.1966 .41249 .20225 .41775 .21042 .41498 .20478 .40971 Metetra
.656 .743 .914 r
.20478 .40971 .21042 .41498 .21862 .41224 .21299 .40695 Metetra
.656 .743 .914 r
.21299 .40695 .21862 .41224 .22684 .4095 .22123 .40419 Metetra
.658 .743 .913 r
.22123 .40419 .22684 .4095 .23509 .40671 .2295 .40138 Metetra
.661 .744 .911 r
.2295 .40138 .23509 .40671 .24338 .40383 .2378 .39848 Metetra
.666 .745 .91 r
.2378 .39848 .24338 .40383 .2517 .40084 .24613 .39548 Metetra
.67 .746 .908 r
.24613 .39548 .2517 .40084 .26005 .39775 .2545 .39238 Metetra
.673 .747 .906 r
.2545 .39238 .26005 .39775 .26844 .39458 .2629 .38918 Metetra
.675 .748 .906 r
.2629 .38918 .26844 .39458 .27685 .39135 .27133 .38594 Metetra
.677 .748 .905 r
.27133 .38594 .27685 .39135 .28529 .38806 .27979 .38264 Metetra
.678 .749 .905 r
.27979 .38264 .28529 .38806 .29376 .38476 .28828 .37932 Metetra
.673 .748 .907 r
.28828 .37932 .29376 .38476 .30225 .38156 .29678 .37611 Metetra
.663 .745 .911 r
.29678 .37611 .30225 .38156 .31075 .37857 .3053 .3731 Metetra
.648 .741 .917 r
.3053 .3731 .31075 .37857 .31925 .3759 .31382 .37041 Metetra
.629 .735 .924 r
.31382 .37041 .31925 .3759 .32776 .37359 .32234 .36807 Metetra
.613 .729 .928 r
.32234 .36807 .32776 .37359 .33628 .37158 .33088 .36604 Metetra
.605 .726 .93 r
.33088 .36604 .33628 .37158 .34483 .36969 .33944 .36413 Metetra
.606 .726 .93 r
.33944 .36413 .34483 .36969 .35341 .36779 .34804 .3622 Metetra
.613 .728 .928 r
.34804 .3622 .35341 .36779 .36203 .36576 .35668 .36015 Metetra
.63 .734 .922 r
.35668 .36015 .36203 .36576 .3707 .36339 .36537 .35775 Metetra
.659 .743 .912 r
.36537 .35775 .3707 .36339 .37944 .36041 .37412 .35475 Metetra
.694 .752 .897 r
.37412 .35475 .37944 .36041 .38823 .35656 .38293 .35089 Metetra
.73 .762 .878 r
.38293 .35089 .38823 .35656 .3971 .35164 .39182 .34597 Metetra
.762 .768 .858 r
.39182 .34597 .3971 .35164 .40602 .34558 .40076 .33991 Metetra
.783 .772 .843 r
.40076 .33991 .40602 .34558 .41499 .33862 .40976 .33297 Metetra
.795 .775 .835 r
.40976 .33297 .41499 .33862 .42398 .33113 .41877 .32549 Metetra
.8 .777 .832 r
.41877 .32549 .42398 .33113 .43299 .32339 .4278 .31778 Metetra
.798 .778 .834 r
.4278 .31778 .43299 .32339 .44199 .31577 .43683 .31017 Metetra
.788 .778 .844 r
.43683 .31017 .44199 .31577 .45099 .30868 .44585 .30309 Metetra
.767 .776 .861 r
.44585 .30309 .45099 .30868 .45997 .30248 .45486 .2969 Metetra
.73 .77 .885 r
.45486 .2969 .45997 .30248 .46894 .29757 .46385 .29198 Metetra
.669 .754 .914 r
.46385 .29198 .46894 .29757 .47791 .29427 .47284 .28867 Metetra
.585 .724 .939 r
.47284 .28867 .47791 .29427 .48688 .29264 .48183 .287 Metetra
.496 .684 .951 r
.48183 .287 .48688 .29264 .49588 .29237 .49085 .28669 Metetra
.418 .645 .951 r
.49085 .28669 .49588 .29237 .50492 .29309 .4999 .28737 Metetra
.364 .614 .947 r
.4999 .28737 .50492 .29309 .51402 .29447 .50901 .28868 Metetra
.347 .603 .944 r
.50901 .28868 .51402 .29447 .52316 .29607 .51817 .29022 Metetra
.364 .61 .944 r
.51817 .29022 .52316 .29607 .53237 .29751 .52739 .29161 Metetra
.407 .632 .946 r
.52739 .29161 .53237 .29751 .54164 .29847 .53667 .29251 Metetra
.477 .666 .946 r
.53667 .29251 .54164 .29847 .55095 .29853 .54599 .29252 Metetra
.556 .701 .937 r
.54599 .29252 .55095 .29853 .5603 .29738 .55536 .29134 Metetra
.619 .727 .924 r
.55536 .29134 .5603 .29738 .56967 .29506 .56476 .28899 Metetra
.663 .743 .91 r
.56476 .28899 .56967 .29506 .57907 .29176 .57418 .28567 Metetra
.691 .753 .899 r
.57418 .28567 .57907 .29176 .58849 .28774 .58361 .28163 Metetra
.706 .759 .893 r
.58361 .28163 .58849 .28774 .59792 .28327 .59307 .27715 Metetra
.712 .761 .89 r
.59307 .27715 .59792 .28327 .60737 .27862 .60254 .2725 Metetra
.713 .762 .89 r
.60254 .2725 .60737 .27862 .61685 .27395 .61204 .26781 Metetra
.708 .76 .893 r
.61204 .26781 .61685 .27395 .62635 .26941 .62157 .26326 Metetra
.695 .756 .899 r
.62157 .26326 .62635 .26941 .63589 .26523 .63114 .25906 Metetra
.677 .75 .906 r
.63114 .25906 .63589 .26523 .64548 .2615 .64075 .25532 Metetra
.66 .744 .912 r
.64075 .25532 .64548 .2615 .65512 .25819 .65041 .25199 Metetra
.646 .739 .917 r
.65041 .25199 .65512 .25819 .6648 .25518 .66012 .24895 Metetra
.639 .736 .919 r
.66012 .24895 .6648 .25518 .67453 .25233 .66987 .24608 Metetra
.638 .735 .919 r
.66987 .24608 .67453 .25233 .6843 .24949 .67966 .24321 Metetra
.64 .736 .918 r
.67966 .24321 .6843 .24949 .6941 .24659 .68948 .24029 Metetra
.643 .737 .917 r
.68948 .24029 .6941 .24659 .70393 .24362 .69934 .23729 Metetra
.648 .739 .916 r
.69934 .23729 .70393 .24362 .7138 .24053 .70922 .23417 Metetra
.655 .741 .914 r
.70922 .23417 .7138 .24053 .72369 .23726 .71914 .23088 Metetra
.661 .744 .911 r
.71914 .23088 .72369 .23726 .7336 .23382 .72908 .22742 Metetra
.666 .746 .91 r
.72908 .22742 .7336 .23382 .74354 .23023 .73904 .22381 Metetra
.67 .748 .909 r
.73904 .22381 .74354 .23023 .75351 .22655 .74903 .22011 Metetra
.67 .748 .909 r
.74903 .22011 .75351 .22655 .76351 .22285 .75906 .21638 Metetra
.669 .747 .909 r
.75906 .21638 .76351 .22285 .77355 .21917 .76912 .21268 Metetra
.667 .747 .91 r
.76912 .21268 .77355 .21917 .78362 .21552 .77922 .20901 Metetra
.666 .746 .91 r
.77922 .20901 .78362 .21552 .79374 .21189 .78936 .20537 Metetra
.664 .745 .911 r
.78936 .20537 .79374 .21189 .80389 .2083 .79953 .20175 Metetra
.661 .745 .912 r
.16644 .4157 .17218 .42093 .18029 .4181 .17457 .41286 Metetra
.66 .744 .912 r
.17457 .41286 .18029 .4181 .18843 .41529 .18273 .41002 Metetra
.659 .744 .913 r
.18273 .41002 .18843 .41529 .1966 .41249 .19091 .4072 Metetra
.658 .743 .913 r
.19091 .4072 .1966 .41249 .20478 .40971 .19911 .40439 Metetra
.657 .743 .913 r
.19911 .40439 .20478 .40971 .21299 .40695 .20734 .4016 Metetra
.657 .742 .913 r
.20734 .4016 .21299 .40695 .22123 .40419 .21559 .3988 Metetra
.658 .742 .911 r
.21559 .3988 .22123 .40419 .2295 .40138 .22387 .39596 Metetra
.661 .742 .91 r
.22387 .39596 .2295 .40138 .2378 .39848 .23219 .39305 Metetra
.665 .743 .908 r
.23219 .39305 .2378 .39848 .24613 .39548 .24054 .39005 Metetra
.669 .744 .907 r
.24054 .39005 .24613 .39548 .2545 .39238 .24892 .38695 Metetra
.672 .746 .907 r
.24892 .38695 .2545 .39238 .2629 .38918 .25734 .38378 Metetra
.673 .748 .907 r
.25734 .38378 .2629 .38918 .27133 .38594 .26578 .38057 Metetra
.675 .75 .908 r
.26578 .38057 .27133 .38594 .27979 .38264 .27425 .3773 Metetra
.675 .753 .909 r
.27425 .3773 .27979 .38264 .28828 .37932 .28275 .37402 Metetra
.672 .754 .912 r
.28275 .37402 .28828 .37932 .29678 .37611 .29127 .37082 Metetra
.663 .753 .917 r
.29127 .37082 .29678 .37611 .3053 .3731 .2998 .36781 Metetra
.65 .749 .922 r
.2998 .36781 .3053 .3731 .31382 .37041 .30834 .36505 Metetra
.634 .743 .927 r
.30834 .36505 .31382 .37041 .32234 .36807 .31689 .3626 Metetra
.62 .735 .928 r
.31689 .3626 .32234 .36807 .33088 .36604 .32545 .3604 Metetra
.615 .727 .926 r
.32545 .3604 .33088 .36604 .33944 .36413 .33404 .35831 Metetra
.616 .721 .921 r
.33404 .35831 .33944 .36413 .34804 .3622 .34266 .3562 Metetra
.622 .717 .914 r
.34266 .3562 .34804 .3622 .35668 .36015 .35132 .35398 Metetra
.636 .716 .905 r
.35132 .35398 .35668 .36015 .36537 .35775 .36003 .35147 Metetra
.658 .72 .894 r
.36003 .35147 .36537 .35775 .37412 .35475 .36879 .34844 Metetra
.686 .729 .882 r
.36879 .34844 .37412 .35475 .38293 .35089 .37762 .34468 Metetra
.717 .741 .871 r
.37762 .34468 .38293 .35089 .39182 .34597 .38651 .34002 Metetra
.748 .758 .861 r
.38651 .34002 .39182 .34597 .40076 .33991 .39547 .3344 Metetra
.772 .777 .857 r
.39547 .3344 .40076 .33991 .40976 .33297 .40446 .32801 Metetra
.79 .799 .86 r
.40446 .32801 .40976 .33297 .41877 .32549 .41348 .32116 Metetra
.802 .824 .869 r
.41348 .32116 .41877 .32549 .4278 .31778 .42252 .31412 Metetra
.807 .852 .884 r
.42252 .31412 .4278 .31778 .43683 .31017 .43156 .30716 Metetra
.799 .881 .906 r
.43156 .30716 .43683 .31017 .44585 .30309 .4406 .30064 Metetra
.772 .906 .933 r
.4406 .30064 .44585 .30309 .45486 .2969 .44963 .29488 Metetra
.713 .919 .963 r
.44963 .29488 .45486 .2969 .46385 .29198 .45865 .29021 Metetra
.607 .903 .985 r
.45865 .29021 .46385 .29198 .47284 .28867 .46767 .2869 Metetra
.465 .847 .984 r
.46767 .2869 .47284 .28867 .48183 .287 .47669 .28499 Metetra
.343 .775 .969 r
.47669 .28499 .48183 .287 .49085 .28669 .48574 .28423 Metetra
.273 .717 .961 r
.48574 .28423 .49085 .28669 .4999 .28737 .49482 .28431 Metetra
.257 .682 .964 r
.49482 .28431 .4999 .28737 .50901 .28868 .50395 .28494 Metetra
.293 .671 .973 r
.50395 .28494 .50901 .28868 .51817 .29022 .51314 .28575 Metetra
.357 .672 .976 r
.51314 .28575 .51817 .29022 .52739 .29161 .52238 .28643 Metetra
.43 .678 .967 r
.52238 .28643 .52739 .29161 .53667 .29251 .53167 .28669 Metetra
.507 .688 .949 r
.53167 .28669 .53667 .29251 .54599 .29252 .54101 .28619 Metetra
.577 .699 .926 r
.54101 .28619 .54599 .29252 .55536 .29134 .55039 .28468 Metetra
.627 .709 .905 r
.55039 .28468 .55536 .29134 .56476 .28899 .5598 .28217 Metetra
.661 .718 .891 r
.5598 .28217 .56476 .28899 .57418 .28567 .56924 .27883 Metetra
.683 .726 .882 r
.56924 .27883 .57418 .28567 .58361 .28163 .5787 .27488 Metetra
.697 .735 .88 r
.5787 .27488 .58361 .28163 .59307 .27715 .58818 .27056 Metetra
.703 .743 .883 r
.58818 .27056 .59307 .27715 .60254 .2725 .59768 .26609 Metetra
.704 .75 .887 r
.59768 .26609 .60254 .2725 .61204 .26781 .60721 .26158 Metetra
.701 .756 .895 r
.60721 .26158 .61204 .26781 .62157 .26326 .61677 .25719 Metetra
.691 .759 .904 r
.61677 .25719 .62157 .26326 .63114 .25906 .62636 .2531 Metetra
.675 .759 .914 r
.62636 .2531 .63114 .25906 .64075 .25532 .636 .2494 Metetra
.66 .756 .921 r
.636 .2494 .64075 .25532 .65041 .25199 .64568 .24603 Metetra
.648 .751 .924 r
.64568 .24603 .65041 .25199 .66012 .24895 .65541 .24292 Metetra
.642 .746 .925 r
.65541 .24292 .66012 .24895 .66987 .24608 .66518 .23995 Metetra
.641 .743 .923 r
.66518 .23995 .66987 .24608 .67966 .24321 .67499 .23698 Metetra
.643 .74 .92 r
.67499 .23698 .67966 .24321 .68948 .24029 .68483 .23396 Metetra
.646 .739 .917 r
.68483 .23396 .68948 .24029 .69934 .23729 .69471 .23088 Metetra
.65 .738 .914 r
.69471 .23088 .69934 .23729 .70922 .23417 .70461 .22769 Metetra
.656 .738 .911 r
.70461 .22769 .70922 .23417 .71914 .23088 .71455 .22435 Metetra
.661 .74 .908 r
.71455 .22435 .71914 .23088 .72908 .22742 .72451 .22086 Metetra
.665 .742 .907 r
.72451 .22086 .72908 .22742 .73904 .22381 .7345 .21725 Metetra
.668 .743 .906 r
.7345 .21725 .73904 .22381 .74903 .22011 .74452 .21356 Metetra
.669 .745 .907 r
.74452 .21356 .74903 .22011 .75906 .21638 .75457 .20984 Metetra
.668 .745 .909 r
.75457 .20984 .75906 .21638 .76912 .21268 .76466 .20615 Metetra
.666 .746 .91 r
.76466 .20615 .76912 .21268 .77922 .20901 .77479 .20247 Metetra
.665 .746 .911 r
.77479 .20247 .77922 .20901 .78936 .20537 .78495 .19882 Metetra
.663 .746 .912 r
.78495 .19882 .78936 .20537 .79953 .20175 .79516 .19519 Metetra
.661 .745 .912 r
.16068 .41045 .16644 .4157 .17457 .41286 .16882 .40759 Metetra
.661 .745 .912 r
.16882 .40759 .17457 .41286 .18273 .41002 .17699 .40473 Metetra
.66 .744 .912 r
.17699 .40473 .18273 .41002 .19091 .4072 .18519 .40187 Metetra
.659 .744 .912 r
.18519 .40187 .19091 .4072 .19911 .40439 .19341 .39903 Metetra
.658 .743 .912 r
.19341 .39903 .19911 .40439 .20734 .4016 .20165 .39619 Metetra
.658 .742 .912 r
.20165 .39619 .20734 .4016 .21559 .3988 .20992 .39336 Metetra
.659 .741 .91 r
.20992 .39336 .21559 .3988 .22387 .39596 .21822 .39048 Metetra
.661 .741 .909 r
.21822 .39048 .22387 .39596 .23219 .39305 .22655 .38755 Metetra
.664 .741 .908 r
.22655 .38755 .23219 .39305 .24054 .39005 .23492 .38455 Metetra
.667 .743 .907 r
.23492 .38455 .24054 .39005 .24892 .38695 .24331 .38148 Metetra
.669 .745 .908 r
.24331 .38148 .24892 .38695 .25734 .38378 .25174 .37836 Metetra
.67 .748 .909 r
.25174 .37836 .25734 .38378 .26578 .38057 .26019 .37519 Metetra
.671 .751 .91 r
.26019 .37519 .26578 .38057 .27425 .3773 .26867 .372 Metetra
.672 .754 .912 r
.26867 .372 .27425 .3773 .28275 .37402 .27718 .36878 Metetra
.669 .757 .916 r
.27718 .36878 .28275 .37402 .29127 .37082 .28571 .36562 Metetra
.662 .757 .921 r
.28571 .36562 .29127 .37082 .2998 .36781 .29426 .36259 Metetra
.653 .755 .924 r
.29426 .36259 .2998 .36781 .30834 .36505 .30282 .35976 Metetra
.641 .749 .927 r
.30282 .35976 .30834 .36505 .31689 .3626 .3114 .35714 Metetra
.632 .74 .926 r
.3114 .35714 .31689 .3626 .32545 .3604 .31999 .3547 Metetra
.628 .73 .92 r
.31999 .3547 .32545 .3604 .33404 .35831 .32861 .35234 Metetra
.629 .721 .913 r
.32861 .35234 .33404 .35831 .34266 .3562 .33726 .34996 Metetra
.633 .713 .904 r
.33726 .34996 .34266 .3562 .35132 .35398 .34595 .3475 Metetra
.642 .708 .895 r
.34595 .3475 .35132 .35398 .36003 .35147 .35468 .34483 Metetra
.658 .709 .885 r
.35468 .34483 .36003 .35147 .36879 .34844 .36346 .34176 Metetra
.678 .715 .877 r
.36346 .34176 .36879 .34844 .37762 .34468 .37229 .33817 Metetra
.702 .728 .871 r
.37229 .33817 .37762 .34468 .38651 .34002 .38119 .33391 Metetra
.727 .749 .869 r
.38119 .33391 .38651 .34002 .39547 .3344 .39013 .32894 Metetra
.75 .777 .875 r
.39013 .32894 .39547 .3344 .40446 .32801 .39912 .32341 Metetra
.768 .813 .888 r
.39912 .32341 .40446 .32801 .41348 .32116 .40813 .31754 Metetra
.78 .854 .906 r
.40813 .31754 .41348 .32116 .42252 .31412 .41716 .31152 Metetra
.78 .899 .926 r
.41716 .31152 .42252 .31412 .43156 .30716 .42621 .30556 Metetra
.757 .939 .943 r
.42621 .30556 .43156 .30716 .4406 .30064 .43525 .29992 Metetra
.697 .96 .946 r
.43525 .29992 .4406 .30064 .44963 .29488 .4443 .29483 Metetra
.588 .941 .922 r
.4443 .29483 .44963 .29488 .45865 .29021 .45335 .29053 Metetra
.436 .875 .871 r
.45335 .29053 .45865 .29021 .46767 .2869 .46241 .28724 Metetra
.293 .792 .823 r
.46241 .28724 .46767 .2869 .47669 .28499 .47147 .28497 Metetra
.214 .738 .818 r
.47147 .28497 .47669 .28499 .48574 .28423 .48056 .28354 Metetra
.203 .724 .861 r
.48056 .28354 .48574 .28423 .49482 .28431 .48969 .28273 Metetra
.248 .734 .926 r
.48969 .28273 .49482 .28431 .50395 .28494 .49885 .28231 Metetra
.332 .746 .978 r
.49885 .28231 .50395 .28494 .51314 .28575 .50806 .28202 Metetra
.42 .743 .993 r
.50806 .28202 .51314 .28575 .52238 .28643 .51733 .28163 Metetra
.494 .728 .976 r
.51733 .28163 .52238 .28643 .53167 .28669 .52664 .28093 Metetra
.554 .713 .946 r
.52664 .28093 .53167 .28669 .54101 .28619 .53599 .27967 Metetra
.602 .705 .916 r
.53599 .27967 .54101 .28619 .55039 .28468 .54539 .27766 Metetra
.636 .702 .893 r
.54539 .27766 .55039 .28468 .5598 .28217 .55481 .27492 Metetra
.659 .704 .88 r
.55481 .27492 .5598 .28217 .56924 .27883 .56427 .27157 Metetra
.675 .711 .875 r
.56427 .27157 .56924 .27883 .5787 .27488 .57375 .26777 Metetra
.685 .72 .876 r
.57375 .26777 .5787 .27488 .58818 .27056 .58325 .2637 Metetra
.691 .73 .881 r
.58325 .2637 .58818 .27056 .59768 .26609 .59279 .2595 Metetra
.693 .742 .889 r
.59279 .2595 .59768 .26609 .60721 .26158 .60234 .25529 Metetra
.691 .752 .898 r
.60234 .25529 .60721 .26158 .61677 .25719 .61193 .25115 Metetra
.683 .759 .909 r
.61193 .25115 .61677 .25719 .62636 .2531 .62156 .24723 Metetra
.672 .763 .919 r
.62156 .24723 .62636 .2531 .636 .2494 .63122 .24359 Metetra
.661 .762 .925 r
.63122 .24359 .636 .2494 .64568 .24603 .64093 .2402 Metetra
.652 .758 .928 r
.64093 .2402 .64568 .24603 .65541 .24292 .65068 .23699 Metetra
.647 .753 .927 r
.65068 .23699 .65541 .24292 .66518 .23995 .66047 .23387 Metetra
.647 .749 .924 r
.66047 .23387 .66518 .23995 .67499 .23698 .67029 .23076 Metetra
.648 .744 .92 r
.67029 .23076 .67499 .23698 .68483 .23396 .68015 .2276 Metetra
.65 .741 .916 r
.68015 .2276 .68483 .23396 .69471 .23088 .69004 .2244 Metetra
.653 .738 .912 r
.69004 .2244 .69471 .23088 .70461 .22769 .69997 .22111 Metetra
.657 .737 .909 r
.69997 .22111 .70461 .22769 .71455 .22435 .70993 .21771 Metetra
.661 .737 .907 r
.70993 .21771 .71455 .22435 .72451 .22086 .71991 .2142 Metetra
.664 .739 .905 r
.71991 .2142 .72451 .22086 .7345 .21725 .72993 .2106 Metetra
.666 .741 .906 r
.72993 .2106 .7345 .21725 .74452 .21356 .73998 .20693 Metetra
.667 .743 .907 r
.73998 .20693 .74452 .21356 .75457 .20984 .75006 .20324 Metetra
.666 .744 .909 r
.75006 .20324 .75457 .20984 .76466 .20615 .76017 .19956 Metetra
.665 .745 .91 r
.76017 .19956 .76466 .20615 .77479 .20247 .77033 .1959 Metetra
.664 .746 .911 r
.77033 .1959 .77479 .20247 .78495 .19882 .78052 .19225 Metetra
.663 .746 .912 r
.78052 .19225 .78495 .19882 .79516 .19519 .79075 .18861 Metetra
.661 .745 .912 r
.15487 .40516 .16068 .41045 .16882 .40759 .16303 .40229 Metetra
.661 .745 .912 r
.16303 .40229 .16882 .40759 .17699 .40473 .17122 .3994 Metetra
.661 .744 .912 r
.17122 .3994 .17699 .40473 .18519 .40187 .17943 .39652 Metetra
.66 .744 .912 r
.17943 .39652 .18519 .40187 .19341 .39903 .18767 .39364 Metetra
.659 .743 .912 r
.18767 .39364 .19341 .39903 .20165 .39619 .19593 .39076 Metetra
.659 .742 .911 r
.19593 .39076 .20165 .39619 .20992 .39336 .20422 .38787 Metetra
.66 .741 .91 r
.20422 .38787 .20992 .39336 .21822 .39048 .21254 .38496 Metetra
.661 .74 .909 r
.21254 .38496 .21822 .39048 .22655 .38755 .22088 .38201 Metetra
.663 .741 .908 r
.22088 .38201 .22655 .38755 .23492 .38455 .22926 .37902 Metetra
.664 .742 .908 r
.22926 .37902 .23492 .38455 .24331 .38148 .23767 .37598 Metetra
.666 .744 .909 r
.23767 .37598 .24331 .38148 .25174 .37836 .2461 .3729 Metetra
.667 .747 .91 r
.2461 .3729 .25174 .37836 .26019 .37519 .25457 .3698 Metetra
.667 .75 .912 r
.25457 .3698 .26019 .37519 .26867 .372 .26306 .36668 Metetra
.668 .754 .915 r
.26306 .36668 .26867 .372 .27718 .36878 .27158 .36354 Metetra
.666 .757 .918 r
.27158 .36354 .27718 .36878 .28571 .36562 .28012 .36043 Metetra
.662 .759 .922 r
.28012 .36043 .28571 .36562 .29426 .36259 .28869 .35739 Metetra
.657 .758 .924 r
.28869 .35739 .29426 .36259 .30282 .35976 .29727 .35446 Metetra
.65 .753 .925 r
.29727 .35446 .30282 .35976 .3114 .35714 .30587 .35165 Metetra
.645 .744 .922 r
.30587 .35165 .3114 .35714 .31999 .3547 .3145 .34895 Metetra
.643 .734 .915 r
.3145 .34895 .31999 .3547 .32861 .35234 .32315 .34629 Metetra
.643 .724 .907 r
.32315 .34629 .32861 .35234 .33726 .34996 .33183 .34361 Metetra
.645 .714 .898 r
.33183 .34361 .33726 .34996 .34595 .3475 .34055 .34088 Metetra
.649 .707 .889 r
.34055 .34088 .34595 .3475 .35468 .34483 .34931 .33802 Metetra
.658 .705 .882 r
.34931 .33802 .35468 .34483 .36346 .34176 .3581 .33493 Metetra
.67 .708 .877 r
.3581 .33493 .36346 .34176 .37229 .33817 .36694 .33152 Metetra
.685 .72 .876 r
.36694 .33152 .37229 .33817 .38119 .33391 .37583 .32772 Metetra
.702 .741 .881 r
.37583 .32772 .38119 .33391 .39013 .32894 .38476 .32349 Metetra
.719 .772 .895 r
.38476 .32349 .39013 .32894 .39912 .32341 .39373 .31893 Metetra
.731 .814 .916 r
.39373 .31893 .39912 .32341 .40813 .31754 .40272 .31417 Metetra
.736 .862 .939 r
.40272 .31417 .40813 .31754 .41716 .31152 .41174 .30931 Metetra
.725 .912 .959 r
.41174 .30931 .41716 .31152 .42621 .30556 .42078 .30448 Metetra
.681 .946 .96 r
.42078 .30448 .42621 .30556 .43525 .29992 .42984 .29984 Metetra
.594 .943 .925 r
.42984 .29984 .43525 .29992 .4443 .29483 .43891 .29551 Metetra
.47 .893 .856 r
.43891 .29551 .4443 .29483 .45335 .29053 .44798 .29165 Metetra
.342 .818 .78 r
.44798 .29165 .45335 .29053 .46241 .28724 .45708 .28837 Metetra
.253 .761 .742 r
.45708 .28837 .46241 .28724 .47147 .28497 .46619 .28569 Metetra
.231 .749 .766 r
.46619 .28569 .47147 .28497 .48056 .28354 .47533 .28351 Metetra
.27 .775 .842 r
.47533 .28351 .48056 .28354 .48969 .28273 .4845 .28168 Metetra
.35 .81 .932 r
.4845 .28168 .48969 .28273 .49885 .28231 .4937 .28008 Metetra
.444 .823 .99 r
.4937 .28008 .49885 .28231 .50806 .28202 .50295 .27855 Metetra
.519 .803 .997 r
.50295 .27855 .50806 .28202 .51733 .28163 .51224 .27695 Metetra
.568 .767 .972 r
.51224 .27695 .51733 .28163 .52664 .28093 .52157 .27517 Metetra
.603 .735 .938 r
.52157 .27517 .52664 .28093 .53599 .27967 .53094 .27305 Metetra
.628 .713 .908 r
.53094 .27305 .53599 .27967 .54539 .27766 .54035 .27048 Metetra
.646 .702 .887 r
.54035 .27048 .54539 .27766 .55481 .27492 .5498 .26748 Metetra
.658 .699 .877 r
.5498 .26748 .55481 .27492 .56427 .27157 .55927 .26413 Metetra
.668 .703 .874 r
.55927 .26413 .56427 .27157 .57375 .26777 .56877 .2605 Metetra
.674 .712 .877 r
.56877 .2605 .57375 .26777 .58325 .2637 .5783 .2567 Metetra
.678 .723 .884 r
.5783 .2567 .58325 .2637 .59279 .2595 .58786 .25283 Metetra
.68 .735 .892 r
.58786 .25283 .59279 .2595 .60234 .25529 .59745 .24894 Metetra
.679 .747 .903 r
.59745 .24894 .60234 .25529 .61193 .25115 .60707 .2451 Metetra
.675 .757 .913 r
.60707 .2451 .61193 .25115 .62156 .24723 .61672 .24138 Metetra
.668 .763 .922 r
.61672 .24138 .62156 .24723 .63122 .24359 .62642 .23781 Metetra
.661 .765 .927 r
.62642 .23781 .63122 .24359 .64093 .2402 .63615 .23438 Metetra
.656 .762 .928 r
.63615 .23438 .64093 .2402 .65068 .23699 .64592 .23106 Metetra
.653 .758 .926 r
.64592 .23106 .65068 .23699 .66047 .23387 .65572 .22779 Metetra
.653 .752 .923 r
.65572 .22779 .66047 .23387 .67029 .23076 .66556 .22451 Metetra
.654 .747 .918 r
.66556 .22451 .67029 .23076 .68015 .2276 .67544 .22121 Metetra
.655 .743 .915 r
.67544 .22121 .68015 .2276 .69004 .2244 .68535 .21787 Metetra
.656 .739 .911 r
.68535 .21787 .69004 .2244 .69997 .22111 .6953 .21448 Metetra
.659 .737 .908 r
.6953 .21448 .69997 .22111 .70993 .21771 .70528 .21101 Metetra
.661 .737 .906 r
.70528 .21101 .70993 .21771 .71991 .2142 .71529 .20748 Metetra
.663 .737 .905 r
.71529 .20748 .71991 .2142 .72993 .2106 .72533 .20388 Metetra
.664 .739 .906 r
.72533 .20388 .72993 .2106 .73998 .20693 .7354 .20025 Metetra
.664 .741 .907 r
.7354 .20025 .73998 .20693 .75006 .20324 .74551 .19659 Metetra
.664 .743 .909 r
.74551 .19659 .75006 .20324 .76017 .19956 .75566 .19294 Metetra
.663 .745 .91 r
.75566 .19294 .76017 .19956 .77033 .1959 .76584 .18929 Metetra
.663 .746 .912 r
.76584 .18929 .77033 .1959 .78052 .19225 .77606 .18564 Metetra
.662 .746 .913 r
.77606 .18564 .78052 .19225 .79075 .18861 .78632 .18199 Metetra
.661 .745 .912 r
.14904 .39985 .15487 .40516 .16303 .40229 .15721 .39695 Metetra
.661 .745 .912 r
.15721 .39695 .16303 .40229 .17122 .3994 .16541 .39405 Metetra
.661 .744 .912 r
.16541 .39405 .17122 .3994 .17943 .39652 .17364 .39113 Metetra
.661 .744 .912 r
.17364 .39113 .17943 .39652 .18767 .39364 .1819 .38821 Metetra
.661 .743 .911 r
.1819 .38821 .18767 .39364 .19593 .39076 .19018 .38529 Metetra
.661 .742 .91 r
.19018 .38529 .19593 .39076 .20422 .38787 .19848 .38235 Metetra
.661 .741 .909 r
.19848 .38235 .20422 .38787 .21254 .38496 .20682 .3794 Metetra
.661 .74 .909 r
.20682 .3794 .21254 .38496 .22088 .38201 .21518 .37644 Metetra
.662 .74 .908 r
.21518 .37644 .22088 .38201 .22926 .37902 .22357 .37345 Metetra
.662 .741 .909 r
.22357 .37345 .22926 .37902 .23767 .37598 .23199 .37044 Metetra
.663 .743 .91 r
.23199 .37044 .23767 .37598 .2461 .3729 .24043 .36742 Metetra
.663 .746 .912 r
.24043 .36742 .2461 .3729 .25457 .3698 .24891 .36438 Metetra
.663 .749 .914 r
.24891 .36438 .25457 .3698 .26306 .36668 .25741 .36133 Metetra
.663 .753 .917 r
.25741 .36133 .26306 .36668 .27158 .36354 .26594 .35826 Metetra
.663 .756 .92 r
.26594 .35826 .27158 .36354 .28012 .36043 .27449 .3552 Metetra
.662 .759 .922 r
.27449 .3552 .28012 .36043 .28869 .35739 .28307 .35215 Metetra
.66 .759 .923 r
.28307 .35215 .28869 .35739 .29727 .35446 .29168 .34913 Metetra
.658 .755 .921 r
.29168 .34913 .29727 .35446 .30587 .35165 .30031 .34614 Metetra
.657 .748 .917 r
.30031 .34614 .30587 .35165 .3145 .34895 .30897 .34316 Metetra
.656 .738 .91 r
.30897 .34316 .3145 .34895 .32315 .34629 .31766 .3402 Metetra
.656 .728 .902 r
.31766 .3402 .32315 .34629 .33183 .34361 .32638 .33722 Metetra
.655 .718 .894 r
.32638 .33722 .33183 .34361 .34055 .34088 .33513 .33422 Metetra
.656 .709 .887 r
.33513 .33422 .34055 .34088 .34931 .33802 .3439 .33117 Metetra
.658 .704 .881 r
.3439 .33117 .34931 .33802 .3581 .33493 .35272 .32805 Metetra
.662 .705 .88 r
.35272 .32805 .3581 .33493 .36694 .33152 .36156 .32483 Metetra
.667 .714 .883 r
.36156 .32483 .36694 .33152 .37583 .32772 .37044 .32149 Metetra
.674 .732 .894 r
.37044 .32149 .37583 .32772 .38476 .32349 .37935 .31801 Metetra
.68 .763 .914 r
.37935 .31801 .38476 .32349 .39373 .31893 .3883 .31443 Metetra
.683 .804 .94 r
.3883 .31443 .39373 .31893 .40272 .31417 .39728 .31078 Metetra
.677 .853 .967 r
.39728 .31078 .40272 .31417 .41174 .30931 .40628 .3071 Metetra
.652 .898 .982 r
.40628 .3071 .41174 .30931 .42078 .30448 .41531 .30342 Metetra
.595 .922 .968 r
.41531 .30342 .42078 .30448 .42984 .29984 .42437 .29978 Metetra
.507 .907 .914 r
.42437 .29978 .42984 .29984 .43891 .29551 .43345 .29623 Metetra
.409 .86 .836 r
.43345 .29623 .43891 .29551 .44798 .29165 .44256 .29281 Metetra
.332 .812 .773 r
.44256 .29281 .44798 .29165 .45708 .28837 .45169 .28955 Metetra
.304 .794 .759 r
.45169 .28955 .45708 .28837 .46619 .28569 .46085 .28646 Metetra
.332 .815 .803 r
.46085 .28646 .46619 .28569 .47533 .28351 .47004 .28351 Metetra
.403 .856 .883 r
.47004 .28351 .47533 .28351 .4845 .28168 .47926 .28065 Metetra
.492 .885 .958 r
.47926 .28065 .4845 .28168 .4937 .28008 .48851 .27785 Metetra
.567 .877 .993 r
.48851 .27785 .4937 .28008 .50295 .27855 .4978 .27506 Metetra
.612 .839 .986 r
.4978 .27506 .50295 .27855 .51224 .27695 .50712 .27225 Metetra
.635 .792 .958 r
.50712 .27225 .51224 .27695 .52157 .27517 .51648 .26937 Metetra
.646 .751 .926 r
.51648 .26937 .52157 .27517 .53094 .27305 .52587 .26638 Metetra
.651 .722 .9 r
.52587 .26638 .53094 .27305 .54035 .27048 .53529 .26326 Metetra
.655 .705 .884 r
.53529 .26326 .54035 .27048 .5498 .26748 .54475 .26 Metetra
.658 .699 .877 r
.54475 .26 .5498 .26748 .55927 .26413 .55424 .25663 Metetra
.661 .7 .876 r
.55424 .25663 .55927 .26413 .56877 .2605 .56376 .25318 Metetra
.663 .707 .88 r
.56376 .25318 .56877 .2605 .5783 .2567 .57332 .24966 Metetra
.665 .718 .888 r
.57332 .24966 .5783 .2567 .58786 .25283 .5829 .24612 Metetra
.666 .73 .897 r
.5829 .24612 .58786 .25283 .59745 .24894 .59252 .24256 Metetra
.667 .743 .907 r
.59252 .24256 .59745 .24894 .60707 .2451 .60217 .23901 Metetra
.665 .754 .916 r
.60217 .23901 .60707 .2451 .61672 .24138 .61186 .23548 Metetra
.663 .762 .923 r
.61186 .23548 .61672 .24138 .62642 .23781 .62158 .23199 Metetra
.661 .765 .927 r
.62158 .23199 .62642 .23781 .63615 .23438 .63133 .22853 Metetra
.66 .764 .927 r
.63133 .22853 .63615 .23438 .64592 .23106 .64112 .2251 Metetra
.659 .76 .924 r
.64112 .2251 .64592 .23106 .65572 .22779 .65095 .22167 Metetra
.659 .755 .921 r
.65095 .22167 .65572 .22779 .66556 .22451 .66081 .21823 Metetra
.659 .749 .917 r
.66081 .21823 .66556 .22451 .67544 .22121 .6707 .21477 Metetra
.659 .745 .913 r
.6707 .21477 .67544 .22121 .68535 .21787 .68063 .2113 Metetra
.66 .741 .91 r
.68063 .2113 .68535 .21787 .6953 .21448 .6906 .2078 Metetra
.66 .738 .907 r
.6906 .2078 .6953 .21448 .70528 .21101 .70059 .20427 Metetra
.661 .737 .906 r
.70059 .20427 .70528 .21101 .71529 .20748 .71063 .20071 Metetra
.662 .737 .906 r
.71063 .20071 .71529 .20748 .72533 .20388 .7207 .19712 Metetra
.662 .738 .906 r
.7207 .19712 .72533 .20388 .7354 .20025 .7308 .19352 Metetra
.662 .74 .908 r
.7308 .19352 .7354 .20025 .74551 .19659 .74094 .18989 Metetra
.662 .742 .91 r
.74094 .18989 .74551 .19659 .75566 .19294 .75111 .18626 Metetra
.662 .744 .911 r
.75111 .18626 .75566 .19294 .76584 .18929 .76132 .18263 Metetra
.662 .745 .912 r
.76132 .18263 .76584 .18929 .77606 .18564 .77157 .17898 Metetra
.662 .746 .913 r
.77157 .17898 .77606 .18564 .78632 .18199 .78186 .17532 Metetra
.661 .745 .912 r
.14317 .39451 .14904 .39985 .15721 .39695 .15136 .39159 Metetra
.662 .745 .912 r
.15136 .39159 .15721 .39695 .16541 .39405 .15957 .38866 Metetra
.662 .745 .912 r
.15957 .38866 .16541 .39405 .17364 .39113 .16782 .38571 Metetra
.662 .744 .911 r
.16782 .38571 .17364 .39113 .1819 .38821 .17609 .38276 Metetra
.662 .744 .911 r
.17609 .38276 .1819 .38821 .19018 .38529 .18439 .37979 Metetra
.662 .743 .91 r
.18439 .37979 .19018 .38529 .19848 .38235 .19271 .37681 Metetra
.662 .742 .909 r
.19271 .37681 .19848 .38235 .20682 .3794 .20106 .37382 Metetra
.661 .741 .909 r
.20106 .37382 .20682 .3794 .21518 .37644 .20944 .37084 Metetra
.661 .741 .909 r
.20944 .37084 .21518 .37644 .22357 .37345 .21785 .36786 Metetra
.66 .741 .91 r
.21785 .36786 .22357 .37345 .23199 .37044 .22628 .36488 Metetra
.66 .743 .911 r
.22628 .36488 .23199 .37044 .24043 .36742 .23473 .3619 Metetra
.66 .745 .913 r
.23473 .3619 .24043 .36742 .24891 .36438 .24322 .35891 Metetra
.659 .748 .915 r
.24322 .35891 .24891 .36438 .25741 .36133 .25173 .35592 Metetra
.659 .751 .918 r
.25173 .35592 .25741 .36133 .26594 .35826 .26027 .35292 Metetra
.66 .754 .92 r
.26027 .35292 .26594 .35826 .27449 .3552 .26883 .3499 Metetra
.661 .757 .921 r
.26883 .3499 .27449 .3552 .28307 .35215 .27743 .34684 Metetra
.663 .758 .92 r
.27743 .34684 .28307 .35215 .29168 .34913 .28606 .34373 Metetra
.665 .756 .918 r
.28606 .34373 .29168 .34913 .30031 .34614 .29472 .34057 Metetra
.667 .75 .913 r
.29472 .34057 .30031 .34614 .30897 .34316 .30342 .33736 Metetra
.667 .742 .906 r
.30342 .33736 .30897 .34316 .31766 .3402 .31214 .33412 Metetra
.666 .733 .899 r
.31214 .33412 .31766 .3402 .32638 .33722 .32089 .33087 Metetra
.665 .724 .893 r
.32089 .33087 .32638 .33722 .33513 .33422 .32966 .32763 Metetra
.663 .715 .887 r
.32966 .32763 .33513 .33422 .3439 .33117 .33846 .32442 Metetra
.659 .709 .885 r
.33846 .32442 .3439 .33117 .35272 .32805 .34729 .32127 Metetra
.655 .707 .886 r
.34729 .32127 .35272 .32805 .36156 .32483 .35614 .31821 Metetra
.65 .712 .893 r
.35614 .31821 .36156 .32483 .37044 .32149 .36502 .31527 Metetra
.645 .725 .907 r
.36502 .31527 .37044 .32149 .37935 .31801 .37392 .31245 Metetra
.639 .749 .928 r
.37392 .31245 .37935 .31801 .3883 .31443 .38284 .30974 Metetra
.631 .783 .954 r
.38284 .30974 .3883 .31443 .39728 .31078 .3918 .30707 Metetra
.615 .823 .98 r
.3918 .30707 .39728 .31078 .40628 .3071 .40079 .30443 Metetra
.587 .861 .995 r
.40079 .30443 .40628 .3071 .41531 .30342 .40981 .30176 Metetra
.543 .885 .986 r
.40981 .30176 .41531 .30342 .42437 .29978 .41887 .29902 Metetra
.489 .887 .949 r
.41887 .29902 .42437 .29978 .43345 .29623 .42796 .29615 Metetra
.443 .876 .902 r
.42796 .29615 .43345 .29623 .44256 .29281 .43709 .29312 Metetra
.427 .87 .871 r
.43709 .29312 .44256 .29281 .45169 .28955 .44626 .28987 Metetra
.449 .882 .874 r
.44626 .28987 .45169 .28955 .46085 .28646 .45547 .28641 Metetra
.503 .906 .909 r
.45547 .28641 .46085 .28646 .47004 .28351 .46471 .28277 Metetra
.57 .924 .951 r
.46471 .28277 .47004 .28351 .47926 .28065 .47398 .279 Metetra
.629 .92 .977 r
.47398 .279 .47926 .28065 .48851 .27785 .48328 .27513 Metetra
.666 .889 .979 r
.48328 .27513 .48851 .27785 .4978 .27506 .4926 .27123 Metetra
.682 .845 .961 r
.4926 .27123 .4978 .27506 .50712 .27225 .50196 .26734 Metetra
.684 .8 .937 r
.50196 .26734 .50712 .27225 .51648 .26937 .51135 .26349 Metetra
.679 .761 .913 r
.51135 .26349 .51648 .26937 .52587 .26638 .52076 .25974 Metetra
.671 .731 .895 r
.52076 .25974 .52587 .26638 .53529 .26326 .5302 .25613 Metetra
.663 .713 .885 r
.5302 .25613 .53529 .26326 .54475 .26 .53968 .25264 Metetra
.658 .704 .881 r
.53968 .25264 .54475 .26 .55424 .25663 .54919 .24926 Metetra
.655 .703 .882 r
.54919 .24926 .55424 .25663 .56376 .25318 .55873 .24595 Metetra
.653 .708 .887 r
.55873 .24595 .56376 .25318 .57332 .24966 .56831 .24268 Metetra
.653 .717 .895 r
.56831 .24268 .57332 .24966 .5829 .24612 .57792 .23942 Metetra
.654 .727 .903 r
.57792 .23942 .5829 .24612 .59252 .24256 .58756 .23615 Metetra
.655 .739 .911 r
.58756 .23615 .59252 .24256 .60217 .23901 .59724 .23285 Metetra
.657 .75 .918 r
.59724 .23285 .60217 .23901 .61186 .23548 .60696 .22949 Metetra
.66 .758 .923 r
.60696 .22949 .61186 .23548 .62158 .23199 .6167 .22606 Metetra
.662 .762 .925 r
.6167 .22606 .62158 .23199 .63133 .22853 .62648 .22258 Metetra
.663 .763 .924 r
.62648 .22258 .63133 .22853 .64112 .2251 .63629 .21904 Metetra
.664 .76 .921 r
.63629 .21904 .64112 .2251 .65095 .22167 .64614 .21547 Metetra
.664 .755 .918 r
.64614 .21547 .65095 .22167 .66081 .21823 .65602 .21188 Metetra
.664 .751 .915 r
.65602 .21188 .66081 .21823 .6707 .21477 .66593 .20829 Metetra
.664 .746 .912 r
.66593 .20829 .6707 .21477 .68063 .2113 .67588 .20469 Metetra
.663 .742 .909 r
.67588 .20469 .68063 .2113 .6906 .2078 .68586 .20109 Metetra
.662 .739 .907 r
.68586 .20109 .6906 .2078 .70059 .20427 .69588 .1975 Metetra
.661 .738 .907 r
.69588 .1975 .70059 .20427 .71063 .20071 .70594 .19392 Metetra
.66 .737 .907 r
.70594 .19392 .71063 .20071 .7207 .19712 .71603 .19034 Metetra
.66 .738 .908 r
.71603 .19034 .7207 .19712 .7308 .19352 .72617 .18676 Metetra
.66 .74 .909 r
.72617 .18676 .7308 .19352 .74094 .18989 .73633 .18316 Metetra
.66 .742 .91 r
.73633 .18316 .74094 .18989 .75111 .18626 .74654 .17955 Metetra
.661 .743 .911 r
.74654 .17955 .75111 .18626 .76132 .18263 .75677 .17592 Metetra
.661 .745 .912 r
.75677 .17592 .76132 .18263 .77157 .17898 .76705 .17227 Metetra
.661 .746 .913 r
.76705 .17227 .77157 .17898 .78186 .17532 .77736 .16861 Metetra
.662 .745 .912 r
.13726 .38912 .14317 .39451 .15136 .39159 .14547 .38618 Metetra
.662 .745 .912 r
.14547 .38618 .15136 .39159 .15957 .38866 .1537 .38323 Metetra
.662 .745 .911 r
.1537 .38323 .15957 .38866 .16782 .38571 .16196 .38026 Metetra
.662 .744 .911 r
.16196 .38026 .16782 .38571 .17609 .38276 .17025 .37728 Metetra
.663 .744 .91 r
.17025 .37728 .17609 .38276 .18439 .37979 .17856 .37427 Metetra
.663 .743 .91 r
.17856 .37427 .18439 .37979 .19271 .37681 .18691 .37126 Metetra
.662 .743 .91 r
.18691 .37126 .19271 .37681 .20106 .37382 .19527 .36824 Metetra
.661 .742 .91 r
.19527 .36824 .20106 .37382 .20944 .37084 .20367 .36524 Metetra
.66 .742 .91 r
.20367 .36524 .20944 .37084 .21785 .36786 .21208 .36226 Metetra
.659 .742 .911 r
.21208 .36226 .21785 .36786 .22628 .36488 .22053 .35929 Metetra
.658 .743 .912 r
.22053 .35929 .22628 .36488 .23473 .3619 .229 .35633 Metetra
.657 .744 .914 r
.229 .35633 .23473 .3619 .24322 .35891 .23749 .35337 Metetra
.657 .746 .915 r
.23749 .35337 .24322 .35891 .25173 .35592 .24601 .35042 Metetra
.657 .748 .917 r
.24601 .35042 .25173 .35592 .26027 .35292 .25456 .34746 Metetra
.658 .75 .918 r
.25456 .34746 .26027 .35292 .26883 .3499 .26315 .34446 Metetra
.661 .753 .918 r
.26315 .34446 .26883 .3499 .27743 .34684 .27176 .34139 Metetra
.665 .754 .916 r
.27176 .34139 .27743 .34684 .28606 .34373 .28041 .33822 Metetra
.67 .754 .913 r
.28041 .33822 .28606 .34373 .29472 .34057 .2891 .33493 Metetra
.673 .751 .909 r
.2891 .33493 .29472 .34057 .30342 .33736 .29782 .33155 Metetra
.674 .745 .904 r
.29782 .33155 .30342 .33736 .31214 .33412 .30657 .32812 Metetra
.674 .739 .899 r
.30657 .32812 .31214 .33412 .32089 .33087 .31535 .32469 Metetra
.672 .732 .895 r
.31535 .32469 .32089 .33087 .32966 .32763 .32415 .32127 Metetra
.668 .726 .893 r
.32415 .32127 .32966 .32763 .33846 .32442 .33298 .31794 Metetra
.66 .72 .893 r
.33298 .31794 .33846 .32442 .34729 .32127 .34182 .31476 Metetra
.651 .716 .896 r
.34182 .31476 .34729 .32127 .35614 .31821 .35068 .31181 Metetra
.638 .716 .904 r
.35068 .31181 .35614 .31821 .36502 .31527 .35956 .30913 Metetra
.623 .722 .917 r
.35956 .30913 .36502 .31527 .37392 .31245 .36845 .30676 Metetra
.607 .734 .935 r
.36845 .30676 .37392 .31245 .38284 .30974 .37737 .30463 Metetra
.593 .754 .955 r
.37737 .30463 .38284 .30974 .3918 .30707 .38631 .30264 Metetra
.578 .779 .974 r
.38631 .30264 .3918 .30707 .40079 .30443 .39529 .3007 Metetra
.563 .806 .99 r
.39529 .3007 .40079 .30443 .40981 .30176 .40431 .29872 Metetra
.551 .834 .998 r
.40431 .29872 .40981 .30176 .41887 .29902 .41337 .29659 Metetra
.547 .859 .997 r
.41337 .29659 .41887 .29902 .42796 .29615 .42248 .29419 Metetra
.557 .881 .991 r
.42248 .29419 .42796 .29615 .43709 .29312 .43163 .29142 Metetra
.584 .901 .984 r
.43163 .29142 .43709 .29312 .44626 .28987 .44083 .28818 Metetra
.623 .915 .98 r
.44083 .28818 .44626 .28987 .45547 .28641 .45008 .28446 Metetra
.661 .917 .977 r
.45008 .28446 .45547 .28641 .46471 .28277 .45936 .28034 Metetra
.692 .906 .971 r
.45936 .28034 .46471 .28277 .47398 .279 .46867 .27593 Metetra
.712 .884 .96 r
.46867 .27593 .47398 .279 .48328 .27513 .47801 .27132 Metetra
.719 .855 .946 r
.47801 .27132 .48328 .27513 .4926 .27123 .48738 .26665 Metetra
.718 .823 .93 r
.48738 .26665 .4926 .27123 .50196 .26734 .49677 .26201 Metetra
.711 .792 .915 r
.49677 .26201 .50196 .26734 .51135 .26349 .50618 .25749 Metetra
.698 .764 .902 r
.50618 .25749 .51135 .26349 .52076 .25974 .51562 .25321 Metetra
.683 .741 .894 r
.51562 .25321 .52076 .25974 .5302 .25613 .52508 .24925 Metetra
.67 .725 .891 r
.52508 .24925 .5302 .25613 .53968 .25264 .53458 .24559 Metetra
.659 .716 .89 r
.53458 .24559 .53968 .25264 .54919 .24926 .54411 .24219 Metetra
.651 .713 .893 r
.54411 .24219 .54919 .24926 .55873 .24595 .55367 .23898 Metetra
.647 .715 .898 r
.55367 .23898 .55873 .24595 .56831 .24268 .56327 .23587 Metetra
.645 .721 .903 r
.56327 .23587 .56831 .24268 .57792 .23942 .5729 .2328 Metetra
.645 .728 .909 r
.5729 .2328 .57792 .23942 .58756 .23615 .58257 .22972 Metetra
.647 .737 .915 r
.58257 .22972 .58756 .23615 .59724 .23285 .59228 .22658 Metetra
.651 .745 .919 r
.59228 .22658 .59724 .23285 .60696 .22949 .60202 .22334 Metetra
.657 .753 .92 r
.60202 .22334 .60696 .22949 .6167 .22606 .61179 .21995 Metetra
.662 .757 .92 r
.61179 .21995 .6167 .22606 .62648 .22258 .62159 .21643 Metetra
.666 .758 .919 r
.62159 .21643 .62648 .22258 .63629 .21904 .63143 .21282 Metetra
.668 .757 .917 r
.63143 .21282 .63629 .21904 .64614 .21547 .64129 .20914 Metetra
.668 .754 .914 r
.64129 .20914 .64614 .21547 .65602 .21188 .65119 .20545 Metetra
.667 .75 .912 r
.65119 .20545 .65602 .21188 .66593 .20829 .66113 .20175 Metetra
.666 .747 .91 r
.66113 .20175 .66593 .20829 .67588 .20469 .6711 .19806 Metetra
.665 .744 .909 r
.6711 .19806 .67588 .20469 .68586 .20109 .6811 .19439 Metetra
.663 .741 .908 r
.6811 .19439 .68586 .20109 .69588 .1975 .69115 .19075 Metetra
.661 .74 .908 r
.69115 .19075 .69588 .1975 .70594 .19392 .70123 .18715 Metetra
.66 .739 .909 r
.70123 .18715 .70594 .19392 .71603 .19034 .71135 .18356 Metetra
.659 .739 .909 r
.71135 .18356 .71603 .19034 .72617 .18676 .7215 .17999 Metetra
.659 .741 .91 r
.7215 .17999 .72617 .18676 .73633 .18316 .7317 .17641 Metetra
.659 .742 .911 r
.7317 .17641 .73633 .18316 .74654 .17955 .74193 .1728 Metetra
.66 .743 .912 r
.74193 .1728 .74654 .17955 .75677 .17592 .7522 .16917 Metetra
.66 .744 .912 r
.7522 .16917 .75677 .17592 .76705 .17227 .7625 .16551 Metetra
.661 .745 .912 r
.7625 .16551 .76705 .17227 .77736 .16861 .77284 .16183 Metetra
.662 .744 .912 r
.13132 .3837 .13726 .38912 .14547 .38618 .13954 .38074 Metetra
.662 .745 .911 r
.13954 .38074 .14547 .38618 .1537 .38323 .14779 .37777 Metetra
.662 .745 .911 r
.14779 .37777 .1537 .38323 .16196 .38026 .15607 .37478 Metetra
.663 .745 .911 r
.15607 .37478 .16196 .38026 .17025 .37728 .16437 .37178 Metetra
.663 .744 .911 r
.16437 .37178 .17025 .37728 .17856 .37427 .1727 .36875 Metetra
.663 .744 .91 r
.1727 .36875 .17856 .37427 .18691 .37126 .18106 .3657 Metetra
.663 .744 .91 r
.18106 .3657 .18691 .37126 .19527 .36824 .18945 .36267 Metetra
.661 .743 .911 r
.18945 .36267 .19527 .36824 .20367 .36524 .19785 .35965 Metetra
.66 .743 .911 r
.19785 .35965 .20367 .36524 .21208 .36226 .20629 .35665 Metetra
.658 .743 .912 r
.20629 .35665 .21208 .36226 .22053 .35929 .21474 .35367 Metetra
.657 .743 .913 r
.21474 .35367 .22053 .35929 .229 .35633 .22323 .35072 Metetra
.656 .743 .914 r
.22323 .35072 .229 .35633 .23749 .35337 .23174 .34776 Metetra
.656 .744 .915 r
.23174 .34776 .23749 .35337 .24601 .35042 .24027 .34482 Metetra
.656 .745 .915 r
.24027 .34482 .24601 .35042 .25456 .34746 .24884 .34186 Metetra
.657 .746 .915 r
.24884 .34186 .25456 .34746 .26315 .34446 .25744 .33886 Metetra
.661 .748 .915 r
.25744 .33886 .26315 .34446 .27176 .34139 .26607 .33577 Metetra
.666 .749 .913 r
.26607 .33577 .27176 .34139 .28041 .33822 .27474 .33256 Metetra
.672 .75 .91 r
.27474 .33256 .28041 .33822 .2891 .33493 .28345 .32921 Metetra
.676 .75 .906 r
.28345 .32921 .2891 .33493 .29782 .33155 .29219 .32575 Metetra
.678 .748 .904 r
.29219 .32575 .29782 .33155 .30657 .32812 .30096 .32222 Metetra
.677 .745 .902 r
.30096 .32222 .30657 .32812 .31535 .32469 .30976 .31869 Metetra
.675 .742 .901 r
.30976 .31869 .31535 .32469 .32415 .32127 .31859 .31519 Metetra
.67 .738 .901 r
.31859 .31519 .32415 .32127 .33298 .31794 .32743 .3118 Metetra
.662 .734 .903 r
.32743 .3118 .33298 .31794 .34182 .31476 .3363 .3086 Metetra
.649 .729 .908 r
.3363 .3086 .34182 .31476 .35068 .31181 .34517 .30568 Metetra
.632 .726 .915 r
.34517 .30568 .35068 .31181 .35956 .30913 .35405 .30311 Metetra
.612 .723 .925 r
.35405 .30311 .35956 .30913 .36845 .30676 .36295 .30093 Metetra
.593 .724 .935 r
.36295 .30093 .36845 .30676 .37737 .30463 .37187 .29904 Metetra
.58 .73 .946 r
.37187 .29904 .37737 .30463 .38631 .30264 .38082 .29733 Metetra
.571 .739 .955 r
.38082 .29733 .38631 .30264 .39529 .3007 .38981 .29569 Metetra
.569 .752 .964 r
.38981 .29569 .39529 .3007 .40431 .29872 .39883 .294 Metetra
.576 .768 .97 r
.39883 .294 .40431 .29872 .41337 .29659 .40791 .29213 Metetra
.593 .786 .973 r
.40791 .29213 .41337 .29659 .42248 .29419 .41703 .28992 Metetra
.619 .805 .971 r
.41703 .28992 .42248 .29419 .43163 .29142 .4262 .28726 Metetra
.652 .82 .964 r
.4262 .28726 .43163 .29142 .44083 .28818 .43543 .284 Metetra
.683 .829 .953 r
.43543 .284 .44083 .28818 .45008 .28446 .4447 .28015 Metetra
.706 .83 .941 r
.4447 .28015 .45008 .28446 .45936 .28034 .45401 .27581 Metetra
.721 .824 .929 r
.45401 .27581 .45936 .28034 .46867 .27593 .46336 .27111 Metetra
.729 .815 .918 r
.46336 .27111 .46867 .27593 .47801 .27132 .47273 .26617 Metetra
.73 .803 .909 r
.47273 .26617 .47801 .27132 .48738 .26665 .48213 .26114 Metetra
.726 .789 .902 r
.48213 .26114 .48738 .26665 .49677 .26201 .49155 .25616 Metetra
.718 .776 .898 r
.49155 .25616 .49677 .26201 .50618 .25749 .50099 .25134 Metetra
.706 .762 .896 r
.50099 .25134 .50618 .25749 .51562 .25321 .51045 .24681 Metetra
.69 .749 .897 r
.51045 .24681 .51562 .25321 .52508 .24925 .51993 .24269 Metetra
.674 .738 .899 r
.51993 .24269 .52508 .24925 .53458 .24559 .52945 .23895 Metetra
.66 .731 .902 r
.52945 .23895 .53458 .24559 .54411 .24219 .539 .23553 Metetra
.65 .728 .906 r
.539 .23553 .54411 .24219 .55367 .23898 .54858 .23234 Metetra
.644 .727 .909 r
.54858 .23234 .55367 .23898 .56327 .23587 .5582 .22929 Metetra
.641 .729 .912 r
.5582 .22929 .56327 .23587 .5729 .2328 .56786 .22629 Metetra
.641 .732 .915 r
.56786 .22629 .5729 .2328 .58257 .22972 .57755 .22328 Metetra
.643 .736 .917 r
.57755 .22328 .58257 .22972 .59228 .22658 .58728 .22021 Metetra
.649 .742 .917 r
.58728 .22021 .59228 .22658 .60202 .22334 .59705 .217 Metetra
.656 .747 .917 r
.59705 .217 .60202 .22334 .61179 .21995 .60684 .21361 Metetra
.662 .75 .915 r
.60684 .21361 .61179 .21995 .62159 .21643 .61667 .21007 Metetra
.667 .751 .914 r
.61667 .21007 .62159 .21643 .63143 .21282 .62653 .20641 Metetra
.669 .751 .912 r
.62653 .20641 .63143 .21282 .64129 .20914 .63641 .20267 Metetra
.669 .75 .911 r
.63641 .20267 .64129 .20914 .65119 .20545 .64634 .19892 Metetra
.668 .749 .91 r
.64634 .19892 .65119 .20545 .66113 .20175 .65629 .19517 Metetra
.668 .747 .91 r
.65629 .19517 .66113 .20175 .6711 .19806 .66629 .19142 Metetra
.666 .745 .909 r
.66629 .19142 .6711 .19806 .6811 .19439 .67632 .18771 Metetra
.664 .744 .91 r
.67632 .18771 .6811 .19439 .69115 .19075 .68638 .18403 Metetra
.661 .742 .91 r
.68638 .18403 .69115 .19075 .70123 .18715 .69649 .1804 Metetra
.66 .742 .911 r
.69649 .1804 .70123 .18715 .71135 .18356 .70663 .1768 Metetra
.658 .741 .911 r
.70663 .1768 .71135 .18356 .7215 .17999 .71682 .17322 Metetra
.658 .742 .912 r
.71682 .17322 .7215 .17999 .7317 .17641 .72704 .16962 Metetra
.659 .743 .912 r
.72704 .16962 .7317 .17641 .74193 .1728 .73729 .16601 Metetra
.659 .743 .912 r
.73729 .16601 .74193 .1728 .7522 .16917 .74759 .16236 Metetra
.66 .744 .912 r
.74759 .16236 .7522 .16917 .7625 .16551 .75791 .15869 Metetra
.661 .744 .912 r
.75791 .15869 .7625 .16551 .77284 .16183 .76828 .15498 Metetra
.662 .744 .911 r
.12535 .37824 .13132 .3837 .13954 .38074 .13358 .37527 Metetra
.662 .744 .911 r
.13358 .37527 .13954 .38074 .14779 .37777 .14185 .37228 Metetra
.662 .744 .911 r
.14185 .37228 .14779 .37777 .15607 .37478 .15014 .36927 Metetra
.663 .745 .911 r
.15014 .36927 .15607 .37478 .16437 .37178 .15846 .36625 Metetra
.663 .745 .911 r
.15846 .36625 .16437 .37178 .1727 .36875 .1668 .3632 Metetra
.663 .745 .911 r
.1668 .3632 .1727 .36875 .18106 .3657 .17518 .36014 Metetra
.663 .745 .911 r
.17518 .36014 .18106 .3657 .18945 .36267 .18358 .35709 Metetra
.661 .744 .912 r
.18358 .35709 .18945 .36267 .19785 .35965 .192 .35405 Metetra
.66 .744 .912 r
.192 .35405 .19785 .35965 .20629 .35665 .20045 .35103 Metetra
.658 .744 .913 r
.20045 .35103 .20629 .35665 .21474 .35367 .20892 .34804 Metetra
.657 .743 .913 r
.20892 .34804 .21474 .35367 .22323 .35072 .21742 .34506 Metetra
.657 .743 .914 r
.21742 .34506 .22323 .35072 .23174 .34776 .22595 .34209 Metetra
.656 .743 .914 r
.22595 .34209 .23174 .34776 .24027 .34482 .2345 .33912 Metetra
.656 .742 .914 r
.2345 .33912 .24027 .34482 .24884 .34186 .24308 .33614 Metetra
.657 .743 .913 r
.24308 .33614 .24884 .34186 .25744 .33886 .2517 .33312 Metetra
.661 .744 .912 r
.2517 .33312 .25744 .33886 .26607 .33577 .26035 .33001 Metetra
.666 .745 .91 r
.26035 .33001 .26607 .33577 .27474 .33256 .26903 .32678 Metetra
.671 .747 .907 r
.26903 .32678 .27474 .33256 .28345 .32921 .27776 .32342 Metetra
.676 .748 .905 r
.27776 .32342 .28345 .32921 .29219 .32575 .28652 .31994 Metetra
.678 .749 .905 r
.28652 .31994 .29219 .32575 .30096 .32222 .29531 .31641 Metetra
.677 .749 .905 r
.29531 .31641 .30096 .32222 .30976 .31869 .30413 .31286 Metetra
.676 .749 .906 r
.30413 .31286 .30976 .31869 .31859 .31519 .31297 .30935 Metetra
.671 .748 .908 r
.31297 .30935 .31859 .31519 .32743 .3118 .32184 .30594 Metetra
.662 .745 .912 r
.32184 .30594 .32743 .3118 .3363 .3086 .33072 .30272 Metetra
.649 .741 .917 r
.33072 .30272 .3363 .3086 .34517 .30568 .33961 .29977 Metetra
.632 .736 .923 r
.33961 .29977 .34517 .30568 .35405 .30311 .34851 .29718 Metetra
.612 .728 .928 r
.34851 .29718 .35405 .30311 .36295 .30093 .35743 .29495 Metetra
.596 .721 .932 r
.35743 .29495 .36295 .30093 .37187 .29904 .36637 .29302 Metetra
.585 .716 .934 r
.36637 .29302 .37187 .29904 .38082 .29733 .37533 .29126 Metetra
.581 .714 .934 r
.37533 .29126 .38082 .29733 .38981 .29569 .38433 .28957 Metetra
.584 .713 .932 r
.38433 .28957 .38981 .29569 .39883 .294 .39338 .28784 Metetra
.594 .716 .929 r
.39338 .28784 .39883 .294 .40791 .29213 .40247 .28592 Metetra
.611 .722 .924 r
.40247 .28592 .40791 .29213 .41703 .28992 .41161 .28367 Metetra
.633 .729 .917 r
.41161 .28367 .41703 .28992 .4262 .28726 .4208 .28097 Metetra
.658 .738 .908 r
.4208 .28097 .4262 .28726 .43543 .284 .43005 .2777 Metetra
.682 .745 .899 r
.43005 .2777 .43543 .284 .4447 .28015 .43934 .27384 Metetra
.7 .751 .892 r
.43934 .27384 .4447 .28015 .45401 .27581 .44867 .26949 Metetra
.712 .755 .886 r
.44867 .26949 .45401 .27581 .46336 .27111 .45804 .26479 Metetra
.719 .758 .883 r
.45804 .26479 .46336 .27111 .47273 .26617 .46743 .25986 Metetra
.722 .76 .883 r
.46743 .25986 .47273 .26617 .48213 .26114 .47685 .25484 Metetra
.72 .761 .885 r
.47685 .25484 .48213 .26114 .49155 .25616 .4863 .24987 Metetra
.715 .76 .888 r
.4863 .24987 .49155 .25616 .50099 .25134 .49576 .24505 Metetra
.704 .758 .894 r
.49576 .24505 .50099 .25134 .51045 .24681 .50524 .24052 Metetra
.69 .754 .901 r
.50524 .24052 .51045 .24681 .51993 .24269 .51475 .23639 Metetra
.674 .75 .907 r
.51475 .23639 .51993 .24269 .52945 .23895 .52429 .23263 Metetra
.661 .745 .912 r
.52429 .23263 .52945 .23895 .539 .23553 .53386 .22919 Metetra
.651 .741 .916 r
.53386 .22919 .539 .23553 .54858 .23234 .54346 .22598 Metetra
.644 .739 .918 r
.54346 .22598 .54858 .23234 .5582 .22929 .55311 .2229 Metetra
.642 .737 .918 r
.55311 .2229 .5582 .22929 .56786 .22629 .56278 .21987 Metetra
.641 .737 .918 r
.56278 .21987 .56786 .22629 .57755 .22328 .5725 .21683 Metetra
.644 .738 .917 r
.5725 .21683 .57755 .22328 .58728 .22021 .58225 .21372 Metetra
.649 .739 .915 r
.58225 .21372 .58728 .22021 .59705 .217 .59204 .21048 Metetra
.656 .742 .913 r
.59204 .21048 .59705 .217 .60684 .21361 .60186 .20707 Metetra
.662 .744 .911 r
.60186 .20707 .60684 .21361 .61667 .21007 .6117 .20351 Metetra
.666 .746 .91 r
.6117 .20351 .61667 .21007 .62653 .20641 .62159 .19983 Metetra
.669 .747 .909 r
.62159 .19983 .62653 .20641 .63641 .20267 .6315 .19607 Metetra
.669 .747 .909 r
.6315 .19607 .63641 .20267 .64634 .19892 .64145 .1923 Metetra
.668 .747 .909 r
.64145 .1923 .64634 .19892 .65629 .19517 .65143 .18852 Metetra
.667 .747 .91 r
.65143 .18852 .65629 .19517 .66629 .19142 .66144 .18476 Metetra
.666 .746 .91 r
.66144 .18476 .66629 .19142 .67632 .18771 .6715 .18102 Metetra
.664 .745 .911 r
.6715 .18102 .67632 .18771 .68638 .18403 .68159 .17733 Metetra
.661 .744 .912 r
.68159 .17733 .68638 .18403 .69649 .1804 .69172 .17367 Metetra
.66 .744 .912 r
.69172 .17367 .69649 .1804 .70663 .1768 .70189 .17005 Metetra
.658 .743 .913 r
.70189 .17005 .70663 .1768 .71682 .17322 .7121 .16644 Metetra
.658 .743 .913 r
.7121 .16644 .71682 .17322 .72704 .16962 .72234 .16282 Metetra
.659 .743 .912 r
.72234 .16282 .72704 .16962 .73729 .16601 .73263 .15917 Metetra
.659 .743 .912 r
.73263 .15917 .73729 .16601 .74759 .16236 .74294 .1555 Metetra
.66 .744 .912 r
.74294 .1555 .74759 .16236 .75791 .15869 .7533 .1518 Metetra
.661 .744 .912 r
.7533 .1518 .75791 .15869 .76828 .15498 .76369 .14807 Metetra
.662 .744 .911 r
.11934 .37275 .12535 .37824 .13358 .37527 .12759 .36976 Metetra
.662 .744 .911 r
.12759 .36976 .13358 .37527 .14185 .37228 .13587 .36675 Metetra
.662 .744 .911 r
.13587 .36675 .14185 .37228 .15014 .36927 .14417 .36373 Metetra
.662 .745 .911 r
.14417 .36373 .15014 .36927 .15846 .36625 .15251 .36069 Metetra
.663 .745 .911 r
.15251 .36069 .15846 .36625 .1668 .3632 .16087 .35763 Metetra
.663 .745 .911 r
.16087 .35763 .1668 .3632 .17518 .36014 .16926 .35456 Metetra
.662 .745 .912 r
.16926 .35456 .17518 .36014 .18358 .35709 .17767 .35149 Metetra
.661 .745 .912 r
.17767 .35149 .18358 .35709 .192 .35405 .18611 .34844 Metetra
.66 .745 .913 r
.18611 .34844 .192 .35405 .20045 .35103 .19458 .34539 Metetra
.659 .744 .913 r
.19458 .34539 .20045 .35103 .20892 .34804 .20307 .34237 Metetra
.658 .744 .913 r
.20307 .34237 .20892 .34804 .21742 .34506 .21159 .33936 Metetra
.657 .743 .913 r
.21159 .33936 .21742 .34506 .22595 .34209 .22013 .33635 Metetra
.657 .742 .913 r
.22013 .33635 .22595 .34209 .2345 .33912 .2287 .33334 Metetra
.657 .741 .912 r
.2287 .33334 .2345 .33912 .24308 .33614 .2373 .33032 Metetra
.658 .741 .911 r
.2373 .33032 .24308 .33614 .2517 .33312 .24593 .32727 Metetra
.661 .741 .909 r
.24593 .32727 .2517 .33312 .26035 .33001 .2546 .32414 Metetra
.665 .742 .908 r
.2546 .32414 .26035 .33001 .26903 .32678 .2633 .32091 Metetra
.669 .744 .906 r
.2633 .32091 .26903 .32678 .27776 .32342 .27204 .31756 Metetra
.673 .746 .906 r
.27204 .31756 .27776 .32342 .28652 .31994 .28081 .31412 Metetra
.675 .749 .907 r
.28081 .31412 .28652 .31994 .29531 .31641 .28962 .31064 Metetra
.675 .752 .909 r
.28962 .31064 .29531 .31641 .30413 .31286 .29845 .30714 Metetra
.674 .754 .911 r
.29845 .30714 .30413 .31286 .31297 .30935 .30731 .30366 Metetra
.67 .755 .914 r
.30731 .30366 .31297 .30935 .32184 .30594 .31619 .30027 Metetra
.662 .754 .918 r
.31619 .30027 .32184 .30594 .33072 .30272 .32509 .29704 Metetra
.651 .751 .923 r
.32509 .29704 .33072 .30272 .33961 .29977 .334 .29402 Metetra
.637 .745 .926 r
.334 .29402 .33961 .29977 .34851 .29718 .34293 .29129 Metetra
.621 .735 .928 r
.34293 .29129 .34851 .29718 .35743 .29495 .35187 .28887 Metetra
.609 .724 .926 r
.35187 .28887 .35743 .29495 .36637 .29302 .36084 .28668 Metetra
.602 .712 .922 r
.36084 .28668 .36637 .29302 .37533 .29126 .36983 .28464 Metetra
.6 .701 .915 r
.36983 .28464 .37533 .29126 .38433 .28957 .37886 .28265 Metetra
.602 .692 .906 r
.37886 .28265 .38433 .28957 .39338 .28784 .38793 .28061 Metetra
.61 .686 .896 r
.38793 .28061 .39338 .28784 .40247 .28592 .39705 .27843 Metetra
.622 .683 .887 r
.39705 .27843 .40247 .28592 .41161 .28367 .40621 .27597 Metetra
.637 .683 .877 r
.40621 .27597 .41161 .28367 .4208 .28097 .41542 .27314 Metetra
.654 .687 .868 r
.41542 .27314 .4208 .28097 .43005 .2777 .42468 .26984 Metetra
.671 .693 .862 r
.42468 .26984 .43005 .2777 .43934 .27384 .43398 .26605 Metetra
.684 .701 .859 r
.43398 .26605 .43934 .27384 .44867 .26949 .44333 .26186 Metetra
.694 .709 .86 r
.44333 .26186 .44867 .26949 .45804 .26479 .45271 .25738 Metetra
.702 .719 .863 r
.45271 .25738 .45804 .26479 .46743 .25986 .46212 .2527 Metetra
.706 .729 .868 r
.46212 .2527 .46743 .25986 .47685 .25484 .47156 .24796 Metetra
.707 .739 .876 r
.47156 .24796 .47685 .25484 .4863 .24987 .48101 .24324 Metetra
.704 .747 .885 r
.48101 .24324 .4863 .24987 .49576 .24505 .4905 .23866 Metetra
.697 .753 .895 r
.4905 .23866 .49576 .24505 .50524 .24052 .5 .2343 Metetra
.685 .757 .906 r
.5 .2343 .50524 .24052 .51475 .23639 .50953 .23027 Metetra
.673 .757 .914 r
.50953 .23027 .51475 .23639 .52429 .23263 .5191 .22655 Metetra
.661 .755 .92 r
.5191 .22655 .52429 .23263 .53386 .22919 .52869 .22309 Metetra
.653 .752 .923 r
.52869 .22309 .53386 .22919 .54346 .22598 .53832 .21981 Metetra
.647 .748 .923 r
.53832 .21981 .54346 .22598 .55311 .2229 .54798 .21663 Metetra
.645 .745 .922 r
.54798 .21663 .55311 .2229 .56278 .21987 .55768 .21349 Metetra
.645 .742 .92 r
.55768 .21349 .56278 .21987 .5725 .21683 .56741 .21035 Metetra
.647 .74 .917 r
.56741 .21035 .5725 .21683 .58225 .21372 .57719 .20715 Metetra
.651 .739 .913 r
.57719 .20715 .58225 .21372 .59204 .21048 .58699 .20384 Metetra
.657 .739 .91 r
.58699 .20384 .59204 .21048 .60186 .20707 .59683 .20038 Metetra
.662 .74 .908 r
.59683 .20038 .60186 .20707 .6117 .20351 .60671 .1968 Metetra
.665 .741 .907 r
.60671 .1968 .6117 .20351 .62159 .19983 .61661 .19311 Metetra
.667 .743 .907 r
.61661 .19311 .62159 .19983 .6315 .19607 .62655 .18936 Metetra
.667 .744 .908 r
.62655 .18936 .6315 .19607 .64145 .1923 .63652 .1856 Metetra
.667 .745 .909 r
.63652 .1856 .64145 .1923 .65143 .18852 .64653 .18183 Metetra
.666 .746 .91 r
.64653 .18183 .65143 .18852 .66144 .18476 .65657 .17807 Metetra
.665 .746 .911 r
.65657 .17807 .66144 .18476 .6715 .18102 .66665 .17433 Metetra
.663 .746 .912 r
.66665 .17433 .6715 .18102 .68159 .17733 .67677 .17062 Metetra
.662 .746 .913 r
.67677 .17062 .68159 .17733 .69172 .17367 .68692 .16694 Metetra
.66 .745 .913 r
.68692 .16694 .69172 .17367 .70189 .17005 .69712 .16328 Metetra
.659 .745 .913 r
.69712 .16328 .70189 .17005 .7121 .16644 .70735 .15963 Metetra
.659 .744 .913 r
.70735 .15963 .7121 .16644 .72234 .16282 .71762 .15598 Metetra
.659 .744 .913 r
.71762 .15598 .72234 .16282 .73263 .15917 .72793 .1523 Metetra
.66 .744 .912 r
.72793 .1523 .73263 .15917 .74294 .1555 .73827 .14859 Metetra
.66 .744 .912 r
.73827 .14859 .74294 .1555 .7533 .1518 .74865 .14486 Metetra
.661 .744 .911 r
.74865 .14486 .7533 .1518 .76369 .14807 .75907 .14111 Metetra
.661 .744 .911 r
.11329 .36722 .11934 .37275 .12759 .36976 .12156 .36421 Metetra
.662 .744 .911 r
.12156 .36421 .12759 .36976 .13587 .36675 .12985 .36119 Metetra
.662 .744 .911 r
.12985 .36119 .13587 .36675 .14417 .36373 .13817 .35815 Metetra
.662 .744 .911 r
.13817 .35815 .14417 .36373 .15251 .36069 .14652 .3551 Metetra
.662 .745 .911 r
.14652 .3551 .15251 .36069 .16087 .35763 .1549 .35204 Metetra
.662 .745 .912 r
.1549 .35204 .16087 .35763 .16926 .35456 .1633 .34896 Metetra
.662 .746 .912 r
.1633 .34896 .16926 .35456 .17767 .35149 .17173 .34588 Metetra
.661 .746 .912 r
.17173 .34588 .17767 .35149 .18611 .34844 .18019 .3428 Metetra
.661 .745 .913 r
.18019 .3428 .18611 .34844 .19458 .34539 .18867 .33973 Metetra
.66 .745 .913 r
.18867 .33973 .19458 .34539 .20307 .34237 .19718 .33667 Metetra
.659 .744 .913 r
.19718 .33667 .20307 .34237 .21159 .33936 .20571 .33362 Metetra
.659 .743 .912 r
.20571 .33362 .21159 .33936 .22013 .33635 .21428 .33056 Metetra
.658 .742 .912 r
.21428 .33056 .22013 .33635 .2287 .33334 .22287 .3275 Metetra
.658 .741 .911 r
.22287 .3275 .2287 .33334 .2373 .33032 .23149 .32444 Metetra
.659 .74 .91 r
.23149 .32444 .2373 .33032 .24593 .32727 .24014 .32134 Metetra
.661 .74 .908 r
.24014 .32134 .24593 .32727 .2546 .32414 .24882 .31819 Metetra
.664 .74 .907 r
.24882 .31819 .2546 .32414 .2633 .32091 .25754 .31496 Metetra
.667 .742 .906 r
.25754 .31496 .2633 .32091 .27204 .31756 .26629 .31166 Metetra
.669 .745 .907 r
.26629 .31166 .27204 .31756 .28081 .31412 .27507 .30828 Metetra
.671 .748 .909 r
.27507 .30828 .28081 .31412 .28962 .31064 .28389 .30487 Metetra
.671 .752 .911 r
.28389 .30487 .28962 .31064 .29845 .30714 .29273 .30145 Metetra
.67 .755 .914 r
.29273 .30145 .29845 .30714 .30731 .30366 .3016 .29804 Metetra
.667 .758 .918 r
.3016 .29804 .30731 .30366 .31619 .30027 .3105 .29468 Metetra
.662 .758 .921 r
.3105 .29468 .31619 .30027 .32509 .29704 .31942 .29143 Metetra
.655 .756 .924 r
.31942 .29143 .32509 .29704 .334 .29402 .32835 .28833 Metetra
.645 .751 .926 r
.32835 .28833 .334 .29402 .34293 .29129 .33731 .28542 Metetra
.634 .741 .925 r
.33731 .28542 .34293 .29129 .35187 .28887 .34628 .28272 Metetra
.626 .729 .92 r
.34628 .28272 .35187 .28887 .36084 .28668 .35528 .28017 Metetra
.622 .715 .912 r
.35528 .28017 .36084 .28668 .36983 .28464 .36431 .27772 Metetra
.62 .701 .902 r
.36431 .27772 .36983 .28464 .37886 .28265 .37338 .27531 Metetra
.621 .688 .891 r
.37338 .27531 .37886 .28265 .38793 .28061 .38248 .27286 Metetra
.625 .677 .879 r
.38248 .27286 .38793 .28061 .39705 .27843 .39162 .2703 Metetra
.632 .669 .868 r
.39162 .2703 .39705 .27843 .40621 .27597 .4008 .26756 Metetra
.64 .665 .858 r
.4008 .26756 .40621 .27597 .41542 .27314 .41003 .26455 Metetra
.651 .665 .851 r
.41003 .26455 .41542 .27314 .42468 .26984 .41931 .26121 Metetra
.662 .67 .847 r
.41931 .26121 .42468 .26984 .43398 .26605 .42862 .25753 Metetra
.671 .677 .847 r
.42862 .25753 .43398 .26605 .44333 .26186 .43798 .25358 Metetra
.679 .687 .85 r
.43798 .25358 .44333 .26186 .45271 .25738 .44737 .24942 Metetra
.685 .699 .857 r
.44737 .24942 .45271 .25738 .46212 .2527 .45678 .24512 Metetra
.69 .712 .865 r
.45678 .24512 .46212 .2527 .47156 .24796 .46623 .24077 Metetra
.691 .725 .876 r
.46623 .24077 .47156 .24796 .48101 .24324 .4757 .23644 Metetra
.691 .738 .887 r
.4757 .23644 .48101 .24324 .4905 .23866 .4852 .23219 Metetra
.686 .749 .899 r
.4852 .23219 .4905 .23866 .5 .2343 .49473 .2281 Metetra
.678 .756 .91 r
.49473 .2281 .5 .2343 .50953 .23027 .50428 .22422 Metetra
.669 .76 .918 r
.50428 .22422 .50953 .23027 .5191 .22655 .51387 .22056 Metetra
.662 .76 .923 r
.51387 .22056 .5191 .22655 .52869 .22309 .52348 .21707 Metetra
.655 .758 .925 r
.52348 .21707 .52869 .22309 .53832 .21981 .53313 .2137 Metetra
.652 .754 .925 r
.53313 .2137 .53832 .21981 .54798 .21663 .54282 .2104 Metetra
.65 .75 .922 r
.54282 .2104 .54798 .21663 .55768 .21349 .55254 .20713 Metetra
.65 .746 .919 r
.55254 .20713 .55768 .21349 .56741 .21035 .5623 .20384 Metetra
.651 .742 .916 r
.5623 .20384 .56741 .21035 .57719 .20715 .57209 .20051 Metetra
.654 .739 .912 r
.57209 .20051 .57719 .20715 .58699 .20384 .58192 .1971 Metetra
.658 .738 .909 r
.58192 .1971 .58699 .20384 .59683 .20038 .59178 .19359 Metetra
.661 .738 .907 r
.59178 .19359 .59683 .20038 .60671 .1968 .60167 .18998 Metetra
.664 .739 .906 r
.60167 .18998 .60671 .1968 .61661 .19311 .6116 .18631 Metetra
.665 .741 .906 r
.6116 .18631 .61661 .19311 .62655 .18936 .62157 .18258 Metetra
.665 .742 .907 r
.62157 .18258 .62655 .18936 .63652 .1856 .63156 .17884 Metetra
.665 .744 .909 r
.63156 .17884 .63652 .1856 .64653 .18183 .6416 .17509 Metetra
.665 .745 .91 r
.6416 .17509 .64653 .18183 .65657 .17807 .65167 .17135 Metetra
.664 .746 .911 r
.65167 .17135 .65657 .17807 .66665 .17433 .66177 .16761 Metetra
.663 .747 .913 r
.66177 .16761 .66665 .17433 .67677 .17062 .67191 .16389 Metetra
.662 .747 .913 r
.67191 .16389 .67677 .17062 .68692 .16694 .6821 .16018 Metetra
.661 .746 .914 r
.6821 .16018 .68692 .16694 .69712 .16328 .69231 .15649 Metetra
.66 .746 .914 r
.69231 .15649 .69712 .16328 .70735 .15963 .70257 .1528 Metetra
.66 .745 .913 r
.70257 .1528 .70735 .15963 .71762 .15598 .71287 .1491 Metetra
.66 .744 .913 r
.71287 .1491 .71762 .15598 .72793 .1523 .7232 .14538 Metetra
.66 .744 .912 r
.7232 .14538 .72793 .1523 .73827 .14859 .73357 .14164 Metetra
.661 .744 .912 r
.73357 .14164 .73827 .14859 .74865 .14486 .74397 .13787 Metetra
.661 .744 .911 r
.74397 .13787 .74865 .14486 .75907 .14111 .75442 .13408 Metetra
.661 .744 .911 r
.10721 .36165 .11329 .36722 .12156 .36421 .11549 .35863 Metetra
.662 .744 .911 r
.11549 .35863 .12156 .36421 .12985 .36119 .1238 .35559 Metetra
.662 .744 .911 r
.1238 .35559 .12985 .36119 .13817 .35815 .13214 .35254 Metetra
.662 .744 .911 r
.13214 .35254 .13817 .35815 .14652 .3551 .1405 .34948 Metetra
.662 .745 .912 r
.1405 .34948 .14652 .3551 .1549 .35204 .14889 .3464 Metetra
.662 .745 .912 r
.14889 .3464 .1549 .35204 .1633 .34896 .15731 .34332 Metetra
.662 .745 .912 r
.15731 .34332 .1633 .34896 .17173 .34588 .16575 .34023 Metetra
.661 .746 .912 r
.16575 .34023 .17173 .34588 .18019 .3428 .17423 .33713 Metetra
.661 .745 .913 r
.17423 .33713 .18019 .3428 .18867 .33973 .18272 .33404 Metetra
.66 .745 .913 r
.18272 .33404 .18867 .33973 .19718 .33667 .19125 .33094 Metetra
.66 .744 .912 r
.19125 .33094 .19718 .33667 .20571 .33362 .1998 .32785 Metetra
.66 .743 .912 r
.1998 .32785 .20571 .33362 .21428 .33056 .20839 .32474 Metetra
.66 .742 .911 r
.20839 .32474 .21428 .33056 .22287 .3275 .217 .32164 Metetra
.659 .741 .91 r
.217 .32164 .22287 .3275 .23149 .32444 .22563 .31852 Metetra
.66 .74 .909 r
.22563 .31852 .23149 .32444 .24014 .32134 .2343 .31538 Metetra
.661 .74 .908 r
.2343 .31538 .24014 .32134 .24882 .31819 .243 .31221 Metetra
.663 .74 .908 r
.243 .31221 .24882 .31819 .25754 .31496 .25173 .30899 Metetra
.664 .742 .908 r
.25173 .30899 .25754 .31496 .26629 .31166 .2605 .30572 Metetra
.666 .744 .908 r
.2605 .30572 .26629 .31166 .27507 .30828 .2693 .3024 Metetra
.667 .747 .91 r
.2693 .3024 .27507 .30828 .28389 .30487 .27812 .29907 Metetra
.667 .751 .913 r
.27812 .29907 .28389 .30487 .29273 .30145 .28698 .29572 Metetra
.666 .754 .916 r
.28698 .29572 .29273 .30145 .3016 .29804 .29586 .29237 Metetra
.665 .757 .919 r
.29586 .29237 .3016 .29804 .3105 .29468 .30477 .28904 Metetra
.662 .758 .921 r
.30477 .28904 .3105 .29468 .31942 .29143 .31371 .28578 Metetra
.658 .757 .923 r
.31371 .28578 .31942 .29143 .32835 .28833 .32267 .28259 Metetra
.652 .753 .923 r
.32267 .28259 .32835 .28833 .33731 .28542 .33165 .2795 Metetra
.647 .745 .921 r
.33165 .2795 .33731 .28542 .34628 .28272 .34066 .27653 Metetra
.642 .734 .915 r
.34066 .27653 .34628 .28272 .35528 .28017 .3497 .27364 Metetra
.64 .721 .907 r
.3497 .27364 .35528 .28017 .36431 .27772 .35876 .2708 Metetra
.638 .708 .897 r
.35876 .2708 .36431 .27772 .37338 .27531 .36786 .26797 Metetra
.638 .695 .887 r
.36786 .26797 .37338 .27531 .38248 .27286 .37699 .26512 Metetra
.639 .684 .876 r
.37699 .26512 .38248 .27286 .39162 .2703 .38616 .2622 Metetra
.642 .675 .866 r
.38616 .2622 .39162 .2703 .4008 .26756 .39537 .25917 Metetra
.646 .669 .858 r
.39537 .25917 .4008 .26756 .41003 .26455 .40462 .25599 Metetra
.652 .668 .853 r
.40462 .25599 .41003 .26455 .41931 .26121 .41391 .25261 Metetra
.658 .67 .85 r
.41391 .25261 .41931 .26121 .42862 .25753 .42323 .24905 Metetra
.664 .676 .851 r
.42323 .24905 .42862 .25753 .43798 .25358 .4326 .24532 Metetra
.669 .685 .856 r
.4326 .24532 .43798 .25358 .44737 .24942 .44199 .24147 Metetra
.673 .696 .863 r
.44199 .24147 .44737 .24942 .45678 .24512 .45142 .23753 Metetra
.676 .708 .872 r
.45142 .23753 .45678 .24512 .46623 .24077 .46087 .23357 Metetra
.678 .721 .882 r
.46087 .23357 .46623 .24077 .4757 .23644 .47036 .2296 Metetra
.678 .734 .893 r
.47036 .2296 .4757 .23644 .4852 .23219 .47987 .22568 Metetra
.676 .745 .903 r
.47987 .22568 .4852 .23219 .49473 .2281 .48942 .22184 Metetra
.671 .754 .913 r
.48942 .22184 .49473 .2281 .50428 .22422 .49899 .21812 Metetra
.666 .759 .919 r
.49899 .21812 .50428 .22422 .51387 .22056 .5086 .21451 Metetra
.662 .76 .923 r
.5086 .21451 .51387 .22056 .52348 .21707 .51824 .211 Metetra
.658 .759 .924 r
.51824 .211 .52348 .21707 .53313 .2137 .52791 .20754 Metetra
.656 .755 .923 r
.52791 .20754 .53313 .2137 .54282 .2104 .53762 .20412 Metetra
.655 .751 .921 r
.53762 .20412 .54282 .2104 .55254 .20713 .54737 .20071 Metetra
.655 .747 .918 r
.54737 .20071 .55254 .20713 .5623 .20384 .55714 .19729 Metetra
.656 .743 .914 r
.55714 .19729 .5623 .20384 .57209 .20051 .56696 .19383 Metetra
.657 .74 .911 r
.56696 .19383 .57209 .20051 .58192 .1971 .57681 .19033 Metetra
.659 .738 .908 r
.57681 .19033 .58192 .1971 .59178 .19359 .58669 .18676 Metetra
.661 .738 .907 r
.58669 .18676 .59178 .19359 .60167 .18998 .59661 .18314 Metetra
.663 .739 .906 r
.59661 .18314 .60167 .18998 .6116 .18631 .60656 .17946 Metetra
.663 .74 .907 r
.60656 .17946 .6116 .18631 .62157 .18258 .61655 .17576 Metetra
.664 .742 .908 r
.61655 .17576 .62157 .18258 .63156 .17884 .62657 .17204 Metetra
.663 .743 .909 r
.62657 .17204 .63156 .17884 .6416 .17509 .63663 .16831 Metetra
.663 .745 .911 r
.63663 .16831 .6416 .17509 .65167 .17135 .64673 .16457 Metetra
.663 .746 .912 r
.64673 .16457 .65167 .17135 .66177 .16761 .65686 .16084 Metetra
.662 .746 .913 r
.65686 .16084 .66177 .16761 .67191 .16389 .66703 .15711 Metetra
.662 .747 .913 r
.66703 .15711 .67191 .16389 .6821 .16018 .67723 .15338 Metetra
.661 .746 .914 r
.67723 .15338 .6821 .16018 .69231 .15649 .68748 .14965 Metetra
.661 .746 .913 r
.68748 .14965 .69231 .15649 .70257 .1528 .69776 .14592 Metetra
.66 .745 .913 r
.69776 .14592 .70257 .1528 .71287 .1491 .70808 .14217 Metetra
.661 .745 .912 r
.70808 .14217 .71287 .1491 .7232 .14538 .71844 .13841 Metetra
.661 .744 .912 r
.71844 .13841 .7232 .14538 .73357 .14164 .72883 .13463 Metetra
.661 .744 .911 r
.72883 .13463 .73357 .14164 .74397 .13787 .73926 .13083 Metetra
.661 .744 .911 r
.73926 .13083 .74397 .13787 .75442 .13408 .74974 .12702 Metetra
.661 .744 .911 r
.1011 .35606 .10721 .36165 .11549 .35863 .10939 .35302 Metetra
.661 .744 .911 r
.10939 .35302 .11549 .35863 .1238 .35559 .11771 .34996 Metetra
.661 .744 .911 r
.11771 .34996 .1238 .35559 .13214 .35254 .12606 .3469 Metetra
.662 .744 .912 r
.12606 .3469 .13214 .35254 .1405 .34948 .13444 .34382 Metetra
.662 .745 .912 r
.13444 .34382 .1405 .34948 .14889 .3464 .14285 .34074 Metetra
.662 .745 .912 r
.14285 .34074 .14889 .3464 .15731 .34332 .15128 .33764 Metetra
.662 .745 .912 r
.15128 .33764 .15731 .34332 .16575 .34023 .15974 .33453 Metetra
.661 .745 .912 r
.15974 .33453 .16575 .34023 .17423 .33713 .16823 .33142 Metetra
.661 .745 .912 r
.16823 .33142 .17423 .33713 .18272 .33404 .17674 .3283 Metetra
.661 .745 .912 r
.17674 .3283 .18272 .33404 .19125 .33094 .18529 .32517 Metetra
.661 .744 .912 r
.18529 .32517 .19125 .33094 .1998 .32785 .19386 .32204 Metetra
.661 .744 .911 r
.19386 .32204 .1998 .32785 .20839 .32474 .20246 .3189 Metetra
.661 .743 .911 r
.20246 .3189 .20839 .32474 .217 .32164 .21109 .31574 Metetra
.661 .742 .91 r
.21109 .31574 .217 .32164 .22563 .31852 .21975 .31258 Metetra
.661 .741 .909 r
.21975 .31258 .22563 .31852 .2343 .31538 .22843 .3094 Metetra
.661 .74 .909 r
.22843 .3094 .2343 .31538 .243 .31221 .23715 .30621 Metetra
.662 .74 .908 r
.23715 .30621 .243 .31221 .25173 .30899 .2459 .30299 Metetra
.662 .741 .909 r
.2459 .30299 .25173 .30899 .2605 .30572 .25467 .29975 Metetra
.663 .743 .91 r
.25467 .29975 .2605 .30572 .2693 .3024 .26348 .29648 Metetra
.663 .746 .912 r
.26348 .29648 .2693 .3024 .27812 .29907 .27232 .29321 Metetra
.663 .749 .914 r
.27232 .29321 .27812 .29907 .28698 .29572 .28119 .28992 Metetra
.663 .752 .916 r
.28119 .28992 .28698 .29572 .29586 .29237 .29009 .28662 Metetra
.663 .755 .918 r
.29009 .28662 .29586 .29237 .30477 .28904 .29901 .28333 Metetra
.662 .756 .92 r
.29901 .28333 .30477 .28904 .31371 .28578 .30797 .28004 Metetra
.661 .756 .921 r
.30797 .28004 .31371 .28578 .32267 .28259 .31695 .27677 Metetra
.659 .753 .92 r
.31695 .27677 .32267 .28259 .33165 .2795 .32596 .27353 Metetra
.657 .747 .917 r
.32596 .27353 .33165 .2795 .34066 .27653 .335 .27031 Metetra
.655 .739 .911 r
.335 .27031 .34066 .27653 .3497 .27364 .34407 .26712 Metetra
.654 .728 .904 r
.34407 .26712 .3497 .27364 .35876 .2708 .35317 .26393 Metetra
.653 .717 .895 r
.35317 .26393 .35876 .2708 .36786 .26797 .36231 .26074 Metetra
.652 .705 .886 r
.36231 .26074 .36786 .26797 .37699 .26512 .37147 .25753 Metetra
.651 .695 .877 r
.37147 .25753 .37699 .26512 .38616 .2622 .38067 .25429 Metetra
.651 .686 .869 r
.38067 .25429 .38616 .2622 .39537 .25917 .3899 .25101 Metetra
.652 .679 .863 r
.3899 .25101 .39537 .25917 .40462 .25599 .39917 .24768 Metetra
.653 .676 .859 r
.39917 .24768 .40462 .25599 .41391 .25261 .40847 .24427 Metetra
.655 .677 .858 r
.40847 .24427 .41391 .25261 .42323 .24905 .41781 .2408 Metetra
.658 .681 .861 r
.41781 .2408 .42323 .24905 .4326 .24532 .42718 .23726 Metetra
.66 .688 .865 r
.42718 .23726 .4326 .24532 .44199 .24147 .43658 .23368 Metetra
.662 .697 .872 r
.43658 .23368 .44199 .24147 .45142 .23753 .44602 .23006 Metetra
.664 .709 .881 r
.44602 .23006 .45142 .23753 .46087 .23357 .45548 .22643 Metetra
.666 .72 .89 r
.45548 .22643 .46087 .23357 .47036 .2296 .46498 .22278 Metetra
.666 .732 .899 r
.46498 .22278 .47036 .2296 .47987 .22568 .47451 .21915 Metetra
.666 .743 .907 r
.47451 .21915 .47987 .22568 .48942 .22184 .48408 .21553 Metetra
.665 .751 .914 r
.48408 .21553 .48942 .22184 .49899 .21812 .49367 .21194 Metetra
.663 .756 .919 r
.49367 .21194 .49899 .21812 .5086 .21451 .5033 .20837 Metetra
.662 .758 .921 r
.5033 .20837 .5086 .21451 .51824 .211 .51296 .20483 Metetra
.661 .757 .922 r
.51296 .20483 .51824 .211 .52791 .20754 .52266 .2013 Metetra
.66 .755 .92 r
.52266 .2013 .52791 .20754 .53762 .20412 .53239 .19777 Metetra
.66 .752 .918 r
.53239 .19777 .53762 .20412 .54737 .20071 .54216 .19423 Metetra
.66 .748 .916 r
.54216 .19423 .54737 .20071 .55714 .19729 .55196 .19069 Metetra
.66 .745 .913 r
.55196 .19069 .55714 .19729 .56696 .19383 .56179 .18712 Metetra
.66 .742 .91 r
.56179 .18712 .56696 .19383 .57681 .19033 .57167 .18353 Metetra
.661 .74 .908 r
.57167 .18353 .57681 .19033 .58669 .18676 .58157 .17991 Metetra
.661 .739 .907 r
.58157 .17991 .58669 .18676 .59661 .18314 .59151 .17626 Metetra
.662 .739 .907 r
.59151 .17626 .59661 .18314 .60656 .17946 .60149 .17259 Metetra
.662 .74 .908 r
.60149 .17259 .60656 .17946 .61655 .17576 .6115 .1689 Metetra
.662 .741 .909 r
.6115 .1689 .61655 .17576 .62657 .17204 .62155 .1652 Metetra
.662 .743 .91 r
.62155 .1652 .62657 .17204 .63663 .16831 .63164 .16148 Metetra
.662 .744 .911 r
.63164 .16148 .63663 .16831 .64673 .16457 .64176 .15775 Metetra
.662 .745 .912 r
.64176 .15775 .64673 .16457 .65686 .16084 .65191 .15402 Metetra
.662 .746 .913 r
.65191 .15402 .65686 .16084 .66703 .15711 .66211 .15027 Metetra
.661 .746 .913 r
.66211 .15027 .66703 .15711 .67723 .15338 .67234 .14652 Metetra
.661 .746 .913 r
.67234 .14652 .67723 .15338 .68748 .14965 .68261 .14276 Metetra
.661 .746 .913 r
.68261 .14276 .68748 .14965 .69776 .14592 .69292 .13899 Metetra
.661 .745 .913 r
.69292 .13899 .69776 .14592 .70808 .14217 .70326 .1352 Metetra
.661 .745 .912 r
.70326 .1352 .70808 .14217 .71844 .13841 .71364 .1314 Metetra
.661 .744 .912 r
.71364 .1314 .71844 .13841 .72883 .13463 .72406 .12758 Metetra
.661 .744 .911 r
.72406 .12758 .72883 .13463 .73926 .13083 .73452 .12375 Metetra
.661 .744 .911 r
.73452 .12375 .73926 .13083 .74974 .12702 .74502 .1199 Metetra
.661 .744 .911 r
.09494 .35043 .1011 .35606 .10939 .35302 .10325 .34737 Metetra
.661 .744 .911 r
.10325 .34737 .10939 .35302 .11771 .34996 .11159 .3443 Metetra
.661 .744 .912 r
.11159 .3443 .11771 .34996 .12606 .3469 .11995 .34122 Metetra
.661 .744 .912 r
.11995 .34122 .12606 .3469 .13444 .34382 .12835 .33813 Metetra
.661 .744 .912 r
.12835 .33813 .13444 .34382 .14285 .34074 .13677 .33503 Metetra
.661 .745 .912 r
.13677 .33503 .14285 .34074 .15128 .33764 .14521 .33192 Metetra
.661 .745 .912 r
.14521 .33192 .15128 .33764 .15974 .33453 .15369 .32881 Metetra
.661 .745 .912 r
.15369 .32881 .15974 .33453 .16823 .33142 .16219 .32567 Metetra
.662 .745 .912 r
.16219 .32567 .16823 .33142 .17674 .3283 .17073 .32253 Metetra
.662 .745 .912 r
.17073 .32253 .17674 .3283 .18529 .32517 .17929 .31937 Metetra
.662 .745 .912 r
.17929 .31937 .18529 .32517 .19386 .32204 .18788 .3162 Metetra
.662 .744 .911 r
.18788 .3162 .19386 .32204 .20246 .3189 .1965 .31302 Metetra
.662 .743 .911 r
.1965 .31302 .20246 .3189 .21109 .31574 .20514 .30982 Metetra
.662 .742 .91 r
.20514 .30982 .21109 .31574 .21975 .31258 .21382 .30661 Metetra
.662 .742 .909 r
.21382 .30661 .21975 .31258 .22843 .3094 .22253 .3034 Metetra
.661 .741 .909 r
.22253 .3034 .22843 .3094 .23715 .30621 .23126 .30018 Metetra
.661 .741 .909 r
.23126 .30018 .23715 .30621 .2459 .30299 .24002 .29696 Metetra
.66 .741 .91 r
.24002 .29696 .2459 .30299 .25467 .29975 .24881 .29374 Metetra
.66 .743 .911 r
.24881 .29374 .25467 .29975 .26348 .29648 .25763 .29052 Metetra
.66 .745 .913 r
.25763 .29052 .26348 .29648 .27232 .29321 .26648 .28729 Metetra
.66 .748 .915 r
.26648 .28729 .27232 .29321 .28119 .28992 .27536 .28405 Metetra
.66 .75 .917 r
.27536 .28405 .28119 .28992 .29009 .28662 .28427 .2808 Metetra
.661 .753 .918 r
.28427 .2808 .29009 .28662 .29901 .28333 .29322 .27753 Metetra
.662 .754 .919 r
.29322 .27753 .29901 .28333 .30797 .28004 .30219 .27422 Metetra
.663 .755 .919 r
.30219 .27422 .30797 .28004 .31695 .27677 .3112 .27088 Metetra
.664 .753 .917 r
.3112 .27088 .31695 .27677 .32596 .27353 .32023 .2675 Metetra
.665 .749 .913 r
.32023 .2675 .32596 .27353 .335 .27031 .32931 .26408 Metetra
.666 .743 .907 r
.32931 .26408 .335 .27031 .34407 .26712 .33841 .26061 Metetra
.666 .734 .901 r
.33841 .26061 .34407 .26712 .35317 .26393 .34755 .25712 Metetra
.665 .724 .893 r
.34755 .25712 .35317 .26393 .36231 .26074 .35671 .25361 Metetra
.664 .714 .886 r
.35671 .25361 .36231 .26074 .37147 .25753 .36591 .25009 Metetra
.662 .704 .879 r
.36591 .25009 .37147 .25753 .38067 .25429 .37514 .24658 Metetra
.66 .696 .873 r
.37514 .24658 .38067 .25429 .3899 .25101 .38439 .24308 Metetra
.657 .689 .868 r
.38439 .24308 .3899 .25101 .39917 .24768 .39368 .23961 Metetra
.655 .685 .866 r
.39368 .23961 .39917 .24768 .40847 .24427 .403 .23617 Metetra
.653 .684 .866 r
.403 .23617 .40847 .24427 .41781 .2408 .41234 .23277 Metetra
.652 .686 .869 r
.41234 .23277 .41781 .2408 .42718 .23726 .42172 .2294 Metetra
.652 .692 .874 r
.42172 .2294 .42718 .23726 .43658 .23368 .43113 .22605 Metetra
.652 .7 .881 r
.43113 .22605 .43658 .23368 .44602 .23006 .44058 .2227 Metetra
.653 .709 .889 r
.44058 .2227 .44602 .23006 .45548 .22643 .45006 .21935 Metetra
.654 .72 .897 r
.45006 .21935 .45548 .22643 .46498 .22278 .45957 .21598 Metetra
.656 .73 .904 r
.45957 .21598 .46498 .22278 .47451 .21915 .46912 .21258 Metetra
.657 .74 .911 r
.46912 .21258 .47451 .21915 .48408 .21553 .4787 .20915 Metetra
.659 .748 .916 r
.4787 .20915 .48408 .21553 .49367 .21194 .48831 .20567 Metetra
.661 .753 .919 r
.48831 .20567 .49367 .21194 .5033 .20837 .49797 .20214 Metetra
.662 .756 .92 r
.49797 .20214 .5033 .20837 .51296 .20483 .50765 .19857 Metetra
.663 .756 .92 r
.50765 .19857 .51296 .20483 .52266 .2013 .51737 .19497 Metetra
.663 .755 .918 r
.51737 .19497 .52266 .2013 .53239 .19777 .52713 .19134 Metetra
.663 .752 .916 r
.52713 .19134 .53239 .19777 .54216 .19423 .53691 .1877 Metetra
.663 .749 .914 r
.53691 .1877 .54216 .19423 .55196 .19069 .54674 .18404 Metetra
.663 .746 .912 r
.54674 .18404 .55196 .19069 .56179 .18712 .5566 .18037 Metetra
.662 .743 .91 r
.5566 .18037 .56179 .18712 .57167 .18353 .56649 .17671 Metetra
.662 .741 .909 r
.56649 .17671 .57167 .18353 .58157 .17991 .57642 .17304 Metetra
.661 .739 .908 r
.57642 .17304 .58157 .17991 .59151 .17626 .58638 .16937 Metetra
.661 .739 .908 r
.58638 .16937 .59151 .17626 .60149 .17259 .59638 .16569 Metetra
.661 .74 .909 r
.59638 .16569 .60149 .17259 .6115 .1689 .60642 .16201 Metetra
.661 .741 .91 r
.60642 .16201 .6115 .1689 .62155 .1652 .6165 .15832 Metetra
.661 .743 .911 r
.6165 .15832 .62155 .1652 .63164 .16148 .62661 .15461 Metetra
.661 .744 .911 r
.62661 .15461 .63164 .16148 .64176 .15775 .63675 .15089 Metetra
.661 .745 .912 r
.63675 .15089 .64176 .15775 .65191 .15402 .64694 .14714 Metetra
.661 .746 .913 r
.64694 .14714 .65191 .15402 .66211 .15027 .65716 .14339 Metetra
.661 .746 .913 r
.65716 .14339 .66211 .15027 .67234 .14652 .66741 .13961 Metetra
.662 .746 .913 r
.66741 .13961 .67234 .14652 .68261 .14276 .67771 .13581 Metetra
.662 .746 .913 r
.67771 .13581 .68261 .14276 .69292 .13899 .68804 .132 Metetra
.662 .745 .912 r
.68804 .132 .69292 .13899 .70326 .1352 .69841 .12817 Metetra
.662 .745 .912 r
.69841 .12817 .70326 .1352 .71364 .1314 .70882 .12434 Metetra
.662 .744 .912 r
.70882 .12434 .71364 .1314 .72406 .12758 .71926 .12048 Metetra
.661 .744 .911 r
.71926 .12048 .72406 .12758 .73452 .12375 .72975 .11662 Metetra
.661 .744 .911 r
.72975 .11662 .73452 .12375 .74502 .1199 .74027 .11274 Metetra
.661 .744 .911 r
.08875 .34477 .09494 .35043 .10325 .34737 .09707 .34169 Metetra
.661 .744 .912 r
.09707 .34169 .10325 .34737 .11159 .3443 .10543 .3386 Metetra
.661 .744 .912 r
.10543 .3386 .11159 .3443 .11995 .34122 .11381 .33551 Metetra
.661 .744 .912 r
.11381 .33551 .11995 .34122 .12835 .33813 .12221 .3324 Metetra
.661 .744 .912 r
.12221 .3324 .12835 .33813 .13677 .33503 .13065 .32929 Metetra
.661 .745 .912 r
.13065 .32929 .13677 .33503 .14521 .33192 .13911 .32617 Metetra
.661 .745 .912 r
.13911 .32617 .14521 .33192 .15369 .32881 .1476 .32303 Metetra
.661 .745 .912 r
.1476 .32303 .15369 .32881 .16219 .32567 .15612 .31988 Metetra
.662 .745 .912 r
.15612 .31988 .16219 .32567 .17073 .32253 .16467 .31671 Metetra
.662 .745 .912 r
.16467 .31671 .17073 .32253 .17929 .31937 .17325 .31353 Metetra
.662 .745 .911 r
.17325 .31353 .17929 .31937 .18788 .3162 .18186 .31032 Metetra
.662 .744 .911 r
.18186 .31032 .18788 .3162 .1965 .31302 .19049 .30711 Metetra
.663 .744 .91 r
.19049 .30711 .1965 .31302 .20514 .30982 .19916 .30388 Metetra
.663 .743 .91 r
.19916 .30388 .20514 .30982 .21382 .30661 .20786 .30063 Metetra
.662 .743 .91 r
.20786 .30063 .21382 .30661 .22253 .3034 .21658 .29739 Metetra
.661 .742 .91 r
.21658 .29739 .22253 .3034 .23126 .30018 .22533 .29415 Metetra
.66 .742 .91 r
.22533 .29415 .23126 .30018 .24002 .29696 .23411 .29092 Metetra
.659 .742 .911 r
.23411 .29092 .24002 .29696 .24881 .29374 .24291 .28771 Metetra
.658 .742 .912 r
.24291 .28771 .24881 .29374 .25763 .29052 .25175 .28452 Metetra
.658 .744 .914 r
.25175 .28452 .25763 .29052 .26648 .28729 .26061 .28132 Metetra
.658 .746 .915 r
.26061 .28132 .26648 .28729 .27536 .28405 .26951 .27811 Metetra
.658 .748 .916 r
.26951 .27811 .27536 .28405 .28427 .2808 .27843 .27488 Metetra
.659 .75 .917 r
.27843 .27488 .28427 .2808 .29322 .27753 .28739 .27161 Metetra
.662 .752 .917 r
.28739 .27161 .29322 .27753 .30219 .27422 .29638 .26829 Metetra
.664 .752 .916 r
.29638 .26829 .30219 .27422 .3112 .27088 .30541 .26489 Metetra
.668 .752 .913 r
.30541 .26489 .3112 .27088 .32023 .2675 .31447 .2614 Metetra
.671 .75 .91 r
.31447 .2614 .32023 .2675 .32931 .26408 .32357 .25782 Metetra
.674 .746 .905 r
.32357 .25782 .32931 .26408 .33841 .26061 .33271 .25416 Metetra
.675 .74 .9 r
.33271 .25416 .33841 .26061 .34755 .25712 .34187 .25044 Metetra
.674 .733 .894 r
.34187 .25044 .34755 .25712 .35671 .25361 .35107 .2467 Metetra
.673 .725 .889 r
.35107 .2467 .35671 .25361 .36591 .25009 .3603 .24295 Metetra
.671 .718 .884 r
.3603 .24295 .36591 .25009 .37514 .24658 .36955 .23923 Metetra
.667 .711 .881 r
.36955 .23923 .37514 .24658 .38439 .24308 .37883 .23557 Metetra
.663 .705 .878 r
.37883 .23557 .38439 .24308 .39368 .23961 .38814 .23199 Metetra
.658 .7 .878 r
.38814 .23199 .39368 .23961 .403 .23617 .39747 .22852 Metetra
.653 .698 .88 r
.39747 .22852 .403 .23617 .41234 .23277 .40683 .22517 Metetra
.649 .699 .883 r
.40683 .22517 .41234 .23277 .42172 .2294 .41622 .22191 Metetra
.646 .702 .887 r
.41622 .22191 .42172 .2294 .43113 .22605 .42565 .21872 Metetra
.645 .708 .893 r
.42565 .21872 .43113 .22605 .44058 .2227 .4351 .21556 Metetra
.645 .715 .898 r
.4351 .21556 .44058 .2227 .45006 .21935 .44459 .2124 Metetra
.646 .722 .904 r
.44459 .2124 .45006 .21935 .45957 .21598 .45412 .20923 Metetra
.648 .73 .909 r
.45412 .20923 .45957 .21598 .46912 .21258 .46368 .206 Metetra
.651 .738 .914 r
.46368 .206 .46912 .21258 .4787 .20915 .47328 .20269 Metetra
.655 .745 .916 r
.47328 .20269 .4787 .20915 .48831 .20567 .48292 .19928 Metetra
.659 .75 .918 r
.48292 .19928 .48831 .20567 .49797 .20214 .49259 .19577 Metetra
.662 .753 .918 r
.49259 .19577 .49797 .20214 .50765 .19857 .5023 .19218 Metetra
.664 .754 .917 r
.5023 .19218 .50765 .19857 .51737 .19497 .51205 .18852 Metetra
.665 .753 .915 r
.51205 .18852 .51737 .19497 .52713 .19134 .52182 .18482 Metetra
.666 .751 .914 r
.52182 .18482 .52713 .19134 .53691 .1877 .53164 .18109 Metetra
.666 .749 .912 r
.53164 .18109 .53691 .1877 .54674 .18404 .54148 .17734 Metetra
.665 .746 .911 r
.54148 .17734 .54674 .18404 .5566 .18037 .55136 .1736 Metetra
.664 .744 .91 r
.55136 .1736 .5566 .18037 .56649 .17671 .56128 .16987 Metetra
.662 .742 .909 r
.56128 .16987 .56649 .17671 .57642 .17304 .57123 .16616 Metetra
.661 .741 .909 r
.57123 .16616 .57642 .17304 .58638 .16937 .58122 .16246 Metetra
.66 .74 .909 r
.58122 .16246 .58638 .16937 .59638 .16569 .59125 .15878 Metetra
.66 .741 .91 r
.59125 .15878 .59638 .16569 .60642 .16201 .60131 .1551 Metetra
.66 .742 .911 r
.60131 .1551 .60642 .16201 .6165 .15832 .61141 .15141 Metetra
.66 .743 .911 r
.61141 .15141 .6165 .15832 .62661 .15461 .62154 .14769 Metetra
.66 .744 .912 r
.62154 .14769 .62661 .15461 .63675 .15089 .63171 .14397 Metetra
.66 .744 .912 r
.63171 .14397 .63675 .15089 .64694 .14714 .64192 .14021 Metetra
.661 .745 .912 r
.64192 .14021 .64694 .14714 .65716 .14339 .65217 .13644 Metetra
.661 .746 .913 r
.65217 .13644 .65716 .14339 .66741 .13961 .66245 .13263 Metetra
.662 .746 .912 r
.66245 .13263 .66741 .13961 .67771 .13581 .67277 .12881 Metetra
.662 .746 .912 r
.67277 .12881 .67771 .13581 .68804 .132 .68313 .12496 Metetra
.662 .745 .912 r
.68313 .12496 .68804 .132 .69841 .12817 .69353 .1211 Metetra
.662 .745 .912 r
.69353 .1211 .69841 .12817 .70882 .12434 .70396 .11722 Metetra
.662 .745 .911 r
.70396 .11722 .70882 .12434 .71926 .12048 .71443 .11334 Metetra
.662 .744 .911 r
.71443 .11334 .71926 .12048 .72975 .11662 .72494 .10944 Metetra
.662 .744 .911 r
.72494 .10944 .72975 .11662 .74027 .11274 .73549 .10554 Metetra
.661 .744 .912 r
.08252 .33907 .08875 .34477 .09707 .34169 .09086 .33598 Metetra
.661 .744 .912 r
.09086 .33598 .09707 .34169 .10543 .3386 .09923 .33287 Metetra
.661 .744 .912 r
.09923 .33287 .10543 .3386 .11381 .33551 .10762 .32976 Metetra
.661 .744 .912 r
.10762 .32976 .11381 .33551 .12221 .3324 .11604 .32664 Metetra
.661 .744 .912 r
.11604 .32664 .12221 .3324 .13065 .32929 .12449 .32351 Metetra
.661 .744 .912 r
.12449 .32351 .13065 .32929 .13911 .32617 .13297 .32037 Metetra
.661 .744 .912 r
.13297 .32037 .13911 .32617 .1476 .32303 .14148 .31722 Metetra
.661 .745 .912 r
.14148 .31722 .1476 .32303 .15612 .31988 .15001 .31405 Metetra
.662 .745 .912 r
.15001 .31405 .15612 .31988 .16467 .31671 .15858 .31086 Metetra
.662 .745 .911 r
.15858 .31086 .16467 .31671 .17325 .31353 .16718 .30764 Metetra
.663 .745 .911 r
.16718 .30764 .17325 .31353 .18186 .31032 .1758 .30442 Metetra
.663 .745 .911 r
.1758 .30442 .18186 .31032 .19049 .30711 .18446 .30117 Metetra
.663 .744 .911 r
.18446 .30117 .19049 .30711 .19916 .30388 .19314 .29791 Metetra
.663 .744 .91 r
.19314 .29791 .19916 .30388 .20786 .30063 .20185 .29464 Metetra
.662 .744 .91 r
.20185 .29464 .20786 .30063 .21658 .29739 .21059 .29137 Metetra
.661 .743 .911 r
.21059 .29137 .21658 .29739 .22533 .29415 .21936 .28811 Metetra
.66 .743 .911 r
.21936 .28811 .22533 .29415 .23411 .29092 .22816 .28487 Metetra
.658 .742 .912 r
.22816 .28487 .23411 .29092 .24291 .28771 .23698 .28166 Metetra
.657 .743 .913 r
.23698 .28166 .24291 .28771 .25175 .28452 .24583 .27846 Metetra
.657 .743 .914 r
.24583 .27846 .25175 .28452 .26061 .28132 .25471 .27527 Metetra
.657 .744 .914 r
.25471 .27527 .26061 .28132 .26951 .27811 .26362 .27206 Metetra
.657 .745 .915 r
.26362 .27206 .26951 .27811 .27843 .27488 .27256 .26883 Metetra
.659 .746 .915 r
.27256 .26883 .27843 .27488 .28739 .27161 .28153 .26556 Metetra
.661 .748 .914 r
.28153 .26556 .28739 .27161 .29638 .26829 .29054 .26222 Metetra
.665 .749 .913 r
.29054 .26222 .29638 .26829 .30541 .26489 .29959 .25878 Metetra
.669 .75 .911 r
.29959 .25878 .30541 .26489 .31447 .2614 .30868 .25523 Metetra
.674 .749 .908 r
.30868 .25523 .31447 .2614 .32357 .25782 .3178 .25156 Metetra
.677 .748 .904 r
.3178 .25156 .32357 .25782 .33271 .25416 .32696 .24779 Metetra
.679 .745 .901 r
.32696 .24779 .33271 .25416 .34187 .25044 .33615 .24395 Metetra
.679 .742 .898 r
.33615 .24395 .34187 .25044 .35107 .2467 .34538 .24008 Metetra
.679 .738 .896 r
.34538 .24008 .35107 .2467 .3603 .24295 .35463 .23621 Metetra
.676 .734 .894 r
.35463 .23621 .3603 .24295 .36955 .23923 .3639 .23238 Metetra
.672 .73 .893 r
.3639 .23238 .36955 .23923 .37883 .23557 .37321 .22862 Metetra
.667 .726 .894 r
.37321 .22862 .37883 .23557 .38814 .23199 .38253 .22498 Metetra
.66 .722 .895 r
.38253 .22498 .38814 .23199 .39747 .22852 .39189 .22149 Metetra
.654 .72 .897 r
.39189 .22149 .39747 .22852 .40683 .22517 .40126 .21815 Metetra
.648 .719 .9 r
.40126 .21815 .40683 .22517 .41622 .22191 .41067 .21494 Metetra
.644 .72 .903 r
.41067 .21494 .41622 .22191 .42565 .21872 .42011 .21181 Metetra
.641 .722 .906 r
.42011 .21181 .42565 .21872 .4351 .21556 .42958 .20873 Metetra
.641 .725 .909 r
.42958 .20873 .4351 .21556 .44459 .2124 .43909 .20566 Metetra
.641 .729 .912 r
.43909 .20566 .44459 .2124 .45412 .20923 .44863 .20256 Metetra
.644 .734 .914 r
.44863 .20256 .45412 .20923 .46368 .206 .45822 .1994 Metetra
.648 .738 .915 r
.45822 .1994 .46368 .206 .47328 .20269 .46784 .19615 Metetra
.653 .743 .916 r
.46784 .19615 .47328 .20269 .48292 .19928 .47749 .19276 Metetra
.658 .746 .915 r
.47749 .19276 .48292 .19928 .49259 .19577 .48719 .18925 Metetra
.662 .748 .914 r
.48719 .18925 .49259 .19577 .5023 .19218 .49692 .18563 Metetra
.665 .749 .913 r
.49692 .18563 .5023 .19218 .51205 .18852 .50669 .18193 Metetra
.666 .749 .912 r
.50669 .18193 .51205 .18852 .52182 .18482 .51649 .17818 Metetra
.667 .749 .911 r
.51649 .17818 .52182 .18482 .53164 .18109 .52632 .17439 Metetra
.667 .748 .911 r
.52632 .17439 .53164 .18109 .54148 .17734 .53619 .17059 Metetra
.666 .746 .91 r
.53619 .17059 .54148 .17734 .55136 .1736 .5461 .1668 Metetra
.665 .745 .91 r
.5461 .1668 .55136 .1736 .56128 .16987 .55604 .16302 Metetra
.663 .743 .91 r
.55604 .16302 .56128 .16987 .57123 .16616 .56601 .15928 Metetra
.661 .743 .91 r
.56601 .15928 .57123 .16616 .58122 .16246 .57603 .15556 Metetra
.66 .742 .911 r
.57603 .15556 .58122 .16246 .59125 .15878 .58607 .15186 Metetra
.659 .742 .911 r
.58607 .15186 .59125 .15878 .60131 .1551 .59616 .14817 Metetra
.659 .742 .912 r
.59616 .14817 .60131 .1551 .61141 .15141 .60628 .14446 Metetra
.659 .743 .912 r
.60628 .14446 .61141 .15141 .62154 .14769 .61644 .14074 Metetra
.66 .743 .912 r
.61644 .14074 .62154 .14769 .63171 .14397 .62664 .13699 Metetra
.66 .744 .912 r
.62664 .13699 .63171 .14397 .64192 .14021 .63688 .13322 Metetra
.661 .745 .912 r
.63688 .13322 .64192 .14021 .65217 .13644 .64715 .12942 Metetra
.661 .745 .912 r
.64715 .12942 .65217 .13644 .66245 .13263 .65746 .12559 Metetra
.662 .745 .912 r
.65746 .12559 .66245 .13263 .67277 .12881 .6678 .12174 Metetra
.662 .745 .912 r
.6678 .12174 .67277 .12881 .68313 .12496 .67819 .11786 Metetra
.662 .745 .912 r
.67819 .11786 .68313 .12496 .69353 .1211 .68861 .11397 Metetra
.662 .745 .911 r
.68861 .11397 .69353 .1211 .70396 .11722 .69907 .11006 Metetra
.662 .745 .911 r
.69907 .11006 .70396 .11722 .71443 .11334 .70957 .10615 Metetra
.662 .744 .911 r
.70957 .10615 .71443 .11334 .72494 .10944 .7201 .10222 Metetra
.662 .744 .911 r
.7201 .10222 .72494 .10944 .73549 .10554 .73068 .09829 Metetra
.661 .744 .912 r
.07625 .33335 .08252 .33907 .09086 .33598 .08461 .33023 Metetra
.661 .744 .912 r
.08461 .33023 .09086 .33598 .09923 .33287 .09299 .32711 Metetra
.661 .744 .912 r
.09299 .32711 .09923 .33287 .10762 .32976 .1014 .32397 Metetra
.661 .744 .912 r
.1014 .32397 .10762 .32976 .11604 .32664 .10984 .32083 Metetra
.661 .744 .912 r
.10984 .32083 .11604 .32664 .12449 .32351 .1183 .31768 Metetra
.661 .744 .912 r
.1183 .31768 .12449 .32351 .13297 .32037 .1268 .31453 Metetra
.661 .744 .912 r
.1268 .31453 .13297 .32037 .14148 .31722 .13532 .31135 Metetra
.661 .744 .912 r
.13532 .31135 .14148 .31722 .15001 .31405 .14387 .30816 Metetra
.662 .744 .911 r
.14387 .30816 .15001 .31405 .15858 .31086 .15245 .30495 Metetra
.662 .744 .911 r
.15245 .30495 .15858 .31086 .16718 .30764 .16106 .30172 Metetra
.663 .745 .911 r
.16106 .30172 .16718 .30764 .1758 .30442 .16971 .29847 Metetra
.663 .745 .911 r
.16971 .29847 .1758 .30442 .18446 .30117 .17838 .29521 Metetra
.663 .745 .911 r
.17838 .29521 .18446 .30117 .19314 .29791 .18708 .29193 Metetra
.663 .745 .911 r
.18708 .29193 .19314 .29791 .20185 .29464 .19581 .28864 Metetra
.663 .745 .911 r
.19581 .28864 .20185 .29464 .21059 .29137 .20457 .28535 Metetra
.662 .744 .911 r
.20457 .28535 .21059 .29137 .21936 .28811 .21335 .28207 Metetra
.66 .744 .912 r
.21335 .28207 .21936 .28811 .22816 .28487 .22216 .27881 Metetra
.658 .743 .913 r
.22216 .27881 .22816 .28487 .23698 .28166 .231 .27557 Metetra
.657 .743 .913 r
.231 .27557 .23698 .28166 .24583 .27846 .23987 .27236 Metetra
.657 .743 .913 r
.23987 .27236 .24583 .27846 .25471 .27527 .24877 .26914 Metetra
.657 .743 .913 r
.24877 .26914 .25471 .27527 .26362 .27206 .25769 .26591 Metetra
.657 .743 .913 r
.25769 .26591 .26362 .27206 .27256 .26883 .26665 .26266 Metetra
.659 .743 .913 r
.26665 .26266 .27256 .26883 .28153 .26556 .27565 .25937 Metetra
.661 .744 .912 r
.27565 .25937 .28153 .26556 .29054 .26222 .28468 .25601 Metetra
.665 .745 .91 r
.28468 .25601 .29054 .26222 .29959 .25878 .29374 .25255 Metetra
.669 .747 .908 r
.29374 .25255 .29959 .25878 .30868 .25523 .30285 .24898 Metetra
.674 .748 .907 r
.30285 .24898 .30868 .25523 .3178 .25156 .31199 .24528 Metetra
.677 .749 .905 r
.31199 .24528 .3178 .25156 .32696 .24779 .32117 .24149 Metetra
.679 .75 .904 r
.32117 .24149 .32696 .24779 .33615 .24395 .33038 .23763 Metetra
.68 .75 .904 r
.33038 .23763 .33615 .24395 .34538 .24008 .33963 .23374 Metetra
.68 .75 .904 r
.33963 .23374 .34538 .24008 .35463 .23621 .3489 .22985 Metetra
.678 .749 .905 r
.3489 .22985 .35463 .23621 .3639 .23238 .3582 .226 Metetra
.674 .748 .906 r
.3582 .226 .3639 .23238 .37321 .22862 .36752 .22222 Metetra
.669 .747 .909 r
.36752 .22222 .37321 .22862 .38253 .22498 .37687 .21856 Metetra
.662 .744 .911 r
.37687 .21856 .38253 .22498 .39189 .22149 .38624 .21504 Metetra
.655 .742 .914 r
.38624 .21504 .39189 .22149 .40126 .21815 .39564 .21168 Metetra
.649 .74 .916 r
.39564 .21168 .40126 .21815 .41067 .21494 .40506 .20844 Metetra
.645 .738 .917 r
.40506 .20844 .41067 .21494 .42011 .21181 .41452 .20529 Metetra
.642 .737 .918 r
.41452 .20529 .42011 .21181 .42958 .20873 .42402 .20219 Metetra
.641 .737 .918 r
.42402 .20219 .42958 .20873 .43909 .20566 .43354 .19909 Metetra
.642 .737 .918 r
.43354 .19909 .43909 .20566 .44863 .20256 .44311 .19597 Metetra
.644 .738 .917 r
.44311 .19597 .44863 .20256 .45822 .1994 .45271 .19279 Metetra
.648 .739 .916 r
.45271 .19279 .45822 .1994 .46784 .19615 .46235 .18951 Metetra
.653 .741 .915 r
.46235 .18951 .46784 .19615 .47749 .19276 .47203 .1861 Metetra
.658 .743 .913 r
.47203 .1861 .47749 .19276 .48719 .18925 .48175 .18256 Metetra
.661 .744 .912 r
.48175 .18256 .48719 .18925 .49692 .18563 .4915 .17892 Metetra
.664 .745 .91 r
.4915 .17892 .49692 .18563 .50669 .18193 .50129 .1752 Metetra
.666 .746 .91 r
.50129 .1752 .50669 .18193 .51649 .17818 .51112 .17142 Metetra
.667 .746 .91 r
.51112 .17142 .51649 .17818 .52632 .17439 .52097 .16761 Metetra
.667 .746 .91 r
.52097 .16761 .52632 .17439 .53619 .17059 .53087 .16379 Metetra
.666 .746 .91 r
.53087 .16379 .53619 .17059 .5461 .1668 .5408 .15997 Metetra
.665 .746 .91 r
.5408 .15997 .5461 .1668 .55604 .16302 .55076 .15617 Metetra
.663 .745 .911 r
.55076 .15617 .55604 .16302 .56601 .15928 .56076 .1524 Metetra
.661 .744 .912 r
.56076 .1524 .56601 .15928 .57603 .15556 .5708 .14866 Metetra
.66 .744 .912 r
.5708 .14866 .57603 .15556 .58607 .15186 .58087 .14494 Metetra
.659 .743 .912 r
.58087 .14494 .58607 .15186 .59616 .14817 .59098 .14122 Metetra
.659 .743 .912 r
.59098 .14122 .59616 .14817 .60628 .14446 .60113 .13748 Metetra
.659 .743 .912 r
.60113 .13748 .60628 .14446 .61644 .14074 .61131 .13373 Metetra
.66 .744 .912 r
.61131 .13373 .61644 .14074 .62664 .13699 .62153 .12996 Metetra
.66 .744 .912 r
.62153 .12996 .62664 .13699 .63688 .13322 .63179 .12617 Metetra
.661 .744 .912 r
.63179 .12617 .63688 .13322 .64715 .12942 .64209 .12234 Metetra
.661 .744 .912 r
.64209 .12234 .64715 .12942 .65746 .12559 .65243 .11849 Metetra
.662 .744 .911 r
.65243 .11849 .65746 .12559 .6678 .12174 .6628 .11461 Metetra
.662 .745 .911 r
.6628 .11461 .6678 .12174 .67819 .11786 .67321 .1107 Metetra
.662 .745 .911 r
.67321 .1107 .67819 .11786 .68861 .11397 .68366 .10678 Metetra
.662 .745 .911 r
.68366 .10678 .68861 .11397 .69907 .11006 .69414 .10285 Metetra
.662 .744 .911 r
.69414 .10285 .69907 .11006 .70957 .10615 .70467 .09891 Metetra
.662 .744 .911 r
.70467 .09891 .70957 .10615 .7201 .10222 .71523 .09496 Metetra
.662 .744 .911 r
.71523 .09496 .7201 .10222 .73068 .09829 .72584 .091 Metetra
.661 .744 .912 r
.06994 .32758 .07625 .33335 .08461 .33023 .07831 .32445 Metetra
.661 .744 .912 r
.07831 .32445 .08461 .33023 .09299 .32711 .08671 .32131 Metetra
.661 .744 .912 r
.08671 .32131 .09299 .32711 .1014 .32397 .09514 .31815 Metetra
.661 .744 .912 r
.09514 .31815 .1014 .32397 .10984 .32083 .10359 .31499 Metetra
.661 .744 .912 r
.10359 .31499 .10984 .32083 .1183 .31768 .11207 .31182 Metetra
.661 .744 .912 r
.11207 .31182 .1183 .31768 .1268 .31453 .12058 .30864 Metetra
.661 .744 .911 r
.12058 .30864 .1268 .31453 .13532 .31135 .12912 .30545 Metetra
.661 .744 .911 r
.12912 .30545 .13532 .31135 .14387 .30816 .13769 .30224 Metetra
.662 .744 .911 r
.13769 .30224 .14387 .30816 .15245 .30495 .14629 .29901 Metetra
.662 .744 .911 r
.14629 .29901 .15245 .30495 .16106 .30172 .15492 .29576 Metetra
.662 .744 .911 r
.15492 .29576 .16106 .30172 .16971 .29847 .16357 .2925 Metetra
.662 .745 .911 r
.16357 .2925 .16971 .29847 .17838 .29521 .17226 .28922 Metetra
.663 .745 .911 r
.17226 .28922 .17838 .29521 .18708 .29193 .18098 .28593 Metetra
.663 .745 .911 r
.18098 .28593 .18708 .29193 .19581 .28864 .18972 .28262 Metetra
.662 .745 .912 r
.18972 .28262 .19581 .28864 .20457 .28535 .1985 .27932 Metetra
.662 .745 .912 r
.1985 .27932 .20457 .28535 .21335 .28207 .2073 .27602 Metetra
.66 .745 .913 r
.2073 .27602 .21335 .28207 .22216 .27881 .21613 .27273 Metetra
.659 .744 .913 r
.21613 .27273 .22216 .27881 .231 .27557 .22499 .26946 Metetra
.658 .744 .913 r
.22499 .26946 .231 .27557 .23987 .27236 .23388 .26621 Metetra
.657 .743 .913 r
.23388 .26621 .23987 .27236 .24877 .26914 .24279 .26295 Metetra
.657 .742 .912 r
.24279 .26295 .24877 .26914 .25769 .26591 .25174 .25968 Metetra
.658 .741 .912 r
.25174 .25968 .25769 .26591 .26665 .26266 .26072 .25639 Metetra
.659 .741 .911 r
.26072 .25639 .26665 .26266 .27565 .25937 .26973 .25307 Metetra
.661 .741 .91 r
.26973 .25307 .27565 .25937 .28468 .25601 .27878 .24968 Metetra
.664 .742 .908 r
.27878 .24968 .28468 .25601 .29374 .25255 .28786 .24621 Metetra
.668 .744 .907 r
.28786 .24621 .29374 .25255 .30285 .24898 .29698 .24265 Metetra
.671 .746 .907 r
.29698 .24265 .30285 .24898 .31199 .24528 .30614 .23899 Metetra
.674 .749 .907 r
.30614 .23899 .31199 .24528 .32117 .24149 .31534 .23525 Metetra
.676 .752 .908 r
.31534 .23525 .32117 .24149 .33038 .23763 .32456 .23145 Metetra
.677 .755 .91 r
.32456 .23145 .33038 .23763 .33963 .23374 .33382 .22762 Metetra
.677 .758 .912 r
.33382 .22762 .33963 .23374 .3489 .22985 .34311 .22379 Metetra
.676 .761 .915 r
.34311 .22379 .3489 .22985 .3582 .226 .35243 .21999 Metetra
.673 .763 .918 r
.35243 .21999 .3582 .226 .36752 .22222 .36177 .21625 Metetra
.669 .764 .921 r
.36177 .21625 .36752 .22222 .37687 .21856 .37114 .2126 Metetra
.663 .763 .924 r
.37114 .2126 .37687 .21856 .38624 .21504 .38053 .20906 Metetra
.657 .761 .927 r
.38053 .20906 .38624 .21504 .39564 .21168 .38995 .20565 Metetra
.652 .758 .928 r
.38995 .20565 .39564 .21168 .40506 .20844 .3994 .20233 Metetra
.648 .755 .928 r
.3994 .20233 .40506 .20844 .41452 .20529 .40889 .19908 Metetra
.645 .752 .926 r
.40889 .19908 .41452 .20529 .42402 .20219 .4184 .19588 Metetra
.645 .748 .924 r
.4184 .19588 .42402 .20219 .43354 .19909 .42795 .19267 Metetra
.645 .745 .922 r
.42795 .19267 .43354 .19909 .44311 .19597 .43754 .18944 Metetra
.647 .743 .919 r
.43754 .18944 .44311 .19597 .45271 .19279 .44717 .18616 Metetra
.65 .741 .916 r
.44717 .18616 .45271 .19279 .46235 .18951 .45683 .18279 Metetra
.654 .74 .913 r
.45683 .18279 .46235 .18951 .47203 .1861 .46654 .17932 Metetra
.658 .741 .911 r
.46654 .17932 .47203 .1861 .48175 .18256 .47628 .17575 Metetra
.661 .741 .909 r
.47628 .17575 .48175 .18256 .4915 .17892 .48605 .17208 Metetra
.664 .742 .908 r
.48605 .17208 .4915 .17892 .50129 .1752 .49586 .16835 Metetra
.665 .743 .908 r
.49586 .16835 .50129 .1752 .51112 .17142 .50571 .16457 Metetra
.666 .744 .909 r
.50571 .16457 .51112 .17142 .52097 .16761 .51559 .16076 Metetra
.666 .745 .909 r
.51559 .16076 .52097 .16761 .53087 .16379 .52551 .15694 Metetra
.665 .745 .91 r
.52551 .15694 .53087 .16379 .5408 .15997 .53546 .15311 Metetra
.664 .746 .911 r
.53546 .15311 .5408 .15997 .55076 .15617 .54545 .1493 Metetra
.663 .746 .912 r
.54545 .1493 .55076 .15617 .56076 .1524 .55547 .14552 Metetra
.661 .746 .913 r
.55547 .14552 .56076 .1524 .5708 .14866 .56553 .14175 Metetra
.66 .745 .913 r
.56553 .14175 .5708 .14866 .58087 .14494 .57563 .13799 Metetra
.66 .745 .913 r
.57563 .13799 .58087 .14494 .59098 .14122 .58576 .13424 Metetra
.66 .744 .913 r
.58576 .13424 .59098 .14122 .60113 .13748 .59594 .13047 Metetra
.66 .744 .912 r
.59594 .13047 .60113 .13748 .61131 .13373 .60615 .12668 Metetra
.66 .744 .912 r
.60615 .12668 .61131 .13373 .62153 .12996 .61639 .12288 Metetra
.66 .744 .912 r
.61639 .12288 .62153 .12996 .63179 .12617 .62668 .11905 Metetra
.661 .744 .911 r
.62668 .11905 .63179 .12617 .64209 .12234 .637 .1152 Metetra
.661 .744 .911 r
.637 .1152 .64209 .12234 .65243 .11849 .64736 .11132 Metetra
.662 .744 .911 r
.64736 .11132 .65243 .11849 .6628 .11461 .65776 .10741 Metetra
.662 .744 .911 r
.65776 .10741 .6628 .11461 .67321 .1107 .66819 .10349 Metetra
.662 .744 .911 r
.66819 .10349 .67321 .1107 .68366 .10678 .67867 .09954 Metetra
.662 .744 .911 r
.67867 .09954 .68366 .10678 .69414 .10285 .68918 .09559 Metetra
.662 .744 .911 r
.68918 .09559 .69414 .10285 .70467 .09891 .69974 .09162 Metetra
.662 .744 .911 r
.69974 .09162 .70467 .09891 .71523 .09496 .71033 .08765 Metetra
.662 .744 .912 r
.71033 .08765 .71523 .09496 .72584 .091 .72096 .08366 Metetra
.661 .744 .912 r
.0636 .32179 .06994 .32758 .07831 .32445 .07198 .31863 Metetra
.661 .744 .912 r
.07198 .31863 .07831 .32445 .08671 .32131 .0804 .31547 Metetra
.661 .744 .912 r
.0804 .31547 .08671 .32131 .09514 .31815 .08884 .3123 Metetra
.661 .744 .912 r
.08884 .3123 .09514 .31815 .10359 .31499 .09731 .30911 Metetra
.661 .744 .912 r
.09731 .30911 .10359 .31499 .11207 .31182 .10581 .30592 Metetra
.661 .744 .911 r
.10581 .30592 .11207 .31182 .12058 .30864 .11433 .30272 Metetra
.661 .744 .911 r
.11433 .30272 .12058 .30864 .12912 .30545 .12289 .2995 Metetra
.661 .744 .911 r
.12289 .2995 .12912 .30545 .13769 .30224 .13147 .29627 Metetra
.662 .744 .911 r
.13147 .29627 .13769 .30224 .14629 .29901 .14008 .29303 Metetra
.662 .744 .911 r
.14008 .29303 .14629 .29901 .15492 .29576 .14873 .28976 Metetra
.662 .744 .911 r
.14873 .28976 .15492 .29576 .16357 .2925 .1574 .28649 Metetra
.662 .745 .911 r
.1574 .28649 .16357 .2925 .17226 .28922 .1661 .2832 Metetra
.662 .745 .912 r
.1661 .2832 .17226 .28922 .18098 .28593 .17484 .27989 Metetra
.662 .745 .912 r
.17484 .27989 .18098 .28593 .18972 .28262 .1836 .27658 Metetra
.662 .746 .912 r
.1836 .27658 .18972 .28262 .1985 .27932 .19239 .27326 Metetra
.662 .746 .913 r
.19239 .27326 .1985 .27932 .2073 .27602 .20121 .26994 Metetra
.661 .746 .913 r
.20121 .26994 .2073 .27602 .21613 .27273 .21006 .26662 Metetra
.66 .745 .913 r
.21006 .26662 .21613 .27273 .22499 .26946 .21894 .26331 Metetra
.659 .744 .913 r
.21894 .26331 .22499 .26946 .23388 .26621 .22784 .26001 Metetra
.659 .743 .912 r
.22784 .26001 .23388 .26621 .24279 .26295 .23678 .2567 Metetra
.659 .742 .911 r
.23678 .2567 .24279 .26295 .25174 .25968 .24575 .25338 Metetra
.659 .741 .91 r
.24575 .25338 .25174 .25968 .26072 .25639 .25475 .25004 Metetra
.66 .74 .909 r
.25475 .25004 .26072 .25639 .26973 .25307 .26378 .24668 Metetra
.661 .74 .908 r
.26378 .24668 .26973 .25307 .27878 .24968 .27285 .24327 Metetra
.663 .74 .908 r
.27285 .24327 .27878 .24968 .28786 .24621 .28195 .2398 Metetra
.665 .742 .907 r
.28195 .2398 .28786 .24621 .29698 .24265 .29108 .23627 Metetra
.668 .745 .908 r
.29108 .23627 .29698 .24265 .30614 .23899 .30026 .23268 Metetra
.67 .748 .909 r
.30026 .23268 .30614 .23899 .31534 .23525 .30946 .22902 Metetra
.671 .753 .912 r
.30946 .22902 .31534 .23525 .32456 .23145 .3187 .22533 Metetra
.672 .757 .915 r
.3187 .22533 .32456 .23145 .33382 .22762 .32797 .22161 Metetra
.672 .762 .918 r
.32797 .22161 .33382 .22762 .34311 .22379 .33727 .21789 Metetra
.671 .767 .922 r
.33727 .21789 .34311 .22379 .35243 .21999 .34661 .21417 Metetra
.669 .77 .926 r
.34661 .21417 .35243 .21999 .36177 .21625 .35597 .2105 Metetra
.666 .773 .929 r
.35597 .2105 .36177 .21625 .37114 .2126 .36535 .20687 Metetra
.663 .774 .932 r
.36535 .20687 .37114 .2126 .38053 .20906 .37477 .20332 Metetra
.659 .773 .933 r
.37477 .20332 .38053 .20906 .38995 .20565 .38422 .19984 Metetra
.655 .77 .933 r
.38422 .19984 .38995 .20565 .3994 .20233 .39369 .19642 Metetra
.653 .766 .932 r
.39369 .19642 .3994 .20233 .40889 .19908 .4032 .19304 Metetra
.652 .761 .93 r
.4032 .19304 .40889 .19908 .4184 .19588 .41275 .18967 Metetra
.651 .756 .926 r
.41275 .18967 .4184 .19588 .42795 .19267 .42233 .18631 Metetra
.651 .751 .923 r
.42233 .18631 .42795 .19267 .43754 .18944 .43194 .18292 Metetra
.653 .747 .919 r
.43194 .18292 .43754 .18944 .44717 .18616 .44159 .1795 Metetra
.654 .743 .915 r
.44159 .1795 .44717 .18616 .45683 .18279 .45128 .17601 Metetra
.657 .741 .912 r
.45128 .17601 .45683 .18279 .46654 .17932 .461 .17246 Metetra
.659 .739 .909 r
.461 .17246 .46654 .17932 .47628 .17575 .47077 .16883 Metetra
.661 .739 .908 r
.47077 .16883 .47628 .17575 .48605 .17208 .48056 .16514 Metetra
.663 .74 .907 r
.48056 .16514 .48605 .17208 .49586 .16835 .4904 .16141 Metetra
.664 .741 .908 r
.4904 .16141 .49586 .16835 .50571 .16457 .50027 .15763 Metetra
.664 .742 .908 r
.50027 .15763 .50571 .16457 .51559 .16076 .51017 .15384 Metetra
.664 .744 .909 r
.51017 .15384 .51559 .16076 .52551 .15694 .52011 .15003 Metetra
.664 .745 .91 r
.52011 .15003 .52551 .15694 .53546 .15311 .53009 .14622 Metetra
.663 .746 .912 r
.53009 .14622 .53546 .15311 .54545 .1493 .5401 .14241 Metetra
.662 .746 .913 r
.5401 .14241 .54545 .1493 .55547 .14552 .55015 .13861 Metetra
.661 .746 .913 r
.55015 .13861 .55547 .14552 .56553 .14175 .56023 .13481 Metetra
.661 .746 .913 r
.56023 .13481 .56553 .14175 .57563 .13799 .57035 .13102 Metetra
.66 .746 .913 r
.57035 .13102 .57563 .13799 .58576 .13424 .58051 .12723 Metetra
.66 .745 .913 r
.58051 .12723 .58576 .13424 .59594 .13047 .59071 .12342 Metetra
.66 .744 .912 r
.59071 .12342 .59594 .13047 .60615 .12668 .60094 .11959 Metetra
.66 .744 .912 r
.60094 .11959 .60615 .12668 .61639 .12288 .61122 .11575 Metetra
.661 .744 .912 r
.61122 .11575 .61639 .12288 .62668 .11905 .62153 .11188 Metetra
.661 .743 .911 r
.62153 .11188 .62668 .11905 .637 .1152 .63187 .108 Metetra
.661 .743 .911 r
.63187 .108 .637 .1152 .64736 .11132 .64226 .10409 Metetra
.662 .744 .911 r
.64226 .10409 .64736 .11132 .65776 .10741 .65268 .10016 Metetra
.662 .744 .911 r
.65268 .10016 .65776 .10741 .66819 .10349 .66315 .09621 Metetra
.662 .744 .911 r
.66315 .09621 .66819 .10349 .67867 .09954 .67365 .09225 Metetra
.662 .744 .911 r
.67365 .09225 .67867 .09954 .68918 .09559 .68419 .08828 Metetra
.662 .744 .911 r
.68419 .08828 .68918 .09559 .69974 .09162 .69477 .08429 Metetra
.662 .744 .912 r
.69477 .08429 .69974 .09162 .71033 .08765 .70539 .08029 Metetra
.662 .744 .912 r
.70539 .08029 .71033 .08765 .72096 .08366 .71605 .07627 Metetra
.661 .744 .912 r
.05721 .31596 .0636 .32179 .07198 .31863 .06561 .31278 Metetra
.661 .744 .912 r
.06561 .31278 .07198 .31863 .0804 .31547 .07404 .3096 Metetra
.661 .744 .912 r
.07404 .3096 .0804 .31547 .08884 .3123 .0825 .3064 Metetra
.661 .744 .912 r
.0825 .3064 .08884 .3123 .09731 .30911 .09099 .3032 Metetra
.661 .744 .912 r
.09099 .3032 .09731 .30911 .10581 .30592 .0995 .29998 Metetra
.661 .744 .911 r
.0995 .29998 .10581 .30592 .11433 .30272 .10804 .29676 Metetra
.661 .744 .911 r
.10804 .29676 .11433 .30272 .12289 .2995 .11661 .29352 Metetra
.661 .744 .911 r
.11661 .29352 .12289 .2995 .13147 .29627 .12521 .29027 Metetra
.661 .744 .911 r
.12521 .29027 .13147 .29627 .14008 .29303 .13384 .28701 Metetra
.662 .744 .911 r
.13384 .28701 .14008 .29303 .14873 .28976 .1425 .28373 Metetra
.662 .744 .911 r
.1425 .28373 .14873 .28976 .1574 .28649 .15119 .28044 Metetra
.662 .744 .911 r
.15119 .28044 .1574 .28649 .1661 .2832 .15991 .27714 Metetra
.662 .745 .912 r
.15991 .27714 .1661 .2832 .17484 .27989 .16866 .27382 Metetra
.662 .745 .912 r
.16866 .27382 .17484 .27989 .1836 .27658 .17744 .2705 Metetra
.662 .745 .912 r
.17744 .2705 .1836 .27658 .19239 .27326 .18625 .26716 Metetra
.661 .746 .913 r
.18625 .26716 .19239 .27326 .20121 .26994 .19508 .26382 Metetra
.661 .746 .913 r
.19508 .26382 .20121 .26994 .21006 .26662 .20395 .26048 Metetra
.661 .745 .913 r
.20395 .26048 .21006 .26662 .21894 .26331 .21285 .25713 Metetra
.66 .744 .912 r
.21285 .25713 .21894 .26331 .22784 .26001 .22177 .25378 Metetra
.66 .743 .912 r
.22177 .25378 .22784 .26001 .23678 .2567 .23073 .25042 Metetra
.66 .742 .911 r
.23073 .25042 .23678 .2567 .24575 .25338 .23972 .24705 Metetra
.66 .741 .91 r
.23972 .24705 .24575 .25338 .25475 .25004 .24874 .24366 Metetra
.66 .741 .909 r
.24874 .24366 .25475 .25004 .26378 .24668 .25779 .24025 Metetra
.661 .74 .909 r
.25779 .24025 .26378 .24668 .27285 .24327 .26688 .23682 Metetra
.662 .74 .908 r
.26688 .23682 .27285 .24327 .28195 .2398 .27599 .23336 Metetra
.663 .741 .908 r
.27599 .23336 .28195 .2398 .29108 .23627 .28515 .22986 Metetra
.664 .744 .909 r
.28515 .22986 .29108 .23627 .30026 .23268 .29433 .22632 Metetra
.665 .747 .911 r
.29433 .22632 .30026 .23268 .30946 .22902 .30355 .22274 Metetra
.666 .751 .913 r
.30355 .22274 .30946 .22902 .3187 .22533 .3128 .21915 Metetra
.667 .755 .916 r
.3128 .21915 .3187 .22533 .32797 .22161 .32208 .21553 Metetra
.667 .76 .92 r
.32208 .21553 .32797 .22161 .33727 .21789 .3314 .21191 Metetra
.666 .764 .923 r
.3314 .21191 .33727 .21789 .34661 .21417 .34075 .20828 Metetra
.666 .768 .926 r
.34075 .20828 .34661 .21417 .35597 .2105 .35012 .20467 Metetra
.664 .771 .929 r
.35012 .20467 .35597 .2105 .36535 .20687 .35953 .20107 Metetra
.662 .772 .931 r
.35953 .20107 .36535 .20687 .37477 .20332 .36897 .1975 Metetra
.661 .771 .932 r
.36897 .1975 .37477 .20332 .38422 .19984 .37844 .19395 Metetra
.659 .769 .931 r
.37844 .19395 .38422 .19984 .39369 .19642 .38795 .19043 Metetra
.658 .766 .929 r
.38795 .19043 .39369 .19642 .4032 .19304 .39748 .18691 Metetra
.657 .762 .927 r
.39748 .18691 .4032 .19304 .41275 .18967 .40705 .1834 Metetra
.657 .757 .924 r
.40705 .1834 .41275 .18967 .42233 .18631 .41666 .17988 Metetra
.657 .752 .92 r
.41666 .17988 .42233 .18631 .43194 .18292 .4263 .17635 Metetra
.657 .748 .917 r
.4263 .17635 .43194 .18292 .44159 .1795 .43598 .17279 Metetra
.658 .744 .914 r
.43598 .17279 .44159 .1795 .45128 .17601 .44569 .16919 Metetra
.659 .742 .911 r
.44569 .16919 .45128 .17601 .461 .17246 .45544 .16556 Metetra
.66 .74 .909 r
.45544 .16556 .461 .17246 .47077 .16883 .46522 .16188 Metetra
.661 .739 .908 r
.46522 .16188 .47077 .16883 .48056 .16514 .47504 .15817 Metetra
.662 .74 .908 r
.47504 .15817 .48056 .16514 .4904 .16141 .4849 .15443 Metetra
.662 .741 .908 r
.4849 .15443 .4904 .16141 .50027 .15763 .49479 .15066 Metetra
.662 .742 .909 r
.49479 .15066 .50027 .15763 .51017 .15384 .50472 .14688 Metetra
.663 .743 .91 r
.50472 .14688 .51017 .15384 .52011 .15003 .51468 .14308 Metetra
.663 .744 .911 r
.51468 .14308 .52011 .15003 .53009 .14622 .52468 .13927 Metetra
.662 .745 .912 r
.52468 .13927 .53009 .14622 .5401 .14241 .53471 .13546 Metetra
.662 .746 .913 r
.53471 .13546 .5401 .14241 .55015 .13861 .54479 .13165 Metetra
.661 .746 .913 r
.54479 .13165 .55015 .13861 .56023 .13481 .5549 .12783 Metetra
.661 .746 .913 r
.5549 .12783 .56023 .13481 .57035 .13102 .56504 .124 Metetra
.661 .746 .913 r
.56504 .124 .57035 .13102 .58051 .12723 .57523 .12016 Metetra
.661 .745 .913 r
.57523 .12016 .58051 .12723 .59071 .12342 .58545 .11631 Metetra
.661 .745 .912 r
.58545 .11631 .59071 .12342 .60094 .11959 .59571 .11245 Metetra
.661 .744 .912 r
.59571 .11245 .60094 .11959 .61122 .11575 .606 .10857 Metetra
.661 .744 .911 r
.606 .10857 .61122 .11575 .62153 .11188 .61634 .10467 Metetra
.661 .744 .911 r
.61634 .10467 .62153 .11188 .63187 .108 .62671 .10075 Metetra
.661 .743 .911 r
.62671 .10075 .63187 .108 .64226 .10409 .63712 .09682 Metetra
.661 .744 .911 r
.63712 .09682 .64226 .10409 .65268 .10016 .64757 .09286 Metetra
.662 .744 .911 r
.64757 .09286 .65268 .10016 .66315 .09621 .65806 .08889 Metetra
.662 .744 .911 r
.65806 .08889 .66315 .09621 .67365 .09225 .66859 .08491 Metetra
.662 .744 .911 r
.66859 .08491 .67365 .09225 .68419 .08828 .67916 .08091 Metetra
.662 .744 .911 r
.67916 .08091 .68419 .08828 .69477 .08429 .68977 .0769 Metetra
.661 .744 .912 r
.68977 .0769 .69477 .08429 .70539 .08029 .70042 .07287 Metetra
.661 .744 .912 r
.70042 .07287 .70539 .08029 .71605 .07627 .7111 .06883 Metetra
.661 .744 .912 r
.05079 .31009 .05721 .31596 .06561 .31278 .0592 .30689 Metetra
.661 .744 .912 r
.0592 .30689 .06561 .31278 .07404 .3096 .06765 .30369 Metetra
.661 .744 .912 r
.06765 .30369 .07404 .3096 .0825 .3064 .07612 .30047 Metetra
.661 .744 .912 r
.07612 .30047 .0825 .3064 .09099 .3032 .08462 .29725 Metetra
.661 .744 .911 r
.08462 .29725 .09099 .3032 .0995 .29998 .09315 .29401 Metetra
.661 .744 .911 r
.09315 .29401 .0995 .29998 .10804 .29676 .10171 .29076 Metetra
.661 .744 .911 r
.10171 .29076 .10804 .29676 .11661 .29352 .1103 .2875 Metetra
.661 .744 .911 r
.1103 .2875 .11661 .29352 .12521 .29027 .11892 .28423 Metetra
.661 .744 .911 r
.11892 .28423 .12521 .29027 .13384 .28701 .12756 .28095 Metetra
.661 .744 .911 r
.12756 .28095 .13384 .28701 .1425 .28373 .13624 .27766 Metetra
.661 .744 .911 r
.13624 .27766 .1425 .28373 .15119 .28044 .14494 .27435 Metetra
.661 .744 .912 r
.14494 .27435 .15119 .28044 .15991 .27714 .15368 .27103 Metetra
.661 .745 .912 r
.15368 .27103 .15991 .27714 .16866 .27382 .16244 .2677 Metetra
.661 .745 .912 r
.16244 .2677 .16866 .27382 .17744 .2705 .17124 .26436 Metetra
.661 .745 .912 r
.17124 .26436 .17744 .2705 .18625 .26716 .18006 .26101 Metetra
.661 .745 .912 r
.18006 .26101 .18625 .26716 .19508 .26382 .18892 .25765 Metetra
.661 .745 .912 r
.18892 .25765 .19508 .26382 .20395 .26048 .1978 .25428 Metetra
.661 .745 .912 r
.1978 .25428 .20395 .26048 .21285 .25713 .20672 .2509 Metetra
.661 .745 .912 r
.20672 .2509 .21285 .25713 .22177 .25378 .21566 .24751 Metetra
.661 .744 .911 r
.21566 .24751 .22177 .25378 .23073 .25042 .22464 .24411 Metetra
.661 .743 .911 r
.22464 .24411 .23073 .25042 .23972 .24705 .23365 .24069 Metetra
.661 .742 .91 r
.23365 .24069 .23972 .24705 .24874 .24366 .24269 .23727 Metetra
.661 .742 .91 r
.24269 .23727 .24874 .24366 .25779 .24025 .25176 .23383 Metetra
.661 .741 .909 r
.25176 .23383 .25779 .24025 .26688 .23682 .26086 .23037 Metetra
.661 .741 .909 r
.26086 .23037 .26688 .23682 .27599 .23336 .27 .2269 Metetra
.662 .742 .91 r
.27 .2269 .27599 .23336 .28515 .22986 .27917 .22341 Metetra
.662 .743 .91 r
.27917 .22341 .28515 .22986 .29433 .22632 .28837 .2199 Metetra
.662 .745 .912 r
.28837 .2199 .29433 .22632 .30355 .22274 .2976 .21638 Metetra
.663 .748 .914 r
.2976 .21638 .30355 .22274 .3128 .21915 .30687 .21284 Metetra
.663 .751 .916 r
.30687 .21284 .3128 .21915 .32208 .21553 .31616 .20929 Metetra
.663 .754 .918 r
.31616 .20929 .32208 .21553 .3314 .21191 .32549 .20573 Metetra
.663 .757 .92 r
.32549 .20573 .3314 .21191 .34075 .20828 .33486 .20216 Metetra
.663 .76 .922 r
.33486 .20216 .34075 .20828 .35012 .20467 .34425 .19858 Metetra
.663 .762 .924 r
.34425 .19858 .35012 .20467 .35953 .20107 .35368 .19499 Metetra
.662 .763 .925 r
.35368 .19499 .35953 .20107 .36897 .1975 .36314 .1914 Metetra
.662 .763 .925 r
.36314 .1914 .36897 .1975 .37844 .19395 .37264 .1878 Metetra
.662 .762 .924 r
.37264 .1878 .37844 .19395 .38795 .19043 .38217 .1842 Metetra
.661 .76 .923 r
.38217 .1842 .38795 .19043 .39748 .18691 .39173 .18059 Metetra
.661 .757 .921 r
.39173 .18059 .39748 .18691 .40705 .1834 .40133 .17696 Metetra
.661 .754 .919 r
.40133 .17696 .40705 .1834 .41666 .17988 .41096 .17333 Metetra
.661 .751 .917 r
.41096 .17333 .41666 .17988 .4263 .17635 .42062 .16968 Metetra
.661 .748 .914 r
.42062 .16968 .4263 .17635 .43598 .17279 .43032 .16602 Metetra
.661 .745 .912 r
.43032 .16602 .43598 .17279 .44569 .16919 .44006 .16234 Metetra
.661 .743 .911 r
.44006 .16234 .44569 .16919 .45544 .16556 .44983 .15864 Metetra
.661 .741 .91 r
.44983 .15864 .45544 .16556 .46522 .16188 .45964 .15492 Metetra
.661 .741 .909 r
.45964 .15492 .46522 .16188 .47504 .15817 .46948 .15119 Metetra
.661 .741 .909 r
.46948 .15119 .47504 .15817 .4849 .15443 .47936 .14744 Metetra
.661 .742 .909 r
.47936 .14744 .4849 .15443 .49479 .15066 .48927 .14367 Metetra
.662 .742 .91 r
.48927 .14367 .49479 .15066 .50472 .14688 .49922 .13988 Metetra
.662 .743 .911 r
.49922 .13988 .50472 .14688 .51468 .14308 .50921 .13609 Metetra
.662 .744 .911 r
.50921 .13609 .51468 .14308 .52468 .13927 .51923 .13228 Metetra
.662 .745 .912 r
.51923 .13228 .52468 .13927 .53471 .13546 .52929 .12845 Metetra
.662 .745 .912 r
.52929 .12845 .53471 .13546 .54479 .13165 .53939 .12462 Metetra
.661 .746 .913 r
.53939 .12462 .54479 .13165 .5549 .12783 .54952 .12077 Metetra
.661 .746 .913 r
.54952 .12077 .5549 .12783 .56504 .124 .55969 .11691 Metetra
.661 .745 .912 r
.55969 .11691 .56504 .124 .57523 .12016 .5699 .11304 Metetra
.661 .745 .912 r
.5699 .11304 .57523 .12016 .58545 .11631 .58015 .10916 Metetra
.661 .745 .912 r
.58015 .10916 .58545 .11631 .59571 .11245 .59043 .10525 Metetra
.661 .744 .912 r
.59043 .10525 .59571 .11245 .606 .10857 .60076 .10134 Metetra
.661 .744 .911 r
.60076 .10134 .606 .10857 .61634 .10467 .61112 .09741 Metetra
.661 .744 .911 r
.61112 .09741 .61634 .10467 .62671 .10075 .62152 .09346 Metetra
.661 .744 .911 r
.62152 .09346 .62671 .10075 .63712 .09682 .63195 .0895 Metetra
.661 .744 .911 r
.63195 .0895 .63712 .09682 .64757 .09286 .64243 .08552 Metetra
.661 .744 .911 r
.64243 .08552 .64757 .09286 .65806 .08889 .65295 .08153 Metetra
.661 .744 .911 r
.65295 .08153 .65806 .08889 .66859 .08491 .6635 .07752 Metetra
.661 .744 .911 r
.6635 .07752 .66859 .08491 .67916 .08091 .6741 .0735 Metetra
.661 .744 .911 r
.6741 .0735 .67916 .08091 .68977 .0769 .68473 .06946 Metetra
.661 .744 .912 r
.68473 .06946 .68977 .0769 .70042 .07287 .69541 .06541 Metetra
.661 .744 .912 r
.69541 .06541 .70042 .07287 .7111 .06883 .70612 .06134 Metetra
.661 .744 .912 r
.04433 .30418 .05079 .31009 .0592 .30689 .05276 .30097 Metetra
.661 .744 .912 r
.05276 .30097 .0592 .30689 .06765 .30369 .06122 .29774 Metetra
.661 .744 .912 r
.06122 .29774 .06765 .30369 .07612 .30047 .0697 .29451 Metetra
.661 .744 .912 r
.0697 .29451 .07612 .30047 .08462 .29725 .07822 .29126 Metetra
.661 .744 .911 r
.07822 .29126 .08462 .29725 .09315 .29401 .08677 .288 Metetra
.661 .744 .911 r
.08677 .288 .09315 .29401 .10171 .29076 .09534 .28473 Metetra
.661 .744 .911 r
.09534 .28473 .10171 .29076 .1103 .2875 .10395 .28145 Metetra
.661 .744 .911 r
.10395 .28145 .1103 .2875 .11892 .28423 .11258 .27816 Metetra
.661 .744 .911 r
.11258 .27816 .11892 .28423 .12756 .28095 .12124 .27486 Metetra
.661 .744 .911 r
.12124 .27486 .12756 .28095 .13624 .27766 .12993 .27155 Metetra
.661 .744 .912 r
.12993 .27155 .13624 .27766 .14494 .27435 .13865 .26822 Metetra
.661 .744 .912 r
.13865 .26822 .14494 .27435 .15368 .27103 .14741 .26489 Metetra
.661 .744 .912 r
.14741 .26489 .15368 .27103 .16244 .2677 .15619 .26154 Metetra
.661 .745 .912 r
.15619 .26154 .16244 .2677 .17124 .26436 .165 .25819 Metetra
.661 .745 .912 r
.165 .25819 .17124 .26436 .18006 .26101 .17384 .25482 Metetra
.661 .745 .912 r
.17384 .25482 .18006 .26101 .18892 .25765 .18271 .25143 Metetra
.662 .745 .912 r
.18271 .25143 .18892 .25765 .1978 .25428 .19162 .24804 Metetra
.662 .745 .912 r
.19162 .24804 .1978 .25428 .20672 .2509 .20055 .24463 Metetra
.662 .745 .912 r
.20055 .24463 .20672 .2509 .21566 .24751 .20952 .2412 Metetra
.662 .744 .911 r
.20952 .2412 .21566 .24751 .22464 .24411 .21851 .23777 Metetra
.662 .744 .911 r
.21851 .23777 .22464 .24411 .23365 .24069 .22754 .23432 Metetra
.662 .743 .911 r
.22754 .23432 .23365 .24069 .24269 .23727 .2366 .23086 Metetra
.661 .743 .91 r
.2366 .23086 .24269 .23727 .25176 .23383 .24569 .22739 Metetra
.661 .742 .91 r
.24569 .22739 .25176 .23383 .26086 .23037 .25481 .22391 Metetra
.661 .742 .91 r
.25481 .22391 .26086 .23037 .27 .2269 .26397 .22042 Metetra
.661 .743 .911 r
.26397 .22042 .27 .2269 .27917 .22341 .27315 .21693 Metetra
.66 .743 .911 r
.27315 .21693 .27917 .22341 .28837 .2199 .28237 .21344 Metetra
.66 .744 .912 r
.28237 .21344 .28837 .2199 .2976 .21638 .29162 .20994 Metetra
.66 .746 .914 r
.29162 .20994 .2976 .21638 .30687 .21284 .3009 .20643 Metetra
.66 .748 .915 r
.3009 .20643 .30687 .21284 .31616 .20929 .31021 .20292 Metetra
.66 .75 .916 r
.31021 .20292 .31616 .20929 .32549 .20573 .31956 .19938 Metetra
.661 .752 .918 r
.31956 .19938 .32549 .20573 .33486 .20216 .32894 .19584 Metetra
.661 .754 .919 r
.32894 .19584 .33486 .20216 .34425 .19858 .33835 .19227 Metetra
.661 .755 .92 r
.33835 .19227 .34425 .19858 .35368 .19499 .3478 .18868 Metetra
.662 .756 .92 r
.3478 .18868 .35368 .19499 .36314 .1914 .35729 .18506 Metetra
.662 .756 .92 r
.35729 .18506 .36314 .1914 .37264 .1878 .3668 .18143 Metetra
.663 .756 .919 r
.3668 .18143 .37264 .1878 .38217 .1842 .37636 .17776 Metetra
.663 .755 .918 r
.37636 .17776 .38217 .1842 .39173 .18059 .38594 .17408 Metetra
.663 .753 .917 r
.38594 .17408 .39173 .18059 .40133 .17696 .39556 .17038 Metetra
.663 .751 .916 r
.39556 .17038 .40133 .17696 .41096 .17333 .40522 .16667 Metetra
.663 .749 .914 r
.40522 .16667 .41096 .17333 .42062 .16968 .41491 .16294 Metetra
.663 .747 .913 r
.41491 .16294 .42062 .16968 .43032 .16602 .42463 .1592 Metetra
.662 .745 .912 r
.42463 .1592 .43032 .16602 .44006 .16234 .43439 .15546 Metetra
.662 .744 .911 r
.43439 .15546 .44006 .16234 .44983 .15864 .44419 .15171 Metetra
.662 .743 .91 r
.44419 .15171 .44983 .15864 .45964 .15492 .45402 .14796 Metetra
.661 .742 .91 r
.45402 .14796 .45964 .15492 .46948 .15119 .46388 .1442 Metetra
.661 .742 .91 r
.46388 .1442 .46948 .15119 .47936 .14744 .47378 .14043 Metetra
.661 .742 .91 r
.47378 .14043 .47936 .14744 .48927 .14367 .48372 .13665 Metetra
.661 .743 .911 r
.48372 .13665 .48927 .14367 .49922 .13988 .49369 .13285 Metetra
.661 .743 .911 r
.49369 .13285 .49922 .13988 .50921 .13609 .5037 .12905 Metetra
.661 .744 .912 r
.5037 .12905 .50921 .13609 .51923 .13228 .51375 .12523 Metetra
.661 .745 .912 r
.51375 .12523 .51923 .13228 .52929 .12845 .52383 .12139 Metetra
.661 .745 .912 r
.52383 .12139 .52929 .12845 .53939 .12462 .53396 .11753 Metetra
.661 .745 .912 r
.53396 .11753 .53939 .12462 .54952 .12077 .54411 .11366 Metetra
.662 .745 .912 r
.54411 .11366 .54952 .12077 .55969 .11691 .55431 .10977 Metetra
.662 .745 .912 r
.55431 .10977 .55969 .11691 .5699 .11304 .56454 .10586 Metetra
.662 .745 .912 r
.56454 .10586 .5699 .11304 .58015 .10916 .57481 .10194 Metetra
.662 .745 .912 r
.57481 .10194 .58015 .10916 .59043 .10525 .58512 .09801 Metetra
.662 .744 .912 r
.58512 .09801 .59043 .10525 .60076 .10134 .59547 .09406 Metetra
.661 .744 .911 r
.59547 .09406 .60076 .10134 .61112 .09741 .60586 .0901 Metetra
.661 .744 .911 r
.60586 .0901 .61112 .09741 .62152 .09346 .61628 .08612 Metetra
.661 .744 .911 r
.61628 .08612 .62152 .09346 .63195 .0895 .62675 .08214 Metetra
.661 .744 .911 r
.62675 .08214 .63195 .0895 .64243 .08552 .63725 .07813 Metetra
.661 .744 .911 r
.63725 .07813 .64243 .08552 .65295 .08153 .64779 .07411 Metetra
.661 .744 .911 r
.64779 .07411 .65295 .08153 .6635 .07752 .65838 .07008 Metetra
.661 .744 .911 r
.65838 .07008 .6635 .07752 .6741 .0735 .669 .06603 Metetra
.661 .744 .912 r
.669 .06603 .6741 .0735 .68473 .06946 .67966 .06197 Metetra
.661 .744 .912 r
.67966 .06197 .68473 .06946 .69541 .06541 .69037 .05789 Metetra
.661 .744 .912 r
.69037 .05789 .69541 .06541 .70612 .06134 .70111 .05379 Metetra
.661 .744 .912 r
.03782 .29824 .04433 .30418 .05276 .30097 .04627 .29501 Metetra
.661 .744 .912 r
.04627 .29501 .05276 .30097 .06122 .29774 .05474 .29176 Metetra
.661 .744 .912 r
.05474 .29176 .06122 .29774 .0697 .29451 .06325 .2885 Metetra
.661 .744 .912 r
.06325 .2885 .0697 .29451 .07822 .29126 .07178 .28524 Metetra
.661 .744 .911 r
.07178 .28524 .07822 .29126 .08677 .288 .08034 .28196 Metetra
.661 .744 .911 r
.08034 .28196 .08677 .288 .09534 .28473 .08893 .27866 Metetra
.661 .744 .911 r
.08893 .27866 .09534 .28473 .10395 .28145 .09755 .27536 Metetra
.661 .744 .911 r
.09755 .27536 .10395 .28145 .11258 .27816 .1062 .27205 Metetra
.661 .744 .911 r
.1062 .27205 .11258 .27816 .12124 .27486 .11488 .26873 Metetra
.661 .744 .912 r
.11488 .26873 .12124 .27486 .12993 .27155 .12359 .2654 Metetra
.661 .744 .912 r
.12359 .2654 .12993 .27155 .13865 .26822 .13233 .26205 Metetra
.661 .744 .912 r
.13233 .26205 .13865 .26822 .14741 .26489 .14109 .2587 Metetra
.661 .744 .912 r
.14109 .2587 .14741 .26489 .15619 .26154 .14989 .25534 Metetra
.661 .744 .912 r
.14989 .25534 .15619 .26154 .165 .25819 .15872 .25196 Metetra
.661 .745 .912 r
.15872 .25196 .165 .25819 .17384 .25482 .16758 .24857 Metetra
.661 .745 .912 r
.16758 .24857 .17384 .25482 .18271 .25143 .17647 .24517 Metetra
.662 .745 .912 r
.17647 .24517 .18271 .25143 .19162 .24804 .18539 .24175 Metetra
.662 .745 .912 r
.18539 .24175 .19162 .24804 .20055 .24463 .19434 .23831 Metetra
.662 .745 .911 r
.19434 .23831 .20055 .24463 .20952 .2412 .20333 .23486 Metetra
.662 .744 .911 r
.20333 .23486 .20952 .2412 .21851 .23777 .21234 .23139 Metetra
.662 .744 .911 r
.21234 .23139 .21851 .23777 .22754 .23432 .22139 .22791 Metetra
.662 .744 .911 r
.22139 .22791 .22754 .23432 .2366 .23086 .23047 .22442 Metetra
.662 .743 .911 r
.23047 .22442 .2366 .23086 .24569 .22739 .23958 .22092 Metetra
.661 .743 .911 r
.23958 .22092 .24569 .22739 .25481 .22391 .24872 .21742 Metetra
.661 .743 .911 r
.24872 .21742 .25481 .22391 .26397 .22042 .25789 .21392 Metetra
.66 .743 .911 r
.25789 .21392 .26397 .22042 .27315 .21693 .26709 .21042 Metetra
.659 .743 .912 r
.26709 .21042 .27315 .21693 .28237 .21344 .27633 .20693 Metetra
.659 .744 .913 r
.27633 .20693 .28237 .21344 .29162 .20994 .28559 .20344 Metetra
.659 .745 .914 r
.28559 .20344 .29162 .20994 .3009 .20643 .29489 .19994 Metetra
.659 .746 .914 r
.29489 .19994 .3009 .20643 .31021 .20292 .30422 .19643 Metetra
.659 .747 .915 r
.30422 .19643 .31021 .20292 .31956 .19938 .31359 .19291 Metetra
.659 .748 .916 r
.31359 .19291 .31956 .19938 .32894 .19584 .32299 .18936 Metetra
.66 .75 .916 r
.32299 .18936 .32894 .19584 .33835 .19227 .33242 .18579 Metetra
.661 .751 .917 r
.33242 .18579 .33835 .19227 .3478 .18868 .34189 .18219 Metetra
.662 .751 .917 r
.34189 .18219 .3478 .18868 .35729 .18506 .3514 .17856 Metetra
.663 .752 .916 r
.3514 .17856 .35729 .18506 .3668 .18143 .36094 .17488 Metetra
.664 .752 .916 r
.36094 .17488 .3668 .18143 .37636 .17776 .37051 .17118 Metetra
.664 .751 .915 r
.37051 .17118 .37636 .17776 .38594 .17408 .38012 .16744 Metetra
.664 .75 .914 r
.38012 .16744 .38594 .17408 .39556 .17038 .38977 .16368 Metetra
.665 .749 .913 r
.38977 .16368 .39556 .17038 .40522 .16667 .39944 .15991 Metetra
.664 .748 .912 r
.39944 .15991 .40522 .16667 .41491 .16294 .40916 .15613 Metetra
.664 .747 .912 r
.40916 .15613 .41491 .16294 .42463 .1592 .41891 .15233 Metetra
.663 .745 .911 r
.41891 .15233 .42463 .1592 .43439 .15546 .42869 .14854 Metetra
.663 .744 .911 r
.42869 .14854 .43439 .15546 .44419 .15171 .43851 .14475 Metetra
.662 .743 .911 r
.43851 .14475 .44419 .15171 .45402 .14796 .44836 .14097 Metetra
.661 .743 .911 r
.44836 .14097 .45402 .14796 .46388 .1442 .45825 .13718 Metetra
.661 .743 .911 r
.45825 .13718 .46388 .1442 .47378 .14043 .46817 .13339 Metetra
.661 .743 .911 r
.46817 .13339 .47378 .14043 .48372 .13665 .47813 .12959 Metetra
.661 .743 .911 r
.47813 .12959 .48372 .13665 .49369 .13285 .48813 .12579 Metetra
.661 .744 .911 r
.48813 .12579 .49369 .13285 .5037 .12905 .49816 .12196 Metetra
.661 .744 .912 r
.49816 .12196 .5037 .12905 .51375 .12523 .50823 .11812 Metetra
.661 .744 .912 r
.50823 .11812 .51375 .12523 .52383 .12139 .51834 .11427 Metetra
.661 .745 .912 r
.51834 .11427 .52383 .12139 .53396 .11753 .52848 .11039 Metetra
.661 .745 .912 r
.52848 .11039 .53396 .11753 .54411 .11366 .53867 .10649 Metetra
.662 .745 .912 r
.53867 .10649 .54411 .11366 .55431 .10977 .54889 .10257 Metetra
.662 .745 .912 r
.54889 .10257 .55431 .10977 .56454 .10586 .55915 .09863 Metetra
.662 .745 .912 r
.55915 .09863 .56454 .10586 .57481 .10194 .56944 .09468 Metetra
.662 .745 .912 r
.56944 .09468 .57481 .10194 .58512 .09801 .57978 .09072 Metetra
.662 .744 .911 r
.57978 .09072 .58512 .09801 .59547 .09406 .59015 .08674 Metetra
.662 .744 .911 r
.59015 .08674 .59547 .09406 .60586 .0901 .60056 .08275 Metetra
.661 .744 .911 r
.60056 .08275 .60586 .0901 .61628 .08612 .61101 .07874 Metetra
.661 .744 .911 r
.61101 .07874 .61628 .08612 .62675 .08214 .62151 .07473 Metetra
.661 .744 .911 r
.62151 .07473 .62675 .08214 .63725 .07813 .63204 .07069 Metetra
.661 .744 .911 r
.63204 .07069 .63725 .07813 .64779 .07411 .64261 .06665 Metetra
.661 .744 .911 r
.64261 .06665 .64779 .07411 .65838 .07008 .65322 .06259 Metetra
.661 .744 .912 r
.65322 .06259 .65838 .07008 .669 .06603 .66387 .05852 Metetra
.661 .744 .912 r
.66387 .05852 .669 .06603 .67966 .06197 .67456 .05442 Metetra
.661 .744 .912 r
.67456 .05442 .67966 .06197 .69037 .05789 .68529 .05032 Metetra
.661 .744 .912 r
.68529 .05032 .69037 .05789 .70111 .05379 .69606 .04619 Metetra
.661 .744 .912 r
.03128 .29226 .03782 .29824 .04627 .29501 .03974 .28901 Metetra
.661 .744 .912 r
.03974 .28901 .04627 .29501 .05474 .29176 .04823 .28574 Metetra
.661 .744 .912 r
.04823 .28574 .05474 .29176 .06325 .2885 .05675 .28246 Metetra
.661 .744 .912 r
.05675 .28246 .06325 .2885 .07178 .28524 .0653 .27917 Metetra
.661 .744 .911 r
.0653 .27917 .07178 .28524 .08034 .28196 .07388 .27587 Metetra
.661 .744 .911 r
.07388 .27587 .08034 .28196 .08893 .27866 .08248 .27256 Metetra
.661 .744 .911 r
.08248 .27256 .08893 .27866 .09755 .27536 .09112 .26924 Metetra
.661 .744 .912 r
.09112 .26924 .09755 .27536 .1062 .27205 .09978 .26591 Metetra
.661 .744 .912 r
.09978 .26591 .1062 .27205 .11488 .26873 .10848 .26256 Metetra
.661 .744 .912 r
.10848 .26256 .11488 .26873 .12359 .2654 .1172 .25921 Metetra
.661 .744 .912 r
.1172 .25921 .12359 .2654 .13233 .26205 .12596 .25585 Metetra
.661 .744 .912 r
.12596 .25585 .13233 .26205 .14109 .2587 .13474 .25247 Metetra
.661 .744 .912 r
.13474 .25247 .14109 .2587 .14989 .25534 .14356 .24909 Metetra
.661 .744 .912 r
.14356 .24909 .14989 .25534 .15872 .25196 .1524 .24569 Metetra
.661 .744 .912 r
.1524 .24569 .15872 .25196 .16758 .24857 .16128 .24228 Metetra
.661 .744 .912 r
.16128 .24228 .16758 .24857 .17647 .24517 .17019 .23886 Metetra
.662 .744 .912 r
.17019 .23886 .17647 .24517 .18539 .24175 .17913 .23542 Metetra
.662 .745 .911 r
.17913 .23542 .18539 .24175 .19434 .23831 .1881 .23195 Metetra
.662 .745 .911 r
.1881 .23195 .19434 .23831 .20333 .23486 .1971 .22848 Metetra
.662 .744 .911 r
.1971 .22848 .20333 .23486 .21234 .23139 .20613 .22498 Metetra
.662 .744 .911 r
.20613 .22498 .21234 .23139 .22139 .22791 .2152 .22148 Metetra
.662 .744 .911 r
.2152 .22148 .22139 .22791 .23047 .22442 .2243 .21796 Metetra
.662 .744 .911 r
.2243 .21796 .23047 .22442 .23958 .22092 .23342 .21444 Metetra
.661 .744 .911 r
.23342 .21444 .23958 .22092 .24872 .21742 .24258 .21092 Metetra
.661 .744 .911 r
.24258 .21092 .24872 .21742 .25789 .21392 .25177 .2074 Metetra
.66 .743 .912 r
.25177 .2074 .25789 .21392 .26709 .21042 .261 .20388 Metetra
.659 .743 .912 r
.261 .20388 .26709 .21042 .27633 .20693 .27025 .20037 Metetra
.658 .743 .913 r
.27025 .20037 .27633 .20693 .28559 .20344 .27953 .19686 Metetra
.658 .744 .913 r
.27953 .19686 .28559 .20344 .29489 .19994 .28885 .19335 Metetra
.658 .744 .914 r
.28885 .19335 .29489 .19994 .30422 .19643 .2982 .18984 Metetra
.658 .745 .914 r
.2982 .18984 .30422 .19643 .31359 .19291 .30759 .1863 Metetra
.658 .745 .914 r
.30759 .1863 .31359 .19291 .32299 .18936 .317 .18275 Metetra
.659 .746 .914 r
.317 .18275 .32299 .18936 .33242 .18579 .32646 .17916 Metetra
.66 .747 .914 r
.32646 .17916 .33242 .18579 .34189 .18219 .33595 .17555 Metetra
.661 .747 .914 r
.33595 .17555 .34189 .18219 .3514 .17856 .34547 .17189 Metetra
.663 .748 .913 r
.34547 .17189 .3514 .17856 .36094 .17488 .35504 .16818 Metetra
.664 .748 .913 r
.35504 .16818 .36094 .17488 .37051 .17118 .36463 .16444 Metetra
.664 .748 .912 r
.36463 .16444 .37051 .17118 .38012 .16744 .37426 .16067 Metetra
.665 .747 .912 r
.37426 .16067 .38012 .16744 .38977 .16368 .38393 .15688 Metetra
.665 .747 .911 r
.38393 .15688 .38977 .16368 .39944 .15991 .39363 .15306 Metetra
.665 .746 .911 r
.39363 .15306 .39944 .15991 .40916 .15613 .40337 .14924 Metetra
.664 .746 .911 r
.40337 .14924 .40916 .15613 .41891 .15233 .41314 .14541 Metetra
.664 .745 .911 r
.41314 .14541 .41891 .15233 .42869 .14854 .42295 .14159 Metetra
.663 .745 .911 r
.42295 .14159 .42869 .14854 .43851 .14475 .43279 .13777 Metetra
.662 .744 .911 r
.43279 .13777 .43851 .14475 .44836 .14097 .44266 .13395 Metetra
.661 .744 .911 r
.44266 .13395 .44836 .14097 .45825 .13718 .45257 .13014 Metetra
.661 .744 .911 r
.45257 .13014 .45825 .13718 .46817 .13339 .46252 .12633 Metetra
.661 .744 .912 r
.46252 .12633 .46817 .13339 .47813 .12959 .4725 .12251 Metetra
.66 .744 .912 r
.4725 .12251 .47813 .12959 .48813 .12579 .48252 .11868 Metetra
.66 .744 .912 r
.48252 .11868 .48813 .12579 .49816 .12196 .49258 .11483 Metetra
.661 .744 .912 r
.49258 .11483 .49816 .12196 .50823 .11812 .50267 .11097 Metetra
.661 .744 .912 r
.50267 .11097 .50823 .11812 .51834 .11427 .51281 .10709 Metetra
.661 .744 .912 r
.51281 .10709 .51834 .11427 .52848 .11039 .52298 .10318 Metetra
.661 .744 .912 r
.52298 .10318 .52848 .11039 .53867 .10649 .53318 .09926 Metetra
.662 .745 .912 r
.53318 .09926 .53867 .10649 .54889 .10257 .54343 .09531 Metetra
.662 .745 .912 r
.54343 .09531 .54889 .10257 .55915 .09863 .55371 .09135 Metetra
.662 .745 .911 r
.55371 .09135 .55915 .09863 .56944 .09468 .56403 .08737 Metetra
.662 .744 .911 r
.56403 .08737 .56944 .09468 .57978 .09072 .57439 .08337 Metetra
.662 .744 .911 r
.57439 .08337 .57978 .09072 .59015 .08674 .58479 .07937 Metetra
.662 .744 .911 r
.58479 .07937 .59015 .08674 .60056 .08275 .59523 .07534 Metetra
.661 .744 .911 r
.59523 .07534 .60056 .08275 .61101 .07874 .60571 .07131 Metetra
.661 .744 .911 r
.60571 .07131 .61101 .07874 .62151 .07473 .61623 .06727 Metetra
.661 .744 .912 r
.61623 .06727 .62151 .07473 .63204 .07069 .62678 .06321 Metetra
.661 .744 .912 r
.62678 .06321 .63204 .07069 .64261 .06665 .63738 .05914 Metetra
.661 .744 .912 r
.63738 .05914 .64261 .06665 .65322 .06259 .64802 .05505 Metetra
.661 .744 .912 r
.64802 .05505 .65322 .06259 .66387 .05852 .6587 .05095 Metetra
.661 .744 .912 r
.6587 .05095 .66387 .05852 .67456 .05442 .66941 .04683 Metetra
.661 .744 .912 r
.66941 .04683 .67456 .05442 .68529 .05032 .68017 .04269 Metetra
.661 .744 .912 r
.68017 .04269 .68529 .05032 .69606 .04619 .69097 .03854 Metetra
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "For biorthogonal filters, ",
  StyleBox["ScalingFunction", "MR"],
  " and ",
  StyleBox["Wavelet", "MR"],
  " give the \"original\" (as opposed to the \"dual\") ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", respectively. To get dual functions, we need to exchange the roles of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", that is, reverse the filter to ",
  Cell[BoxData[
      \(TraditionalForm\`{\(h\&~\), h}\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.25"}],

Cell[TextData[{
  "This gives the biorthogonal spline filter of order ",
  Cell[BoxData[
      \(TraditionalForm\`{3, 3}\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.26"}],

Cell["b33 = BiorthogonalSplineFilter[3, 3];", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S3.1.2"],

Cell["We use the numerical approximation to the filter.", "MathCaption",
  CellTags->{"S3.1.2", "2.27"}],

Cell[CellGroupData[{

Cell["b33 = MapAt[N, #, {1}]& /@ b33", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S3.1.2"],

Cell[BoxData[
    \({{{0.0662912607362388417`, \(-0.198873782208716516`\), 
          \(-0.154679608384557276`\), 0.994368911043582492`, 
          0.994368911043582492`, \(-0.154679608384557276`\), 
          \(-0.198873782208716516`\), 0.0662912607362388417`}, 
        \(-3\)}, {{0.176776695296636887`, 0.530330085889910662`, 
          0.530330085889910662`, 0.176776695296636887`}, \(-1\)}}\)], "Output",\

  CellLabel->"Out[31]= ",
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is the \"original\" scaling function. We could also have obtained the \
same result by just using ",
  StyleBox["b33[[1]]", "MR"],
  " (the filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ") instead of ",
  StyleBox["b33", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.28"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[b33, 7],
PlotJoined -> True, PlotRange -> All,
PlotLabel -> \"phi_33(t)\"]\
\>", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.431973 0.136054 0.244222 0.105748 [
[.02381 .23172 -6 -9 ]
[.02381 .23172 6 0 ]
[.15986 .23172 -6 -9 ]
[.15986 .23172 6 0 ]
[.29592 .23172 -6 -9 ]
[.29592 .23172 6 0 ]
[.56803 .23172 -3 -9 ]
[.56803 .23172 3 0 ]
[.70408 .23172 -3 -9 ]
[.70408 .23172 3 0 ]
[.84014 .23172 -3 -9 ]
[.84014 .23172 3 0 ]
[.97619 .23172 -3 -9 ]
[.97619 .23172 3 0 ]
[.41947 .03273 -12 -4.5 ]
[.41947 .03273 0 4.5 ]
[.41947 .13847 -12 -4.5 ]
[.41947 .13847 0 4.5 ]
[.41947 .34997 -6 -4.5 ]
[.41947 .34997 0 4.5 ]
[.41947 .45572 -6 -4.5 ]
[.41947 .45572 0 4.5 ]
[.41947 .56146 -6 -4.5 ]
[.41947 .56146 0 4.5 ]
[.5 .63053 -27 0 ]
[.5 .63053 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24422 m
.02381 .25047 L
s
[(-3)] .02381 .23172 0 1 Mshowa
.15986 .24422 m
.15986 .25047 L
s
[(-2)] .15986 .23172 0 1 Mshowa
.29592 .24422 m
.29592 .25047 L
s
[(-1)] .29592 .23172 0 1 Mshowa
.56803 .24422 m
.56803 .25047 L
s
[(1)] .56803 .23172 0 1 Mshowa
.70408 .24422 m
.70408 .25047 L
s
[(2)] .70408 .23172 0 1 Mshowa
.84014 .24422 m
.84014 .25047 L
s
[(3)] .84014 .23172 0 1 Mshowa
.97619 .24422 m
.97619 .25047 L
s
[(4)] .97619 .23172 0 1 Mshowa
.125 Mabswid
.05102 .24422 m
.05102 .24797 L
s
.07823 .24422 m
.07823 .24797 L
s
.10544 .24422 m
.10544 .24797 L
s
.13265 .24422 m
.13265 .24797 L
s
.18707 .24422 m
.18707 .24797 L
s
.21429 .24422 m
.21429 .24797 L
s
.2415 .24422 m
.2415 .24797 L
s
.26871 .24422 m
.26871 .24797 L
s
.32313 .24422 m
.32313 .24797 L
s
.35034 .24422 m
.35034 .24797 L
s
.37755 .24422 m
.37755 .24797 L
s
.40476 .24422 m
.40476 .24797 L
s
.45918 .24422 m
.45918 .24797 L
s
.48639 .24422 m
.48639 .24797 L
s
.51361 .24422 m
.51361 .24797 L
s
.54082 .24422 m
.54082 .24797 L
s
.59524 .24422 m
.59524 .24797 L
s
.62245 .24422 m
.62245 .24797 L
s
.64966 .24422 m
.64966 .24797 L
s
.67687 .24422 m
.67687 .24797 L
s
.73129 .24422 m
.73129 .24797 L
s
.7585 .24422 m
.7585 .24797 L
s
.78571 .24422 m
.78571 .24797 L
s
.81293 .24422 m
.81293 .24797 L
s
.86735 .24422 m
.86735 .24797 L
s
.89456 .24422 m
.89456 .24797 L
s
.92177 .24422 m
.92177 .24797 L
s
.94898 .24422 m
.94898 .24797 L
s
.25 Mabswid
0 .24422 m
1 .24422 L
s
.43197 .03273 m
.43822 .03273 L
s
[(-2)] .41947 .03273 1 0 Mshowa
.43197 .13847 m
.43822 .13847 L
s
[(-1)] .41947 .13847 1 0 Mshowa
.43197 .34997 m
.43822 .34997 L
s
[(1)] .41947 .34997 1 0 Mshowa
.43197 .45572 m
.43822 .45572 L
s
[(2)] .41947 .45572 1 0 Mshowa
.43197 .56146 m
.43822 .56146 L
s
[(3)] .41947 .56146 1 0 Mshowa
.125 Mabswid
.43197 .05388 m
.43572 .05388 L
s
.43197 .07503 m
.43572 .07503 L
s
.43197 .09617 m
.43572 .09617 L
s
.43197 .11732 m
.43572 .11732 L
s
.43197 .15962 m
.43572 .15962 L
s
.43197 .18077 m
.43572 .18077 L
s
.43197 .20192 m
.43572 .20192 L
s
.43197 .22307 m
.43572 .22307 L
s
.43197 .26537 m
.43572 .26537 L
s
.43197 .28652 m
.43572 .28652 L
s
.43197 .30767 m
.43572 .30767 L
s
.43197 .32882 m
.43572 .32882 L
s
.43197 .37112 m
.43572 .37112 L
s
.43197 .39227 m
.43572 .39227 L
s
.43197 .41342 m
.43572 .41342 L
s
.43197 .43457 m
.43572 .43457 L
s
.43197 .47687 m
.43572 .47687 L
s
.43197 .49802 m
.43572 .49802 L
s
.43197 .51917 m
.43572 .51917 L
s
.43197 .54032 m
.43572 .54032 L
s
.43197 .01158 m
.43572 .01158 L
s
.43197 .58261 m
.43572 .58261 L
s
.43197 .60376 m
.43572 .60376 L
s
.25 Mabswid
.43197 0 m
.43197 .61803 L
s
[(phi_33\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .24422 m
.02487 .24422 L
.02594 .24422 L
.027 .24422 L
.02806 .24422 L
.02912 .24422 L
.03019 .24422 L
.03125 .24422 L
.03231 .24422 L
.03338 .24422 L
.03444 .24422 L
.0355 .24422 L
.03656 .24422 L
.03763 .24422 L
.03869 .24422 L
.03975 .24422 L
.04082 .24422 L
.04188 .24422 L
.04294 .24422 L
.04401 .24423 L
.04507 .24422 L
.04613 .24421 L
.04719 .24421 L
.04826 .2442 L
.04932 .24423 L
.05038 .24426 L
.05145 .24425 L
.05251 .24424 L
.05357 .24424 L
.05463 .24424 L
.0557 .24425 L
.05676 .24426 L
.05782 .24421 L
.05889 .24418 L
.05995 .24417 L
.06101 .24415 L
.06207 .24421 L
.06314 .24427 L
.0642 .24426 L
.06526 .24428 L
.06633 .24416 L
.06739 .24402 L
.06845 .24409 L
.06952 .24415 L
.07058 .24408 L
.07164 .24405 L
.0727 .24403 L
.07377 .24397 L
.07483 .24431 L
.07589 .24463 L
Mistroke
.07696 .24459 L
.07802 .24459 L
.07908 .2445 L
.08014 .24437 L
.08121 .24443 L
.08227 .24447 L
.08333 .24446 L
.0844 .24448 L
.08546 .2444 L
.08652 .24429 L
.08759 .24448 L
.08865 .24461 L
.08971 .24458 L
.09077 .24462 L
.09184 .24415 L
.0929 .24363 L
.09396 .2438 L
.09503 .24396 L
.09609 .24367 L
.09715 .24353 L
.09821 .24342 L
.09928 .24321 L
.10034 .24412 L
.1014 .24507 L
.10247 .24472 L
.10353 .24441 L
.10459 .24466 L
.10565 .24461 L
.10672 .24481 L
.10778 .24514 L
.10884 .24354 L
.10991 .24206 L
.11097 .24212 L
.11203 .24196 L
.1131 .24282 L
.11416 .24376 L
.11522 .24351 L
.11628 .24347 L
.11735 .24268 L
.11841 .24166 L
.11947 .24242 L
.12054 .24327 L
.1216 .24217 L
.12266 .24165 L
.12372 .24157 L
.12479 .24109 L
.12585 .24511 L
.12691 .24918 L
.12798 .24856 L
.12904 .24831 L
Mistroke
.1301 .24818 L
.13116 .24736 L
.13223 .2482 L
.13329 .24908 L
.13435 .24719 L
.13542 .24546 L
.13648 .24576 L
.13754 .24579 L
.13861 .24642 L
.13967 .24726 L
.14073 .24686 L
.14179 .24655 L
.14286 .24672 L
.14392 .24665 L
.14498 .24696 L
.14605 .24741 L
.14711 .24612 L
.14817 .24511 L
.14923 .245 L
.1503 .24452 L
.15136 .24696 L
.15242 .24964 L
.15349 .24833 L
.15455 .24709 L
.15561 .24808 L
.15668 .24806 L
.15774 .24846 L
.1588 .24935 L
.15986 .24343 L
.16093 .2378 L
.16199 .23788 L
.16305 .23719 L
.16412 .2397 L
.16518 .24258 L
.16624 .2414 L
.1673 .24091 L
.16837 .23829 L
.16943 .23496 L
.17049 .23689 L
.17156 .23902 L
.17262 .23572 L
.17368 .23413 L
.17474 .23345 L
.17581 .2316 L
.17687 .24313 L
.17793 .25437 L
.179 .25329 L
.18006 .25363 L
.18112 .24948 L
.18219 .24419 L
Mistroke
.18325 .24623 L
.18431 .24731 L
.18537 .2489 L
.18644 .25179 L
.1875 .24844 L
.18856 .24442 L
.18963 .25054 L
.19069 .25412 L
.19175 .25405 L
.19281 .2561 L
.19388 .23698 L
.19494 .21729 L
.196 .22098 L
.19707 .22315 L
.19813 .22176 L
.19919 .2242 L
.20026 .22021 L
.20132 .21536 L
.20238 .22905 L
.20344 .2424 L
.20451 .23894 L
.20557 .23688 L
.20663 .23616 L
.2077 .23264 L
.20876 .23563 L
.20982 .23919 L
.21088 .22802 L
.21195 .21846 L
.21301 .21797 L
.21407 .21556 L
.21514 .22589 L
.2162 .23587 L
.21726 .23467 L
.21832 .23626 L
.21939 .22302 L
.22045 .20743 L
.22151 .21731 L
.22258 .22748 L
.22364 .21676 L
.2247 .21332 L
.22577 .21187 L
.22683 .2059 L
.22789 .25349 L
.22895 .30066 L
.23002 .29584 L
.23108 .29595 L
.23214 .28884 L
.23321 .27535 L
.23427 .28542 L
.23533 .29408 L
Mistroke
.23639 .28609 L
.23746 .28113 L
.23852 .27915 L
.23958 .27465 L
.24065 .28793 L
.24171 .29864 L
.24277 .29777 L
.24384 .30032 L
.2449 .27382 L
.24596 .24646 L
.24702 .25112 L
.24809 .25306 L
.24915 .25637 L
.25021 .26391 L
.25128 .25879 L
.25234 .25394 L
.2534 .26302 L
.25446 .27036 L
.25553 .27124 L
.25659 .27391 L
.25765 .26624 L
.25872 .25917 L
.25978 .26108 L
.26084 .26099 L
.2619 .27354 L
.26297 .28763 L
.26403 .2831 L
.26509 .27899 L
.26616 .2853 L
.26722 .28753 L
.26828 .29014 L
.26935 .29502 L
.27041 .27333 L
.27147 .25078 L
.27253 .25825 L
.2736 .26431 L
.27466 .25914 L
.27572 .26042 L
.27679 .2553 L
.27785 .24743 L
.27891 .28097 L
.27997 .31212 L
.28104 .3102 L
.2821 .31303 L
.28316 .29369 L
.28423 .27251 L
.28529 .2772 L
.28635 .27708 L
.28741 .29356 L
.28848 .31501 L
Mistroke
.28954 .29753 L
.2906 .27842 L
.29167 .301 L
.29273 .311 L
.29379 .31165 L
.29486 .32115 L
.29592 .23338 L
.29698 .14475 L
.29804 .15668 L
.29911 .1606 L
.30017 .16304 L
.30123 .17997 L
.3023 .16075 L
.30336 .14086 L
.30442 .17823 L
.30548 .21209 L
.30655 .20477 L
.30761 .20285 L
.30867 .18861 L
.30974 .17021 L
.3108 .17653 L
.31186 .18119 L
.31293 .17763 L
.31399 .17811 L
.31505 .17263 L
.31611 .16539 L
.31718 .18183 L
.31824 .19459 L
.3193 .19476 L
.32037 .20006 L
.32143 .16755 L
.32249 .13153 L
.32355 .14932 L
.32462 .1667 L
.32568 .14829 L
.32674 .14366 L
.32781 .13915 L
.32887 .12676 L
.32993 .21087 L
.33099 .29498 L
.33206 .28263 L
.33312 .27818 L
.33418 .27355 L
.33525 .25515 L
.33631 .27262 L
.33737 .29051 L
.33844 .25466 L
.3395 .22239 L
.34056 .22771 L
.34162 .22786 L
Mistroke
.34269 .24115 L
.34375 .25803 L
.34481 .25094 L
.34588 .24574 L
.34694 .24574 L
.348 .24153 L
.34906 .24706 L
.35013 .25435 L
.35119 .23484 L
.35225 .22005 L
.35332 .2182 L
.35438 .21049 L
.35544 .24855 L
.35651 .29028 L
.35757 .26951 L
.35863 .24974 L
.35969 .2673 L
.36076 .26925 L
.36182 .27473 L
.36288 .28852 L
.36395 .19459 L
.36501 .10281 L
.36607 .11078 L
.36713 .10842 L
.3682 .12888 L
.36926 .16041 L
.37032 .14117 L
.37139 .12656 L
.37245 .13003 L
.37351 .12637 L
.37457 .13663 L
.37564 .15142 L
.3767 .12019 L
.37776 .09887 L
.37883 .09838 L
.37989 .08868 L
.38095 .16965 L
.38202 .251 L
.38308 .24058 L
.38414 .23918 L
.3852 .22102 L
.38627 .19232 L
.38733 .20793 L
.38839 .21998 L
.38946 .211 L
.39052 .20903 L
.39158 .19755 L
.39264 .18103 L
.39371 .21387 L
.39477 .23759 L
Mistroke
.39583 .235 L
.3969 .24247 L
.39796 .16149 L
.39902 .0762 L
.40009 .0962 L
.40115 .11062 L
.40221 .09671 L
.40327 .10171 L
.40434 .08548 L
.4054 .06283 L
.40646 .14287 L
.40753 .22323 L
.40859 .20078 L
.40965 .18514 L
.41071 .19224 L
.41178 .17988 L
.41284 .19868 L
.4139 .22382 L
.41497 .13412 L
.41603 .05338 L
.41709 .05611 L
.41815 .04499 L
.41922 .10995 L
.42028 .17701 L
.42134 .16642 L
.42241 .1724 L
.42347 .10571 L
.42453 .0235 L
.4256 .0841 L
.42666 .14843 L
.42772 .07846 L
.42878 .05185 L
.42985 .04765 L
.43091 .01472 L
.43197 .30873 L
.43304 .60332 L
.4341 .56876 L
.43516 .56237 L
.43622 .5408 L
.43729 .47459 L
.43835 .53898 L
.43941 .60117 L
.44048 .50833 L
.44154 .43003 L
.4426 .44079 L
.44366 .43459 L
.44473 .49699 L
.44579 .5613 L
.44685 .54782 L
.44792 .54614 L
Mistroke
.44898 .4885 L
.45004 .4208 L
.45111 .44431 L
.45217 .4645 L
.45323 .44197 L
.45429 .43707 L
.45536 .42531 L
.45642 .40426 L
.45748 .49123 L
.45855 .58081 L
.45961 .54948 L
.46067 .52334 L
.46173 .54204 L
.4628 .53535 L
.46386 .54999 L
.46492 .57517 L
.46599 .44309 L
.46705 .3143 L
.46811 .32987 L
.46918 .33142 L
.47024 .35351 L
.4713 .39347 L
.47236 .367 L
.47343 .34411 L
.47449 .37072 L
.47555 .38909 L
.47662 .39434 L
.47768 .4064 L
.47874 .3737 L
.4798 .34638 L
.48087 .35088 L
.48193 .34687 L
.48299 .41021 L
.48406 .47654 L
.48512 .46471 L
.48618 .45867 L
.48724 .4573 L
.48831 .44454 L
.48937 .4575 L
.49043 .47151 L
.4915 .43904 L
.49256 .40926 L
.49362 .41407 L
.49469 .4145 L
.49575 .42537 L
.49681 .43979 L
.49787 .43369 L
.49894 .42917 L
.5 .43083 L
.50106 .42917 L
Mistroke
.50213 .43369 L
.50319 .43979 L
.50425 .42537 L
.50531 .4145 L
.50638 .41407 L
.50744 .40926 L
.5085 .43904 L
.50957 .47151 L
.51063 .4575 L
.51169 .44454 L
.51276 .4573 L
.51382 .45867 L
.51488 .46471 L
.51594 .47654 L
.51701 .41021 L
.51807 .34687 L
.51913 .35088 L
.5202 .34638 L
.52126 .3737 L
.52232 .4064 L
.52338 .39434 L
.52445 .38909 L
.52551 .37072 L
.52657 .34411 L
.52764 .367 L
.5287 .39347 L
.52976 .35351 L
.53082 .33142 L
.53189 .32987 L
.53295 .3143 L
.53401 .44309 L
.53508 .57517 L
.53614 .54999 L
.5372 .53535 L
.53827 .54204 L
.53933 .52334 L
.54039 .54948 L
.54145 .58081 L
.54252 .49123 L
.54358 .40426 L
.54464 .42531 L
.54571 .43707 L
.54677 .44197 L
.54783 .4645 L
.54889 .44431 L
.54996 .4208 L
.55102 .4885 L
.55208 .54614 L
.55315 .54782 L
.55421 .5613 L
Mistroke
.55527 .49699 L
.55634 .43459 L
.5574 .44079 L
.55846 .43003 L
.55952 .50833 L
.56059 .60117 L
.56165 .53898 L
.56271 .47459 L
.56378 .5408 L
.56484 .56237 L
.5659 .56876 L
.56696 .60332 L
.56803 .30873 L
.56909 .01472 L
.57015 .04765 L
.57122 .05185 L
.57228 .07846 L
.57334 .14843 L
.5744 .0841 L
.57547 .0235 L
.57653 .10571 L
.57759 .1724 L
.57866 .16642 L
.57972 .17701 L
.58078 .10995 L
.58185 .04499 L
.58291 .05611 L
.58397 .05338 L
.58503 .13412 L
.5861 .22382 L
.58716 .19868 L
.58822 .17988 L
.58929 .19224 L
.59035 .18514 L
.59141 .20078 L
.59247 .22323 L
.59354 .14287 L
.5946 .06283 L
.59566 .08548 L
.59673 .10171 L
.59779 .09671 L
.59885 .11062 L
.59991 .0962 L
.60098 .0762 L
.60204 .16149 L
.6031 .24247 L
.60417 .235 L
.60523 .23759 L
.60629 .21387 L
.60736 .18103 L
Mistroke
.60842 .19755 L
.60948 .20903 L
.61054 .211 L
.61161 .21998 L
.61267 .20793 L
.61373 .19232 L
.6148 .22102 L
.61586 .23918 L
.61692 .24058 L
.61798 .251 L
.61905 .16965 L
.62011 .08868 L
.62117 .09838 L
.62224 .09887 L
.6233 .12019 L
.62436 .15142 L
.62543 .13663 L
.62649 .12637 L
.62755 .13003 L
.62861 .12656 L
.62968 .14117 L
.63074 .16041 L
.6318 .12888 L
.63287 .10842 L
.63393 .11078 L
.63499 .10281 L
.63605 .19459 L
.63712 .28852 L
.63818 .27473 L
.63924 .26925 L
.64031 .2673 L
.64137 .24974 L
.64243 .26951 L
.64349 .29028 L
.64456 .24855 L
.64562 .21049 L
.64668 .2182 L
.64775 .22005 L
.64881 .23484 L
.64987 .25435 L
.65094 .24706 L
.652 .24153 L
.65306 .24574 L
.65412 .24574 L
.65519 .25094 L
.65625 .25803 L
.65731 .24115 L
.65838 .22786 L
.65944 .22771 L
.6605 .22239 L
Mistroke
.66156 .25466 L
.66263 .29051 L
.66369 .27262 L
.66475 .25515 L
.66582 .27355 L
.66688 .27818 L
.66794 .28263 L
.66901 .29498 L
.67007 .21087 L
.67113 .12676 L
.67219 .13915 L
.67326 .14366 L
.67432 .14829 L
.67538 .1667 L
.67645 .14932 L
.67751 .13153 L
.67857 .16755 L
.67963 .20006 L
.6807 .19476 L
.68176 .19459 L
.68282 .18183 L
.68389 .16539 L
.68495 .17263 L
.68601 .17811 L
.68707 .17763 L
.68814 .18119 L
.6892 .17653 L
.69026 .17021 L
.69133 .18861 L
.69239 .20285 L
.69345 .20477 L
.69452 .21209 L
.69558 .17823 L
.69664 .14086 L
.6977 .16075 L
.69877 .17997 L
.69983 .16304 L
.70089 .1606 L
.70196 .15668 L
.70302 .14475 L
.70408 .23338 L
.70514 .32115 L
.70621 .31165 L
.70727 .311 L
.70833 .301 L
.7094 .27842 L
.71046 .29753 L
.71152 .31501 L
.71259 .29356 L
.71365 .27708 L
Mistroke
.71471 .2772 L
.71577 .27251 L
.71684 .29369 L
.7179 .31303 L
.71896 .3102 L
.72003 .31212 L
.72109 .28097 L
.72215 .24743 L
.72321 .2553 L
.72428 .26042 L
.72534 .25914 L
.7264 .26431 L
.72747 .25825 L
.72853 .25078 L
.72959 .27333 L
.73065 .29502 L
.73172 .29014 L
.73278 .28753 L
.73384 .2853 L
.73491 .27899 L
.73597 .2831 L
.73703 .28763 L
.7381 .27354 L
.73916 .26099 L
.74022 .26108 L
.74128 .25917 L
.74235 .26624 L
.74341 .27391 L
.74447 .27124 L
.74554 .27036 L
.7466 .26302 L
.74766 .25394 L
.74872 .25879 L
.74979 .26391 L
.75085 .25637 L
.75191 .25306 L
.75298 .25112 L
.75404 .24646 L
.7551 .27382 L
.75616 .30032 L
.75723 .29777 L
.75829 .29864 L
.75935 .28793 L
.76042 .27465 L
.76148 .27915 L
.76254 .28113 L
.76361 .28609 L
.76467 .29408 L
.76573 .28542 L
.76679 .27535 L
Mistroke
.76786 .28884 L
.76892 .29595 L
.76998 .29584 L
.77105 .30066 L
.77211 .25349 L
.77317 .2059 L
.77423 .21187 L
.7753 .21332 L
.77636 .21676 L
.77742 .22748 L
.77849 .21731 L
.77955 .20743 L
.78061 .22302 L
.78168 .23626 L
.78274 .23467 L
.7838 .23587 L
.78486 .22589 L
.78593 .21556 L
.78699 .21797 L
.78805 .21846 L
.78912 .22802 L
.79018 .23919 L
.79124 .23563 L
.7923 .23264 L
.79337 .23616 L
.79443 .23688 L
.79549 .23894 L
.79656 .2424 L
.79762 .22905 L
.79868 .21536 L
.79974 .22021 L
.80081 .2242 L
.80187 .22176 L
.80293 .22315 L
.804 .22098 L
.80506 .21729 L
.80612 .23698 L
.80719 .2561 L
.80825 .25405 L
.80931 .25412 L
.81037 .25054 L
.81144 .24442 L
.8125 .24844 L
.81356 .25179 L
.81463 .2489 L
.81569 .24731 L
.81675 .24623 L
.81781 .24419 L
.81888 .24948 L
.81994 .25363 L
Mistroke
.821 .25329 L
.82207 .25437 L
.82313 .24313 L
.82419 .2316 L
.82526 .23345 L
.82632 .23413 L
.82738 .23572 L
.82844 .23902 L
.82951 .23689 L
.83057 .23496 L
.83163 .23829 L
.8327 .24091 L
.83376 .2414 L
.83482 .24258 L
.83588 .2397 L
.83695 .23719 L
.83801 .23788 L
.83907 .2378 L
.84014 .24343 L
.8412 .24935 L
.84226 .24846 L
.84332 .24806 L
.84439 .24808 L
.84545 .24709 L
.84651 .24833 L
.84758 .24964 L
.84864 .24696 L
.8497 .24452 L
.85077 .245 L
.85183 .24511 L
.85289 .24612 L
.85395 .24741 L
.85502 .24696 L
.85608 .24665 L
.85714 .24672 L
.85821 .24655 L
.85927 .24686 L
.86033 .24726 L
.86139 .24642 L
.86246 .24579 L
.86352 .24576 L
.86458 .24546 L
.86565 .24719 L
.86671 .24908 L
.86777 .2482 L
.86884 .24736 L
.8699 .24818 L
.87096 .24831 L
.87202 .24856 L
.87309 .24918 L
Mistroke
.87415 .24511 L
.87521 .24109 L
.87628 .24157 L
.87734 .24165 L
.8784 .24217 L
.87946 .24327 L
.88053 .24242 L
.88159 .24166 L
.88265 .24268 L
.88372 .24347 L
.88478 .24351 L
.88584 .24376 L
.8869 .24282 L
.88797 .24196 L
.88903 .24212 L
.89009 .24206 L
.89116 .24354 L
.89222 .24514 L
.89328 .24481 L
.89435 .24461 L
.89541 .24466 L
.89647 .24441 L
.89753 .24472 L
.8986 .24507 L
.89966 .24412 L
.90072 .24321 L
.90179 .24342 L
.90285 .24353 L
.90391 .24367 L
.90497 .24396 L
.90604 .2438 L
.9071 .24363 L
.90816 .24415 L
.90923 .24462 L
.91029 .24458 L
.91135 .24461 L
.91241 .24448 L
.91348 .24429 L
.91454 .2444 L
.9156 .24448 L
.91667 .24446 L
.91773 .24447 L
.91879 .24443 L
.91986 .24437 L
.92092 .2445 L
.92198 .24459 L
.92304 .24459 L
.92411 .24463 L
.92517 .24431 L
.92623 .24397 L
Mistroke
.9273 .24403 L
.92836 .24405 L
.92942 .24408 L
.93048 .24415 L
.93155 .24409 L
.93261 .24402 L
.93367 .24416 L
.93474 .24428 L
.9358 .24426 L
.93686 .24427 L
.93793 .24421 L
.93899 .24415 L
.94005 .24417 L
.94111 .24418 L
.94218 .24421 L
.94324 .24426 L
.9443 .24425 L
.94537 .24424 L
.94643 .24424 L
.94749 .24424 L
.94855 .24425 L
.94962 .24426 L
.95068 .24423 L
.95174 .2442 L
.95281 .24421 L
.95387 .24421 L
.95493 .24422 L
.95599 .24423 L
.95706 .24422 L
.95812 .24422 L
.95918 .24422 L
.96025 .24422 L
.96131 .24422 L
.96237 .24422 L
.96344 .24422 L
.9645 .24422 L
.96556 .24422 L
.96662 .24422 L
.96769 .24422 L
.96875 .24422 L
.96981 .24422 L
.97088 .24422 L
.97194 .24422 L
.973 .24422 L
.97406 .24422 L
.97513 .24422 L
.97619 .24422 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is the \"original\" basic wavelet. Note that in contrast to the case \
of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", the calculation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " depends on both filters, ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.29"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[b33, 7],
PlotJoined -> True, PlotRange -> All,
PlotLabel -> \"psi_33(t)\"]\
\>", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.072447 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 .01923 -12 -4.5 ]
[.39226 .01923 0 4.5 ]
[.39226 .16412 -12 -4.5 ]
[.39226 .16412 0 4.5 ]
[.39226 .45391 -6 -4.5 ]
[.39226 .45391 0 4.5 ]
[.39226 .5988 -6 -4.5 ]
[.39226 .5988 0 4.5 ]
[.5 .63053 -27 0 ]
[.5 .63053 27 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 .01923 m
.41101 .01923 L
s
[(-4)] .39226 .01923 1 0 Mshowa
.40476 .16412 m
.41101 .16412 L
s
[(-2)] .39226 .16412 1 0 Mshowa
.40476 .45391 m
.41101 .45391 L
s
[(2)] .39226 .45391 1 0 Mshowa
.40476 .5988 m
.41101 .5988 L
s
[(4)] .39226 .5988 1 0 Mshowa
.125 Mabswid
.40476 .05545 m
.40851 .05545 L
s
.40476 .09168 m
.40851 .09168 L
s
.40476 .1279 m
.40851 .1279 L
s
.40476 .20035 m
.40851 .20035 L
s
.40476 .23657 m
.40851 .23657 L
s
.40476 .27279 m
.40851 .27279 L
s
.40476 .34524 m
.40851 .34524 L
s
.40476 .38146 m
.40851 .38146 L
s
.40476 .41769 m
.40851 .41769 L
s
.40476 .49013 m
.40851 .49013 L
s
.40476 .52636 m
.40851 .52636 L
s
.40476 .56258 m
.40851 .56258 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(psi_33\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .30902 m
.0253 .30902 L
.02679 .30902 L
.02827 .30902 L
.02976 .30902 L
.03125 .30902 L
.03274 .30902 L
.03423 .30902 L
.03571 .30902 L
.0372 .30902 L
.03869 .30902 L
.04018 .30902 L
.04167 .30902 L
.04315 .30901 L
.04464 .30901 L
.04613 .30901 L
.04762 .30902 L
.04911 .30903 L
.0506 .30902 L
.05208 .30901 L
.05357 .30903 L
.05506 .30904 L
.05655 .30904 L
.05804 .30905 L
.05952 .309 L
.06101 .30895 L
.0625 .30897 L
.06399 .30898 L
.06548 .30898 L
.06696 .30899 L
.06845 .30897 L
.06994 .30896 L
.07143 .30903 L
.07292 .30909 L
.0744 .30911 L
.07589 .30915 L
.07738 .30903 L
.07887 .30893 L
.08036 .30894 L
.08185 .30892 L
.08333 .30913 L
.08482 .30938 L
.08631 .30926 L
.0878 .30914 L
.08929 .30928 L
.09077 .30932 L
.09226 .30937 L
.09375 .30947 L
.09524 .30886 L
.09673 .30827 L
Mistroke
.09821 .30834 L
.0997 .30834 L
.10119 .30851 L
.10268 .30875 L
.10417 .30864 L
.10565 .30856 L
.10714 .30859 L
.10863 .30855 L
.11012 .30869 L
.11161 .30888 L
.1131 .30855 L
.11458 .30831 L
.11607 .30836 L
.11756 .30829 L
.11905 .30915 L
.12054 .3101 L
.12202 .30979 L
.12351 .3095 L
.125 .31003 L
.12649 .31027 L
.12798 .31047 L
.12946 .31086 L
.13095 .3092 L
.13244 .30746 L
.13393 .30811 L
.13542 .30867 L
.1369 .30822 L
.13839 .30831 L
.13988 .30795 L
.14137 .30735 L
.14286 .31025 L
.14435 .31297 L
.14583 .31286 L
.14732 .31315 L
.14881 .31158 L
.1503 .30985 L
.15179 .31032 L
.15327 .31039 L
.15476 .31183 L
.15625 .3137 L
.15774 .3123 L
.15923 .31076 L
.16071 .31277 L
.1622 .31372 L
.16369 .31385 L
.16518 .31474 L
.16667 .30739 L
.16815 .29996 L
.16964 .30109 L
.17113 .30155 L
Mistroke
.17262 .30179 L
.17411 .30329 L
.1756 .30176 L
.17708 .30015 L
.17857 .3036 L
.18006 .30676 L
.18155 .30621 L
.18304 .30616 L
.18452 .30501 L
.18601 .30347 L
.1875 .30419 L
.18899 .30477 L
.19048 .30445 L
.19196 .30459 L
.19345 .30401 L
.19494 .3032 L
.19643 .30556 L
.19792 .3074 L
.1994 .30759 L
.20089 .30848 L
.20238 .30401 L
.20387 .29912 L
.20536 .30152 L
.20685 .30377 L
.20833 .30198 L
.20982 .302 L
.21131 .30127 L
.2128 .29965 L
.21429 .31047 L
.21577 .32075 L
.21726 .3206 L
.21875 .32186 L
.22024 .31727 L
.22173 .31201 L
.22321 .31417 L
.2247 .31507 L
.22619 .31986 L
.22768 .32594 L
.22917 .32241 L
.23065 .31853 L
.23214 .32455 L
.23363 .32742 L
.23512 .32868 L
.23661 .33205 L
.2381 .31101 L
.23958 .29052 L
.24107 .29246 L
.24256 .29179 L
.24405 .29947 L
.24554 .3092 L
Mistroke
.24702 .30547 L
.24851 .30355 L
.25 .30039 L
.25149 .29485 L
.25298 .30106 L
.25446 .30846 L
.25595 .29726 L
.25744 .29077 L
.25893 .29082 L
.26042 .28698 L
.2619 .32232 L
.26339 .35861 L
.26488 .35198 L
.26637 .34825 L
.26786 .35014 L
.26935 .34514 L
.27083 .35249 L
.27232 .36121 L
.27381 .33734 L
.2753 .31427 L
.27679 .31996 L
.27827 .32308 L
.27976 .32516 L
.28125 .33182 L
.28274 .32658 L
.28423 .32062 L
.28571 .33779 L
.2872 .35212 L
.28869 .35336 L
.29018 .35776 L
.29167 .33981 L
.29315 .32288 L
.29464 .32446 L
.29613 .32115 L
.29762 .34547 L
.29911 .37373 L
.3006 .35646 L
.30208 .33889 L
.30357 .35669 L
.30506 .36172 L
.30655 .3646 L
.30804 .37515 L
.30952 .29281 L
.31101 .21171 L
.3125 .21883 L
.31399 .21709 L
.31548 .23293 L
.31696 .25884 L
.31845 .24152 L
.31994 .22778 L
Mistroke
.32143 .23352 L
.32292 .2333 L
.3244 .24038 L
.32589 .25155 L
.32738 .22492 L
.32887 .20581 L
.33036 .20547 L
.33185 .19761 L
.33333 .26154 L
.33482 .32602 L
.33631 .31691 L
.3378 .31493 L
.33929 .3005 L
.34077 .27751 L
.34226 .28938 L
.34375 .29858 L
.34524 .28971 L
.34673 .28626 L
.34821 .27717 L
.3497 .26406 L
.35119 .28881 L
.35268 .30678 L
.35417 .304 L
.35565 .30893 L
.35714 .24678 L
.35863 .1814 L
.36012 .19571 L
.36161 .20567 L
.3631 .19545 L
.36458 .19934 L
.36607 .18641 L
.36756 .1689 L
.36905 .22695 L
.37054 .28497 L
.37202 .26844 L
.37351 .25705 L
.375 .26036 L
.37649 .24982 L
.37798 .26304 L
.37946 .28049 L
.38095 .21753 L
.38244 .16136 L
.38393 .16178 L
.38542 .15226 L
.3869 .20019 L
.38839 .24873 L
.38988 .24115 L
.39137 .24611 L
.39286 .19215 L
.39435 .12693 L
Mistroke
.39583 .17164 L
.39732 .21856 L
.39881 .16773 L
.4003 .14957 L
.40179 .14453 L
.40327 .11851 L
.40476 .33655 L
.40625 .55334 L
.40774 .53073 L
.40923 .5303 L
.41071 .50133 L
.4122 .44236 L
.41369 .48901 L
.41518 .53016 L
.41667 .48742 L
.41815 .45797 L
.41964 .45249 L
.42113 .43526 L
.42262 .49349 L
.42411 .54254 L
.4256 .53768 L
.42708 .54715 L
.42857 .44127 L
.43006 .33089 L
.43155 .35145 L
.43304 .36139 L
.43452 .37174 L
.43601 .39995 L
.4375 .37972 L
.43899 .35952 L
.44048 .40352 L
.44196 .44133 L
.44345 .44143 L
.44494 .44877 L
.44643 .42282 L
.44792 .39633 L
.4494 .40529 L
.45089 .40801 L
.45238 .44049 L
.45387 .47855 L
.45536 .46505 L
.45685 .45196 L
.45833 .47422 L
.45982 .48432 L
.46131 .49133 L
.4628 .50593 L
.46429 .43743 L
.46577 .36572 L
.46726 .39007 L
.46875 .41012 L
Mistroke
.47024 .39252 L
.47173 .39585 L
.47321 .37951 L
.4747 .35407 L
.47619 .46444 L
.47768 .56683 L
.47917 .5613 L
.48065 .57155 L
.48214 .50612 L
.48363 .43526 L
.48512 .45057 L
.48661 .44938 L
.4881 .50881 L
.48958 .58456 L
.49107 .52588 L
.49256 .4624 L
.49405 .53564 L
.49554 .56617 L
.49702 .5702 L
.49851 .60332 L
.5 .30902 L
.50149 .01472 L
.50298 .04783 L
.50446 .05186 L
.50595 .08239 L
.50744 .15563 L
.50893 .09215 L
.51042 .03348 L
.5119 .10923 L
.51339 .16865 L
.51488 .16746 L
.51637 .18277 L
.51786 .11191 L
.51935 .04648 L
.52083 .05673 L
.52232 .0512 L
.52381 .15359 L
.5253 .26396 L
.52679 .23852 L
.52827 .22219 L
.52976 .22552 L
.53125 .20791 L
.53274 .22796 L
.53423 .25231 L
.53571 .18061 L
.5372 .11211 L
.53869 .12671 L
.54018 .13371 L
.54167 .14381 L
.54315 .16607 L
Mistroke
.54464 .15299 L
.54613 .13948 L
.54762 .17755 L
.54911 .21002 L
.5506 .21275 L
.55208 .2217 L
.55357 .19522 L
.55506 .16927 L
.55655 .17661 L
.55804 .1767 L
.55952 .21451 L
.56101 .25851 L
.5625 .23832 L
.56399 .21809 L
.56548 .24629 L
.56696 .25664 L
.56845 .26658 L
.56994 .28715 L
.57143 .17677 L
.57292 .07089 L
.5744 .08035 L
.57589 .0755 L
.57738 .12455 L
.57887 .18277 L
.58036 .16555 L
.58185 .16007 L
.58333 .13061 L
.58482 .08787 L
.58631 .12903 L
.5878 .17567 L
.58929 .1167 L
.59077 .08773 L
.59226 .0873 L
.59375 .0647 L
.59524 .28149 L
.59673 .49952 L
.59821 .4735 L
.5997 .46846 L
.60119 .45031 L
.60268 .39947 L
.60417 .44639 L
.60565 .4911 L
.60714 .42589 L
.60863 .37192 L
.61012 .37688 L
.61161 .3693 L
.6131 .41784 L
.61458 .46578 L
.61607 .45625 L
.61756 .45668 L
Mistroke
.61905 .4005 L
.62054 .33754 L
.62202 .35499 L
.62351 .36822 L
.625 .35767 L
.62649 .36098 L
.62798 .3496 L
.62946 .33306 L
.63095 .39109 L
.63244 .44913 L
.63393 .43163 L
.63542 .41869 L
.6369 .42259 L
.63839 .41236 L
.63988 .42233 L
.64137 .43663 L
.64286 .37125 L
.64435 .30911 L
.64583 .31403 L
.64732 .31125 L
.64881 .32922 L
.6503 .35398 L
.65179 .34087 L
.65327 .33177 L
.65476 .32833 L
.65625 .31945 L
.65774 .32865 L
.65923 .34052 L
.66071 .31754 L
.6622 .30311 L
.66369 .30113 L
.66518 .29202 L
.66667 .35649 L
.66815 .42042 L
.66964 .41256 L
.67113 .41222 L
.67262 .39312 L
.67411 .36648 L
.6756 .37765 L
.67708 .38473 L
.67857 .38451 L
.68006 .39026 L
.68155 .37651 L
.68304 .35919 L
.68452 .38511 L
.68601 .40094 L
.6875 .3992 L
.68899 .40633 L
.69048 .32523 L
.69196 .24288 L
Mistroke
.69345 .25343 L
.69494 .25631 L
.69643 .26135 L
.69792 .27915 L
.6994 .26158 L
.70089 .2443 L
.70238 .27256 L
.70387 .29688 L
.70536 .29358 L
.70685 .29515 L
.70833 .27823 L
.70982 .26028 L
.71131 .26468 L
.7128 .26592 L
.71429 .28024 L
.71577 .29741 L
.71726 .29145 L
.71875 .28622 L
.72024 .29288 L
.72173 .29495 L
.72321 .29808 L
.7247 .30377 L
.72619 .28069 L
.72768 .25682 L
.72917 .26554 L
.73065 .2729 L
.73214 .26789 L
.73363 .26979 L
.73512 .26605 L
.73661 .25942 L
.7381 .29572 L
.73958 .33105 L
.74107 .32721 L
.74256 .32727 L
.74405 .32077 L
.74554 .30957 L
.74702 .31697 L
.74851 .32318 L
.75 .31764 L
.75149 .31448 L
.75298 .31256 L
.75446 .30884 L
.75595 .31857 L
.75744 .32624 L
.75893 .32557 L
.76042 .32751 L
.7619 .30702 L
.76339 .28598 L
.76488 .28935 L
.76637 .29061 L
Mistroke
.76786 .29349 L
.76935 .29951 L
.77083 .29563 L
.77232 .2921 L
.77381 .29817 L
.7753 .30296 L
.77679 .30386 L
.77827 .30602 L
.77976 .30076 L
.78125 .29617 L
.78274 .29743 L
.78423 .29728 L
.78571 .30757 L
.7872 .31839 L
.78869 .31676 L
.79018 .31604 L
.79167 .31606 L
.79315 .31426 L
.79464 .31652 L
.79613 .31891 L
.79762 .31403 L
.79911 .30956 L
.8006 .31044 L
.80208 .31063 L
.80357 .31248 L
.80506 .31484 L
.80655 .31402 L
.80804 .31345 L
.80952 .31358 L
.81101 .31326 L
.8125 .31384 L
.81399 .31457 L
.81548 .31303 L
.81696 .31188 L
.81845 .31182 L
.81994 .31128 L
.82143 .31443 L
.82292 .31789 L
.8244 .31628 L
.82589 .31475 L
.82738 .31624 L
.82887 .31648 L
.83036 .31694 L
.83185 .31808 L
.83333 .31064 L
.83482 .30329 L
.83631 .30418 L
.8378 .30432 L
.83929 .30526 L
.84077 .30728 L
Mistroke
.84226 .30573 L
.84375 .30433 L
.84524 .3062 L
.84673 .30765 L
.84821 .30771 L
.8497 .30818 L
.85119 .30645 L
.85268 .30488 L
.85417 .30518 L
.85565 .30506 L
.85714 .30778 L
.85863 .31069 L
.86012 .31009 L
.86161 .30973 L
.8631 .30981 L
.86458 .30937 L
.86607 .30992 L
.86756 .31057 L
.86905 .30883 L
.87054 .30717 L
.87202 .30756 L
.87351 .30776 L
.875 .308 L
.87649 .30853 L
.87798 .30824 L
.87946 .30793 L
.88095 .30888 L
.88244 .30974 L
.88393 .30968 L
.88542 .30972 L
.8869 .30949 L
.88839 .30915 L
.88988 .30934 L
.89137 .30949 L
.89286 .30944 L
.89435 .30947 L
.89583 .30939 L
.89732 .30928 L
.89881 .30952 L
.9003 .3097 L
.90179 .30969 L
.90327 .30976 L
.90476 .30917 L
.90625 .30856 L
.90774 .30867 L
.90923 .30871 L
.91071 .30875 L
.9122 .30889 L
.91369 .30878 L
.91518 .30866 L
Mistroke
.91667 .3089 L
.91815 .30912 L
.91964 .30909 L
.92113 .3091 L
.92262 .309 L
.92411 .30888 L
.9256 .30892 L
.92708 .30894 L
.92857 .309 L
.93006 .30908 L
.93155 .30906 L
.93304 .30905 L
.93452 .30906 L
.93601 .30905 L
.9375 .30906 L
.93899 .30908 L
.94048 .30903 L
.94196 .30898 L
.94345 .30899 L
.94494 .30899 L
.94643 .30901 L
.94792 .30902 L
.9494 .30902 L
.95089 .30901 L
.95238 .30902 L
.95387 .30902 L
.95536 .30902 L
.95685 .30902 L
.95833 .30902 L
.95982 .30901 L
.96131 .30902 L
.9628 .30902 L
.96429 .30902 L
.96577 .30902 L
.96726 .30902 L
.96875 .30902 L
.97024 .30902 L
.97173 .30902 L
.97321 .30902 L
.9747 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "To get \"dual\" functions we reverse the roles of ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". Note that this is just the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "\[Hyphen]spline function of order 2 (",
  Cell[BoxData[
      \(TraditionalForm\`\( = \(N\&~\) - 1\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ")."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.30"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[ScalingFunction[Reverse[b33], 7],
PlotJoined -> True, PlotRange -> All,
PlotLabel -> \"dual phi_33(t)\"]\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.0147151 0.784805 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.18254 .00222 -12 -9 ]
[.18254 .00222 12 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.32877 .0932 -18 -4.5 ]
[.32877 .0932 0 4.5 ]
[.32877 .17168 -18 -4.5 ]
[.32877 .17168 0 4.5 ]
[.32877 .25016 -18 -4.5 ]
[.32877 .25016 0 4.5 ]
[.32877 .32864 -18 -4.5 ]
[.32877 .32864 0 4.5 ]
[.32877 .40712 -18 -4.5 ]
[.32877 .40712 0 4.5 ]
[.32877 .4856 -18 -4.5 ]
[.32877 .4856 0 4.5 ]
[.32877 .56408 -18 -4.5 ]
[.32877 .56408 0 4.5 ]
[.5 .63053 -42 0 ]
[.5 .63053 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-1)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-0.5)] .18254 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(0.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(1)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(1.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.34127 .0932 m
.34752 .0932 L
s
[(0.1)] .32877 .0932 1 0 Mshowa
.34127 .17168 m
.34752 .17168 L
s
[(0.2)] .32877 .17168 1 0 Mshowa
.34127 .25016 m
.34752 .25016 L
s
[(0.3)] .32877 .25016 1 0 Mshowa
.34127 .32864 m
.34752 .32864 L
s
[(0.4)] .32877 .32864 1 0 Mshowa
.34127 .40712 m
.34752 .40712 L
s
[(0.5)] .32877 .40712 1 0 Mshowa
.34127 .4856 m
.34752 .4856 L
s
[(0.6)] .32877 .4856 1 0 Mshowa
.34127 .56408 m
.34752 .56408 L
s
[(0.7)] .32877 .56408 1 0 Mshowa
.125 Mabswid
.34127 .03041 m
.34502 .03041 L
s
.34127 .04611 m
.34502 .04611 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0775 m
.34502 .0775 L
s
.34127 .10889 m
.34502 .10889 L
s
.34127 .12459 m
.34502 .12459 L
s
.34127 .14028 m
.34502 .14028 L
s
.34127 .15598 m
.34502 .15598 L
s
.34127 .18737 m
.34502 .18737 L
s
.34127 .20307 m
.34502 .20307 L
s
.34127 .21876 m
.34502 .21876 L
s
.34127 .23446 m
.34502 .23446 L
s
.34127 .26585 m
.34502 .26585 L
s
.34127 .28155 m
.34502 .28155 L
s
.34127 .29724 m
.34502 .29724 L
s
.34127 .31294 m
.34502 .31294 L
s
.34127 .34433 m
.34502 .34433 L
s
.34127 .36003 m
.34502 .36003 L
s
.34127 .37573 m
.34502 .37573 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .42281 m
.34502 .42281 L
s
.34127 .43851 m
.34502 .43851 L
s
.34127 .45421 m
.34502 .45421 L
s
.34127 .4699 m
.34502 .4699 L
s
.34127 .50129 m
.34502 .50129 L
s
.34127 .51699 m
.34502 .51699 L
s
.34127 .53269 m
.34502 .53269 L
s
.34127 .54838 m
.34502 .54838 L
s
.34127 .57977 m
.34502 .57977 L
s
.34127 .59547 m
.34502 .59547 L
s
.34127 .61117 m
.34502 .61117 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(dual phi_33\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02629 .01474 L
.02877 .01481 L
.03125 .01493 L
.03373 .0151 L
.03621 .01531 L
.03869 .01558 L
.04117 .01589 L
.04365 .01625 L
.04613 .01666 L
.04861 .01711 L
.05109 .01761 L
.05357 .01816 L
.05605 .01876 L
.05853 .01941 L
.06101 .0201 L
.06349 .02085 L
.06597 .02164 L
.06845 .02248 L
.07093 .02336 L
.07341 .0243 L
.07589 .02528 L
.07837 .02631 L
.08085 .02738 L
.08333 .02851 L
.08581 .02968 L
.08829 .03091 L
.09077 .03217 L
.09325 .03349 L
.09573 .03486 L
.09821 .03627 L
.10069 .03773 L
.10317 .03924 L
.10565 .0408 L
.10813 .0424 L
.11062 .04405 L
.1131 .04575 L
.11558 .0475 L
.11806 .0493 L
.12054 .05114 L
.12302 .05304 L
.1255 .05498 L
.12798 .05696 L
.13046 .059 L
.13294 .06108 L
.13542 .06321 L
.1379 .06539 L
.14038 .06762 L
.14286 .0699 L
.14534 .07222 L
Mistroke
.14782 .07459 L
.1503 .07701 L
.15278 .07948 L
.15526 .08199 L
.15774 .08455 L
.16022 .08716 L
.1627 .08982 L
.16518 .09253 L
.16766 .09528 L
.17014 .09809 L
.17262 .10094 L
.1751 .10383 L
.17758 .10678 L
.18006 .10977 L
.18254 .11282 L
.18502 .11591 L
.1875 .11904 L
.18998 .12223 L
.19246 .12546 L
.19494 .12874 L
.19742 .13207 L
.1999 .13545 L
.20238 .13887 L
.20486 .14235 L
.20734 .14587 L
.20982 .14944 L
.2123 .15305 L
.21478 .15672 L
.21726 .16043 L
.21974 .16419 L
.22222 .168 L
.2247 .17185 L
.22718 .17576 L
.22966 .17971 L
.23214 .18371 L
.23462 .18776 L
.2371 .19185 L
.23958 .196 L
.24206 .20019 L
.24454 .20443 L
.24702 .20871 L
.2495 .21305 L
.25198 .21743 L
.25446 .22186 L
.25694 .22634 L
.25942 .23087 L
.2619 .23544 L
.26438 .24006 L
.26687 .24473 L
.26935 .24945 L
Mistroke
.27183 .25422 L
.27431 .25903 L
.27679 .26389 L
.27927 .2688 L
.28175 .27376 L
.28423 .27877 L
.28671 .28382 L
.28919 .28892 L
.29167 .29407 L
.29415 .29927 L
.29663 .30451 L
.29911 .30981 L
.30159 .31515 L
.30407 .32054 L
.30655 .32597 L
.30903 .33146 L
.31151 .33699 L
.31399 .34257 L
.31647 .3482 L
.31895 .35388 L
.32143 .3596 L
.32391 .36537 L
.32639 .37119 L
.32887 .37706 L
.33135 .38298 L
.33383 .38894 L
.33631 .39495 L
.33879 .40101 L
.34127 .40712 L
.34375 .4132 L
.34623 .41919 L
.34871 .42508 L
.35119 .43088 L
.35367 .43658 L
.35615 .44218 L
.35863 .44769 L
.36111 .4531 L
.36359 .45842 L
.36607 .46364 L
.36855 .46877 L
.37103 .4738 L
.37351 .47873 L
.37599 .48357 L
.37847 .48831 L
.38095 .49296 L
.38343 .49751 L
.38591 .50196 L
.38839 .50632 L
.39087 .51058 L
.39335 .51475 L
Mistroke
.39583 .51882 L
.39831 .5228 L
.40079 .52668 L
.40327 .53046 L
.40575 .53415 L
.40823 .53774 L
.41071 .54124 L
.41319 .54464 L
.41567 .54795 L
.41815 .55116 L
.42063 .55427 L
.42312 .55729 L
.4256 .56021 L
.42808 .56303 L
.43056 .56576 L
.43304 .5684 L
.43552 .57094 L
.438 .57338 L
.44048 .57573 L
.44296 .57798 L
.44544 .58013 L
.44792 .58219 L
.4504 .58416 L
.45288 .58603 L
.45536 .5878 L
.45784 .58948 L
.46032 .59106 L
.4628 .59254 L
.46528 .59393 L
.46776 .59522 L
.47024 .59642 L
.47272 .59752 L
.4752 .59853 L
.47768 .59944 L
.48016 .60025 L
.48264 .60097 L
.48512 .60159 L
.4876 .60212 L
.49008 .60255 L
.49256 .60289 L
.49504 .60313 L
.49752 .60327 L
.5 .60332 L
.50248 .60327 L
.50496 .60313 L
.50744 .60289 L
.50992 .60255 L
.5124 .60212 L
.51488 .60159 L
.51736 .60097 L
Mistroke
.51984 .60025 L
.52232 .59944 L
.5248 .59853 L
.52728 .59752 L
.52976 .59642 L
.53224 .59522 L
.53472 .59393 L
.5372 .59254 L
.53968 .59106 L
.54216 .58948 L
.54464 .5878 L
.54712 .58603 L
.5496 .58416 L
.55208 .58219 L
.55456 .58013 L
.55704 .57798 L
.55952 .57573 L
.562 .57338 L
.56448 .57094 L
.56696 .5684 L
.56944 .56576 L
.57192 .56303 L
.5744 .56021 L
.57688 .55729 L
.57937 .55427 L
.58185 .55116 L
.58433 .54795 L
.58681 .54464 L
.58929 .54124 L
.59177 .53774 L
.59425 .53415 L
.59673 .53046 L
.59921 .52668 L
.60169 .5228 L
.60417 .51882 L
.60665 .51475 L
.60913 .51058 L
.61161 .50632 L
.61409 .50196 L
.61657 .49751 L
.61905 .49296 L
.62153 .48831 L
.62401 .48357 L
.62649 .47873 L
.62897 .4738 L
.63145 .46877 L
.63393 .46364 L
.63641 .45842 L
.63889 .4531 L
.64137 .44769 L
Mistroke
.64385 .44218 L
.64633 .43658 L
.64881 .43088 L
.65129 .42508 L
.65377 .41919 L
.65625 .4132 L
.65873 .40712 L
.66121 .40101 L
.66369 .39495 L
.66617 .38894 L
.66865 .38298 L
.67113 .37706 L
.67361 .37119 L
.67609 .36537 L
.67857 .3596 L
.68105 .35388 L
.68353 .3482 L
.68601 .34257 L
.68849 .33699 L
.69097 .33146 L
.69345 .32597 L
.69593 .32054 L
.69841 .31515 L
.70089 .30981 L
.70337 .30451 L
.70585 .29927 L
.70833 .29407 L
.71081 .28892 L
.71329 .28382 L
.71577 .27877 L
.71825 .27376 L
.72073 .2688 L
.72321 .26389 L
.72569 .25903 L
.72817 .25422 L
.73065 .24945 L
.73313 .24473 L
.73562 .24006 L
.7381 .23544 L
.74058 .23087 L
.74306 .22634 L
.74554 .22186 L
.74802 .21743 L
.7505 .21305 L
.75298 .20871 L
.75546 .20443 L
.75794 .20019 L
.76042 .196 L
.7629 .19185 L
.76538 .18776 L
Mistroke
.76786 .18371 L
.77034 .17971 L
.77282 .17576 L
.7753 .17185 L
.77778 .168 L
.78026 .16419 L
.78274 .16043 L
.78522 .15672 L
.7877 .15305 L
.79018 .14944 L
.79266 .14587 L
.79514 .14235 L
.79762 .13887 L
.8001 .13545 L
.80258 .13207 L
.80506 .12874 L
.80754 .12546 L
.81002 .12223 L
.8125 .11904 L
.81498 .11591 L
.81746 .11282 L
.81994 .10977 L
.82242 .10678 L
.8249 .10383 L
.82738 .10094 L
.82986 .09809 L
.83234 .09528 L
.83482 .09253 L
.8373 .08982 L
.83978 .08716 L
.84226 .08455 L
.84474 .08199 L
.84722 .07948 L
.8497 .07701 L
.85218 .07459 L
.85466 .07222 L
.85714 .0699 L
.85962 .06762 L
.8621 .06539 L
.86458 .06321 L
.86706 .06108 L
.86954 .059 L
.87202 .05696 L
.8745 .05498 L
.87698 .05304 L
.87946 .05114 L
.88194 .0493 L
.88442 .0475 L
.8869 .04575 L
.88938 .04405 L
Mistroke
.89187 .0424 L
.89435 .0408 L
.89683 .03924 L
.89931 .03773 L
.90179 .03627 L
.90427 .03486 L
.90675 .03349 L
.90923 .03217 L
.91171 .03091 L
.91419 .02968 L
.91667 .02851 L
.91915 .02738 L
.92163 .02631 L
.92411 .02528 L
.92659 .0243 L
.92907 .02336 L
.93155 .02248 L
.93403 .02164 L
.93651 .02085 L
.93899 .0201 L
.94147 .01941 L
.94395 .01876 L
.94643 .01816 L
.94891 .01761 L
.95139 .01711 L
.95387 .01666 L
.95635 .01625 L
.95883 .01589 L
.96131 .01558 L
.96379 .01531 L
.96627 .0151 L
.96875 .01493 L
.97123 .01481 L
.97371 .01474 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell["This gives the dual wavelet.", "MathCaption",
  CellTags->{"S3.1.2", "2.31"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[Wavelet[Reverse[b33], 7],
PlotJoined -> True, PlotRange -> All,
PlotLabel -> \"dual psi_33(t)\"]\
\>", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.190476 0.309017 0.297645 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.39226 .01137 -12 -4.5 ]
[.39226 .01137 0 4.5 ]
[.39226 .16019 -24 -4.5 ]
[.39226 .16019 0 4.5 ]
[.39226 .45784 -18 -4.5 ]
[.39226 .45784 0 4.5 ]
[.39226 .60666 -6 -4.5 ]
[.39226 .60666 0 4.5 ]
[.5 .63053 -42 0 ]
[.5 .63053 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-2)] .02381 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-1)] .21429 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.40476 .01137 m
.41101 .01137 L
s
[(-1)] .39226 .01137 1 0 Mshowa
.40476 .16019 m
.41101 .16019 L
s
[(-0.5)] .39226 .16019 1 0 Mshowa
.40476 .45784 m
.41101 .45784 L
s
[(0.5)] .39226 .45784 1 0 Mshowa
.40476 .60666 m
.41101 .60666 L
s
[(1)] .39226 .60666 1 0 Mshowa
.125 Mabswid
.40476 .04114 m
.40851 .04114 L
s
.40476 .0709 m
.40851 .0709 L
s
.40476 .10067 m
.40851 .10067 L
s
.40476 .13043 m
.40851 .13043 L
s
.40476 .18996 m
.40851 .18996 L
s
.40476 .21972 m
.40851 .21972 L
s
.40476 .24949 m
.40851 .24949 L
s
.40476 .27925 m
.40851 .27925 L
s
.40476 .33878 m
.40851 .33878 L
s
.40476 .36855 m
.40851 .36855 L
s
.40476 .39831 m
.40851 .39831 L
s
.40476 .42807 m
.40851 .42807 L
s
.40476 .4876 m
.40851 .4876 L
s
.40476 .51737 m
.40851 .51737 L
s
.40476 .54713 m
.40851 .54713 L
s
.40476 .5769 m
.40851 .5769 L
s
.25 Mabswid
.40476 0 m
.40476 .61803 L
s
[(dual psi_33\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .30902 m
.0253 .30901 L
.02679 .309 L
.02827 .30899 L
.02976 .30896 L
.03125 .30893 L
.03274 .30889 L
.03423 .30885 L
.03571 .3088 L
.0372 .30874 L
.03869 .30868 L
.04018 .3086 L
.04167 .30853 L
.04315 .30844 L
.04464 .30835 L
.04613 .30825 L
.04762 .30814 L
.04911 .30803 L
.0506 .30791 L
.05208 .30779 L
.05357 .30765 L
.05506 .30751 L
.05655 .30737 L
.05804 .30722 L
.05952 .30705 L
.06101 .30689 L
.0625 .30671 L
.06399 .30653 L
.06548 .30635 L
.06696 .30615 L
.06845 .30595 L
.06994 .30574 L
.07143 .30553 L
.07292 .30531 L
.0744 .30508 L
.07589 .30484 L
.07738 .3046 L
.07887 .30435 L
.08036 .3041 L
.08185 .30384 L
.08333 .30357 L
.08482 .30329 L
.08631 .30301 L
.0878 .30272 L
.08929 .30242 L
.09077 .30212 L
.09226 .30181 L
.09375 .30149 L
.09524 .30117 L
.09673 .30084 L
Mistroke
.09821 .3005 L
.0997 .30016 L
.10119 .29981 L
.10268 .29945 L
.10417 .29908 L
.10565 .29871 L
.10714 .29833 L
.10863 .29795 L
.11012 .29756 L
.11161 .29716 L
.1131 .29675 L
.11458 .29634 L
.11607 .29592 L
.11756 .2955 L
.11905 .29506 L
.12054 .29463 L
.12202 .29418 L
.12351 .29373 L
.125 .29327 L
.12649 .2928 L
.12798 .29233 L
.12946 .29185 L
.13095 .29136 L
.13244 .29086 L
.13393 .29036 L
.13542 .28986 L
.1369 .28934 L
.13839 .28882 L
.13988 .28829 L
.14137 .28776 L
.14286 .28722 L
.14435 .28667 L
.14583 .28611 L
.14732 .28555 L
.14881 .28498 L
.1503 .28441 L
.15179 .28382 L
.15327 .28323 L
.15476 .28264 L
.15625 .28204 L
.15774 .28143 L
.15923 .28081 L
.16071 .28019 L
.1622 .27956 L
.16369 .27892 L
.16518 .27828 L
.16667 .27762 L
.16815 .27697 L
.16964 .2763 L
.17113 .27563 L
Mistroke
.17262 .27495 L
.17411 .27427 L
.1756 .27358 L
.17708 .27288 L
.17857 .27217 L
.18006 .27146 L
.18155 .27074 L
.18304 .27002 L
.18452 .26929 L
.18601 .26855 L
.1875 .2678 L
.18899 .26705 L
.19048 .26629 L
.19196 .26552 L
.19345 .26475 L
.19494 .26397 L
.19643 .26318 L
.19792 .26239 L
.1994 .26159 L
.20089 .26078 L
.20238 .25997 L
.20387 .25915 L
.20536 .25832 L
.20685 .25748 L
.20833 .25664 L
.20982 .25579 L
.21131 .25494 L
.2128 .25408 L
.21429 .25321 L
.21577 .25236 L
.21726 .25156 L
.21875 .25082 L
.22024 .25012 L
.22173 .24947 L
.22321 .24888 L
.2247 .24833 L
.22619 .24783 L
.22768 .24738 L
.22917 .24699 L
.23065 .24664 L
.23214 .24634 L
.23363 .24609 L
.23512 .2459 L
.23661 .24575 L
.2381 .24565 L
.23958 .2456 L
.24107 .24561 L
.24256 .24566 L
.24405 .24576 L
.24554 .24591 L
Mistroke
.24702 .24611 L
.24851 .24637 L
.25 .24667 L
.25149 .24702 L
.25298 .24742 L
.25446 .24787 L
.25595 .24838 L
.25744 .24893 L
.25893 .24953 L
.26042 .25018 L
.2619 .25088 L
.26339 .25163 L
.26488 .25244 L
.26637 .25329 L
.26786 .25419 L
.26935 .25514 L
.27083 .25614 L
.27232 .25719 L
.27381 .2583 L
.2753 .25945 L
.27679 .26065 L
.27827 .2619 L
.27976 .2632 L
.28125 .26455 L
.28274 .26595 L
.28423 .2674 L
.28571 .2689 L
.2872 .27046 L
.28869 .27206 L
.29018 .27371 L
.29167 .27541 L
.29315 .27716 L
.29464 .27896 L
.29613 .28081 L
.29762 .28271 L
.29911 .28466 L
.3006 .28666 L
.30208 .28871 L
.30357 .29081 L
.30506 .29296 L
.30655 .29516 L
.30804 .29742 L
.30952 .29972 L
.31101 .30207 L
.3125 .30447 L
.31399 .30692 L
.31548 .30942 L
.31696 .31197 L
.31845 .31457 L
.31994 .31722 L
Mistroke
.32143 .31992 L
.32292 .32267 L
.3244 .32547 L
.32589 .32832 L
.32738 .33122 L
.32887 .33417 L
.33036 .33717 L
.33185 .34022 L
.33333 .34332 L
.33482 .34647 L
.33631 .34967 L
.3378 .35291 L
.33929 .35621 L
.34077 .35956 L
.34226 .36296 L
.34375 .36641 L
.34524 .36991 L
.34673 .37346 L
.34821 .37706 L
.3497 .38071 L
.35119 .38441 L
.35268 .38816 L
.35417 .39196 L
.35565 .39581 L
.35714 .39971 L
.35863 .40365 L
.36012 .40765 L
.36161 .4117 L
.3631 .4158 L
.36458 .41995 L
.36607 .42415 L
.36756 .4284 L
.36905 .4327 L
.37054 .43705 L
.37202 .44144 L
.37351 .44589 L
.375 .45039 L
.37649 .45494 L
.37798 .45954 L
.37946 .46419 L
.38095 .46888 L
.38244 .47363 L
.38393 .47843 L
.38542 .48328 L
.3869 .48818 L
.38839 .49313 L
.38988 .49812 L
.39137 .50317 L
.39286 .50827 L
.39435 .51342 L
Mistroke
.39583 .51862 L
.39732 .52386 L
.39881 .52916 L
.4003 .53451 L
.40179 .53991 L
.40327 .54536 L
.40476 .55085 L
.40625 .55623 L
.40774 .56132 L
.40923 .56611 L
.41071 .57062 L
.4122 .57483 L
.41369 .57876 L
.41518 .58239 L
.41667 .58573 L
.41815 .58879 L
.41964 .59155 L
.42113 .59402 L
.42262 .5962 L
.42411 .59809 L
.4256 .59969 L
.42708 .60099 L
.42857 .60201 L
.43006 .60274 L
.43155 .60317 L
.43304 .60332 L
.43452 .60317 L
.43601 .60274 L
.4375 .60201 L
.43899 .60099 L
.44048 .59969 L
.44196 .59809 L
.44345 .5962 L
.44494 .59402 L
.44643 .59155 L
.44792 .58879 L
.4494 .58573 L
.45089 .58239 L
.45238 .57876 L
.45387 .57483 L
.45536 .57062 L
.45685 .56611 L
.45833 .56132 L
.45982 .55623 L
.46131 .55085 L
.4628 .54519 L
.46429 .53923 L
.46577 .53298 L
.46726 .52644 L
.46875 .51961 L
Mistroke
.47024 .51248 L
.47173 .50507 L
.47321 .49737 L
.4747 .48938 L
.47619 .48109 L
.47768 .47252 L
.47917 .46365 L
.48065 .4545 L
.48214 .44505 L
.48363 .43531 L
.48512 .42528 L
.48661 .41497 L
.4881 .40436 L
.48958 .39346 L
.49107 .38227 L
.49256 .37078 L
.49405 .35901 L
.49554 .34695 L
.49702 .3346 L
.49851 .32195 L
.5 .30902 L
.50149 .29608 L
.50298 .28344 L
.50446 .27108 L
.50595 .25902 L
.50744 .24725 L
.50893 .23577 L
.51042 .22458 L
.5119 .21368 L
.51339 .20307 L
.51488 .19275 L
.51637 .18272 L
.51786 .17298 L
.51935 .16354 L
.52083 .15438 L
.52232 .14552 L
.52381 .13694 L
.5253 .12866 L
.52679 .12066 L
.52827 .11296 L
.52976 .10555 L
.53125 .09843 L
.53274 .0916 L
.53423 .08506 L
.53571 .07881 L
.5372 .07285 L
.53869 .06718 L
.54018 .0618 L
.54167 .05672 L
.54315 .05192 L
Mistroke
.54464 .04742 L
.54613 .0432 L
.54762 .03928 L
.54911 .03564 L
.5506 .0323 L
.55208 .02925 L
.55357 .02649 L
.55506 .02402 L
.55655 .02184 L
.55804 .01995 L
.55952 .01835 L
.56101 .01704 L
.5625 .01602 L
.56399 .0153 L
.56548 .01486 L
.56696 .01472 L
.56845 .01486 L
.56994 .0153 L
.57143 .01602 L
.57292 .01704 L
.5744 .01835 L
.57589 .01995 L
.57738 .02184 L
.57887 .02402 L
.58036 .02649 L
.58185 .02925 L
.58333 .0323 L
.58482 .03564 L
.58631 .03928 L
.5878 .0432 L
.58929 .04742 L
.59077 .05192 L
.59226 .05672 L
.59375 .0618 L
.59524 .06718 L
.59673 .07268 L
.59821 .07813 L
.5997 .08352 L
.60119 .08887 L
.60268 .09417 L
.60417 .09942 L
.60565 .10462 L
.60714 .10976 L
.60863 .11486 L
.61012 .11991 L
.61161 .12491 L
.6131 .12986 L
.61458 .13475 L
.61607 .1396 L
.61756 .1444 L
Mistroke
.61905 .14915 L
.62054 .15385 L
.62202 .1585 L
.62351 .16309 L
.625 .16764 L
.62649 .17214 L
.62798 .17659 L
.62946 .18099 L
.63095 .18534 L
.63244 .18964 L
.63393 .19389 L
.63542 .19808 L
.6369 .20223 L
.63839 .20633 L
.63988 .21038 L
.64137 .21438 L
.64286 .21833 L
.64435 .22223 L
.64583 .22608 L
.64732 .22988 L
.64881 .23362 L
.6503 .23732 L
.65179 .24097 L
.65327 .24457 L
.65476 .24812 L
.65625 .25162 L
.65774 .25507 L
.65923 .25847 L
.66071 .26182 L
.6622 .26512 L
.66369 .26837 L
.66518 .27157 L
.66667 .27472 L
.66815 .27782 L
.66964 .28087 L
.67113 .28387 L
.67262 .28682 L
.67411 .28972 L
.6756 .29257 L
.67708 .29537 L
.67857 .29812 L
.68006 .30082 L
.68155 .30347 L
.68304 .30607 L
.68452 .30862 L
.68601 .31112 L
.6875 .31357 L
.68899 .31597 L
.69048 .31832 L
.69196 .32062 L
Mistroke
.69345 .32287 L
.69494 .32507 L
.69643 .32722 L
.69792 .32932 L
.6994 .33137 L
.70089 .33337 L
.70238 .33532 L
.70387 .33722 L
.70536 .33907 L
.70685 .34087 L
.70833 .34263 L
.70982 .34433 L
.71131 .34598 L
.7128 .34758 L
.71429 .34913 L
.71577 .35063 L
.71726 .35208 L
.71875 .35348 L
.72024 .35483 L
.72173 .35613 L
.72321 .35739 L
.7247 .35859 L
.72619 .35974 L
.72768 .36084 L
.72917 .36189 L
.73065 .36289 L
.73214 .36384 L
.73363 .36475 L
.73512 .3656 L
.73661 .3664 L
.7381 .36715 L
.73958 .36785 L
.74107 .3685 L
.74256 .36911 L
.74405 .36966 L
.74554 .37016 L
.74702 .37061 L
.74851 .37101 L
.75 .37137 L
.75149 .37167 L
.75298 .37192 L
.75446 .37212 L
.75595 .37227 L
.75744 .37238 L
.75893 .37243 L
.76042 .37243 L
.7619 .37238 L
.76339 .37229 L
.76488 .37214 L
.76637 .37194 L
Mistroke
.76786 .37169 L
.76935 .37139 L
.77083 .37105 L
.77232 .37065 L
.77381 .3702 L
.7753 .36971 L
.77679 .36916 L
.77827 .36856 L
.77976 .36791 L
.78125 .36722 L
.78274 .36647 L
.78423 .36567 L
.78571 .36483 L
.7872 .36396 L
.78869 .36309 L
.79018 .36224 L
.79167 .36139 L
.79315 .36055 L
.79464 .35972 L
.79613 .35889 L
.79762 .35807 L
.79911 .35725 L
.8006 .35645 L
.80208 .35565 L
.80357 .35485 L
.80506 .35406 L
.80655 .35328 L
.80804 .35251 L
.80952 .35175 L
.81101 .35099 L
.8125 .35023 L
.81399 .34949 L
.81548 .34875 L
.81696 .34802 L
.81845 .34729 L
.81994 .34657 L
.82143 .34586 L
.82292 .34515 L
.8244 .34446 L
.82589 .34376 L
.82738 .34308 L
.82887 .3424 L
.83036 .34173 L
.83185 .34107 L
.83333 .34041 L
.83482 .33976 L
.83631 .33911 L
.8378 .33848 L
.83929 .33785 L
.84077 .33722 L
Mistroke
.84226 .33661 L
.84375 .336 L
.84524 .3354 L
.84673 .3348 L
.84821 .33421 L
.8497 .33363 L
.85119 .33305 L
.85268 .33248 L
.85417 .33192 L
.85565 .33137 L
.85714 .33082 L
.85863 .33028 L
.86012 .32974 L
.86161 .32921 L
.8631 .32869 L
.86458 .32818 L
.86607 .32767 L
.86756 .32717 L
.86905 .32668 L
.87054 .32619 L
.87202 .32571 L
.87351 .32523 L
.875 .32477 L
.87649 .32431 L
.87798 .32385 L
.87946 .32341 L
.88095 .32297 L
.88244 .32254 L
.88393 .32211 L
.88542 .32169 L
.8869 .32128 L
.88839 .32087 L
.88988 .32048 L
.89137 .32008 L
.89286 .3197 L
.89435 .31932 L
.89583 .31895 L
.89732 .31859 L
.89881 .31823 L
.9003 .31788 L
.90179 .31753 L
.90327 .3172 L
.90476 .31687 L
.90625 .31654 L
.90774 .31622 L
.90923 .31591 L
.91071 .31561 L
.9122 .31532 L
.91369 .31503 L
.91518 .31474 L
Mistroke
.91667 .31447 L
.91815 .3142 L
.91964 .31394 L
.92113 .31368 L
.92262 .31343 L
.92411 .31319 L
.9256 .31295 L
.92708 .31273 L
.92857 .31251 L
.93006 .31229 L
.93155 .31208 L
.93304 .31188 L
.93452 .31169 L
.93601 .3115 L
.9375 .31132 L
.93899 .31115 L
.94048 .31098 L
.94196 .31082 L
.94345 .31067 L
.94494 .31052 L
.94643 .31038 L
.94792 .31025 L
.9494 .31012 L
.95089 .31 L
.95238 .30989 L
.95387 .30978 L
.95536 .30968 L
.95685 .30959 L
.95833 .30951 L
.95982 .30943 L
.96131 .30936 L
.9628 .30929 L
.96429 .30923 L
.96577 .30918 L
.96726 .30914 L
.96875 .3091 L
.97024 .30907 L
.97173 .30905 L
.97321 .30903 L
.9747 .30902 L
.97619 .30902 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " The function ",
  StyleBox["WaveletPacket", "MR"],
  " is not applicable for biorthogonal filters. \nWhen we have an IIR filter, \
we use the inverse wavelet or wavelet packet transform method to get the \
approximate values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " at dyadic points. This is the so\[Hyphen]called cascade algorithm. "
}], "Text",
  CellTags->{"S3.1.2", "2.32"}],

Cell["\<\
This generates the Meyer wavelet of order 2 using the inverse \
transform method.\
\>", "MathCaption",
  CellTags->{"S3.1.2", "2.33"}],

Cell["\<\
Wavelet[MeyerFilter[2, 10], 6,
InverseTransform -> True];\
\>", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"S3.1.2"],

Cell["This is the graph of the Meyer wavelet of order 2.", "MathCaption",
  CellTags->{"S3.1.2", "2.34"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotRange -> {{-5, 5}, All},
PlotJoined -> True, PlotLabel -> \"Meyer psi_2(t)\"]\
\>", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.350389 0.283538 [
[.1 .33789 -6 -9 ]
[.1 .33789 6 0 ]
[.3 .33789 -6 -9 ]
[.3 .33789 6 0 ]
[.7 .33789 -3 -9 ]
[.7 .33789 3 0 ]
[.9 .33789 -3 -9 ]
[.9 .33789 3 0 ]
[.4875 .06685 -12 -4.5 ]
[.4875 .06685 0 4.5 ]
[.4875 .20862 -24 -4.5 ]
[.4875 .20862 0 4.5 ]
[.4875 .49216 -18 -4.5 ]
[.4875 .49216 0 4.5 ]
[.5 .63053 -42 0 ]
[.5 .63053 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .35039 m
.1 .35664 L
s
[(-4)] .1 .33789 0 1 Mshowa
.3 .35039 m
.3 .35664 L
s
[(-2)] .3 .33789 0 1 Mshowa
.7 .35039 m
.7 .35664 L
s
[(2)] .7 .33789 0 1 Mshowa
.9 .35039 m
.9 .35664 L
s
[(4)] .9 .33789 0 1 Mshowa
.125 Mabswid
.15 .35039 m
.15 .35414 L
s
.2 .35039 m
.2 .35414 L
s
.25 .35039 m
.25 .35414 L
s
.35 .35039 m
.35 .35414 L
s
.4 .35039 m
.4 .35414 L
s
.45 .35039 m
.45 .35414 L
s
.55 .35039 m
.55 .35414 L
s
.6 .35039 m
.6 .35414 L
s
.65 .35039 m
.65 .35414 L
s
.75 .35039 m
.75 .35414 L
s
.8 .35039 m
.8 .35414 L
s
.85 .35039 m
.85 .35414 L
s
.05 .35039 m
.05 .35414 L
s
.95 .35039 m
.95 .35414 L
s
.25 Mabswid
0 .35039 m
1 .35039 L
s
.5 .06685 m
.50625 .06685 L
s
[(-1)] .4875 .06685 1 0 Mshowa
.5 .20862 m
.50625 .20862 L
s
[(-0.5)] .4875 .20862 1 0 Mshowa
.5 .49216 m
.50625 .49216 L
s
[(0.5)] .4875 .49216 1 0 Mshowa
.125 Mabswid
.5 .0952 m
.50375 .0952 L
s
.5 .12356 m
.50375 .12356 L
s
.5 .15191 m
.50375 .15191 L
s
.5 .18027 m
.50375 .18027 L
s
.5 .23697 m
.50375 .23697 L
s
.5 .26533 m
.50375 .26533 L
s
.5 .29368 m
.50375 .29368 L
s
.5 .32203 m
.50375 .32203 L
s
.5 .37874 m
.50375 .37874 L
s
.5 .4071 m
.50375 .4071 L
s
.5 .43545 m
.50375 .43545 L
s
.5 .4638 m
.50375 .4638 L
s
.5 .0385 m
.50375 .0385 L
s
.5 .01014 m
.50375 .01014 L
s
.5 .52051 m
.50375 .52051 L
s
.5 .54886 m
.50375 .54886 L
s
.5 .57722 m
.50375 .57722 L
s
.5 .60557 m
.50375 .60557 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Meyer psi_2\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .35024 m
.00156 .35031 L
.00312 .35038 L
.00469 .35045 L
.00625 .3505 L
.00781 .35059 L
.00937 .35066 L
.01094 .35073 L
.0125 .3508 L
.01406 .35095 L
.01562 .35109 L
.01719 .35123 L
.01875 .35134 L
.02031 .3515 L
.02187 .35162 L
.02344 .35174 L
.025 .35182 L
.02656 .35198 L
.02812 .35211 L
.02969 .35224 L
.03125 .35232 L
.03281 .35248 L
.03437 .35258 L
.03594 .35269 L
.0375 .35276 L
.03906 .35295 L
.04062 .35308 L
.04219 .35324 L
.04375 .35332 L
.04531 .35353 L
.04687 .35365 L
.04844 .35378 L
.05 .35382 L
.05156 .354 L
.05312 .35407 L
.05469 .35418 L
.05625 .35419 L
.05781 .35436 L
.05937 .35442 L
.06094 .35453 L
.0625 .35453 L
.06406 .35469 L
.06562 .35474 L
.06719 .35485 L
.06875 .35485 L
.07031 .35503 L
.07187 .3551 L
.07344 .35522 L
.075 .3552 L
.07656 .35533 L
Mistroke
.07812 .35532 L
.07969 .35537 L
.08125 .3553 L
.08281 .35539 L
.08437 .35537 L
.08594 .35541 L
.0875 .3553 L
.08906 .3553 L
.09062 .35516 L
.09219 .3551 L
.09375 .35492 L
.09531 .35487 L
.09687 .35474 L
.09844 .35465 L
.1 .35445 L
.10156 .3543 L
.10312 .35406 L
.10469 .35386 L
.10625 .35358 L
.10781 .35338 L
.10937 .35312 L
.11094 .35289 L
.1125 .35258 L
.11406 .35225 L
.11562 .35186 L
.11719 .3515 L
.11875 .35112 L
.12031 .35075 L
.12187 .35041 L
.12344 .35009 L
.125 .34977 L
.12656 .34938 L
.12812 .34903 L
.12969 .34867 L
.13125 .34837 L
.13281 .34797 L
.13437 .34766 L
.13594 .34732 L
.1375 .34703 L
.13906 .34657 L
.14062 .34619 L
.14219 .34577 L
.14375 .34546 L
.14531 .34494 L
.14687 .3446 L
.14844 .34422 L
.15 .34401 L
.15156 .34357 L
.15312 .34332 L
.15469 .34301 L
Mistroke
.15625 .34289 L
.15781 .34245 L
.15937 .34222 L
.16094 .34189 L
.1625 .34178 L
.16406 .34133 L
.16562 .34112 L
.16719 .34077 L
.16875 .34066 L
.17031 .34014 L
.17187 .33989 L
.17344 .33952 L
.175 .33945 L
.17656 .33906 L
.17812 .33899 L
.17969 .33878 L
.18125 .33887 L
.18281 .33857 L
.18437 .33855 L
.18594 .3384 L
.1875 .3386 L
.18906 .33849 L
.19062 .3387 L
.19219 .33876 L
.19375 .3391 L
.19531 .33908 L
.19687 .33931 L
.19844 .3394 L
.2 .33981 L
.20156 .33999 L
.20312 .34047 L
.20469 .34081 L
.20625 .34137 L
.20781 .34165 L
.20937 .34213 L
.21094 .34251 L
.2125 .34314 L
.21406 .34368 L
.21562 .34443 L
.21719 .34509 L
.21875 .34586 L
.22031 .34647 L
.22187 .34713 L
.22344 .34771 L
.225 .3484 L
.22656 .34911 L
.22812 .34986 L
.22969 .35056 L
.23125 .35124 L
.23281 .35194 L
Mistroke
.23437 .35254 L
.23594 .35311 L
.2375 .35366 L
.23906 .35446 L
.24062 .35516 L
.24219 .35589 L
.24375 .35649 L
.24531 .35739 L
.24687 .35804 L
.24844 .35871 L
.25 .35914 L
.25156 .36001 L
.25312 .36059 L
.25469 .36129 L
.25625 .36172 L
.25781 .3628 L
.25937 .36354 L
.26094 .36445 L
.2625 .36496 L
.26406 .36617 L
.26562 .36694 L
.26719 .36795 L
.26875 .36853 L
.27031 .36997 L
.27187 .37091 L
.27344 .37206 L
.275 .37254 L
.27656 .37372 L
.27812 .37422 L
.27969 .37504 L
.28125 .37524 L
.28281 .37633 L
.28437 .37685 L
.28594 .37779 L
.2875 .37797 L
.28906 .37883 L
.29062 .37896 L
.29219 .37952 L
.29375 .37937 L
.29531 .37992 L
.29687 .37982 L
.29844 .38009 L
.3 .37957 L
.30156 .37942 L
.30312 .37853 L
.30469 .37791 L
.30625 .3766 L
.30781 .37563 L
.30937 .37407 L
.31094 .37275 L
Mistroke
.3125 .37084 L
.31406 .36908 L
.31562 .36683 L
.31719 .36478 L
.31875 .36243 L
.32031 .3603 L
.32187 .35797 L
.32344 .3558 L
.325 .35353 L
.32656 .35134 L
.32812 .34912 L
.32969 .34688 L
.33125 .34478 L
.33281 .34269 L
.33437 .34076 L
.33594 .33853 L
.3375 .33644 L
.33906 .33411 L
.34062 .33205 L
.34219 .32973 L
.34375 .32795 L
.34531 .32618 L
.34687 .32509 L
.34844 .32386 L
.35 .3232 L
.35156 .32231 L
.35312 .32212 L
.35469 .32184 L
.35625 .32233 L
.35781 .32257 L
.35937 .32364 L
.36094 .32448 L
.3625 .3258 L
.36406 .3262 L
.36562 .32718 L
.36719 .32787 L
.36875 .32908 L
.37031 .32922 L
.37187 .33011 L
.37344 .33092 L
.375 .3322 L
.37656 .33206 L
.37812 .33254 L
.37969 .33297 L
.38125 .33383 L
.38281 .33291 L
.38437 .33269 L
.38594 .3326 L
.3875 .33329 L
.38906 .33213 L
Mistroke
.39062 .33173 L
.39219 .33105 L
.39375 .33079 L
.39531 .32782 L
.39687 .32538 L
.39844 .3225 L
.4 .32078 L
.40156 .31694 L
.40312 .31418 L
.40469 .31064 L
.40625 .30794 L
.40781 .30254 L
.40937 .29807 L
.41094 .29292 L
.4125 .28992 L
.41406 .28584 L
.41562 .28367 L
.41719 .28055 L
.41875 .27902 L
.42031 .27578 L
.42187 .27375 L
.42344 .27035 L
.425 .26935 L
.42656 .26836 L
.42812 .26938 L
.42969 .26895 L
.43125 .27028 L
.43281 .27157 L
.43437 .27407 L
.43594 .2751 L
.4375 .27803 L
.43906 .28272 L
.44062 .28896 L
.44219 .29444 L
.44375 .30116 L
.44531 .31028 L
.44687 .31988 L
.44844 .32888 L
.45 .33795 L
.45156 .35005 L
.45312 .36188 L
.45469 .374 L
.45625 .38555 L
.45781 .40113 L
.45937 .41539 L
.46094 .43019 L
.4625 .44209 L
.46406 .45721 L
.46562 .46929 L
.46719 .48312 L
Mistroke
.46875 .49389 L
.47031 .50949 L
.47187 .52175 L
.47344 .53646 L
.475 .54566 L
.47656 .55773 L
.47812 .56439 L
.47969 .57432 L
.48125 .57926 L
.48281 .58841 L
.48437 .59266 L
.48594 .60038 L
.4875 .6012 L
.48906 .60332 L
.49062 .59885 L
.49219 .59772 L
.49375 .59106 L
.49531 .58673 L
.49687 .5776 L
.49844 .57184 L
.5 .56046 L
.50156 .54901 L
.50313 .53248 L
.50469 .51837 L
.50625 .50061 L
.50781 .48301 L
.50938 .46278 L
.51094 .44446 L
.5125 .42419 L
.51406 .40266 L
.51563 .37971 L
.51719 .35692 L
.51875 .33401 L
.52031 .30902 L
.52188 .285 L
.52344 .26029 L
.525 .23848 L
.52656 .21469 L
.52813 .19428 L
.52969 .17144 L
.53125 .15252 L
.53281 .12998 L
.53438 .11224 L
.53594 .09143 L
.5375 .07779 L
.53906 .06209 L
.54063 .05384 L
.54219 .0414 L
.54375 .03571 L
.54531 .02556 L
Mistroke
.54688 .02242 L
.54844 .01472 L
.55 .01583 L
.55156 .01472 L
.55313 .02242 L
.55469 .02556 L
.55625 .03571 L
.55781 .0414 L
.55938 .05384 L
.56094 .06209 L
.5625 .07779 L
.56406 .09143 L
.56563 .11224 L
.56719 .12998 L
.56875 .15252 L
.57031 .17144 L
.57188 .19428 L
.57344 .21469 L
.575 .23848 L
.57656 .26029 L
.57813 .285 L
.57969 .30902 L
.58125 .33401 L
.58281 .35692 L
.58438 .37971 L
.58594 .40266 L
.5875 .42419 L
.58906 .44446 L
.59063 .46278 L
.59219 .48301 L
.59375 .50061 L
.59531 .51837 L
.59688 .53248 L
.59844 .54901 L
.6 .56046 L
.60156 .57184 L
.60313 .5776 L
.60469 .58673 L
.60625 .59106 L
.60781 .59772 L
.60938 .59885 L
.61094 .60332 L
.6125 .6012 L
.61406 .60038 L
.61563 .59266 L
.61719 .58841 L
.61875 .57926 L
.62031 .57432 L
.62188 .56439 L
.62344 .55773 L
Mistroke
.625 .54566 L
.62656 .53646 L
.62813 .52175 L
.62969 .50949 L
.63125 .49389 L
.63281 .48312 L
.63438 .46929 L
.63594 .45721 L
.6375 .44209 L
.63906 .43019 L
.64063 .41539 L
.64219 .40113 L
.64375 .38555 L
.64531 .374 L
.64688 .36188 L
.64844 .35005 L
.65 .33795 L
.65156 .32888 L
.65313 .31988 L
.65469 .31028 L
.65625 .30116 L
.65781 .29444 L
.65938 .28896 L
.66094 .28272 L
.6625 .27803 L
.66406 .2751 L
.66563 .27407 L
.66719 .27157 L
.66875 .27028 L
.67031 .26895 L
.67188 .26938 L
.67344 .26836 L
.675 .26935 L
.67656 .27035 L
.67813 .27375 L
.67969 .27578 L
.68125 .27902 L
.68281 .28055 L
.68438 .28367 L
.68594 .28584 L
.6875 .28992 L
.68906 .29292 L
.69063 .29807 L
.69219 .30254 L
.69375 .30794 L
.69531 .31064 L
.69688 .31418 L
.69844 .31694 L
.7 .32078 L
.70156 .3225 L
Mistroke
.70313 .32538 L
.70469 .32782 L
.70625 .33079 L
.70781 .33105 L
.70938 .33173 L
.71094 .33213 L
.7125 .33329 L
.71406 .3326 L
.71563 .33269 L
.71719 .33291 L
.71875 .33383 L
.72031 .33297 L
.72188 .33254 L
.72344 .33206 L
.725 .3322 L
.72656 .33092 L
.72813 .33011 L
.72969 .32922 L
.73125 .32908 L
.73281 .32787 L
.73438 .32718 L
.73594 .3262 L
.7375 .3258 L
.73906 .32448 L
.74063 .32364 L
.74219 .32257 L
.74375 .32233 L
.74531 .32184 L
.74688 .32212 L
.74844 .32231 L
.75 .3232 L
.75156 .32386 L
.75313 .32509 L
.75469 .32618 L
.75625 .32795 L
.75781 .32973 L
.75938 .33205 L
.76094 .33411 L
.7625 .33644 L
.76406 .33853 L
.76563 .34076 L
.76719 .34269 L
.76875 .34478 L
.77031 .34688 L
.77188 .34912 L
.77344 .35134 L
.775 .35353 L
.77656 .3558 L
.77813 .35797 L
.77969 .3603 L
Mistroke
.78125 .36243 L
.78281 .36478 L
.78438 .36683 L
.78594 .36908 L
.7875 .37084 L
.78906 .37275 L
.79063 .37407 L
.79219 .37563 L
.79375 .3766 L
.79531 .37791 L
.79688 .37853 L
.79844 .37942 L
.8 .37957 L
.80156 .38009 L
.80313 .37982 L
.80469 .37992 L
.80625 .37937 L
.80781 .37952 L
.80938 .37896 L
.81094 .37883 L
.8125 .37797 L
.81406 .37779 L
.81563 .37685 L
.81719 .37633 L
.81875 .37524 L
.82031 .37504 L
.82188 .37422 L
.82344 .37372 L
.825 .37254 L
.82656 .37206 L
.82813 .37091 L
.82969 .36997 L
.83125 .36853 L
.83281 .36795 L
.83438 .36694 L
.83594 .36617 L
.8375 .36496 L
.83906 .36445 L
.84063 .36354 L
.84219 .3628 L
.84375 .36172 L
.84531 .36129 L
.84688 .36059 L
.84844 .36001 L
.85 .35914 L
.85156 .35871 L
.85313 .35804 L
.85469 .35739 L
.85625 .35649 L
.85781 .35589 L
Mistroke
.85938 .35516 L
.86094 .35446 L
.8625 .35366 L
.86406 .35311 L
.86563 .35254 L
.86719 .35194 L
.86875 .35124 L
.87031 .35056 L
.87188 .34986 L
.87344 .34911 L
.875 .3484 L
.87656 .34771 L
.87813 .34713 L
.87969 .34647 L
.88125 .34586 L
.88281 .34509 L
.88438 .34443 L
.88594 .34368 L
.8875 .34314 L
.88906 .34251 L
.89063 .34213 L
.89219 .34165 L
.89375 .34137 L
.89531 .34081 L
.89688 .34047 L
.89844 .33999 L
.9 .33981 L
.90156 .3394 L
.90313 .33931 L
.90469 .33908 L
.90625 .3391 L
.90781 .33876 L
.90938 .3387 L
.91094 .33849 L
.9125 .3386 L
.91406 .3384 L
.91563 .33855 L
.91719 .33857 L
.91875 .33887 L
.92031 .33878 L
.92188 .33899 L
.92344 .33906 L
.925 .33945 L
.92656 .33952 L
.92813 .33989 L
.92969 .34014 L
.93125 .34066 L
.93281 .34077 L
.93438 .34112 L
.93594 .34133 L
Mistroke
.9375 .34178 L
.93906 .34189 L
.94063 .34222 L
.94219 .34245 L
.94375 .34289 L
.94531 .34301 L
.94688 .34332 L
.94844 .34357 L
.95 .34401 L
.95156 .34422 L
.95313 .3446 L
.95469 .34494 L
.95625 .34546 L
.95781 .34577 L
.95938 .34619 L
.96094 .34657 L
.9625 .34703 L
.96406 .34732 L
.96563 .34766 L
.96719 .34797 L
.96875 .34837 L
.97031 .34867 L
.97188 .34903 L
.97344 .34938 L
.975 .34977 L
.97656 .35009 L
.97813 .35041 L
.97969 .35075 L
.98125 .35112 L
.98281 .3515 L
.98438 .35186 L
.98594 .35225 L
.9875 .35258 L
.98906 .35289 L
.99063 .35312 L
.99219 .35338 L
.99375 .35358 L
.99531 .35386 L
.99688 .35406 L
.99844 .3543 L
1 .35445 L
Mfstroke
1 .35445 m
1 .35445 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "We get the spline wavelet packet ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_2\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " using the truncated filter and the inverse transform method."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.35"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[WaveletPacket[2, SplineFilter[4, 9],
6, InverseTransform -> True], PlotJoined -> True,
PlotRange -> {{-5, 5}, All}, PlotLabel ->
\"fourth order spline wavelet packet w_2(t)\"]\
\>", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.309017 0.23055 [
[.1 .29652 -6 -9 ]
[.1 .29652 6 0 ]
[.3 .29652 -6 -9 ]
[.3 .29652 6 0 ]
[.7 .29652 -3 -9 ]
[.7 .29652 3 0 ]
[.9 .29652 -3 -9 ]
[.9 .29652 3 0 ]
[.4875 .07847 -12 -4.5 ]
[.4875 .07847 0 4.5 ]
[.4875 .19374 -24 -4.5 ]
[.4875 .19374 0 4.5 ]
[.4875 .42429 -18 -4.5 ]
[.4875 .42429 0 4.5 ]
[.4875 .53957 -6 -4.5 ]
[.4875 .53957 0 4.5 ]
[.5 .63053 -123 0 ]
[.5 .63053 123 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .30902 m
.1 .31527 L
s
[(-4)] .1 .29652 0 1 Mshowa
.3 .30902 m
.3 .31527 L
s
[(-2)] .3 .29652 0 1 Mshowa
.7 .30902 m
.7 .31527 L
s
[(2)] .7 .29652 0 1 Mshowa
.9 .30902 m
.9 .31527 L
s
[(4)] .9 .29652 0 1 Mshowa
.125 Mabswid
.15 .30902 m
.15 .31277 L
s
.2 .30902 m
.2 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.4 .30902 m
.4 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.6 .30902 m
.6 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.8 .30902 m
.8 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.05 .30902 m
.05 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .07847 m
.50625 .07847 L
s
[(-1)] .4875 .07847 1 0 Mshowa
.5 .19374 m
.50625 .19374 L
s
[(-0.5)] .4875 .19374 1 0 Mshowa
.5 .42429 m
.50625 .42429 L
s
[(0.5)] .4875 .42429 1 0 Mshowa
.5 .53957 m
.50625 .53957 L
s
[(1)] .4875 .53957 1 0 Mshowa
.125 Mabswid
.5 .10152 m
.50375 .10152 L
s
.5 .12458 m
.50375 .12458 L
s
.5 .14763 m
.50375 .14763 L
s
.5 .17069 m
.50375 .17069 L
s
.5 .2168 m
.50375 .2168 L
s
.5 .23985 m
.50375 .23985 L
s
.5 .26291 m
.50375 .26291 L
s
.5 .28596 m
.50375 .28596 L
s
.5 .33207 m
.50375 .33207 L
s
.5 .35513 m
.50375 .35513 L
s
.5 .37818 m
.50375 .37818 L
s
.5 .40124 m
.50375 .40124 L
s
.5 .44735 m
.50375 .44735 L
s
.5 .4704 m
.50375 .4704 L
s
.5 .49346 m
.50375 .49346 L
s
.5 .51651 m
.50375 .51651 L
s
.5 .05541 m
.50375 .05541 L
s
.5 .03236 m
.50375 .03236 L
s
.5 .0093 m
.50375 .0093 L
s
.5 .56262 m
.50375 .56262 L
s
.5 .58568 m
.50375 .58568 L
s
.5 .60873 m
.50375 .60873 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(fourth order spline wavelet packet w_2\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .30932 m
.00156 .30937 L
.00312 .30941 L
.00469 .30944 L
.00625 .30945 L
.00781 .30944 L
.00937 .30942 L
.01094 .30939 L
.0125 .30933 L
.01406 .30928 L
.01562 .3092 L
.01719 .30914 L
.01875 .30907 L
.02031 .30899 L
.02187 .30888 L
.02344 .30879 L
.025 .3087 L
.02656 .30863 L
.02812 .30856 L
.02969 .30853 L
.03125 .30855 L
.03281 .30859 L
.03437 .30868 L
.03594 .30876 L
.0375 .30889 L
.03906 .30903 L
.04062 .3092 L
.04219 .30934 L
.04375 .30949 L
.04531 .30966 L
.04687 .30988 L
.04844 .31005 L
.05 .31018 L
.05156 .3103 L
.05312 .31038 L
.05469 .31038 L
.05625 .31027 L
.05781 .31015 L
.05937 .30994 L
.06094 .30974 L
.0625 .30942 L
.06406 .30912 L
.06562 .30871 L
.06719 .30836 L
.06875 .30791 L
.07031 .3075 L
.07187 .30699 L
.07344 .3066 L
.075 .30622 L
.07656 .30592 L
Mistroke
.07812 .30566 L
.07969 .30555 L
.08125 .30559 L
.08281 .30567 L
.08437 .30585 L
.08594 .30609 L
.0875 .30654 L
.08906 .30697 L
.09062 .3076 L
.09219 .30819 L
.09375 .30903 L
.09531 .30976 L
.09687 .31065 L
.09844 .31137 L
.1 .31222 L
.10156 .31287 L
.10312 .31358 L
.10469 .31407 L
.10625 .31452 L
.10781 .31481 L
.10937 .31504 L
.11094 .31509 L
.1125 .31496 L
.11406 .31475 L
.11562 .31434 L
.11719 .31384 L
.11875 .31306 L
.12031 .31237 L
.12187 .31146 L
.12344 .31066 L
.125 .30959 L
.12656 .30873 L
.12812 .30769 L
.12969 .30684 L
.13125 .30578 L
.13281 .305 L
.13437 .30415 L
.13594 .30355 L
.1375 .3029 L
.13906 .3025 L
.14062 .30216 L
.14219 .30203 L
.14375 .302 L
.14531 .30206 L
.14687 .30225 L
.14844 .30253 L
.15 .30305 L
.15156 .30353 L
.15312 .30427 L
.15469 .305 L
Mistroke
.15625 .30607 L
.15781 .30693 L
.15937 .30802 L
.16094 .30891 L
.1625 .31011 L
.16406 .31104 L
.16562 .31216 L
.16719 .31305 L
.16875 .31416 L
.17031 .315 L
.17187 .3159 L
.17344 .31652 L
.175 .31709 L
.17656 .31745 L
.17812 .31765 L
.17969 .31761 L
.18125 .3173 L
.18281 .31696 L
.18437 .31635 L
.18594 .3157 L
.1875 .31462 L
.18906 .31365 L
.19062 .31229 L
.19219 .31103 L
.19375 .3093 L
.19531 .30789 L
.19687 .3062 L
.19844 .30487 L
.2 .30326 L
.20156 .30207 L
.20312 .30076 L
.20469 .29985 L
.20625 .2989 L
.20781 .29828 L
.20937 .29778 L
.21094 .29761 L
.2125 .29772 L
.21406 .298 L
.21562 .29864 L
.21719 .29943 L
.21875 .3007 L
.22031 .30182 L
.22187 .3033 L
.22344 .30462 L
.225 .30646 L
.22656 .30793 L
.22812 .30977 L
.22969 .31132 L
.23125 .31333 L
.23281 .31485 L
Mistroke
.23437 .31655 L
.23594 .31779 L
.2375 .31921 L
.23906 .32017 L
.24062 .3211 L
.24219 .32161 L
.24375 .32205 L
.24531 .32229 L
.24687 .32234 L
.24844 .32216 L
.25 .32157 L
.25156 .32096 L
.25312 .31987 L
.25469 .3187 L
.25625 .31684 L
.25781 .31529 L
.25937 .31327 L
.26094 .31156 L
.2625 .30919 L
.26406 .30729 L
.26562 .30491 L
.26719 .30298 L
.26875 .30054 L
.27031 .29861 L
.27187 .29647 L
.27344 .29496 L
.275 .29348 L
.27656 .29248 L
.27812 .29173 L
.27969 .29154 L
.28125 .29188 L
.28281 .29238 L
.28437 .2934 L
.28594 .29459 L
.2875 .29669 L
.28906 .29862 L
.29062 .30138 L
.29219 .30397 L
.29375 .30758 L
.29531 .31057 L
.29687 .3142 L
.29844 .31712 L
.3 .32066 L
.30156 .32334 L
.30312 .3263 L
.30469 .32841 L
.30625 .33064 L
.30781 .33212 L
.30937 .3334 L
.31094 .33394 L
Mistroke
.3125 .33396 L
.31406 .33353 L
.31562 .33239 L
.31719 .33087 L
.31875 .3284 L
.32031 .32617 L
.32187 .32317 L
.32344 .32046 L
.325 .31668 L
.32656 .31363 L
.32812 .30975 L
.32969 .30647 L
.33125 .30223 L
.33281 .29903 L
.33437 .29541 L
.33594 .29277 L
.3375 .28971 L
.33906 .28766 L
.34062 .2856 L
.34219 .28441 L
.34375 .28335 L
.34531 .28277 L
.34687 .28259 L
.34844 .28293 L
.35 .28413 L
.35156 .2854 L
.35312 .28765 L
.35469 .2901 L
.35625 .29392 L
.35781 .29709 L
.35937 .3012 L
.36094 .30471 L
.3625 .30958 L
.36406 .31347 L
.36562 .31837 L
.36719 .32242 L
.36875 .32755 L
.37031 .33154 L
.37187 .3359 L
.37344 .33898 L
.375 .34208 L
.37656 .3441 L
.37812 .34567 L
.37969 .34613 L
.38125 .34572 L
.38281 .34503 L
.38437 .34343 L
.38594 .34142 L
.3875 .33774 L
.38906 .33434 L
Mistroke
.39062 .32936 L
.39219 .32447 L
.39375 .31757 L
.39531 .31201 L
.39687 .30539 L
.39844 .30007 L
.4 .29333 L
.40156 .28839 L
.40312 .2827 L
.40469 .27847 L
.40625 .27334 L
.40781 .26959 L
.40937 .26572 L
.41094 .26338 L
.4125 .26149 L
.41406 .26063 L
.41562 .26071 L
.41719 .26215 L
.41875 .26511 L
.42031 .26749 L
.42187 .27072 L
.42344 .27389 L
.425 .27944 L
.42656 .28373 L
.42812 .29005 L
.42969 .29602 L
.43125 .30541 L
.43281 .31321 L
.43437 .32306 L
.43594 .331 L
.4375 .34135 L
.43906 .34954 L
.44062 .35913 L
.44219 .36582 L
.44375 .37344 L
.44531 .38012 L
.44687 .38769 L
.44844 .39285 L
.45 .39597 L
.45156 .39823 L
.45312 .39794 L
.45469 .3951 L
.45625 .38656 L
.45781 .37813 L
.45937 .3654 L
.46094 .3534 L
.4625 .33521 L
.46406 .31915 L
.46562 .29799 L
.46719 .28052 L
Mistroke
.46875 .25798 L
.47031 .23798 L
.47187 .2137 L
.47344 .19484 L
.475 .17594 L
.47656 .16122 L
.47812 .14813 L
.47969 .14181 L
.48125 .1422 L
.48281 .14582 L
.48437 .15543 L
.48594 .16726 L
.4875 .18871 L
.48906 .2098 L
.49062 .23996 L
.49219 .26702 L
.49375 .30382 L
.49531 .33731 L
.49687 .37942 L
.49844 .41373 L
.5 .45159 L
.50156 .4818 L
.50313 .51285 L
.50469 .53275 L
.50625 .5469 L
.50781 .5533 L
.50938 .55347 L
.51094 .54734 L
.5125 .53 L
.51406 .50957 L
.51563 .47729 L
.51719 .44602 L
.51875 .40158 L
.52031 .3596 L
.52188 .30505 L
.52344 .25899 L
.525 .20569 L
.52656 .16218 L
.52813 .1145 L
.52969 .08099 L
.53125 .05061 L
.53281 .03212 L
.53438 .01834 L
.53594 .01472 L
.5375 .02134 L
.53906 .03512 L
.54063 .06118 L
.54219 .0892 L
.54375 .13119 L
.54531 .17318 L
Mistroke
.54688 .22985 L
.54844 .27942 L
.55 .33861 L
.55156 .38819 L
.55313 .44486 L
.55469 .48684 L
.55625 .52883 L
.55781 .55686 L
.55938 .58291 L
.56094 .59669 L
.5625 .60332 L
.56406 .59969 L
.56563 .58591 L
.56719 .56742 L
.56875 .53705 L
.57031 .50353 L
.57188 .45586 L
.57344 .41234 L
.575 .35905 L
.57656 .31298 L
.57813 .25843 L
.57969 .21646 L
.58125 .17202 L
.58281 .14074 L
.58438 .10846 L
.58594 .08804 L
.5875 .07069 L
.58906 .06456 L
.59063 .06474 L
.59219 .07114 L
.59375 .08529 L
.59531 .10519 L
.59688 .13623 L
.59844 .16645 L
.6 .2043 L
.60156 .23862 L
.60313 .28072 L
.60469 .31421 L
.60625 .35101 L
.60781 .37807 L
.60938 .40824 L
.61094 .42932 L
.6125 .45077 L
.61406 .46261 L
.61563 .47222 L
.61719 .47583 L
.61875 .47622 L
.62031 .4699 L
.62188 .45681 L
.62344 .4421 L
Mistroke
.625 .42319 L
.62656 .40433 L
.62813 .38005 L
.62969 .36005 L
.63125 .33751 L
.63281 .32005 L
.63438 .29889 L
.63594 .28283 L
.6375 .26464 L
.63906 .25264 L
.64063 .2399 L
.64219 .23148 L
.64375 .22293 L
.64531 .2201 L
.64688 .21981 L
.64844 .22206 L
.65 .22519 L
.65156 .23034 L
.65313 .23791 L
.65469 .24459 L
.65625 .25222 L
.65781 .25891 L
.65938 .26849 L
.66094 .27669 L
.6625 .28703 L
.66406 .29497 L
.66563 .30482 L
.66719 .31262 L
.66875 .32202 L
.67031 .32799 L
.67188 .3343 L
.67344 .33859 L
.675 .34414 L
.67656 .34731 L
.67813 .35055 L
.67969 .35293 L
.68125 .35589 L
.68281 .35733 L
.68438 .35741 L
.68594 .35654 L
.6875 .35465 L
.68906 .35232 L
.69063 .34844 L
.69219 .34469 L
.69375 .33956 L
.69531 .33533 L
.69688 .32965 L
.69844 .3247 L
.7 .31796 L
.70156 .31264 L
Mistroke
.70313 .30602 L
.70469 .30046 L
.70625 .29356 L
.70781 .28867 L
.70938 .28369 L
.71094 .2803 L
.7125 .27661 L
.71406 .2746 L
.71563 .27301 L
.71719 .27231 L
.71875 .2719 L
.72031 .27236 L
.72188 .27394 L
.72344 .27595 L
.725 .27905 L
.72656 .28213 L
.72813 .28649 L
.72969 .29048 L
.73125 .29561 L
.73281 .29966 L
.73438 .30456 L
.73594 .30845 L
.7375 .31333 L
.73906 .31684 L
.74063 .32094 L
.74219 .32411 L
.74375 .32793 L
.74531 .33038 L
.74688 .33264 L
.74844 .33391 L
.75 .33511 L
.75156 .33544 L
.75313 .33526 L
.75469 .33468 L
.75625 .33362 L
.75781 .33243 L
.75938 .33038 L
.76094 .32832 L
.7625 .32527 L
.76406 .32263 L
.76563 .31901 L
.76719 .3158 L
.76875 .31156 L
.77031 .30829 L
.77188 .30441 L
.77344 .30135 L
.775 .29758 L
.77656 .29486 L
.77813 .29186 L
.77969 .28964 L
Mistroke
.78125 .28716 L
.78281 .28564 L
.78438 .2845 L
.78594 .28408 L
.7875 .28409 L
.78906 .28464 L
.79063 .28591 L
.79219 .2874 L
.79375 .28962 L
.79531 .29174 L
.79688 .29469 L
.79844 .29737 L
.8 .30091 L
.80156 .30383 L
.80313 .30746 L
.80469 .31046 L
.80625 .31406 L
.80781 .31665 L
.80938 .31941 L
.81094 .32134 L
.8125 .32344 L
.81406 .32464 L
.81563 .32566 L
.81719 .32615 L
.81875 .3265 L
.82031 .32631 L
.82188 .32555 L
.82344 .32456 L
.825 .32307 L
.82656 .32156 L
.82813 .31942 L
.82969 .31749 L
.83125 .31506 L
.83281 .31312 L
.83438 .31074 L
.83594 .30884 L
.8375 .30647 L
.83906 .30476 L
.84063 .30275 L
.84219 .30119 L
.84375 .29934 L
.84531 .29816 L
.84688 .29707 L
.84844 .29647 L
.85 .29587 L
.85156 .29569 L
.85313 .29575 L
.85469 .29598 L
.85625 .29642 L
.85781 .29694 L
Mistroke
.85938 .29787 L
.86094 .29882 L
.8625 .30025 L
.86406 .30149 L
.86563 .30319 L
.86719 .3047 L
.86875 .30671 L
.87031 .30826 L
.87188 .31011 L
.87344 .31157 L
.875 .31341 L
.87656 .31474 L
.87813 .31622 L
.87969 .31733 L
.88125 .3186 L
.88281 .31939 L
.88438 .32003 L
.88594 .32032 L
.8875 .32043 L
.88906 .32026 L
.89063 .31976 L
.89219 .31914 L
.89375 .31819 L
.89531 .31727 L
.89688 .31596 L
.89844 .31477 L
.9 .31317 L
.90156 .31183 L
.90313 .31015 L
.90469 .30873 L
.90625 .30701 L
.90781 .30575 L
.90938 .30439 L
.91094 .30342 L
.9125 .30234 L
.91406 .30169 L
.91563 .30108 L
.91719 .30073 L
.91875 .30042 L
.92031 .30039 L
.92188 .30059 L
.92344 .30094 L
.925 .30151 L
.92656 .30213 L
.92813 .30303 L
.92969 .30388 L
.93125 .30498 L
.93281 .30587 L
.93438 .307 L
.93594 .30792 L
Mistroke
.9375 .30912 L
.93906 .31002 L
.94063 .3111 L
.94219 .31196 L
.94375 .31303 L
.94531 .31376 L
.94688 .3145 L
.94844 .31498 L
.95 .3155 L
.95156 .31578 L
.95313 .31598 L
.95469 .31603 L
.95625 .316 L
.95781 .31587 L
.95938 .31553 L
.96094 .31513 L
.9625 .31448 L
.96406 .31389 L
.96563 .31303 L
.96719 .31225 L
.96875 .31119 L
.97031 .31034 L
.97188 .3093 L
.97344 .30844 L
.975 .30737 L
.97656 .30657 L
.97813 .30567 L
.97969 .30497 L
.98125 .30419 L
.98281 .3037 L
.98438 .30328 L
.98594 .30307 L
.9875 .30294 L
.98906 .303 L
.99063 .30322 L
.99219 .30352 L
.99375 .30397 L
.99531 .30445 L
.99688 .30516 L
.99844 .30582 L
1 .30666 L
Mfstroke
1 .30666 m
1 .30666 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Interpolation\\\\\\\"\\\"\
, \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to interpolate "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InterpolationDomain\\\\\\\
\"\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"{-100,\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"100}\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("interpolation domain "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InverseTransform\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to use inverse transform method "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.36"}],

Cell[TextData[{
  "Options for ",
  StyleBox["ScalingFunction", "MR"],
  ", ",
  StyleBox["Wavelet", "MR"],
  ", and ",
  StyleBox["WaveletPacket", "MR"],
  "."
}], "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "In contrast to Daubechies wavelets, the infinitely supported Shannon, \
Meyer, and spline wavelets all have analytic expressions and can be \
determined directly. For Meyer wavelets, the analytic expression in the \
Fourier domain is known and we need to perform a Fourier transform to get ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". The transform is approximated by a finite sum with intervals of length ",
  
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\((3  i)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "; the user can determine the interval length by choosing the integer ",
  Cell[BoxData[
      \(TraditionalForm\`i\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". Spline scaling functions and wavelets of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " are superpositions of ",
  Cell[BoxData[
      \(TraditionalForm\`n\^th\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " order ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "\[Hyphen]spline functions: "
}], "Text",
  CellTags->{"S3.1.2", "2.37"}],

Cell[BoxData[
    FormBox[
      RowBox[{"\[Phi]", \((t)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((t - k)\), 
        \("and"\), "\[Psi]", \((t)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = -\[Infinity]\), "\[Infinity]",
          LimitsPositioning->True], \(d\_k\), \(\[Beta]\_n\), \((2  t - k)\), 
        "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.1.2", "2.38"}],

Cell[TextData[{
  "They are approximated by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "-", 
              StyleBox[\("kmax"\),
                "TI"]}], 
            StyleBox[\("kmax"\),
              "TI"],
            LimitsPositioning->True], \(c\_k\), \(\[Beta]\_n\), \((t - k)\)}],
         TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", \((t)\), "=", 
          UnderoverscriptBox["\[Sum]", \(k = k\_0\), 
            RowBox[{
              StyleBox[\("kmax"\),
                "TI"], "+", "1"}],
            LimitsPositioning->True], \(d\_k\), \(\[Beta]\_n\), \((2  t - k)
          \)}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_0\), "=", "-", 
          StyleBox[\("kmax"\),
            "TI"], "+", "1"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " odd and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_0\), "=", "-", 
          StyleBox[\("kmax"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " even. If we want to control the magnitude of the terms we neglect, we can \
specify a small positive number ",
  StyleBox["tol", "TI"],
  "; ",
  StyleBox["kmax", "TI"],
  " is determined by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            SubscriptBox["c", 
              RowBox[{
                StyleBox[\("kmax"\),
                  "TI"], "+", "1"}]], "\[RightBracketingBar]"}], "<", 
          StyleBox[\("tol"\),
            "TI"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.39"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ShannonPhi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give Shannon "\), 
                    StyleBox[\(\[Phi] \((t)\)\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ShannonPsi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give Shannon "\), 
                    StyleBox[\(\[Psi] \((t)\)\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MeyerPhi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"i\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give Meyer "\), 
                    StyleBox[\(\[Phi] \((t)\)\),
                      "InlineFormula"], \(" of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" with summation interval "\), 
                    StyleBox[\(2 \[Pi]/\((3 i)\)\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MeyerPsi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"i\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give Meyer "\), 
                    StyleBox[\(\[Psi] \((t)\)\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SplinePhi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"kmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give spline "\), 
                    StyleBox[\(\[Phi] \((t)\)\),
                      "InlineFormula"], \(" of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" as a summation of "\), 
                    StyleBox[
                      RowBox[{"2", 
                        StyleBox[\("kmax"\),
                          "TI"], "+", "1"}],
                      "InlineFormula"], \(" "\), 
                    StyleBox["B",
                      "InlineFormula"], \("\[Hyphen]splines "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SplinePhi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"tol\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give spline "\), 
                    StyleBox[\(\[Phi] \((t)\)\),
                      "InlineFormula"], \(" of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" neglecting coefficients "\), 
                    StyleBox[
                      RowBox[{
                      "\[VerticalSeparator]", \(c\_k\), 
                        "\[VerticalSeparator]", "<", 
                        StyleBox[\("tol"\),
                          "TI"]}],
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SplinePsi[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"kmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give spline "\), 
                    StyleBox[\(\[Psi] \((t)\)\),
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.40"}],

Cell[TextData[{
  "Infinitely supported ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "Note that the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`d\_k\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " do not necessarily decrease monotonically, so it makes little sense to \
specify the third argument in ",
  StyleBox["SplinePsi", "MR"],
  " as ",
  StyleBox["tol", "TI"],
  "; it should be a nonnegative integer ",
  StyleBox["kmax", "TI"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.41"}],

Cell["This is the Shannon wavelet.", "MathCaption",
  CellTags->{"S3.1.2", "2.42"}],

Cell[CellGroupData[{

Cell["\<\
Plot[ShannonPsi[t], {t, -10, 10}, PlotRange -> All,
AxesLabel -> {\"t\", \"Shannon psi(t)\"}]\
\>", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.33582 0.321349 [
[.02381 .32332 -9 -9 ]
[.02381 .32332 9 0 ]
[.2619 .32332 -6 -9 ]
[.2619 .32332 6 0 ]
[.7381 .32332 -3 -9 ]
[.7381 .32332 3 0 ]
[.97619 .32332 -6 -9 ]
[.97619 .32332 6 0 ]
[1.025 .33582 0 -4.5 ]
[1.025 .33582 6 4.5 ]
[.4875 .01447 -12 -4.5 ]
[.4875 .01447 0 4.5 ]
[.4875 .09481 -30 -4.5 ]
[.4875 .09481 0 4.5 ]
[.4875 .17515 -24 -4.5 ]
[.4875 .17515 0 4.5 ]
[.4875 .25548 -30 -4.5 ]
[.4875 .25548 0 4.5 ]
[.4875 .41616 -24 -4.5 ]
[.4875 .41616 0 4.5 ]
[.4875 .49649 -18 -4.5 ]
[.4875 .49649 0 4.5 ]
[.4875 .57683 -24 -4.5 ]
[.4875 .57683 0 4.5 ]
[.5 .64303 -42 0 ]
[.5 .64303 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .33582 m
.02381 .34207 L
s
[(-10)] .02381 .32332 0 1 Mshowa
.2619 .33582 m
.2619 .34207 L
s
[(-5)] .2619 .32332 0 1 Mshowa
.7381 .33582 m
.7381 .34207 L
s
[(5)] .7381 .32332 0 1 Mshowa
.97619 .33582 m
.97619 .34207 L
s
[(10)] .97619 .32332 0 1 Mshowa
.125 Mabswid
.07143 .33582 m
.07143 .33957 L
s
.11905 .33582 m
.11905 .33957 L
s
.16667 .33582 m
.16667 .33957 L
s
.21429 .33582 m
.21429 .33957 L
s
.30952 .33582 m
.30952 .33957 L
s
.35714 .33582 m
.35714 .33957 L
s
.40476 .33582 m
.40476 .33957 L
s
.45238 .33582 m
.45238 .33957 L
s
.54762 .33582 m
.54762 .33957 L
s
.59524 .33582 m
.59524 .33957 L
s
.64286 .33582 m
.64286 .33957 L
s
.69048 .33582 m
.69048 .33957 L
s
.78571 .33582 m
.78571 .33957 L
s
.83333 .33582 m
.83333 .33957 L
s
.88095 .33582 m
.88095 .33957 L
s
.92857 .33582 m
.92857 .33957 L
s
.25 Mabswid
0 .33582 m
1 .33582 L
s
[(t)] 1.025 .33582 -1 0 Mshowa
.5 .01447 m
.50625 .01447 L
s
[(-1)] .4875 .01447 1 0 Mshowa
.5 .09481 m
.50625 .09481 L
s
[(-0.75)] .4875 .09481 1 0 Mshowa
.5 .17515 m
.50625 .17515 L
s
[(-0.5)] .4875 .17515 1 0 Mshowa
.5 .25548 m
.50625 .25548 L
s
[(-0.25)] .4875 .25548 1 0 Mshowa
.5 .41616 m
.50625 .41616 L
s
[(0.25)] .4875 .41616 1 0 Mshowa
.5 .49649 m
.50625 .49649 L
s
[(0.5)] .4875 .49649 1 0 Mshowa
.5 .57683 m
.50625 .57683 L
s
[(0.75)] .4875 .57683 1 0 Mshowa
.125 Mabswid
.5 .03054 m
.50375 .03054 L
s
.5 .04661 m
.50375 .04661 L
s
.5 .06267 m
.50375 .06267 L
s
.5 .07874 m
.50375 .07874 L
s
.5 .11088 m
.50375 .11088 L
s
.5 .12694 m
.50375 .12694 L
s
.5 .14301 m
.50375 .14301 L
s
.5 .15908 m
.50375 .15908 L
s
.5 .19121 m
.50375 .19121 L
s
.5 .20728 m
.50375 .20728 L
s
.5 .22335 m
.50375 .22335 L
s
.5 .23942 m
.50375 .23942 L
s
.5 .27155 m
.50375 .27155 L
s
.5 .28762 m
.50375 .28762 L
s
.5 .30369 m
.50375 .30369 L
s
.5 .31975 m
.50375 .31975 L
s
.5 .35189 m
.50375 .35189 L
s
.5 .36796 m
.50375 .36796 L
s
.5 .38402 m
.50375 .38402 L
s
.5 .40009 m
.50375 .40009 L
s
.5 .43223 m
.50375 .43223 L
s
.5 .44829 m
.50375 .44829 L
s
.5 .46436 m
.50375 .46436 L
s
.5 .48043 m
.50375 .48043 L
s
.5 .51256 m
.50375 .51256 L
s
.5 .52863 m
.50375 .52863 L
s
.5 .5447 m
.50375 .5447 L
s
.5 .56076 m
.50375 .56076 L
s
.5 .5929 m
.50375 .5929 L
s
.5 .60897 m
.50375 .60897 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Shannon psi\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .34556 m
.02846 .33954 L
.03068 .33692 L
.03279 .33486 L
.03398 .33393 L
.03527 .33312 L
.03645 .33259 L
.03754 .33227 L
.03871 .33212 L
.04 .33217 L
.04065 .33228 L
.04135 .33245 L
.04262 .33289 L
.04393 .33352 L
.04516 .33422 L
.04793 .33603 L
.05057 .33774 L
.05172 .33838 L
.05297 .33896 L
.0542 .33937 L
.05533 .3396 L
.05641 .33966 L
.05756 .33955 L
.05876 .33922 L
.05989 .33871 L
.06112 .33793 L
.06244 .33685 L
.06787 .33027 L
.07073 .32608 L
.07376 .32184 L
.07641 .31886 L
.07714 .31822 L
.07792 .31763 L
.07859 .31721 L
.07933 .31685 L
.08064 .31649 L
.08136 .31645 L
.08202 .31652 L
.08321 .31689 L
.08448 .31764 L
.08514 .31817 L
.08584 .31884 L
.08708 .32029 L
.0899 .32468 L
.09501 .33531 L
.10001 .34615 L
.10238 .35042 L
.10458 .3535 L
.1057 .35468 L
.1069 .35562 L
Mistroke
.10758 .35601 L
.10822 .35628 L
.10942 .35651 L
.11057 .35641 L
.11163 .35606 L
.11279 .35539 L
.11402 .35438 L
.11652 .35153 L
.11885 .34816 L
.12415 .33972 L
.12653 .33638 L
.1277 .33498 L
.12878 .33386 L
.12974 .33302 L
.1308 .33228 L
.13187 .33172 L
.133 .33136 L
.13423 .33121 L
.13535 .33129 L
.13659 .33162 L
.13789 .33219 L
.13902 .33285 L
.14007 .33358 L
.14247 .33549 L
.14493 .33754 L
.14753 .33938 L
.14889 .34007 L
.14967 .34035 L
.15039 .34053 L
.15166 .34065 L
.15237 .34059 L
.15302 .34045 L
.15429 .33995 L
.15546 .33922 L
.15675 .3381 L
.15812 .33659 L
.16296 .32906 L
.16722 .32118 L
.16945 .31737 L
.1718 .31409 L
.17305 .31278 L
.17372 .31223 L
.17443 .31176 L
.17567 .31125 L
.17684 .31115 L
.17811 .31149 L
.17931 .31225 L
.18039 .31329 L
.18156 .31479 L
.18392 .3189 L
Mistroke
.18644 .3247 L
.19101 .33738 L
.19599 .35099 L
.19735 .35411 L
.1988 .357 L
.20006 .35906 L
.20142 .36079 L
.20221 .36155 L
.20294 .36208 L
.20364 .36244 L
.20437 .36265 L
.20565 .36262 L
.20637 .36239 L
.20705 .36203 L
.20774 .36153 L
.2084 .36093 L
.20963 .35953 L
.2124 .35519 L
.21718 .3455 L
.21972 .3403 L
.22245 .33546 L
.22372 .33363 L
.22505 .33206 L
.22619 .33103 L
.22744 .33023 L
.22861 .32982 L
.22986 .32972 L
.23104 .32994 L
.23211 .33039 L
.23343 .33122 L
.23465 .33222 L
.23739 .33504 L
.23997 .3379 L
.24238 .34026 L
.24343 .34108 L
.24443 .34168 L
.24559 .34214 L
.24664 .3423 L
.2478 .34219 L
.24888 .34177 L
.25007 .34098 L
.25133 .33973 L
.25256 .33811 L
.25389 .33596 L
.2563 .33111 L
.2608 .32004 L
.26541 .30906 L
.26674 .30655 L
.26799 .3046 L
.26912 .30325 L
Mistroke
.27034 .30226 L
.27099 .30196 L
.27171 .30182 L
.27245 .30188 L
.27315 .30214 L
.2744 .30309 L
.27511 .30391 L
.27575 .30483 L
.27699 .30705 L
.27834 .31013 L
.28079 .31731 L
.28648 .33895 L
.28928 .35007 L
.29185 .35929 L
.29419 .36615 L
.29538 .36892 L
.29666 .37127 L
.29795 .37294 L
.29915 .37386 L
.29988 .37411 L
.30057 .37413 L
.30188 .37361 L
.303 .37259 L
.30425 .3709 L
.30555 .36855 L
.30677 .36588 L
.31129 .35328 L
.3139 .34541 L
.31664 .33782 L
.31898 .33257 L
.32031 .33028 L
.32154 .32864 L
.32285 .32746 L
.32409 .32689 L
.32521 .32681 L
.32642 .32717 L
.32773 .32806 L
.3284 .32868 L
.32913 .32949 L
.33163 .33301 L
.3343 .33745 L
.33571 .33976 L
.33721 .34199 L
.33865 .34376 L
.33996 .34493 L
.34127 .34559 L
.34251 .34568 L
.34375 .34519 L
.34505 .34403 L
.34617 .34249 L
Mistroke
.34739 .34024 L
.35012 .33316 L
.35266 .32445 L
.35743 .30542 L
.35978 .29645 L
.36195 .2894 L
.36315 .28626 L
.36448 .28358 L
.36517 .28256 L
.36581 .28184 L
.36649 .28134 L
.36723 .28113 L
.36845 .28154 L
.36974 .28302 L
.37083 .28515 L
.37203 .28838 L
.37345 .29337 L
.37474 .29893 L
.37763 .31445 L
.38284 .34861 L
.3877 .37903 L
.39015 .39073 L
.39154 .39577 L
.39284 .39928 L
.39403 .40142 L
.39516 .40246 L
.39618 .40258 L
.39728 .40184 L
.39848 .40004 L
.39976 .39705 L
.40085 .39368 L
.40205 .38919 L
.42286 .32056 L
.42814 .33436 L
.43071 .34303 L
.43305 .3501 L
.43433 .35312 L
.43553 .35521 L
.4368 .35643 L
.43752 .35661 L
.43818 .35642 L
.43948 .35501 L
.44022 .35357 L
.44091 .35177 L
.4423 .34684 L
.4438 .33957 L
.44626 .32347 L
.44894 .30093 L
.45383 .25326 L
.45614 .23179 L
Mistroke
.45741 .22132 L
.4586 .2127 L
.45971 .20598 L
.46092 .20042 L
.46201 .19709 L
.46302 .19562 L
.46419 .19599 L
.46525 .19837 L
.46648 .20364 L
.46765 .21118 L
.46873 .22035 L
.46972 .23069 L
.47198 .26043 L
.47674 .34717 L
.48181 .45616 L
.48415 .50398 L
.48668 .54839 L
.48784 .56527 L
.48906 .58009 L
.4901 .59008 L
.49125 .59798 L
.49195 .60118 L
.49261 .60298 L
.49385 .60312 L
.49455 .6013 L
.49519 .59842 L
.4959 .59391 L
.49664 .5876 L
.49788 .57375 L
.49903 .55706 L
.50166 .50664 L
.50664 .37473 L
.51207 .21115 L
.51455 .1431 L
.5172 .08283 L
.51848 .05949 L
.51969 .04166 L
.52078 .02932 L
.52195 .02008 L
.52311 .01526 L
.5242 .01472 L
.52538 .01851 L
.52665 .02758 L
.52729 .03406 L
.52799 .0425 L
.52925 .06143 L
.53162 .1082 L
.53623 .23111 L
.54049 .36024 L
.54514 .4878 L
Mistroke
.54776 .54288 L
.549 .56335 L
.55015 .57875 L
.55122 .58983 L
.55236 .59807 L
.55363 .60288 L
.55479 .60332 L
.55588 .60037 L
.55706 .59364 L
.55817 .58408 L
.5592 .57272 L
.56167 .5366 L
.56398 .49401 L
.56922 .38217 L
.5743 .28205 L
.57569 .25979 L
.57716 .23943 L
.57844 .22482 L
.57982 .21233 L
.58047 .20764 L
.58115 .20354 L
.58238 .19834 L
.58352 .19588 L
.58478 .19576 L
.5855 .19684 L
.58615 .19851 L
.5869 .2012 L
.58761 .20445 L
.58888 .21178 L
.59026 .22165 L
.59506 .26586 L
.59769 .29171 L
.60015 .31386 L
.60255 .33186 L
.60474 .34428 L
.60599 .34944 L
.60718 .35303 L
.60843 .35545 L
.60914 .35622 L
.6098 .35656 L
.61096 .35634 L
.61206 .35525 L
.61305 .35362 L
.61411 .35127 L
.6187 .33699 L
.62108 .32925 L
.62239 .32554 L
.62363 .32262 L
.62478 .32053 L
.62603 .31905 L
Mistroke
.62717 .3185 L
.62822 .31871 L
.62946 .31985 L
.63063 .32181 L
.63191 .32492 L
.63328 .32933 L
.63609 .34116 L
.63866 .35431 L
.64123 .36825 L
.64398 .38223 L
.64532 .38816 L
.64657 .393 L
.64772 .39665 L
.64893 .39963 L
.65022 .40171 L
.65141 .40257 L
.65268 .40233 L
.65341 .40164 L
.65409 .40064 L
.65482 .39919 L
.65551 .39745 L
.65681 .39328 L
.65973 .38005 L
.66936 .31827 L
.67213 .30257 L
.67349 .29618 L
.67473 .29122 L
.67585 .28758 L
.67707 .28451 L
.6783 .28242 L
.6796 .28129 L
.68084 .28122 L
.68201 .28203 L
.68306 .28345 L
.6842 .28565 L
.68544 .28876 L
.68676 .29275 L
.68913 .30126 L
.69368 .31954 L
.698 .33467 L
.70035 .34049 L
.70168 .34285 L
.70292 .34441 L
.70406 .3453 L
.70509 .34567 L
.70629 .3456 L
.70741 .34509 L
.70865 .34409 L
.70995 .34261 L
.71228 .33918 L
Mistroke
.71481 .33493 L
.71754 .33071 L
.71875 .32919 L
.7199 .32805 L
.72093 .32732 L
.72205 .32687 L
.72311 .32681 L
.72423 .32715 L
.7252 .32779 L
.72626 .32885 L
.7275 .33057 L
.72864 .33256 L
.7312 .33837 L
.73584 .35179 L
.74057 .36521 L
.74194 .36828 L
.74323 .37067 L
.74438 .37232 L
.74564 .37353 L
.74673 .37407 L
.74794 .37406 L
.7492 .37338 L
.75038 .37211 L
.75148 .37038 L
.75249 .36838 L
.75476 .36248 L
.75996 .34371 L
.7655 .32189 L
.76819 .3131 L
.76951 .30957 L
.77072 .30687 L
.77183 .30489 L
.773 .30332 L
.77417 .30231 L
.77545 .30183 L
.77673 .302 L
.77794 .30273 L
.77903 .30383 L
.78021 .30544 L
.78285 .31042 L
.7853 .31617 L
.79003 .32813 L
.79235 .33332 L
.79447 .33722 L
.79558 .33883 L
.79678 .34026 L
.79799 .34131 L
.79926 .34201 L
.79995 .34222 L
.80058 .3423 L
Mistroke
.80131 .34228 L
.80199 .34215 L
.80321 .34167 L
.80454 .34083 L
.80582 .33975 L
.80724 .33835 L
.81009 .33518 L
.81275 .33242 L
.81392 .33142 L
.81521 .33055 L
.81642 .32999 L
.81771 .32972 L
.81839 .32973 L
.81912 .32984 L
.82044 .33037 L
.8217 .33125 L
.82233 .33182 L
.82302 .33256 L
.8254 .33582 L
.83021 .34502 L
.83469 .35422 L
.836 .35656 L
.83741 .35876 L
.83866 .36035 L
.83998 .36162 L
.84118 .36235 L
.84249 .36269 L
.84368 .36254 L
.8448 .36201 L
.84546 .36151 L
.84619 .3608 L
.84751 .35912 L
.85 .35468 L
.8529 .34776 L
.8556 .34029 L
.86068 .32597 L
.86335 .31963 L
.86481 .31679 L
.86617 .31462 L
.86737 .31313 L
.86865 .31199 L
.86938 .31156 L
.87007 .31129 L
.87136 .31115 L
.87255 .31144 L
.87365 .31205 L
.87485 .31305 L
.87613 .31448 L
.88086 .32202 L
.88584 .33115 L
Mistroke
.8879 .33444 L
.89009 .33729 L
.89136 .33856 L
.8925 .33946 L
.89366 .34011 L
.89474 .34049 L
.89588 .34064 L
.89709 .34056 L
.89811 .3403 L
.89924 .33983 L
.90046 .33915 L
.90176 .33825 L
.90412 .33636 L
.90683 .33412 L
.90816 .33314 L
.9094 .33237 L
.91052 .33182 L
.91171 .33141 L
.91303 .33121 L
.91423 .33128 L
.91537 .33158 L
.91659 .33214 L
.91762 .33283 L
.91876 .33379 L
.92129 .33664 L
.92365 .34 L
.92825 .34736 L
.93028 .3504 L
.93251 .35326 L
.93368 .35446 L
.93495 .35547 L
.93565 .35589 L
.93628 .35618 L
.93754 .35649 L
.93823 .35651 L
.93887 .35642 L
.93958 .35621 L
.94033 .35586 L
.94105 .3554 L
.94173 .35485 L
.943 .35355 L
.94548 .35003 L
.94776 .34585 L
.95291 .33463 L
.95517 .3297 L
.95758 .32493 L
.95982 .32127 L
.96194 .31867 L
.96308 .31768 L
.96432 .31693 L
Mistroke
.96545 .31655 L
.96649 .31645 L
.96764 .31663 L
.96891 .31715 L
.96955 .31753 L
.97024 .31803 L
.97149 .31913 L
.97619 .32505 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "Meyer ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " of order 4 is obtained by approximating the Fourier integral by a \
discrete sum with intervals of length ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\((3  i)\) = 2  \[Pi]/90\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.43"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[MeyerPhi[4, t, 30]], {t, -6, 6},
PlotRange -> All, AxesLabel -> {\"t\", \"Meyer phi_4(t)\"}]\
\>", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.114489 0.467001 [
[.02381 .10199 -6 -9 ]
[.02381 .10199 6 0 ]
[.18254 .10199 -6 -9 ]
[.18254 .10199 6 0 ]
[.34127 .10199 -6 -9 ]
[.34127 .10199 6 0 ]
[.65873 .10199 -3 -9 ]
[.65873 .10199 3 0 ]
[.81746 .10199 -3 -9 ]
[.81746 .10199 3 0 ]
[.97619 .10199 -3 -9 ]
[.97619 .10199 3 0 ]
[1.025 .11449 0 -4.5 ]
[1.025 .11449 6 4.5 ]
[.4875 .02109 -24 -4.5 ]
[.4875 .02109 0 4.5 ]
[.4875 .20789 -18 -4.5 ]
[.4875 .20789 0 4.5 ]
[.4875 .30129 -18 -4.5 ]
[.4875 .30129 0 4.5 ]
[.4875 .39469 -18 -4.5 ]
[.4875 .39469 0 4.5 ]
[.4875 .48809 -18 -4.5 ]
[.4875 .48809 0 4.5 ]
[.4875 .58149 -6 -4.5 ]
[.4875 .58149 0 4.5 ]
[.5 .64303 -42 0 ]
[.5 .64303 42 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .11449 m
.02381 .12074 L
s
[(-6)] .02381 .10199 0 1 Mshowa
.18254 .11449 m
.18254 .12074 L
s
[(-4)] .18254 .10199 0 1 Mshowa
.34127 .11449 m
.34127 .12074 L
s
[(-2)] .34127 .10199 0 1 Mshowa
.65873 .11449 m
.65873 .12074 L
s
[(2)] .65873 .10199 0 1 Mshowa
.81746 .11449 m
.81746 .12074 L
s
[(4)] .81746 .10199 0 1 Mshowa
.97619 .11449 m
.97619 .12074 L
s
[(6)] .97619 .10199 0 1 Mshowa
.125 Mabswid
.06349 .11449 m
.06349 .11824 L
s
.10317 .11449 m
.10317 .11824 L
s
.14286 .11449 m
.14286 .11824 L
s
.22222 .11449 m
.22222 .11824 L
s
.2619 .11449 m
.2619 .11824 L
s
.30159 .11449 m
.30159 .11824 L
s
.38095 .11449 m
.38095 .11824 L
s
.42063 .11449 m
.42063 .11824 L
s
.46032 .11449 m
.46032 .11824 L
s
.53968 .11449 m
.53968 .11824 L
s
.57937 .11449 m
.57937 .11824 L
s
.61905 .11449 m
.61905 .11824 L
s
.69841 .11449 m
.69841 .11824 L
s
.7381 .11449 m
.7381 .11824 L
s
.77778 .11449 m
.77778 .11824 L
s
.85714 .11449 m
.85714 .11824 L
s
.89683 .11449 m
.89683 .11824 L
s
.93651 .11449 m
.93651 .11824 L
s
.25 Mabswid
0 .11449 m
1 .11449 L
s
[(t)] 1.025 .11449 -1 0 Mshowa
.5 .02109 m
.50625 .02109 L
s
[(-0.2)] .4875 .02109 1 0 Mshowa
.5 .20789 m
.50625 .20789 L
s
[(0.2)] .4875 .20789 1 0 Mshowa
.5 .30129 m
.50625 .30129 L
s
[(0.4)] .4875 .30129 1 0 Mshowa
.5 .39469 m
.50625 .39469 L
s
[(0.6)] .4875 .39469 1 0 Mshowa
.5 .48809 m
.50625 .48809 L
s
[(0.8)] .4875 .48809 1 0 Mshowa
.5 .58149 m
.50625 .58149 L
s
[(1)] .4875 .58149 1 0 Mshowa
.125 Mabswid
.5 .04444 m
.50375 .04444 L
s
.5 .06779 m
.50375 .06779 L
s
.5 .09114 m
.50375 .09114 L
s
.5 .13784 m
.50375 .13784 L
s
.5 .16119 m
.50375 .16119 L
s
.5 .18454 m
.50375 .18454 L
s
.5 .23124 m
.50375 .23124 L
s
.5 .25459 m
.50375 .25459 L
s
.5 .27794 m
.50375 .27794 L
s
.5 .32464 m
.50375 .32464 L
s
.5 .34799 m
.50375 .34799 L
s
.5 .37134 m
.50375 .37134 L
s
.5 .41804 m
.50375 .41804 L
s
.5 .44139 m
.50375 .44139 L
s
.5 .46474 m
.50375 .46474 L
s
.5 .51144 m
.50375 .51144 L
s
.5 .53479 m
.50375 .53479 L
s
.5 .55814 m
.50375 .55814 L
s
.5 .60484 m
.50375 .60484 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(Meyer phi_4\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .11968 m
.02846 .11891 L
.03279 .11797 L
.04262 .11521 L
.06244 .10839 L
.06792 .10669 L
.0731 .10535 L
.07775 .10444 L
.08038 .10406 L
.08164 .10392 L
.0828 .10382 L
.08405 .10373 L
.08474 .1037 L
.0854 .10367 L
.08656 .10365 L
.08783 .10365 L
.08856 .10367 L
.08922 .10369 L
.08999 .10373 L
.09071 .10378 L
.09199 .10388 L
.09337 .10404 L
.09621 .10448 L
.09921 .10512 L
.10458 .10671 L
.10954 .10866 L
.11406 .1108 L
.12422 .1165 L
.14255 .12726 L
.14736 .1295 L
.14999 .13054 L
.15246 .13136 L
.15474 .13198 L
.15682 .13242 L
.15795 .13261 L
.15914 .13276 L
.16033 .13288 L
.16164 .13295 L
.16231 .13296 L
.16304 .13296 L
.16373 .13295 L
.16436 .13292 L
.16556 .13283 L
.16684 .13268 L
.1682 .13246 L
.16948 .1322 L
.17239 .13139 L
.17491 .13045 L
.17721 .12941 L
.1824 .12643 L
Mistroke
.19227 .11866 L
.20142 .10977 L
.21211 .09894 L
.21734 .09409 L
.22216 .09021 L
.22697 .08709 L
.22939 .08587 L
.23204 .08483 L
.23344 .08441 L
.23471 .08412 L
.23541 .08399 L
.23618 .08388 L
.2369 .08381 L
.23757 .08376 L
.23876 .08374 L
.24007 .08381 L
.24073 .08388 L
.24144 .08398 L
.24272 .08423 L
.24389 .08454 L
.24498 .0849 L
.24746 .08597 L
.24987 .08735 L
.25244 .08918 L
.25711 .09342 L
.26134 .09823 L
.28218 .13081 L
.29133 .1459 L
.29617 .15292 L
.30137 .15918 L
.30397 .1617 L
.30643 .16365 L
.30865 .165 L
.3099 .16559 L
.31105 .16603 L
.31213 .16633 L
.31314 .16652 L
.31424 .16662 L
.31544 .16661 L
.31662 .16646 L
.31787 .16617 L
.31893 .1658 L
.3201 .16528 L
.32269 .16363 L
.32505 .16157 L
.32777 .15851 L
.33035 .15496 L
.33989 .13657 L
.3496 .11093 L
.35988 .07966 L
Mistroke
.36952 .05104 L
.37833 .0297 L
.38064 .02537 L
.38316 .02139 L
.38554 .01842 L
.3866 .01736 L
.38775 .0164 L
.38844 .01593 L
.38907 .01556 L
.39032 .01502 L
.39145 .01476 L
.39265 .01472 L
.39394 .01497 L
.39514 .01547 L
.39646 .01632 L
.39788 .0176 L
.40023 .02059 L
.4028 .02509 L
.40745 .03667 L
.41199 .05223 L
.41618 .07036 L
.42582 .12496 L
.43486 .19031 L
.45547 .36683 L
.46531 .4494 L
.47567 .52332 L
.47994 .54804 L
.48451 .56986 L
.48713 .58009 L
.48952 .58783 L
.49192 .59409 L
.49417 .59851 L
.49529 .60018 L
.49649 .60158 L
.49717 .60219 L
.49782 .60265 L
.49903 .6032 L
.50031 .60332 L
.50149 .60302 L
.50279 .60223 L
.50351 .60158 L
.50417 .60086 L
.50645 .59743 L
.50773 .59486 L
.50891 .5921 L
.51337 .57825 L
.51821 .55749 L
.5235 .52845 L
.53418 .45345 L
.55538 .27154 L
Mistroke
.57467 .12177 L
.58428 .0682 L
.5897 .04594 L
.59229 .03745 L
.59471 .03074 L
.59699 .02552 L
.59908 .02166 L
.60141 .0184 L
.60269 .01705 L
.6039 .01605 L
.60507 .01536 L
.60632 .0149 L
.6075 .01472 L
.60856 .01476 L
.60982 .01507 L
.61053 .01536 L
.61118 .0157 L
.61239 .0165 L
.61365 .01759 L
.6162 .0205 L
.61861 .02409 L
.62313 .03273 L
.63328 .05899 L
.65161 .11442 L
.66126 .1392 L
.66613 .14911 L
.66894 .15387 L
.67151 .15759 L
.6737 .16025 L
.67608 .16263 L
.67848 .16446 L
.67979 .16522 L
.68101 .16578 L
.68217 .16618 L
.68327 .16644 L
.68425 .16658 L
.68532 .16663 L
.68649 .16656 L
.68772 .16636 L
.68877 .16608 L
.68993 .16567 L
.69242 .16439 L
.69514 .16245 L
.70009 .15758 L
.70937 .14482 L
.72033 .1265 L
.73026 .11004 L
.73514 .10285 L
.74041 .09614 L
.74496 .09139 L
Mistroke
.74996 .08746 L
.75271 .08589 L
.75528 .08481 L
.7567 .08438 L
.75799 .08408 L
.75871 .08395 L
.75948 .08385 L
.76022 .08379 L
.76089 .08375 L
.76209 .08375 L
.76321 .08382 L
.76444 .08397 L
.76514 .08409 L
.76577 .08422 L
.76829 .08494 L
.76956 .08542 L
.77094 .08602 L
.77624 .08908 L
.78124 .09288 L
.79058 .1016 L
.80077 .11198 L
.81154 .12195 L
.81615 .12545 L
.82109 .12853 L
.82393 .12995 L
.82652 .13101 L
.82912 .13184 L
.83029 .13214 L
.83159 .13242 L
.83266 .13261 L
.83381 .13276 L
.83503 .13288 L
.83618 .13295 L
.83726 .13297 L
.83839 .13295 L
.83936 .1329 L
.84043 .13281 L
.84169 .13266 L
.84283 .13248 L
.84541 .13194 L
.8478 .13128 L
.85005 .13052 L
.85975 .12605 L
.87003 .12002 L
.87966 .11421 L
.88847 .10957 L
.89297 .10762 L
.89789 .10591 L
.90058 .10517 L
.90308 .10461 L
Mistroke
.90547 .1042 L
.90679 .10402 L
.90801 .10388 L
.90917 .10379 L
.91039 .10371 L
.91161 .10366 L
.91231 .10365 L
.91296 .10365 L
.91413 .10366 L
.9152 .1037 L
.91644 .10376 L
.91761 .10385 L
.91978 .10408 L
.92178 .10436 L
.92631 .10522 L
.93095 .10638 L
.93595 .10787 L
.94498 .11095 L
.95502 .11444 L
.96559 .11758 L
.97065 .11873 L
.97619 .11968 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is the spline ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " of order 6. The infinite sum is truncated at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("kmax"\),
            "TI"], "=", "10"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.44"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SplinePsi[6, t, 10]], {t, -6, 6},
PlotRange -> All, AxesLabel -> {\"t\", \"spline psi_6(t)\"}]\
\>", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.309003 0.274157 [
[.02381 .2965 -6 -9 ]
[.02381 .2965 6 0 ]
[.18254 .2965 -6 -9 ]
[.18254 .2965 6 0 ]
[.34127 .2965 -6 -9 ]
[.34127 .2965 6 0 ]
[.65873 .2965 -3 -9 ]
[.65873 .2965 3 0 ]
[.81746 .2965 -3 -9 ]
[.81746 .2965 3 0 ]
[.97619 .2965 -3 -9 ]
[.97619 .2965 3 0 ]
[1.025 .309 0 -4.5 ]
[1.025 .309 6 4.5 ]
[.4875 .03485 -12 -4.5 ]
[.4875 .03485 0 4.5 ]
[.4875 .17192 -24 -4.5 ]
[.4875 .17192 0 4.5 ]
[.4875 .44608 -18 -4.5 ]
[.4875 .44608 0 4.5 ]
[.4875 .58316 -6 -4.5 ]
[.4875 .58316 0 4.5 ]
[.5 .64303 -45 0 ]
[.5 .64303 45 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .309 m
.02381 .31525 L
s
[(-6)] .02381 .2965 0 1 Mshowa
.18254 .309 m
.18254 .31525 L
s
[(-4)] .18254 .2965 0 1 Mshowa
.34127 .309 m
.34127 .31525 L
s
[(-2)] .34127 .2965 0 1 Mshowa
.65873 .309 m
.65873 .31525 L
s
[(2)] .65873 .2965 0 1 Mshowa
.81746 .309 m
.81746 .31525 L
s
[(4)] .81746 .2965 0 1 Mshowa
.97619 .309 m
.97619 .31525 L
s
[(6)] .97619 .2965 0 1 Mshowa
.125 Mabswid
.06349 .309 m
.06349 .31275 L
s
.10317 .309 m
.10317 .31275 L
s
.14286 .309 m
.14286 .31275 L
s
.22222 .309 m
.22222 .31275 L
s
.2619 .309 m
.2619 .31275 L
s
.30159 .309 m
.30159 .31275 L
s
.38095 .309 m
.38095 .31275 L
s
.42063 .309 m
.42063 .31275 L
s
.46032 .309 m
.46032 .31275 L
s
.53968 .309 m
.53968 .31275 L
s
.57937 .309 m
.57937 .31275 L
s
.61905 .309 m
.61905 .31275 L
s
.69841 .309 m
.69841 .31275 L
s
.7381 .309 m
.7381 .31275 L
s
.77778 .309 m
.77778 .31275 L
s
.85714 .309 m
.85714 .31275 L
s
.89683 .309 m
.89683 .31275 L
s
.93651 .309 m
.93651 .31275 L
s
.25 Mabswid
0 .309 m
1 .309 L
s
[(t)] 1.025 .309 -1 0 Mshowa
.5 .03485 m
.50625 .03485 L
s
[(-1)] .4875 .03485 1 0 Mshowa
.5 .17192 m
.50625 .17192 L
s
[(-0.5)] .4875 .17192 1 0 Mshowa
.5 .44608 m
.50625 .44608 L
s
[(0.5)] .4875 .44608 1 0 Mshowa
.5 .58316 m
.50625 .58316 L
s
[(1)] .4875 .58316 1 0 Mshowa
.125 Mabswid
.5 .06226 m
.50375 .06226 L
s
.5 .08968 m
.50375 .08968 L
s
.5 .11709 m
.50375 .11709 L
s
.5 .14451 m
.50375 .14451 L
s
.5 .19934 m
.50375 .19934 L
s
.5 .22676 m
.50375 .22676 L
s
.5 .25417 m
.50375 .25417 L
s
.5 .28159 m
.50375 .28159 L
s
.5 .33642 m
.50375 .33642 L
s
.5 .36383 m
.50375 .36383 L
s
.5 .39125 m
.50375 .39125 L
s
.5 .41867 m
.50375 .41867 L
s
.5 .4735 m
.50375 .4735 L
s
.5 .50091 m
.50375 .50091 L
s
.5 .52833 m
.50375 .52833 L
s
.5 .55574 m
.50375 .55574 L
s
.5 .00743 m
.50375 .00743 L
s
.5 .61057 m
.50375 .61057 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(spline psi_6\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .30901 m
.02605 .30901 L
.02846 .30901 L
.03072 .30902 L
.03279 .30902 L
.03521 .30903 L
.03784 .30904 L
.04262 .30906 L
.045 .30908 L
.04762 .3091 L
.05293 .30915 L
.06244 .30928 L
.06782 .30936 L
.07293 .30943 L
.07429 .30944 L
.07574 .30946 L
.07658 .30946 L
.07733 .30947 L
.0781 .30947 L
.07881 .30947 L
.07947 .30947 L
.08016 .30947 L
.0814 .30947 L
.08209 .30946 L
.08273 .30946 L
.08344 .30945 L
.0842 .30944 L
.08556 .30942 L
.08682 .30939 L
.08818 .30935 L
.08967 .3093 L
.09219 .30918 L
.09486 .30902 L
.09987 .30859 L
.10458 .30802 L
.10928 .30728 L
.11441 .30629 L
.12476 .30398 L
.1294 .30296 L
.13194 .30246 L
.13435 .30203 L
.13659 .3017 L
.13777 .30156 L
.13902 .30143 L
.14007 .30134 L
.14123 .30126 L
.14228 .30121 L
.14327 .30119 L
.14452 .30119 L
.14522 .3012 L
Mistroke
.14585 .30122 L
.14709 .30129 L
.14825 .30139 L
.14961 .30155 L
.15086 .30173 L
.15367 .30229 L
.15597 .30289 L
.15848 .3037 L
.16355 .30577 L
.18209 .31598 L
.18735 .31857 L
.18993 .31963 L
.19232 .32045 L
.19449 .32105 L
.19679 .32152 L
.19798 .3217 L
.1991 .32183 L
.20032 .32192 L
.20164 .32196 L
.20296 .32195 L
.20418 .32188 L
.20489 .32183 L
.20553 .32176 L
.20696 .32157 L
.20835 .32133 L
.20985 .32101 L
.21256 .32029 L
.22257 .31665 L
.22753 .31467 L
.23286 .31276 L
.23789 .31132 L
.24248 .31034 L
.24763 .30957 L
.25252 .309 L
.25779 .30828 L
.26078 .30772 L
.26354 .30702 L
.26816 .30536 L
.27076 .30412 L
.27315 .30278 L
.28218 .29603 L
.28733 .29143 L
.29284 .28659 L
.29552 .28451 L
.29804 .28283 L
.30031 .28162 L
.30159 .2811 L
.30277 .28072 L
.30386 .28047 L
.30503 .28032 L
Mistroke
.30613 .28029 L
.30714 .28036 L
.30832 .28057 L
.30961 .28095 L
.31082 .28147 L
.31195 .28209 L
.31442 .28392 L
.31666 .28613 L
.32167 .29291 L
.32679 .30203 L
.33233 .31349 L
.33752 .32457 L
.34236 .33406 L
.34696 .34136 L
.34953 .34446 L
.35188 .34655 L
.35321 .34741 L
.35445 .34798 L
.35509 .3482 L
.3558 .34837 L
.35655 .34848 L
.35724 .3485 L
.35852 .34838 L
.35969 .34807 L
.36097 .34753 L
.36232 .34673 L
.36484 .34467 L
.36753 .34174 L
.37238 .3351 L
.37811 .32642 L
.38062 .32284 L
.38339 .31935 L
.38579 .31688 L
.38711 .31578 L
.38837 .31493 L
.38905 .31455 L
.38979 .3142 L
.39109 .31377 L
.39242 .31357 L
.39364 .31359 L
.39434 .3137 L
.3951 .31388 L
.39581 .31413 L
.39647 .31441 L
.39771 .3151 L
.39902 .31602 L
.40176 .31852 L
.40475 .32197 L
.40979 .32847 L
.41256 .33179 L
Mistroke
.41392 .33319 L
.41518 .3343 L
.41637 .33515 L
.41762 .3358 L
.41888 .33615 L
.4196 .33621 L
.42027 .33616 L
.42144 .33582 L
.4225 .33522 L
.42374 .33414 L
.42491 .33272 L
.42615 .33077 L
.42749 .32813 L
.42993 .32186 L
.4323 .31391 L
.43449 .305 L
.4447 .24652 L
.45357 .18776 L
.45613 .17308 L
.45855 .16121 L
.46072 .15273 L
.46195 .149 L
.46309 .14631 L
.46424 .14437 L
.46533 .14332 L
.46652 .14307 L
.4678 .1439 L
.46908 .14591 L
.46972 .14737 L
.47042 .14932 L
.47166 .15369 L
.47282 .15881 L
.47512 .17206 L
.47721 .18758 L
.4819 .23368 L
.49265 .38111 L
.49737 .45132 L
.50256 .52079 L
.50488 .54678 L
.50737 .57001 L
.50858 .57927 L
.50972 .58676 L
.51085 .59284 L
.51187 .59719 L
.51306 .60082 L
.51432 .60296 L
.51549 .60332 L
.51659 .60222 L
.51788 .59915 L
.51907 .59463 L
Mistroke
.52037 .58781 L
.52174 .57853 L
.52422 .55654 L
.52687 .52601 L
.53166 .45538 L
.54253 .25488 L
.54748 .1665 L
.55272 .0891 L
.55546 .05833 L
.55692 .04511 L
.55848 .03346 L
.55991 .0252 L
.56123 .0197 L
.56248 .01631 L
.5638 .01472 L
.56507 .01507 L
.56621 .01697 L
.56685 .01866 L
.56754 .02099 L
.56879 .02652 L
.56996 .03319 L
.5712 .04175 L
.57342 .06066 L
.57843 .11752 L
.58393 .19511 L
.59393 .34073 L
.59885 .39947 L
.60341 .4401 L
.60594 .4561 L
.60722 .46231 L
.60864 .46772 L
.60933 .46979 L
.61005 .4716 L
.61085 .47312 L
.61158 .47412 L
.61289 .47495 L
.61364 .47488 L
.61434 .47448 L
.61563 .47288 L
.61686 .47041 L
.61796 .46744 L
.61916 .46348 L
.62184 .45207 L
.62431 .43898 L
.6341 .37523 L
.6395 .34089 L
.64463 .3141 L
.64694 .30457 L
.64939 .29628 L
.6508 .2924 L
Mistroke
.65208 .28944 L
.65338 .28695 L
.65458 .28512 L
.65567 .28382 L
.65683 .28281 L
.65799 .28216 L
.65926 .28182 L
.66036 .28184 L
.66154 .28213 L
.66265 .28265 L
.66367 .28331 L
.66602 .28538 L
.66851 .2882 L
.67298 .29395 L
.67549 .2971 L
.6782 .30009 L
.67945 .30125 L
.68076 .3023 L
.68189 .30306 L
.68311 .30369 L
.68424 .30411 L
.68527 .30435 L
.68631 .30445 L
.68728 .30441 L
.68843 .30419 L
.68948 .30384 L
.69063 .30329 L
.69186 .30251 L
.69423 .30051 L
.69645 .29809 L
.70151 .2912 L
.70649 .28363 L
.70912 .27981 L
.71192 .27616 L
.71462 .27325 L
.71705 .27127 L
.71823 .27056 L
.7195 .26999 L
.7207 .26965 L
.72181 .26951 L
.72288 .26954 L
.72403 .26974 L
.72512 .2701 L
.72611 .27058 L
.72727 .2713 L
.72853 .2723 L
.73083 .27465 L
.73577 .2818 L
.74034 .29036 L
.74935 .30944 L
Mistroke
.75432 .31931 L
.75905 .32717 L
.76171 .33072 L
.76461 .33379 L
.76588 .33486 L
.76724 .33581 L
.76852 .33652 L
.76969 .33703 L
.77099 .33742 L
.77167 .33756 L
.77239 .33766 L
.7736 .33772 L
.77428 .33769 L
.77493 .33762 L
.77612 .3374 L
.77721 .3371 L
.77848 .33663 L
.77967 .33609 L
.78425 .3332 L
.78931 .32902 L
.79956 .31998 L
.80413 .31657 L
.80906 .31365 L
.81132 .31259 L
.81371 .31166 L
.81798 .31043 L
.85606 .30166 L
.86089 .29974 L
.86613 .29791 L
.86854 .29723 L
.87108 .29666 L
.87213 .29648 L
.87326 .29631 L
.87449 .29618 L
.87565 .29609 L
.87638 .29606 L
.87706 .29604 L
.8778 .29604 L
.87859 .29607 L
.87935 .2961 L
.88006 .29616 L
.88069 .29622 L
.88138 .2963 L
.88271 .2965 L
.88411 .29678 L
.88662 .29743 L
.89138 .29916 L
.8966 .30166 L
.90747 .30785 L
.91282 .31077 L
Mistroke
.91776 .3131 L
.92224 .31476 L
.92451 .31542 L
.927 .316 L
.9295 .31642 L
.9309 .31659 L
.93219 .3167 L
.93332 .31677 L
.93455 .31681 L
.93585 .31682 L
.93705 .31679 L
.93832 .31674 L
.93949 .31665 L
.94077 .31654 L
.94213 .31639 L
.94692 .31564 L
.95588 .31373 L
.96627 .31144 L
.97598 .30983 L
.97619 .3098 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is the spline wavelet ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " of order 6. The neglected terms have coefficients ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c\_k \[VerticalSeparator]  < 0.02\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.45"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SplinePhi[6, t, 0.02]], {t, -6, 6},
PlotRange -> All, AxesLabel -> {\"t\", \"spline phi_6(t)\"}]\
\>", "Input",
  CellLabel->"In[42]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.113603 0.46696 [
[.02381 .1011 -6 -9 ]
[.02381 .1011 6 0 ]
[.18254 .1011 -6 -9 ]
[.18254 .1011 6 0 ]
[.34127 .1011 -6 -9 ]
[.34127 .1011 6 0 ]
[.65873 .1011 -3 -9 ]
[.65873 .1011 3 0 ]
[.81746 .1011 -3 -9 ]
[.81746 .1011 3 0 ]
[.97619 .1011 -3 -9 ]
[.97619 .1011 3 0 ]
[1.025 .1136 0 -4.5 ]
[1.025 .1136 6 4.5 ]
[.4875 .02021 -24 -4.5 ]
[.4875 .02021 0 4.5 ]
[.4875 .20699 -18 -4.5 ]
[.4875 .20699 0 4.5 ]
[.4875 .30039 -18 -4.5 ]
[.4875 .30039 0 4.5 ]
[.4875 .39378 -18 -4.5 ]
[.4875 .39378 0 4.5 ]
[.4875 .48717 -18 -4.5 ]
[.4875 .48717 0 4.5 ]
[.4875 .58056 -6 -4.5 ]
[.4875 .58056 0 4.5 ]
[.5 .64303 -45 0 ]
[.5 .64303 45 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .1136 m
.02381 .11985 L
s
[(-6)] .02381 .1011 0 1 Mshowa
.18254 .1136 m
.18254 .11985 L
s
[(-4)] .18254 .1011 0 1 Mshowa
.34127 .1136 m
.34127 .11985 L
s
[(-2)] .34127 .1011 0 1 Mshowa
.65873 .1136 m
.65873 .11985 L
s
[(2)] .65873 .1011 0 1 Mshowa
.81746 .1136 m
.81746 .11985 L
s
[(4)] .81746 .1011 0 1 Mshowa
.97619 .1136 m
.97619 .11985 L
s
[(6)] .97619 .1011 0 1 Mshowa
.125 Mabswid
.06349 .1136 m
.06349 .11735 L
s
.10317 .1136 m
.10317 .11735 L
s
.14286 .1136 m
.14286 .11735 L
s
.22222 .1136 m
.22222 .11735 L
s
.2619 .1136 m
.2619 .11735 L
s
.30159 .1136 m
.30159 .11735 L
s
.38095 .1136 m
.38095 .11735 L
s
.42063 .1136 m
.42063 .11735 L
s
.46032 .1136 m
.46032 .11735 L
s
.53968 .1136 m
.53968 .11735 L
s
.57937 .1136 m
.57937 .11735 L
s
.61905 .1136 m
.61905 .11735 L
s
.69841 .1136 m
.69841 .11735 L
s
.7381 .1136 m
.7381 .11735 L
s
.77778 .1136 m
.77778 .11735 L
s
.85714 .1136 m
.85714 .11735 L
s
.89683 .1136 m
.89683 .11735 L
s
.93651 .1136 m
.93651 .11735 L
s
.25 Mabswid
0 .1136 m
1 .1136 L
s
[(t)] 1.025 .1136 -1 0 Mshowa
.5 .02021 m
.50625 .02021 L
s
[(-0.2)] .4875 .02021 1 0 Mshowa
.5 .20699 m
.50625 .20699 L
s
[(0.2)] .4875 .20699 1 0 Mshowa
.5 .30039 m
.50625 .30039 L
s
[(0.4)] .4875 .30039 1 0 Mshowa
.5 .39378 m
.50625 .39378 L
s
[(0.6)] .4875 .39378 1 0 Mshowa
.5 .48717 m
.50625 .48717 L
s
[(0.8)] .4875 .48717 1 0 Mshowa
.5 .58056 m
.50625 .58056 L
s
[(1)] .4875 .58056 1 0 Mshowa
.125 Mabswid
.5 .04356 m
.50375 .04356 L
s
.5 .06691 m
.50375 .06691 L
s
.5 .09025 m
.50375 .09025 L
s
.5 .13695 m
.50375 .13695 L
s
.5 .1603 m
.50375 .1603 L
s
.5 .18365 m
.50375 .18365 L
s
.5 .23034 m
.50375 .23034 L
s
.5 .25369 m
.50375 .25369 L
s
.5 .27704 m
.50375 .27704 L
s
.5 .32373 m
.50375 .32373 L
s
.5 .34708 m
.50375 .34708 L
s
.5 .37043 m
.50375 .37043 L
s
.5 .41713 m
.50375 .41713 L
s
.5 .44047 m
.50375 .44047 L
s
.5 .46382 m
.50375 .46382 L
s
.5 .51052 m
.50375 .51052 L
s
.5 .53387 m
.50375 .53387 L
s
.5 .55721 m
.50375 .55721 L
s
.5 .60391 m
.50375 .60391 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(spline phi_6\\(t\\))] .5 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .11937 m
.02846 .12017 L
.03279 .12073 L
.03527 .12097 L
.03754 .12113 L
.03879 .12119 L
.0395 .12122 L
.04015 .12124 L
.04135 .12126 L
.04262 .12127 L
.04384 .12125 L
.04496 .12122 L
.04626 .12116 L
.04749 .12109 L
.04967 .12091 L
.05205 .12065 L
.05466 .12028 L
.05744 .11978 L
.06244 .11866 L
.07382 .11517 L
.08454 .11111 L
.0941 .10744 L
.09952 .10556 L
.10458 .10406 L
.10929 .10295 L
.11193 .10247 L
.11434 .10213 L
.11566 .10199 L
.11688 .10189 L
.11757 .10184 L
.11822 .10181 L
.11889 .10178 L
.11964 .10176 L
.1209 .10175 L
.12205 .10177 L
.12332 .10182 L
.12396 .10186 L
.12466 .10191 L
.1259 .10202 L
.12708 .10216 L
.12928 .10249 L
.13166 .10295 L
.13423 .10358 L
.13886 .10504 L
.14313 .10673 L
.16349 .11796 L
.17344 .12392 L
.18253 .12849 L
.18702 .1302 L
.18938 .13091 L
Mistroke
.1919 .13151 L
.19315 .13174 L
.19433 .13192 L
.19538 .13205 L
.19652 .13215 L
.1976 .13221 L
.19875 .13223 L
.19973 .13222 L
.2008 .13218 L
.20212 .13207 L
.20337 .13191 L
.20449 .13173 L
.2057 .13149 L
.20843 .13077 L
.21095 .1299 L
.21555 .12778 L
.22042 .12485 L
.22982 .11751 L
.23993 .10795 L
.24941 .09871 L
.25822 .09115 L
.26287 .08797 L
.26524 .08662 L
.26782 .08542 L
.26929 .08486 L
.27065 .08442 L
.27192 .08409 L
.27259 .08395 L
.27332 .08382 L
.27457 .08365 L
.27574 .08356 L
.27643 .08355 L
.27708 .08355 L
.2783 .08362 L
.27951 .08376 L
.2802 .08388 L
.28085 .08401 L
.28215 .08434 L
.28355 .0848 L
.28609 .0859 L
.28841 .08721 L
.29377 .0913 L
.29942 .09714 L
.30894 .10998 L
.31913 .12626 L
.32868 .14169 L
.33749 .15388 L
.34246 .1591 L
.34496 .16115 L
.34772 .16289 L
Mistroke
.34916 .16357 L
.35048 .16404 L
.35121 .16424 L
.352 .16441 L
.35275 .16452 L
.35345 .16458 L
.35415 .16459 L
.35481 .16457 L
.35605 .16442 L
.35674 .16427 L
.35738 .1641 L
.35881 .16358 L
.35998 .16301 L
.36123 .16227 L
.36349 .16055 L
.36617 .15788 L
.36861 .15486 L
.37393 .14641 L
.37896 .1362 L
.39719 .08633 L
.40757 .0555 L
.41265 .04196 L
.41731 .03128 L
.42195 .02287 L
.42428 .01964 L
.42683 .01699 L
.42818 .01598 L
.4294 .01531 L
.43008 .01505 L
.43082 .01485 L
.43151 .01474 L
.43215 .01472 L
.4333 .01485 L
.43455 .01526 L
.43587 .016 L
.4371 .01698 L
.4384 .01833 L
.43981 .02018 L
.44239 .02454 L
.4449 .03008 L
.44723 .03635 L
.4525 .05467 L
.45811 .08037 L
.46843 .14318 L
.47958 .22927 L
.49976 .40508 L
.51011 .48725 L
.51976 .54831 L
.52462 .5714 L
.52711 .58095 L
Mistroke
.52982 .58948 L
.53136 .59344 L
.53278 .59652 L
.53412 .59889 L
.53559 .60092 L
.5369 .60222 L
.53814 .60298 L
.53944 .60332 L
.54017 .60329 L
.54084 .60314 L
.54212 .60247 L
.54334 .60141 L
.54442 .60011 L
.5456 .59832 L
.54824 .59287 L
.55068 .58616 L
.55512 .56984 L
.55982 .54721 L
.56969 .48407 L
.58054 .39712 L
.60167 .21371 L
.61168 .13801 L
.62095 .08196 L
.62558 .05999 L
.63051 .04139 L
.63546 .02773 L
.63827 .02218 L
.63954 .0202 L
.64092 .01839 L
.64204 .0172 L
.64323 .01619 L
.64449 .01541 L
.64567 .01495 L
.64684 .01473 L
.64795 .01475 L
.64894 .01495 L
.65002 .01534 L
.65121 .016 L
.6525 .01697 L
.65513 .0197 L
.65757 .0231 L
.65984 .02695 L
.67024 .0512 L
.68012 .0801 L
.69865 .13218 L
.7036 .14292 L
.70826 .15121 L
.71084 .15497 L
.71363 .15835 L
.71616 .16079 L
Mistroke
.71849 .16249 L
.71956 .16311 L
.7207 .16364 L
.72178 .16404 L
.72276 .16431 L
.72391 .16451 L
.72517 .16459 L
.72635 .16455 L
.72744 .16439 L
.72857 .16413 L
.72962 .16379 L
.73078 .16332 L
.73202 .16268 L
.73456 .16103 L
.73689 .15912 L
.74164 .15415 L
.74671 .14755 L
.75584 .13349 L
.76662 .11586 L
.77655 .10134 L
.78144 .09545 L
.78681 .09024 L
.78942 .08823 L
.79222 .08646 L
.79376 .08566 L
.79517 .08505 L
.79651 .08456 L
.79793 .08415 L
.79915 .08388 L
.79985 .08376 L
.8005 .08368 L
.80165 .08358 L
.80288 .08354 L
.80354 .08356 L
.80425 .0836 L
.805 .08367 L
.80569 .08376 L
.80694 .08398 L
.80828 .0843 L
.81092 .08517 L
.81341 .08627 L
.81809 .08898 L
.82779 .09671 L
.83807 .1066 L
.8477 .11585 L
.85651 .12315 L
.86101 .12618 L
.86593 .12883 L
.86862 .12998 L
.87112 .13083 L
Mistroke
.87351 .13146 L
.87484 .13173 L
.87605 .13192 L
.8772 .13206 L
.87841 .13217 L
.87944 .13222 L
.88058 .13223 L
.8818 .13221 L
.88311 .13213 L
.88435 .13201 L
.88548 .13186 L
.88766 .13147 L
.89004 .13089 L
.89435 .12949 L
.8992 .12742 L
.90376 .12511 L
.91413 .11903 L
.92437 .11284 L
.92995 .10975 L
.93514 .10722 L
.9402 .10516 L
.94479 .10368 L
.94723 .10306 L
.94989 .10252 L
.95134 .10228 L
.95269 .10211 L
.95397 .10197 L
.95467 .10191 L
.95533 .10186 L
.95648 .1018 L
.95753 .10176 L
.95866 .10175 L
.95989 .10176 L
.96096 .1018 L
.9621 .10186 L
.96317 .10194 L
.96415 .10204 L
.96655 .10233 L
.96914 .10277 L
.97384 .10381 L
.97619 .10445 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "\[Hyphen]spline function of order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Beta]\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", can be obtained using ",
  StyleBox["BSpline[", "MR"],
  StyleBox["n", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["t", "TI"],
  StyleBox["]", "MR"],
  ". Note that although we include this function in this section, it is not \
an orthogonal scaling function. "
}], "Text",
  CellTags->{"S3.1.2", "2.46"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BSpline[\\\\\\\"\\\", \\\
\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\
\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give "\), 
                    StyleBox[\(n\^th\),
                      "InlineFormula"], \(" order "\), 
                    StyleBox["B",
                      "InlineFormula"], \("\[Hyphen]spline "\), 
                    StyleBox[\(\(\[Beta]\_n\) \((t)\)\),
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.47"}],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "\[Hyphen]spline function."
}], "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "Here is the ",
  Cell[BoxData[
      \(TraditionalForm\`B\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "\[Hyphen]spline of order 5."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.48"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[BSpline[5, t]], {t, -3, 3},
PlotRange -> All, PlotLabel -> \"B-spline of order 5\"]\
\>", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0147151 1.07019 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -3 -9 ]
[.81746 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .12173 -18 -4.5 ]
[.4875 .12173 0 4.5 ]
[.4875 .22875 -18 -4.5 ]
[.4875 .22875 0 4.5 ]
[.4875 .33577 -18 -4.5 ]
[.4875 .33577 0 4.5 ]
[.4875 .44279 -18 -4.5 ]
[.4875 .44279 0 4.5 ]
[.4875 .54981 -18 -4.5 ]
[.4875 .54981 0 4.5 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-3)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-2)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-1)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(1)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12173 m
.50625 .12173 L
s
[(0.1)] .4875 .12173 1 0 Mshowa
.5 .22875 m
.50625 .22875 L
s
[(0.2)] .4875 .22875 1 0 Mshowa
.5 .33577 m
.50625 .33577 L
s
[(0.3)] .4875 .33577 1 0 Mshowa
.5 .44279 m
.50625 .44279 L
s
[(0.4)] .4875 .44279 1 0 Mshowa
.5 .54981 m
.50625 .54981 L
s
[(0.5)] .4875 .54981 1 0 Mshowa
.125 Mabswid
.5 .03612 m
.50375 .03612 L
s
.5 .05752 m
.50375 .05752 L
s
.5 .07893 m
.50375 .07893 L
s
.5 .10033 m
.50375 .10033 L
s
.5 .14314 m
.50375 .14314 L
s
.5 .16454 m
.50375 .16454 L
s
.5 .18595 m
.50375 .18595 L
s
.5 .20735 m
.50375 .20735 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27156 m
.50375 .27156 L
s
.5 .29296 m
.50375 .29296 L
s
.5 .31437 m
.50375 .31437 L
s
.5 .35718 m
.50375 .35718 L
s
.5 .37858 m
.50375 .37858 L
s
.5 .39998 m
.50375 .39998 L
s
.5 .42139 m
.50375 .42139 L
s
.5 .46419 m
.50375 .46419 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .507 m
.50375 .507 L
s
.5 .52841 m
.50375 .52841 L
s
.5 .57121 m
.50375 .57121 L
s
.5 .59262 m
.50375 .59262 L
s
.5 .61402 m
.50375 .61402 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(B-spline of order 5)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.03944 .01472 L
.04011 .01472 L
.04132 .01472 L
.04262 .01472 L
.04396 .01472 L
.04519 .01472 L
.04654 .01472 L
.04797 .01472 L
.05038 .01472 L
.05174 .01472 L
.05302 .01472 L
.0554 .01472 L
.05757 .01472 L
.06007 .01472 L
.06244 .01472 L
.06486 .01473 L
.06753 .01473 L
.07031 .01473 L
.07293 .01474 L
.07759 .01475 L
.08022 .01477 L
.08263 .01478 L
.08773 .01481 L
.09332 .01486 L
.09915 .01493 L
.10458 .01502 L
.10963 .01513 L
.1151 .01528 L
.11993 .01544 L
.12504 .01566 L
.13471 .0162 L
.14362 .0169 L
.15306 .01791 L
.1632 .01937 L
.17277 .02121 L
.18151 .02335 L
Mistroke
.20054 .02997 L
.2113 .03521 L
.22127 .04124 L
.24184 .05793 L
.26046 .07888 L
.27974 .10729 L
.30057 .14627 L
.34163 .2476 L
.38117 .36649 L
.41919 .47956 L
.44038 .53248 L
.45967 .5698 L
.46927 .58361 L
.47432 .58949 L
.47969 .59463 L
.48437 .59816 L
.48686 .59966 L
.48953 .601 L
.49198 .60196 L
.49306 .6023 L
.49423 .60261 L
.49527 .60284 L
.49637 .60304 L
.49754 .60319 L
.49863 .60328 L
.49987 .60332 L
.50057 .60331 L
.50123 .60329 L
.50192 .60324 L
.50255 .60318 L
.50328 .60309 L
.50398 .60298 L
.50633 .60247 L
.50767 .60207 L
.5089 .60164 L
.51429 .599 L
.51701 .59721 L
.52002 .59487 L
.53041 .58401 L
.54018 .57004 L
.56034 .53088 L
.57884 .48491 L
.61843 .36774 L
.6565 .25288 L
.67773 .19604 L
.69703 .15131 L
.71732 .11226 L
.73604 .08351 L
.75521 .06086 L
.76594 .05088 L
Mistroke
.77599 .04311 L
.79473 .03212 L
.80468 .02785 L
.81537 .02424 L
.82548 .0216 L
.83652 .01942 L
.84694 .01791 L
.85661 .01688 L
.86169 .01646 L
.86719 .01608 L
.87203 .0158 L
.87715 .01556 L
.88177 .01538 L
.88684 .01522 L
.89111 .01511 L
.89576 .01501 L
.90101 .01493 L
.90597 .01487 L
.91081 .01482 L
.91528 .01479 L
.92011 .01476 L
.92285 .01475 L
.92543 .01474 L
.92796 .01474 L
.93062 .01473 L
.93353 .01473 L
.9362 .01472 L
.93878 .01472 L
.94121 .01472 L
.94339 .01472 L
.94576 .01472 L
.94834 .01472 L
.94964 .01472 L
.95107 .01472 L
.95229 .01472 L
.9536 .01472 L
.95482 .01472 L
.95596 .01472 L
.9572 .01472 L
.95832 .01472 L
.95956 .01472 L
.96089 .01472 L
.96205 .01472 L
.9633 .01472 L
.96448 .01472 L
.96556 .01472 L
.96662 .01472 L
.9676 .01472 L
.96868 .01472 L
.96983 .01472 L
Mistroke
.97104 .01472 L
.97219 .01472 L
.97322 .01472 L
.97433 .01472 L
.97523 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "The so\[Hyphen]called local trigonometric basis is the sine or cosine \
basis rendered localized in time by a window function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " of finite width. Partition the time axis into equal intervals of length ",
  
  Cell[BoxData[
      \(TraditionalForm\`L = a\_\(j + 1\) - a\_j\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", the local sine and cosine bases of Coifman and Meyer are given by "
}], "Text",
  CellTags->{"S3.1.2", "2.49"}],

Cell[BoxData[
    \(TraditionalForm
    \`{\(\@\(2\/L\)\) b \((t)\) sin \( \[Pi]\/L\) \((k + 1\/2)\) 
          \((t - a\_j)\)}\_\(j, k\)\)], "DisplayFormula",
  CellTags->{"S3.1.2", "2.50"}],

Cell["and ", "Text",
  CellTags->{"S3.1.2", "2.51"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({\(\@\(2\/L\)\) b \((t)\) cos \( \[Pi]\/L\) \((k + 1\/2)\) 
            \((t - a\_j)\)}\_\(j, k\).\)\)], "DisplayFormula",
  CellTags->{"S3.1.2", "2.52"}],

Cell[TextData[{
  "Consider the basis functions on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, L]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " (",
  StyleBox["i.e.", "TI"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`a\_j = 0\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "). The window function ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " is specified by the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, L]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", the half\[Hyphen]width of the transition regions on either side, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", and the taper function describing the transition from ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\) = 0\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`b \((t)\) = 1\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". The default taper function is ",
  StyleBox["Polynomial[2]", "MR"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\(t\^3\) \((10 - 15  t + 6  t\^2)\)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  ". The default value for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " or taper width is ",
  StyleBox["Automatic", "MR"],
  " which is ",
  Cell[BoxData[
      \(TraditionalForm\`L/4\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ". "
}], "Text",
  CellTags->{"S3.1.2", "2.53"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WindowFunction[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"L\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("give window function "\), 
                    StyleBox[\(b \((t)\)\),
                      "InlineFormula"], \(" over the interval "\), 
                    StyleBox[\(\[InvisibleSpace]\([0, L]\)\),
                      "InlineFormula"], \(" with default taper "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosPacket[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"L\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"k\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give cosine packet of frequency index "\), 
                    StyleBox["k",
                      "InlineFormula"], \(" over "\), 
                    StyleBox[\(\[InvisibleSpace]\([0, L]\)\),
                      "InlineFormula"], \(" with default taper "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinPacket[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"t\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"L\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"k\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("give sine packet "\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.54"}],

Cell["Sine and cosine packets and window function.", "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "To get a window other than the default, we set the option ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S3.1.2"],
  StyleBox["taperfunction", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["epsilon", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", where ",
  StyleBox["taperfunction", "TI"],
  " can be ",
  StyleBox["Polynomial[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", ",
  StyleBox["Trig[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", or a suitable function of your choice which must be input as a pure \
function. "
}], "Text",
  CellTags->{"S3.1.2", "2.55"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  RowBox[{
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Polynomial[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"2\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"],\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Automatic\\\\\\\"\\\", \\\"MR\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], \(" "\)}], "\[Null]"},
                {"\[Null]", "\[Null]", \("taper function and taper width "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.56"}],

Cell[TextData[{
  "Option for ",
  StyleBox["WindowFunction", "MR"],
  ", ",
  StyleBox["CosPacket", "MR"],
  ", and ",
  StyleBox["SinPacket", "MR"],
  "."
}], "Caption",
  CellTags->"S3.1.2"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("no taper function "\)},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Polynomial[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"],\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"epsilon\\\\\\\"\\\", \\\"MR\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], \(" "\)}], 
                  RowBox[{
                  \("set taper function to \"polynomial\" of order "\), 
                    StyleBox["n",
                      "InlineFormula"], \(" and set taper width to "\), 
                    StyleBox["\[Epsilon]",
                      "InlineFormula"], \(" "\)}]},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Trig[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"],\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"epsilon\\\\\\\"\\\", \\\"MR\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], \(" "\)}], 
                  RowBox[{
                  \("set taper function to trigonometric function of order \
"\), 
                    StyleBox["n",
                      "InlineFormula"], \(" and set taper width to "\), 
                    StyleBox["\[Epsilon]",
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.2", "2.57"}],

Cell[TextData[{
  "Settings for the ",
  StyleBox["Taper", "MR"],
  " option."
}], "Caption",
  CellTags->"S3.1.2"],

Cell[TextData[{
  "This is a window over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 3]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " with the default taper."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.58"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[WindowFunction[t, 3]], {t, -1, 4},
AspectRatio -> Automatic,
PlotLabel -> \"window function b(t)\"]\
\>", "Input",
  CellLabel->"In[44]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.00476191 0.190476 [
[.02381 -0.00774 -6 -9 ]
[.02381 -0.00774 6 0 ]
[.40476 -0.00774 -3 -9 ]
[.40476 -0.00774 3 0 ]
[.59524 -0.00774 -3 -9 ]
[.59524 -0.00774 3 0 ]
[.78571 -0.00774 -3 -9 ]
[.78571 -0.00774 3 0 ]
[.97619 -0.00774 -3 -9 ]
[.97619 -0.00774 3 0 ]
[.20179 .04286 -18 -4.5 ]
[.20179 .04286 0 4.5 ]
[.20179 .08095 -18 -4.5 ]
[.20179 .08095 0 4.5 ]
[.20179 .11905 -18 -4.5 ]
[.20179 .11905 0 4.5 ]
[.20179 .15714 -18 -4.5 ]
[.20179 .15714 0 4.5 ]
[.20179 .19524 -6 -4.5 ]
[.20179 .19524 0 4.5 ]
[.5 .2125 -60 0 ]
[.5 .2125 60 9 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .00476 m
.02381 .01101 L
s
[(-1)] .02381 -0.00774 0 1 Mshowa
.40476 .00476 m
.40476 .01101 L
s
[(1)] .40476 -0.00774 0 1 Mshowa
.59524 .00476 m
.59524 .01101 L
s
[(2)] .59524 -0.00774 0 1 Mshowa
.78571 .00476 m
.78571 .01101 L
s
[(3)] .78571 -0.00774 0 1 Mshowa
.97619 .00476 m
.97619 .01101 L
s
[(4)] .97619 -0.00774 0 1 Mshowa
.125 Mabswid
.0619 .00476 m
.0619 .00851 L
s
.1 .00476 m
.1 .00851 L
s
.1381 .00476 m
.1381 .00851 L
s
.17619 .00476 m
.17619 .00851 L
s
.25238 .00476 m
.25238 .00851 L
s
.29048 .00476 m
.29048 .00851 L
s
.32857 .00476 m
.32857 .00851 L
s
.36667 .00476 m
.36667 .00851 L
s
.44286 .00476 m
.44286 .00851 L
s
.48095 .00476 m
.48095 .00851 L
s
.51905 .00476 m
.51905 .00851 L
s
.55714 .00476 m
.55714 .00851 L
s
.63333 .00476 m
.63333 .00851 L
s
.67143 .00476 m
.67143 .00851 L
s
.70952 .00476 m
.70952 .00851 L
s
.74762 .00476 m
.74762 .00851 L
s
.82381 .00476 m
.82381 .00851 L
s
.8619 .00476 m
.8619 .00851 L
s
.9 .00476 m
.9 .00851 L
s
.9381 .00476 m
.9381 .00851 L
s
.25 Mabswid
0 .00476 m
1 .00476 L
s
.21429 .04286 m
.22054 .04286 L
s
[(0.2)] .20179 .04286 1 0 Mshowa
.21429 .08095 m
.22054 .08095 L
s
[(0.4)] .20179 .08095 1 0 Mshowa
.21429 .11905 m
.22054 .11905 L
s
[(0.6)] .20179 .11905 1 0 Mshowa
.21429 .15714 m
.22054 .15714 L
s
[(0.8)] .20179 .15714 1 0 Mshowa
.21429 .19524 m
.22054 .19524 L
s
[(1)] .20179 .19524 1 0 Mshowa
.125 Mabswid
.21429 .01429 m
.21804 .01429 L
s
.21429 .02381 m
.21804 .02381 L
s
.21429 .03333 m
.21804 .03333 L
s
.21429 .05238 m
.21804 .05238 L
s
.21429 .0619 m
.21804 .0619 L
s
.21429 .07143 m
.21804 .07143 L
s
.21429 .09048 m
.21804 .09048 L
s
.21429 .1 m
.21804 .1 L
s
.21429 .10952 m
.21804 .10952 L
s
.21429 .12857 m
.21804 .12857 L
s
.21429 .1381 m
.21804 .1381 L
s
.21429 .14762 m
.21804 .14762 L
s
.21429 .16667 m
.21804 .16667 L
s
.21429 .17619 m
.21804 .17619 L
s
.21429 .18571 m
.21804 .18571 L
s
.25 Mabswid
.21429 0 m
.21429 .2 L
s
[(window function b\\(t\\))] .5 .2125 0 -1 Mshowa
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
.5 Mabswid
.02381 .00476 m
.04262 .00476 L
.0522 .00476 L
.06244 .00476 L
.06525 .00476 L
.0679 .00476 L
.06905 .00476 L
.07027 .00476 L
.07091 .00476 L
.07162 .00477 L
.07286 .00497 L
.07412 .00531 L
.07527 .00569 L
.07786 .00676 L
.08255 .00926 L
.09385 .01722 L
.10458 .0265 L
.14277 .06595 L
.18342 .10972 L
.22255 .14655 L
.24252 .16189 L
.26413 .17529 L
.27428 .18036 L
.285 .18484 L
.29504 .18824 L
.3042 .19068 L
.31367 .19258 L
.31889 .19338 L
.32383 .19398 L
.3284 .19441 L
.33262 .19471 L
.33725 .19495 L
.33959 .19504 L
.34217 .19511 L
.34452 .19516 L
.34585 .19518 L
.34708 .1952 L
.3484 .19521 L
.34959 .19522 L
.35025 .19523 L
.35096 .19523 L
.35226 .19523 L
.35337 .19524 L
.3546 .19524 L
.35588 .19524 L
.35708 .19524 L
.35819 .19524 L
.35922 .19524 L
.36152 .19524 L
.38237 .19524 L
Mistroke
.42213 .19524 L
.46038 .19524 L
.50107 .19524 L
.54026 .19524 L
.58189 .19524 L
.6028 .19524 L
.62201 .19524 L
.63173 .19524 L
.63647 .19524 L
.63854 .19524 L
.64079 .19524 L
.64201 .19524 L
.64314 .19524 L
.64422 .19524 L
.64536 .19524 L
.64656 .19524 L
.64769 .19523 L
.64892 .19523 L
.64961 .19523 L
.65025 .19522 L
.6515 .19521 L
.65266 .1952 L
.65394 .19519 L
.6553 .19516 L
.65809 .19511 L
.66061 .19503 L
.66293 .19494 L
.66548 .19482 L
.67062 .19449 L
.67538 .19406 L
.67984 .19355 L
.68988 .19194 L
.69551 .19075 L
.70065 .18947 L
.71971 .18298 L
.73048 .17808 L
.74046 .17274 L
.77969 .14466 L
.81741 .10887 L
.85758 .06556 L
.89624 .02575 L
.9066 .01686 L
.91626 .00998 L
.92112 .00725 L
.92362 .00612 L
.92493 .00562 L
.92632 .00518 L
.92706 .00499 L
.92787 .00484 L
.9286 .00476 L
Mistroke
.92929 .00476 L
.9321 .00476 L
.93735 .00476 L
.97614 .00476 L
.97619 .00476 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "Here is a window function over the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([1, 4]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " with the taper function ",
  Cell[BoxData[
      \(TraditionalForm
      \`sin \(\[InvisibleSpace]\([
        \[Pi] \( t\^3\) \((10 - 15  t + 6  t\^2)\)/2]\)\)\)], "InlineFormula",
    
    CellTags->"S3.1.2"],
  ". Note that the taper function is input as a pure function. The taper \
width ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`1\)], "InlineFormula",
    CellTags->"S3.1.2"],
  ", that is, the window actually extends from ",
  Cell[BoxData[
      \(TraditionalForm\`0\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`5\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.59"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[WindowFunction[t-1, 3,
Taper -> {Sin[Pi/2 #^3(10-15#+6#^2)]&, 1}]],
{t, 0, 5}, AspectRatio -> Automatic,
Ticks->{Automatic, {0,1}}, PlotLabel -> \"window function b(t)\"]\
\>", 
  "Input",
  CellLabel->"In[45]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0047619 0.190476 [
[.21429 -0.00774 -3 -9 ]
[.21429 -0.00774 3 0 ]
[.40476 -0.00774 -3 -9 ]
[.40476 -0.00774 3 0 ]
[.59524 -0.00774 -3 -9 ]
[.59524 -0.00774 3 0 ]
[.78571 -0.00774 -3 -9 ]
[.78571 -0.00774 3 0 ]
[.97619 -0.00774 -3 -9 ]
[.97619 -0.00774 3 0 ]
[.01131 .19524 -6 -4.5 ]
[.01131 .19524 0 4.5 ]
[.5 .2125 -60 0 ]
[.5 .2125 60 9 ]
[ 0 0 0 0 ]
[ 1 .2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .00476 m
.21429 .01101 L
s
[(1)] .21429 -0.00774 0 1 Mshowa
.40476 .00476 m
.40476 .01101 L
s
[(2)] .40476 -0.00774 0 1 Mshowa
.59524 .00476 m
.59524 .01101 L
s
[(3)] .59524 -0.00774 0 1 Mshowa
.78571 .00476 m
.78571 .01101 L
s
[(4)] .78571 -0.00774 0 1 Mshowa
.97619 .00476 m
.97619 .01101 L
s
[(5)] .97619 -0.00774 0 1 Mshowa
.125 Mabswid
.0619 .00476 m
.0619 .00851 L
s
.1 .00476 m
.1 .00851 L
s
.1381 .00476 m
.1381 .00851 L
s
.17619 .00476 m
.17619 .00851 L
s
.25238 .00476 m
.25238 .00851 L
s
.29048 .00476 m
.29048 .00851 L
s
.32857 .00476 m
.32857 .00851 L
s
.36667 .00476 m
.36667 .00851 L
s
.44286 .00476 m
.44286 .00851 L
s
.48095 .00476 m
.48095 .00851 L
s
.51905 .00476 m
.51905 .00851 L
s
.55714 .00476 m
.55714 .00851 L
s
.63333 .00476 m
.63333 .00851 L
s
.67143 .00476 m
.67143 .00851 L
s
.70952 .00476 m
.70952 .00851 L
s
.74762 .00476 m
.74762 .00851 L
s
.82381 .00476 m
.82381 .00851 L
s
.8619 .00476 m
.8619 .00851 L
s
.9 .00476 m
.9 .00851 L
s
.9381 .00476 m
.9381 .00851 L
s
.25 Mabswid
0 .00476 m
1 .00476 L
s
.02381 .19524 m
.03006 .19524 L
s
[(1)] .01131 .19524 1 0 Mshowa
.02381 0 m
.02381 .2 L
s
[(window function b\\(t\\))] .5 .2125 0 -1 Mshowa
0 0 m
1 0 L
1 .2 L
0 .2 L
closepath
clip
newpath
.5 Mabswid
.02381 .00476 m
.02499 .00476 L
.02605 .00476 L
.02729 .00476 L
.02846 .00477 L
.02954 .00477 L
.03053 .00478 L
.03163 .00479 L
.03279 .0048 L
.03395 .00482 L
.0352 .00484 L
.03746 .00489 L
.04016 .00498 L
.04262 .0051 L
.04514 .00524 L
.04748 .00541 L
.05278 .00593 L
.05746 .00656 L
.06244 .00743 L
.06791 .00863 L
.07382 .01027 L
.08454 .01417 L
.09498 .0192 L
.10458 .02494 L
.1234 .03926 L
.14407 .05917 L
.18449 .10574 L
.2234 .14858 L
.24464 .16668 L
.2544 .17333 L
.26476 .17922 L
.27422 .18358 L
.28467 .18735 L
.29417 .18994 L
.30309 .19174 L
.31292 .19315 L
.31787 .19367 L
.32327 .19412 L
.32791 .19441 L
.33286 .19466 L
.33753 .19483 L
.34178 .19495 L
.34663 .19506 L
.34907 .19509 L
.35176 .19513 L
.35405 .19515 L
.35651 .19517 L
.35882 .19519 L
.36096 .1952 L
.36363 .19521 L
Mistroke
.36654 .19522 L
.3691 .19523 L
.37041 .19523 L
.37183 .19523 L
.37323 .19523 L
.37452 .19523 L
.37572 .19523 L
.37704 .19524 L
.37934 .19524 L
.38059 .19524 L
.38176 .19524 L
.38303 .19524 L
.38437 .19524 L
.38552 .19524 L
.38678 .19524 L
.38749 .19524 L
.38814 .19524 L
.38884 .19524 L
.3896 .19524 L
.39089 .19524 L
.39159 .19524 L
.39224 .19524 L
.39353 .19524 L
.39475 .19524 L
.39585 .19524 L
.39704 .19524 L
.39833 .19524 L
.39898 .19524 L
.3997 .19524 L
.40097 .19524 L
.40215 .19524 L
.4033 .19524 L
.40456 .19524 L
.40574 .19524 L
.40684 .19524 L
.41111 .19524 L
.42072 .19524 L
.45995 .19524 L
.49767 .19524 L
.53784 .19524 L
.5563 .19524 L
.56676 .19524 L
.5765 .19524 L
.58617 .19524 L
.58896 .19524 L
.59159 .19524 L
.59395 .19524 L
.5946 .19524 L
.59529 .19524 L
.59652 .19524 L
Mistroke
.59782 .19524 L
.59901 .19524 L
.59967 .19524 L
.60039 .19524 L
.6017 .19524 L
.60292 .19524 L
.60422 .19524 L
.60544 .19524 L
.60655 .19524 L
.60725 .19524 L
.60798 .19524 L
.60929 .19524 L
.61002 .19524 L
.6107 .19524 L
.61149 .19524 L
.61225 .19524 L
.6136 .19524 L
.61483 .19524 L
.61616 .19524 L
.61761 .19524 L
.61883 .19524 L
.61994 .19524 L
.62115 .19524 L
.62246 .19524 L
.62468 .19523 L
.62589 .19523 L
.62702 .19523 L
.62965 .19523 L
.63204 .19522 L
.63479 .19522 L
.6374 .19521 L
.63995 .1952 L
.64264 .19518 L
.64495 .19516 L
.64748 .19514 L
.6502 .1951 L
.65313 .19506 L
.65569 .19501 L
.65841 .19495 L
.66367 .19479 L
.66855 .1946 L
.67435 .19428 L
.6796 .19389 L
.68458 .19343 L
.68996 .19279 L
.69971 .19124 L
.70925 .1891 L
.7197 .1859 L
.73061 .18147 L
.74078 .17622 L
Mistroke
.76119 .1622 L
.77976 .1455 L
.81968 .10078 L
.85808 .05693 L
.87752 .03847 L
.88783 .03023 L
.89894 .02271 L
.90954 .01687 L
.91924 .01265 L
.929 .00945 L
.93827 .00729 L
.94326 .00645 L
.94779 .00587 L
.9503 .00561 L
.95301 .00538 L
.95536 .00521 L
.95793 .00507 L
.96032 .00496 L
.96256 .00489 L
.96491 .00484 L
.96623 .00481 L
.96744 .0048 L
.96856 .00479 L
.96959 .00478 L
.97073 .00477 L
.97193 .00477 L
.97298 .00476 L
.97396 .00476 L
.97503 .00476 L
.97619 .00476 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "We can also get an asymmetric window function by specifying different \
taper functions for the left (",
  StyleBox["Trig[2]", "MR"],
  ") and right (",
  StyleBox["Polynomial[5]", "MR"],
  ") transition regions."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.60"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[WindowFunction[t, 4,
Taper->{{Trig[2], Automatic}, {Polynomial[5], 2}}]],
{t, -2, 6}, AspectRatio -> Automatic,
Ticks->{Automatic, {0,1}}, PlotLabel -> \"window function b(t)\"]\
\>", 
  "Input",
  CellLabel->"In[46]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .125 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.119048 0.00297619 0.119048 [
[.02381 -0.00952 -6 -9 ]
[.02381 -0.00952 6 0 ]
[.5 -0.00952 -3 -9 ]
[.5 -0.00952 3 0 ]
[.7381 -0.00952 -3 -9 ]
[.7381 -0.00952 3 0 ]
[.97619 -0.00952 -3 -9 ]
[.97619 -0.00952 3 0 ]
[.2494 .12202 -6 -4.5 ]
[.2494 .12202 0 4.5 ]
[.5 .1375 -60 0 ]
[.5 .1375 60 9 ]
[ 0 0 0 0 ]
[ 1 .125 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .00298 m
.02381 .00923 L
s
[(-2)] .02381 -0.00952 0 1 Mshowa
.5 .00298 m
.5 .00923 L
s
[(2)] .5 -0.00952 0 1 Mshowa
.7381 .00298 m
.7381 .00923 L
s
[(4)] .7381 -0.00952 0 1 Mshowa
.97619 .00298 m
.97619 .00923 L
s
[(6)] .97619 -0.00952 0 1 Mshowa
.125 Mabswid
.08333 .00298 m
.08333 .00673 L
s
.14286 .00298 m
.14286 .00673 L
s
.20238 .00298 m
.20238 .00673 L
s
.32143 .00298 m
.32143 .00673 L
s
.38095 .00298 m
.38095 .00673 L
s
.44048 .00298 m
.44048 .00673 L
s
.55952 .00298 m
.55952 .00673 L
s
.61905 .00298 m
.61905 .00673 L
s
.67857 .00298 m
.67857 .00673 L
s
.79762 .00298 m
.79762 .00673 L
s
.85714 .00298 m
.85714 .00673 L
s
.91667 .00298 m
.91667 .00673 L
s
.25 Mabswid
0 .00298 m
1 .00298 L
s
.2619 .12202 m
.26815 .12202 L
s
[(1)] .2494 .12202 1 0 Mshowa
.2619 0 m
.2619 .125 L
s
[(window function b\\(t\\))] .5 .1375 0 -1 Mshowa
0 0 m
1 0 L
1 .125 L
0 .125 L
closepath
clip
newpath
.5 Mabswid
.02381 .00298 m
.06244 .00298 L
.08255 .00298 L
.10458 .00298 L
.11448 .00298 L
.12507 .00298 L
.1302 .00298 L
.13506 .00298 L
.13942 .00298 L
.14061 .00298 L
.14188 .00298 L
.14296 .00298 L
.14415 .00298 L
.14544 .00298 L
.14664 .00298 L
.14795 .00298 L
.14868 .00298 L
.14935 .00298 L
.15057 .00298 L
.15189 .00298 L
.15314 .00299 L
.15429 .00299 L
.1554 .003 L
.15644 .00301 L
.15758 .00302 L
.1588 .00303 L
.16008 .00305 L
.16129 .00308 L
.16356 .00313 L
.16608 .00323 L
.16876 .00336 L
.17104 .00351 L
.17356 .00373 L
.17626 .00403 L
.17917 .00444 L
.18444 .00545 L
.1894 .0068 L
.19401 .00847 L
.19907 .01082 L
.20448 .01402 L
.21553 .02301 L
.22558 .03415 L
.24638 .06405 L
.25551 .078 L
.26556 .09201 L
.27457 .10239 L
.28425 .11072 L
.28959 .11407 L
.29447 .11644 L
.29937 .11824 L
Mistroke
.30403 .1195 L
.30663 .12003 L
.30907 .12045 L
.31364 .12104 L
.3162 .12129 L
.31856 .12146 L
.32114 .12161 L
.32387 .12173 L
.32607 .12181 L
.32842 .12187 L
.33063 .12191 L
.33265 .12194 L
.33502 .12197 L
.33636 .12198 L
.33759 .12199 L
.33986 .122 L
.34101 .12201 L
.34227 .12201 L
.34463 .12201 L
.34597 .12202 L
.34721 .12202 L
.34852 .12202 L
.34971 .12202 L
.35109 .12202 L
.35239 .12202 L
.35352 .12202 L
.35471 .12202 L
.35572 .12202 L
.35684 .12202 L
.35804 .12202 L
.35933 .12202 L
.36055 .12202 L
.36166 .12202 L
.36295 .12202 L
.3636 .12202 L
.36432 .12202 L
.36559 .12202 L
.36679 .12202 L
.36747 .12202 L
.36819 .12202 L
.36947 .12202 L
.37019 .12202 L
.37086 .12202 L
.37159 .12202 L
.37237 .12202 L
.37368 .12202 L
.37442 .12202 L
.37511 .12202 L
.37636 .12202 L
.37699 .12202 L
Mistroke
.37769 .12202 L
.37889 .12202 L
.38019 .12202 L
.38141 .12202 L
.38253 .12202 L
.42226 .12202 L
.46047 .12202 L
.4818 .12202 L
.49187 .12202 L
.49629 .12202 L
.4988 .12202 L
.50002 .12202 L
.50113 .12202 L
.5023 .12202 L
.50341 .12202 L
.50458 .12202 L
.50585 .12202 L
.5071 .12202 L
.50773 .12202 L
.50843 .12202 L
.50967 .12202 L
.51082 .12202 L
.51211 .12202 L
.51275 .12202 L
.51345 .12202 L
.5147 .12202 L
.51587 .12202 L
.51657 .12202 L
.51724 .12202 L
.51849 .12202 L
.51984 .12202 L
.5213 .12202 L
.52248 .12202 L
.52359 .12202 L
.5248 .12202 L
.5261 .12202 L
.52746 .12202 L
.52875 .12202 L
.53118 .12202 L
.53344 .12202 L
.53554 .12202 L
.53784 .12202 L
.54028 .12202 L
.5429 .12201 L
.54567 .12201 L
.54802 .12201 L
.55061 .122 L
.55339 .12199 L
.55638 .12198 L
.56175 .12195 L
Mistroke
.56436 .12193 L
.56718 .12191 L
.57232 .12185 L
.57732 .12178 L
.58194 .1217 L
.58659 .12159 L
.5916 .12145 L
.60066 .12111 L
.60617 .12083 L
.61142 .12052 L
.62128 .11977 L
.63086 .11882 L
.64107 .11753 L
.65946 .11437 L
.68086 .1092 L
.70103 .10275 L
.73957 .08645 L
.78056 .06494 L
.82003 .0432 L
.85799 .02467 L
.87913 .01645 L
.8984 .01065 L
.90797 .00841 L
.91837 .00646 L
.9282 .00507 L
.9373 .00414 L
.94189 .00379 L
.94683 .0035 L
.9515 .00329 L
.95578 .00316 L
.95824 .0031 L
.96053 .00306 L
.96304 .00303 L
.96444 .00301 L
.96572 .003 L
.96707 .00299 L
.96831 .00299 L
.96967 .00298 L
.97035 .00298 L
.97111 .00298 L
.97237 .00298 L
.97308 .00298 L
.97373 .00298 L
.97499 .00298 L
.97619 .00298 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "We evaluate the cosine packet of frequency index 15 over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([0, 2]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " with the default taper and plot it over the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([\(-1\), 3]\)\)\)], 
    "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.61"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[CosPacket[t, 2, 15]], {t, -1, 3},
AxesLabel->{\"t\", \"\"}, PlotLabel -> \"cosine packet\"]\
\>", "Input",
  CellLabel->"In[47]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.309005 0.294342 [
[.02381 .29651 -6 -9 ]
[.02381 .29651 6 0 ]
[.5 .29651 -3 -9 ]
[.5 .29651 3 0 ]
[.7381 .29651 -3 -9 ]
[.7381 .29651 3 0 ]
[.97619 .29651 -3 -9 ]
[.97619 .29651 3 0 ]
[1.025 .30901 0 -4.5 ]
[1.025 .30901 6 4.5 ]
[.2494 .01466 -12 -4.5 ]
[.2494 .01466 0 4.5 ]
[.2494 .16183 -24 -4.5 ]
[.2494 .16183 0 4.5 ]
[.2494 .45618 -18 -4.5 ]
[.2494 .45618 0 4.5 ]
[.2494 .60335 -6 -4.5 ]
[.2494 .60335 0 4.5 ]
[.5 .63053 -39 0 ]
[.5 .63053 39 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30901 m
.02381 .31526 L
s
[(-1)] .02381 .29651 0 1 Mshowa
.5 .30901 m
.5 .31526 L
s
[(1)] .5 .29651 0 1 Mshowa
.7381 .30901 m
.7381 .31526 L
s
[(2)] .7381 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(3)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.21429 .30901 m
.21429 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.40476 .30901 m
.40476 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.59524 .30901 m
.59524 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.78571 .30901 m
.78571 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
[(t)] 1.025 .30901 -1 0 Mshowa
.2619 .01466 m
.26815 .01466 L
s
[(-1)] .2494 .01466 1 0 Mshowa
.2619 .16183 m
.26815 .16183 L
s
[(-0.5)] .2494 .16183 1 0 Mshowa
.2619 .45618 m
.26815 .45618 L
s
[(0.5)] .2494 .45618 1 0 Mshowa
.2619 .60335 m
.26815 .60335 L
s
[(1)] .2494 .60335 1 0 Mshowa
.125 Mabswid
.2619 .0441 m
.26565 .0441 L
s
.2619 .07353 m
.26565 .07353 L
s
.2619 .10297 m
.26565 .10297 L
s
.2619 .1324 m
.26565 .1324 L
s
.2619 .19127 m
.26565 .19127 L
s
.2619 .2207 m
.26565 .2207 L
s
.2619 .25014 m
.26565 .25014 L
s
.2619 .27957 m
.26565 .27957 L
s
.2619 .33844 m
.26565 .33844 L
s
.2619 .36787 m
.26565 .36787 L
s
.2619 .39731 m
.26565 .39731 L
s
.2619 .42674 m
.26565 .42674 L
s
.2619 .48561 m
.26565 .48561 L
s
.2619 .51505 m
.26565 .51505 L
s
.2619 .54448 m
.26565 .54448 L
s
.2619 .57391 m
.26565 .57391 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
[(cosine packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.06244 .30901 L
.08255 .30901 L
.10458 .30901 L
.11448 .30901 L
.12507 .30901 L
.1302 .30901 L
.13506 .30901 L
.13942 .30901 L
.14061 .30901 L
.14188 .30901 L
.14296 .30901 L
.14415 .30933 L
.14664 .31031 L
.14732 .31056 L
.14804 .31078 L
.14935 .31102 L
.14999 .31105 L
.15068 .311 L
.15194 .31067 L
.15316 .31001 L
.15429 .30909 L
.1554 .30788 L
.15644 .30647 L
.1588 .30232 L
.16356 .291 L
.16604 .28464 L
.16735 .28151 L
.16874 .27852 L
.16995 .27633 L
.17059 .27536 L
.17128 .27447 L
.1725 .27339 L
.17364 .27299 L
.17432 .27305 L
.17507 .27341 L
.17586 .2741 L
.17658 .27507 L
.17789 .27757 L
.17929 .28137 L
.18068 .2863 L
.18199 .29198 L
.18444 .30502 L
.19416 .37149 L
.19652 .38526 L
.19783 .39142 L
.19906 .3961 L
.19976 .39817 L
.20052 .39993 L
.20121 .40106 L
Mistroke
.20185 .40169 L
.20311 .40168 L
.20381 .40093 L
.20445 .39978 L
.20561 .39654 L
.20683 .39148 L
.20788 .38584 L
.20902 .3783 L
.21158 .35667 L
.21396 .33137 L
.22291 .21874 L
.22534 .19236 L
.22668 .18029 L
.22793 .17086 L
.22928 .163 L
.22999 .15989 L
.23076 .15742 L
.23143 .15603 L
.23213 .15534 L
.23338 .15614 L
.23457 .15936 L
.23584 .16544 L
.23704 .17366 L
.23812 .18316 L
.24079 .21409 L
.2433 .25179 L
.25215 .41284 L
.25457 .45225 L
.25591 .47096 L
.25717 .48623 L
.25835 .49799 L
.25963 .50785 L
.26079 .51396 L
.26187 .51707 L
.26302 .51759 L
.26411 .51536 L
.2653 .50986 L
.26659 .50038 L
.26787 .48747 L
.26921 .47024 L
.27161 .43106 L
.27695 .31646 L
.28192 .19989 L
.28618 .11631 L
.28741 .0978 L
.28857 .08319 L
.28961 .07266 L
.29073 .0642 L
.29189 .05885 L
.29317 .05703 L
Mistroke
.29381 .05775 L
.2945 .05976 L
.29575 .06661 L
.29699 .07746 L
.29817 .09138 L
.30038 .12635 L
.30998 .36359 L
.31251 .43033 L
.31525 .4943 L
.3165 .51941 L
.31783 .5423 L
.31907 .55997 L
.32021 .57261 L
.32135 .58187 L
.32259 .58763 L
.32373 .58903 L
.32481 .58681 L
.32606 .57992 L
.32722 .56951 L
.3285 .55376 L
.32985 .53237 L
.33401 .4412 L
.3386 .3123 L
.34352 .1721 L
.3462 .10739 L
.34751 .08098 L
.3487 .06047 L
.34973 .04567 L
.35084 .0329 L
.35201 .02329 L
.35312 .018 L
.35435 .01651 L
.35564 .01993 L
.35674 .02687 L
.35796 .03868 L
.35935 .0574 L
.36068 .07992 L
.36316 .13319 L
.36874 .28821 L
.37403 .44239 L
.37653 .50434 L
.37882 .55015 L
.37996 .56811 L
.38121 .58376 L
.38246 .595 L
.38378 .60177 L
.38495 .60331 L
.38619 .60033 L
.38737 .59318 L
.38844 .58308 L
Mistroke
.38975 .56627 L
.39097 .54663 L
.3937 .48934 L
.39868 .35316 L
.40329 .21615 L
.40761 .10562 L
.40978 .06377 L
.411 .04542 L
.41212 .03222 L
.41334 .02193 L
.41403 .01807 L
.41467 .01577 L
.41584 .01482 L
.41709 .01845 L
.41833 .02675 L
.41903 .03348 L
.41969 .04107 L
.42244 .08541 L
.42482 .13806 L
.42736 .20559 L
.43308 .37468 L
.43589 .45332 L
.43849 .51568 L
.44094 .56117 L
.44217 .5783 L
.44289 .58624 L
.44354 .59222 L
.4442 .59701 L
.4449 .60061 L
.44561 .60273 L
.44637 .60332 L
.44704 .60235 L
.44775 .59982 L
.44904 .59137 L
.45028 .57856 L
.45163 .55975 L
.45408 .51375 L
.45866 .39622 L
.4636 .24909 L
.46633 .17209 L
.46892 .10867 L
.47132 .06228 L
.47268 .04243 L
.47394 .02861 L
.4751 .01995 L
.47616 .01565 L
.47738 .01493 L
.47852 .01842 L
.47974 .02651 L
.48103 .03982 L
Mistroke
.48213 .05488 L
.48334 .07508 L
.48854 .19805 L
.4942 .36534 L
.49699 .44424 L
.49956 .50761 L
.50194 .55406 L
.50314 .57218 L
.50383 .58082 L
.50446 .58755 L
.50509 .59312 L
.50579 .59784 L
.50648 .60113 L
.50721 .60301 L
.50786 .6033 L
.50855 .6022 L
.50979 .59654 L
.51099 .58662 L
.5123 .57111 L
.51467 .53132 L
.51698 .48008 L
.5191 .42442 L
.52432 .27068 L
.52719 .1878 L
.52992 .11869 L
.53245 .06758 L
.53388 .04562 L
.53456 .03709 L
.5352 .03028 L
.53631 .02136 L
.53754 .01581 L
.53874 .01483 L
.54003 .01871 L
.54121 .02667 L
.5423 .03777 L
.54351 .05388 L
.5448 .07537 L
.54982 .19363 L
.55882 .45447 L
.56148 .518 L
.56289 .54552 L
.56438 .56935 L
.56568 .58526 L
.56642 .59214 L
.56711 .59713 L
.56833 .60237 L
.56963 .60295 L
.57089 .59855 L
.5716 .59393 L
.57227 .58829 L
Mistroke
.57348 .57466 L
.57477 .55565 L
.57723 .50779 L
.57947 .45345 L
.58883 .18244 L
.59111 .12457 L
.59355 .07365 L
.59495 .05084 L
.59622 .03463 L
.59751 .02305 L
.59872 .01661 L
.60003 .01472 L
.60069 .01576 L
.60142 .01847 L
.60271 .02718 L
.60392 .03979 L
.60534 .05983 L
.60664 .0828 L
.60957 .14849 L
.61439 .28446 L
.61954 .43528 L
.62219 .50169 L
.62349 .52945 L
.62468 .5516 L
.62575 .56829 L
.62692 .58308 L
.6281 .59396 L
.62935 .60096 L
.63054 .60319 L
.63162 .60144 L
.63288 .59494 L
.63406 .58443 L
.63516 .57115 L
.63617 .5559 L
.63847 .51183 L
.6436 .3781 L
.64914 .21487 L
.65169 .14728 L
.65437 .08824 L
.65548 .0686 L
.65666 .05106 L
.65796 .03625 L
.65918 .02683 L
.65984 .0235 L
.66055 .02144 L
.66183 .02157 L
.66253 .02376 L
.6632 .02716 L
.66393 .03239 L
.66471 .03971 L
Mistroke
.66611 .05705 L
.66744 .07828 L
.66994 .12908 L
.67502 .26243 L
.67974 .39541 L
.68405 .49754 L
.68529 .52052 L
.68646 .53892 L
.6875 .55243 L
.68864 .56397 L
.68983 .57214 L
.69107 .57651 L
.69223 .57662 L
.69331 .57332 L
.69459 .56532 L
.69575 .55426 L
.69709 .5373 L
.69836 .5174 L
.70801 .29278 L
.71055 .22992 L
.71329 .16995 L
.71455 .14634 L
.71588 .12475 L
.71703 .10908 L
.71826 .09561 L
.71939 .08633 L
.72042 .08061 L
.72145 .0775 L
.72243 .07699 L
.72357 .07936 L
.72463 .0843 L
.72578 .09266 L
.72701 .10469 L
.72938 .13642 L
.73161 .17442 L
.73667 .27843 L
.74164 .38074 L
.74427 .4257 L
.74571 .44613 L
.74706 .46217 L
.74836 .47431 L
.74903 .47943 L
.74975 .48385 L
.75102 .48919 L
.75219 .49129 L
.75336 .49071 L
.75445 .48779 L
.75565 .48207 L
.75694 .47317 L
.75932 .44988 L
Mistroke
.76192 .41651 L
.76663 .34371 L
.77089 .27781 L
.77312 .24763 L
.77547 .2213 L
.77668 .21032 L
.778 .20053 L
.77921 .19371 L
.78033 .18921 L
.78148 .18641 L
.78253 .18548 L
.78374 .18627 L
.78488 .18877 L
.78614 .19338 L
.78748 .2002 L
.78987 .21671 L
.79526 .26689 L
.80009 .31407 L
.80275 .33621 L
.80527 .35288 L
.8067 .36009 L
.80745 .36322 L
.80825 .36603 L
.80899 .36815 L
.80966 .36968 L
.81096 .37157 L
.81228 .3721 L
.81302 .37182 L
.8137 .3712 L
.81496 .36925 L
.81628 .36614 L
.81884 .35762 L
.82126 .34746 L
.8258 .32668 L
.82816 .31665 L
.83068 .30766 L
.83199 .30383 L
.83343 .30038 L
.83475 .29795 L
.83598 .2963 L
.83711 .29529 L
.83834 .29471 L
.83951 .29464 L
.84059 .29493 L
.84167 .29551 L
.84264 .29627 L
.84482 .2985 L
.84935 .30402 L
.85059 .30537 L
.85193 .30663 L
Mistroke
.85308 .30752 L
.85433 .30826 L
.85564 .30876 L
.85688 .30899 L
.85809 .30901 L
.8592 .30901 L
.86435 .30901 L
.87357 .30901 L
.89439 .30901 L
.93365 .30901 L
.9714 .30901 L
.97619 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "This is a sine packet of frequency index ",
  Cell[BoxData[
      \(TraditionalForm\`24\)], "InlineFormula",
    CellTags->"S3.1.2"],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[InvisibleSpace]\([3, 8]\)\)\)], "InlineFormula",
    CellTags->"S3.1.2"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.62"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SinPacket[t-3, 5, 24,
Taper -> {Polynomial[4], 2}]], {t, 0, 10},
PlotPoints -> 35, AxesLabel -> {\"t\", \"\"},
PlotLabel -> \"sine packet\"]\
\>", "Input",
  CellLabel->"In[48]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.309017 0.465333 [
[.21429 .29652 -3 -9 ]
[.21429 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -3 -9 ]
[.78571 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -4.5 ]
[1.025 .30902 6 4.5 ]
[.01131 .02982 -24 -4.5 ]
[.01131 .02982 0 4.5 ]
[.01131 .12288 -24 -4.5 ]
[.01131 .12288 0 4.5 ]
[.01131 .21595 -24 -4.5 ]
[.01131 .21595 0 4.5 ]
[.01131 .40208 -18 -4.5 ]
[.01131 .40208 0 4.5 ]
[.01131 .49515 -18 -4.5 ]
[.01131 .49515 0 4.5 ]
[.01131 .58822 -18 -4.5 ]
[.01131 .58822 0 4.5 ]
[.5 .63053 -33 0 ]
[.5 .63053 33 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
[(t)] 1.025 .30902 -1 0 Mshowa
.02381 .02982 m
.03006 .02982 L
s
[(-0.6)] .01131 .02982 1 0 Mshowa
.02381 .12288 m
.03006 .12288 L
s
[(-0.4)] .01131 .12288 1 0 Mshowa
.02381 .21595 m
.03006 .21595 L
s
[(-0.2)] .01131 .21595 1 0 Mshowa
.02381 .40208 m
.03006 .40208 L
s
[(0.2)] .01131 .40208 1 0 Mshowa
.02381 .49515 m
.03006 .49515 L
s
[(0.4)] .01131 .49515 1 0 Mshowa
.02381 .58822 m
.03006 .58822 L
s
[(0.6)] .01131 .58822 1 0 Mshowa
.125 Mabswid
.02381 .05308 m
.02756 .05308 L
s
.02381 .07635 m
.02756 .07635 L
s
.02381 .09962 m
.02756 .09962 L
s
.02381 .14615 m
.02756 .14615 L
s
.02381 .16942 m
.02756 .16942 L
s
.02381 .19268 m
.02756 .19268 L
s
.02381 .23922 m
.02756 .23922 L
s
.02381 .26248 m
.02756 .26248 L
s
.02381 .28575 m
.02756 .28575 L
s
.02381 .33228 m
.02756 .33228 L
s
.02381 .35555 m
.02756 .35555 L
s
.02381 .37882 m
.02756 .37882 L
s
.02381 .42535 m
.02756 .42535 L
s
.02381 .44862 m
.02756 .44862 L
s
.02381 .47188 m
.02756 .47188 L
s
.02381 .51842 m
.02756 .51842 L
s
.02381 .54168 m
.02756 .54168 L
s
.02381 .56495 m
.02756 .56495 L
s
.02381 .00655 m
.02756 .00655 L
s
.02381 .61148 m
.02756 .61148 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(sine packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.05108 .30902 L
.08082 .30902 L
.09528 .30902 L
.10234 .30902 L
.10876 .30902 L
.11196 .30902 L
.11543 .30902 L
.11702 .30902 L
.11789 .30902 L
.11871 .30902 L
.1194 .30902 L
.12015 .30902 L
.12098 .30902 L
.12174 .30903 L
.12259 .30904 L
.1235 .30906 L
.12436 .30909 L
.12514 .30912 L
.12692 .3092 L
.12786 .30925 L
.12838 .30927 L
.12885 .30929 L
.12972 .30931 L
.13018 .30932 L
.13067 .30932 L
.13154 .30931 L
.13234 .30927 L
.13315 .30921 L
.13402 .3091 L
.13485 .30897 L
.13562 .30882 L
.14196 .30656 L
.1437 .30588 L
.14464 .30558 L
.14553 .30535 L
.14628 .30522 L
.14709 .30516 L
.14798 .30519 L
.1488 .30533 L
.14926 .30546 L
.14976 .30564 L
.15065 .30606 L
.1516 .30669 L
.15265 .30757 L
.15454 .30962 L
.1563 .312 L
.15995 .31748 L
.16173 .31983 L
.1625 .32068 L
Mistroke
.16334 .32142 L
.16421 .32198 L
.16504 .32227 L
.1655 .32233 L
.16598 .32229 L
.16685 .32199 L
.16731 .3217 L
.1678 .32129 L
.16868 .32028 L
.16973 .31861 L
.17068 .31668 L
.17427 .30638 L
.17766 .29439 L
.17924 .28912 L
.18092 .28446 L
.18161 .28293 L
.18235 .28161 L
.18317 .28057 L
.18393 .28004 L
.18476 .27998 L
.18566 .28055 L
.18612 .28111 L
.18661 .2819 L
.18749 .28385 L
.18837 .28646 L
.18919 .28951 L
.19074 .29662 L
.19762 .33937 L
.1993 .34845 L
.20022 .35252 L
.20109 .35562 L
.20158 .357 L
.20212 .35818 L
.20261 .35895 L
.20306 .35938 L
.20395 .35943 L
.2044 .35904 L
.2049 .35828 L
.20572 .35625 L
.20658 .35307 L
.20732 .34954 L
.20813 .34484 L
.21162 .3162 L
.21465 .28515 L
.21793 .25393 L
.21887 .24686 L
.21987 .2407 L
.22072 .23671 L
.2212 .23501 L
.22166 .23381 L
Mistroke
.22254 .23262 L
.22335 .23291 L
.2238 .23365 L
.22429 .23494 L
.22517 .23856 L
.22604 .24366 L
.22683 .24957 L
.22859 .2669 L
.23176 .30872 L
.23542 .36208 L
.23734 .38618 L
.23839 .39685 L
.23937 .40478 L
.24023 .40989 L
.24115 .41329 L
.24168 .41422 L
.24218 .4144 L
.24311 .41286 L
.24396 .40928 L
.24475 .40415 L
.24562 .39655 L
.24654 .38636 L
.25316 .27089 L
.25664 .21013 L
.25748 .19871 L
.25839 .18858 L
.2589 .18383 L
.25938 .18023 L
.2603 .17529 L
.26116 .17331 L
.26196 .17384 L
.26283 .17706 L
.26376 .18348 L
.26457 .19149 L
.26532 .20095 L
.26703 .22889 L
.2732 .37103 L
.27491 .40894 L
.27672 .44216 L
.27777 .45671 L
.27871 .46645 L
.27917 .46991 L
.27966 .47267 L
.28056 .47504 L
.2814 .47409 L
.28233 .46945 L
.28279 .46569 L
.28329 .46064 L
.28419 .44891 L
.28594 .41726 L
Mistroke
.28753 .3799 L
.29389 .20181 L
.29543 .16585 L
.29628 .14937 L
.29709 .13633 L
.29755 .13023 L
.29804 .12464 L
.29891 .11765 L
.2998 .11438 L
.30062 .11491 L
.30154 .1196 L
.3024 .12793 L
.30318 .13855 L
.30402 .15321 L
.30591 .19691 L
.30764 .24754 L
.311 .35862 L
.31413 .45418 L
.31577 .49218 L
.31669 .50829 L
.31753 .51928 L
.31845 .52695 L
.31897 .52919 L
.31945 .52989 L
.32033 .52771 L
.32077 .5249 L
.32126 .52047 L
.32174 .51489 L
.32224 .50767 L
.32313 .49142 L
.32515 .44074 L
.3288 .31508 L
.33226 .18887 L
.33396 .1368 L
.33553 .09957 L
.33641 .08427 L
.33734 .07291 L
.33827 .06681 L
.3388 .06579 L
.3393 .06646 L
.34016 .07135 L
.34095 .07992 L
.34186 .09453 L
.34273 .11282 L
.34429 .15557 L
.34594 .21234 L
.34893 .33076 L
.35222 .45743 L
.35387 .50852 L
.35482 .53184 L
Mistroke
.35569 .54863 L
.35614 .55561 L
.35664 .5617 L
.35716 .56641 L
.35765 .56919 L
.35811 .5703 L
.3586 .56989 L
.35948 .56504 L
.36034 .55532 L
.36114 .54186 L
.36202 .52252 L
.36296 .49675 L
.36707 .34209 L
.37083 .18309 L
.37243 .12513 L
.37414 .0765 L
.37465 .06531 L
.37513 .05624 L
.37602 .04331 L
.37686 .03619 L
.37777 .03411 L
.37865 .03776 L
.37915 .04229 L
.37962 .04811 L
.38056 .06439 L
.38157 .08824 L
.3834 .14614 L
.38507 .21191 L
.38843 .36138 L
.39159 .49034 L
.39317 .53971 L
.39406 .56113 L
.39488 .57624 L
.39573 .58698 L
.39665 .59281 L
.39712 .59334 L
.39762 .59211 L
.39852 .58524 L
.39903 .57872 L
.3995 .57106 L
.40057 .54818 L
.40151 .52206 L
.4025 .48896 L
.40612 .33606 L
.4098 .17066 L
.41155 .10537 L
.41317 .05893 L
.41395 .0423 L
.41479 .02933 L
.41573 .02097 L
Mistroke
.41657 .01904 L
.41737 .0222 L
.41824 .03104 L
.41906 .0444 L
.41981 .0608 L
.42147 .10949 L
.42329 .1793 L
.42696 .34742 L
.43018 .48668 L
.43111 .51948 L
.43199 .5462 L
.43279 .56636 L
.43364 .58308 L
.43438 .59344 L
.43519 .60017 L
.43593 .60193 L
.43663 .59976 L
.43744 .59253 L
.43819 .58157 L
.43901 .56495 L
.43988 .54259 L
.44169 .48134 L
.44341 .40982 L
.44662 .25991 L
.45007 .11384 L
.45102 .08262 L
.45202 .05534 L
.45288 .03727 L
.45336 .0293 L
.45382 .0234 L
.45462 .01677 L
.45549 .01513 L
.45632 .01896 L
.45708 .02713 L
.45784 .03948 L
.45853 .05416 L
.46007 .09812 L
.46173 .16015 L
.46353 .23902 L
.46678 .39198 L
.46847 .46476 L
.47027 .52986 L
.47114 .55503 L
.47197 .57434 L
.47271 .58766 L
.47351 .59759 L
.4744 .60287 L
.4749 .60319 L
.47537 .60173 L
.47587 .59835 L
Mistroke
.47632 .59363 L
.47685 .58627 L
.47735 .57743 L
.47904 .53483 L
.48089 .46925 L
.4849 .28744 L
.48688 .19659 L
.48869 .12276 L
.49034 .06923 L
.49118 .04851 L
.49209 .03118 L
.49301 .01989 L
.49352 .01632 L
.49399 .01484 L
.4949 .01679 L
.49577 .0245 L
.49656 .03648 L
.49744 .05492 L
.49922 .10741 L
.50241 .2395 L
.50618 .41573 L
.50783 .48431 L
.50877 .51795 L
.50964 .54498 L
.51058 .5688 L
.51143 .58532 L
.51234 .59719 L
.51284 .60108 L
.51331 .60299 L
.51379 .60318 L
.5143 .60146 L
.51521 .59344 L
.51572 .5863 L
.51619 .57793 L
.51727 .55309 L
.51908 .49548 L
.52073 .42888 L
.52444 .2561 L
.52781 .11376 L
.52878 .08177 L
.5297 .05674 L
.53051 .03892 L
.5314 .025 L
.53218 .01755 L
.53304 .01472 L
.53393 .01775 L
.53477 .02606 L
.53555 .0385 L
.53626 .0536 L
.53786 .09947 L
Mistroke
.54155 .25163 L
.54546 .43348 L
.54707 .49788 L
.5488 .55293 L
.5498 .57611 L
.55071 .59134 L
.55158 .6002 L
.55249 .60332 L
.55334 .60048 L
.55411 .59319 L
.55499 .57933 L
.55583 .56117 L
.55732 .5177 L
.55893 .4571 L
.56229 .3046 L
.56598 .14015 L
.5669 .10616 L
.56789 .07472 L
.56875 .05237 L
.56968 .03363 L
.57023 .02555 L
.57074 .02003 L
.57122 .01657 L
.57173 .01484 L
.57224 .01513 L
.57272 .01719 L
.57361 .02566 L
.57446 .03937 L
.57537 .05942 L
.57699 .10823 L
.58064 .26185 L
.58409 .42286 L
.58579 .49213 L
.58735 .54403 L
.58823 .56667 L
.58916 .58504 L
.59009 .59724 L
.59062 .60127 L
.59112 .60311 L
.59198 .6018 L
.59277 .59564 L
.59368 .58277 L
.59454 .56504 L
.5961 .52092 L
.59775 .45931 L
.60074 .32489 L
.60402 .17378 L
.60582 .1046 L
.6075 .05537 L
.60837 .03696 L
Mistroke
.6093 .02319 L
.60983 .01823 L
.61033 .01551 L
.61079 .01472 L
.61128 .01564 L
.61215 .02186 L
.61308 .03476 L
.61388 .05069 L
.61476 .07321 L
.6167 .13937 L
.61881 .22917 L
.62261 .40712 L
.62448 .48541 L
.62623 .54395 L
.62711 .56667 L
.62804 .5852 L
.62858 .59294 L
.62909 .5983 L
.62954 .60146 L
.63004 .6031 L
.63085 .60169 L
.63176 .59423 L
.63221 .58817 L
.6327 .57999 L
.63358 .56099 L
.63529 .51007 L
.63685 .45013 L
.6402 .29695 L
.64335 .15525 L
.64509 .09161 L
.64601 .06481 L
.64698 .04236 L
.6478 .02847 L
.6487 .01889 L
.64951 .01546 L
.65027 .01685 L
.65074 .01994 L
.65126 .02521 L
.65219 .03975 L
.6531 .05978 L
.65394 .08307 L
.65787 .23811 L
.66126 .39658 L
.66304 .47213 L
.66401 .50797 L
.66491 .5369 L
.6658 .56072 L
.66661 .57782 L
.66751 .59141 L
.668 .59636 L
Mistroke
.66846 .59935 L
.66928 .60063 L
.67003 .59734 L
.67085 .58888 L
.67172 .57456 L
.67248 .55778 L
.67329 .53564 L
.67476 .48611 L
.67811 .34209 L
.67998 .25486 L
.68201 .16601 L
.68381 .10037 L
.68479 .07157 L
.68572 .05001 L
.68654 .03568 L
.68743 .02568 L
.68791 .0227 L
.68842 .02144 L
.68932 .02399 L
.69015 .03162 L
.69091 .04315 L
.69176 .06048 L
.69266 .08408 L
.69988 .38271 L
.70185 .46461 L
.70294 .50303 L
.70395 .53355 L
.70488 .55629 L
.70574 .57212 L
.70622 .57889 L
.70669 .58376 L
.70717 .58723 L
.70771 .58904 L
.70817 .58892 L
.70867 .58702 L
.70958 .57896 L
.71046 .56555 L
.71128 .54863 L
.71313 .49552 L
.71508 .42201 L
.71866 .26594 L
.72193 .13668 L
.72357 .08813 L
.7245 .06757 L
.72536 .05349 L
.72612 .04528 L
.72694 .04077 L
.72781 .0412 L
.72862 .04637 L
.7295 .057 L
Mistroke
.73042 .07361 L
.73121 .09188 L
.73207 .11579 L
.7358 .25317 L
.73904 .38817 L
.74082 .45431 L
.7425 .50515 L
.74327 .52345 L
.74407 .53917 L
.74496 .5518 L
.74577 .559 L
.7465 .56172 L
.74719 .56108 L
.74794 .55684 L
.74874 .54827 L
.74923 .54114 L
.74968 .53314 L
.75054 .51504 L
.75245 .46136 L
.7559 .33509 L
.75788 .25799 L
.75996 .18384 L
.76174 .13245 L
.76275 .1099 L
.76321 .10158 L
.7637 .09383 L
.76458 .08338 L
.76542 .07782 L
.76624 .07653 L
.76699 .07893 L
.76781 .08534 L
.7687 .09682 L
.76964 .11344 L
.77052 .13294 L
.77407 .2406 L
.77789 .37474 L
.77968 .43007 L
.78066 .45596 L
.78158 .47671 L
.78245 .49252 L
.7829 .49934 L
.78338 .5054 L
.78423 .5131 L
.78501 .51672 L
.78594 .51668 L
.78646 .51462 L
.78693 .51149 L
.78785 .5021 L
.78872 .48938 L
.79067 .44905 L
Mistroke
.7928 .391 L
.79637 .27996 L
.79832 .22323 L
.80016 .17905 L
.80172 .15128 L
.80259 .14024 L
.8034 .13321 L
.80423 .12916 L
.80514 .1285 L
.8056 .12966 L
.80609 .13198 L
.80698 .13891 L
.80784 .149 L
.8088 .16355 L
.81073 .20233 L
.8142 .29099 L
.81798 .38651 L
.81906 .40894 L
.8201 .42698 L
.82102 .44008 L
.82154 .44606 L
.82203 .45075 L
.8225 .45433 L
.823 .45723 L
.82388 .45986 L
.82438 .45999 L
.8249 .45906 L
.82535 .45741 L
.82584 .45472 L
.82673 .44766 L
.82767 .43712 L
.82938 .41136 L
.83626 .26798 L
.83807 .235 L
.83906 .22006 L
.83999 .20844 L
.84079 .20056 L
.84164 .19424 L
.8421 .19178 L
.84258 .18993 L
.84345 .18851 L
.84394 .18878 L
.84439 .18967 L
.8449 .19146 L
.84539 .19388 L
.84625 .19986 L
.84719 .20857 L
.84931 .23558 L
.85127 .26666 L
.85484 .3272 L
Mistroke
.85658 .35358 L
.85817 .37347 L
.85898 .3816 L
.85985 .38882 L
.86078 .3945 L
.86165 .39797 L
.86211 .39903 L
.86261 .39961 L
.86314 .39955 L
.86364 .39889 L
.86452 .3963 L
.86502 .39409 L
.86548 .3916 L
.86722 .37843 L
.86881 .36237 L
.87238 .31894 L
.874 .29908 L
.87572 .2801 L
.87732 .26554 L
.87881 .25529 L
.87963 .2512 L
.88052 .24811 L
.88103 .24696 L
.88151 .24629 L
.88241 .24608 L
.88288 .24652 L
.88338 .24738 L
.88428 .24989 L
.88483 .25201 L
.88535 .25438 L
.88632 .2597 L
.88972 .2849 L
.89341 .31531 L
.89509 .32728 L
.89601 .33292 L
.89688 .33753 L
.89769 .34111 L
.89858 .34419 L
.89938 .34623 L
.90012 .34747 L
.901 .34814 L
.90182 .34801 L
.90272 .34707 L
.90323 .3462 L
.90369 .34519 L
.90458 .34278 L
.90554 .33948 L
.90749 .33123 L
.91121 .31297 L
.91326 .30372 L
Mistroke
.91519 .29662 L
.91607 .29408 L
.91699 .29191 L
.91748 .29099 L
.91801 .29015 L
.91849 .28955 L
.91895 .28912 L
.91981 .28865 L
.92059 .28862 L
.9215 .28901 L
.92236 .28977 L
.9291 .30363 L
.9307 .30735 L
.9324 .3108 L
.93385 .31319 L
.93468 .3143 L
.93543 .31513 L
.93631 .31588 L
.9368 .3162 L
.93725 .31644 L
.93806 .31671 L
.93895 .3168 L
.9394 .31678 L
.9399 .31669 L
.94043 .31654 L
.94092 .31635 L
.9418 .31591 L
.94274 .31531 L
.94617 .31251 L
.94936 .30998 L
.95093 .30901 L
.95174 .30861 L
.95262 .30825 L
.95312 .30808 L
.95358 .30795 L
.95449 .30775 L
.95531 .30764 L
.95618 .30758 L
.95704 .30758 L
.95795 .30763 L
.95882 .30772 L
.95961 .30782 L
.96336 .30843 L
.96489 .30865 L
.96652 .30883 L
.96736 .3089 L
.96781 .30893 L
.9683 .30895 L
.96915 .30899 L
.96995 .30901 L
Mistroke
.97071 .30902 L
.97153 .30903 L
.9724 .30903 L
.9732 .30903 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "When the frequency index is half\[Hyphen]integral, we get the \
so\[Hyphen]called Sin\[Hyphen]II or Cos\[Hyphen]II packet. Note that setting \
",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["False", "MR"],
  " gives a rectangular window."
}], "MathCaption",
  CellTags->{"S3.1.2", "2.63"}],

Cell[CellGroupData[{

Cell["\<\
Plot[Evaluate[SinPacket[t, 3, 14-1/2, Taper -> False]],
{t, -1, 4}, AxesLabel -> {\"t\",\"\"},
PlotLabel -> \"Sin-II packet\"]\
\>", "Input",
  CellLabel->"In[49]:= ",
  CellTags->"S3.1.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.214286 0.190476 0.309013 0.36045 [
[.02381 .29651 -6 -9 ]
[.02381 .29651 6 0 ]
[.40476 .29651 -3 -9 ]
[.40476 .29651 3 0 ]
[.59524 .29651 -3 -9 ]
[.59524 .29651 3 0 ]
[.78571 .29651 -3 -9 ]
[.78571 .29651 3 0 ]
[.97619 .29651 -3 -9 ]
[.97619 .29651 3 0 ]
[1.025 .30901 0 -4.5 ]
[1.025 .30901 6 4.5 ]
[.20179 .03868 -30 -4.5 ]
[.20179 .03868 0 4.5 ]
[.20179 .12879 -24 -4.5 ]
[.20179 .12879 0 4.5 ]
[.20179 .2189 -30 -4.5 ]
[.20179 .2189 0 4.5 ]
[.20179 .39913 -24 -4.5 ]
[.20179 .39913 0 4.5 ]
[.20179 .48924 -18 -4.5 ]
[.20179 .48924 0 4.5 ]
[.20179 .57935 -24 -4.5 ]
[.20179 .57935 0 4.5 ]
[.5 .63053 -39 0 ]
[.5 .63053 39 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30901 m
.02381 .31526 L
s
[(-1)] .02381 .29651 0 1 Mshowa
.40476 .30901 m
.40476 .31526 L
s
[(1)] .40476 .29651 0 1 Mshowa
.59524 .30901 m
.59524 .31526 L
s
[(2)] .59524 .29651 0 1 Mshowa
.78571 .30901 m
.78571 .31526 L
s
[(3)] .78571 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(4)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.0619 .30901 m
.0619 .31276 L
s
.1 .30901 m
.1 .31276 L
s
.1381 .30901 m
.1381 .31276 L
s
.17619 .30901 m
.17619 .31276 L
s
.25238 .30901 m
.25238 .31276 L
s
.29048 .30901 m
.29048 .31276 L
s
.32857 .30901 m
.32857 .31276 L
s
.36667 .30901 m
.36667 .31276 L
s
.44286 .30901 m
.44286 .31276 L
s
.48095 .30901 m
.48095 .31276 L
s
.51905 .30901 m
.51905 .31276 L
s
.55714 .30901 m
.55714 .31276 L
s
.63333 .30901 m
.63333 .31276 L
s
.67143 .30901 m
.67143 .31276 L
s
.70952 .30901 m
.70952 .31276 L
s
.74762 .30901 m
.74762 .31276 L
s
.82381 .30901 m
.82381 .31276 L
s
.8619 .30901 m
.8619 .31276 L
s
.9 .30901 m
.9 .31276 L
s
.9381 .30901 m
.9381 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
[(t)] 1.025 .30901 -1 0 Mshowa
.21429 .03868 m
.22054 .03868 L
s
[(-0.75)] .20179 .03868 1 0 Mshowa
.21429 .12879 m
.22054 .12879 L
s
[(-0.5)] .20179 .12879 1 0 Mshowa
.21429 .2189 m
.22054 .2189 L
s
[(-0.25)] .20179 .2189 1 0 Mshowa
.21429 .39913 m
.22054 .39913 L
s
[(0.25)] .20179 .39913 1 0 Mshowa
.21429 .48924 m
.22054 .48924 L
s
[(0.5)] .20179 .48924 1 0 Mshowa
.21429 .57935 m
.22054 .57935 L
s
[(0.75)] .20179 .57935 1 0 Mshowa
.125 Mabswid
.21429 .0567 m
.21804 .0567 L
s
.21429 .07472 m
.21804 .07472 L
s
.21429 .09274 m
.21804 .09274 L
s
.21429 .11077 m
.21804 .11077 L
s
.21429 .14681 m
.21804 .14681 L
s
.21429 .16483 m
.21804 .16483 L
s
.21429 .18286 m
.21804 .18286 L
s
.21429 .20088 m
.21804 .20088 L
s
.21429 .23692 m
.21804 .23692 L
s
.21429 .25495 m
.21804 .25495 L
s
.21429 .27297 m
.21804 .27297 L
s
.21429 .29099 m
.21804 .29099 L
s
.21429 .32704 m
.21804 .32704 L
s
.21429 .34506 m
.21804 .34506 L
s
.21429 .36308 m
.21804 .36308 L
s
.21429 .3811 m
.21804 .3811 L
s
.21429 .41715 m
.21804 .41715 L
s
.21429 .43517 m
.21804 .43517 L
s
.21429 .45319 m
.21804 .45319 L
s
.21429 .47122 m
.21804 .47122 L
s
.21429 .50726 m
.21804 .50726 L
s
.21429 .52528 m
.21804 .52528 L
s
.21429 .54331 m
.21804 .54331 L
s
.21429 .56133 m
.21804 .56133 L
s
.21429 .02065 m
.21804 .02065 L
s
.21429 .00263 m
.21804 .00263 L
s
.21429 .59737 m
.21804 .59737 L
s
.21429 .6154 m
.21804 .6154 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
[(Sin-II packet)] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30901 m
.06244 .30901 L
.10458 .30901 L
.14415 .30901 L
.18221 .30901 L
.20178 .30901 L
.20742 .30901 L
.21019 .30901 L
.2114 .30901 L
.21274 .30901 L
.21394 .30901 L
.21506 .32664 L
.21625 .35334 L
.21753 .38164 L
.22272 .48687 L
.22525 .52898 L
.22665 .54863 L
.22796 .56463 L
.22918 .57723 L
.23051 .58818 L
.23171 .59561 L
.23282 .60027 L
.23414 .60306 L
.23538 .60291 L
.23609 .60163 L
.23673 .5997 L
.23748 .59659 L
.23818 .59276 L
.23959 .58263 L
.2409 .57039 L
.24385 .53319 L
.24848 .45258 L
.25359 .34314 L
.25863 .23 L
.26394 .12388 L
.26627 .08603 L
.26876 .05353 L
.27019 .03902 L
.27149 .02866 L
.2728 .02109 L
.27403 .0166 L
.27516 .01482 L
.27634 .01531 L
.27736 .01768 L
.27847 .02233 L
.27967 .02969 L
.28096 .04023 L
.28329 .06589 L
.28596 .10493 L
.28888 .15724 L
Mistroke
.29419 .26989 L
.29897 .37757 L
.30414 .48315 L
.30692 .52952 L
.30947 .56333 L
.31074 .5765 L
.31191 .58651 L
.31314 .59453 L
.31379 .59774 L
.31449 .60038 L
.3157 .60297 L
.31701 .60291 L
.31825 .60011 L
.31939 .59517 L
.32042 .58882 L
.32156 .57978 L
.32386 .55526 L
.32658 .51635 L
.32907 .47271 L
.33469 .35521 L
.3396 .24463 L
.34484 .13705 L
.34749 .0922 L
.34999 .05814 L
.35224 .03541 L
.35351 .02616 L
.35467 .02002 L
.35576 .01636 L
.35679 .01482 L
.35791 .01522 L
.35911 .01807 L
.36037 .02374 L
.36156 .03158 L
.36264 .04063 L
.3638 .05254 L
.36628 .08454 L
.36902 .12929 L
.37456 .24184 L
.38452 .45938 L
.38942 .54207 L
.39189 .57182 L
.39329 .58453 L
.39459 .59351 L
.3958 .59926 L
.39694 .60241 L
.39796 .60332 L
.39906 .60226 L
.40027 .59868 L
.40155 .59216 L
.40264 .58442 L
Mistroke
.40384 .57367 L
.40655 .54127 L
.40903 .50279 L
.41461 .39299 L
.41949 .28364 L
.42469 .17139 L
.42735 .12133 L
.42986 .08134 L
.43211 .05259 L
.43327 .04073 L
.43454 .03018 L
.43574 .02269 L
.43686 .0179 L
.43804 .01518 L
.43931 .01495 L
.44049 .01725 L
.4416 .02164 L
.4426 .02737 L
.44369 .0355 L
.44617 .06113 L
.44891 .09983 L
.45446 .20432 L
.46442 .4244 L
.46934 .51636 L
.47182 .55215 L
.47323 .56877 L
.47452 .58118 L
.47571 .59031 L
.47684 .59675 L
.47803 .60119 L
.47932 .60325 L
.48045 .60268 L
.48164 .59967 L
.48266 .59516 L
.48378 .58816 L
.48517 .57657 L
.4865 .56273 L
.48898 .5298 L
.49456 .42868 L
.50464 .20611 L
.5096 .11081 L
.51203 .0738 L
.51426 .04702 L
.51552 .03529 L
.51685 .0257 L
.51754 .02187 L
.51818 .01903 L
.51888 .01673 L
.51964 .01523 L
.52095 .01496 L
Mistroke
.52218 .01745 L
.52329 .02194 L
.5245 .02919 L
.52564 .03826 L
.52671 .04866 L
.52914 .07878 L
.53407 .16296 L
.54291 .35614 L
.54786 .46096 L
.55049 .50837 L
.55328 .54998 L
.55466 .56655 L
.55596 .5795 L
.55713 .58882 L
.55839 .59636 L
.5596 .60101 L
.56087 .60321 L
.56195 .60286 L
.56314 .60011 L
.56438 .59466 L
.56556 .58708 L
.56662 .57834 L
.56777 .5668 L
.57034 .53382 L
.57272 .49542 L
.58167 .30827 L
.58604 .21114 L
.59064 .1209 L
.59305 .08237 L
.59433 .06507 L
.59569 .04917 L
.59695 .03704 L
.59809 .02822 L
.59924 .02153 L
.60032 .01728 L
.60161 .01487 L
.60226 .01475 L
.60297 .01546 L
.60424 .01889 L
.60542 .02459 L
.60613 .02917 L
.60681 .03431 L
.60808 .04594 L
.61094 .08114 L
.61572 .16322 L
.62092 .27444 L
.6258 .38403 L
.63107 .49027 L
.63349 .5301 L
.63605 .56381 L
Mistroke
.63823 .58484 L
.63947 .59336 L
.64062 .59897 L
.64131 .60123 L
.64205 .60275 L
.64275 .60331 L
.6434 .60306 L
.64463 .60057 L
.64594 .59508 L
.64661 .59112 L
.64734 .58601 L
.64865 .57458 L
.65163 .53871 L
.65417 .49864 L
.65684 .44876 L
.6616 .34653 L
.67117 .14082 L
.67392 .09378 L
.67652 .05821 L
.67885 .03475 L
.68017 .02537 L
.68138 .01929 L
.68244 .01604 L
.68358 .01472 L
.68465 .01554 L
.68563 .01804 L
.68678 .02308 L
.68803 .03111 L
.68921 .04105 L
.69031 .05224 L
.69488 .11765 L
.69975 .21276 L
.7091 .41992 L
.71401 .51271 L
.71648 .5492 L
.7179 .56628 L
.71919 .57917 L
.72042 .58897 L
.72157 .59594 L
.7228 .60082 L
.72349 .60244 L
.72412 .6032 L
.72518 .6029 L
.72635 .6003 L
.72757 .59507 L
.72872 .58789 L
.72984 .57868 L
.73092 .56805 L
.73293 .54339 L
.73746 .46846 L
Mistroke
.74705 .26051 L
.75231 .15002 L
.7549 .10425 L
.75727 .06923 L
.75952 .04338 L
.76066 .03334 L
.7619 .02474 L
.76316 .01873 L
.76386 .01654 L
.7645 .01528 L
.76574 .01487 L
.76692 .01696 L
.76797 .02088 L
.76909 .02711 L
.77005 .0341 L
.7711 .04353 L
.77345 .07071 L
.77566 .10331 L
.78076 .19938 L
.78324 .25327 L
.78432 .27752 L
.78549 .30404 L
.78672 .30901 L
.78789 .30901 L
.79044 .30901 L
.79585 .30901 L
.81435 .30901 L
.85528 .30901 L
.89469 .30901 L
.93259 .30901 L
.97293 .30901 L
.97619 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],

Cell[TextData[{
  "3.1.3 Viewing Details of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`w\)], "InlineFormula",
    CellTags->"S3.1.3"]
}], "Subsection",
  CellTags->{"S3.1.3", "3.1"}],

Cell[TextData[{
  "Suppose we would like to see more details of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " in a particular small interval of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", 
            RowBox[{
              StyleBox[\("tmin"\),
                "TI"], ",", 
              StyleBox[\("tmax"\),
                "TI"]}], "]"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.3"],
  ", the function ",
  StyleBox["Zoom", "MR"],
  " allows us to enlarge the function in the specified region to a given \
resolution. "
}], "Text",
  CellTags->{"S3.1.3", "3.2"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Zoom[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"flist\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"j\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"tmin\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"tmax\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  RowBox[{
                  "\<\"blow up the function \
\\!\\(\\*StyleBox[\\\"\\\\\\\"flist\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", 
                    StyleBox["j",
                      "InlineFormula"], \(" times in interval "\), 
                    StyleBox[
                      RowBox[{"{", 
                        RowBox[{
                          StyleBox[\("tmin"\),
                            "TI"], ",", 
                          StyleBox[\("tmax"\),
                            "TI"]}], "}"}],
                      "InlineFormula"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.3", "3.3"}],

Cell["Zoom\[Hyphen]in function.", "Caption",
  CellTags->"S3.1.3"],

Cell[TextData[{
  "The first argument ",
  StyleBox["flist", "TI"],
  " is a list of arguments and function values ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"k", "/", 
            SuperscriptBox["2", 
              StyleBox[\("jmax"\),
                "TI"]], ",", "f", 
            RowBox[{"(", 
              RowBox[{"k", "/", 
                SuperscriptBox["2", 
                  StyleBox[\("jmax"\),
                    "TI"]]}], ")"}]}], "}"}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S3.1.3"],
  ", that is, ",
  StyleBox["flist", "TI"],
  " can be the output of ",
  StyleBox["ScalingFunction", "MR"],
  ", ",
  StyleBox["Wavelet", "MR"],
  ", or ",
  StyleBox["WaveletPacket", "MR"],
  " using the filter ",
  StyleBox["filter", "TI"],
  ". The output of ",
  StyleBox["Zoom", "MR"],
  " is a list of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{"k", "/", 
            SuperscriptBox["2", 
              RowBox[{
                StyleBox[\("jmax"\),
                  "TI"], "+", "j"}]], ",", "f", 
            RowBox[{"(", 
              RowBox[{"k", "/", 
                SuperscriptBox["2", 
                  RowBox[{
                    StyleBox[\("jmax"\),
                      "TI"], "+", "j"}]]}], ")"}]}], "}"}], TraditionalForm]],
     "InlineFormula",
    CellTags->"S3.1.3"],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", "/", 
          SuperscriptBox["2", 
            RowBox[{
              StyleBox[\("jmax"\),
                "TI"], "+", "j"}]]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.3"],
  " inside the region ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{"[", 
            RowBox[{
              StyleBox[\("tmin"\),
                "TI"], "-", \(\[Delta]\_1\), ",", 
              StyleBox[\("tmax"\),
                "TI"], "+", \(\[Delta]\_2\)}], "]"}]}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S3.1.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_i \[GreaterEqual] 0\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ") are determined by the filter and they ensure that the boundary points \
are calculated correctly. The method employed is the inverse transform method \
or the cascade algorithm. \nFor example, we can see that the derivative of \
the second\[Hyphen]order Daubechies wavelet indeed does not exist by looking \
at its graph in detail. "
}], "Text",
  CellTags->{"S3.1.3", "3.4"}],

Cell[TextData[{
  "The Daubechies wavelet of order 2 is calculated down to scale ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^4\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ". To get consistent results, the inverse transform method is used here."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.5"}],

Cell["\<\
(d2 = DaubechiesFilter[2];
psilist = Wavelet[d2, 4, InverseTransform -> True];)\
\>", "Input",
  CellLabel->"In[50]:= ",
  CellTags->"S3.1.3"],

Cell["This is the plot of the approximate wavelet.", "MathCaption",
  CellTags->{"S3.1.3", "3.6"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[psilist, PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"psi_2(t)\"}]\
\>", "Input",
  CellLabel->"In[51]:= ",
  CellTags->"S3.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.270753 0.199929 [
[.02381 .25825 -6 -9 ]
[.02381 .25825 6 0 ]
[.18254 .25825 -12 -9 ]
[.18254 .25825 12 0 ]
[.5 .25825 -9 -9 ]
[.5 .25825 9 0 ]
[.65873 .25825 -3 -9 ]
[.65873 .25825 3 0 ]
[.81746 .25825 -9 -9 ]
[.81746 .25825 9 0 ]
[.97619 .25825 -3 -9 ]
[.97619 .25825 3 0 ]
[1.025 .27075 0 -4.5 ]
[1.025 .27075 6 4.5 ]
[.32877 .07082 -12 -4.5 ]
[.32877 .07082 0 4.5 ]
[.32877 .17079 -24 -4.5 ]
[.32877 .17079 0 4.5 ]
[.32877 .37072 -18 -4.5 ]
[.32877 .37072 0 4.5 ]
[.32877 .47068 -6 -4.5 ]
[.32877 .47068 0 4.5 ]
[.32877 .57065 -18 -4.5 ]
[.32877 .57065 0 4.5 ]
[.34127 .64303 -24 0 ]
[.34127 .64303 24 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27075 m
.02381 .277 L
s
[(-1)] .02381 .25825 0 1 Mshowa
.18254 .27075 m
.18254 .277 L
s
[(-0.5)] .18254 .25825 0 1 Mshowa
.5 .27075 m
.5 .277 L
s
[(0.5)] .5 .25825 0 1 Mshowa
.65873 .27075 m
.65873 .277 L
s
[(1)] .65873 .25825 0 1 Mshowa
.81746 .27075 m
.81746 .277 L
s
[(1.5)] .81746 .25825 0 1 Mshowa
.97619 .27075 m
.97619 .277 L
s
[(2)] .97619 .25825 0 1 Mshowa
.125 Mabswid
.05556 .27075 m
.05556 .2745 L
s
.0873 .27075 m
.0873 .2745 L
s
.11905 .27075 m
.11905 .2745 L
s
.15079 .27075 m
.15079 .2745 L
s
.21429 .27075 m
.21429 .2745 L
s
.24603 .27075 m
.24603 .2745 L
s
.27778 .27075 m
.27778 .2745 L
s
.30952 .27075 m
.30952 .2745 L
s
.37302 .27075 m
.37302 .2745 L
s
.40476 .27075 m
.40476 .2745 L
s
.43651 .27075 m
.43651 .2745 L
s
.46825 .27075 m
.46825 .2745 L
s
.53175 .27075 m
.53175 .2745 L
s
.56349 .27075 m
.56349 .2745 L
s
.59524 .27075 m
.59524 .2745 L
s
.62698 .27075 m
.62698 .2745 L
s
.69048 .27075 m
.69048 .2745 L
s
.72222 .27075 m
.72222 .2745 L
s
.75397 .27075 m
.75397 .2745 L
s
.78571 .27075 m
.78571 .2745 L
s
.84921 .27075 m
.84921 .2745 L
s
.88095 .27075 m
.88095 .2745 L
s
.9127 .27075 m
.9127 .2745 L
s
.94444 .27075 m
.94444 .2745 L
s
.25 Mabswid
0 .27075 m
1 .27075 L
s
[(t)] 1.025 .27075 -1 0 Mshowa
.34127 .07082 m
.34752 .07082 L
s
[(-1)] .32877 .07082 1 0 Mshowa
.34127 .17079 m
.34752 .17079 L
s
[(-0.5)] .32877 .17079 1 0 Mshowa
.34127 .37072 m
.34752 .37072 L
s
[(0.5)] .32877 .37072 1 0 Mshowa
.34127 .47068 m
.34752 .47068 L
s
[(1)] .32877 .47068 1 0 Mshowa
.34127 .57065 m
.34752 .57065 L
s
[(1.5)] .32877 .57065 1 0 Mshowa
.125 Mabswid
.34127 .09082 m
.34502 .09082 L
s
.34127 .11081 m
.34502 .11081 L
s
.34127 .1308 m
.34502 .1308 L
s
.34127 .1508 m
.34502 .1508 L
s
.34127 .19078 m
.34502 .19078 L
s
.34127 .21077 m
.34502 .21077 L
s
.34127 .23077 m
.34502 .23077 L
s
.34127 .25076 m
.34502 .25076 L
s
.34127 .29075 m
.34502 .29075 L
s
.34127 .31074 m
.34502 .31074 L
s
.34127 .33073 m
.34502 .33073 L
s
.34127 .35072 m
.34502 .35072 L
s
.34127 .39071 m
.34502 .39071 L
s
.34127 .4107 m
.34502 .4107 L
s
.34127 .4307 m
.34502 .4307 L
s
.34127 .45069 m
.34502 .45069 L
s
.34127 .49067 m
.34502 .49067 L
s
.34127 .51067 m
.34502 .51067 L
s
.34127 .53066 m
.34502 .53066 L
s
.34127 .55065 m
.34502 .55065 L
s
.34127 .05083 m
.34502 .05083 L
s
.34127 .03084 m
.34502 .03084 L
s
.34127 .01085 m
.34502 .01085 L
s
.34127 .59064 m
.34502 .59064 L
s
.34127 .61063 m
.34502 .61063 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
[(psi_2\\(t\\))] .34127 .64303 0 -1 Mshowa
.5 Mabswid
.02381 .25909 m
.04365 .25056 L
.06349 .24515 L
.08333 .2389 L
.10317 .23578 L
.12302 .23182 L
.14286 .22702 L
.1627 .22245 L
.18254 .221 L
.20238 .21871 L
.22222 .21558 L
.24206 .21269 L
.2619 .20895 L
.28175 .20544 L
.30159 .20215 L
.32143 .1988 L
.34127 .29954 L
.36111 .37239 L
.38095 .41735 L
.40079 .46978 L
.42063 .49433 L
.44048 .52634 L
.46032 .56583 L
.48016 .60332 L
.5 .42638 L
.51984 .30689 L
.53968 .24487 L
.55952 .16744 L
.57937 .14747 L
.59921 .11211 L
.61905 .06135 L
.63889 .01472 L
.65873 .13046 L
.67857 .2027 L
.69841 .23143 L
.71825 .27181 L
.7381 .26869 L
.75794 .27723 L
.77778 .29742 L
.79762 .31449 L
.81746 .28805 L
.8373 .27326 L
.85714 .27014 L
.87698 .26389 L
.89683 .2693 L
.91667 .27159 L
.93651 .27075 L
.95635 .27075 L
.97619 .27075 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "We want to look at the region around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " in greater detail by enlarging it 5 times."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.7"}],

Cell["psilist1 = Zoom[psilist, d2, 5, {1/2-1/16, 1/2+1/16}];", "Input",
  CellLabel->"In[52]:= ",
  CellTags->"S3.1.3"],

Cell[TextData[{
  "We see that now the interval between two adjacent points is ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^\((4 + 5)\) = 1/512\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ". Two left boundary points are included to ensure correct results for \
further iterations using ",
  StyleBox["Zoom", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.8"}],

Cell[CellGroupData[{

Cell["Short[psilist1, 2]", "Input",
  CellLabel->"In[53]:= ",
  CellTags->"S3.1.3"],

Cell[BoxData[
    TagBox[
      \({{111\/256, 1.53978525730913933`}, 
        \[LeftSkeleton]65\[RightSkeleton], {9\/16, 0.479650133646902077`}}\),
      (Short[ #, 2]&)]], "Output",
  CellLabel->"Out[53]//Short= ",
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "This is the \"zoom\[Hyphen]in\" plot of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.9"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[psilist1, Frame -> True, Axes -> False,
FrameLabel -> {\"t\", \"psi(t)\"}]\
\>", "Input",
  CellLabel->"In[54]:= ",
  CellTags->"S3.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3.17965 7.38817 -0.201404 0.465183 [
[.07114 -0.0125 -12 -9 ]
[.07114 -0.0125 12 0 ]
[.2189 -0.0125 -12 -9 ]
[.2189 -0.0125 12 0 ]
[.36667 -0.0125 -12 -9 ]
[.36667 -0.0125 12 0 ]
[.51443 -0.0125 -9 -9 ]
[.51443 -0.0125 9 0 ]
[.66219 -0.0125 -12 -9 ]
[.66219 -0.0125 12 0 ]
[.80996 -0.0125 -12 -9 ]
[.80996 -0.0125 12 0 ]
[.95772 -0.0125 -12 -9 ]
[.95772 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3 -18 ]
[.5 -0.0125 3 -9 ]
[-0.0125 .07771 -18 -4.5 ]
[-0.0125 .07771 0 4.5 ]
[-0.0125 .17074 -18 -4.5 ]
[-0.0125 .17074 0 4.5 ]
[-0.0125 .26378 -6 -4.5 ]
[-0.0125 .26378 0 4.5 ]
[-0.0125 .35682 -18 -4.5 ]
[-0.0125 .35682 0 4.5 ]
[-0.0125 .44985 -18 -4.5 ]
[-0.0125 .44985 0 4.5 ]
[-0.0125 .54289 -18 -4.5 ]
[-0.0125 .54289 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -27 -18 ]
[-0.01875 .30902 -18 18 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07114 0 m
.07114 .00625 L
s
[(0.44)] .07114 -0.0125 0 1 Mshowa
.2189 0 m
.2189 .00625 L
s
[(0.46)] .2189 -0.0125 0 1 Mshowa
.36667 0 m
.36667 .00625 L
s
[(0.48)] .36667 -0.0125 0 1 Mshowa
.51443 0 m
.51443 .00625 L
s
[(0.5)] .51443 -0.0125 0 1 Mshowa
.66219 0 m
.66219 .00625 L
s
[(0.52)] .66219 -0.0125 0 1 Mshowa
.80996 0 m
.80996 .00625 L
s
[(0.54)] .80996 -0.0125 0 1 Mshowa
.95772 0 m
.95772 .00625 L
s
[(0.56)] .95772 -0.0125 0 1 Mshowa
.125 Mabswid
.10808 0 m
.10808 .00375 L
s
.14502 0 m
.14502 .00375 L
s
.18196 0 m
.18196 .00375 L
s
.25584 0 m
.25584 .00375 L
s
.29278 0 m
.29278 .00375 L
s
.32973 0 m
.32973 .00375 L
s
.40361 0 m
.40361 .00375 L
s
.44055 0 m
.44055 .00375 L
s
.47749 0 m
.47749 .00375 L
s
.55137 0 m
.55137 .00375 L
s
.58831 0 m
.58831 .00375 L
s
.62525 0 m
.62525 .00375 L
s
.69913 0 m
.69913 .00375 L
s
.73608 0 m
.73608 .00375 L
s
.77302 0 m
.77302 .00375 L
s
.8469 0 m
.8469 .00375 L
s
.88384 0 m
.88384 .00375 L
s
.92078 0 m
.92078 .00375 L
s
.0342 0 m
.0342 .00375 L
s
.99466 0 m
.99466 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 .07771 m
.00625 .07771 L
s
[(0.6)] -0.0125 .07771 1 0 Mshowa
0 .17074 m
.00625 .17074 L
s
[(0.8)] -0.0125 .17074 1 0 Mshowa
0 .26378 m
.00625 .26378 L
s
[(1)] -0.0125 .26378 1 0 Mshowa
0 .35682 m
.00625 .35682 L
s
[(1.2)] -0.0125 .35682 1 0 Mshowa
0 .44985 m
.00625 .44985 L
s
[(1.4)] -0.0125 .44985 1 0 Mshowa
0 .54289 m
.00625 .54289 L
s
[(1.6)] -0.0125 .54289 1 0 Mshowa
.125 Mabswid
0 .10096 m
.00375 .10096 L
s
0 .12422 m
.00375 .12422 L
s
0 .14748 m
.00375 .14748 L
s
0 .194 m
.00375 .194 L
s
0 .21726 m
.00375 .21726 L
s
0 .24052 m
.00375 .24052 L
s
0 .28704 m
.00375 .28704 L
s
0 .3103 m
.00375 .3103 L
s
0 .33356 m
.00375 .33356 L
s
0 .38007 m
.00375 .38007 L
s
0 .40333 m
.00375 .40333 L
s
0 .42659 m
.00375 .42659 L
s
0 .47311 m
.00375 .47311 L
s
0 .49637 m
.00375 .49637 L
s
0 .51963 m
.00375 .51963 L
s
0 .05445 m
.00375 .05445 L
s
0 .03119 m
.00375 .03119 L
s
0 .00793 m
.00375 .00793 L
s
0 .56615 m
.00375 .56615 L
s
0 .58941 m
.00375 .58941 L
s
0 .61267 m
.00375 .61267 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(psi\\(t\\))] -0.01875 .30902 -18 0 Mabsadd 1 0 90 Mrotshowa
.07114 .61178 m
.07114 .61803 L
s
.2189 .61178 m
.2189 .61803 L
s
.36667 .61178 m
.36667 .61803 L
s
.51443 .61178 m
.51443 .61803 L
s
.66219 .61178 m
.66219 .61803 L
s
.80996 .61178 m
.80996 .61803 L
s
.95772 .61178 m
.95772 .61803 L
s
.125 Mabswid
.10808 .61428 m
.10808 .61803 L
s
.14502 .61428 m
.14502 .61803 L
s
.18196 .61428 m
.18196 .61803 L
s
.25584 .61428 m
.25584 .61803 L
s
.29278 .61428 m
.29278 .61803 L
s
.32973 .61428 m
.32973 .61803 L
s
.40361 .61428 m
.40361 .61803 L
s
.44055 .61428 m
.44055 .61803 L
s
.47749 .61428 m
.47749 .61803 L
s
.55137 .61428 m
.55137 .61803 L
s
.58831 .61428 m
.58831 .61803 L
s
.62525 .61428 m
.62525 .61803 L
s
.69913 .61428 m
.69913 .61803 L
s
.73608 .61428 m
.73608 .61803 L
s
.77302 .61428 m
.77302 .61803 L
s
.8469 .61428 m
.8469 .61803 L
s
.88384 .61428 m
.88384 .61803 L
s
.92078 .61428 m
.92078 .61803 L
s
.0342 .61428 m
.0342 .61803 L
s
.99466 .61428 m
.99466 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07771 m
1 .07771 L
s
.99375 .17074 m
1 .17074 L
s
.99375 .26378 m
1 .26378 L
s
.99375 .35682 m
1 .35682 L
s
.99375 .44985 m
1 .44985 L
s
.99375 .54289 m
1 .54289 L
s
.125 Mabswid
.99625 .10096 m
1 .10096 L
s
.99625 .12422 m
1 .12422 L
s
.99625 .14748 m
1 .14748 L
s
.99625 .194 m
1 .194 L
s
.99625 .21726 m
1 .21726 L
s
.99625 .24052 m
1 .24052 L
s
.99625 .28704 m
1 .28704 L
s
.99625 .3103 m
1 .3103 L
s
.99625 .33356 m
1 .33356 L
s
.99625 .38007 m
1 .38007 L
s
.99625 .40333 m
1 .40333 L
s
.99625 .42659 m
1 .42659 L
s
.99625 .47311 m
1 .47311 L
s
.99625 .49637 m
1 .49637 L
s
.99625 .51963 m
1 .51963 L
s
.99625 .05445 m
1 .05445 L
s
.99625 .03119 m
1 .03119 L
s
.99625 .00793 m
1 .00793 L
s
.99625 .56615 m
1 .56615 L
s
.99625 .58941 m
1 .58941 L
s
.99625 .61267 m
1 .61267 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .51488 Mdot
.03824 .51775 Mdot
.05267 .51993 Mdot
.0671 .52229 Mdot
.08153 .52484 Mdot
.09596 .52734 Mdot
.11039 .53003 Mdot
.12482 .53266 Mdot
.13925 .53525 Mdot
.15368 .53785 Mdot
.16811 .54063 Mdot
.18254 .54337 Mdot
.19697 .54606 Mdot
.2114 .54876 Mdot
.22583 .5514 Mdot
.24026 .55407 Mdot
.25469 .55674 Mdot
.26912 .55942 Mdot
.28355 .56227 Mdot
.29798 .56508 Mdot
.31241 .56784 Mdot
.32684 .57061 Mdot
.34127 .57333 Mdot
.3557 .57607 Mdot
.37013 .57882 Mdot
.38456 .58156 Mdot
.39899 .58426 Mdot
.41342 .58697 Mdot
.42785 .58969 Mdot
.44228 .59241 Mdot
.45671 .59514 Mdot
.47114 .59787 Mdot
.48557 .60059 Mdot
.5 .60332 Mdot
.51443 .53188 Mdot
.52886 .48032 Mdot
.54329 .44863 Mdot
.55772 .41161 Mdot
.57215 .39447 Mdot
.58658 .372 Mdot
.60101 .3442 Mdot
.61544 .31783 Mdot
.62987 .31134 Mdot
.6443 .29952 Mdot
.65873 .28237 Mdot
.67316 .26665 Mdot
.68759 .24561 Mdot
.70202 .22599 Mdot
.71645 .2078 Mdot
.73088 .18923 Mdot
.74531 .19053 Mdot
.75974 .1865 Mdot
.77417 .17715 Mdot
.7886 .16923 Mdot
.80303 .15598 Mdot
.81746 .14416 Mdot
.83189 .13377 Mdot
.84632 .12299 Mdot
.86075 .10689 Mdot
.87518 .09222 Mdot
.88961 .07897 Mdot
.90404 .06534 Mdot
.91847 .05313 Mdot
.9329 .04055 Mdot
.94733 .02758 Mdot
.96176 .01472 Mdot
.97619 .02172 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "We get identical results by calculating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " on the whole support using the inverse transform method with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\("jmax"\),
            "TI"], "=", "9"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.10"}],

Cell[CellGroupData[{

Cell["\<\
Select[Wavelet[d2, 9, InverseTransform -> True],
111/256 <= #[[1]] <= 9/16&] == psilist1\
\>", "Input",
  CellLabel->"In[55]:= ",
  CellTags->"S3.1.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[55]= ",
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "The output of ",
  StyleBox["Zoom", "MR"],
  " can be further iterated."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.11"}],

Cell["Nest[Zoom[#, d2, 6, {0.4999,0.5001}]&, psilist1, 2];", "Input",
  CellLabel->"In[56]:= ",
  CellTags->"S3.1.3"],

Cell[TextData[{
  "Now ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " is calculated down to the scale ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^21\)], "InlineFormula",
    CellTags->"S3.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.12"}],

Cell[CellGroupData[{

Cell["%[[2, 1]]-%[[1, 1]]", "Input",
  CellLabel->"In[57]:= ",
  CellTags->"S3.1.3"],

Cell[BoxData[
    \(1\/2097152\)], "Output",
  CellLabel->"Out[57]= ",
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "We see clearly that the slope at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1/2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " is not continuous."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.13"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%%, PlotJoined -> True, Frame -> True,
Axes -> False, FrameLabel -> {\"t\", \"psi(t)\"}]\
\>", "Input",
  CellLabel->"In[58]:= ",
  CellTags->"S3.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1942.38 3885.77 -21.0982 12.5294 [
[.11328 -0.0125 -18 -9 ]
[.11328 -0.0125 18 0 ]
[.30756 -0.0125 -21 -9 ]
[.30756 -0.0125 21 0 ]
[.50185 -0.0125 -9 -9 ]
[.50185 -0.0125 9 0 ]
[.69614 -0.0125 -21 -9 ]
[.69614 -0.0125 21 0 ]
[.89043 -0.0125 -18 -9 ]
[.89043 -0.0125 18 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3 -18 ]
[.5 -0.0125 3 -9 ]
[-0.0125 .07646 -24 -4.5 ]
[-0.0125 .07646 0 4.5 ]
[-0.0125 .20175 -18 -4.5 ]
[-0.0125 .20175 0 4.5 ]
[-0.0125 .32704 -24 -4.5 ]
[-0.0125 .32704 0 4.5 ]
[-0.0125 .45234 -24 -4.5 ]
[-0.0125 .45234 0 4.5 ]
[-0.0125 .57763 -24 -4.5 ]
[-0.0125 .57763 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -33 -18 ]
[-0.01875 .30902 -24 18 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11328 0 m
.11328 .00625 L
s
[(0.4999)] .11328 -0.0125 0 1 Mshowa
.30756 0 m
.30756 .00625 L
s
[(0.49995)] .30756 -0.0125 0 1 Mshowa
.50185 0 m
.50185 .00625 L
s
[(0.5)] .50185 -0.0125 0 1 Mshowa
.69614 0 m
.69614 .00625 L
s
[(0.50005)] .69614 -0.0125 0 1 Mshowa
.89043 0 m
.89043 .00625 L
s
[(0.5001)] .89043 -0.0125 0 1 Mshowa
.125 Mabswid
.15213 0 m
.15213 .00375 L
s
.19099 0 m
.19099 .00375 L
s
.22985 0 m
.22985 .00375 L
s
.26871 0 m
.26871 .00375 L
s
.34642 0 m
.34642 .00375 L
s
.38528 0 m
.38528 .00375 L
s
.42414 0 m
.42414 .00375 L
s
.463 0 m
.463 .00375 L
s
.54071 0 m
.54071 .00375 L
s
.57957 0 m
.57957 .00375 L
s
.61843 0 m
.61843 .00375 L
s
.65728 0 m
.65728 .00375 L
s
.735 0 m
.735 .00375 L
s
.77386 0 m
.77386 .00375 L
s
.81271 0 m
.81271 .00375 L
s
.85157 0 m
.85157 .00375 L
s
.07442 0 m
.07442 .00375 L
s
.03556 0 m
.03556 .00375 L
s
.92929 0 m
.92929 .00375 L
s
.96815 0 m
.96815 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 .07646 m
.00625 .07646 L
s
[(1.69)] -0.0125 .07646 1 0 Mshowa
0 .20175 m
.00625 .20175 L
s
[(1.7)] -0.0125 .20175 1 0 Mshowa
0 .32704 m
.00625 .32704 L
s
[(1.71)] -0.0125 .32704 1 0 Mshowa
0 .45234 m
.00625 .45234 L
s
[(1.72)] -0.0125 .45234 1 0 Mshowa
0 .57763 m
.00625 .57763 L
s
[(1.73)] -0.0125 .57763 1 0 Mshowa
.125 Mabswid
0 .10151 m
.00375 .10151 L
s
0 .12657 m
.00375 .12657 L
s
0 .15163 m
.00375 .15163 L
s
0 .17669 m
.00375 .17669 L
s
0 .22681 m
.00375 .22681 L
s
0 .25187 m
.00375 .25187 L
s
0 .27693 m
.00375 .27693 L
s
0 .30198 m
.00375 .30198 L
s
0 .3521 m
.00375 .3521 L
s
0 .37716 m
.00375 .37716 L
s
0 .40222 m
.00375 .40222 L
s
0 .42728 m
.00375 .42728 L
s
0 .4774 m
.00375 .4774 L
s
0 .50245 m
.00375 .50245 L
s
0 .52751 m
.00375 .52751 L
s
0 .55257 m
.00375 .55257 L
s
0 .0514 m
.00375 .0514 L
s
0 .02634 m
.00375 .02634 L
s
0 .00128 m
.00375 .00128 L
s
0 .60269 m
.00375 .60269 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(psi\\(t\\))] -0.01875 .30902 -24 0 Mabsadd 1 0 90 Mrotshowa
.11328 .61178 m
.11328 .61803 L
s
.30756 .61178 m
.30756 .61803 L
s
.50185 .61178 m
.50185 .61803 L
s
.69614 .61178 m
.69614 .61803 L
s
.89043 .61178 m
.89043 .61803 L
s
.125 Mabswid
.15213 .61428 m
.15213 .61803 L
s
.19099 .61428 m
.19099 .61803 L
s
.22985 .61428 m
.22985 .61803 L
s
.26871 .61428 m
.26871 .61803 L
s
.34642 .61428 m
.34642 .61803 L
s
.38528 .61428 m
.38528 .61803 L
s
.42414 .61428 m
.42414 .61803 L
s
.463 .61428 m
.463 .61803 L
s
.54071 .61428 m
.54071 .61803 L
s
.57957 .61428 m
.57957 .61803 L
s
.61843 .61428 m
.61843 .61803 L
s
.65728 .61428 m
.65728 .61803 L
s
.735 .61428 m
.735 .61803 L
s
.77386 .61428 m
.77386 .61803 L
s
.81271 .61428 m
.81271 .61803 L
s
.85157 .61428 m
.85157 .61803 L
s
.07442 .61428 m
.07442 .61803 L
s
.03556 .61428 m
.03556 .61803 L
s
.92929 .61428 m
.92929 .61803 L
s
.96815 .61428 m
.96815 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .07646 m
1 .07646 L
s
.99375 .20175 m
1 .20175 L
s
.99375 .32704 m
1 .32704 L
s
.99375 .45234 m
1 .45234 L
s
.99375 .57763 m
1 .57763 L
s
.125 Mabswid
.99625 .10151 m
1 .10151 L
s
.99625 .12657 m
1 .12657 L
s
.99625 .15163 m
1 .15163 L
s
.99625 .17669 m
1 .17669 L
s
.99625 .22681 m
1 .22681 L
s
.99625 .25187 m
1 .25187 L
s
.99625 .27693 m
1 .27693 L
s
.99625 .30198 m
1 .30198 L
s
.99625 .3521 m
1 .3521 L
s
.99625 .37716 m
1 .37716 L
s
.99625 .40222 m
1 .40222 L
s
.99625 .42728 m
1 .42728 L
s
.99625 .4774 m
1 .4774 L
s
.99625 .50245 m
1 .50245 L
s
.99625 .52751 m
1 .52751 L
s
.99625 .55257 m
1 .55257 L
s
.99625 .0514 m
1 .0514 L
s
.99625 .02634 m
1 .02634 L
s
.99625 .00128 m
1 .00128 L
s
.99625 .60269 m
1 .60269 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .59871 m
.02566 .59873 L
.02752 .59875 L
.02937 .59877 L
.03122 .59878 L
.03307 .5988 L
.03493 .59882 L
.03678 .59884 L
.03863 .59886 L
.04049 .59887 L
.04234 .59889 L
.04419 .59891 L
.04604 .59893 L
.0479 .59895 L
.04975 .59896 L
.0516 .59898 L
.05346 .599 L
.05531 .59902 L
.05716 .59904 L
.05901 .59905 L
.06087 .59907 L
.06272 .59909 L
.06457 .59911 L
.06643 .59912 L
.06828 .59914 L
.07013 .59916 L
.07198 .59918 L
.07384 .5992 L
.07569 .59921 L
.07754 .59923 L
.0794 .59925 L
.08125 .59927 L
.0831 .59929 L
.08495 .5993 L
.08681 .59932 L
.08866 .59934 L
.09051 .59936 L
.09237 .59938 L
.09422 .59939 L
.09607 .59941 L
.09792 .59943 L
.09978 .59945 L
.10163 .59947 L
.10348 .59948 L
.10534 .5995 L
.10719 .59952 L
.10904 .59954 L
.11089 .59955 L
.11275 .59957 L
.1146 .59959 L
Mistroke
.11645 .59961 L
.11831 .59963 L
.12016 .59964 L
.12201 .59966 L
.12387 .59968 L
.12572 .5997 L
.12757 .59972 L
.12942 .59973 L
.13128 .59975 L
.13313 .59977 L
.13498 .59979 L
.13684 .59981 L
.13869 .59982 L
.14054 .59984 L
.14239 .59986 L
.14425 .59988 L
.1461 .5999 L
.14795 .59991 L
.14981 .59993 L
.15166 .59995 L
.15351 .59997 L
.15536 .59999 L
.15722 .6 L
.15907 .60002 L
.16092 .60004 L
.16278 .60006 L
.16463 .60007 L
.16648 .60009 L
.16833 .60011 L
.17019 .60013 L
.17204 .60015 L
.17389 .60016 L
.17575 .60018 L
.1776 .6002 L
.17945 .60022 L
.1813 .60024 L
.18316 .60025 L
.18501 .60027 L
.18686 .60029 L
.18872 .60031 L
.19057 .60033 L
.19242 .60034 L
.19427 .60036 L
.19613 .60038 L
.19798 .6004 L
.19983 .60042 L
.20169 .60043 L
.20354 .60045 L
.20539 .60047 L
.20724 .60049 L
Mistroke
.2091 .6005 L
.21095 .60052 L
.2128 .60054 L
.21466 .60056 L
.21651 .60058 L
.21836 .60059 L
.22021 .60061 L
.22207 .60063 L
.22392 .60065 L
.22577 .60067 L
.22763 .60068 L
.22948 .6007 L
.23133 .60072 L
.23319 .60074 L
.23504 .60076 L
.23689 .60077 L
.23874 .60079 L
.2406 .60081 L
.24245 .60083 L
.2443 .60085 L
.24616 .60086 L
.24801 .60088 L
.24986 .6009 L
.25171 .60092 L
.25357 .60094 L
.25542 .60095 L
.25727 .60097 L
.25913 .60099 L
.26098 .60101 L
.26283 .60102 L
.26468 .60104 L
.26654 .60106 L
.26839 .60108 L
.27024 .6011 L
.2721 .60111 L
.27395 .60113 L
.2758 .60115 L
.27765 .60117 L
.27951 .60119 L
.28136 .6012 L
.28321 .60122 L
.28507 .60124 L
.28692 .60126 L
.28877 .60128 L
.29062 .60129 L
.29248 .60131 L
.29433 .60133 L
.29618 .60135 L
.29804 .60137 L
.29989 .60138 L
Mistroke
.30174 .6014 L
.30359 .60142 L
.30545 .60144 L
.3073 .60145 L
.30915 .60147 L
.31101 .60149 L
.31286 .60151 L
.31471 .60153 L
.31656 .60154 L
.31842 .60156 L
.32027 .60158 L
.32212 .6016 L
.32398 .60162 L
.32583 .60163 L
.32768 .60165 L
.32953 .60167 L
.33139 .60169 L
.33324 .60171 L
.33509 .60172 L
.33695 .60174 L
.3388 .60176 L
.34065 .60178 L
.34251 .6018 L
.34436 .60181 L
.34621 .60183 L
.34806 .60185 L
.34992 .60187 L
.35177 .60189 L
.35362 .6019 L
.35548 .60192 L
.35733 .60194 L
.35918 .60196 L
.36103 .60197 L
.36289 .60199 L
.36474 .60201 L
.36659 .60203 L
.36845 .60205 L
.3703 .60206 L
.37215 .60208 L
.374 .6021 L
.37586 .60212 L
.37771 .60214 L
.37956 .60215 L
.38142 .60217 L
.38327 .60219 L
.38512 .60221 L
.38697 .60223 L
.38883 .60224 L
.39068 .60226 L
.39253 .60228 L
Mistroke
.39439 .6023 L
.39624 .60232 L
.39809 .60233 L
.39994 .60235 L
.4018 .60237 L
.40365 .60239 L
.4055 .6024 L
.40736 .60242 L
.40921 .60244 L
.41106 .60246 L
.41291 .60248 L
.41477 .60249 L
.41662 .60251 L
.41847 .60253 L
.42033 .60255 L
.42218 .60257 L
.42403 .60258 L
.42588 .6026 L
.42774 .60262 L
.42959 .60264 L
.43144 .60266 L
.4333 .60267 L
.43515 .60269 L
.437 .60271 L
.43885 .60273 L
.44071 .60275 L
.44256 .60276 L
.44441 .60278 L
.44627 .6028 L
.44812 .60282 L
.44997 .60283 L
.45183 .60285 L
.45368 .60287 L
.45553 .60289 L
.45738 .60291 L
.45924 .60292 L
.46109 .60294 L
.46294 .60296 L
.4648 .60298 L
.46665 .603 L
.4685 .60301 L
.47035 .60303 L
.47221 .60305 L
.47406 .60307 L
.47591 .60309 L
.47777 .6031 L
.47962 .60312 L
.48147 .60314 L
.48332 .60316 L
.48518 .60318 L
Mistroke
.48703 .60319 L
.48888 .60321 L
.49074 .60323 L
.49259 .60325 L
.49444 .60327 L
.49629 .60328 L
.49815 .6033 L
.5 .60332 L
.50185 .58275 L
.50371 .56769 L
.50556 .55816 L
.50741 .54714 L
.50926 .54164 L
.51112 .53467 L
.51297 .52621 L
.51482 .51815 L
.51668 .51561 L
.51853 .51159 L
.52038 .50609 L
.52223 .50099 L
.52409 .49441 L
.52594 .48822 L
.52779 .48243 L
.52965 .47654 L
.5315 .47616 L
.53335 .4743 L
.5352 .47097 L
.53706 .46803 L
.53891 .46362 L
.54076 .45959 L
.54262 .45597 L
.54447 .45224 L
.54632 .44703 L
.54817 .44222 L
.55003 .4378 L
.55188 .43328 L
.55373 .42915 L
.55559 .42492 L
.55744 .42058 L
.55929 .41627 L
.56115 .41748 L
.563 .4172 L
.56485 .41545 L
.5667 .4141 L
.56856 .41127 L
.57041 .40883 L
.57226 .40679 L
.57412 .40464 L
.57597 .40102 L
.57782 .39779 L
Mistroke
.57967 .39496 L
.58153 .39202 L
.58338 .38948 L
.58523 .38683 L
.58709 .38408 L
.58894 .38135 L
.59079 .37715 L
.59264 .37334 L
.5945 .36992 L
.59635 .36641 L
.5982 .36328 L
.60006 .36006 L
.60191 .35672 L
.60376 .35342 L
.60561 .35051 L
.60747 .34749 L
.60932 .34437 L
.61117 .34127 L
.61303 .33807 L
.61488 .3349 L
.61673 .33176 L
.61858 .32861 L
.62044 .33097 L
.62229 .33186 L
.62414 .33127 L
.626 .33108 L
.62785 .3294 L
.6297 .32813 L
.63155 .32725 L
.63341 .32626 L
.63526 .3238 L
.63711 .32173 L
.63897 .32006 L
.64082 .31828 L
.64267 .31689 L
.64452 .31541 L
.64638 .31381 L
.64823 .31224 L
.65008 .3092 L
.65194 .30655 L
.65379 .3043 L
.65564 .30194 L
.65749 .29998 L
.65935 .29791 L
.6612 .29573 L
.66305 .29359 L
.66491 .29184 L
.66676 .28998 L
.66861 .28802 L
.67047 .28609 L
Mistroke
.67232 .28405 L
.67417 .28203 L
.67602 .28005 L
.67788 .27806 L
.67973 .27459 L
.68158 .27152 L
.68344 .26884 L
.68529 .26606 L
.68714 .26367 L
.68899 .26118 L
.69085 .25858 L
.6927 .25601 L
.69455 .25383 L
.69641 .25155 L
.69826 .24916 L
.70011 .24681 L
.70196 .24434 L
.70382 .24191 L
.70567 .2395 L
.70752 .23708 L
.70938 .23506 L
.71123 .23294 L
.71308 .23071 L
.71493 .2285 L
.71679 .22619 L
.71864 .22391 L
.72049 .22166 L
.72235 .2194 L
.7242 .21703 L
.72605 .2147 L
.7279 .21239 L
.72976 .21007 L
.73161 .20778 L
.73346 .20549 L
.73532 .20318 L
.73717 .20088 L
.73902 .20409 L
.74087 .20583 L
.74273 .20609 L
.74458 .20674 L
.74643 .20592 L
.74829 .20549 L
.75014 .20546 L
.75199 .20533 L
.75384 .20371 L
.7557 .20249 L
.75755 .20167 L
.7594 .20074 L
.76126 .2002 L
.76311 .19956 L
Mistroke
.76496 .19882 L
.76681 .1981 L
.76867 .19591 L
.77052 .19411 L
.77237 .1927 L
.77423 .19119 L
.77608 .19008 L
.77793 .18886 L
.77979 .18753 L
.78164 .18624 L
.78349 .18534 L
.78534 .18433 L
.7872 .18321 L
.78905 .18213 L
.7909 .18094 L
.79276 .17978 L
.79461 .17864 L
.79646 .1775 L
.79831 .17488 L
.80017 .17266 L
.80202 .17083 L
.80387 .16889 L
.80573 .16736 L
.80758 .16571 L
.80943 .16396 L
.81128 .16224 L
.81314 .16091 L
.81499 .15948 L
.81684 .15794 L
.8187 .15644 L
.82055 .15482 L
.8224 .15323 L
.82425 .15167 L
.82611 .15011 L
.82796 .14894 L
.82981 .14766 L
.83167 .14628 L
.83352 .14492 L
.83537 .14346 L
.83722 .14203 L
.83908 .14063 L
.84093 .13922 L
.84278 .1377 L
.84464 .13621 L
.84649 .13475 L
.84834 .13328 L
.85019 .13184 L
.85205 .1304 L
.8539 .12894 L
.85575 .12749 L
Mistroke
.85761 .12456 L
.85946 .12202 L
.86131 .11989 L
.86316 .11764 L
.86502 .11579 L
.86687 .11384 L
.86872 .11178 L
.87058 .10974 L
.87243 .10811 L
.87428 .10636 L
.87613 .10452 L
.87799 .1027 L
.87984 .10077 L
.88169 .09887 L
.88355 .097 L
.8854 .09512 L
.88725 .09364 L
.88911 .09206 L
.89096 .09036 L
.89281 .0887 L
.89466 .08693 L
.89652 .08518 L
.89837 .08347 L
.90022 .08175 L
.90208 .07992 L
.90393 .07812 L
.90578 .07635 L
.90763 .07457 L
.90949 .07282 L
.91134 .07106 L
.91319 .0693 L
.91505 .06753 L
.9169 .06617 L
.91875 .06469 L
.9206 .06311 L
.92246 .06156 L
.92431 .05991 L
.92616 .05828 L
.92802 .05668 L
.92987 .05507 L
.93172 .05335 L
.93357 .05167 L
.93543 .05001 L
.93728 .04835 L
.93913 .04671 L
.94099 .04507 L
.94284 .04341 L
.94469 .04176 L
.94654 .04001 L
.9484 .03828 L
Mistroke
.95025 .03658 L
.9521 .03488 L
.95396 .0332 L
.95581 .03151 L
.95766 .02982 L
.95951 .02813 L
.96137 .02646 L
.96322 .02479 L
.96507 .02312 L
.96693 .02144 L
.96878 .01976 L
.97063 .01807 L
.97248 .0164 L
.97434 .01472 L
.97619 .01855 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "The following example shows the biorthogonal spline scaling function of \
order ",
  Cell[BoxData[
      \(TraditionalForm\`{3, 3}\)], "InlineFormula",
    CellTags->"S3.1.3"],
  " in detail around ",
  Cell[BoxData[
      \(TraditionalForm\`t = 2\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ". "
}], "Text",
  CellTags->{"S3.1.3", "3.14"}],

Cell[TextData[{
  "This gives the scaling function to scale ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^4\)], "InlineFormula",
    CellTags->"S3.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.15"}],

Cell["phi = ScalingFunction[b33, 4, InverseTransform -> True];", "Input",
  CellLabel->"In[59]:= ",
  CellTags->"S3.1.3"],

Cell[TextData[{
  "The scaling function is calculated to scale ",
  Cell[BoxData[
      \(TraditionalForm\`1/2\^19\)], "InlineFormula",
    CellTags->"S3.1.3"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.3", "3.16"}],

Cell["Nest[Zoom[#, b33, 5, {2, 2.0005}]&, phi, 3];", "Input",
  CellLabel->"In[60]:= ",
  CellTags->"S3.1.3"],

Cell["This shows the detailed structure of the scaling function.", 
  "MathCaption",
  CellTags->{"S3.1.3", "3.17"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotJoined -> True, Frame -> True,
Axes -> False, FrameLabel -> {\"t\", \"phi(t)\"},
PlotRange -> {0, 3}]\
\>", "Input",
  CellLabel->"In[61]:= ",
  CellTags->"S3.1.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-3396.71 1698.37 0 0.206011 [
[.03353 -0.0125 -3 -9 ]
[.03353 -0.0125 3 0 ]
[.20337 -0.0125 -18 -9 ]
[.20337 -0.0125 18 0 ]
[.3732 -0.0125 -18 -9 ]
[.3732 -0.0125 18 0 ]
[.54304 -0.0125 -18 -9 ]
[.54304 -0.0125 18 0 ]
[.71288 -0.0125 -18 -9 ]
[.71288 -0.0125 18 0 ]
[.88271 -0.0125 -18 -9 ]
[.88271 -0.0125 18 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -3 -18 ]
[.5 -0.0125 3 -9 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -27 -18 ]
[-0.01875 .30902 -18 18 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03353 0 m
.03353 .00625 L
s
[(2)] .03353 -0.0125 0 1 Mshowa
.20337 0 m
.20337 .00625 L
s
[(2.0001)] .20337 -0.0125 0 1 Mshowa
.3732 0 m
.3732 .00625 L
s
[(2.0002)] .3732 -0.0125 0 1 Mshowa
.54304 0 m
.54304 .00625 L
s
[(2.0003)] .54304 -0.0125 0 1 Mshowa
.71288 0 m
.71288 .00625 L
s
[(2.0004)] .71288 -0.0125 0 1 Mshowa
.88271 0 m
.88271 .00625 L
s
[(2.0005)] .88271 -0.0125 0 1 Mshowa
.125 Mabswid
.0675 0 m
.0675 .00375 L
s
.10146 0 m
.10146 .00375 L
s
.13543 0 m
.13543 .00375 L
s
.1694 0 m
.1694 .00375 L
s
.23733 0 m
.23733 .00375 L
s
.2713 0 m
.2713 .00375 L
s
.30527 0 m
.30527 .00375 L
s
.33923 0 m
.33923 .00375 L
s
.40717 0 m
.40717 .00375 L
s
.44114 0 m
.44114 .00375 L
s
.4751 0 m
.4751 .00375 L
s
.50907 0 m
.50907 .00375 L
s
.57701 0 m
.57701 .00375 L
s
.61097 0 m
.61097 .00375 L
s
.64494 0 m
.64494 .00375 L
s
.67891 0 m
.67891 .00375 L
s
.74684 0 m
.74684 .00375 L
s
.78081 0 m
.78081 .00375 L
s
.81478 0 m
.81478 .00375 L
s
.84875 0 m
.84875 .00375 L
s
.91668 0 m
.91668 .00375 L
s
.95065 0 m
.95065 .00375 L
s
.98462 0 m
.98462 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(t)] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
[(phi\\(t\\))] -0.01875 .30902 -18 0 Mabsadd 1 0 90 Mrotshowa
.03353 .61178 m
.03353 .61803 L
s
.20337 .61178 m
.20337 .61803 L
s
.3732 .61178 m
.3732 .61803 L
s
.54304 .61178 m
.54304 .61803 L
s
.71288 .61178 m
.71288 .61803 L
s
.88271 .61178 m
.88271 .61803 L
s
.125 Mabswid
.0675 .61428 m
.0675 .61803 L
s
.10146 .61428 m
.10146 .61803 L
s
.13543 .61428 m
.13543 .61803 L
s
.1694 .61428 m
.1694 .61803 L
s
.23733 .61428 m
.23733 .61803 L
s
.2713 .61428 m
.2713 .61803 L
s
.30527 .61428 m
.30527 .61803 L
s
.33923 .61428 m
.33923 .61803 L
s
.40717 .61428 m
.40717 .61803 L
s
.44114 .61428 m
.44114 .61803 L
s
.4751 .61428 m
.4751 .61803 L
s
.50907 .61428 m
.50907 .61803 L
s
.57701 .61428 m
.57701 .61803 L
s
.61097 .61428 m
.61097 .61803 L
s
.64494 .61428 m
.64494 .61803 L
s
.67891 .61428 m
.67891 .61803 L
s
.74684 .61428 m
.74684 .61803 L
s
.78081 .61428 m
.78081 .61803 L
s
.81478 .61428 m
.81478 .61803 L
s
.84875 .61428 m
.84875 .61803 L
s
.91668 .61428 m
.91668 .61803 L
s
.95065 .61428 m
.95065 .61803 L
s
.98462 .61428 m
.98462 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03198 0 m
.03353 .48021 L
s
.03353 .48021 m
.0362 .61803 L
s
.03762 .61803 m
.04001 .53591 L
s
.04001 .53591 m
.04268 .61803 L
s
.04351 .61803 m
.04649 .42281 L
.04972 .41737 L
s
.04972 .41737 m
.0527 .61803 L
s
.05526 .61803 m
.0562 .61061 L
.05944 .34293 L
.06268 .33916 L
.06592 .33111 L
.06916 .34089 L
.0724 .59417 L
.07564 .59824 L
.07888 .58632 L
.08212 .56351 L
.08536 .27576 L
.0886 .23526 L
.09184 .32298 L
.09508 .29985 L
.09832 .28893 L
.10155 .30997 L
.10479 .23907 L
.10803 .27528 L
.11127 .55207 L
.11451 .58763 L
.11775 .51173 L
.12099 .52984 L
.12423 .5228 L
.12747 .49435 L
.13071 .56888 L
.13395 .5214 L
.13719 .22291 L
.14043 .18275 L
.14367 .2044 L
.14691 .18506 L
.15015 .30373 L
.15339 .30842 L
.15662 .25714 L
.15986 .26146 L
.1631 .24996 L
.16634 .24352 L
.16958 .29417 L
.17282 .28935 L
.17606 .19152 L
.1793 .21153 L
.18254 .1831 L
.18578 .22364 L
.18902 .5073 L
.19226 .54738 L
.1955 .51994 L
.19874 .53891 L
.20198 .43663 L
.20522 .43098 L
.20845 .47875 L
.21169 .47159 L
Mistroke
.21493 .4673 L
.21817 .4701 L
.22141 .41593 L
.22465 .41779 L
.22789 .52596 L
.23113 .50245 L
.23437 .52438 L
.23761 .47915 L
.24085 .17646 L
.24409 .12724 L
.24733 .17492 L
.25057 .14584 L
.25381 .1898 L
.25705 .19666 L
.26029 .12835 L
.26352 .14435 L
.26676 .28112 L
.27 .29237 L
.27324 .27513 L
.27648 .2789 L
.27972 .21885 L
.28296 .21176 L
.2862 .23749 L
.28944 .2317 L
.29268 .21977 L
.29592 .22189 L
.29916 .20166 L
.3024 .20645 L
.30564 .26645 L
.30888 .26412 L
.31212 .27451 L
.31535 .26614 L
.31859 .15234 L
.32183 .13876 L
.32507 .20306 L
.32831 .19711 L
.33155 .1454 L
.33479 .17238 L
.33803 .13234 L
.34127 .17833 L
.34451 .46655 L
.34775 .51259 L
.35099 .47174 L
.35423 .49871 L
.35747 .44852 L
.36071 .44216 L
.36395 .50645 L
.36718 .49214 L
.37042 .37417 L
.37366 .36476 L
Mistroke
.3769 .37662 L
.38014 .37336 L
.38338 .43071 L
.38662 .43551 L
.38986 .41311 L
.3931 .41571 L
.39634 .41222 L
.39958 .40689 L
.40282 .42948 L
.40606 .42214 L
.4093 .36053 L
.41254 .36252 L
.41578 .34657 L
.41902 .35538 L
.42225 .48267 L
.42549 .4964 L
.42873 .42701 L
.43197 .43203 L
.43521 .4792 L
.43845 .44882 L
.44169 .49211 L
.44493 .44159 L
.44817 .13724 L
.45141 .08865 L
.45465 .11889 L
.45789 .09108 L
.46113 .17007 L
.46437 .17221 L
.46761 .10946 L
.47085 .11605 L
.47408 .17214 L
.47732 .17107 L
.48056 .18683 L
.4838 .18329 L
.48704 .09988 L
.49028 .10459 L
.49352 .09952 L
.49676 .11598 L
.5 .25881 L
.50324 .27925 L
.50648 .25194 L
.50972 .26281 L
.51296 .2386 L
.5162 .23267 L
.51944 .2626 L
.52268 .25277 L
.52592 .18731 L
.52915 .18046 L
.53239 .18397 L
.53563 .18108 L
Mistroke
.53887 .21399 L
.54211 .21514 L
.54535 .20416 L
.54859 .20398 L
.55183 .19165 L
.55507 .18807 L
.55831 .20117 L
.56155 .19803 L
.56479 .17333 L
.56803 .17637 L
.57127 .16837 L
.57451 .1755 L
.57775 .24143 L
.58098 .25071 L
.58422 .22466 L
.58746 .23009 L
.5907 .24514 L
.59394 .23574 L
.59718 .26091 L
.60042 .24368 L
.60366 .12464 L
.6069 .11162 L
.61014 .113 L
.61338 .11008 L
.61662 .18806 L
.61986 .19072 L
.6231 .17994 L
.62634 .17953 L
.62958 .11494 L
.63282 .10767 L
.63605 .16827 L
.63929 .16598 L
.64253 .09715 L
.64577 .12427 L
.64901 .0926 L
.65225 .13955 L
.65549 .4293 L
.65873 .47618 L
.66197 .44487 L
.66521 .47187 L
.66845 .40206 L
.67169 .39979 L
.67493 .46013 L
.67817 .45297 L
.68141 .39037 L
.68465 .39013 L
.68788 .37833 L
.69112 .381 L
.69436 .4594 L
.6976 .45596 L
Mistroke
.70084 .45798 L
.70408 .44415 L
.70732 .32074 L
.71056 .30281 L
.7138 .32774 L
.71704 .31796 L
.72028 .33546 L
.72352 .34065 L
.72676 .31392 L
.73 .32282 L
.73324 .38601 L
.73648 .3925 L
.73971 .38624 L
.74295 .38879 L
.74619 .36132 L
.74943 .3587 L
.75267 .37019 L
.75591 .3678 L
.75915 .36518 L
.76239 .36611 L
.76563 .35374 L
.76887 .35526 L
.77211 .38459 L
.77535 .38111 L
.77859 .38604 L
.78183 .37848 L
.78507 .31154 L
.78831 .30128 L
.79155 .32941 L
.79478 .32305 L
.79802 .30176 L
.80126 .31156 L
.8045 .28415 L
.80774 .30291 L
.81098 .43707 L
.81422 .45163 L
.81746 .4476 L
.8207 .45089 L
.82394 .36731 L
.82718 .36344 L
.83042 .37642 L
.83366 .37537 L
.8369 .43649 L
.84014 .44287 L
.84338 .37877 L
.84661 .38029 L
.84985 .45554 L
.85309 .42655 L
.85633 .45755 L
.85957 .40766 L
Mistroke
.86281 .10159 L
.86605 .05073 L
.86929 .0882 L
.87253 .05788 L
.87577 .11717 L
.87901 .12005 L
.88225 .05253 L
.88549 .06236 L
.88873 .1589 L
.89197 .16262 L
.89521 .15961 L
.89845 .15831 L
.90168 .08544 L
.90492 .08249 L
.90816 .09204 L
.9114 .09546 L
.91464 .15627 L
.91788 .16582 L
.92112 .14061 L
.92436 .14706 L
.9276 .16607 L
.93084 .16071 L
.93408 .1794 L
.93732 .169 L
.94056 .0757 L
.9438 .06403 L
.94704 .0988 L
.95028 .09315 L
.95351 .08051 L
.95675 .0944 L
.95999 .06672 L
.96323 .09015 L
.96647 .23667 L
.96971 .25846 L
.97295 .24268 L
.97619 .25454 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],

Cell[TextData[{
  "Similarly, ",
  StyleBox["Zoom", "MR"],
  " can be used to calculate the details of wavelet packets ",
  Cell[BoxData[
      \(TraditionalForm\`\(w\_n\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.3"],
  ". "
}], "Text",
  CellTags->{"S3.1.3", "3.18"}],

Cell[TextData[{
  "3.1.4 Derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)], "InlineFormula",
    CellTags->"S3.1.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)], "InlineFormula",
    CellTags->"S3.1.4"]
}], "Subsection",
  CellTags->{"S3.1.4", "4.1"}],

Cell[TextData[{
  "If we formally take the derivatives of the dilation equation (",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 3.1.1", "1.5"},
    ButtonStyle->"AddOnsLink"],
  ") and wavelet equation (",
  ButtonBox["1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.3"},
    ButtonStyle->"AddOnsLink"],
  "), we get "
}], "Text",
  CellTags->{"S3.1.4", "4.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Phi]\^\((m)\)\), \((t)\), "=", \(2\^m\), \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(h\_k\), \(\[Phi]\^\((m)\)\), \((
        2  t - k)\)}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.1.4", "4.3"}],

Cell["and ", "Text",
  CellTags->{"S3.1.4", "4.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi]\^\((m)\)\), \((t)\), "=", \(2\^m\), \(\@2\), 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(g\_k\), \(\[Phi]\^\((m)\)\), \((
        2  t - k)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(1.5) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.1.4", "4.5"}],

Cell[TextData[{
  "If the ",
  Cell[BoxData[
      \(TraditionalForm\`m\^th\)], "InlineFormula",
    CellTags->"S3.1.4"],
  " derivative ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\((m)\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.4"],
  " exists, we can first obtain its values at the integers by solving the \
eigenvalue problem (",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 3.1.4", "4.3"},
    ButtonStyle->"AddOnsLink"],
  ") and then recursively find its values at half\[Hyphen]integers, quarter\
\[Hyphen]integers, etc. Once ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\^\((m)\)\), 
          RowBox[{"(", 
            RowBox[{"k", "/", 
              SuperscriptBox["2", 
                StyleBox[\("jmax"\),
                  "TI"]]}], ")"}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.1.4"],
  " is known, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\((m)\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.4"],
  " at the dyadic points can be obtained using (",
  ButtonBox["1.5",
    ButtonData:>{"Wavelets 3.1.4", "4.5"},
    ButtonStyle->"AddOnsLink"],
  "). However, it should be kept in mind that the existence of a solution to \
the eigenvalue problem (",
  ButtonBox["1.4",
    ButtonData:>{"Wavelets 3.1.4", "4.3"},
    ButtonStyle->"AddOnsLink"],
  ") does not imply the existence of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\((m)\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.1.4"],
  ". "
}], "Text",
  CellTags->{"S3.1.4", "4.6"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"DScalingFunction[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"jmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"m\\\\\
\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", 
                  RowBox[{\("compute "\), 
                    StyleBox[\(\[Phi]\^\((m)\)\),
                      "InlineFormula"], 
                    "\<\" using filter \\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\
\\\\\"\\\", \\\"TI\\\"]\\) to scale \"\>", 
                    StyleBox[
                      RowBox[{"1", "/", 
                        SuperscriptBox["2", 
                          StyleBox[\("jmax"\),
                            "TI"]]}],
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"DWavelet[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"jmax\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"m\\\\\
\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", 
                  RowBox[{\("compute "\), 
                    StyleBox[\(\[Psi]\^\((m)\)\),
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.1.4", "4.7"}],

Cell["Derivatives of scaling function and wavelet.", "Caption",
  CellTags->"S3.1.4"],

Cell[TextData[{
  "This gives the first derivative of the Daubechies scaling function of \
order 6 at the dyadic points ",
  Cell[BoxData[
      \(TraditionalForm\`k/2\^7\)], "InlineFormula",
    CellTags->"S3.1.4"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.4", "4.8"}],

Cell["DScalingFunction[DaubechiesFilter[6], 7, 1];", "Input",
  CellLabel->"In[62]:= ",
  CellTags->"S3.1.4"],

Cell[TextData[{
  "We plot the derivative as a function of\[NonBreakingSpace]",
  Cell[BoxData[
      \(TraditionalForm\`t\)], "InlineFormula",
    CellTags->"S3.1.4"],
  "."
}], "MathCaption",
  CellTags->{"S3.1.4", "4.9"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[%, PlotJoined -> True, PlotRange -> All,
AxesLabel -> {\"t\", \"\"}, PlotLabel -> \"phi'(t)\"]\
\>", "Input",
  CellLabel->"In[63]:= ",
  CellTags->"S3.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0865801 0.373695 0.178733 [
[.19697 .36119 -3 -9 ]
[.19697 .36119 3 0 ]
[.37013 .36119 -3 -9 ]
[.37013 .36119 3 0 ]
[.54329 .36119 -3 -9 ]
[.54329 .36119 3 0 ]
[.71645 .36119 -3 -9 ]
[.71645 .36119 3 0 ]
[.88961 .36119 -6 -9 ]
[.88961 .36119 6 0 ]
[1.025 .37369 0 -4.5 ]
[1.025 .37369 6 4.5 ]
[.01131 .01623 -12 -4.5 ]
[.01131 .01623 0 4.5 ]
[.01131 .1056 -24 -4.5 ]
[.01131 .1056 0 4.5 ]
[.01131 .19496 -12 -4.5 ]
[.01131 .19496 0 4.5 ]
[.01131 .28433 -24 -4.5 ]
[.01131 .28433 0 4.5 ]
[.01131 .46306 -18 -4.5 ]
[.01131 .46306 0 4.5 ]
[.01131 .55243 -6 -4.5 ]
[.01131 .55243 0 4.5 ]
[.5 .63053 -21 0 ]
[.5 .63053 21 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19697 .37369 m
.19697 .37994 L
s
[(2)] .19697 .36119 0 1 Mshowa
.37013 .37369 m
.37013 .37994 L
s
[(4)] .37013 .36119 0 1 Mshowa
.54329 .37369 m
.54329 .37994 L
s
[(6)] .54329 .36119 0 1 Mshowa
.71645 .37369 m
.71645 .37994 L
s
[(8)] .71645 .36119 0 1 Mshowa
.88961 .37369 m
.88961 .37994 L
s
[(10)] .88961 .36119 0 1 Mshowa
.125 Mabswid
.0671 .37369 m
.0671 .37744 L
s
.11039 .37369 m
.11039 .37744 L
s
.15368 .37369 m
.15368 .37744 L
s
.24026 .37369 m
.24026 .37744 L
s
.28355 .37369 m
.28355 .37744 L
s
.32684 .37369 m
.32684 .37744 L
s
.41342 .37369 m
.41342 .37744 L
s
.45671 .37369 m
.45671 .37744 L
s
.5 .37369 m
.5 .37744 L
s
.58658 .37369 m
.58658 .37744 L
s
.62987 .37369 m
.62987 .37744 L
s
.67316 .37369 m
.67316 .37744 L
s
.75974 .37369 m
.75974 .37744 L
s
.80303 .37369 m
.80303 .37744 L
s
.84632 .37369 m
.84632 .37744 L
s
.9329 .37369 m
.9329 .37744 L
s
.97619 .37369 m
.97619 .37744 L
s
.25 Mabswid
0 .37369 m
1 .37369 L
s
[(t)] 1.025 .37369 -1 0 Mshowa
.02381 .01623 m
.03006 .01623 L
s
[(-2)] .01131 .01623 1 0 Mshowa
.02381 .1056 m
.03006 .1056 L
s
[(-1.5)] .01131 .1056 1 0 Mshowa
.02381 .19496 m
.03006 .19496 L
s
[(-1)] .01131 .19496 1 0 Mshowa
.02381 .28433 m
.03006 .28433 L
s
[(-0.5)] .01131 .28433 1 0 Mshowa
.02381 .46306 m
.03006 .46306 L
s
[(0.5)] .01131 .46306 1 0 Mshowa
.02381 .55243 m
.03006 .55243 L
s
[(1)] .01131 .55243 1 0 Mshowa
.125 Mabswid
.02381 .0341 m
.02756 .0341 L
s
.02381 .05198 m
.02756 .05198 L
s
.02381 .06985 m
.02756 .06985 L
s
.02381 .08772 m
.02756 .08772 L
s
.02381 .12347 m
.02756 .12347 L
s
.02381 .14134 m
.02756 .14134 L
s
.02381 .15922 m
.02756 .15922 L
s
.02381 .17709 m
.02756 .17709 L
s
.02381 .21284 m
.02756 .21284 L
s
.02381 .23071 m
.02756 .23071 L
s
.02381 .24858 m
.02756 .24858 L
s
.02381 .26645 m
.02756 .26645 L
s
.02381 .3022 m
.02756 .3022 L
s
.02381 .32007 m
.02756 .32007 L
s
.02381 .33795 m
.02756 .33795 L
s
.02381 .35582 m
.02756 .35582 L
s
.02381 .39157 m
.02756 .39157 L
s
.02381 .40944 m
.02756 .40944 L
s
.02381 .42731 m
.02756 .42731 L
s
.02381 .44519 m
.02756 .44519 L
s
.02381 .48093 m
.02756 .48093 L
s
.02381 .49881 m
.02756 .49881 L
s
.02381 .51668 m
.02756 .51668 L
s
.02381 .53455 m
.02756 .53455 L
s
.02381 .5703 m
.02756 .5703 L
s
.02381 .58817 m
.02756 .58817 L
s
.02381 .60605 m
.02756 .60605 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
[(phi'\\(t\\))] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .37369 m
.02449 .37376 L
.02516 .3739 L
.02584 .37409 L
.02652 .37436 L
.02719 .37465 L
.02787 .37495 L
.02854 .37534 L
.02922 .37579 L
.0299 .37625 L
.03057 .37671 L
.03125 .37719 L
.03193 .37766 L
.0326 .37823 L
.03328 .37891 L
.03396 .3796 L
.03463 .38035 L
.03531 .38109 L
.03598 .38179 L
.03666 .38252 L
.03734 .38325 L
.03801 .38399 L
.03869 .38478 L
.03937 .38553 L
.04004 .38628 L
.04072 .38713 L
.0414 .38808 L
.04207 .38909 L
.04275 .39022 L
.04343 .39133 L
.0441 .3924 L
.04478 .39358 L
.04545 .3948 L
.04613 .39598 L
.04681 .39715 L
.04748 .39828 L
.04816 .39934 L
.04884 .40047 L
.04951 .40167 L
.05019 .40282 L
.05087 .40398 L
.05154 .40516 L
.05222 .40634 L
.0529 .40756 L
.05357 .40883 L
.05425 .41004 L
.05492 .41122 L
.0556 .41241 L
.05628 .41357 L
.05695 .41485 L
Mistroke
.05763 .41627 L
.05831 .41772 L
.05898 .41929 L
.05966 .42089 L
.06034 .4225 L
.06101 .42424 L
.06169 .42607 L
.06236 .42785 L
.06304 .42959 L
.06372 .43133 L
.06439 .433 L
.06507 .43479 L
.06575 .43673 L
.06642 .43863 L
.0671 .44058 L
.06778 .4425 L
.06845 .44433 L
.06913 .44619 L
.06981 .44803 L
.07048 .44983 L
.07116 .45162 L
.07183 .45334 L
.07251 .45499 L
.07319 .45674 L
.07386 .45858 L
.07454 .46043 L
.07522 .46238 L
.07589 .46425 L
.07657 .46602 L
.07725 .46786 L
.07792 .46969 L
.0786 .47153 L
.07927 .47344 L
.07995 .47531 L
.08063 .47717 L
.0813 .47909 L
.08198 .48105 L
.08266 .48303 L
.08333 .48506 L
.08401 .48702 L
.08469 .48892 L
.08536 .49081 L
.08604 .49264 L
.08672 .4945 L
.08739 .49641 L
.08807 .49826 L
.08874 .5001 L
.08942 .50206 L
.0901 .50414 L
.09077 .50631 L
Mistroke
.09145 .50864 L
.09213 .51096 L
.0928 .51326 L
.09348 .51571 L
.09416 .51823 L
.09483 .52075 L
.09551 .52331 L
.09619 .52586 L
.09686 .52839 L
.09754 .53107 L
.09821 .53391 L
.09889 .53676 L
.09957 .53972 L
.10024 .5426 L
.10092 .54536 L
.1016 .54815 L
.10227 .55087 L
.10295 .5536 L
.10363 .55638 L
.1043 .55906 L
.10498 .56167 L
.10565 .56444 L
.10633 .56736 L
.10701 .57035 L
.10768 .57351 L
.10836 .57658 L
.10904 .57953 L
.10971 .58262 L
.11039 .58572 L
.11107 .58847 L
.11174 .59087 L
.11242 .59299 L
.1131 .59464 L
.11377 .59628 L
.11445 .59792 L
.11512 .59909 L
.1158 .59999 L
.11648 .60087 L
.11715 .60164 L
.11783 .60234 L
.11851 .60309 L
.11918 .60332 L
.11986 .60302 L
.12054 .60262 L
.12121 .60185 L
.12189 .60126 L
.12256 .60103 L
.12324 .60063 L
.12392 .60039 L
.12459 .60005 L
Mistroke
.12527 .59948 L
.12595 .59918 L
.12662 .599 L
.1273 .59824 L
.12798 .59693 L
.12865 .59532 L
.12933 .59306 L
.13001 .59099 L
.13068 .58921 L
.13136 .58687 L
.13203 .5844 L
.13271 .5821 L
.13339 .57983 L
.13406 .57779 L
.13474 .57612 L
.13542 .57408 L
.13609 .57172 L
.13677 .56959 L
.13745 .5674 L
.13812 .56516 L
.1388 .56301 L
.13948 .56067 L
.14015 .55817 L
.14083 .55591 L
.1415 .55384 L
.14218 .55176 L
.14286 .54984 L
.14353 .54735 L
.14421 .54412 L
.14489 .54072 L
.14556 .5367 L
.14624 .53258 L
.14692 .52849 L
.14759 .5237 L
.14827 .51845 L
.14894 .51351 L
.14962 .50875 L
.1503 .50403 L
.15097 .4997 L
.15165 .49471 L
.15233 .48901 L
.153 .48351 L
.15368 .47774 L
.15436 .47225 L
.15503 .46737 L
.15571 .46235 L
.15639 .45755 L
.15706 .453 L
.15774 .44851 L
.15841 .4445 L
Mistroke
.15909 .44095 L
.15977 .4369 L
.16044 .43237 L
.16112 .42783 L
.1618 .4228 L
.16247 .41828 L
.16315 .41442 L
.16383 .41021 L
.1645 .40614 L
.16518 .40201 L
.16585 .39753 L
.16653 .39327 L
.16721 .38904 L
.16788 .38457 L
.16856 .37998 L
.16924 .37523 L
.16991 .3702 L
.17059 .36564 L
.17127 .36159 L
.17194 .35761 L
.17262 .35406 L
.1733 .35036 L
.17397 .34639 L
.17465 .34284 L
.17532 .33942 L
.176 .33533 L
.17668 .33063 L
.17735 .32545 L
.17803 .31939 L
.17871 .31349 L
.17938 .30778 L
.18006 .30125 L
.18074 .29434 L
.18141 .2875 L
.18209 .2805 L
.18277 .27354 L
.18344 .26678 L
.18412 .2592 L
.18479 .25079 L
.18547 .24231 L
.18615 .23329 L
.18682 .22478 L
.1875 .21709 L
.18818 .20925 L
.18885 .20188 L
.18953 .19451 L
.19021 .18689 L
.19088 .17996 L
.19156 .17346 L
.19223 .16609 L
Mistroke
.19291 .15796 L
.19359 .1495 L
.19426 .14006 L
.19494 .13123 L
.19562 .12317 L
.19629 .11435 L
.19697 .10554 L
.19765 .0975 L
.19832 .09 L
.199 .08333 L
.19968 .07786 L
.20035 .07207 L
.20103 .06604 L
.2017 .06102 L
.20238 .05637 L
.20306 .05196 L
.20373 .04808 L
.20441 .04426 L
.20509 .04048 L
.20576 .03778 L
.20644 .03609 L
.20712 .03481 L
.20779 .03441 L
.20847 .03331 L
.20915 .03118 L
.20982 .02924 L
.2105 .02662 L
.21117 .02429 L
.21185 .02257 L
.21253 .01996 L
.2132 .01695 L
.21388 .01527 L
.21456 .01472 L
.21523 .01487 L
.21591 .01657 L
.21659 .01755 L
.21726 .01765 L
.21794 .01896 L
.21861 .02042 L
.21929 .02162 L
.21997 .02301 L
.22064 .02383 L
.22132 .02394 L
.222 .02488 L
.22267 .02649 L
.22335 .02777 L
.22403 .02933 L
.2247 .03076 L
.22538 .0318 L
.22606 .03321 L
Mistroke
.22673 .03473 L
.22741 .03589 L
.22808 .03688 L
.22876 .0377 L
.22944 .03819 L
.23011 .03989 L
.23079 .04298 L
.23147 .04653 L
.23214 .05138 L
.23282 .05632 L
.2335 .0611 L
.23417 .06731 L
.23485 .07436 L
.23552 .08088 L
.2362 .08713 L
.23688 .09328 L
.23755 .0987 L
.23823 .10542 L
.23891 .11357 L
.23958 .12136 L
.24026 .12974 L
.24094 .13726 L
.24161 .14325 L
.24229 .14936 L
.24297 .15464 L
.24364 .15943 L
.24432 .1641 L
.24499 .16743 L
.24567 .16965 L
.24635 .17288 L
.24702 .17704 L
.2477 .1812 L
.24838 .18639 L
.24905 .19021 L
.24973 .1923 L
.25041 .19507 L
.25108 .19732 L
.25176 .1998 L
.25244 .20321 L
.25311 .20604 L
.25379 .20886 L
.25446 .21215 L
.25514 .21555 L
.25582 .21945 L
.25649 .22398 L
.25717 .2272 L
.25785 .22902 L
.25852 .23053 L
.2592 .23076 L
.25988 .2314 L
Mistroke
.26055 .23279 L
.26123 .23297 L
.2619 .23281 L
.26258 .2341 L
.26326 .23664 L
.26393 .24029 L
.26461 .24595 L
.26529 .25106 L
.26596 .25557 L
.26664 .2619 L
.26732 .26892 L
.26799 .27581 L
.26867 .28307 L
.26935 .29015 L
.27002 .29673 L
.2707 .30511 L
.27137 .31528 L
.27205 .32559 L
.27273 .3371 L
.2734 .34726 L
.27408 .35532 L
.27476 .36358 L
.27543 .37055 L
.27611 .37748 L
.27679 .38494 L
.27746 .39059 L
.27814 .39514 L
.27881 .40161 L
.27949 .40976 L
.28017 .41861 L
.28084 .42966 L
.28152 .43912 L
.2822 .44664 L
.28287 .4558 L
.28355 .46481 L
.28423 .47297 L
.2849 .48103 L
.28558 .4877 L
.28626 .49276 L
.28693 .49878 L
.28761 .50545 L
.28828 .51112 L
.28896 .51683 L
.28964 .52174 L
.29031 .52542 L
.29099 .52916 L
.29167 .53248 L
.29234 .53472 L
.29302 .53618 L
.2937 .53674 L
Mistroke
.29437 .53616 L
.29505 .53687 L
.29573 .53911 L
.2964 .54144 L
.29708 .54516 L
.29775 .54831 L
.29843 .55051 L
.29911 .55422 L
.29978 .55849 L
.30046 .56126 L
.30114 .56292 L
.30181 .56366 L
.30249 .56253 L
.30317 .56264 L
.30384 .56414 L
.30452 .56431 L
.30519 .56458 L
.30587 .56474 L
.30655 .56412 L
.30722 .56415 L
.3079 .56458 L
.30858 .56402 L
.30925 .5628 L
.30993 .56143 L
.31061 .5594 L
.31128 .55788 L
.31196 .55711 L
.31264 .556 L
.31331 .55519 L
.31399 .55428 L
.31466 .55298 L
.31534 .55213 L
.31602 .55148 L
.31669 .54965 L
.31737 .54669 L
.31805 .54305 L
.31872 .53805 L
.3194 .53316 L
.32008 .52852 L
.32075 .52256 L
.32143 .51598 L
.3221 .50956 L
.32278 .50302 L
.32346 .49654 L
.32413 .49047 L
.32481 .4832 L
.32549 .47472 L
.32616 .46628 L
.32684 .45716 L
.32752 .44937 L
Mistroke
.32819 .44353 L
.32887 .43791 L
.32955 .43374 L
.33022 .42996 L
.3309 .42615 L
.33157 .42427 L
.33225 .42376 L
.33293 .42221 L
.3336 .41987 L
.33428 .41752 L
.33496 .414 L
.33563 .41245 L
.33631 .41321 L
.33699 .41337 L
.33766 .41444 L
.33834 .41499 L
.33902 .41407 L
.33969 .41388 L
.34037 .41342 L
.34104 .41253 L
.34172 .41175 L
.3424 .41004 L
.34307 .40747 L
.34375 .40684 L
.34443 .40818 L
.3451 .41009 L
.34578 .41401 L
.34646 .41716 L
.34713 .41911 L
.34781 .42284 L
.34848 .42698 L
.34916 .42948 L
.34984 .43075 L
.35051 .43062 L
.35119 .42807 L
.35187 .42644 L
.35254 .42572 L
.35322 .42295 L
.3539 .41958 L
.35457 .41625 L
.35525 .41233 L
.35593 .40873 L
.3566 .40567 L
.35728 .40056 L
.35795 .39353 L
.35863 .38623 L
.35931 .37753 L
.35998 .3707 L
.36066 .36657 L
.36134 .3624 L
Mistroke
.36201 .36006 L
.36269 .35777 L
.36337 .35482 L
.36404 .35428 L
.36472 .35518 L
.3654 .35384 L
.36607 .35064 L
.36675 .34662 L
.36742 .33999 L
.3681 .33549 L
.36878 .33354 L
.36945 .3297 L
.37013 .32622 L
.37081 .32311 L
.37148 .31931 L
.37216 .31687 L
.37284 .31558 L
.37351 .31301 L
.37419 .30965 L
.37486 .30659 L
.37554 .30287 L
.37622 .30034 L
.37689 .29939 L
.37757 .29829 L
.37825 .298 L
.37892 .29805 L
.3796 .29798 L
.38028 .29903 L
.38095 .30087 L
.38163 .30144 L
.38231 .30081 L
.38298 .29973 L
.38366 .29715 L
.38433 .29525 L
.38501 .29425 L
.38569 .29187 L
.38636 .28912 L
.38704 .28714 L
.38772 .2855 L
.38839 .28451 L
.38907 .28466 L
.38975 .28366 L
.39042 .28151 L
.3911 .27999 L
.39177 .27808 L
.39245 .27685 L
.39313 .27684 L
.3938 .27659 L
.39448 .27674 L
.39516 .27749 L
Mistroke
.39583 .27849 L
.39651 .28035 L
.39719 .28306 L
.39786 .28506 L
.39854 .28635 L
.39922 .28774 L
.39989 .28845 L
.40057 .28998 L
.40124 .29257 L
.40192 .29463 L
.4026 .29691 L
.40327 .29956 L
.40395 .30222 L
.40463 .30548 L
.4053 .30933 L
.40598 .31289 L
.40666 .3163 L
.40733 .32 L
.40801 .32364 L
.40869 .32785 L
.40936 .3328 L
.41004 .33784 L
.41071 .34333 L
.41139 .34909 L
.41207 .35497 L
.41274 .3614 L
.41342 .36826 L
.4141 .37398 L
.41477 .37842 L
.41545 .38229 L
.41613 .38474 L
.4168 .38729 L
.41748 .39014 L
.41815 .39146 L
.41883 .39196 L
.41951 .3929 L
.42018 .39395 L
.42086 .39508 L
.42154 .39685 L
.42221 .39708 L
.42289 .39565 L
.42357 .39436 L
.42424 .39217 L
.42492 .39073 L
.4256 .39069 L
.42627 .39025 L
.42695 .3904 L
.42762 .39069 L
.4283 .39066 L
.42898 .39169 L
Mistroke
.42965 .39345 L
.43033 .39361 L
.43101 .39226 L
.43168 .39033 L
.43236 .38665 L
.43304 .38385 L
.43371 .38225 L
.43439 .37921 L
.43506 .37599 L
.43574 .37371 L
.43642 .37186 L
.43709 .37106 L
.43777 .37179 L
.43845 .37169 L
.43912 .37087 L
.4398 .37118 L
.44048 .37162 L
.44115 .37226 L
.44183 .37353 L
.44251 .37454 L
.44318 .3754 L
.44386 .37739 L
.44453 .38037 L
.44521 .38369 L
.44589 .3879 L
.44656 .39073 L
.44724 .39172 L
.44792 .39256 L
.44859 .39196 L
.44927 .39144 L
.44995 .39142 L
.45062 .38968 L
.4513 .38698 L
.45198 .38562 L
.45265 .38532 L
.45333 .38554 L
.454 .3874 L
.45468 .38774 L
.45536 .38632 L
.45603 .38601 L
.45671 .38535 L
.45739 .38482 L
.45806 .38521 L
.45874 .38487 L
.45942 .38425 L
.46009 .38447 L
.46077 .38516 L
.46144 .38618 L
.46212 .38793 L
.4628 .38876 L
Mistroke
.46347 .3885 L
.46415 .38834 L
.46483 .38744 L
.4655 .38685 L
.46618 .38691 L
.46686 .3862 L
.46753 .38527 L
.46821 .38499 L
.46889 .38507 L
.46956 .38563 L
.47024 .38702 L
.47091 .38794 L
.47159 .38839 L
.47227 .38945 L
.47294 .39055 L
.47362 .3917 L
.4743 .39314 L
.47497 .39438 L
.47565 .39546 L
.47633 .39706 L
.477 .39908 L
.47768 .40118 L
.47835 .40364 L
.47903 .40538 L
.47971 .40618 L
.48038 .40684 L
.48106 .40676 L
.48174 .40659 L
.48241 .40653 L
.48309 .40557 L
.48377 .40402 L
.48444 .40294 L
.48512 .40217 L
.4858 .40146 L
.48647 .40131 L
.48715 .40028 L
.48782 .39825 L
.4885 .39652 L
.48918 .39439 L
.48985 .39252 L
.49053 .39131 L
.49121 .3898 L
.49188 .38841 L
.49256 .38726 L
.49324 .38609 L
.49391 .38536 L
.49459 .38504 L
.49527 .38394 L
.49594 .38206 L
.49662 .38 L
Mistroke
.49729 .37716 L
.49797 .37469 L
.49865 .37279 L
.49932 .37021 L
.5 .36753 L
.50068 .36537 L
.50135 .36351 L
.50203 .36217 L
.50271 .36162 L
.50338 .3607 L
.50406 .35945 L
.50473 .35881 L
.50541 .35829 L
.50609 .35787 L
.50676 .35777 L
.50744 .35758 L
.50812 .35731 L
.50879 .35767 L
.50947 .35856 L
.51015 .35964 L
.51082 .36121 L
.5115 .36219 L
.51218 .36239 L
.51285 .36261 L
.51353 .36226 L
.5142 .36199 L
.51488 .36202 L
.51556 .36133 L
.51623 .36028 L
.51691 .35993 L
.51759 .36017 L
.51826 .36073 L
.51894 .36213 L
.51962 .36293 L
.52029 .36302 L
.52097 .36373 L
.52165 .36437 L
.52232 .36487 L
.523 .36553 L
.52367 .36577 L
.52435 .36561 L
.52503 .36586 L
.5257 .36639 L
.52638 .36676 L
.52706 .36729 L
.52773 .36755 L
.52841 .3674 L
.52909 .36733 L
.52976 .36711 L
.53044 .36672 L
Mistroke
.53111 .36628 L
.53179 .36556 L
.53247 .36459 L
.53314 .36413 L
.53382 .36421 L
.5345 .36446 L
.53517 .36528 L
.53585 .36597 L
.53653 .36643 L
.5372 .36747 L
.53788 .36876 L
.53856 .36975 L
.53923 .37058 L
.53991 .37123 L
.54058 .37145 L
.54126 .37218 L
.54194 .37346 L
.54261 .37449 L
.54329 .37571 L
.54397 .3767 L
.54464 .3772 L
.54532 .37784 L
.546 .37832 L
.54667 .37858 L
.54735 .37876 L
.54802 .3786 L
.5487 .37809 L
.54938 .37794 L
.55005 .37813 L
.55073 .37831 L
.55141 .37882 L
.55208 .37899 L
.55276 .37872 L
.55344 .37871 L
.55411 .37863 L
.55479 .37847 L
.55547 .3784 L
.55614 .37813 L
.55682 .37769 L
.55749 .37742 L
.55817 .37725 L
.55885 .37705 L
.55952 .37695 L
.5602 .3766 L
.56088 .37594 L
.56155 .37526 L
.56223 .37438 L
.56291 .37347 L
.56358 .37261 L
.56426 .37152 L
Mistroke
.56494 .37029 L
.56561 .36939 L
.56629 .3688 L
.56696 .36839 L
.56764 .36839 L
.56832 .36829 L
.56899 .36804 L
.56967 .36819 L
.57035 .36851 L
.57102 .36872 L
.5717 .36893 L
.57238 .36908 L
.57305 .36905 L
.57373 .3694 L
.5744 .37015 L
.57508 .37087 L
.57576 .3718 L
.57643 .37247 L
.57711 .37271 L
.57779 .373 L
.57846 .37306 L
.57914 .37306 L
.57982 .37313 L
.58049 .37284 L
.58117 .3723 L
.58185 .37215 L
.58252 .37234 L
.5832 .37264 L
.58387 .37337 L
.58455 .37378 L
.58523 .3738 L
.5859 .37415 L
.58658 .37446 L
.58726 .37469 L
.58793 .375 L
.58861 .37509 L
.58929 .37497 L
.58996 .37507 L
.59064 .37533 L
.59131 .37551 L
.59199 .37578 L
.59267 .3759 L
.59334 .37578 L
.59402 .37571 L
.5947 .37554 L
.59537 .3753 L
.59605 .37506 L
.59673 .37467 L
.5974 .37414 L
.59808 .37385 L
Mistroke
.59876 .37377 L
.59943 .37377 L
.60011 .37402 L
.60078 .37418 L
.60146 .37422 L
.60214 .3745 L
.60281 .37487 L
.60349 .37512 L
.60417 .3753 L
.60484 .37539 L
.60552 .3753 L
.6062 .37541 L
.60687 .37575 L
.60755 .37598 L
.60823 .37629 L
.6089 .37651 L
.60958 .37655 L
.61025 .37665 L
.61093 .37671 L
.61161 .37669 L
.61228 .37663 L
.61296 .37646 L
.61364 .37616 L
.61431 .376 L
.61499 .37598 L
.61567 .37597 L
.61634 .37608 L
.61702 .37609 L
.61769 .37594 L
.61837 .3759 L
.61905 .37585 L
.61972 .37576 L
.6204 .37569 L
.62108 .37554 L
.62175 .37531 L
.62243 .37516 L
.62311 .37506 L
.62378 .37493 L
.62446 .37483 L
.62514 .37467 L
.62581 .37442 L
.62649 .37417 L
.62716 .37389 L
.62784 .37358 L
.62852 .37328 L
.62919 .37292 L
.62987 .37252 L
.63055 .37221 L
.63122 .372 L
.6319 .37183 L
Mistroke
.63258 .37178 L
.63325 .3717 L
.63393 .37159 L
.6346 .37159 L
.63528 .37163 L
.63596 .37165 L
.63663 .37166 L
.63731 .37165 L
.63799 .37159 L
.63866 .37164 L
.63934 .3718 L
.64002 .37194 L
.64069 .37215 L
.64137 .3723 L
.64205 .37234 L
.64272 .37241 L
.6434 .37244 L
.64407 .37245 L
.64475 .37247 L
.64543 .37242 L
.6461 .3723 L
.64678 .3723 L
.64746 .37239 L
.64813 .37251 L
.64881 .37274 L
.64949 .37291 L
.65016 .37298 L
.65084 .37315 L
.65152 .37331 L
.65219 .37344 L
.65287 .37356 L
.65354 .37362 L
.65422 .37361 L
.6549 .37365 L
.65557 .37373 L
.65625 .37377 L
.65693 .37382 L
.6576 .37384 L
.65828 .37381 L
.65896 .3738 L
.65963 .37378 L
.66031 .37371 L
.66098 .37361 L
.66166 .37348 L
.66234 .37331 L
.66301 .37321 L
.66369 .3732 L
.66437 .3732 L
.66504 .37328 L
.66572 .37334 L
Mistroke
.6664 .37338 L
.66707 .37349 L
.66775 .37366 L
.66843 .37376 L
.6691 .37382 L
.66978 .37385 L
.67045 .37381 L
.67113 .37384 L
.67181 .37395 L
.67248 .37402 L
.67316 .37411 L
.67384 .37418 L
.67451 .3742 L
.67519 .37424 L
.67587 .3743 L
.67654 .37431 L
.67722 .37431 L
.6779 .37428 L
.67857 .37421 L
.67925 .37418 L
.67992 .37421 L
.6806 .37424 L
.68128 .3743 L
.68195 .37434 L
.68263 .37434 L
.68331 .37438 L
.68398 .37442 L
.68466 .37444 L
.68534 .37444 L
.68601 .37442 L
.68669 .37436 L
.68736 .37433 L
.68804 .37432 L
.68872 .37428 L
.68939 .37424 L
.69007 .3742 L
.69075 .37413 L
.69142 .37407 L
.6921 .37401 L
.69278 .37392 L
.69345 .37383 L
.69413 .37372 L
.69481 .37359 L
.69548 .3735 L
.69616 .37344 L
.69683 .3734 L
.69751 .37339 L
.69819 .37337 L
.69886 .37335 L
.69954 .37337 L
Mistroke
.70022 .37341 L
.70089 .37342 L
.70157 .37343 L
.70225 .37343 L
.70292 .37341 L
.7036 .37342 L
.70427 .37347 L
.70495 .37352 L
.70563 .37358 L
.7063 .37362 L
.70698 .37362 L
.70766 .37364 L
.70833 .37364 L
.70901 .37364 L
.70969 .37363 L
.71036 .3736 L
.71104 .37354 L
.71172 .37352 L
.71239 .37353 L
.71307 .37355 L
.71374 .3736 L
.71442 .37363 L
.7151 .37363 L
.71577 .37366 L
.71645 .37369 L
.71713 .3737 L
.7178 .37372 L
.71848 .37372 L
.71916 .3737 L
.71983 .3737 L
.72051 .37372 L
.72119 .37372 L
.72186 .37374 L
.72254 .37374 L
.72321 .37372 L
.72389 .37371 L
.72457 .37369 L
.72524 .37367 L
.72592 .37364 L
.7266 .3736 L
.72727 .37355 L
.72795 .37352 L
.72863 .37351 L
.7293 .37351 L
.72998 .37353 L
.73065 .37354 L
.73133 .37354 L
.73201 .37357 L
.73268 .3736 L
.73336 .37362 L
Mistroke
.73404 .37364 L
.73471 .37364 L
.73539 .37364 L
.73607 .37365 L
.73674 .37368 L
.73742 .3737 L
.7381 .37373 L
.73877 .37375 L
.73945 .37375 L
.74012 .37376 L
.7408 .37377 L
.74148 .37377 L
.74215 .37377 L
.74283 .37376 L
.74351 .37374 L
.74418 .37373 L
.74486 .37373 L
.74554 .37374 L
.74621 .37375 L
.74689 .37376 L
.74756 .37375 L
.74824 .37375 L
.74892 .37376 L
.74959 .37376 L
.75027 .37376 L
.75095 .37376 L
.75162 .37375 L
.7523 .37374 L
.75298 .37375 L
.75365 .37375 L
.75433 .37375 L
.75501 .37375 L
.75568 .37374 L
.75636 .37374 L
.75703 .37373 L
.75771 .37371 L
.75839 .3737 L
.75906 .37369 L
.75974 .37367 L
.76042 .37366 L
.76109 .37365 L
.76177 .37365 L
.76245 .37365 L
.76312 .37365 L
.7638 .37365 L
.76448 .37365 L
.76515 .37366 L
.76583 .37366 L
.7665 .37367 L
.76718 .37367 L
Mistroke
.76786 .37367 L
.76853 .37367 L
.76921 .37368 L
.76989 .37369 L
.77056 .3737 L
.77124 .37371 L
.77192 .37371 L
.77259 .37371 L
.77327 .37371 L
.77394 .37371 L
.77462 .37371 L
.7753 .3737 L
.77597 .3737 L
.77665 .37369 L
.77733 .37369 L
.778 .37369 L
.77868 .3737 L
.77936 .3737 L
.78003 .3737 L
.78071 .3737 L
.78139 .3737 L
.78206 .3737 L
.78274 .3737 L
.78341 .3737 L
.78409 .3737 L
.78477 .3737 L
.78544 .3737 L
.78612 .3737 L
.7868 .3737 L
.78747 .3737 L
.78815 .3737 L
.78883 .3737 L
.7895 .3737 L
.79018 .3737 L
.79085 .37369 L
.79153 .37369 L
.79221 .37369 L
.79288 .37368 L
.79356 .37368 L
.79424 .37368 L
.79491 .37368 L
.79559 .37368 L
.79627 .37368 L
.79694 .37368 L
.79762 .37369 L
.7983 .37369 L
.79897 .37369 L
.79965 .37369 L
.80032 .37369 L
.801 .37369 L
Mistroke
.80168 .37369 L
.80235 .3737 L
.80303 .3737 L
.80371 .3737 L
.80438 .3737 L
.80506 .3737 L
.80574 .3737 L
.80641 .3737 L
.80709 .3737 L
.80777 .3737 L
.80844 .3737 L
.80912 .3737 L
.80979 .3737 L
.81047 .3737 L
.81115 .3737 L
.81182 .3737 L
.8125 .3737 L
.81318 .3737 L
.81385 .3737 L
.81453 .3737 L
.81521 .3737 L
.81588 .3737 L
.81656 .37369 L
.81723 .37369 L
.81791 .3737 L
.81859 .3737 L
.81926 .3737 L
.81994 .3737 L
.82062 .3737 L
.82129 .3737 L
.82197 .3737 L
.82265 .37369 L
.82332 .37369 L
.824 .37369 L
.82468 .37369 L
.82535 .37369 L
.82603 .37369 L
.8267 .37369 L
.82738 .37369 L
.82806 .37369 L
.82873 .37369 L
.82941 .37369 L
.83009 .37369 L
.83076 .37369 L
.83144 .37369 L
.83212 .37369 L
.83279 .37369 L
.83347 .37369 L
.83415 .37369 L
.83482 .37369 L
Mistroke
.8355 .37369 L
.83617 .3737 L
.83685 .3737 L
.83753 .3737 L
.8382 .3737 L
.83888 .3737 L
.83956 .3737 L
.84023 .3737 L
.84091 .37369 L
.84159 .37369 L
.84226 .37369 L
.84294 .37369 L
.84361 .37369 L
.84429 .3737 L
.84497 .37369 L
.84564 .37369 L
.84632 .37369 L
.847 .37369 L
.84767 .37369 L
.84835 .37369 L
.84903 .37369 L
.8497 .37369 L
.85038 .37369 L
.85106 .37369 L
.85173 .3737 L
.85241 .3737 L
.85308 .3737 L
.85376 .3737 L
.85444 .37369 L
.85511 .37369 L
.85579 .37369 L
.85647 .37369 L
.85714 .37369 L
.85782 .37369 L
.8585 .37369 L
.85917 .37369 L
.85985 .37369 L
.86052 .37369 L
.8612 .37369 L
.86188 .37369 L
.86255 .37369 L
.86323 .37369 L
.86391 .37369 L
.86458 .37369 L
.86526 .37369 L
.86594 .37369 L
.86661 .37369 L
.86729 .37369 L
.86797 .37369 L
.86864 .37369 L
Mistroke
.86932 .37369 L
.86999 .37369 L
.87067 .37369 L
.87135 .37369 L
.87202 .37369 L
.8727 .37369 L
.87338 .37369 L
.87405 .37369 L
.87473 .37369 L
.87541 .37369 L
.87608 .37369 L
.87676 .37369 L
.87744 .37369 L
.87811 .37369 L
.87879 .37369 L
.87946 .37369 L
.88014 .37369 L
.88082 .37369 L
.88149 .37369 L
.88217 .37369 L
.88285 .37369 L
.88352 .37369 L
.8842 .37369 L
.88488 .37369 L
.88555 .37369 L
.88623 .37369 L
.8869 .37369 L
.88758 .37369 L
.88826 .37369 L
.88893 .37369 L
.88961 .37369 L
.89029 .37369 L
.89096 .37369 L
.89164 .37369 L
.89232 .37369 L
.89299 .37369 L
.89367 .37369 L
.89435 .37369 L
.89502 .37369 L
.8957 .37369 L
.89637 .37369 L
.89705 .37369 L
.89773 .37369 L
.8984 .37369 L
.89908 .37369 L
.89976 .37369 L
.90043 .37369 L
.90111 .37369 L
.90179 .37369 L
.90246 .37369 L
Mistroke
.90314 .37369 L
.90381 .37369 L
.90449 .37369 L
.90517 .37369 L
.90584 .37369 L
.90652 .37369 L
.9072 .37369 L
.90787 .37369 L
.90855 .37369 L
.90923 .37369 L
.9099 .37369 L
.91058 .37369 L
.91126 .37369 L
.91193 .37369 L
.91261 .37369 L
.91328 .37369 L
.91396 .37369 L
.91464 .37369 L
.91531 .37369 L
.91599 .37369 L
.91667 .37369 L
.91734 .37369 L
.91802 .37369 L
.9187 .37369 L
.91937 .37369 L
.92005 .37369 L
.92073 .37369 L
.9214 .37369 L
.92208 .37369 L
.92275 .37369 L
.92343 .37369 L
.92411 .37369 L
.92478 .37369 L
.92546 .37369 L
.92614 .37369 L
.92681 .37369 L
.92749 .37369 L
.92817 .37369 L
.92884 .37369 L
.92952 .37369 L
.93019 .37369 L
.93087 .37369 L
.93155 .37369 L
.93222 .37369 L
.9329 .37369 L
.93358 .37369 L
.93425 .37369 L
.93493 .37369 L
.93561 .37369 L
.93628 .37369 L
Mistroke
.93696 .37369 L
.93764 .37369 L
.93831 .37369 L
.93899 .37369 L
.93966 .37369 L
.94034 .37369 L
.94102 .37369 L
.94169 .37369 L
.94237 .37369 L
.94305 .37369 L
.94372 .37369 L
.9444 .37369 L
.94508 .37369 L
.94575 .37369 L
.94643 .37369 L
.9471 .37369 L
.94778 .37369 L
.94846 .37369 L
.94913 .37369 L
.94981 .37369 L
.95049 .37369 L
.95116 .37369 L
.95184 .37369 L
.95252 .37369 L
.95319 .37369 L
.95387 .37369 L
.95455 .37369 L
.95522 .37369 L
.9559 .37369 L
.95657 .37369 L
.95725 .37369 L
.95793 .37369 L
.9586 .37369 L
.95928 .37369 L
.95996 .37369 L
.96063 .37369 L
.96131 .37369 L
.96199 .37369 L
.96266 .37369 L
.96334 .37369 L
.96402 .37369 L
.96469 .37369 L
.96537 .37369 L
.96604 .37369 L
.96672 .37369 L
.9674 .37369 L
.96807 .37369 L
.96875 .37369 L
.96943 .37369 L
.9701 .37369 L
Mistroke
.97078 .37369 L
.97146 .37369 L
.97213 .37369 L
.97281 .37369 L
.97348 .37369 L
.97416 .37369 L
.97484 .37369 L
.97551 .37369 L
.97619 .37369 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.4"]
}, Open  ]],

Cell["\<\
The second derivative of the least asymmetric wavelet of order 10 \
is plotted here.\
\>", "MathCaption",
  CellTags->{"S3.1.4", "4.10"}],

Cell[CellGroupData[{

Cell["\<\
ListPlot[DWavelet[LeastAsymmetricFilter[10], 7, 2],
PlotJoined -> True, PlotRange -> {{-5, 5}, All},
AxesLabel -> {\"t\", \"\"}, PlotLabel -> \"psi''(t)\"]\
\>", "Input",
  CellLabel->"In[64]:= ",
  CellTags->"S3.1.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.339821 0.00798748 [
[.1 .32732 -6 -9 ]
[.1 .32732 6 0 ]
[.3 .32732 -6 -9 ]
[.3 .32732 6 0 ]
[.7 .32732 -3 -9 ]
[.7 .32732 3 0 ]
[.9 .32732 -3 -9 ]
[.9 .32732 3 0 ]
[1.025 .33982 0 -4.5 ]
[1.025 .33982 6 4.5 ]
[.4875 .02032 -18 -4.5 ]
[.4875 .02032 0 4.5 ]
[.4875 .1002 -18 -4.5 ]
[.4875 .1002 0 4.5 ]
[.4875 .18007 -18 -4.5 ]
[.4875 .18007 0 4.5 ]
[.4875 .25995 -18 -4.5 ]
[.4875 .25995 0 4.5 ]
[.4875 .4197 -12 -4.5 ]
[.4875 .4197 0 4.5 ]
[.4875 .49957 -12 -4.5 ]
[.4875 .49957 0 4.5 ]
[.4875 .57945 -12 -4.5 ]
[.4875 .57945 0 4.5 ]
[.5 .63053 -24 0 ]
[.5 .63053 24 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 .33982 m
.1 .34607 L
s
[(-4)] .1 .32732 0 1 Mshowa
.3 .33982 m
.3 .34607 L
s
[(-2)] .3 .32732 0 1 Mshowa
.7 .33982 m
.7 .34607 L
s
[(2)] .7 .32732 0 1 Mshowa
.9 .33982 m
.9 .34607 L
s
[(4)] .9 .32732 0 1 Mshowa
.125 Mabswid
.15 .33982 m
.15 .34357 L
s
.2 .33982 m
.2 .34357 L
s
.25 .33982 m
.25 .34357 L
s
.35 .33982 m
.35 .34357 L
s
.4 .33982 m
.4 .34357 L
s
.45 .33982 m
.45 .34357 L
s
.55 .33982 m
.55 .34357 L
s
.6 .33982 m
.6 .34357 L
s
.65 .33982 m
.65 .34357 L
s
.75 .33982 m
.75 .34357 L
s
.8 .33982 m
.8 .34357 L
s
.85 .33982 m
.85 .34357 L
s
.05 .33982 m
.05 .34357 L
s
.95 .33982 m
.95 .34357 L
s
.25 Mabswid
0 .33982 m
1 .33982 L
s
[(t)] 1.025 .33982 -1 0 Mshowa
.5 .02032 m
.50625 .02032 L
s
[(-40)] .4875 .02032 1 0 Mshowa
.5 .1002 m
.50625 .1002 L
s
[(-30)] .4875 .1002 1 0 Mshowa
.5 .18007 m
.50625 .18007 L
s
[(-20)] .4875 .18007 1 0 Mshowa
.5 .25995 m
.50625 .25995 L
s
[(-10)] .4875 .25995 1 0 Mshowa
.5 .4197 m
.50625 .4197 L
s
[(10)] .4875 .4197 1 0 Mshowa
.5 .49957 m
.50625 .49957 L
s
[(20)] .4875 .49957 1 0 Mshowa
.5 .57945 m
.50625 .57945 L
s
[(30)] .4875 .57945 1 0 Mshowa
.125 Mabswid
.5 .0363 m
.50375 .0363 L
s
.5 .05227 m
.50375 .05227 L
s
.5 .06825 m
.50375 .06825 L
s
.5 .08422 m
.50375 .08422 L
s
.5 .11617 m
.50375 .11617 L
s
.5 .13215 m
.50375 .13215 L
s
.5 .14812 m
.50375 .14812 L
s
.5 .1641 m
.50375 .1641 L
s
.5 .19605 m
.50375 .19605 L
s
.5 .21202 m
.50375 .21202 L
s
.5 .228 m
.50375 .228 L
s
.5 .24397 m
.50375 .24397 L
s
.5 .27592 m
.50375 .27592 L
s
.5 .2919 m
.50375 .2919 L
s
.5 .30787 m
.50375 .30787 L
s
.5 .32385 m
.50375 .32385 L
s
.5 .3558 m
.50375 .3558 L
s
.5 .37177 m
.50375 .37177 L
s
.5 .38775 m
.50375 .38775 L
s
.5 .40372 m
.50375 .40372 L
s
.5 .43567 m
.50375 .43567 L
s
.5 .45165 m
.50375 .45165 L
s
.5 .46762 m
.50375 .46762 L
s
.5 .4836 m
.50375 .4836 L
s
.5 .51555 m
.50375 .51555 L
s
.5 .53152 m
.50375 .53152 L
s
.5 .5475 m
.50375 .5475 L
s
.5 .56347 m
.50375 .56347 L
s
.5 .00435 m
.50375 .00435 L
s
.5 .59542 m
.50375 .59542 L
s
.5 .6114 m
.50375 .6114 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
[(psi''\\(t\\))] .5 .63053 0 -1 Mshowa
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .33984 m
.00078 .33983 L
.00156 .33983 L
.00234 .33983 L
.00312 .33983 L
.00391 .33982 L
.00469 .33982 L
.00547 .33982 L
.00625 .33982 L
.00703 .33981 L
.00781 .33981 L
.00859 .33981 L
.00937 .3398 L
.01016 .3398 L
.01094 .33979 L
.01172 .33979 L
.0125 .33979 L
.01328 .33979 L
.01406 .33979 L
.01484 .33979 L
.01562 .33979 L
.01641 .33979 L
.01719 .33979 L
.01797 .33979 L
.01875 .33979 L
.01953 .33979 L
.02031 .33979 L
.02109 .33979 L
.02187 .33979 L
.02266 .33979 L
.02344 .33979 L
.02422 .33979 L
.025 .33979 L
.02578 .33979 L
.02656 .33978 L
.02734 .33978 L
.02812 .33977 L
.02891 .33976 L
.02969 .33976 L
.03047 .33975 L
.03125 .33975 L
.03203 .33974 L
.03281 .33974 L
.03359 .33974 L
.03437 .33974 L
.03516 .33974 L
.03594 .33974 L
.03672 .33973 L
.0375 .33973 L
.03828 .33973 L
Mistroke
.03906 .33972 L
.03984 .33971 L
.04062 .3397 L
.04141 .3397 L
.04219 .3397 L
.04297 .33969 L
.04375 .33969 L
.04453 .33969 L
.04531 .33968 L
.04609 .33968 L
.04687 .33968 L
.04766 .33967 L
.04844 .33967 L
.04922 .33967 L
.05 .33967 L
.05078 .33968 L
.05156 .33969 L
.05234 .3397 L
.05312 .33971 L
.05391 .33972 L
.05469 .33973 L
.05547 .33975 L
.05625 .33977 L
.05703 .33978 L
.05781 .33979 L
.05859 .3398 L
.05937 .33981 L
.06016 .33982 L
.06094 .33984 L
.06172 .33985 L
.0625 .33987 L
.06328 .33988 L
.06406 .33989 L
.06484 .3399 L
.06562 .33992 L
.06641 .33993 L
.06719 .33994 L
.06797 .33994 L
.06875 .33995 L
.06953 .33997 L
.07031 .33999 L
.07109 .34 L
.07187 .34002 L
.07266 .34003 L
.07344 .34004 L
.07422 .34005 L
.075 .34006 L
.07578 .34007 L
.07656 .34007 L
.07734 .34007 L
Mistroke
.07812 .34007 L
.07891 .34008 L
.07969 .34008 L
.08047 .34008 L
.08125 .34008 L
.08203 .34008 L
.08281 .34008 L
.08359 .34008 L
.08437 .34008 L
.08516 .34007 L
.08594 .34007 L
.08672 .34007 L
.0875 .34006 L
.08828 .34007 L
.08906 .34008 L
.08984 .34009 L
.09062 .3401 L
.09141 .34011 L
.09219 .34011 L
.09297 .34012 L
.09375 .34013 L
.09453 .34014 L
.09531 .34014 L
.09609 .34014 L
.09687 .34014 L
.09766 .34014 L
.09844 .34015 L
.09922 .34015 L
.1 .34015 L
.10078 .34015 L
.10156 .34014 L
.10234 .34014 L
.10312 .34014 L
.10391 .34013 L
.10469 .34012 L
.10547 .34011 L
.10625 .3401 L
.10703 .34011 L
.10781 .34011 L
.10859 .34011 L
.10937 .34011 L
.11016 .34011 L
.11094 .34011 L
.11172 .34011 L
.1125 .34011 L
.11328 .34009 L
.11406 .34007 L
.11484 .34005 L
.11562 .34003 L
.11641 .34002 L
Mistroke
.11719 .34001 L
.11797 .33999 L
.11875 .33997 L
.11953 .33995 L
.12031 .33993 L
.12109 .33992 L
.12187 .33991 L
.12266 .33989 L
.12344 .33987 L
.12422 .33986 L
.125 .33984 L
.12578 .33985 L
.12656 .33987 L
.12734 .33988 L
.12812 .3399 L
.12891 .33991 L
.12969 .33993 L
.13047 .33995 L
.13125 .33997 L
.13203 .33997 L
.13281 .33998 L
.13359 .33998 L
.13437 .33998 L
.13516 .33999 L
.13594 .34001 L
.13672 .34001 L
.1375 .34002 L
.13828 .34003 L
.13906 .34003 L
.13984 .34005 L
.14062 .34006 L
.14141 .34005 L
.14219 .34005 L
.14297 .34004 L
.14375 .34004 L
.14453 .34005 L
.14531 .34007 L
.14609 .34007 L
.14687 .34008 L
.14766 .34008 L
.14844 .34008 L
.14922 .34008 L
.15 .34007 L
.15078 .34004 L
.15156 .34 L
.15234 .33996 L
.15312 .3399 L
.15391 .33987 L
.15469 .33983 L
.15547 .33978 L
Mistroke
.15625 .33973 L
.15703 .33969 L
.15781 .33963 L
.15859 .33959 L
.15937 .33954 L
.16016 .33948 L
.16094 .33942 L
.16172 .33937 L
.1625 .33931 L
.16328 .33929 L
.16406 .33926 L
.16484 .33923 L
.16562 .33921 L
.16641 .33919 L
.16719 .33916 L
.16797 .33914 L
.16875 .33912 L
.16953 .33908 L
.17031 .33904 L
.17109 .339 L
.17187 .33895 L
.17266 .33892 L
.17344 .33889 L
.17422 .33885 L
.175 .33882 L
.17578 .33878 L
.17656 .33874 L
.17734 .33872 L
.17812 .33869 L
.17891 .33864 L
.17969 .33859 L
.18047 .33855 L
.18125 .33851 L
.18203 .3385 L
.18281 .33849 L
.18359 .33847 L
.18437 .33846 L
.18516 .33845 L
.18594 .33842 L
.18672 .33842 L
.1875 .3384 L
.18828 .33835 L
.18906 .3383 L
.18984 .33825 L
.19062 .33819 L
.19141 .33816 L
.19219 .33814 L
.19297 .33809 L
.19375 .33806 L
.19453 .33803 L
Mistroke
.19531 .33799 L
.19609 .33797 L
.19687 .33796 L
.19766 .33792 L
.19844 .3379 L
.19922 .33788 L
.2 .33787 L
.20078 .33791 L
.20156 .33796 L
.20234 .338 L
.20312 .33806 L
.20391 .33813 L
.20469 .33818 L
.20547 .33826 L
.20625 .33834 L
.20703 .33838 L
.20781 .33842 L
.20859 .33847 L
.20937 .33851 L
.21016 .33858 L
.21094 .33866 L
.21172 .33872 L
.2125 .33879 L
.21328 .33886 L
.21406 .33892 L
.21484 .33901 L
.21562 .33909 L
.21641 .33914 L
.21719 .33919 L
.21797 .33925 L
.21875 .33931 L
.21953 .33941 L
.22031 .33951 L
.22109 .3396 L
.22187 .33969 L
.22266 .33978 L
.22344 .33985 L
.22422 .33994 L
.225 .34001 L
.22578 .34003 L
.22656 .34004 L
.22734 .34004 L
.22812 .34002 L
.22891 .34004 L
.22969 .34006 L
.23047 .34006 L
.23125 .34006 L
.23203 .34006 L
.23281 .34004 L
.23359 .34006 L
Mistroke
.23437 .34007 L
.23516 .34004 L
.23594 .34003 L
.23672 .34002 L
.2375 .34002 L
.23828 .34008 L
.23906 .34015 L
.23984 .34021 L
.24062 .34029 L
.24141 .34036 L
.24219 .34043 L
.24297 .34052 L
.24375 .3406 L
.24453 .34063 L
.24531 .34067 L
.24609 .3407 L
.24687 .34072 L
.24766 .34079 L
.24844 .34086 L
.24922 .34091 L
.25 .34096 L
.25078 .341 L
.25156 .34102 L
.25234 .34107 L
.25312 .34111 L
.25391 .34112 L
.25469 .34113 L
.25547 .34114 L
.25625 .34116 L
.25703 .34125 L
.25781 .34135 L
.25859 .34142 L
.25937 .34151 L
.26016 .34158 L
.26094 .34163 L
.26172 .34172 L
.2625 .34178 L
.26328 .34177 L
.26406 .34177 L
.26484 .34173 L
.26562 .34169 L
.26641 .34173 L
.26719 .34176 L
.26797 .34176 L
.26875 .34178 L
.26953 .34175 L
.27031 .34169 L
.27109 .34171 L
.27187 .34171 L
.27266 .34167 L
Mistroke
.27344 .34168 L
.27422 .34168 L
.275 .3417 L
.27578 .34188 L
.27656 .34208 L
.27734 .34228 L
.27812 .34252 L
.27891 .34271 L
.27969 .34288 L
.28047 .34312 L
.28125 .34334 L
.28203 .34352 L
.28281 .34372 L
.28359 .34387 L
.28437 .34401 L
.28516 .34425 L
.28594 .34446 L
.28672 .34464 L
.2875 .34482 L
.28828 .34487 L
.28906 .34487 L
.28984 .34493 L
.29062 .34494 L
.29141 .34491 L
.29219 .34492 L
.29297 .34486 L
.29375 .34481 L
.29453 .34491 L
.29531 .345 L
.29609 .34507 L
.29687 .34518 L
.29766 .34516 L
.29844 .34512 L
.29922 .34516 L
.3 .34514 L
.30078 .34509 L
.30156 .34508 L
.30234 .34496 L
.30312 .34485 L
.30391 .34488 L
.30469 .34486 L
.30547 .34482 L
.30625 .34478 L
.30703 .34452 L
.30781 .34421 L
.30859 .344 L
.30937 .34373 L
.31016 .34346 L
.31094 .34327 L
.31172 .34298 L
Mistroke
.3125 .34275 L
.31328 .34279 L
.31406 .34284 L
.31484 .34293 L
.31562 .34308 L
.31641 .34297 L
.31719 .34286 L
.31797 .34287 L
.31875 .34281 L
.31953 .34284 L
.32031 .34293 L
.32109 .34281 L
.32187 .3427 L
.32266 .34277 L
.32344 .34268 L
.32422 .34261 L
.325 .34245 L
.32578 .34181 L
.32656 .34105 L
.32734 .34035 L
.32812 .33949 L
.32891 .33876 L
.32969 .33809 L
.33047 .33717 L
.33125 .33634 L
.33203 .3357 L
.33281 .335 L
.33359 .33445 L
.33437 .33393 L
.33516 .33307 L
.33594 .33227 L
.33672 .33161 L
.3375 .33092 L
.33828 .33056 L
.33906 .33034 L
.33984 .32993 L
.34062 .32965 L
.34141 .32956 L
.34219 .32937 L
.34297 .32934 L
.34375 .32928 L
.34453 .32874 L
.34531 .32819 L
.34609 .32775 L
.34687 .32722 L
.34766 .32698 L
.34844 .3269 L
.34922 .32657 L
.35 .32642 L
.35078 .32655 L
Mistroke
.35156 .32661 L
.35234 .32697 L
.35312 .32738 L
.35391 .32727 L
.35469 .3273 L
.35547 .32749 L
.35625 .32764 L
.35703 .32842 L
.35781 .3294 L
.35859 .32997 L
.35937 .33075 L
.36016 .33166 L
.36094 .33227 L
.36172 .33318 L
.3625 .33389 L
.36328 .33358 L
.36406 .33321 L
.36484 .3328 L
.36562 .33213 L
.36641 .33219 L
.36719 .33234 L
.36797 .33201 L
.36875 .33193 L
.36953 .33182 L
.37031 .3315 L
.37109 .33184 L
.37187 .33216 L
.37266 .33181 L
.37344 .33186 L
.37422 .33202 L
.375 .33233 L
.37578 .33408 L
.37656 .33621 L
.37734 .33802 L
.37812 .34033 L
.37891 .34252 L
.37969 .34447 L
.38047 .34709 L
.38125 .34951 L
.38203 .35097 L
.38281 .35254 L
.38359 .3539 L
.38437 .35505 L
.38516 .35715 L
.38594 .35925 L
.38672 .36079 L
.3875 .36251 L
.38828 .36384 L
.38906 .36477 L
.38984 .3663 L
Mistroke
.39062 .36756 L
.39141 .36791 L
.39219 .36851 L
.39297 .36888 L
.39375 .36918 L
.39453 .37088 L
.39531 .3727 L
.39609 .37384 L
.39687 .37528 L
.39766 .37623 L
.39844 .37656 L
.39922 .37748 L
.4 .37781 L
.40078 .3766 L
.40156 .37535 L
.40234 .37346 L
.40312 .37115 L
.40391 .37023 L
.40469 .36909 L
.40547 .36713 L
.40625 .36536 L
.40703 .36251 L
.40781 .35909 L
.40859 .35677 L
.40937 .35403 L
.41016 .35039 L
.41094 .34747 L
.41172 .3441 L
.4125 .34109 L
.41328 .34083 L
.41406 .34088 L
.41484 .3407 L
.41562 .34126 L
.41641 .34052 L
.41719 .3394 L
.41797 .33956 L
.41875 .33911 L
.41953 .33794 L
.42031 .33716 L
.42109 .33515 L
.42187 .33298 L
.42266 .33266 L
.42344 .3317 L
.42422 .33013 L
.425 .32847 L
.42578 .32418 L
.42656 .31901 L
.42734 .31487 L
.42812 .30975 L
.42891 .30417 L
Mistroke
.42969 .29924 L
.43047 .29313 L
.43125 .28738 L
.43203 .28437 L
.43281 .28138 L
.43359 .27828 L
.43437 .27588 L
.43516 .27176 L
.43594 .26727 L
.43672 .26427 L
.4375 .26066 L
.43828 .25657 L
.43906 .25319 L
.43984 .24861 L
.44062 .24428 L
.44141 .24255 L
.44219 .24052 L
.44297 .23834 L
.44375 .23665 L
.44453 .23238 L
.44531 .2277 L
.44609 .22508 L
.44687 .22196 L
.44766 .21893 L
.44844 .21755 L
.44922 .2153 L
.45 .21435 L
.45078 .21795 L
.45156 .22218 L
.45234 .22716 L
.45312 .23361 L
.45391 .23761 L
.45469 .24175 L
.45547 .24823 L
.45625 .2542 L
.45703 .26086 L
.45781 .26871 L
.45859 .27458 L
.45937 .28095 L
.46016 .29009 L
.46094 .29816 L
.46172 .30636 L
.4625 .31432 L
.46328 .31741 L
.46406 .31961 L
.46484 .32298 L
.46562 .32491 L
.46641 .32801 L
.46719 .33209 L
.46797 .33393 L
Mistroke
.46875 .33673 L
.46953 .3423 L
.47031 .34746 L
.47109 .35392 L
.47187 .36103 L
.47266 .36484 L
.47344 .36907 L
.47422 .37493 L
.475 .38041 L
.47578 .38846 L
.47656 .39786 L
.47734 .40522 L
.47812 .41367 L
.47891 .42412 L
.47969 .43347 L
.48047 .44388 L
.48125 .45397 L
.48203 .45921 L
.48281 .46393 L
.48359 .46977 L
.48437 .47426 L
.48516 .48046 L
.48594 .48778 L
.48672 .4926 L
.4875 .49857 L
.48828 .50746 L
.48906 .51561 L
.48984 .52518 L
.49062 .53503 L
.49141 .54023 L
.49219 .54548 L
.49297 .55195 L
.49375 .55722 L
.49453 .56529 L
.49531 .57417 L
.49609 .57926 L
.49687 .58483 L
.49766 .59171 L
.49844 .59581 L
.49922 .60049 L
.5 .60332 L
.50078 .59797 L
.50156 .59098 L
.50234 .58372 L
.50313 .57365 L
.50391 .56625 L
.50469 .55908 L
.50547 .54779 L
.50625 .5373 L
.50703 .52797 L
Mistroke
.50781 .51698 L
.50859 .50828 L
.50938 .49934 L
.51016 .48539 L
.51094 .47234 L
.51172 .4601 L
.5125 .44756 L
.51328 .44058 L
.51406 .4351 L
.51484 .42713 L
.51563 .42098 L
.51641 .41506 L
.51719 .40758 L
.51797 .4026 L
.51875 .39663 L
.51953 .38537 L
.52031 .37415 L
.52109 .36261 L
.52188 .34978 L
.52266 .34078 L
.52344 .33222 L
.52422 .32101 L
.525 .31093 L
.52578 .30068 L
.52656 .28916 L
.52734 .28026 L
.52813 .27092 L
.52891 .25776 L
.52969 .24577 L
.53047 .23393 L
.53125 .22199 L
.53203 .21559 L
.53281 .21036 L
.53359 .20271 L
.53438 .19674 L
.53516 .19049 L
.53594 .18242 L
.53672 .17699 L
.5375 .1702 L
.53828 .15758 L
.53906 .14518 L
.53984 .13197 L
.54063 .11762 L
.54141 .10863 L
.54219 .10014 L
.54297 .08913 L
.54375 .07987 L
.54453 .06941 L
.54531 .05794 L
.54609 .05095 L
Mistroke
.54688 .04389 L
.54766 .03374 L
.54844 .02659 L
.54922 .01982 L
.55 .01472 L
.55078 .01909 L
.55156 .02588 L
.55234 .03193 L
.55313 .04142 L
.55391 .04944 L
.55469 .0568 L
.55547 .06883 L
.55625 .08006 L
.55703 .0878 L
.55781 .09701 L
.55859 .10472 L
.55938 .11212 L
.56016 .12535 L
.56094 .13843 L
.56172 .14964 L
.5625 .16188 L
.56328 .1704 L
.56406 .17732 L
.56484 .18742 L
.56563 .19612 L
.56641 .20261 L
.56719 .21074 L
.56797 .21731 L
.56875 .22438 L
.56953 .23775 L
.57031 .25164 L
.57109 .2643 L
.57188 .27855 L
.57266 .29015 L
.57344 .30031 L
.57422 .31328 L
.575 .32462 L
.57578 .33272 L
.57656 .34137 L
.57734 .34788 L
.57813 .3537 L
.57891 .36398 L
.57969 .37359 L
.58047 .38145 L
.58125 .3899 L
.58203 .39456 L
.58281 .39773 L
.58359 .40389 L
.58438 .40874 L
.58516 .4118 L
Mistroke
.58594 .41676 L
.58672 .4201 L
.5875 .42443 L
.58828 .43566 L
.58906 .44744 L
.58984 .45886 L
.59063 .472 L
.59141 .48129 L
.59219 .48962 L
.59297 .50096 L
.59375 .51065 L
.59453 .51905 L
.59531 .52826 L
.59609 .5341 L
.59688 .53949 L
.59766 .54872 L
.59844 .55598 L
.59922 .5619 L
.6 .56709 L
.60078 .56535 L
.60156 .56136 L
.60234 .55888 L
.60313 .55374 L
.60391 .54818 L
.60469 .54347 L
.60547 .53541 L
.60625 .52782 L
.60703 .52465 L
.60781 .52079 L
.60859 .51705 L
.60938 .51406 L
.61016 .50678 L
.61094 .49888 L
.61172 .49312 L
.6125 .48608 L
.61328 .47952 L
.61406 .47403 L
.61484 .466 L
.61563 .45842 L
.61641 .45395 L
.61719 .44844 L
.61797 .44301 L
.61875 .4377 L
.61953 .42773 L
.62031 .41694 L
.62109 .40824 L
.62188 .39833 L
.62266 .38899 L
.62344 .38137 L
.62422 .37192 L
Mistroke
.625 .36387 L
.62578 .36071 L
.62656 .35783 L
.62734 .35586 L
.62813 .35529 L
.62891 .35143 L
.62969 .3476 L
.63047 .3462 L
.63125 .34404 L
.63203 .3428 L
.63281 .34279 L
.63359 .34046 L
.63438 .33866 L
.63516 .33965 L
.63594 .33945 L
.63672 .33944 L
.6375 .33912 L
.63828 .3337 L
.63906 .32735 L
.63984 .32214 L
.64063 .31544 L
.64141 .31002 L
.64219 .30556 L
.64297 .29887 L
.64375 .29316 L
.64453 .2901 L
.64531 .2867 L
.64609 .28462 L
.64688 .28323 L
.64766 .27892 L
.64844 .27512 L
.64922 .27285 L
.65 .27041 L
.65078 .27046 L
.65156 .2718 L
.65234 .27171 L
.65313 .27274 L
.65391 .27527 L
.65469 .27718 L
.65547 .28025 L
.65625 .28328 L
.65703 .28308 L
.65781 .28279 L
.65859 .28331 L
.65938 .28309 L
.66016 .28448 L
.66094 .2867 L
.66172 .28748 L
.6625 .28916 L
.66328 .29249 L
Mistroke
.66406 .29551 L
.66484 .29963 L
.66563 .30407 L
.66641 .30616 L
.66719 .3085 L
.66797 .31167 L
.66875 .31441 L
.66953 .3189 L
.67031 .32404 L
.67109 .32749 L
.67188 .33142 L
.67266 .33617 L
.67344 .33979 L
.67422 .34391 L
.675 .34736 L
.67578 .34711 L
.67656 .34624 L
.67734 .34548 L
.67813 .34353 L
.67891 .34286 L
.67969 .34248 L
.68047 .34034 L
.68125 .33869 L
.68203 .33794 L
.68281 .3366 L
.68359 .33624 L
.68438 .33594 L
.68516 .33351 L
.68594 .33141 L
.68672 .32987 L
.6875 .32816 L
.68828 .32851 L
.68906 .32953 L
.68984 .32952 L
.69063 .33023 L
.69141 .33137 L
.69219 .33193 L
.69297 .33338 L
.69375 .33456 L
.69453 .33361 L
.69531 .33262 L
.69609 .33177 L
.69688 .3304 L
.69766 .33023 L
.69844 .33038 L
.69922 .32956 L
.7 .32921 L
.70078 .32933 L
.70156 .32912 L
.70234 .32964 L
Mistroke
.70313 .33018 L
.70391 .32945 L
.70469 .32893 L
.70547 .32867 L
.70625 .32825 L
.70703 .32903 L
.70781 .33015 L
.70859 .33049 L
.70938 .33118 L
.71016 .3321 L
.71094 .3325 L
.71172 .33336 L
.7125 .33391 L
.71328 .33279 L
.71406 .33154 L
.71484 .33026 L
.71563 .32854 L
.71641 .3277 L
.71719 .32702 L
.71797 .32559 L
.71875 .32448 L
.71953 .32357 L
.72031 .32241 L
.72109 .32193 L
.72188 .32147 L
.72266 .32011 L
.72344 .31909 L
.72422 .3183 L
.725 .31757 L
.72578 .31822 L
.72656 .31928 L
.72734 .31995 L
.72813 .32111 L
.72891 .32234 L
.72969 .32334 L
.73047 .32496 L
.73125 .32645 L
.73203 .32697 L
.73281 .32757 L
.73359 .32814 L
.73438 .32851 L
.73516 .32967 L
.73594 .33094 L
.73672 .33175 L
.7375 .33279 L
.73828 .33381 L
.73906 .33461 L
.73984 .33586 L
.74063 .33703 L
.74141 .33755 L
Mistroke
.74219 .33823 L
.74297 .33892 L
.74375 .33955 L
.74453 .34095 L
.74531 .3425 L
.74609 .34362 L
.74688 .34494 L
.74766 .34622 L
.74844 .34718 L
.74922 .34842 L
.75 .34941 L
.75078 .34947 L
.75156 .34943 L
.75234 .3493 L
.75313 .34888 L
.75391 .34892 L
.75469 .34901 L
.75547 .34863 L
.75625 .34839 L
.75703 .3482 L
.75781 .34783 L
.75859 .34777 L
.75938 .34767 L
.76016 .34704 L
.76094 .34654 L
.76172 .3461 L
.7625 .34565 L
.76328 .34584 L
.76406 .3462 L
.76484 .34631 L
.76563 .34663 L
.76641 .34697 L
.76719 .34716 L
.76797 .34763 L
.76875 .348 L
.76953 .34784 L
.77031 .34769 L
.77109 .34753 L
.77188 .34724 L
.77266 .3473 L
.77344 .34742 L
.77422 .34729 L
.775 .34729 L
.77578 .34733 L
.77656 .34728 L
.77734 .34742 L
.77813 .34755 L
.77891 .34736 L
.77969 .34724 L
.78047 .34715 L
Mistroke
.78125 .34702 L
.78203 .34721 L
.78281 .34748 L
.78359 .34755 L
.78438 .34772 L
.78516 .34791 L
.78594 .34797 L
.78672 .34815 L
.7875 .34825 L
.78828 .34796 L
.78906 .34763 L
.78984 .34729 L
.79063 .34684 L
.79141 .34659 L
.79219 .34637 L
.79297 .34597 L
.79375 .34564 L
.79453 .34537 L
.79531 .34502 L
.79609 .34482 L
.79688 .34462 L
.79766 .34421 L
.79844 .34386 L
.79922 .34356 L
.8 .34326 L
.80078 .34324 L
.80156 .34331 L
.80234 .34327 L
.80313 .34334 L
.80391 .34343 L
.80469 .34347 L
.80547 .34363 L
.80625 .34376 L
.80703 .34366 L
.80781 .34356 L
.80859 .34348 L
.80938 .34334 L
.81016 .34335 L
.81094 .3434 L
.81172 .34335 L
.8125 .34335 L
.81328 .34339 L
.81406 .34339 L
.81484 .34348 L
.81563 .34357 L
.81641 .3435 L
.81719 .34346 L
.81797 .34344 L
.81875 .34339 L
.81953 .34349 L
Mistroke
.82031 .34363 L
.82109 .34366 L
.82188 .34372 L
.82266 .34382 L
.82344 .34384 L
.82422 .3439 L
.825 .34392 L
.82578 .34369 L
.82656 .34344 L
.82734 .34319 L
.82813 .34286 L
.82891 .34261 L
.82969 .34238 L
.83047 .34204 L
.83125 .34174 L
.83203 .34151 L
.83281 .34124 L
.83359 .34103 L
.83438 .34082 L
.83516 .34049 L
.83594 .34017 L
.83672 .33989 L
.8375 .3396 L
.83828 .3394 L
.83906 .33925 L
.83984 .33903 L
.84063 .33885 L
.84141 .33873 L
.84219 .33858 L
.84297 .33848 L
.84375 .33838 L
.84453 .33813 L
.84531 .33788 L
.84609 .33767 L
.84688 .33744 L
.84766 .33725 L
.84844 .33712 L
.84922 .33693 L
.85 .33679 L
.85078 .33677 L
.85156 .33675 L
.85234 .33677 L
.85313 .33683 L
.85391 .3368 L
.85469 .33678 L
.85547 .33682 L
.85625 .33684 L
.85703 .3369 L
.85781 .33699 L
.85859 .33702 L
Mistroke
.85938 .33708 L
.86016 .3372 L
.86094 .3373 L
.86172 .3374 L
.8625 .3375 L
.86328 .33748 L
.86406 .33744 L
.86484 .33744 L
.86563 .3374 L
.86641 .33737 L
.86719 .33737 L
.86797 .33732 L
.86875 .33729 L
.86953 .33734 L
.87031 .33738 L
.87109 .33744 L
.87188 .33752 L
.87266 .33753 L
.87344 .33753 L
.87422 .33758 L
.875 .33761 L
.87578 .33765 L
.87656 .33771 L
.87734 .33773 L
.87813 .33776 L
.87891 .33784 L
.87969 .33791 L
.88047 .33798 L
.88125 .33806 L
.88203 .33807 L
.88281 .33806 L
.88359 .33809 L
.88438 .33809 L
.88516 .33811 L
.88594 .33814 L
.88672 .33815 L
.8875 .33818 L
.88828 .33829 L
.88906 .3384 L
.88984 .33852 L
.89063 .33865 L
.89141 .33874 L
.89219 .33882 L
.89297 .33893 L
.89375 .33903 L
.89453 .33913 L
.89531 .33925 L
.89609 .33932 L
.89688 .3394 L
.89766 .33952 L
Mistroke
.89844 .33961 L
.89922 .3397 L
.9 .33979 L
.90078 .33979 L
.90156 .33977 L
.90234 .33977 L
.90313 .33974 L
.90391 .3397 L
.90469 .33969 L
.90547 .33963 L
.90625 .33958 L
.90703 .33959 L
.90781 .33959 L
.90859 .33959 L
.90938 .33961 L
.91016 .33958 L
.91094 .33954 L
.91172 .33952 L
.9125 .33949 L
.91328 .33947 L
.91406 .33945 L
.91484 .33941 L
.91563 .33937 L
.91641 .33937 L
.91719 .33936 L
.91797 .33935 L
.91875 .33935 L
.91953 .33929 L
.92031 .33923 L
.92109 .33919 L
.92188 .33915 L
.92266 .3391 L
.92344 .33908 L
.92422 .33903 L
.925 .33901 L
.92578 .33905 L
.92656 .3391 L
.92734 .33915 L
.92813 .33922 L
.92891 .33926 L
.92969 .3393 L
.93047 .33937 L
.93125 .33944 L
.93203 .33949 L
.93281 .33955 L
.93359 .33959 L
.93438 .33963 L
.93516 .33972 L
.93594 .33979 L
.93672 .33985 L
Mistroke
.9375 .33992 L
.93828 .33995 L
.93906 .33996 L
.93984 .33999 L
.94063 .34001 L
.94141 .34001 L
.94219 .34003 L
.94297 .34003 L
.94375 .34003 L
.94453 .34008 L
.94531 .34012 L
.94609 .34016 L
.94688 .34021 L
.94766 .34023 L
.94844 .34025 L
.94922 .34028 L
.95 .3403 L
.95078 .34031 L
.95156 .34032 L
.95234 .34031 L
.95313 .3403 L
.95391 .34032 L
.95469 .34033 L
.95547 .34033 L
.95625 .34034 L
.95703 .34032 L
.95781 .3403 L
.95859 .34029 L
.95938 .34027 L
.96016 .34025 L
.96094 .34023 L
.96172 .34021 L
.9625 .34019 L
.96328 .34021 L
.96406 .34023 L
.96484 .34024 L
.96563 .34027 L
.96641 .34028 L
.96719 .34029 L
.96797 .34031 L
.96875 .34033 L
.96953 .34033 L
.97031 .34034 L
.97109 .34034 L
.97188 .34033 L
.97266 .34035 L
.97344 .34036 L
.97422 .34036 L
.975 .34036 L
.97578 .34035 L
Mistroke
.97656 .34033 L
.97734 .34031 L
.97813 .34029 L
.97891 .34027 L
.97969 .34024 L
.98047 .34021 L
.98125 .34018 L
.98203 .34017 L
.98281 .34016 L
.98359 .34015 L
.98438 .34015 L
.98516 .34013 L
.98594 .34011 L
.98672 .34009 L
.9875 .34007 L
.98828 .34005 L
.98906 .34002 L
.98984 .33999 L
.99063 .33995 L
.99141 .33993 L
.99219 .33991 L
.99297 .33989 L
.99375 .33987 L
.99453 .33983 L
.99531 .3398 L
.99609 .33977 L
.99688 .33975 L
.99766 .33971 L
.99844 .33969 L
.99922 .33966 L
1 .33964 L
Mfstroke
1 .33964 m
1 .33964 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.1.4"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 143}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 67, 1, 58, "Section",
      CellTags->"Contents"],
    Cell[1779, 52, 1162, 39, 84, "Contents",
      CellTags->"Contents"]},
  "S3.1.0"->{
    Cell[2944, 93, 74, 1, 58, "Section",
      CellTags->{"S3.1.0", "0.1"}]},
  "0.1"->{
    Cell[2944, 93, 74, 1, 58, "Section",
      CellTags->{"S3.1.0", "0.1"}]},
  "S3.1.1"->{
    Cell[3021, 96, 66, 1, 41, "Subsection",
      CellTags->{"S3.1.1", "1.1"}],
    Cell[3090, 99, 803, 20, 80, "Text",
      CellTags->{"S3.1.1", "1.2"}],
    Cell[3896, 121, 368, 8, 40, "DisplayFormula",
      CellTags->{"S3.1.1", "1.3"}],
    Cell[4267, 131, 223, 7, 24, "Text",
      CellTags->{"S3.1.1", "1.4"}],
    Cell[4493, 140, 363, 8, 40, "DisplayFormula",
      CellTags->{"S3.1.1", "1.5"}],
    Cell[4859, 150, 309, 11, 24, "Text",
      CellTags->{"S3.1.1", "1.6"}],
    Cell[5171, 163, 235, 5, 26, "DisplayFormula",
      CellTags->{"S3.1.1", "1.7"}],
    Cell[5409, 170, 672, 20, 56, "Text",
      CellTags->{"S3.1.1", "1.8"}],
    Cell[6084, 192, 443, 9, 46, "DisplayFormula",
      CellTags->{"S3.1.1", "1.9"}],
    Cell[6530, 203, 855, 23, 96, "Text",
      CellTags->{"S3.1.1", "1.10"}],
    Cell[7388, 228, 363, 9, 70, "DisplayFormula",
      CellTags->{"S3.1.1", "1.11"}],
    Cell[7754, 239, 721, 16, 70, "Text",
      CellTags->{"S3.1.1", "1.12"}],
    Cell[8478, 257, 539, 13, 70, "DisplayFormula",
      CellTags->{"S3.1.1", "1.13"}],
    Cell[9020, 272, 352, 11, 70, "Text",
      CellTags->{"S3.1.1", "1.14"}],
    Cell[9375, 285, 3202, 59, 70, "Text",
      CellTags->{"S3.1.1", "1.15"}],
    Cell[12580, 346, 71, 1, 70, "Caption",
      CellTags->"S3.1.1"],
    Cell[12654, 349, 1200, 38, 70, "Text",
      CellTags->{"S3.1.1", "1.16"}],
    Cell[13857, 389, 78, 1, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.17"}],
    Cell[13938, 392, 93, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[14034, 396, 85, 1, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.18"}],
    Cell[14144, 401, 76, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[14223, 405, 102, 3, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[14340, 411, 135, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.19"}],
    Cell[14500, 419, 83, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[14586, 423, 130, 3, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[14731, 429, 192, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.20"}],
    Cell[14948, 438, 87, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[15038, 442, 569, 12, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[15622, 457, 130, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.21"}],
    Cell[15777, 465, 76, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[15856, 469, 83, 3, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[15954, 475, 202, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.22"}],
    Cell[16181, 484, 89, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[16273, 488, 760, 13, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[17048, 504, 142, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.23"}],
    Cell[17215, 512, 80, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[17298, 516, 267, 6, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[17580, 525, 210, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.24"}],
    Cell[17815, 534, 88, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[17906, 538, 1039, 28, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[18960, 569, 2381, 57, 70, "Text",
      CellTags->{"S3.1.1", "1.25"}],
    Cell[21344, 628, 1839, 38, 70, "Text",
      CellTags->{"S3.1.1", "1.26"}],
    Cell[23186, 668, 64, 1, 70, "Caption",
      CellTags->"S3.1.1"],
    Cell[23253, 671, 1458, 47, 70, "Text",
      CellTags->{"S3.1.1", "1.27"}],
    Cell[24714, 720, 410, 15, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.28"}],
    Cell[25149, 739, 80, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[25232, 743, 194, 4, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[25441, 750, 422, 15, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.29"}],
    Cell[25888, 769, 82, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[25973, 773, 357, 7, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[26345, 783, 762, 25, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.30"}],
    Cell[27132, 812, 83, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[27218, 816, 323, 6, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[27556, 825, 1179, 34, 70, "Text",
      CellTags->{"S3.1.1", "1.31"}],
    Cell[28738, 861, 1003, 23, 70, "Text",
      CellTags->{"S3.1.1", "1.32"}],
    Cell[29744, 886, 68, 1, 70, "Caption",
      CellTags->"S3.1.1"],
    Cell[29815, 889, 504, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.33"}],
    Cell[30322, 908, 327, 11, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.34"}],
    Cell[30674, 923, 95, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[30772, 927, 275, 6, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[31062, 936, 127, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.35"}],
    Cell[31214, 944, 87, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[31304, 948, 331, 7, 70, "Output",
      CellTags->"S3.1.1"],
    Cell[31650, 958, 466, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.36"}],
    Cell[32119, 977, 718, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.37"}],
    Cell[32840, 996, 65, 1, 70, "Caption",
      CellTags->"S3.1.1"],
    Cell[32908, 999, 232, 7, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.38"}],
    Cell[33165, 1010, 97, 2, 70, "Input",
      CellTags->"S3.1.1"],
    Cell[33265, 1014, 454, 9, 70, "Output",
      CellTags->"S3.1.1"]},
  "1.1"->{
    Cell[3021, 96, 66, 1, 41, "Subsection",
      CellTags->{"S3.1.1", "1.1"}]},
  "1.2"->{
    Cell[3090, 99, 803, 20, 80, "Text",
      CellTags->{"S3.1.1", "1.2"}]},
  "1.3"->{
    Cell[3896, 121, 368, 8, 40, "DisplayFormula",
      CellTags->{"S3.1.1", "1.3"}]},
  "1.4"->{
    Cell[4267, 131, 223, 7, 24, "Text",
      CellTags->{"S3.1.1", "1.4"}]},
  "1.5"->{
    Cell[4493, 140, 363, 8, 40, "DisplayFormula",
      CellTags->{"S3.1.1", "1.5"}]},
  "1.6"->{
    Cell[4859, 150, 309, 11, 24, "Text",
      CellTags->{"S3.1.1", "1.6"}]},
  "1.7"->{
    Cell[5171, 163, 235, 5, 26, "DisplayFormula",
      CellTags->{"S3.1.1", "1.7"}]},
  "1.8"->{
    Cell[5409, 170, 672, 20, 56, "Text",
      CellTags->{"S3.1.1", "1.8"}]},
  "1.9"->{
    Cell[6084, 192, 443, 9, 46, "DisplayFormula",
      CellTags->{"S3.1.1", "1.9"}]},
  "1.10"->{
    Cell[6530, 203, 855, 23, 96, "Text",
      CellTags->{"S3.1.1", "1.10"}]},
  "1.11"->{
    Cell[7388, 228, 363, 9, 70, "DisplayFormula",
      CellTags->{"S3.1.1", "1.11"}]},
  "1.12"->{
    Cell[7754, 239, 721, 16, 70, "Text",
      CellTags->{"S3.1.1", "1.12"}]},
  "1.13"->{
    Cell[8478, 257, 539, 13, 70, "DisplayFormula",
      CellTags->{"S3.1.1", "1.13"}]},
  "1.14"->{
    Cell[9020, 272, 352, 11, 70, "Text",
      CellTags->{"S3.1.1", "1.14"}]},
  "1.15"->{
    Cell[9375, 285, 3202, 59, 70, "Text",
      CellTags->{"S3.1.1", "1.15"}]},
  "1.16"->{
    Cell[12654, 349, 1200, 38, 70, "Text",
      CellTags->{"S3.1.1", "1.16"}]},
  "1.17"->{
    Cell[13857, 389, 78, 1, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.17"}]},
  "1.18"->{
    Cell[14034, 396, 85, 1, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.18"}]},
  "1.19"->{
    Cell[14340, 411, 135, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.19"}]},
  "1.20"->{
    Cell[14731, 429, 192, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.20"}]},
  "1.21"->{
    Cell[15622, 457, 130, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.21"}]},
  "1.22"->{
    Cell[15954, 475, 202, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.22"}]},
  "1.23"->{
    Cell[17048, 504, 142, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.23"}]},
  "1.24"->{
    Cell[17580, 525, 210, 5, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.24"}]},
  "1.25"->{
    Cell[18960, 569, 2381, 57, 70, "Text",
      CellTags->{"S3.1.1", "1.25"}]},
  "1.26"->{
    Cell[21344, 628, 1839, 38, 70, "Text",
      CellTags->{"S3.1.1", "1.26"}]},
  "1.27"->{
    Cell[23253, 671, 1458, 47, 70, "Text",
      CellTags->{"S3.1.1", "1.27"}]},
  "1.28"->{
    Cell[24714, 720, 410, 15, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.28"}]},
  "1.29"->{
    Cell[25441, 750, 422, 15, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.29"}]},
  "1.30"->{
    Cell[26345, 783, 762, 25, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.30"}]},
  "1.31"->{
    Cell[27556, 825, 1179, 34, 70, "Text",
      CellTags->{"S3.1.1", "1.31"}]},
  "1.32"->{
    Cell[28738, 861, 1003, 23, 70, "Text",
      CellTags->{"S3.1.1", "1.32"}]},
  "1.33"->{
    Cell[29815, 889, 504, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.33"}]},
  "1.34"->{
    Cell[30322, 908, 327, 11, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.34"}]},
  "1.35"->{
    Cell[31062, 936, 127, 4, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.35"}]},
  "1.36"->{
    Cell[31650, 958, 466, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.36"}]},
  "1.37"->{
    Cell[32119, 977, 718, 17, 70, "Text",
      CellTags->{"S3.1.1", "1.37"}]},
  "1.38"->{
    Cell[32908, 999, 232, 7, 70, "MathCaption",
      CellTags->{"S3.1.1", "1.38"}]},
  "S3.1.2"->{
    Cell[33734, 1026, 107, 1, 70, "Subsection",
      CellTags->{"S3.1.2", "2.1"}],
    Cell[33844, 1029, 752, 21, 70, "Text",
      CellTags->{"S3.1.2", "2.2"}],
    Cell[34599, 1052, 273, 6, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.3"}],
    Cell[34875, 1060, 51, 1, 70, "Text",
      CellTags->{"S3.1.2", "2.4"}],
    Cell[34929, 1063, 277, 6, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.5"}],
    Cell[35209, 1071, 610, 17, 70, "Text",
      CellTags->{"S3.1.2", "2.6"}],
    Cell[35822, 1090, 2148, 43, 70, "Text",
      CellTags->{"S3.1.2", "2.7"}],
    Cell[37973, 1135, 87, 1, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[38063, 1138, 1867, 63, 70, "Text",
      CellTags->{"S3.1.2", "2.8"}],
    Cell[39933, 1203, 95, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.9"}],
    Cell[40053, 1208, 89, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[40145, 1212, 193, 4, 70, "Output",
      CellTags->"S3.1.2"],
    Cell[40353, 1219, 240, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.10"}],
    Cell[40596, 1228, 90, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[40689, 1232, 644, 21, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.11"}],
    Cell[41358, 1257, 79, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[41440, 1261, 168, 4, 70, "Output",
      CellTags->"S3.1.2"],
    Cell[41623, 1268, 365, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.12"}],
    Cell[42013, 1285, 116, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[42132, 1289, 5626, 373, 70, 5553, 370, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[47773, 1665, 403, 11, 70, "Text",
      CellTags->{"S3.1.2", "2.13"}],
    Cell[48179, 1678, 298, 9, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.14"}],
    Cell[48502, 1691, 108, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[48613, 1695, 176, 5, 70, "Output",
      CellTags->"S3.1.2"],
    Cell[48804, 1703, 327, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.15"}],
    Cell[49156, 1718, 77, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[49236, 1722, 102, 3, 70, "Output",
      CellTags->"S3.1.2"],
    Cell[49353, 1728, 275, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.16"}],
    Cell[49653, 1740, 167, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[49823, 1747, 10707, 715, 70, 10634, 712, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[60545, 2465, 138, 4, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.17"}],
    Cell[60686, 2471, 147, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[60836, 2478, 311, 10, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.18"}],
    Cell[61172, 2492, 211, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[61386, 2500, 14462, 950, 70, 14389, 947, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[75863, 3453, 97, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.19"}],
    Cell[75963, 3456, 89, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[76055, 3460, 214, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.20"}],
    Cell[76272, 3470, 119, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[76394, 3474, 191, 5, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.21"}],
    Cell[76610, 3483, 171, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[76784, 3491, 8948, 658, 70, 8875, 655, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[85747, 4152, 400, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.22"}],
    Cell[86172, 4169, 211, 7, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[86386, 4178, 14052, 1004, 70, 13979, 1001, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[100453, 5185, 209, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.23"}],
    Cell[100687, 5196, 211, 7, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[100901, 5205, 14559, 1046, 70, 14486, 1043, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[115475, 6254, 252, 5, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.24"}],
    Cell[115752, 6263, 195, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[115950, 6271, 380134, 9552, 70, 380061, 9549, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[496099, 15826, 846, 27, 70, "Text",
      CellTags->{"S3.1.2", "2.25"}],
    Cell[496948, 15855, 223, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.26"}],
    Cell[497174, 15864, 102, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[497279, 15868, 104, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.27"}],
    Cell[497408, 15873, 95, 2, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[497506, 15877, 459, 9, 70, "Output",
      CellTags->"S3.1.2"],
    Cell[497980, 15889, 363, 12, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.28"}],
    Cell[498368, 15905, 172, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[498543, 15913, 18208, 1194, 70, 18135, 1191, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[516766, 17110, 600, 20, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.29"}],
    Cell[517391, 17134, 164, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[517558, 17142, 13129, 858, 70, 13056, 855, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[530702, 18003, 599, 19, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.30"}],
    Cell[531326, 18026, 186, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[531515, 18034, 10287, 690, 70, 10214, 687, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[541817, 18727, 83, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.31"}],
    Cell[541925, 18732, 178, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[542106, 18740, 13272, 870, 70, 13199, 867, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[555393, 19613, 693, 20, 70, "Text",
      CellTags->{"S3.1.2", "2.32"}],
    Cell[556089, 19635, 144, 4, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.33"}],
    Cell[556236, 19641, 130, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[556369, 19648, 105, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.34"}],
    Cell[556499, 19653, 166, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[556668, 19660, 12599, 849, 70, 12526, 846, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[569282, 20512, 275, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.35"}],
    Cell[569582, 20523, 257, 7, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[569842, 20532, 12835, 867, 70, 12762, 864, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[582692, 21402, 1359, 30, 70, "Text",
      CellTags->{"S3.1.2", "2.36"}],
    Cell[584054, 21434, 197, 9, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[584254, 21445, 1322, 35, 70, "Text",
      CellTags->{"S3.1.2", "2.37"}],
    Cell[585579, 21482, 496, 9, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.38"}],
    Cell[586078, 21493, 2055, 66, 70, "Text",
      CellTags->{"S3.1.2", "2.39"}],
    Cell[588136, 21561, 5290, 105, 70, "Text",
      CellTags->{"S3.1.2", "2.40"}],
    Cell[593429, 21668, 284, 11, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[593716, 21681, 436, 14, 70, "Text",
      CellTags->{"S3.1.2", "2.41"}],
    Cell[594155, 21697, 83, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.42"}],
    Cell[594263, 21702, 166, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[594432, 21709, 12467, 831, 70, 12394, 828, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[606914, 22543, 425, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.43"}],
    Cell[607364, 22560, 179, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[607546, 22567, 7748, 518, 70, 7675, 515, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[615309, 23088, 423, 14, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.44"}],
    Cell[615757, 23106, 181, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[615941, 23113, 8977, 603, 70, 8904, 600, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[624933, 23719, 423, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.45"}],
    Cell[625381, 23736, 183, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[625567, 23743, 7995, 537, 70, 7922, 534, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[633577, 24283, 676, 23, 70, "Text",
      CellTags->{"S3.1.2", "2.46"}],
    Cell[634256, 24308, 989, 22, 70, "Text",
      CellTags->{"S3.1.2", "2.47"}],
    Cell[635248, 24332, 171, 6, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[635422, 24340, 205, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.48"}],
    Cell[635652, 24351, 170, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[635825, 24358, 6034, 421, 70, 5961, 418, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[641874, 24782, 554, 13, 70, "Text",
      CellTags->{"S3.1.2", "2.49"}],
    Cell[642431, 24797, 191, 4, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.50"}],
    Cell[642625, 24803, 52, 1, 70, "Text",
      CellTags->{"S3.1.2", "2.51"}],
    Cell[642680, 24806, 198, 4, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.52"}],
    Cell[642881, 24812, 1606, 50, 70, "Text",
      CellTags->{"S3.1.2", "2.53"}],
    Cell[644490, 24864, 2245, 43, 70, "Text",
      CellTags->{"S3.1.2", "2.54"}],
    Cell[646738, 24909, 85, 1, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[646826, 24912, 770, 29, 70, "Text",
      CellTags->{"S3.1.2", "2.55"}],
    Cell[647599, 24943, 1208, 27, 70, "Text",
      CellTags->{"S3.1.2", "2.56"}],
    Cell[648810, 24972, 193, 9, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[649006, 24983, 2497, 53, 70, "Text",
      CellTags->{"S3.1.2", "2.57"}],
    Cell[651506, 25038, 115, 5, 70, "Caption",
      CellTags->"S3.1.2"],
    Cell[651624, 25045, 255, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.58"}],
    Cell[651904, 25056, 186, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[652093, 25064, 4822, 327, 70, 4749, 324, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[656930, 25394, 975, 31, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.59"}],
    Cell[657930, 25429, 260, 8, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[658193, 25439, 5027, 332, 70, 4954, 329, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[663235, 25774, 283, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.60"}],
    Cell[663543, 25786, 267, 8, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[663813, 25796, 4880, 317, 70, 4807, 314, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[668708, 26116, 440, 12, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.61"}],
    Cell[669173, 26132, 178, 5, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[669354, 26139, 9422, 622, 70, 9349, 619, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[678791, 26764, 340, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.62"}],
    Cell[679156, 26779, 227, 7, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[679386, 26788, 14581, 948, 70, 14508, 945, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"],
    Cell[693982, 27739, 340, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.63"}],
    Cell[694347, 27754, 199, 6, 70, "Input",
      CellTags->"S3.1.2"],
    Cell[694549, 27762, 8277, 555, 70, 8204, 552, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.2"]},
  "2.1"->{
    Cell[33734, 1026, 107, 1, 70, "Subsection",
      CellTags->{"S3.1.2", "2.1"}]},
  "2.2"->{
    Cell[33844, 1029, 752, 21, 70, "Text",
      CellTags->{"S3.1.2", "2.2"}]},
  "2.3"->{
    Cell[34599, 1052, 273, 6, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.3"}]},
  "2.4"->{
    Cell[34875, 1060, 51, 1, 70, "Text",
      CellTags->{"S3.1.2", "2.4"}]},
  "2.5"->{
    Cell[34929, 1063, 277, 6, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.5"}]},
  "2.6"->{
    Cell[35209, 1071, 610, 17, 70, "Text",
      CellTags->{"S3.1.2", "2.6"}]},
  "2.7"->{
    Cell[35822, 1090, 2148, 43, 70, "Text",
      CellTags->{"S3.1.2", "2.7"}]},
  "2.8"->{
    Cell[38063, 1138, 1867, 63, 70, "Text",
      CellTags->{"S3.1.2", "2.8"}]},
  "2.9"->{
    Cell[39933, 1203, 95, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.9"}]},
  "2.10"->{
    Cell[40353, 1219, 240, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.10"}]},
  "2.11"->{
    Cell[40689, 1232, 644, 21, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.11"}]},
  "2.12"->{
    Cell[41623, 1268, 365, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.12"}]},
  "2.13"->{
    Cell[47773, 1665, 403, 11, 70, "Text",
      CellTags->{"S3.1.2", "2.13"}]},
  "2.14"->{
    Cell[48179, 1678, 298, 9, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.14"}]},
  "2.15"->{
    Cell[48804, 1703, 327, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.15"}]},
  "2.16"->{
    Cell[49353, 1728, 275, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.16"}]},
  "2.17"->{
    Cell[60545, 2465, 138, 4, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.17"}]},
  "2.18"->{
    Cell[60836, 2478, 311, 10, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.18"}]},
  "2.19"->{
    Cell[75863, 3453, 97, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.19"}]},
  "2.20"->{
    Cell[76055, 3460, 214, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.20"}]},
  "2.21"->{
    Cell[76394, 3474, 191, 5, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.21"}]},
  "2.22"->{
    Cell[85747, 4152, 400, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.22"}]},
  "2.23"->{
    Cell[100453, 5185, 209, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.23"}]},
  "2.24"->{
    Cell[115475, 6254, 252, 5, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.24"}]},
  "2.25"->{
    Cell[496099, 15826, 846, 27, 70, "Text",
      CellTags->{"S3.1.2", "2.25"}]},
  "2.26"->{
    Cell[496948, 15855, 223, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.26"}]},
  "2.27"->{
    Cell[497279, 15868, 104, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.27"}]},
  "2.28"->{
    Cell[497980, 15889, 363, 12, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.28"}]},
  "2.29"->{
    Cell[516766, 17110, 600, 20, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.29"}]},
  "2.30"->{
    Cell[530702, 18003, 599, 19, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.30"}]},
  "2.31"->{
    Cell[541817, 18727, 83, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.31"}]},
  "2.32"->{
    Cell[555393, 19613, 693, 20, 70, "Text",
      CellTags->{"S3.1.2", "2.32"}]},
  "2.33"->{
    Cell[556089, 19635, 144, 4, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.33"}]},
  "2.34"->{
    Cell[556369, 19648, 105, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.34"}]},
  "2.35"->{
    Cell[569282, 20512, 275, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.35"}]},
  "2.36"->{
    Cell[582692, 21402, 1359, 30, 70, "Text",
      CellTags->{"S3.1.2", "2.36"}]},
  "2.37"->{
    Cell[584254, 21445, 1322, 35, 70, "Text",
      CellTags->{"S3.1.2", "2.37"}]},
  "2.38"->{
    Cell[585579, 21482, 496, 9, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.38"}]},
  "2.39"->{
    Cell[586078, 21493, 2055, 66, 70, "Text",
      CellTags->{"S3.1.2", "2.39"}]},
  "2.40"->{
    Cell[588136, 21561, 5290, 105, 70, "Text",
      CellTags->{"S3.1.2", "2.40"}]},
  "2.41"->{
    Cell[593716, 21681, 436, 14, 70, "Text",
      CellTags->{"S3.1.2", "2.41"}]},
  "2.42"->{
    Cell[594155, 21697, 83, 1, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.42"}]},
  "2.43"->{
    Cell[606914, 22543, 425, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.43"}]},
  "2.44"->{
    Cell[615309, 23088, 423, 14, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.44"}]},
  "2.45"->{
    Cell[624933, 23719, 423, 13, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.45"}]},
  "2.46"->{
    Cell[633577, 24283, 676, 23, 70, "Text",
      CellTags->{"S3.1.2", "2.46"}]},
  "2.47"->{
    Cell[634256, 24308, 989, 22, 70, "Text",
      CellTags->{"S3.1.2", "2.47"}]},
  "2.48"->{
    Cell[635422, 24340, 205, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.48"}]},
  "2.49"->{
    Cell[641874, 24782, 554, 13, 70, "Text",
      CellTags->{"S3.1.2", "2.49"}]},
  "2.50"->{
    Cell[642431, 24797, 191, 4, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.50"}]},
  "2.51"->{
    Cell[642625, 24803, 52, 1, 70, "Text",
      CellTags->{"S3.1.2", "2.51"}]},
  "2.52"->{
    Cell[642680, 24806, 198, 4, 70, "DisplayFormula",
      CellTags->{"S3.1.2", "2.52"}]},
  "2.53"->{
    Cell[642881, 24812, 1606, 50, 70, "Text",
      CellTags->{"S3.1.2", "2.53"}]},
  "2.54"->{
    Cell[644490, 24864, 2245, 43, 70, "Text",
      CellTags->{"S3.1.2", "2.54"}]},
  "2.55"->{
    Cell[646826, 24912, 770, 29, 70, "Text",
      CellTags->{"S3.1.2", "2.55"}]},
  "2.56"->{
    Cell[647599, 24943, 1208, 27, 70, "Text",
      CellTags->{"S3.1.2", "2.56"}]},
  "2.57"->{
    Cell[649006, 24983, 2497, 53, 70, "Text",
      CellTags->{"S3.1.2", "2.57"}]},
  "2.58"->{
    Cell[651624, 25045, 255, 7, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.58"}]},
  "2.59"->{
    Cell[656930, 25394, 975, 31, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.59"}]},
  "2.60"->{
    Cell[663235, 25774, 283, 8, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.60"}]},
  "2.61"->{
    Cell[668708, 26116, 440, 12, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.61"}]},
  "2.62"->{
    Cell[678791, 26764, 340, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.62"}]},
  "2.63"->{
    Cell[693982, 27739, 340, 11, 70, "MathCaption",
      CellTags->{"S3.1.2", "2.63"}]},
  "S3.1.3"->{
    Cell[702841, 28320, 391, 14, 70, "Subsection",
      CellTags->{"S3.1.3", "3.1"}],
    Cell[703235, 28336, 1004, 33, 70, "Text",
      CellTags->{"S3.1.3", "3.2"}],
    Cell[704242, 28371, 1840, 41, 70, "Text",
      CellTags->{"S3.1.3", "3.3"}],
    Cell[706085, 28414, 66, 1, 70, "Caption",
      CellTags->"S3.1.3"],
    Cell[706154, 28417, 2630, 82, 70, "Text",
      CellTags->{"S3.1.3", "3.4"}],
    Cell[708787, 28501, 303, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.5"}],
    Cell[709093, 28510, 152, 5, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[709248, 28517, 98, 1, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.6"}],
    Cell[709371, 28522, 164, 5, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[709538, 28529, 4531, 320, 70, 4458, 317, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.3"],
    Cell[714084, 28852, 251, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.7"}],
    Cell[714338, 28861, 119, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[714460, 28865, 378, 10, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.8"}],
    Cell[714863, 28879, 83, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[714949, 28883, 237, 6, 70, "Output",
      CellTags->"S3.1.3"],
    Cell[715201, 28892, 320, 11, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.9"}],
    Cell[715546, 28907, 156, 5, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[715705, 28914, 6674, 501, 70, 6601, 498, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.3"],
    Cell[722394, 29418, 451, 14, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.10"}],
    Cell[722870, 29436, 161, 5, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[723034, 29443, 86, 3, 70, "Output",
      CellTags->"S3.1.3"],
    Cell[723135, 29449, 142, 5, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.11"}],
    Cell[723280, 29456, 117, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[723400, 29460, 419, 15, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.12"}],
    Cell[723844, 29479, 84, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[723931, 29483, 92, 3, 70, "Output",
      CellTags->"S3.1.3"],
    Cell[724038, 29489, 224, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.13"}],
    Cell[724287, 29500, 170, 5, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[724460, 29507, 13167, 927, 70, 13094, 924, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.3"],
    Cell[737642, 30437, 363, 12, 70, "Text",
      CellTags->{"S3.1.3", "3.14"}],
    Cell[738008, 30451, 213, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.15"}],
    Cell[738224, 30460, 121, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[738348, 30464, 217, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.16"}],
    Cell[738568, 30473, 109, 2, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[738680, 30477, 116, 2, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.17"}],
    Cell[738821, 30483, 190, 6, 70, "Input",
      CellTags->"S3.1.3"],
    Cell[739014, 30491, 10384, 772, 70, 10311, 769, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.3"],
    Cell[749413, 31266, 276, 9, 70, "Text",
      CellTags->{"S3.1.3", "3.18"}]},
  "3.1"->{
    Cell[702841, 28320, 391, 14, 70, "Subsection",
      CellTags->{"S3.1.3", "3.1"}]},
  "3.2"->{
    Cell[703235, 28336, 1004, 33, 70, "Text",
      CellTags->{"S3.1.3", "3.2"}]},
  "3.3"->{
    Cell[704242, 28371, 1840, 41, 70, "Text",
      CellTags->{"S3.1.3", "3.3"}]},
  "3.4"->{
    Cell[706154, 28417, 2630, 82, 70, "Text",
      CellTags->{"S3.1.3", "3.4"}]},
  "3.5"->{
    Cell[708787, 28501, 303, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.5"}]},
  "3.6"->{
    Cell[709248, 28517, 98, 1, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.6"}]},
  "3.7"->{
    Cell[714084, 28852, 251, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.7"}]},
  "3.8"->{
    Cell[714460, 28865, 378, 10, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.8"}]},
  "3.9"->{
    Cell[715201, 28892, 320, 11, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.9"}]},
  "3.10"->{
    Cell[722394, 29418, 451, 14, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.10"}]},
  "3.11"->{
    Cell[723135, 29449, 142, 5, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.11"}]},
  "3.12"->{
    Cell[723400, 29460, 419, 15, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.12"}]},
  "3.13"->{
    Cell[724038, 29489, 224, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.13"}]},
  "3.14"->{
    Cell[737642, 30437, 363, 12, 70, "Text",
      CellTags->{"S3.1.3", "3.14"}]},
  "3.15"->{
    Cell[738008, 30451, 213, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.15"}]},
  "3.16"->{
    Cell[738348, 30464, 217, 7, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.16"}]},
  "3.17"->{
    Cell[738680, 30477, 116, 2, 70, "MathCaption",
      CellTags->{"S3.1.3", "3.17"}]},
  "3.18"->{
    Cell[749413, 31266, 276, 9, 70, "Text",
      CellTags->{"S3.1.3", "3.18"}]},
  "S3.1.4"->{
    Cell[749692, 31277, 289, 10, 70, "Subsection",
      CellTags->{"S3.1.4", "4.1"}],
    Cell[749984, 31289, 359, 11, 70, "Text",
      CellTags->{"S3.1.4", "4.2"}],
    Cell[750346, 31302, 397, 8, 70, "DisplayFormula",
      CellTags->{"S3.1.4", "4.3"}],
    Cell[750746, 31312, 51, 1, 70, "Text",
      CellTags->{"S3.1.4", "4.4"}],
    Cell[750800, 31315, 402, 8, 70, "DisplayFormula",
      CellTags->{"S3.1.4", "4.5"}],
    Cell[751205, 31325, 1532, 44, 70, "Text",
      CellTags->{"S3.1.4", "4.6"}],
    Cell[752740, 31371, 1930, 39, 70, "Text",
      CellTags->{"S3.1.4", "4.7"}],
    Cell[754673, 31412, 85, 1, 70, "Caption",
      CellTags->"S3.1.4"],
    Cell[754761, 31415, 272, 8, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.8"}],
    Cell[755036, 31425, 109, 2, 70, "Input",
      CellTags->"S3.1.4"],
    Cell[755148, 31429, 224, 7, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.9"}],
    Cell[755397, 31440, 176, 5, 70, "Input",
      CellTags->"S3.1.4"],
    Cell[755576, 31447, 26080, 1693, 70, 26007, 1690, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.4"],
    Cell[781671, 33143, 147, 4, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.10"}],
    Cell[781843, 33151, 228, 6, 70, "Input",
      CellTags->"S3.1.4"],
    Cell[782074, 33159, 23771, 1568, 70, 23698, 1565, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.1.4"]},
  "4.1"->{
    Cell[749692, 31277, 289, 10, 70, "Subsection",
      CellTags->{"S3.1.4", "4.1"}]},
  "4.2"->{
    Cell[749984, 31289, 359, 11, 70, "Text",
      CellTags->{"S3.1.4", "4.2"}]},
  "4.3"->{
    Cell[750346, 31302, 397, 8, 70, "DisplayFormula",
      CellTags->{"S3.1.4", "4.3"}]},
  "4.4"->{
    Cell[750746, 31312, 51, 1, 70, "Text",
      CellTags->{"S3.1.4", "4.4"}]},
  "4.5"->{
    Cell[750800, 31315, 402, 8, 70, "DisplayFormula",
      CellTags->{"S3.1.4", "4.5"}]},
  "4.6"->{
    Cell[751205, 31325, 1532, 44, 70, "Text",
      CellTags->{"S3.1.4", "4.6"}]},
  "4.7"->{
    Cell[752740, 31371, 1930, 39, 70, "Text",
      CellTags->{"S3.1.4", "4.7"}]},
  "4.8"->{
    Cell[754761, 31415, 272, 8, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.8"}]},
  "4.9"->{
    Cell[755148, 31429, 224, 7, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.9"}]},
  "4.10"->{
    Cell[781671, 33143, 147, 4, 70, "MathCaption",
      CellTags->{"S3.1.4", "4.10"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 806499, 34748},
  {"S3.1.0", 806658, 34753},
  {"0.1", 806747, 34756},
  {"S3.1.1", 806839, 34759},
  {"1.1", 812125, 34898},
  {"1.2", 812217, 34901},
  {"1.3", 812305, 34904},
  {"1.4", 812403, 34907},
  {"1.5", 812491, 34910},
  {"1.6", 812589, 34913},
  {"1.7", 812678, 34916},
  {"1.8", 812776, 34919},
  {"1.9", 812865, 34922},
  {"1.10", 812964, 34925},
  {"1.11", 813055, 34928},
  {"1.12", 813155, 34931},
  {"1.13", 813246, 34934},
  {"1.14", 813347, 34937},
  {"1.15", 813438, 34940},
  {"1.16", 813530, 34943},
  {"1.17", 813623, 34946},
  {"1.18", 813720, 34949},
  {"1.19", 813817, 34952},
  {"1.20", 813915, 34955},
  {"1.21", 814013, 34958},
  {"1.22", 814111, 34961},
  {"1.23", 814209, 34964},
  {"1.24", 814307, 34967},
  {"1.25", 814405, 34970},
  {"1.26", 814498, 34973},
  {"1.27", 814591, 34976},
  {"1.28", 814684, 34979},
  {"1.29", 814783, 34982},
  {"1.30", 814882, 34985},
  {"1.31", 814981, 34988},
  {"1.32", 815074, 34991},
  {"1.33", 815167, 34994},
  {"1.34", 815259, 34997},
  {"1.35", 815358, 35000},
  {"1.36", 815456, 35003},
  {"1.37", 815548, 35006},
  {"1.38", 815640, 35009},
  {"S3.1.2", 815740, 35012},
  {"2.1", 828219, 35329},
  {"2.2", 828315, 35332},
  {"2.3", 828406, 35335},
  {"2.4", 828506, 35338},
  {"2.5", 828595, 35341},
  {"2.6", 828695, 35344},
  {"2.7", 828786, 35347},
  {"2.8", 828878, 35350},
  {"2.9", 828970, 35353},
  {"2.10", 829067, 35356},
  {"2.11", 829166, 35359},
  {"2.12", 829266, 35362},
  {"2.13", 829366, 35365},
  {"2.14", 829459, 35368},
  {"2.15", 829558, 35371},
  {"2.16", 829658, 35374},
  {"2.17", 829757, 35377},
  {"2.18", 829856, 35380},
  {"2.19", 829956, 35383},
  {"2.20", 830054, 35386},
  {"2.21", 830153, 35389},
  {"2.22", 830252, 35392},
  {"2.23", 830352, 35395},
  {"2.24", 830452, 35398},
  {"2.25", 830552, 35401},
  {"2.26", 830647, 35404},
  {"2.27", 830748, 35407},
  {"2.28", 830849, 35410},
  {"2.29", 830951, 35413},
  {"2.30", 831053, 35416},
  {"2.31", 831155, 35419},
  {"2.32", 831255, 35422},
  {"2.33", 831350, 35425},
  {"2.34", 831451, 35428},
  {"2.35", 831552, 35431},
  {"2.36", 831653, 35434},
  {"2.37", 831749, 35437},
  {"2.38", 831845, 35440},
  {"2.39", 831949, 35443},
  {"2.40", 832045, 35446},
  {"2.41", 832142, 35449},
  {"2.42", 832237, 35452},
  {"2.43", 832337, 35455},
  {"2.44", 832439, 35458},
  {"2.45", 832541, 35461},
  {"2.46", 832643, 35464},
  {"2.47", 832738, 35467},
  {"2.48", 832833, 35470},
  {"2.49", 832934, 35473},
  {"2.50", 833029, 35476},
  {"2.51", 833133, 35479},
  {"2.52", 833226, 35482},
  {"2.53", 833330, 35485},
  {"2.54", 833426, 35488},
  {"2.55", 833522, 35491},
  {"2.56", 833617, 35494},
  {"2.57", 833713, 35497},
  {"2.58", 833809, 35500},
  {"2.59", 833910, 35503},
  {"2.60", 834012, 35506},
  {"2.61", 834113, 35509},
  {"2.62", 834215, 35512},
  {"2.63", 834317, 35515},
  {"S3.1.3", 834421, 35518},
  {"3.1", 837755, 35603},
  {"3.2", 837854, 35606},
  {"3.3", 837948, 35609},
  {"3.4", 838042, 35612},
  {"3.5", 838136, 35615},
  {"3.6", 838235, 35618},
  {"3.7", 838333, 35621},
  {"3.8", 838432, 35624},
  {"3.9", 838532, 35627},
  {"3.10", 838633, 35630},
  {"3.11", 838735, 35633},
  {"3.12", 838836, 35636},
  {"3.13", 838938, 35639},
  {"3.14", 839039, 35642},
  {"3.15", 839134, 35645},
  {"3.16", 839235, 35648},
  {"3.17", 839336, 35651},
  {"3.18", 839437, 35654},
  {"S3.1.4", 839533, 35657},
  {"4.1", 841003, 35694},
  {"4.2", 841102, 35697},
  {"4.3", 841195, 35700},
  {"4.4", 841297, 35703},
  {"4.5", 841388, 35706},
  {"4.6", 841490, 35709},
  {"4.7", 841584, 35712},
  {"4.8", 841678, 35715},
  {"4.9", 841777, 35718},
  {"4.10", 841877, 35721}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 67, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1779, 52, 1162, 39, 84, "Contents",
  CellTags->"Contents"],
Cell[2944, 93, 74, 1, 58, "Section",
  CellTags->{"S3.1.0", "0.1"}],
Cell[3021, 96, 66, 1, 41, "Subsection",
  CellTags->{"S3.1.1", "1.1"}],
Cell[3090, 99, 803, 20, 80, "Text",
  CellTags->{"S3.1.1", "1.2"}],
Cell[3896, 121, 368, 8, 40, "DisplayFormula",
  CellTags->{"S3.1.1", "1.3"}],
Cell[4267, 131, 223, 7, 24, "Text",
  CellTags->{"S3.1.1", "1.4"}],
Cell[4493, 140, 363, 8, 40, "DisplayFormula",
  CellTags->{"S3.1.1", "1.5"}],
Cell[4859, 150, 309, 11, 24, "Text",
  CellTags->{"S3.1.1", "1.6"}],
Cell[5171, 163, 235, 5, 26, "DisplayFormula",
  CellTags->{"S3.1.1", "1.7"}],
Cell[5409, 170, 672, 20, 56, "Text",
  CellTags->{"S3.1.1", "1.8"}],
Cell[6084, 192, 443, 9, 46, "DisplayFormula",
  CellTags->{"S3.1.1", "1.9"}],
Cell[6530, 203, 855, 23, 96, "Text",
  CellTags->{"S3.1.1", "1.10"}],
Cell[7388, 228, 363, 9, 70, "DisplayFormula",
  CellTags->{"S3.1.1", "1.11"}],
Cell[7754, 239, 721, 16, 70, "Text",
  CellTags->{"S3.1.1", "1.12"}],
Cell[8478, 257, 539, 13, 70, "DisplayFormula",
  CellTags->{"S3.1.1", "1.13"}],
Cell[9020, 272, 352, 11, 70, "Text",
  CellTags->{"S3.1.1", "1.14"}],
Cell[9375, 285, 3202, 59, 70, "Text",
  CellTags->{"S3.1.1", "1.15"}],
Cell[12580, 346, 71, 1, 70, "Caption",
  CellTags->"S3.1.1"],
Cell[12654, 349, 1200, 38, 70, "Text",
  CellTags->{"S3.1.1", "1.16"}],
Cell[13857, 389, 78, 1, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.17"}],
Cell[13938, 392, 93, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[14034, 396, 85, 1, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.18"}],

Cell[CellGroupData[{
Cell[14144, 401, 76, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[14223, 405, 102, 3, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[14340, 411, 135, 4, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.19"}],

Cell[CellGroupData[{
Cell[14500, 419, 83, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[14586, 423, 130, 3, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[14731, 429, 192, 5, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.20"}],

Cell[CellGroupData[{
Cell[14948, 438, 87, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[15038, 442, 569, 12, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[15622, 457, 130, 4, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.21"}],

Cell[CellGroupData[{
Cell[15777, 465, 76, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[15856, 469, 83, 3, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[15954, 475, 202, 5, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.22"}],

Cell[CellGroupData[{
Cell[16181, 484, 89, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[16273, 488, 760, 13, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[17048, 504, 142, 4, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.23"}],

Cell[CellGroupData[{
Cell[17215, 512, 80, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[17298, 516, 267, 6, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[17580, 525, 210, 5, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.24"}],

Cell[CellGroupData[{
Cell[17815, 534, 88, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[17906, 538, 1039, 28, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[18960, 569, 2381, 57, 70, "Text",
  CellTags->{"S3.1.1", "1.25"}],
Cell[21344, 628, 1839, 38, 70, "Text",
  CellTags->{"S3.1.1", "1.26"}],
Cell[23186, 668, 64, 1, 70, "Caption",
  CellTags->"S3.1.1"],
Cell[23253, 671, 1458, 47, 70, "Text",
  CellTags->{"S3.1.1", "1.27"}],
Cell[24714, 720, 410, 15, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.28"}],

Cell[CellGroupData[{
Cell[25149, 739, 80, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[25232, 743, 194, 4, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[25441, 750, 422, 15, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.29"}],

Cell[CellGroupData[{
Cell[25888, 769, 82, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[25973, 773, 357, 7, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[26345, 783, 762, 25, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.30"}],

Cell[CellGroupData[{
Cell[27132, 812, 83, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[27218, 816, 323, 6, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[27556, 825, 1179, 34, 70, "Text",
  CellTags->{"S3.1.1", "1.31"}],
Cell[28738, 861, 1003, 23, 70, "Text",
  CellTags->{"S3.1.1", "1.32"}],
Cell[29744, 886, 68, 1, 70, "Caption",
  CellTags->"S3.1.1"],
Cell[29815, 889, 504, 17, 70, "Text",
  CellTags->{"S3.1.1", "1.33"}],
Cell[30322, 908, 327, 11, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.34"}],

Cell[CellGroupData[{
Cell[30674, 923, 95, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[30772, 927, 275, 6, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[31062, 936, 127, 4, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.35"}],

Cell[CellGroupData[{
Cell[31214, 944, 87, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[31304, 948, 331, 7, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[31650, 958, 466, 17, 70, "Text",
  CellTags->{"S3.1.1", "1.36"}],
Cell[32119, 977, 718, 17, 70, "Text",
  CellTags->{"S3.1.1", "1.37"}],
Cell[32840, 996, 65, 1, 70, "Caption",
  CellTags->"S3.1.1"],
Cell[32908, 999, 232, 7, 70, "MathCaption",
  CellTags->{"S3.1.1", "1.38"}],

Cell[CellGroupData[{
Cell[33165, 1010, 97, 2, 70, "Input",
  CellTags->"S3.1.1"],
Cell[33265, 1014, 454, 9, 70, "Output",
  CellTags->"S3.1.1"]
}, Open  ]],
Cell[33734, 1026, 107, 1, 70, "Subsection",
  CellTags->{"S3.1.2", "2.1"}],
Cell[33844, 1029, 752, 21, 70, "Text",
  CellTags->{"S3.1.2", "2.2"}],
Cell[34599, 1052, 273, 6, 70, "DisplayFormula",
  CellTags->{"S3.1.2", "2.3"}],
Cell[34875, 1060, 51, 1, 70, "Text",
  CellTags->{"S3.1.2", "2.4"}],
Cell[34929, 1063, 277, 6, 70, "DisplayFormula",
  CellTags->{"S3.1.2", "2.5"}],
Cell[35209, 1071, 610, 17, 70, "Text",
  CellTags->{"S3.1.2", "2.6"}],
Cell[35822, 1090, 2148, 43, 70, "Text",
  CellTags->{"S3.1.2", "2.7"}],
Cell[37973, 1135, 87, 1, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[38063, 1138, 1867, 63, 70, "Text",
  CellTags->{"S3.1.2", "2.8"}],
Cell[39933, 1203, 95, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.9"}],

Cell[CellGroupData[{
Cell[40053, 1208, 89, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[40145, 1212, 193, 4, 70, "Output",
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[40353, 1219, 240, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.10"}],
Cell[40596, 1228, 90, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[40689, 1232, 644, 21, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.11"}],

Cell[CellGroupData[{
Cell[41358, 1257, 79, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[41440, 1261, 168, 4, 70, "Output",
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[41623, 1268, 365, 13, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.12"}],

Cell[CellGroupData[{
Cell[42013, 1285, 116, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[42132, 1289, 5626, 373, 70, 5553, 370, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[47773, 1665, 403, 11, 70, "Text",
  CellTags->{"S3.1.2", "2.13"}],
Cell[48179, 1678, 298, 9, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.14"}],

Cell[CellGroupData[{
Cell[48502, 1691, 108, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[48613, 1695, 176, 5, 70, "Output",
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[48804, 1703, 327, 11, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.15"}],

Cell[CellGroupData[{
Cell[49156, 1718, 77, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[49236, 1722, 102, 3, 70, "Output",
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[49353, 1728, 275, 8, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.16"}],

Cell[CellGroupData[{
Cell[49653, 1740, 167, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[49823, 1747, 10707, 715, 70, 10634, 712, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[60545, 2465, 138, 4, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.17"}],
Cell[60686, 2471, 147, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[60836, 2478, 311, 10, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.18"}],

Cell[CellGroupData[{
Cell[61172, 2492, 211, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[61386, 2500, 14462, 950, 70, 14389, 947, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[75863, 3453, 97, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.19"}],
Cell[75963, 3456, 89, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[76055, 3460, 214, 8, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.20"}],
Cell[76272, 3470, 119, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[76394, 3474, 191, 5, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.21"}],

Cell[CellGroupData[{
Cell[76610, 3483, 171, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[76784, 3491, 8948, 658, 70, 8875, 655, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[85747, 4152, 400, 13, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.22"}],

Cell[CellGroupData[{
Cell[86172, 4169, 211, 7, 70, "Input",
  CellTags->"S3.1.2"],
Cell[86386, 4178, 14052, 1004, 70, 13979, 1001, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[100453, 5185, 209, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.23"}],

Cell[CellGroupData[{
Cell[100687, 5196, 211, 7, 70, "Input",
  CellTags->"S3.1.2"],
Cell[100901, 5205, 14559, 1046, 70, 14486, 1043, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[115475, 6254, 252, 5, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.24"}],

Cell[CellGroupData[{
Cell[115752, 6263, 195, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[115950, 6271, 380134, 9552, 70, 380061, 9549, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[496099, 15826, 846, 27, 70, "Text",
  CellTags->{"S3.1.2", "2.25"}],
Cell[496948, 15855, 223, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.26"}],
Cell[497174, 15864, 102, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[497279, 15868, 104, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.27"}],

Cell[CellGroupData[{
Cell[497408, 15873, 95, 2, 70, "Input",
  CellTags->"S3.1.2"],
Cell[497506, 15877, 459, 9, 70, "Output",
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[497980, 15889, 363, 12, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.28"}],

Cell[CellGroupData[{
Cell[498368, 15905, 172, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[498543, 15913, 18208, 1194, 70, 18135, 1191, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[516766, 17110, 600, 20, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.29"}],

Cell[CellGroupData[{
Cell[517391, 17134, 164, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[517558, 17142, 13129, 858, 70, 13056, 855, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[530702, 18003, 599, 19, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.30"}],

Cell[CellGroupData[{
Cell[531326, 18026, 186, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[531515, 18034, 10287, 690, 70, 10214, 687, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[541817, 18727, 83, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.31"}],

Cell[CellGroupData[{
Cell[541925, 18732, 178, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[542106, 18740, 13272, 870, 70, 13199, 867, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[555393, 19613, 693, 20, 70, "Text",
  CellTags->{"S3.1.2", "2.32"}],
Cell[556089, 19635, 144, 4, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.33"}],
Cell[556236, 19641, 130, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[556369, 19648, 105, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.34"}],

Cell[CellGroupData[{
Cell[556499, 19653, 166, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[556668, 19660, 12599, 849, 70, 12526, 846, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[569282, 20512, 275, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.35"}],

Cell[CellGroupData[{
Cell[569582, 20523, 257, 7, 70, "Input",
  CellTags->"S3.1.2"],
Cell[569842, 20532, 12835, 867, 70, 12762, 864, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[582692, 21402, 1359, 30, 70, "Text",
  CellTags->{"S3.1.2", "2.36"}],
Cell[584054, 21434, 197, 9, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[584254, 21445, 1322, 35, 70, "Text",
  CellTags->{"S3.1.2", "2.37"}],
Cell[585579, 21482, 496, 9, 70, "DisplayFormula",
  CellTags->{"S3.1.2", "2.38"}],
Cell[586078, 21493, 2055, 66, 70, "Text",
  CellTags->{"S3.1.2", "2.39"}],
Cell[588136, 21561, 5290, 105, 70, "Text",
  CellTags->{"S3.1.2", "2.40"}],
Cell[593429, 21668, 284, 11, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[593716, 21681, 436, 14, 70, "Text",
  CellTags->{"S3.1.2", "2.41"}],
Cell[594155, 21697, 83, 1, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.42"}],

Cell[CellGroupData[{
Cell[594263, 21702, 166, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[594432, 21709, 12467, 831, 70, 12394, 828, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[606914, 22543, 425, 13, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.43"}],

Cell[CellGroupData[{
Cell[607364, 22560, 179, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[607546, 22567, 7748, 518, 70, 7675, 515, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[615309, 23088, 423, 14, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.44"}],

Cell[CellGroupData[{
Cell[615757, 23106, 181, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[615941, 23113, 8977, 603, 70, 8904, 600, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[624933, 23719, 423, 13, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.45"}],

Cell[CellGroupData[{
Cell[625381, 23736, 183, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[625567, 23743, 7995, 537, 70, 7922, 534, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[633577, 24283, 676, 23, 70, "Text",
  CellTags->{"S3.1.2", "2.46"}],
Cell[634256, 24308, 989, 22, 70, "Text",
  CellTags->{"S3.1.2", "2.47"}],
Cell[635248, 24332, 171, 6, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[635422, 24340, 205, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.48"}],

Cell[CellGroupData[{
Cell[635652, 24351, 170, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[635825, 24358, 6034, 421, 70, 5961, 418, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[641874, 24782, 554, 13, 70, "Text",
  CellTags->{"S3.1.2", "2.49"}],
Cell[642431, 24797, 191, 4, 70, "DisplayFormula",
  CellTags->{"S3.1.2", "2.50"}],
Cell[642625, 24803, 52, 1, 70, "Text",
  CellTags->{"S3.1.2", "2.51"}],
Cell[642680, 24806, 198, 4, 70, "DisplayFormula",
  CellTags->{"S3.1.2", "2.52"}],
Cell[642881, 24812, 1606, 50, 70, "Text",
  CellTags->{"S3.1.2", "2.53"}],
Cell[644490, 24864, 2245, 43, 70, "Text",
  CellTags->{"S3.1.2", "2.54"}],
Cell[646738, 24909, 85, 1, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[646826, 24912, 770, 29, 70, "Text",
  CellTags->{"S3.1.2", "2.55"}],
Cell[647599, 24943, 1208, 27, 70, "Text",
  CellTags->{"S3.1.2", "2.56"}],
Cell[648810, 24972, 193, 9, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[649006, 24983, 2497, 53, 70, "Text",
  CellTags->{"S3.1.2", "2.57"}],
Cell[651506, 25038, 115, 5, 70, "Caption",
  CellTags->"S3.1.2"],
Cell[651624, 25045, 255, 7, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.58"}],

Cell[CellGroupData[{
Cell[651904, 25056, 186, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[652093, 25064, 4822, 327, 70, 4749, 324, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[656930, 25394, 975, 31, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.59"}],

Cell[CellGroupData[{
Cell[657930, 25429, 260, 8, 70, "Input",
  CellTags->"S3.1.2"],
Cell[658193, 25439, 5027, 332, 70, 4954, 329, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[663235, 25774, 283, 8, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.60"}],

Cell[CellGroupData[{
Cell[663543, 25786, 267, 8, 70, "Input",
  CellTags->"S3.1.2"],
Cell[663813, 25796, 4880, 317, 70, 4807, 314, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[668708, 26116, 440, 12, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.61"}],

Cell[CellGroupData[{
Cell[669173, 26132, 178, 5, 70, "Input",
  CellTags->"S3.1.2"],
Cell[669354, 26139, 9422, 622, 70, 9349, 619, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[678791, 26764, 340, 11, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.62"}],

Cell[CellGroupData[{
Cell[679156, 26779, 227, 7, 70, "Input",
  CellTags->"S3.1.2"],
Cell[679386, 26788, 14581, 948, 70, 14508, 945, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[693982, 27739, 340, 11, 70, "MathCaption",
  CellTags->{"S3.1.2", "2.63"}],

Cell[CellGroupData[{
Cell[694347, 27754, 199, 6, 70, "Input",
  CellTags->"S3.1.2"],
Cell[694549, 27762, 8277, 555, 70, 8204, 552, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.2"]
}, Open  ]],
Cell[702841, 28320, 391, 14, 70, "Subsection",
  CellTags->{"S3.1.3", "3.1"}],
Cell[703235, 28336, 1004, 33, 70, "Text",
  CellTags->{"S3.1.3", "3.2"}],
Cell[704242, 28371, 1840, 41, 70, "Text",
  CellTags->{"S3.1.3", "3.3"}],
Cell[706085, 28414, 66, 1, 70, "Caption",
  CellTags->"S3.1.3"],
Cell[706154, 28417, 2630, 82, 70, "Text",
  CellTags->{"S3.1.3", "3.4"}],
Cell[708787, 28501, 303, 7, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.5"}],
Cell[709093, 28510, 152, 5, 70, "Input",
  CellTags->"S3.1.3"],
Cell[709248, 28517, 98, 1, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.6"}],

Cell[CellGroupData[{
Cell[709371, 28522, 164, 5, 70, "Input",
  CellTags->"S3.1.3"],
Cell[709538, 28529, 4531, 320, 70, 4458, 317, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[714084, 28852, 251, 7, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.7"}],
Cell[714338, 28861, 119, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[714460, 28865, 378, 10, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.8"}],

Cell[CellGroupData[{
Cell[714863, 28879, 83, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[714949, 28883, 237, 6, 70, "Output",
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[715201, 28892, 320, 11, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.9"}],

Cell[CellGroupData[{
Cell[715546, 28907, 156, 5, 70, "Input",
  CellTags->"S3.1.3"],
Cell[715705, 28914, 6674, 501, 70, 6601, 498, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[722394, 29418, 451, 14, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.10"}],

Cell[CellGroupData[{
Cell[722870, 29436, 161, 5, 70, "Input",
  CellTags->"S3.1.3"],
Cell[723034, 29443, 86, 3, 70, "Output",
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[723135, 29449, 142, 5, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.11"}],
Cell[723280, 29456, 117, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[723400, 29460, 419, 15, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.12"}],

Cell[CellGroupData[{
Cell[723844, 29479, 84, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[723931, 29483, 92, 3, 70, "Output",
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[724038, 29489, 224, 7, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.13"}],

Cell[CellGroupData[{
Cell[724287, 29500, 170, 5, 70, "Input",
  CellTags->"S3.1.3"],
Cell[724460, 29507, 13167, 927, 70, 13094, 924, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[737642, 30437, 363, 12, 70, "Text",
  CellTags->{"S3.1.3", "3.14"}],
Cell[738008, 30451, 213, 7, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.15"}],
Cell[738224, 30460, 121, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[738348, 30464, 217, 7, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.16"}],
Cell[738568, 30473, 109, 2, 70, "Input",
  CellTags->"S3.1.3"],
Cell[738680, 30477, 116, 2, 70, "MathCaption",
  CellTags->{"S3.1.3", "3.17"}],

Cell[CellGroupData[{
Cell[738821, 30483, 190, 6, 70, "Input",
  CellTags->"S3.1.3"],
Cell[739014, 30491, 10384, 772, 70, 10311, 769, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.3"]
}, Open  ]],
Cell[749413, 31266, 276, 9, 70, "Text",
  CellTags->{"S3.1.3", "3.18"}],
Cell[749692, 31277, 289, 10, 70, "Subsection",
  CellTags->{"S3.1.4", "4.1"}],
Cell[749984, 31289, 359, 11, 70, "Text",
  CellTags->{"S3.1.4", "4.2"}],
Cell[750346, 31302, 397, 8, 70, "DisplayFormula",
  CellTags->{"S3.1.4", "4.3"}],
Cell[750746, 31312, 51, 1, 70, "Text",
  CellTags->{"S3.1.4", "4.4"}],
Cell[750800, 31315, 402, 8, 70, "DisplayFormula",
  CellTags->{"S3.1.4", "4.5"}],
Cell[751205, 31325, 1532, 44, 70, "Text",
  CellTags->{"S3.1.4", "4.6"}],
Cell[752740, 31371, 1930, 39, 70, "Text",
  CellTags->{"S3.1.4", "4.7"}],
Cell[754673, 31412, 85, 1, 70, "Caption",
  CellTags->"S3.1.4"],
Cell[754761, 31415, 272, 8, 70, "MathCaption",
  CellTags->{"S3.1.4", "4.8"}],
Cell[755036, 31425, 109, 2, 70, "Input",
  CellTags->"S3.1.4"],
Cell[755148, 31429, 224, 7, 70, "MathCaption",
  CellTags->{"S3.1.4", "4.9"}],

Cell[CellGroupData[{
Cell[755397, 31440, 176, 5, 70, "Input",
  CellTags->"S3.1.4"],
Cell[755576, 31447, 26080, 1693, 70, 26007, 1690, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.4"]
}, Open  ]],
Cell[781671, 33143, 147, 4, 70, "MathCaption",
  CellTags->{"S3.1.4", "4.10"}],

Cell[CellGroupData[{
Cell[781843, 33151, 228, 6, 70, "Input",
  CellTags->"S3.1.4"],
Cell[782074, 33159, 23771, 1568, 70, 23698, 1565, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.1.4"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

