(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    110956,       4020]*)
(*NotebookOutlinePosition[    144590,       5009]*)
(*  CellTagsIndexPosition[    141265,       4877]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["3.2 Various Transforms", "Section",
  CellTags->"Contents"],

Cell[TextData[{
  ButtonBox["3.2.1 Wavelet Transforms",
    ButtonData:>{"Wavelets 3.2.1"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.2.2 Wavelet Packet Transforms",
    ButtonData:>{"Wavelets 3.2.2"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.2.3 Local Sine and Cosine Transforms",
    ButtonData:>{"Wavelets 3.2.3"},
    ButtonStyle->"AddOnsLink"],
  "\n",
  ButtonBox["3.2.4 Sine and Cosine Packet Transforms",
    ButtonData:>{"Wavelets 3.2.4"},
    ButtonStyle->"AddOnsLink"],
  "\n "
}], "Contents",
  CellTags->"Contents"],

Cell["3.2 Various Transforms", "Section",
  CellTags->{"S3.2.0", "0.1"}],

Cell["3.2.1 Wavelet Transforms", "Subsection",
  CellTags->{"S3.2.1", "1.1"}],

Cell[TextData[{
  "Representing a function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " in terms of a wavelet basis is accomplished by doing a wavelet transform. \
The approximation ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_J\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " can be written in terms of the wavelet basis ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\[Psi]\_\(j  k\)\) \((t)\) = \(2\^\(j/2\)\) \[Psi] \((
          \(2\^j\) t - k)\)}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm
      \`{\(\[Phi]\_\(\(j\_0\) k\)\) \((t)\) = \(2\^\(j\_0/2\)\) \[Phi] \((
          \(2\^j\_0\) t - k)\)}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " as "
}], "Text",
  CellTags->{"S3.2.1", "1.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_J\), \((t)\), "=", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%J\), \(\[Phi]\_\(J  k\)\), \((t)
        \), "=", 
        UnderoverscriptBox["\[Sum]", \(l = j\_0\), \(J - 1\),
          LimitsPositioning->True], 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(d\_k\%l\), \(\[Psi]\_\(l  k\)\), \((t)
        \), "+", 
        UnderscriptBox["\[Sum]", "k",
          LimitsPositioning->True], \(f\_k\%j\_0\), 
        \(\[Phi]\_\(\(j\_0\) k\)\), \((t)\)}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S3.2.1", "1.3"}],

Cell[TextData[{
  "where the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k\%j\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_k\%j\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " are given by the inner products "
}], "Text",
  CellTags->{"S3.2.1", "1.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(f\_k\%j\), "=", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "f", 
        \((t)\), \(\[Phi]\_\(j  k\)\), \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], \("and"\), \(d\_k\%j\), "=", 
        \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), "f", \((t)\), 
        \(\[Psi]\_\(j  k\)\), \((t)\), " ", 
        StyleBox[\("dt"\),
          "TI"], "."}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.1", "1.5"}],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_k\%j}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " represent the smooth part or trend of the function at resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`{d\_k\%j}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ", the details. A (forward) wavelet transform decomposes a trend into a \
trend and details at the next coarser level iteratively, thus transforming ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0\%J, f\_1\%J, \[Ellipsis], f\_\(N - 1\)\%J}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  " into "
}], "Text",
  CellTags->{"S3.2.1", "1.6"}],

Cell[BoxData[
    \(TraditionalForm
    \`{{f\_0\%j\_0, f\_1\%j\_0, \[Ellipsis]}, {d\_0\%j\_0, d\_1\%j\_0, 
        \[Ellipsis]}, {d\_0\%\(j\_0 + 1\), d\_1\%\(j\_0 + 1\), \[Ellipsis]}, 
      \[Ellipsis], {d\_0\%\(J - 1\), d\_1\%\(J - 1\), \[Ellipsis], 
        d\_\(N/2 - 1\)\%\(J - 1\)}}\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.1) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.2.1", "1.7"}],

Cell["using the formulas ", "Text",
  CellTags->{"S3.2.1", "1.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_k\%\(j - 1\)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(l - 2  k\)\), \(f\_l\%j\), 
        \("and"\), \(d\_k\%\(j - 1\)\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(l - 2  k\)\), \(f\_l\%j\), "."}], 
      TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.2) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.2.1", "1.9"}],

Cell["The inverse wavelet transform does the inverse using ", "Text",
  CellTags->{"S3.2.1", "1.10"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_k\%j\), "=", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(h\_\(k - 2  l\)\), " ", 
        \(f\_l\%\(j - 1\)\), "+", 
        UnderscriptBox["\[Sum]", "l",
          LimitsPositioning->True], \(g\_\(k - 2  l\)\), " ", 
        \(d\_l\%\(j - 1\)\), "."}], TraditionalForm]], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.3) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.2.1", "1.11"}],

Cell[TextData[{
  "It is conventional to take a set of sampled data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f\_k = f \((k/2\^J)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " in appropriate units, to be the inner products ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0\%J, f\_1\%J, \[Ellipsis], f\_\(N - 1\)\%J}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  " with a proportionality constant which is often ignored. A wavelet \
transform transforms the data into the form (",
  ButtonBox["2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  "). Here the coarsest level ",
  Cell[BoxData[
      \(TraditionalForm\`j\_0\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " is defined to be the level where the length of the trend is either odd or \
smaller than the length of filter ",
  Cell[BoxData[
      \(TraditionalForm\`{h\_k}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ". Applying the decomposition formulas (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 3.2.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  ") once constitutes one decomposition. For example, decomposing the data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0\%J, f\_1\%J, \[Ellipsis], f\_\(N - 1\)\%J}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  " once gives "
}], "Text",
  CellTags->{"S3.2.1", "1.12"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{f\_0\%\(J - 1\), f\_1\%\(J - 1\), \[Ellipsis], 
          f\_\(N/2 - 1\)\%\(J - 1\)}, {d\_0\%\(J - 1\), d\_1\%\(J - 1\), 
          \[Ellipsis], d\_\(N/2 - 1\)\%\(J - 1\)}}.\)\)], "DisplayFormula",
  CellTags->{"S3.2.1", "1.13"}],

Cell["The following functions are used to do wavelet transforms. ", "Text",
  CellTags->{"S3.2.1", "1.14"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WaveletTransform[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do wavelet transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \\\"TI\\\"]\\) using filter \
\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WaveletTransform[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("do wavelet transform and stop after "\), 
                    StyleBox["l",
                      "InlineFormula"], \(" decompositions "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InverseWaveletTransform[\
\\\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"wtdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do inverse wavelet transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"wtdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.1", "1.15"}],

Cell["Functions doing wavelet transforms.", "Caption",
  CellTags->"S3.2.1"],

Cell[TextData[{
  "The argument ",
  StyleBox["data", "TI"],
  " is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " is a number for one\[Hyphen]dimensional data and a list ",
  Cell[BoxData[
      \(TraditionalForm
      \`{f\_\(i  0\), f\_\(i  1\), \[Ellipsis], f\_\(i, M - 1\)}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  " for two\[Hyphen]dimensional data. As always, ",
  StyleBox["filter", "TI"],
  " is the lowpass filter ",
  Cell[BoxData[
      \(TraditionalForm\`{{h\_\(-m\), h\_\(-m + 1\), \[Ellipsis]}, -m}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  ". The third argument in ",
  StyleBox["WaveletTransform", "MR"],
  " specifies the number of times the decomposition is done and when it is \
omitted, (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 3.2.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  ") is repeatedly used to decompose the trend until the coarsest level is \
reached. The output of ",
  StyleBox["WaveletTransform", "MR"],
  " is of the form (",
  ButtonBox["2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.7"},
    ButtonStyle->"AddOnsLink"],
  ") for one\[Hyphen]dimensional data. For two\[Hyphen]dimensional data, the \
output is "
}], "Text",
  CellTags->{"S3.2.1", "1.16"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({f\^j\_0, {d\^\(\((I)\) j\_0\), d\^\(\((I  I)\) j\_0\), 
        d\^\(\((I  I  I)\) j\_0\)}, 
      \[Ellipsis], {d\^\(\((I)\) J - 1\), d\^\(\((I  I)\) J - 1\), 
        d\^\(\((I  I  I)\) J - 1\)}}, \)\)], "DisplayFormula",
  CellTags->{"S3.2.1", "1.17"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\^j\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " is the trend matrix at resolution level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(\((S)\) j\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`S = I, I  I\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`I  I  I\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ") is the detail matrix. Matrix ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(\((I)\) j\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " contains the smooth part in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " direction and details in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " direction, matrix ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(\((I  I)\) j\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " contains the details in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " direction and smooth part in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " direction, and matrix ",
  Cell[BoxData[
      \(TraditionalForm\`d\^\(\((I  I  I)\) j\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " contains the details in both ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " directions. \nAs a simple example to illustrate how the functions are \
used, we do wavelet transforms on a set of random data of length 12 using the \
Haar filter. "
}], "Text",
  CellTags->{"S3.2.1", "1.18"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S3.2.1", "1.19"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S3.2.1"],

Cell["Here is a set of random data of length 12.", "MathCaption",
  CellTags->{"S3.2.1", "1.20"}],

Cell["\<\
(d1 = DaubechiesFilter[1];
SeedRandom[239541];
data = Table[Random[], {12}];)\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S3.2.1"],

Cell["\<\
The decomposition is stopped when the length of the trend part is \
either odd or less than the filter length.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.21"}],

Cell[CellGroupData[{

Cell["wtdata = WaveletTransform[data, d1]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{0.624594339448571034`, 0.832341360801927976`, 1.2892401054530862`}, {
        \(-0.504941958885006947`\), 0.266549873902391931`, 
        0.17687289153846752`}, {\(-0.000634042341240896156`\), 
        0.393714166152546507`, \(-0.558591717128805864`\), 
        0.354764324581653944`, 0.0073669161642359624`, 
        \(-0.619794460613516129`\)}}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["\<\
Here is an example where the wavelet decomposition is done only \
once with the Haar filter.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.22"}],

Cell[CellGroupData[{

Cell["WaveletTransform[data, d1, 1]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{0.084607009681609604`, 0.798702776148024096`, 0.777033443845882487`, 
        0.400074997124281495`, 1.03669844215845996`, 0.786562400128613781`}, {
        \(-0.000634042341240896156`\), 0.393714166152546507`, 
        \(-0.558591717128805864`\), 0.354764324581653944`, 
        0.0073669161642359624`, \(-0.619794460613516129`\)}}\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "This gives the inverse wavelet transform. Note that the first argument of \
",
  StyleBox["InverseWaveletTransform", "MR"],
  " should be in the form of the output of ",
  StyleBox["WaveletTransform", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.23"}],

Cell["InverseWaveletTransform[%, d1];", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S3.2.1"],

Cell["We check that we recover the original data.", "MathCaption",
  CellTags->{"S3.2.1", "1.24"}],

Cell[CellGroupData[{

Cell["Chop[data-%]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["\<\
Again the original data are recovered within machine \
precision.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.25"}],

Cell[CellGroupData[{

Cell["Max[Abs[data-InverseWaveletTransform[wtdata, d1]]]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \(3.33066907387546962`*^-16\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "This computes the wavelet transform of two\[Hyphen]dimensional data ",
  StyleBox["data2d", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.26"}],

Cell["\<\
(data2d = Table[Random[], {12}, {12}];
wtdata = WaveletTransform[data2d, d1];)\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S3.2.1"],

Cell["This shows how the detail matrices are grouped together.", "MathCaption",
  CellTags->{"S3.2.1", "1.27"}],

Cell[CellGroupData[{

Cell["Dimensions /@ wtdata", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{3, 3}, {3, 3, 3}, {3, 6, 6}}\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["The inverse transform gives back the original data.", "MathCaption",
  CellTags->{"S3.2.1", "1.28"}],

Cell[CellGroupData[{

Cell["\<\
Union[Flatten[Chop[data2d - InverseWaveletTransform[wtdata, \
d1]]]]\
\>", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["The boundary points are handled according to the equations ", "Text",
  CellTags->{"S3.2.1", "1.29"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_0\%\(j - 1\)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = -m\), \(-m + L - 1\),
          LimitsPositioning->True], \(h\_k\), \(f\_k\%j\)}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.1", "1.30"}],

Cell["and ", "Text",
  CellTags->{"S3.2.1", "1.31"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(f\_\(N/2 - 1\)\%\(j - 1\)\), "=", 
        UnderoverscriptBox["\[Sum]", \(k = N - 2 - m\), \(N + L - m - 3\),
          LimitsPositioning->True], \(h\_\(k - N + 2\)\), \(f\_k\%j\), ","}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.1", "1.32"}],

Cell[TextData[{
  "so that ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L - 2 - m\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " data points are padded in the front and at the end of data, respectively, \
for the forward transform, where ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " is the starting index of the filter ",
  Cell[BoxData[
      \(TraditionalForm\`h\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " is the length of the filter. (The number of padded sites can be worked \
out for the inverse transform similarly.) Note that we can choose to pad \
boundary sites differently by changing the value of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " in the filter. For example, by changing ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`L/2 - 1\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ", we pad the boundaries symmetrically as is shown below. \nThe values of \
padded sites depend on the boundary condition we use. The default boundary \
condition is periodic. "
}], "Text",
  CellTags->{"S3.2.1", "1.33"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->True}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.1", "1.34"}],

Cell[TextData[{
  "Option for ",
  StyleBox["WaveletTransform", "MR"],
  " and ",
  StyleBox["InverseWaveletTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.1"],

Cell[TextData[{
  "If we define our data to be ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S3.2.1"],
  ", different boundary conditions are defined as follows. "
}], "Text",
  CellTags->{"S3.2.1", "1.35"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"Fixed\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("set "\), 
                    StyleBox[\(f\_\(-i\) = f\_0\),
                      "InlineFormula"], \(" and "\), 
                    StyleBox[\(f\_\(N - 1 + i\) = f\_\(N - 1\)\),
                      "InlineFormula"], \(" for "\), 
                    StyleBox[\(i > 0\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("set "\), 
                    StyleBox[\(f\_\(i + N\) = f\_i\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"Reflective\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", 
                  RowBox[{\("set "\), 
                    StyleBox[\(f\_\(-i\) = f\_\(i - 1\)\),
                      "InlineFormula"], \(" and "\), 
                    StyleBox[\(f\_\(N - 1 + i\) = f\_\(N - i\)\),
                      "InlineFormula"], \(" for "\), 
                    StyleBox[\(i > 0\),
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"Zero\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("set "\), 
                    StyleBox[\(f\_i = 0\),
                      "InlineFormula"], \(" for "\), 
                    StyleBox[\(i < 0\),
                      "InlineFormula"], \(" and "\), 
                    StyleBox[\(i > N - 1\),
                      "InlineFormula"], \(" "\)}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.1", "1.36"}],

Cell[TextData[{
  "Settings for the ",
  StyleBox["BoundaryCondition", "MR"],
  " option."
}], "Caption",
  CellTags->"S3.2.1"],

Cell["We generate the second\[Hyphen]order Daubechies filter.", "MathCaption",
  CellTags->{"S3.2.1", "1.37"}],

Cell[CellGroupData[{

Cell["d2=DaubechiesFilter[2]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{0.482962913144534056`, 0.836516303737807831`, 0.224143868042013361`, 
        \(-0.129409522551260369`\)}, 0}\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "By changing the starting index to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ", we pad the boundary symmetrically in the following wavelet transform."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.38"}],

Cell[CellGroupData[{

Cell["MapAt[-1&, d2, {2}]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{0.482962913144534056`, 0.836516303737807831`, 0.224143868042013361`, 
        \(-0.129409522551260369`\)}, \(-1\)}\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["The zero boundary condition is used in this transform.", "MathCaption",
  CellTags->{"S3.2.1", "1.39"}],

Cell[CellGroupData[{

Cell["WaveletTransform[data, %, BoundaryCondition -> Zero]", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({{0.0830269401877606583`, 0.800583743871509589`, 
        1.19737929704092294`}, {\(-0.463555620619512254`\), 
        \(-0.111291645656724957`\), \(-0.282617811959894016`\)}, {
        0.370106517154199998`, 0.0318365121126722172`, 
        \(-0.460567686645071994`\), 0.571608823354563888`, 
        \(-0.382279881581419935`\), \(-0.711246983689134992`\)}}\)], "Output",\

  CellLabel->"Out[13]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["\<\
Note that, in general, boundary conditions other than periodic do \
not give perfect reconstruction. That is, the original data cannot be \
recovered exactly due to the influence of the boundaries.\
\>", "MathCaption",\

  CellTags->{"S3.2.1", "1.40"}],

Cell[CellGroupData[{

Cell["\<\
Chop[data-InverseWaveletTransform[%, %%,
BoundaryCondition -> Zero]]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({0.00523853482056987918`, \(-0.00257390087525907773`\), 
      0.00148604236319849203`, 0, 0, 0, 0, 0, 0, 0.0812665006908884812`, 
      0.140757708149949696`, 0.286327032476981013`}\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "The multiresolution decomposition of a signal consists of writing ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_J\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " as "
}], "Text",
  CellTags->{"S3.2.1", "1.41"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(f\_J\) \((t)\) = \(f\_\(j\_0\)\) \((t)\) + \(d\_\(j\_0\)\) \((t)\) + 
      \(d\_\(j\_0 + 1\)\) \((t)\) + \[CenterEllipsis] + \(d\_\(J - 1\)\) \((t)
      \).\)], "DisplayFormula",
  CellTags->{"S3.2.1", "1.42"}],

Cell[TextData[{
  "In practice, we calculate the multiresolution decomposition at dyadic \
points ",
  Cell[BoxData[
      \(TraditionalForm\`{k/2\^J}\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ". The function ",
  StyleBox["MRDecomposition", "MR"],
  " gives the above decomposition in the form "
}], "Text",
  CellTags->{"S3.2.1", "1.43"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{f\_\(\(j\_0\) 0\), f\_\(\(j\_0\) 1\), \[Ellipsis], 
        f\_\(\(j\_0\) N - 1\)}, {d\_\(\(j\_0\) 0\), d\_\(\(j\_0\) 1\), 
        \[Ellipsis], d\_\(\(j\_0\) N - 1\)}, 
      \[Ellipsis], {d\_\(J - 1, 0\), d\_\(J - 1, 1\), \[Ellipsis], 
        d\_\(J - 1, N - 1\)}}, \)\)], "DisplayFormula",
  CellTags->{"S3.2.1", "1.44"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`d\_\(j  k\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(j  k\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ") is the inner product of ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_j\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ") and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(J  k\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  ". "
}], "Text",
  CellTags->{"S3.2.1", "1.45"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MRDecomposition[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"wtdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"calculate multiresolution decomposition from wavelet transformed \
data \\!\\(\\*StyleBox[\\\"\\\\\\\"wtdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.1", "1.46"}],

Cell["Function doing multiresolution decomposition.", "Caption",
  CellTags->"S3.2.1"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->True}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.1", "1.47"}],

Cell[TextData[{
  "Option for ",
  StyleBox["MRDecomposition", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.1"],

Cell["We generate linear chirp data of length 64.", "MathCaption",
  CellTags->{"S3.2.1", "1.48"}],

Cell["data = Sin[N[25Pi](Range[0, 63]/64)^2];", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S3.2.1"],

Cell[TextData[{
  "To get the multiresolution decomposition of ",
  StyleBox["data", "MR"],
  ", we first do wavelet transform on ",
  StyleBox["data", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.49"}],

Cell["\<\
(wtdata = WaveletTransform[data, d2];
 mrdata = MRDecomposition[wtdata, d2];)\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S3.2.1"],

Cell["\<\
The original data are split into a trend plus details at different \
resolution levels.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.50"}],

Cell[CellGroupData[{

Cell["Length /@ mrdata", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({64, 64, 64, 64, 64, 64}\)], "Output",
  CellLabel->"Out[17]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "We use ",
  StyleBox["PlotCoefficients", "MR"],
  " to plot each level of the decomposition and stack them together. The \
bottom plot is the trend ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_\(j\_0\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  "; the top plot, the finest details ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_\(J - 1\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.51"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[mrdata, PlotLines -> False,
PlotJoined -> True]\
\>", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S3.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 -0.0923038 0.0455388 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01854 m
.03869 .01839 L
.05357 .0183 L
.06845 .0182 L
.08333 .01816 L
.09821 .0181 L
.1131 .01803 L
.12798 .01796 L
.14286 .01795 L
.15774 .01793 L
.17262 .01789 L
.1875 .01786 L
.20238 .0178 L
.21726 .01776 L
.23214 .01771 L
.24702 .01767 L
.2619 .01769 L
.27679 .01769 L
.29167 .01768 L
.30655 .01767 L
.32143 .01764 L
.33631 .01762 L
.35119 .0176 L
.36607 .01759 L
.38095 .01755 L
.39583 .01752 L
.41071 .01749 L
.4256 .01746 L
.44048 .01744 L
.45536 .01741 L
.47024 .01739 L
.48512 .01736 L
.5 .01758 L
.51488 .01773 L
.52976 .01782 L
.54464 .01793 L
.55952 .01797 L
.5744 .01802 L
.58929 .0181 L
.60417 .01817 L
.61905 .01817 L
.63393 .01819 L
.64881 .01823 L
.66369 .01827 L
.67857 .01832 L
.69345 .01837 L
.70833 .01841 L
.72321 .01846 L
.7381 .01843 L
.75298 .01843 L
Mistroke
.76786 .01844 L
.78274 .01845 L
.79762 .01848 L
.8125 .0185 L
.82738 .01852 L
.84226 .01854 L
.85714 .01858 L
.87202 .01861 L
.8869 .01863 L
.90179 .01866 L
.91667 .01869 L
.93155 .01871 L
.94643 .01874 L
.96131 .01876 L
Mfstroke
.02381 .12409 m
.03869 .12458 L
.05357 .12499 L
.06845 .12542 L
.08333 .12576 L
.09821 .12614 L
.1131 .12653 L
.12798 .12691 L
.14286 .12722 L
.15774 .12755 L
.17262 .12789 L
.1875 .12824 L
.20238 .1286 L
.21726 .12896 L
.23214 .12931 L
.24702 .12967 L
.2619 .12697 L
.27679 .1251 L
.29167 .12404 L
.30655 .12276 L
.32143 .12229 L
.33631 .12161 L
.35119 .12071 L
.36607 .11987 L
.38095 .11985 L
.39583 .1196 L
.41071 .11914 L
.4256 .11874 L
.44048 .11812 L
.45536 .11755 L
.47024 .11705 L
.48512 .11652 L
.5 .11747 L
.51488 .11802 L
.52976 .11818 L
.54464 .11844 L
.55952 .11831 L
.5744 .11829 L
.58929 .11837 L
.60417 .11842 L
.61905 .11809 L
.63393 .11785 L
.64881 .11772 L
.66369 .11757 L
.67857 .11751 L
.69345 .11744 L
.70833 .11733 L
.72321 .11723 L
.7381 .11841 L
.75298 .11924 L
Mistroke
.76786 .11974 L
.78274 .12032 L
.79762 .12056 L
.8125 .1209 L
.82738 .12132 L
.84226 .12172 L
.85714 .12178 L
.87202 .12193 L
.8869 .12218 L
.90179 .12239 L
.91667 .1227 L
.93155 .12299 L
.94643 .12325 L
.96131 .12352 L
Mfstroke
.02381 .22971 m
.03869 .23691 L
.05357 .24118 L
.06845 .24623 L
.08333 .24834 L
.09821 .25124 L
.1131 .25493 L
.12798 .2584 L
.14286 .24278 L
.15774 .23227 L
.17262 .22689 L
.1875 .22013 L
.20238 .21849 L
.21726 .21547 L
.23214 .21109 L
.24702 .20707 L
.2619 .21633 L
.27679 .22203 L
.29167 .22418 L
.30655 .22728 L
.32143 .22682 L
.33631 .22731 L
.35119 .22876 L
.36607 .22995 L
.38095 .22888 L
.39583 .22842 L
.41071 .22856 L
.4256 .22854 L
.44048 .22913 L
.45536 .22955 L
.47024 .22981 L
.48512 .23012 L
.5 .22976 L
.51488 .22958 L
.52976 .22958 L
.54464 .22953 L
.55952 .22966 L
.5744 .22974 L
.58929 .22977 L
.60417 .22981 L
.61905 .22896 L
.63393 .22834 L
.64881 .22797 L
.66369 .22753 L
.67857 .22734 L
.69345 .22708 L
.70833 .22675 L
.72321 .22644 L
.7381 .22726 L
.75298 .22778 L
Mistroke
.76786 .228 L
.78274 .22829 L
.79762 .22829 L
.8125 .22836 L
.82738 .22852 L
.84226 .22865 L
.85714 .22634 L
.87202 .22468 L
.8869 .22367 L
.90179 .22249 L
.91667 .22197 L
.93155 .22127 L
.94643 .2204 L
.96131 .21957 L
Mfstroke
.02381 .33304 m
.03869 .32434 L
.05357 .31998 L
.06845 .31445 L
.08333 .32467 L
.09821 .33067 L
.1131 .33245 L
.12798 .33536 L
.14286 .35012 L
.15774 .36171 L
.17262 .37012 L
.1875 .37939 L
.20238 .34534 L
.21726 .3229 L
.23214 .31207 L
.24702 .29812 L
.2619 .32363 L
.27679 .33858 L
.29167 .34294 L
.30655 .35015 L
.32143 .33698 L
.33631 .32927 L
.35119 .32701 L
.36607 .3233 L
.38095 .33665 L
.39583 .34543 L
.41071 .34964 L
.4256 .35507 L
.44048 .34087 L
.45536 .33193 L
.47024 .32824 L
.48512 .32315 L
.5 .32986 L
.51488 .3334 L
.52976 .33378 L
.54464 .33501 L
.55952 .33526 L
.5744 .33576 L
.58929 .33654 L
.60417 .33724 L
.61905 .33726 L
.63393 .33746 L
.64881 .33785 L
.66369 .33819 L
.67857 .33702 L
.69345 .33625 L
.70833 .33589 L
.72321 .33542 L
.7381 .33452 L
.75298 .33373 L
Mistroke
.76786 .33306 L
.78274 .33236 L
.79762 .33613 L
.8125 .33869 L
.82738 .34006 L
.84226 .34175 L
.85714 .33568 L
.87202 .33169 L
.8869 .32978 L
.90179 .32731 L
.91667 .33532 L
.93155 .34053 L
.94643 .34293 L
.96131 .34608 L
Mfstroke
.02381 .43924 m
.03869 .4396 L
.05357 .44358 L
.06845 .44659 L
.08333 .44129 L
.09821 .43822 L
.1131 .44106 L
.12798 .44232 L
.14286 .4475 L
.15774 .45163 L
.17262 .4409 L
.1875 .43416 L
.20238 .4473 L
.21726 .45511 L
.23214 .44845 L
.24702 .44567 L
.2619 .42217 L
.27679 .40422 L
.29167 .4361 L
.30655 .45462 L
.32143 .47412 L
.33631 .49337 L
.35119 .44881 L
.36607 .42135 L
.38095 .41273 L
.39583 .39905 L
.41071 .44539 L
.4256 .47564 L
.44048 .44592 L
.45536 .43227 L
.47024 .43191 L
.48512 .42799 L
.5 .46707 L
.51488 .49463 L
.52976 .43233 L
.54464 .3941 L
.55952 .44989 L
.5744 .48049 L
.58929 .43577 L
.60417 .41123 L
.61905 .44668 L
.63393 .46605 L
.64881 .43494 L
.66369 .41735 L
.67857 .45275 L
.69345 .47395 L
.70833 .43521 L
.72321 .41254 L
.7381 .45304 L
.75298 .47662 L
Mistroke
.76786 .44332 L
.78274 .42525 L
.79762 .43312 L
.8125 .43404 L
.82738 .44516 L
.84226 .45355 L
.85714 .43964 L
.87202 .43171 L
.8869 .4413 L
.90179 .4462 L
.91667 .44962 L
.93155 .45344 L
.94643 .44297 L
.96131 .43632 L
Mfstroke
.02381 .54895 m
.03869 .55062 L
.05357 .54904 L
.06845 .55051 L
.08333 .5491 L
.09821 .55021 L
.1131 .54958 L
.12798 .54938 L
.14286 .55087 L
.15774 .54801 L
.17262 .5527 L
.1875 .54715 L
.20238 .55295 L
.21726 .54887 L
.23214 .54861 L
.24702 .5534 L
.2619 .54211 L
.27679 .55519 L
.29167 .54543 L
.30655 .54826 L
.32143 .56049 L
.33631 .54193 L
.35119 .55722 L
.36607 .55153 L
.38095 .53243 L
.39583 .55851 L
.41071 .55091 L
.4256 .54308 L
.44048 .57056 L
.45536 .54638 L
.47024 .52364 L
.48512 .55974 L
.5 .56404 L
.51488 .541 L
.52976 .55396 L
.54464 .55314 L
.55952 .5298 L
.5744 .55221 L
.58929 .58021 L
.60417 .5433 L
.61905 .51384 L
.63393 .55886 L
.64881 .58734 L
.66369 .53909 L
.67857 .5158 L
.69345 .56168 L
.70833 .57199 L
.72321 .53801 L
.7381 .55079 L
.75298 .55804 L
Mistroke
.76786 .51794 L
.78274 .55149 L
.79762 .60253 L
.8125 .53307 L
.82738 .51297 L
.84226 .57459 L
.85714 .53209 L
.87202 .54182 L
.8869 .60332 L
.90179 .52469 L
.91667 .54136 L
.93155 .57251 L
.94643 .50008 L
.96131 .57888 L
Mfstroke
0 1 1 r
.02381 .01472 m
.97619 .01472 L
s
.02381 .12173 m
.97619 .12173 L
s
.02381 .22875 m
.97619 .22875 L
s
.02381 .33577 m
.97619 .33577 L
s
.02381 .44279 m
.97619 .44279 L
s
.02381 .54981 m
.97619 .54981 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "This plots ",
  Cell[BoxData[
      \(TraditionalForm
      \`\(f\_\(j\_0 + 3\)\) \((t)\) = \(f\_\(j\_0\)\) \((t)\) + 
        \(d\_\(j\_0\)\) \((t)\) + \(d\_\(j\_0 + 1\)\) \((t)\) + 
        \(d\_\(j\_0 + 2\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.2.1"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.52"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[Plus @@ Take[mrdata, 4],
PlotLines -> False, PlotJoined -> True, Axes -> True]\
\>", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S3.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.321061 0.287981 [
[.17262 .30856 -6 -9 ]
[.17262 .30856 6 0 ]
[.32143 .30856 -6 -9 ]
[.32143 .30856 6 0 ]
[.47024 .30856 -6 -9 ]
[.47024 .30856 6 0 ]
[.61905 .30856 -6 -9 ]
[.61905 .30856 6 0 ]
[.76786 .30856 -6 -9 ]
[.76786 .30856 6 0 ]
[.91667 .30856 -6 -9 ]
[.91667 .30856 6 0 ]
[.01131 .03308 -12 -4.5 ]
[.01131 .03308 0 4.5 ]
[.01131 .17707 -24 -4.5 ]
[.01131 .17707 0 4.5 ]
[.01131 .46505 -18 -4.5 ]
[.01131 .46505 0 4.5 ]
[.01131 .60904 -6 -4.5 ]
[.01131 .60904 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17262 .32106 m
.17262 .32731 L
s
[(10)] .17262 .30856 0 1 Mshowa
.32143 .32106 m
.32143 .32731 L
s
[(20)] .32143 .30856 0 1 Mshowa
.47024 .32106 m
.47024 .32731 L
s
[(30)] .47024 .30856 0 1 Mshowa
.61905 .32106 m
.61905 .32731 L
s
[(40)] .61905 .30856 0 1 Mshowa
.76786 .32106 m
.76786 .32731 L
s
[(50)] .76786 .30856 0 1 Mshowa
.91667 .32106 m
.91667 .32731 L
s
[(60)] .91667 .30856 0 1 Mshowa
.125 Mabswid
.05357 .32106 m
.05357 .32481 L
s
.08333 .32106 m
.08333 .32481 L
s
.1131 .32106 m
.1131 .32481 L
s
.14286 .32106 m
.14286 .32481 L
s
.20238 .32106 m
.20238 .32481 L
s
.23214 .32106 m
.23214 .32481 L
s
.2619 .32106 m
.2619 .32481 L
s
.29167 .32106 m
.29167 .32481 L
s
.35119 .32106 m
.35119 .32481 L
s
.38095 .32106 m
.38095 .32481 L
s
.41071 .32106 m
.41071 .32481 L
s
.44048 .32106 m
.44048 .32481 L
s
.5 .32106 m
.5 .32481 L
s
.52976 .32106 m
.52976 .32481 L
s
.55952 .32106 m
.55952 .32481 L
s
.58929 .32106 m
.58929 .32481 L
s
.64881 .32106 m
.64881 .32481 L
s
.67857 .32106 m
.67857 .32481 L
s
.70833 .32106 m
.70833 .32481 L
s
.7381 .32106 m
.7381 .32481 L
s
.79762 .32106 m
.79762 .32481 L
s
.82738 .32106 m
.82738 .32481 L
s
.85714 .32106 m
.85714 .32481 L
s
.8869 .32106 m
.8869 .32481 L
s
.94643 .32106 m
.94643 .32481 L
s
.97619 .32106 m
.97619 .32481 L
s
.25 Mabswid
0 .32106 m
1 .32106 L
s
.02381 .03308 m
.03006 .03308 L
s
[(-1)] .01131 .03308 1 0 Mshowa
.02381 .17707 m
.03006 .17707 L
s
[(-0.5)] .01131 .17707 1 0 Mshowa
.02381 .46505 m
.03006 .46505 L
s
[(0.5)] .01131 .46505 1 0 Mshowa
.02381 .60904 m
.03006 .60904 L
s
[(1)] .01131 .60904 1 0 Mshowa
.125 Mabswid
.02381 .06188 m
.02756 .06188 L
s
.02381 .09068 m
.02756 .09068 L
s
.02381 .11947 m
.02756 .11947 L
s
.02381 .14827 m
.02756 .14827 L
s
.02381 .20587 m
.02756 .20587 L
s
.02381 .23467 m
.02756 .23467 L
s
.02381 .26347 m
.02756 .26347 L
s
.02381 .29226 m
.02756 .29226 L
s
.02381 .34986 m
.02756 .34986 L
s
.02381 .37866 m
.02756 .37866 L
s
.02381 .40746 m
.02756 .40746 L
s
.02381 .43625 m
.02756 .43625 L
s
.02381 .49385 m
.02756 .49385 L
s
.02381 .52265 m
.02756 .52265 L
s
.02381 .55145 m
.02756 .55145 L
s
.02381 .58024 m
.02756 .58024 L
s
.02381 .00428 m
.02756 .00428 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .34896 m
.03869 .34162 L
.05357 .34302 L
.06845 .34207 L
.08333 .42199 L
.09821 .48024 L
.1131 .51682 L
.12798 .55921 L
.14286 .55568 L
.15774 .56446 L
.17262 .58554 L
.1875 .60332 L
.20238 .37962 L
.21726 .22063 L
.23214 .12634 L
.24702 .01472 L
.2619 .21771 L
.27679 .33641 L
.29167 .3708 L
.30655 .42778 L
.32143 .33851 L
.33631 .28842 L
.35119 .27752 L
.36607 .25612 L
.38095 .33344 L
.39583 .3843 L
.41071 .40872 L
.4256 .44022 L
.44048 .35001 L
.45536 .29241 L
.47024 .26743 L
.48512 .23371 L
.5 .28119 L
.51488 .30691 L
.52976 .31087 L
.54464 .32066 L
.55952 .32244 L
.5744 .32637 L
.58929 .33244 L
.60417 .33794 L
.61905 .33055 L
.63393 .32662 L
.64881 .32614 L
.66369 .32474 L
.67857 .31611 L
.69345 .30942 L
.70833 .30466 L
.72321 .29939 L
.7381 .3062 L
.75298 .30977 L
Mistroke
.76786 .3101 L
.78274 .3113 L
.79762 .33676 L
.8125 .35572 L
.82738 .36818 L
.84226 .38238 L
.85714 .32992 L
.87202 .29532 L
.8869 .27859 L
.90179 .25706 L
.91667 .30658 L
.93155 .33706 L
.94643 .3485 L
.96131 .36505 L
Mfstroke
0 1 1 r
.02381 .32106 m
.97619 .32106 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.2.1"]
}, Open  ]],

Cell["\<\
The original signal is, of course, the sum of the signals at all \
levels.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.53"}],

Cell[CellGroupData[{

Cell["Union[Chop[data - (Plus @@ mrdata)]]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "This sets all coefficients except those in the third entry of ",
  StyleBox["wtdata", "TI"],
  " to zero."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.54"}],

Cell["wtdata - MapAt[#-#&, wtdata, {3}];", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S3.2.1"],

Cell["\<\
Note that we can also get a particular level of multiresolution \
decomposition by setting the coefficients of other levels to zero and doing \
the inverse wavelet transform.\
\>", "MathCaption",
  CellTags->{"S3.2.1", "1.55"}],

Cell["detail3 = InverseWaveletTransform[%, d2];", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S3.2.1"],

Cell[TextData[{
  "This shows that ",
  StyleBox["detail3", "MR"],
  " is the same as the third entry of ",
  StyleBox["mrdata", "MR"],
  " obtained using ",
  StyleBox["MRDecomposition", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.1", "1.56"}],

Cell[CellGroupData[{

Cell["Union[Chop[mrdata[[3]] - detail3]]", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S3.2.1"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[23]= ",
  CellTags->"S3.2.1"]
}, Open  ]],

Cell[TextData[{
  "Note that the function ",
  StyleBox["MRDecomposition", "MR"],
  " is only applicable to one\[Hyphen]dimensional data. For \
two\[Hyphen]dimensional data, we can use the inverse wavelet transform method \
as shown above. "
}], "Text",
  CellTags->{"S3.2.1", "1.57"}],

Cell["3.2.2 Wavelet Packet Transforms", "Subsection",
  CellTags->{"S3.2.2", "2.1"}],

Cell[TextData[{
  "A wavelet transform iterates the decomposition of the smooth part into a \
smooth part and details while leaving the details intact. In wavelet packet \
transforms, the details are further decomposed into a \"smooth\" part plus \
\"details\". For example, if we represent the result of filtering ",
  Cell[BoxData[
      \(TraditionalForm\`{f\_0, f\_1, \[Ellipsis], f\_\(N - 1\)}\)], 
    "InlineFormula",
    CellTags->"S3.2.2"],
  " using (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 3.2.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  ") as ",
  Cell[BoxData[
      \(TraditionalForm
      \`{f\_0\%\(J - 1\), f\_1\%\(J - 1\), \[Ellipsis], 
          f\_\(N/2 - 1\)\%\(J - 1\)} = h  f\)], "InlineFormula",
    CellTags->"S3.2.2"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm
      \`{d\_0\%\(J - 1\), d\_1\%\(J - 1\), \[Ellipsis], 
          d\_\(N/2 - 1\)\%\(J - 1\)} = g  f\)], "InlineFormula",
    CellTags->"S3.2.2"],
  ", we have, after one wavelet packet decomposition, ",
  Cell[BoxData[
      \(TraditionalForm\`{h  f, g  f}\)], "InlineFormula",
    CellTags->"S3.2.2"],
  ", and after two decompositions, ",
  Cell[BoxData[
      \(TraditionalForm\`{h  h  f, g  h  f, h  g  f, g  g  f}\)], 
    "InlineFormula",
    CellTags->"S3.2.2"],
  ", and so on. The function ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  " gives the table of wavelet packet coefficients in the form "
}], "Text",
  CellTags->{"S3.2.2", "2.2"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{f}, {h  f, g  f}, {h  h  f, g  h  f, h  g  f, g  g  f}, 
        \[Ellipsis]}.\)\)], "DisplayFormula",
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(2.4) "}], "EquationNumber"]}, {None, None}},
  CellTags->{"S3.2.2", "2.3"}],

Cell["\<\
Similarly, for two\[Hyphen]dimensional data, the output is a list \
of nested matrices \
\>", "Text",
  CellTags->{"S3.2.2", "2.4"}],

Cell[BoxData[
    \(TraditionalForm
    \`\({{f}, {{h  f, \(g\^\((I)\)\) f}, {
            \(g\^\((I  I)\)\) f, \(g\^\((I  I  I)\)\) f}}, {{{
              h  h  f, \(g\^\((I)\)\) h  f}, {
              \(g\^\((I  I)\)\) h  f, \(g\^\((I  I  I)\)\) h  f}}, 
          \[Ellipsis]}, \[Ellipsis]}.\)\)], "DisplayFormula",
  CellTags->{"S3.2.2", "2.5"}],

Cell[TextData[{
  "Each list in (",
  ButtonBox["2.4",
    ButtonData:>{"Wavelets 3.2.2", "2.3"},
    ButtonStyle->"AddOnsLink"],
  ") corresponds to a level of resolution or to a fixed number of \
decompositions done on the original data. By repeatedly applying (",
  ButtonBox["2.2",
    ButtonData:>{"Wavelets 3.2.1", "1.9"},
    ButtonStyle->"AddOnsLink"],
  "), we create a table of wavelet packet coefficients. Different \
combinations of the coefficients can correspond to choosing different \
orthogonal wavelet packet basis to decompose the original data. Among all the \
possible orthogonal wavelet packet bases, the best basis is defined to be the \
one that gives the minimum cost. "
}], "Text",
  CellTags->{"S3.2.2", "2.6"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\
WaveletPacketCoefficients[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"give wavelet packet coefficient table of \\!\\(\\*StyleBox[\\\"\\\
\\\\\"data\\\\\\\"\\\", \\\"TI\\\"]\\) using filter \
\\!\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\
WaveletPacketCoefficients[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("give wavelet packet coefficients up to "\), 
                    StyleBox["l",
                      "InlineFormula"], \(" decompositions "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WaveletPacketTransform[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("do wavelet packet transform using the best basis obtained from the \
entropy criterion "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"WaveletPacketTransform[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  \("do wavelet packet transform using the best basis within \
"\), 
                    StyleBox["l",
                      "InlineFormula"], \(" decompositions "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\
InverseWaveletPacketTransform[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"wpdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"filter\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do inverse wavelet packet transform on \\!\\(\\*StyleBox[\\\"\\\\\
\\\"wpdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.2", "2.7"}],

Cell["Wavelet packet coefficients and wavelet packet transforms.", "Caption",
  CellTags->"S3.2.2"],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " The argument ",
  StyleBox["filter", "TI"],
  " in these functions should be an orthogonal filter. \n",
  StyleBox["Warning:", "TB"],
  " For two\[Hyphen]dimensional data, ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  " and ",
  StyleBox["WaveletPacketTransform", "MR"],
  " can impose large memory requirements. The use of these functions should \
be attempted only if you have sufficient memory on your computer. "
}], "Text",
  CellTags->{"S3.2.2", "2.8"}],

Cell["We generate random data of length 8.", "MathCaption",
  CellTags->{"S3.2.2", "2.9"}],

Cell["\<\
(SeedRandom[348547];
data=Table[Random[],{8}];)\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S3.2.2"],

Cell["\<\
These are the wavelet packet coefficients. The third argument of 2 \
specifies the maximum number of decompositions to be done.\
\>", "MathCaption",\

  CellTags->{"S3.2.2", "2.10"}],

Cell[CellGroupData[{

Cell["WaveletPacketCoefficients[data, d1, 2]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{{0.3610628606962194`, 0.157262356938540159`, 0.429807030479367924`, 
          0.622740800800131477`, 0.279635120613107535`, 
          0.628021266109342146`, 0.605419055792206872`, 
          0.752824570027854722`}}, {{0.366511276249531636`, 
          0.744263709020928221`, 0.641809986038723678`, 
          0.960423278320769391`}, {0.144108718216289481`, 
          \(-0.136424777313699818`\), \(-0.246346205951830699`\), 
          \(-0.104231438700316769`\)}}, {{0.785436524457129614`, 
          1.13295000627125586`}, {\(-0.267111306822369964`\), 
          \(-0.225293619548806001`\)}, {0.00543336671845783758`, 
          \(-0.247895829865941275`\)}, {0.198367137039221468`, 
          \(-0.100490315630293403`\)}}}\)], "Output",
  CellLabel->"Out[25]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
If the third argument is omitted, the decomposition is done as many \
times as possible.\
\>", "MathCaption",
  CellTags->{"S3.2.2", "2.11"}],

Cell[CellGroupData[{

Cell["coef = WaveletPacketCoefficients[data, d1]", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{{0.3610628606962194`, 0.157262356938540159`, 0.429807030479367924`, 
          0.622740800800131477`, 0.279635120613107535`, 
          0.628021266109342146`, 0.605419055792206872`, 
          0.752824570027854722`}}, {{0.366511276249531636`, 
          0.744263709020928221`, 0.641809986038723678`, 
          0.960423278320769391`}, {0.144108718216289481`, 
          \(-0.136424777313699818`\), \(-0.246346205951830699`\), 
          \(-0.104231438700316769`\)}}, {{0.785436524457129614`, 
          1.13295000627125586`}, {\(-0.267111306822369964`\), 
          \(-0.225293619548806001`\)}, {0.00543336671845783758`, 
          \(-0.247895829865941275`\)}, {0.198367137039221468`, 
          \(-0.100490315630293403`\)}}, {{1.35650412481497673`}, {
          \(-0.245729139544516606`\)}, {\(-0.348182862526721192`\)}, {
          \(-0.0295695702446754573`\)}, {\(-0.171446851874778927`\)}, {
          0.179130792777368608`}, {0.0692093641392376834`}, {
          0.211324131390751634`}}}\)], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
This gives the number of times the decomposition is performed.\
\>",
   "MathCaption",
  CellTags->{"S3.2.2", "2.12"}],

Cell[CellGroupData[{

Cell["Length[coef]-1", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[27]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell[TextData[{
  "From all these coefficients, we can choose appropriate combinations such \
that they form an orthogonal wavelet packet decomposition of the original \
data. For example, we can extract the following components from ",
  StyleBox["coef", "MR"],
  ". "
}], "Text",
  CellTags->{"S3.2.2", "2.13"}],

Cell["\<\
We obtain a wavelet packet transform by choosing a particular \
orthogonal wavelet packet basis.\
\>", "MathCaption",
  CellTags->{"S3.2.2", "2.14"}],

Cell[CellGroupData[{

Cell["\<\
(comp = {{3, 1}, {4, 3}, {4, 4}, {2, 2}};
 Apply[coef[[##]]&, comp, {1}])\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{0.785436524457129614`, 1.13295000627125586`}, {
        \(-0.348182862526721192`\)}, {\(-0.0295695702446754573`\)}, {
        0.144108718216289481`, \(-0.136424777313699818`\), 
        \(-0.246346205951830699`\), \(-0.104231438700316769`\)}}\)], "Output",\

  CellLabel->"Out[28]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
This shows the position of the subspaces whose bases form the \
particular orthogonal basis we chose.\
\>", "MathCaption",
  CellTags->{"S3.2.2", "2.15"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S3.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .16187 translate
.23809 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .30902 translate
.47619 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.2.2"]
}, Open  ]],

Cell[TextData[{
  "The wavelet basis is a special case of a wavelet packet basis. This gives \
the same result as using ",
  StyleBox["WaveletTransform", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.2", "2.16"}],

Cell[CellGroupData[{

Cell["Apply[coef[[##]]&, {{4, 1}, {4, 2}, {3, 2}, {2, 2}}, {1}]", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{1.35650412481497673`}, {\(-0.245729139544516606`\)}, {
        \(-0.267111306822369964`\), \(-0.225293619548806001`\)}, {
        0.144108718216289481`, \(-0.136424777313699818`\), 
        \(-0.246346205951830699`\), \(-0.104231438700316769`\)}}\)], "Output",\

  CellLabel->"Out[30]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
This gives the wavelet packet transform by choosing the best basis \
using the entropy criterion.\
\>", "MathCaption",
  CellTags->{"S3.2.2", "2.17"}],

Cell[CellGroupData[{

Cell["WaveletPacketTransform[data, d1]", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{1.35650412481497673`}, {\(-0.245729139544516606`\)}, {
        \(-0.348182862526721192`\)}, {\(-0.0295695702446754573`\)}, {
        0.00543336671845783758`, \(-0.247895829865941275`\)}, {
        0.0692093641392376834`}, {0.211324131390751634`}}\)], "Output",
  CellLabel->"Out[31]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["This shows the position of the best basis.", "MathCaption",
  CellTags->{"S3.2.2", "2.18"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"S3.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.38095 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .16187 translate
.2381 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.85714 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
Instead of finding the best basis, sometimes we may want to find \
the \"best level\". Note the coefficients are all from the same level.\
\>", 
  "MathCaption",
  CellTags->{"S3.2.2", "2.19"}],

Cell[CellGroupData[{

Cell["WaveletPacketTransform[data, d1, BestLevel -> True]", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{1.35650412481497673`}, {\(-0.245729139544516606`\)}, {
        \(-0.348182862526721192`\)}, {\(-0.0295695702446754573`\)}, {
        \(-0.171446851874778927`\)}, {0.179130792777368608`}, {
        0.0692093641392376834`}, {0.211324131390751634`}}\)], "Output",
  CellLabel->"Out[33]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["\<\
Here a threshold cost function is used and we get a different best \
basis.\
\>", "MathCaption",
  CellTags->{"S3.2.2", "2.20"}],

Cell[CellGroupData[{

Cell["\<\
WaveletPacketTransform[data, d1,
CostFunction -> (If[Abs[#]>0.2, 1, 0]&)]\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({{0.785436524457129614`, 1.13295000627125586`}, {
        \(-0.348182862526721192`\)}, {\(-0.0295695702446754573`\)}, {
        \(-0.171446851874778927`\)}, {0.179130792777368608`}, {
        0.198367137039221468`, \(-0.100490315630293403`\)}}\)], "Output",
  CellLabel->"Out[34]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell["We check that we get perfect reconstruction.", "MathCaption",
  CellTags->{"S3.2.2", "2.21"}],

Cell[CellGroupData[{

Cell["Chop[InverseWaveletPacketTransform[%, d1] - data]", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"S3.2.2"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[35]= ",
  CellTags->"S3.2.2"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BestLevel\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to choose the best level "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CostFunction\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Entropy\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("cost function "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.2", "2.22"}],

Cell[TextData[{
  "Options for ",
  StyleBox["WaveletPacketTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.2"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->True}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.2", "2.23"}],

Cell[TextData[{
  "Option for ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  " and ",
  StyleBox["InverseWaveletPacketTransform", "MR"],
  ". "
}], "Caption",
  CellTags->"S3.2.2"],

Cell[TextData[{
  "For two\[Hyphen]dimensional data, the output of ",
  StyleBox["WaveletPacketTransform", "MR"],
  " is a list of nested matrices. We will see an example of a \
two\[Hyphen]dimensional wavelet packet transform in Section ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3"},
    ButtonStyle->"AddOnsLink"],
  ". "
}], "Text",
  CellTags->{"S3.2.2", "2.24"}],

Cell["3.2.3 Local Sine and Cosine Transforms", "Subsection",
  CellTags->{"S3.2.3", "3.1"}],

Cell["\<\
Local cosine and sine transforms can be thought of as \"dual\" to \
wavelet packet transforms. A window is used to slice a signal into segments, \
and a cosine or sine transform is done on each segment separately. The \
discrete versions of Sin\[Hyphen]II, Cos\[Hyphen]II, Sin\[Hyphen]IV, and Cos\
\[Hyphen]IV transforms are given by \
\>", "Text",
  CellTags->{"S3.2.3", "3.2"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(" Cos\[Hyphen]IV: "\), "  ", \(c\_k\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "cos", \(\[Pi]\/N\), 
        \((k + 1/2)\), \((i + 1/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), "cos", \(\[Pi]\/N\), 
        \((k + 1/2)\), \((i + 1/2)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.3", "3.3"}],

Cell["", "Text",
  CellTags->{"S3.2.3", "3.4"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(" Sin\[Hyphen]IV: "\), "  ", \(c\_k\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "sin", \(\[Pi]\/N\), 
        \((k + 1/2)\), \((i + 1/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), "sin", \(\[Pi]\/N\), 
        \((k + 1/2)\), \((i + 1/2)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.3", "3.5"}],

Cell["", "Text",
  CellTags->{"S3.2.3", "3.6"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(" Cos\[Hyphen]II: "\), "  ", \(c\_k\), "=", \(s\_k\), \(\@\(2\/N\)\), 
        
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "cos", \(\[Pi]\/N\), "k", \((
        i + 1/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), \(s\_k\), "cos", \(\[Pi]\/N\), 
        "k", \((i + 1/2)\)}], TraditionalForm]], "DisplayFormula",
  CellTags->{"S3.2.3", "3.7"}],

Cell["", "Text",
  CellTags->{"S3.2.3", "3.8"}],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(" Sin\[Hyphen]II: "\), "  ", \(c\_k\), "=", \(s\_\(k + 1\)\), 
        \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(i = 0\), \(N - 1\),
          LimitsPositioning->True], \(f\_i\), "sin", \(\[Pi]\/N\), 
        \((k + 1)\), \((i + 1/2)\), "     ", \(f\_i\), "=", \(\@\(2\/N\)\), 
        UnderoverscriptBox["\[Sum]", \(k = 0\), \(N - 1\),
          LimitsPositioning->True], \(c\_k\), \(s\_\(k + 1\)\), "sin", 
        \(\[Pi]\/N\), \((k + 1)\), \((i + 1/2)\), ","}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->{"S3.2.3", "3.9"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k = 1/\@2\)], "InlineFormula",
    CellTags->"S3.2.3"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0\)], "InlineFormula",
    CellTags->"S3.2.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.2.3"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_k = 1\)], "InlineFormula",
    CellTags->"S3.2.3"],
  " otherwise. \nLocal sine or cosine bases of Coifman and Meyer are Sin\
\[Hyphen]IV or Cos\[Hyphen]IV bases multiplied by a smooth window function. \
The window functions are determined by their behavior in the transition \
region where they are called taper functions. A sine or cosine basis is \
specified by the window width ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.2.3"],
  ", the taper, and the type II or IV. "
}], "Text",
  CellTags->{"S3.2.3", "3.10"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinTransform[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  "\<\"give Sin\[Hyphen]IV transform of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \\\"TI\\\"]\\) with window \
width \"\>", 
                    StyleBox["n",
                      "InlineFormula"], \(" and default taper "\)}]},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinTransform[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"nx\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"ny\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  \("give Sin\[Hyphen]IV transform in two dimensions "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosTransform[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("give Cos\[Hyphen]IV transform "\)},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosTransform[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"nx\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"ny\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>"}], 
                  \("give Cos\[Hyphen]IV transform in two dimensions "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InverseSinTransform[\\\\\
\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"stdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"give inverse sine transform of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"stdata\\\\\\\"\\\", \\\"TI\\\"]\\) with default \
taper \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InverseCosTransform[\\\\\
\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"ctdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"give inverse cosine transform of \
\\!\\(\\*StyleBox[\\\"\\\\\\\"ctdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.3", "3.11"}],

Cell["Sine and cosine transforms.", "Caption",
  CellTags->"S3.2.3"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BasisType\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"IV\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", 
                  "\<\"basis type; either \
\\!\\(\\*StyleBox[\\\"\\\\\\\"II\\\\\\\"\\\", \\\"MR\\\"]\\) or \
\\!\\(\\*StyleBox[\\\"\\\\\\\"IV\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"{Polynomial[2],\\\\\\\"\\\
\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"4}\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("taper function and taper width "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.3", "3.12"}],

Cell[TextData[{
  "Options for ",
  StyleBox["CosTransform", "MR"],
  ", ",
  StyleBox["SinTransform", "MR"],
  ", ",
  StyleBox["InverseCosTransform", "MR"],
  ", and ",
  StyleBox["InverseSinTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.3"],

Cell[TextData[{
  "There are only two basis types: II and IV. If we choose to use type II, \
the window function is set to be a rectangular window. The boundary condition \
can be set to any one of the settings as for the function ",
  StyleBox["WaveletTransform", "MR"],
  ". The option ",
  StyleBox["Taper", "MR"],
  " gives both the taper function and the half\[Hyphen]width of the \
transition region or taper width ",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S3.2.3"],
  " in the form ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S3.2.3"],
  StyleBox["taperfunction", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["m", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S3.2.3"],
  ". For two\[Hyphen]dimensional transforms, different taper functions can be \
used for the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.2.3"],
  "\[Hyphen] and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.2.3"],
  "\[Hyphen]directions by setting ",
  StyleBox["Taper", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S3.2.3"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S3.2.3"],
  StyleBox["taperx", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["mx", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S3.2.3"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S3.2.3"],
  StyleBox["tapery", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["my", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S3.2.3"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S3.2.3"],
  ". The taper function can be ",
  StyleBox["Polynomial[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", ",
  StyleBox["Trig[", "MR"],
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  ", or any function that satisfies the conditions given in Section ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.1"},
    ButtonStyle->"AddOnsLink"],
  ". If ",
  StyleBox["Taper", "MR"],
  " is set to ",
  StyleBox["False", "MR"],
  ", a rectangular window is used. "
}], "Text",
  CellTags->{"S3.2.3", "3.13"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Polynomial[\\\\\\\"\\\"\
, \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"],\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"m\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"]}], 
                  RowBox[{
                  "\<\"use \
\\!\\(\\*StyleBox[\\\"\\\\\\\"Polynomial[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) as \
taper function and taper width \"\>", 
                    StyleBox["m",
                      "InlineFormula"], \(" "\)}]},
                {
                  RowBox[{
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                    StyleBox["{",
                      "InlineFormula"], 
                    "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Trig[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"],\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"m\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>", 
                    StyleBox["}",
                      "InlineFormula"], \(" "\)}], 
                  RowBox[{
                  "\<\"use \\!\\(\\*StyleBox[\\\"\\\\\\\"Trig[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) as \
taper function and taper width \"\>", 
                    StyleBox["m",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("use no taper"\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.3", "3.14"}],

Cell[TextData[{
  "Settings for the ",
  StyleBox["Taper", "MR"],
  " option."
}], "Caption",
  CellTags->"S3.2.3"],

Cell["A list of 15 random numbers is generated.", "MathCaption",
  CellTags->{"S3.2.3", "3.15"}],

Cell["\<\
(SeedRandom[34958];
data=Table[Random[], {15}];)\
\>", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"S3.2.3"],

Cell["\<\
This does the sine transform without a taper function, that is, \
with a rectangular window. Note that the default basis type is IV.\
\>", 
  "MathCaption",
  CellTags->{"S3.2.3", "3.16"}],

Cell[CellGroupData[{

Cell["SinTransform[data, 5, Taper -> False]", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({{0.68527705728121564`, 0.756949234666266423`, 
        \(-0.0295241380264984556`\), 0.152116090103410739`, 
        0.693752384747654016`}, {0.937756856273894356`, 
        0.475155900716305268`, 0.28192718464228065`, 0.022553906641716912`, 
        \(-0.208153095848556679`\)}, {1.41763191447932452`, 
        \(-0.241322417005200673`\), \(-0.0845688349288914764`\), 
        0.183967680272387763`, 0.202159186534353363`}}\)], "Output",
  CellLabel->"Out[37]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
We check that the original data are recovered using the inverse Sin\
\[Hyphen]IV transform.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.17"}],

Cell[CellGroupData[{

Cell["Chop[InverseSinTransform[%, Taper -> False]-data]", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[38]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell[TextData[{
  "This does the Cos\[Hyphen]II transform. Note that once the basis type is ",
  
  StyleBox["II", "MR"],
  ", the option ",
  StyleBox["Taper", "MR"],
  " is automatically set to ",
  StyleBox["False", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.2.3", "3.18"}],

Cell[CellGroupData[{

Cell["CosTransform[data, 5, BasisType -> II]", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({{0.972879373620640564`, 0.479008658891536853`, 
        \(-0.249935947713594108`\), 0.271023040413594529`, 
        0.485813856051248471`}, {1.02593528591917215`, 
        0.0328183823245228323`, \(-0.161135696766132419`\), 
        \(-0.293940814645104708`\), \(-0.249988412794870429`\)}, {
        1.24763898797982708`, \(-0.722666134916116575`\), 
        0.0632075462545612687`, 0.244208498228369119`, 
        0.0854325139124957111`}}\)], "Output",
  CellLabel->"Out[39]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
This gives the local cosine transform of Coifman and Meyer using \
the window specified by the taper function.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.19"}],

Cell[CellGroupData[{

Cell["CosTransform[data, 5, Taper -> {Trig[1], 2}]", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({{1.32793085836816171`, 0.192834926775563157`, 0.00463487201853640318`, 
        0.613363760330420504`, 0.269561904713741151`}, {
        0.922845060771607172`, \(-0.312043944913552451`\), 
        \(-0.149901034141632738`\), \(-0.366228240358729006`\), 
        \(-0.118283229610418239`\)}, {0.891081978505312477`, 
        \(-0.702475283677471562`\), 0.499428730432482925`, 
        0.131378320421956429`, 0.0535629864927238052`}}\)], "Output",
  CellLabel->"Out[40]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
We check that the original data are recovered using the inverse \
cosine transform.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.20"}],

Cell[CellGroupData[{

Cell["\<\
(idata = InverseCosTransform[%, Taper -> {Trig[1], 2}];
 Chop[idata-data])\
\>", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[41]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
The output of a two\[Hyphen]dimensional cosine or sine transform is \
a list of nested matrices.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.21"}],

Cell[CellGroupData[{

Cell["\<\
(data2 = Table[Random[], {8}, {8}];
 ctdata = CosTransform[data2, {4, 4}, Taper -> False];
 Dimensions /@ ctdata)\
\>", "Input",
  CellLabel->"In[42]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({{2, 4, 4}, {2, 4, 4}}\)], "Output",
  CellLabel->"Out[42]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
The original data are recovered using the inverse cosine transform.\
\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.22"}],

Cell[CellGroupData[{

Cell["\<\
Union[Flatten[Chop[
InverseCosTransform[ctdata, Taper -> False]-data2]]]\
\>", "Input",
  CellLabel->"In[43]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[43]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell[TextData[{
  "The Malvar basis of second kind uses Cos\[Hyphen]II and Sin\[Hyphen]II \
functions alternately for adjacent segments. The basis is specified by the \
window width ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.2.3"],
  " and the taper. "
}], "Text",
  CellTags->{"S3.2.3", "3.23"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"MalvarTransform[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  "\<\"do Malvar transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \\\"TI\\\"]\\) with window \
width \"\>", 
                    StyleBox["n",
                      "InlineFormula"], \(" and default taper "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"InverseMalvarTransform[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"mtdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do inverse Malvar transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"mtdata\\\\\\\"\\\", \\\"TI\\\"]\\) with default \
taper \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.3", "3.24"}],

Cell["Malvar transforms.", "Caption",
  CellTags->"S3.2.3"],

Cell[TextData[{
  StyleBox["Note:", "TB"],
  " The number of segments (",
  Cell[BoxData[
      \(TraditionalForm\` = \)], "InlineFormula",
    CellTags->"S3.2.3"],
  "(",
  StyleBox["data length", "TI"],
  ")",
  Cell[BoxData[
      \(TraditionalForm\`/\)], "InlineFormula",
    CellTags->"S3.2.3"],
  "(",
  StyleBox["window width", "TI"],
  ")) has to be even and this function is for one\[Hyphen]dimensional data \
only. "
}], "Text",
  CellTags->{"S3.2.3", "3.25"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"{Polynomial[2],\\\\\\\"\\\
\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"4}\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("taper function "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.3", "3.26"}],

Cell[TextData[{
  "Options for ",
  StyleBox["MalvarTransform", "MR"],
  " and ",
  StyleBox["InverseMalvarTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.3"],

Cell["\<\
This gives the Malvar transform of a set of random data of length \
20.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.27"}],

Cell[CellGroupData[{

Cell["\<\
(data = Table[Random[], {20}];
MalvarTransform[data, 5, Taper -> {Polynomial[2], 2}])\
\>", "Input",
  CellLabel->"In[44]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({{1.72890354307071874`, \(-0.189587903717870371`\), 
        \(-0.231996364493308959`\), 0.238033164377697703`, 
        0.013793643849842343`}, {1.14232110113666007`, 
        \(-0.456481487799079843`\), 0.0119654557591429977`, 
        \(-0.0998792770190373779`\), \(-0.0855435091046612328`\)}, {
        1.64698226751619625`, 0.361876163647423298`, 0.375707208539789005`, 
        \(-0.232389424575335112`\), 0.427208563946533192`}, {
        0.917580107152958568`, \(-0.216358521134298165`\), 
        0.280512266410483377`, 0.389222357706785881`, 
        \(-0.0111665017958638035`\)}}\)], "Output",
  CellLabel->"Out[44]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["\<\
The default periodic boundary condition guarantees perfect \
reconstruction.\
\>", "MathCaption",
  CellTags->{"S3.2.3", "3.28"}],

Cell[CellGroupData[{

Cell["\<\
Union[Chop[data - InverseMalvarTransform[%,
Taper -> {Polynomial[2], 2}]]]\
\>", "Input",
  CellLabel->"In[45]:= ",
  CellTags->"S3.2.3"],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[45]= ",
  CellTags->"S3.2.3"]
}, Open  ]],

Cell["3.2.4 Sine and Cosine Packet Transforms", "Subsection",
  CellTags->{"S3.2.4", "4.1"}],

Cell[TextData[{
  "We have a library of orthonormal trigonometric functions just as in the \
case of wavelet packet transform. Instead of slicing the data into segments \
of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.2.4"],
  ", we can equally well slice the data into segments of length ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)], "InlineFormula",
    CellTags->"S3.2.4"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\^j\)], "InlineFormula",
    CellTags->"S3.2.4"],
  ". This is the same as dilating the basis function by ",
  Cell[BoxData[
      \(TraditionalForm\`2\^j\)], "InlineFormula",
    CellTags->"S3.2.4"],
  ". ",
  StyleBox["CosPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " or ",
  StyleBox["SinPacketCoefficients[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " gives the cosine or sine packet coefficient table in the form ",
  Cell[BoxData[
      \(TraditionalForm\`{C\_0, C\_1, C\_2, \[Ellipsis]}\)], "InlineFormula",
    CellTags->"S3.2.4"],
  " where the \"",
  Cell[BoxData[
      \(TraditionalForm\`j\^th\)], "InlineFormula",
    CellTags->"S3.2.4"],
  " level\" coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`C\_j\)], "InlineFormula",
    CellTags->"S3.2.4"],
  " is the result of ",
  StyleBox["CosTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\"\>", "j"], TraditionalForm]], "InlineFormula",
    CellTags->"S3.2.4"],
  StyleBox["]", "MR"],
  " or\[NonBreakingSpace]",
  StyleBox["SinTransform[", "MR"],
  StyleBox["data", "TI"],
  StyleBox[",", "MR"],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\"\>", "j"], TraditionalForm]], "InlineFormula",
    CellTags->"S3.2.4"],
  StyleBox["]", "MR"],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`n\_j = N/2\^j\)], "InlineFormula",
    CellTags->"S3.2.4"],
  "). ",
  StyleBox["CosPacketTransform", "MR"],
  " or ",
  StyleBox["SinPacketTransform", "MR"],
  " gives the transformation by picking the best basis. "
}], "Text",
  CellTags->{"S3.2.4", "4.2"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinPacketCoefficients[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("give sine packet coefficient table using default taper "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinPacketCoefficients[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  \("give sine packet coefficient table up to level "\), 
                    StyleBox["l",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosPacketCoefficients[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("give cosine packet coefficient table using default taper "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosPacketCoefficients[\\\
\\\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  \("give cosine packet coefficient table up to level "\), 
                    StyleBox["l",
                      "InlineFormula"], \(" "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinPacketTransform[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("do sine packet transform using the best basis obtained from the \
entropy criterion "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"SinPacketTransform[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  \("do sine packet transform using the best basis within "\),
                     
                    StyleBox["l",
                      "InlineFormula"], \(" levels "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosPacketTransform[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("do cosine packet transform using the best basis obtained from the \
entropy criterion "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CosPacketTransform[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"l\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{
                  \("do cosine packet transform using the best basis within "\
\), 
                    StyleBox["l",
                      "InlineFormula"], \(" levels "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\
InverseSinPacketTransform[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"spdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do inverse sine packet transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"spdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"\
InverseCosPacketTransform[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"cpdata\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"do inverse cosine packet transform on \
\\!\\(\\*StyleBox[\\\"\\\\\\\"cpdata\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.4", "4.3"}],

Cell["Sine and cosine packet transforms.", "Caption",
  CellTags->"S3.2.4"],

Cell[TextData[{
  "For two\[Hyphen]dimensional data, the second argument ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.2.4"],
  " in the above functions should be replaced by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox[\("nx"\),
              "TI"], ",", 
            StyleBox[\("ny"\),
              "TI"]}], "}"}], TraditionalForm]], "InlineFormula",
    CellTags->"S3.2.4"],
  ". \n",
  StyleBox["Warning:", "TB"],
  " For two\[Hyphen]dimensional data, the functions ",
  StyleBox["CosPacketCoefficients", "MR"],
  ", ",
  StyleBox["SinPacketCoefficients", "MR"],
  ", ",
  StyleBox["CosPacketTransform", "MR"],
  ", and ",
  StyleBox["SinPacketTransform", "MR"],
  " can impose large memory requirements. The use of these functions should \
be attempted only if you have sufficient memory on your computer. "
}], "Text",
  CellTags->{"S3.2.4", "4.4"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BasisType\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"IV\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", \("basis type "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BestLevel\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to choose the best level "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CostFunction\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Entropy\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("cost function "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"{Polynomial[2],\\\\\\\"\\\
\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"4}\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("taper function and taper width "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.4", "4.5"}],

Cell[TextData[{
  "Options for ",
  StyleBox["CosPacketTransform", "MR"],
  " and ",
  StyleBox["SinPacketTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.4"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BasisType\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"IV\\\\\\\"\\\", \\\"MR\\\
\"]\\) \"\>", \("basis type "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"BoundaryCondition\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Periodic\\\\\\\"\\\", \\\
\"MR\\\"]\\) \"\>", \("boundary condition "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Taper\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"{Polynomial[2],\\\\\\\"\\\
\", \\\"MR\\\"]\\) \\!\\(\\*StyleBox[\\\"\\\\\\\"4}\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("taper function and taper width "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.2.4", "4.6"}],

Cell[TextData[{
  "Options for ",
  StyleBox["SinPacketCoefficients", "MR"],
  ", ",
  StyleBox["CosPacketCoefficients", "MR"],
  ", ",
  StyleBox["InverseSinPacketTransform", "MR"],
  ", and",
  StyleBox["InverseCosPacketTransform", "MR"],
  "."
}], "Caption",
  CellTags->"S3.2.4"],

Cell["This generates a set of random data of length 16.", "MathCaption",
  CellTags->{"S3.2.4", "4.7"}],

Cell["\<\
(SeedRandom[5647];
data = Table[Random[], {16}];)\
\>", "Input",
  CellLabel->"In[46]:= ",
  CellTags->"S3.2.4"],

Cell[TextData[{
  "Here the cosine coefficient table consists of three cosine transforms with \
",
  Cell[BoxData[
      \(TraditionalForm\`N = 8, 4\)], "InlineFormula",
    CellTags->"S3.2.4"],
  ", and 2, respectively."
}], "MathCaption",
  CellTags->{"S3.2.4", "4.8"}],

Cell[CellGroupData[{

Cell["CosPacketCoefficients[data, 8, 2, Taper -> False]", "Input",
  CellLabel->"In[47]:= ",
  CellTags->"S3.2.4"],

Cell[BoxData[
    \({{{1.6203936198600588`, \(-0.131018363240351098`\), 
          0.494194912624530147`, \(-0.383092881687214248`\), 
          0.660009514519626439`, \(-0.375777440342373747`\), 
          0.312606504129093742`, 0.200081615391134937`}, {
          0.928607221620038103`, \(-0.233458204316254436`\), 
          0.0113255442301463138`, \(-0.21581786556385043`\), 
          0.334885869662139423`, 0.162569450303831768`, 
          0.0599697716094425281`, 0.345979136050048774`}}, {{
          1.37140466631581992`, \(-0.16390154132257062`\), 
          0.35040281081397433`, \(-0.0215032705090572573`\)}, {
          0.86913973347760649`, \(-0.540372193667777622`\), 
          0.818572902549978209`, 0.0089560216167104425`}, {
          0.679513924292430715`, \(-0.358050688967101571`\), 
          0.440730808686979802`, 0.0598891413748386369`}, {
          0.501346386619384709`, \(-0.220466681608744741`\), 
          0.207843137227909968`, 0.307364085882119653`}}, {{
          1.14155259049608082`, \(-0.170469976981950699`\)}, {
          0.817321151629742814`, \(-0.175050848863209225`\)}, {
          0.567082485408978964`, 0.219383319091393902`}, {
          1.07978931174351511`, \(-0.426487101097361342`\)}, {
          0.45430580981559574`, 0.0585934587303045617`}, {
          0.737707766549235621`, \(-0.183657597426200211`\)}, {
          0.33915116849832354`, 0.075230905218095474`}, {
          0.541464653734904288`, 0.154136409134259677`}}}\)], "Output",
  CellLabel->"Out[47]= ",
  CellTags->"S3.2.4"]
}, Open  ]],

Cell["\<\
This gives the transform using the best basis. Note that we usually \
subtract the mean of the data before searching for the best basis using the \
entropy criterion.\
\>", "MathCaption",
  CellTags->{"S3.2.4", "4.9"}],

Cell[CellGroupData[{

Cell["\<\
(mean = (Plus @@ data)/16;
CosPacketTransform[data-mean, 8, 2, Taper -> False])\
\>", "Input",
  CellLabel->"In[48]:= ",
  CellTags->"S3.2.4"],

Cell[BoxData[
    \({{0.515889872532042126`, 0.088688006269966948`}, {
        0.191658433665703924`, 0.0841071343887083777`}, {
        0.00132061392893175466`, \(-0.235634643989642889`\), 
        0.614953781683177602`, 0.181575977143467763`}, {
        \(-0.171356908148443132`\), 0.317751441982222093`}, {
        0.112045048585196971`, 0.0755003858257173021`}, {
        \(-0.366472732929289968`\), 0.0842708680693899658`, 
        0.00422401636110929334`, 0.479984041408877004`}}\)], "Output",
  CellLabel->"Out[48]= ",
  CellTags->"S3.2.4"]
}, Open  ]],

Cell["\<\
This shows the position of the subspaces whose bases form the best \
basis.\
\>", "MathCaption",
  CellTags->{"S3.2.4", "4.10"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[%]", "Input",
  CellLabel->"In[49]:= ",
  CellTags->"S3.2.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0595238 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .16187 m
.97619 .16187 L
s
.02381 .30902 m
.97619 .30902 L
s
.02381 .45617 m
.97619 .45617 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.14286 .01472 m
.14286 .16187 L
s
.2619 .01472 m
.2619 .30902 L
s
.38095 .01472 m
.38095 .16187 L
s
.5 .01472 m
.5 .45617 L
s
.61905 .01472 m
.61905 .16187 L
s
.7381 .01472 m
.7381 .30902 L
s
.85714 .01472 m
.85714 .16187 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.14286 .01472 translate
.11904 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.2619 .16187 translate
.2381 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.61905 .01472 translate
.11905 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.7381 .16187 translate
.23809 .14715 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.2.4"]
}, Open  ]],

Cell["The original data are recovered.", "MathCaption",
  CellTags->{"S3.2.4", "4.11"}],

Cell[CellGroupData[{

Cell["\<\
Chop[data-(InverseCosPacketTransform[%%,
Taper -> False]+mean)]\
\>", "Input",
  CellLabel->"In[50]:= ",
  CellTags->"S3.2.4"],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[50]= ",
  CellTags->"S3.2.4"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 111}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 65, 1, 58, "Section",
      CellTags->"Contents"],
    Cell[1777, 52, 555, 18, 84, "Contents",
      CellTags->"Contents"]},
  "S3.2.0"->{
    Cell[2335, 72, 72, 1, 58, "Section",
      CellTags->{"S3.2.0", "0.1"}]},
  "0.1"->{
    Cell[2335, 72, 72, 1, 58, "Section",
      CellTags->{"S3.2.0", "0.1"}]},
  "S3.2.1"->{
    Cell[2410, 75, 77, 1, 41, "Subsection",
      CellTags->{"S3.2.1", "1.1"}],
    Cell[2490, 78, 954, 28, 59, "Text",
      CellTags->{"S3.2.1", "1.2"}],
    Cell[3447, 108, 639, 15, 53, "DisplayFormula",
      CellTags->{"S3.2.1", "1.3"}],
    Cell[4089, 125, 326, 11, 25, "Text",
      CellTags->{"S3.2.1", "1.4"}],
    Cell[4418, 138, 482, 11, 38, "DisplayFormula",
      CellTags->{"S3.2.1", "1.5"}],
    Cell[4903, 151, 759, 21, 58, "Text",
      CellTags->{"S3.2.1", "1.6"}],
    Cell[5665, 174, 444, 8, 29, "DisplayFormula",
      CellTags->{"S3.2.1", "1.7"}],
    Cell[6112, 184, 66, 1, 24, "Text",
      CellTags->{"S3.2.1", "1.8"}],
    Cell[6181, 187, 514, 11, 39, "DisplayFormula",
      CellTags->{"S3.2.1", "1.9"}],
    Cell[6698, 200, 101, 1, 24, "Text",
      CellTags->{"S3.2.1", "1.10"}],
    Cell[6802, 203, 503, 11, 39, "DisplayFormula",
      CellTags->{"S3.2.1", "1.11"}],
    Cell[7308, 216, 1489, 40, 70, "Text",
      CellTags->{"S3.2.1", "1.12"}],
    Cell[8800, 258, 275, 5, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.13"}],
    Cell[9078, 265, 107, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.14"}],
    Cell[9188, 268, 2016, 38, 70, "Text",
      CellTags->{"S3.2.1", "1.15"}],
    Cell[11207, 308, 76, 1, 70, "Caption",
      CellTags->"S3.2.1"],
    Cell[11286, 311, 1431, 42, 70, "Text",
      CellTags->{"S3.2.1", "1.16"}],
    Cell[12720, 355, 300, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.17"}],
    Cell[13023, 363, 1941, 61, 70, "Text",
      CellTags->{"S3.2.1", "1.18"}],
    Cell[14967, 426, 78, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.19"}],
    Cell[15048, 429, 93, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[15144, 433, 97, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.20"}],
    Cell[15244, 436, 149, 6, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[15396, 444, 173, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.21"}],
    Cell[15594, 452, 99, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[15696, 456, 429, 8, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[16140, 467, 155, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.22"}],
    Cell[16320, 475, 93, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[16416, 479, 415, 7, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[16846, 489, 283, 8, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.23"}],
    Cell[17132, 499, 95, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[17230, 503, 98, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.24"}],
    Cell[17353, 508, 76, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[17432, 512, 117, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[17564, 518, 128, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.25"}],
    Cell[17717, 526, 114, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[17834, 530, 106, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[17955, 536, 174, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.26"}],
    Cell[18132, 543, 150, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[18285, 550, 111, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.27"}],
    Cell[18421, 555, 84, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[18508, 559, 111, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[18634, 565, 106, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.28"}],
    Cell[18765, 570, 141, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[18909, 577, 85, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[19009, 583, 107, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.29"}],
    Cell[19119, 586, 269, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.30"}],
    Cell[19391, 594, 52, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.31"}],
    Cell[19446, 597, 306, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.32"}],
    Cell[19755, 605, 1429, 40, 70, "Text",
      CellTags->{"S3.2.1", "1.33"}],
    Cell[21187, 647, 765, 19, 70, "Text",
      CellTags->{"S3.2.1", "1.34"}],
    Cell[21955, 668, 169, 7, 70, "Caption",
      CellTags->"S3.2.1"],
    Cell[22127, 677, 286, 8, 70, "Text",
      CellTags->{"S3.2.1", "1.35"}],
    Cell[22416, 687, 2500, 53, 70, "Text",
      CellTags->{"S3.2.1", "1.36"}],
    Cell[24919, 742, 127, 5, 70, "Caption",
      CellTags->"S3.2.1"],
    Cell[25049, 749, 110, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.37"}],
    Cell[25184, 754, 87, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[25274, 758, 193, 4, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[25482, 765, 276, 7, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.38"}],
    Cell[25783, 776, 84, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[25870, 780, 198, 4, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[26083, 787, 109, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.39"}],
    Cell[26217, 792, 117, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[26337, 796, 442, 9, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[26794, 808, 262, 6, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.40"}],
    Cell[27081, 818, 141, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[27225, 825, 264, 5, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[27504, 833, 244, 7, 70, "Text",
      CellTags->{"S3.2.1", "1.41"}],
    Cell[27751, 842, 256, 5, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.42"}],
    Cell[28010, 849, 346, 10, 70, "Text",
      CellTags->{"S3.2.1", "1.43"}],
    Cell[28359, 861, 371, 7, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.44"}],
    Cell[28733, 870, 648, 23, 70, "Text",
      CellTags->{"S3.2.1", "1.45"}],
    Cell[29384, 895, 814, 17, 70, "Text",
      CellTags->{"S3.2.1", "1.46"}],
    Cell[30201, 914, 86, 1, 70, "Caption",
      CellTags->"S3.2.1"],
    Cell[30290, 917, 765, 19, 70, "Text",
      CellTags->{"S3.2.1", "1.47"}],
    Cell[31058, 938, 112, 5, 70, "Caption",
      CellTags->"S3.2.1"],
    Cell[31173, 945, 98, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.48"}],
    Cell[31274, 948, 104, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[31381, 952, 215, 7, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.49"}],
    Cell[31599, 961, 150, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[31752, 968, 150, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.50"}],
    Cell[31927, 976, 81, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[32011, 980, 106, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[32132, 986, 490, 14, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.51"}],
    Cell[32647, 1004, 137, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[32787, 1011, 7004, 455, 70, 6931, 452, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.2.1"],
    Cell[39806, 1469, 341, 10, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.52"}],
    Cell[40172, 1483, 168, 5, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[40343, 1490, 4392, 310, 70, 4319, 307, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.2.1"],
    Cell[44750, 1803, 137, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.53"}],
    Cell[44912, 1811, 101, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[45016, 1815, 85, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[45116, 1821, 176, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.54"}],
    Cell[45295, 1828, 99, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[45397, 1832, 237, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.55"}],
    Cell[45637, 1839, 106, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[45746, 1843, 251, 9, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.56"}],
    Cell[46022, 1856, 99, 2, 70, "Input",
      CellTags->"S3.2.1"],
    Cell[46124, 1860, 85, 3, 70, "Output",
      CellTags->"S3.2.1"],
    Cell[46224, 1866, 285, 7, 70, "Text",
      CellTags->{"S3.2.1", "1.57"}]},
  "1.1"->{
    Cell[2410, 75, 77, 1, 41, "Subsection",
      CellTags->{"S3.2.1", "1.1"}]},
  "1.2"->{
    Cell[2490, 78, 954, 28, 59, "Text",
      CellTags->{"S3.2.1", "1.2"}]},
  "1.3"->{
    Cell[3447, 108, 639, 15, 53, "DisplayFormula",
      CellTags->{"S3.2.1", "1.3"}]},
  "1.4"->{
    Cell[4089, 125, 326, 11, 25, "Text",
      CellTags->{"S3.2.1", "1.4"}]},
  "1.5"->{
    Cell[4418, 138, 482, 11, 38, "DisplayFormula",
      CellTags->{"S3.2.1", "1.5"}]},
  "1.6"->{
    Cell[4903, 151, 759, 21, 58, "Text",
      CellTags->{"S3.2.1", "1.6"}]},
  "1.7"->{
    Cell[5665, 174, 444, 8, 29, "DisplayFormula",
      CellTags->{"S3.2.1", "1.7"}]},
  "1.8"->{
    Cell[6112, 184, 66, 1, 24, "Text",
      CellTags->{"S3.2.1", "1.8"}]},
  "1.9"->{
    Cell[6181, 187, 514, 11, 39, "DisplayFormula",
      CellTags->{"S3.2.1", "1.9"}]},
  "1.10"->{
    Cell[6698, 200, 101, 1, 24, "Text",
      CellTags->{"S3.2.1", "1.10"}]},
  "1.11"->{
    Cell[6802, 203, 503, 11, 39, "DisplayFormula",
      CellTags->{"S3.2.1", "1.11"}]},
  "1.12"->{
    Cell[7308, 216, 1489, 40, 70, "Text",
      CellTags->{"S3.2.1", "1.12"}]},
  "1.13"->{
    Cell[8800, 258, 275, 5, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.13"}]},
  "1.14"->{
    Cell[9078, 265, 107, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.14"}]},
  "1.15"->{
    Cell[9188, 268, 2016, 38, 70, "Text",
      CellTags->{"S3.2.1", "1.15"}]},
  "1.16"->{
    Cell[11286, 311, 1431, 42, 70, "Text",
      CellTags->{"S3.2.1", "1.16"}]},
  "1.17"->{
    Cell[12720, 355, 300, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.17"}]},
  "1.18"->{
    Cell[13023, 363, 1941, 61, 70, "Text",
      CellTags->{"S3.2.1", "1.18"}]},
  "1.19"->{
    Cell[14967, 426, 78, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.19"}]},
  "1.20"->{
    Cell[15144, 433, 97, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.20"}]},
  "1.21"->{
    Cell[15396, 444, 173, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.21"}]},
  "1.22"->{
    Cell[16140, 467, 155, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.22"}]},
  "1.23"->{
    Cell[16846, 489, 283, 8, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.23"}]},
  "1.24"->{
    Cell[17230, 503, 98, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.24"}]},
  "1.25"->{
    Cell[17564, 518, 128, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.25"}]},
  "1.26"->{
    Cell[17955, 536, 174, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.26"}]},
  "1.27"->{
    Cell[18285, 550, 111, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.27"}]},
  "1.28"->{
    Cell[18634, 565, 106, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.28"}]},
  "1.29"->{
    Cell[19009, 583, 107, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.29"}]},
  "1.30"->{
    Cell[19119, 586, 269, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.30"}]},
  "1.31"->{
    Cell[19391, 594, 52, 1, 70, "Text",
      CellTags->{"S3.2.1", "1.31"}]},
  "1.32"->{
    Cell[19446, 597, 306, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.32"}]},
  "1.33"->{
    Cell[19755, 605, 1429, 40, 70, "Text",
      CellTags->{"S3.2.1", "1.33"}]},
  "1.34"->{
    Cell[21187, 647, 765, 19, 70, "Text",
      CellTags->{"S3.2.1", "1.34"}]},
  "1.35"->{
    Cell[22127, 677, 286, 8, 70, "Text",
      CellTags->{"S3.2.1", "1.35"}]},
  "1.36"->{
    Cell[22416, 687, 2500, 53, 70, "Text",
      CellTags->{"S3.2.1", "1.36"}]},
  "1.37"->{
    Cell[25049, 749, 110, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.37"}]},
  "1.38"->{
    Cell[25482, 765, 276, 7, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.38"}]},
  "1.39"->{
    Cell[26083, 787, 109, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.39"}]},
  "1.40"->{
    Cell[26794, 808, 262, 6, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.40"}]},
  "1.41"->{
    Cell[27504, 833, 244, 7, 70, "Text",
      CellTags->{"S3.2.1", "1.41"}]},
  "1.42"->{
    Cell[27751, 842, 256, 5, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.42"}]},
  "1.43"->{
    Cell[28010, 849, 346, 10, 70, "Text",
      CellTags->{"S3.2.1", "1.43"}]},
  "1.44"->{
    Cell[28359, 861, 371, 7, 70, "DisplayFormula",
      CellTags->{"S3.2.1", "1.44"}]},
  "1.45"->{
    Cell[28733, 870, 648, 23, 70, "Text",
      CellTags->{"S3.2.1", "1.45"}]},
  "1.46"->{
    Cell[29384, 895, 814, 17, 70, "Text",
      CellTags->{"S3.2.1", "1.46"}]},
  "1.47"->{
    Cell[30290, 917, 765, 19, 70, "Text",
      CellTags->{"S3.2.1", "1.47"}]},
  "1.48"->{
    Cell[31173, 945, 98, 1, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.48"}]},
  "1.49"->{
    Cell[31381, 952, 215, 7, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.49"}]},
  "1.50"->{
    Cell[31752, 968, 150, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.50"}]},
  "1.51"->{
    Cell[32132, 986, 490, 14, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.51"}]},
  "1.52"->{
    Cell[39806, 1469, 341, 10, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.52"}]},
  "1.53"->{
    Cell[44750, 1803, 137, 4, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.53"}]},
  "1.54"->{
    Cell[45116, 1821, 176, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.54"}]},
  "1.55"->{
    Cell[45397, 1832, 237, 5, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.55"}]},
  "1.56"->{
    Cell[45746, 1843, 251, 9, 70, "MathCaption",
      CellTags->{"S3.2.1", "1.56"}]},
  "1.57"->{
    Cell[46224, 1866, 285, 7, 70, "Text",
      CellTags->{"S3.2.1", "1.57"}]},
  "S3.2.2"->{
    Cell[46512, 1875, 84, 1, 70, "Subsection",
      CellTags->{"S3.2.2", "2.1"}],
    Cell[46599, 1878, 1464, 38, 70, "Text",
      CellTags->{"S3.2.2", "2.2"}],
    Cell[48066, 1918, 281, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.2", "2.3"}],
    Cell[48350, 1926, 142, 4, 70, "Text",
      CellTags->{"S3.2.2", "2.4"}],
    Cell[48495, 1932, 349, 7, 70, "DisplayFormula",
      CellTags->{"S3.2.2", "2.5"}],
    Cell[48847, 1941, 738, 16, 70, "Text",
      CellTags->{"S3.2.2", "2.6"}],
    Cell[49588, 1959, 3271, 63, 70, "Text",
      CellTags->{"S3.2.2", "2.7"}],
    Cell[52862, 2024, 99, 1, 70, "Caption",
      CellTags->"S3.2.2"],
    Cell[52964, 2027, 512, 13, 70, "Text",
      CellTags->{"S3.2.2", "2.8"}],
    Cell[53479, 2042, 90, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.9"}],
    Cell[53572, 2045, 120, 5, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[53695, 2052, 192, 5, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.10"}],
    Cell[53912, 2061, 103, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[54018, 2065, 809, 14, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[54842, 2082, 151, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.11"}],
    Cell[55018, 2090, 107, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[55128, 2094, 1076, 18, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[56219, 2115, 128, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.12"}],
    Cell[56372, 2123, 79, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[56454, 2127, 83, 3, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[56552, 2133, 313, 7, 70, "Text",
      CellTags->{"S3.2.2", "2.13"}],
    Cell[56868, 2142, 159, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.14"}],
    Cell[57052, 2150, 146, 5, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[57201, 2157, 328, 7, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[57544, 2167, 164, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.15"}],
    Cell[57733, 2175, 85, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[57821, 2179, 1825, 142, 70, 1752, 139, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.2.2"],
    Cell[59661, 2324, 217, 6, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.16"}],
    Cell[59903, 2334, 122, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[60028, 2338, 332, 7, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[60375, 2348, 160, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.17"}],
    Cell[60560, 2356, 97, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[60660, 2360, 330, 6, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[61005, 2369, 97, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.18"}],
    Cell[61127, 2374, 85, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[61215, 2378, 2360, 187, 70, 2287, 184, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.2.2"],
    Cell[63590, 2568, 203, 5, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.19"}],
    Cell[63818, 2577, 116, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[63937, 2581, 330, 6, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[64282, 2590, 138, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.20"}],
    Cell[64445, 2598, 146, 5, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[64594, 2605, 325, 6, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[64934, 2614, 99, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.21"}],
    Cell[65058, 2619, 114, 2, 70, "Input",
      CellTags->"S3.2.2"],
    Cell[65175, 2623, 106, 3, 70, "Output",
      CellTags->"S3.2.2"],
    Cell[65296, 2629, 1270, 29, 70, "Text",
      CellTags->{"S3.2.2", "2.22"}],
    Cell[66569, 2660, 120, 5, 70, "Caption",
      CellTags->"S3.2.2"],
    Cell[66692, 2667, 765, 19, 70, "Text",
      CellTags->{"S3.2.2", "2.23"}],
    Cell[67460, 2688, 185, 7, 70, "Caption",
      CellTags->"S3.2.2"],
    Cell[67648, 2697, 376, 10, 70, "Text",
      CellTags->{"S3.2.2", "2.24"}]},
  "2.1"->{
    Cell[46512, 1875, 84, 1, 70, "Subsection",
      CellTags->{"S3.2.2", "2.1"}]},
  "2.2"->{
    Cell[46599, 1878, 1464, 38, 70, "Text",
      CellTags->{"S3.2.2", "2.2"}]},
  "2.3"->{
    Cell[48066, 1918, 281, 6, 70, "DisplayFormula",
      CellTags->{"S3.2.2", "2.3"}]},
  "2.4"->{
    Cell[48350, 1926, 142, 4, 70, "Text",
      CellTags->{"S3.2.2", "2.4"}]},
  "2.5"->{
    Cell[48495, 1932, 349, 7, 70, "DisplayFormula",
      CellTags->{"S3.2.2", "2.5"}]},
  "2.6"->{
    Cell[48847, 1941, 738, 16, 70, "Text",
      CellTags->{"S3.2.2", "2.6"}]},
  "2.7"->{
    Cell[49588, 1959, 3271, 63, 70, "Text",
      CellTags->{"S3.2.2", "2.7"}]},
  "2.8"->{
    Cell[52964, 2027, 512, 13, 70, "Text",
      CellTags->{"S3.2.2", "2.8"}]},
  "2.9"->{
    Cell[53479, 2042, 90, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.9"}]},
  "2.10"->{
    Cell[53695, 2052, 192, 5, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.10"}]},
  "2.11"->{
    Cell[54842, 2082, 151, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.11"}]},
  "2.12"->{
    Cell[56219, 2115, 128, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.12"}]},
  "2.13"->{
    Cell[56552, 2133, 313, 7, 70, "Text",
      CellTags->{"S3.2.2", "2.13"}]},
  "2.14"->{
    Cell[56868, 2142, 159, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.14"}]},
  "2.15"->{
    Cell[57544, 2167, 164, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.15"}]},
  "2.16"->{
    Cell[59661, 2324, 217, 6, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.16"}]},
  "2.17"->{
    Cell[60375, 2348, 160, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.17"}]},
  "2.18"->{
    Cell[61005, 2369, 97, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.18"}]},
  "2.19"->{
    Cell[63590, 2568, 203, 5, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.19"}]},
  "2.20"->{
    Cell[64282, 2590, 138, 4, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.20"}]},
  "2.21"->{
    Cell[64934, 2614, 99, 1, 70, "MathCaption",
      CellTags->{"S3.2.2", "2.21"}]},
  "2.22"->{
    Cell[65296, 2629, 1270, 29, 70, "Text",
      CellTags->{"S3.2.2", "2.22"}]},
  "2.23"->{
    Cell[66692, 2667, 765, 19, 70, "Text",
      CellTags->{"S3.2.2", "2.23"}]},
  "2.24"->{
    Cell[67648, 2697, 376, 10, 70, "Text",
      CellTags->{"S3.2.2", "2.24"}]},
  "S3.2.3"->{
    Cell[68027, 2709, 91, 1, 70, "Subsection",
      CellTags->{"S3.2.3", "3.1"}],
    Cell[68121, 2712, 389, 7, 70, "Text",
      CellTags->{"S3.2.3", "3.2"}],
    Cell[68513, 2721, 553, 10, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.3"}],
    Cell[69069, 2733, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.4"}],
    Cell[69119, 2736, 553, 10, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.5"}],
    Cell[69675, 2748, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.6"}],
    Cell[69725, 2751, 560, 11, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.7"}],
    Cell[70288, 2764, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.8"}],
    Cell[70338, 2767, 600, 12, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.9"}],
    Cell[70941, 2781, 946, 27, 70, "Text",
      CellTags->{"S3.2.3", "3.10"}],
    Cell[71890, 2810, 3723, 74, 70, "Text",
      CellTags->{"S3.2.3", "3.11"}],
    Cell[75616, 2886, 68, 1, 70, "Caption",
      CellTags->"S3.2.3"],
    Cell[75687, 2889, 1486, 33, 70, "Text",
      CellTags->{"S3.2.3", "3.12"}],
    Cell[77176, 2924, 254, 11, 70, "Caption",
      CellTags->"S3.2.3"],
    Cell[77433, 2937, 2445, 83, 70, "Text",
      CellTags->{"S3.2.3", "3.13"}],
    Cell[79881, 3022, 2604, 55, 70, "Text",
      CellTags->{"S3.2.3", "3.14"}],
    Cell[82488, 3079, 115, 5, 70, "Caption",
      CellTags->"S3.2.3"],
    Cell[82606, 3086, 96, 1, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.15"}],
    Cell[82705, 3089, 121, 5, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[82829, 3096, 198, 5, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.16"}],
    Cell[83052, 3105, 102, 2, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[83157, 3109, 506, 9, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[83678, 3121, 154, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.17"}],
    Cell[83857, 3129, 114, 2, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[83974, 3133, 127, 3, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[84116, 3139, 282, 10, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.18"}],
    Cell[84423, 3153, 103, 2, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[84529, 3157, 522, 10, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[85066, 3170, 173, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.19"}],
    Cell[85264, 3178, 109, 2, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[85376, 3182, 514, 9, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[85905, 3194, 146, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.20"}],
    Cell[86076, 3202, 147, 5, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[86226, 3209, 127, 3, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[86368, 3215, 159, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.21"}],
    Cell[86552, 3223, 186, 6, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[86741, 3231, 104, 3, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[86860, 3237, 132, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.22"}],
    Cell[87017, 3245, 145, 5, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[87165, 3252, 85, 3, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[87265, 3258, 338, 9, 70, "Text",
      CellTags->{"S3.2.3", "3.23"}],
    Cell[87606, 3269, 1317, 29, 70, "Text",
      CellTags->{"S3.2.3", "3.24"}],
    Cell[88926, 3300, 59, 1, 70, "Caption",
      CellTags->"S3.2.3"],
    Cell[88988, 3303, 470, 17, 70, "Text",
      CellTags->{"S3.2.3", "3.25"}],
    Cell[89461, 3322, 1080, 25, 70, "Text",
      CellTags->{"S3.2.3", "3.26"}],
    Cell[90544, 3349, 168, 7, 70, "Caption",
      CellTags->"S3.2.3"],
    Cell[90715, 3358, 134, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.27"}],
    Cell[90874, 3366, 158, 5, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[91035, 3373, 672, 12, 70, "Output",
      CellTags->"S3.2.3"],
    Cell[91722, 3388, 139, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.28"}],
    Cell[91886, 3396, 147, 5, 70, "Input",
      CellTags->"S3.2.3"],
    Cell[92036, 3403, 85, 3, 70, "Output",
      CellTags->"S3.2.3"]},
  "3.1"->{
    Cell[68027, 2709, 91, 1, 70, "Subsection",
      CellTags->{"S3.2.3", "3.1"}]},
  "3.2"->{
    Cell[68121, 2712, 389, 7, 70, "Text",
      CellTags->{"S3.2.3", "3.2"}]},
  "3.3"->{
    Cell[68513, 2721, 553, 10, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.3"}]},
  "3.4"->{
    Cell[69069, 2733, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.4"}]},
  "3.5"->{
    Cell[69119, 2736, 553, 10, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.5"}]},
  "3.6"->{
    Cell[69675, 2748, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.6"}]},
  "3.7"->{
    Cell[69725, 2751, 560, 11, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.7"}]},
  "3.8"->{
    Cell[70288, 2764, 47, 1, 70, "Text",
      CellTags->{"S3.2.3", "3.8"}]},
  "3.9"->{
    Cell[70338, 2767, 600, 12, 70, "DisplayFormula",
      CellTags->{"S3.2.3", "3.9"}]},
  "3.10"->{
    Cell[70941, 2781, 946, 27, 70, "Text",
      CellTags->{"S3.2.3", "3.10"}]},
  "3.11"->{
    Cell[71890, 2810, 3723, 74, 70, "Text",
      CellTags->{"S3.2.3", "3.11"}]},
  "3.12"->{
    Cell[75687, 2889, 1486, 33, 70, "Text",
      CellTags->{"S3.2.3", "3.12"}]},
  "3.13"->{
    Cell[77433, 2937, 2445, 83, 70, "Text",
      CellTags->{"S3.2.3", "3.13"}]},
  "3.14"->{
    Cell[79881, 3022, 2604, 55, 70, "Text",
      CellTags->{"S3.2.3", "3.14"}]},
  "3.15"->{
    Cell[82606, 3086, 96, 1, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.15"}]},
  "3.16"->{
    Cell[82829, 3096, 198, 5, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.16"}]},
  "3.17"->{
    Cell[83678, 3121, 154, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.17"}]},
  "3.18"->{
    Cell[84116, 3139, 282, 10, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.18"}]},
  "3.19"->{
    Cell[85066, 3170, 173, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.19"}]},
  "3.20"->{
    Cell[85905, 3194, 146, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.20"}]},
  "3.21"->{
    Cell[86368, 3215, 159, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.21"}]},
  "3.22"->{
    Cell[86860, 3237, 132, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.22"}]},
  "3.23"->{
    Cell[87265, 3258, 338, 9, 70, "Text",
      CellTags->{"S3.2.3", "3.23"}]},
  "3.24"->{
    Cell[87606, 3269, 1317, 29, 70, "Text",
      CellTags->{"S3.2.3", "3.24"}]},
  "3.25"->{
    Cell[88988, 3303, 470, 17, 70, "Text",
      CellTags->{"S3.2.3", "3.25"}]},
  "3.26"->{
    Cell[89461, 3322, 1080, 25, 70, "Text",
      CellTags->{"S3.2.3", "3.26"}]},
  "3.27"->{
    Cell[90715, 3358, 134, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.27"}]},
  "3.28"->{
    Cell[91722, 3388, 139, 4, 70, "MathCaption",
      CellTags->{"S3.2.3", "3.28"}]},
  "S3.2.4"->{
    Cell[92136, 3409, 92, 1, 70, "Subsection",
      CellTags->{"S3.2.4", "4.1"}],
    Cell[92231, 3412, 2410, 79, 70, "Text",
      CellTags->{"S3.2.4", "4.2"}],
    Cell[94644, 3493, 5662, 107, 70, "Text",
      CellTags->{"S3.2.4", "4.3"}],
    Cell[100309, 3602, 75, 1, 70, "Caption",
      CellTags->"S3.2.4"],
    Cell[100387, 3605, 946, 28, 70, "Text",
      CellTags->{"S3.2.4", "4.4"}],
    Cell[101336, 3635, 1821, 40, 70, "Text",
      CellTags->{"S3.2.4", "4.5"}],
    Cell[103160, 3677, 167, 7, 70, "Caption",
      CellTags->"S3.2.4"],
    Cell[103330, 3686, 1325, 30, 70, "Text",
      CellTags->{"S3.2.4", "4.6"}],
    Cell[104658, 3718, 283, 11, 70, "Caption",
      CellTags->"S3.2.4"],
    Cell[104944, 3731, 103, 1, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.7"}],
    Cell[105050, 3734, 122, 5, 70, "Input",
      CellTags->"S3.2.4"],
    Cell[105175, 3741, 271, 8, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.8"}],
    Cell[105471, 3753, 114, 2, 70, "Input",
      CellTags->"S3.2.4"],
    Cell[105588, 3757, 1538, 26, 70, "Output",
      CellTags->"S3.2.4"],
    Cell[107141, 3786, 228, 5, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.9"}],
    Cell[107394, 3795, 152, 5, 70, "Input",
      CellTags->"S3.2.4"],
    Cell[107549, 3802, 547, 10, 70, "Output",
      CellTags->"S3.2.4"],
    Cell[108111, 3815, 138, 4, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.10"}],
    Cell[108274, 3823, 85, 2, 70, "Input",
      CellTags->"S3.2.4"],
    Cell[108362, 3827, 2182, 172, 70, 2109, 169, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.2.4"],
    Cell[110559, 4002, 87, 1, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.11"}],
    Cell[110671, 4007, 136, 5, 70, "Input",
      CellTags->"S3.2.4"],
    Cell[110810, 4014, 130, 3, 70, "Output",
      CellTags->"S3.2.4"]},
  "4.1"->{
    Cell[92136, 3409, 92, 1, 70, "Subsection",
      CellTags->{"S3.2.4", "4.1"}]},
  "4.2"->{
    Cell[92231, 3412, 2410, 79, 70, "Text",
      CellTags->{"S3.2.4", "4.2"}]},
  "4.3"->{
    Cell[94644, 3493, 5662, 107, 70, "Text",
      CellTags->{"S3.2.4", "4.3"}]},
  "4.4"->{
    Cell[100387, 3605, 946, 28, 70, "Text",
      CellTags->{"S3.2.4", "4.4"}]},
  "4.5"->{
    Cell[101336, 3635, 1821, 40, 70, "Text",
      CellTags->{"S3.2.4", "4.5"}]},
  "4.6"->{
    Cell[103330, 3686, 1325, 30, 70, "Text",
      CellTags->{"S3.2.4", "4.6"}]},
  "4.7"->{
    Cell[104944, 3731, 103, 1, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.7"}]},
  "4.8"->{
    Cell[105175, 3741, 271, 8, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.8"}]},
  "4.9"->{
    Cell[107141, 3786, 228, 5, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.9"}]},
  "4.10"->{
    Cell[108111, 3815, 138, 4, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.10"}]},
  "4.11"->{
    Cell[110559, 4002, 87, 1, 70, "MathCaption",
      CellTags->{"S3.2.4", "4.11"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 111594, 4038},
  {"S3.2.0", 111752, 4043},
  {"0.1", 111841, 4046},
  {"S3.2.1", 111933, 4049},
  {"1.1", 119815, 4254},
  {"1.2", 119907, 4257},
  {"1.3", 119995, 4260},
  {"1.4", 120094, 4263},
  {"1.5", 120183, 4266},
  {"1.6", 120282, 4269},
  {"1.7", 120371, 4272},
  {"1.8", 120469, 4275},
  {"1.9", 120556, 4278},
  {"1.10", 120656, 4281},
  {"1.11", 120746, 4284},
  {"1.12", 120847, 4287},
  {"1.13", 120939, 4290},
  {"1.14", 121039, 4293},
  {"1.15", 121129, 4296},
  {"1.16", 121221, 4299},
  {"1.17", 121314, 4302},
  {"1.18", 121415, 4305},
  {"1.19", 121508, 4308},
  {"1.20", 121605, 4311},
  {"1.21", 121702, 4314},
  {"1.22", 121800, 4317},
  {"1.23", 121898, 4320},
  {"1.24", 121996, 4323},
  {"1.25", 122093, 4326},
  {"1.26", 122191, 4329},
  {"1.27", 122289, 4332},
  {"1.28", 122387, 4335},
  {"1.29", 122485, 4338},
  {"1.30", 122576, 4341},
  {"1.31", 122677, 4344},
  {"1.32", 122767, 4347},
  {"1.33", 122868, 4350},
  {"1.34", 122961, 4353},
  {"1.35", 123053, 4356},
  {"1.36", 123144, 4359},
  {"1.37", 123237, 4362},
  {"1.38", 123335, 4365},
  {"1.39", 123433, 4368},
  {"1.40", 123531, 4371},
  {"1.41", 123629, 4374},
  {"1.42", 123720, 4377},
  {"1.43", 123821, 4380},
  {"1.44", 123913, 4383},
  {"1.45", 124014, 4386},
  {"1.46", 124106, 4389},
  {"1.47", 124198, 4392},
  {"1.48", 124290, 4395},
  {"1.49", 124387, 4398},
  {"1.50", 124485, 4401},
  {"1.51", 124583, 4404},
  {"1.52", 124682, 4407},
  {"1.53", 124782, 4410},
  {"1.54", 124881, 4413},
  {"1.55", 124980, 4416},
  {"1.56", 125079, 4419},
  {"1.57", 125178, 4422},
  {"S3.2.2", 125272, 4425},
  {"2.1", 129283, 4530},
  {"2.2", 129378, 4533},
  {"2.3", 129470, 4536},
  {"2.4", 129570, 4539},
  {"2.5", 129660, 4542},
  {"2.6", 129760, 4545},
  {"2.7", 129851, 4548},
  {"2.8", 129943, 4551},
  {"2.9", 130034, 4554},
  {"2.10", 130131, 4557},
  {"2.11", 130230, 4560},
  {"2.12", 130329, 4563},
  {"2.13", 130428, 4566},
  {"2.14", 130520, 4569},
  {"2.15", 130619, 4572},
  {"2.16", 130718, 4575},
  {"2.17", 130817, 4578},
  {"2.18", 130916, 4581},
  {"2.19", 131014, 4584},
  {"2.20", 131113, 4587},
  {"2.21", 131212, 4590},
  {"2.22", 131310, 4593},
  {"2.23", 131404, 4596},
  {"2.24", 131497, 4599},
  {"S3.2.3", 131592, 4602},
  {"3.1", 135635, 4707},
  {"3.2", 135730, 4710},
  {"3.3", 135820, 4713},
  {"3.4", 135921, 4716},
  {"3.5", 136010, 4719},
  {"3.6", 136111, 4722},
  {"3.7", 136200, 4725},
  {"3.8", 136301, 4728},
  {"3.9", 136390, 4731},
  {"3.10", 136492, 4734},
  {"3.11", 136585, 4737},
  {"3.12", 136679, 4740},
  {"3.13", 136773, 4743},
  {"3.14", 136867, 4746},
  {"3.15", 136961, 4749},
  {"3.16", 137059, 4752},
  {"3.17", 137158, 4755},
  {"3.18", 137257, 4758},
  {"3.19", 137357, 4761},
  {"3.20", 137456, 4764},
  {"3.21", 137555, 4767},
  {"3.22", 137654, 4770},
  {"3.23", 137753, 4773},
  {"3.24", 137845, 4776},
  {"3.25", 137939, 4779},
  {"3.26", 138032, 4782},
  {"3.27", 138126, 4785},
  {"3.28", 138225, 4788},
  {"S3.2.4", 138326, 4791},
  {"4.1", 140200, 4840},
  {"4.2", 140295, 4843},
  {"4.3", 140387, 4846},
  {"4.4", 140480, 4849},
  {"4.5", 140572, 4852},
  {"4.6", 140665, 4855},
  {"4.7", 140758, 4858},
  {"4.8", 140856, 4861},
  {"4.9", 140954, 4864},
  {"4.10", 141053, 4867},
  {"4.11", 141153, 4870}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 65, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1777, 52, 555, 18, 84, "Contents",
  CellTags->"Contents"],
Cell[2335, 72, 72, 1, 58, "Section",
  CellTags->{"S3.2.0", "0.1"}],
Cell[2410, 75, 77, 1, 41, "Subsection",
  CellTags->{"S3.2.1", "1.1"}],
Cell[2490, 78, 954, 28, 59, "Text",
  CellTags->{"S3.2.1", "1.2"}],
Cell[3447, 108, 639, 15, 53, "DisplayFormula",
  CellTags->{"S3.2.1", "1.3"}],
Cell[4089, 125, 326, 11, 25, "Text",
  CellTags->{"S3.2.1", "1.4"}],
Cell[4418, 138, 482, 11, 38, "DisplayFormula",
  CellTags->{"S3.2.1", "1.5"}],
Cell[4903, 151, 759, 21, 58, "Text",
  CellTags->{"S3.2.1", "1.6"}],
Cell[5665, 174, 444, 8, 29, "DisplayFormula",
  CellTags->{"S3.2.1", "1.7"}],
Cell[6112, 184, 66, 1, 24, "Text",
  CellTags->{"S3.2.1", "1.8"}],
Cell[6181, 187, 514, 11, 39, "DisplayFormula",
  CellTags->{"S3.2.1", "1.9"}],
Cell[6698, 200, 101, 1, 24, "Text",
  CellTags->{"S3.2.1", "1.10"}],
Cell[6802, 203, 503, 11, 39, "DisplayFormula",
  CellTags->{"S3.2.1", "1.11"}],
Cell[7308, 216, 1489, 40, 70, "Text",
  CellTags->{"S3.2.1", "1.12"}],
Cell[8800, 258, 275, 5, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.13"}],
Cell[9078, 265, 107, 1, 70, "Text",
  CellTags->{"S3.2.1", "1.14"}],
Cell[9188, 268, 2016, 38, 70, "Text",
  CellTags->{"S3.2.1", "1.15"}],
Cell[11207, 308, 76, 1, 70, "Caption",
  CellTags->"S3.2.1"],
Cell[11286, 311, 1431, 42, 70, "Text",
  CellTags->{"S3.2.1", "1.16"}],
Cell[12720, 355, 300, 6, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.17"}],
Cell[13023, 363, 1941, 61, 70, "Text",
  CellTags->{"S3.2.1", "1.18"}],
Cell[14967, 426, 78, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.19"}],
Cell[15048, 429, 93, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[15144, 433, 97, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.20"}],
Cell[15244, 436, 149, 6, 70, "Input",
  CellTags->"S3.2.1"],
Cell[15396, 444, 173, 4, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.21"}],

Cell[CellGroupData[{
Cell[15594, 452, 99, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[15696, 456, 429, 8, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[16140, 467, 155, 4, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.22"}],

Cell[CellGroupData[{
Cell[16320, 475, 93, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[16416, 479, 415, 7, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[16846, 489, 283, 8, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.23"}],
Cell[17132, 499, 95, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[17230, 503, 98, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.24"}],

Cell[CellGroupData[{
Cell[17353, 508, 76, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[17432, 512, 117, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[17564, 518, 128, 4, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.25"}],

Cell[CellGroupData[{
Cell[17717, 526, 114, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[17834, 530, 106, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[17955, 536, 174, 5, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.26"}],
Cell[18132, 543, 150, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[18285, 550, 111, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.27"}],

Cell[CellGroupData[{
Cell[18421, 555, 84, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[18508, 559, 111, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[18634, 565, 106, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.28"}],

Cell[CellGroupData[{
Cell[18765, 570, 141, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[18909, 577, 85, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[19009, 583, 107, 1, 70, "Text",
  CellTags->{"S3.2.1", "1.29"}],
Cell[19119, 586, 269, 6, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.30"}],
Cell[19391, 594, 52, 1, 70, "Text",
  CellTags->{"S3.2.1", "1.31"}],
Cell[19446, 597, 306, 6, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.32"}],
Cell[19755, 605, 1429, 40, 70, "Text",
  CellTags->{"S3.2.1", "1.33"}],
Cell[21187, 647, 765, 19, 70, "Text",
  CellTags->{"S3.2.1", "1.34"}],
Cell[21955, 668, 169, 7, 70, "Caption",
  CellTags->"S3.2.1"],
Cell[22127, 677, 286, 8, 70, "Text",
  CellTags->{"S3.2.1", "1.35"}],
Cell[22416, 687, 2500, 53, 70, "Text",
  CellTags->{"S3.2.1", "1.36"}],
Cell[24919, 742, 127, 5, 70, "Caption",
  CellTags->"S3.2.1"],
Cell[25049, 749, 110, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.37"}],

Cell[CellGroupData[{
Cell[25184, 754, 87, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[25274, 758, 193, 4, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[25482, 765, 276, 7, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.38"}],

Cell[CellGroupData[{
Cell[25783, 776, 84, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[25870, 780, 198, 4, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[26083, 787, 109, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.39"}],

Cell[CellGroupData[{
Cell[26217, 792, 117, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[26337, 796, 442, 9, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[26794, 808, 262, 6, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.40"}],

Cell[CellGroupData[{
Cell[27081, 818, 141, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[27225, 825, 264, 5, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[27504, 833, 244, 7, 70, "Text",
  CellTags->{"S3.2.1", "1.41"}],
Cell[27751, 842, 256, 5, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.42"}],
Cell[28010, 849, 346, 10, 70, "Text",
  CellTags->{"S3.2.1", "1.43"}],
Cell[28359, 861, 371, 7, 70, "DisplayFormula",
  CellTags->{"S3.2.1", "1.44"}],
Cell[28733, 870, 648, 23, 70, "Text",
  CellTags->{"S3.2.1", "1.45"}],
Cell[29384, 895, 814, 17, 70, "Text",
  CellTags->{"S3.2.1", "1.46"}],
Cell[30201, 914, 86, 1, 70, "Caption",
  CellTags->"S3.2.1"],
Cell[30290, 917, 765, 19, 70, "Text",
  CellTags->{"S3.2.1", "1.47"}],
Cell[31058, 938, 112, 5, 70, "Caption",
  CellTags->"S3.2.1"],
Cell[31173, 945, 98, 1, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.48"}],
Cell[31274, 948, 104, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[31381, 952, 215, 7, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.49"}],
Cell[31599, 961, 150, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[31752, 968, 150, 4, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.50"}],

Cell[CellGroupData[{
Cell[31927, 976, 81, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[32011, 980, 106, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[32132, 986, 490, 14, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.51"}],

Cell[CellGroupData[{
Cell[32647, 1004, 137, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[32787, 1011, 7004, 455, 70, 6931, 452, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[39806, 1469, 341, 10, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.52"}],

Cell[CellGroupData[{
Cell[40172, 1483, 168, 5, 70, "Input",
  CellTags->"S3.2.1"],
Cell[40343, 1490, 4392, 310, 70, 4319, 307, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[44750, 1803, 137, 4, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.53"}],

Cell[CellGroupData[{
Cell[44912, 1811, 101, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[45016, 1815, 85, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[45116, 1821, 176, 5, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.54"}],
Cell[45295, 1828, 99, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[45397, 1832, 237, 5, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.55"}],
Cell[45637, 1839, 106, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[45746, 1843, 251, 9, 70, "MathCaption",
  CellTags->{"S3.2.1", "1.56"}],

Cell[CellGroupData[{
Cell[46022, 1856, 99, 2, 70, "Input",
  CellTags->"S3.2.1"],
Cell[46124, 1860, 85, 3, 70, "Output",
  CellTags->"S3.2.1"]
}, Open  ]],
Cell[46224, 1866, 285, 7, 70, "Text",
  CellTags->{"S3.2.1", "1.57"}],
Cell[46512, 1875, 84, 1, 70, "Subsection",
  CellTags->{"S3.2.2", "2.1"}],
Cell[46599, 1878, 1464, 38, 70, "Text",
  CellTags->{"S3.2.2", "2.2"}],
Cell[48066, 1918, 281, 6, 70, "DisplayFormula",
  CellTags->{"S3.2.2", "2.3"}],
Cell[48350, 1926, 142, 4, 70, "Text",
  CellTags->{"S3.2.2", "2.4"}],
Cell[48495, 1932, 349, 7, 70, "DisplayFormula",
  CellTags->{"S3.2.2", "2.5"}],
Cell[48847, 1941, 738, 16, 70, "Text",
  CellTags->{"S3.2.2", "2.6"}],
Cell[49588, 1959, 3271, 63, 70, "Text",
  CellTags->{"S3.2.2", "2.7"}],
Cell[52862, 2024, 99, 1, 70, "Caption",
  CellTags->"S3.2.2"],
Cell[52964, 2027, 512, 13, 70, "Text",
  CellTags->{"S3.2.2", "2.8"}],
Cell[53479, 2042, 90, 1, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.9"}],
Cell[53572, 2045, 120, 5, 70, "Input",
  CellTags->"S3.2.2"],
Cell[53695, 2052, 192, 5, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.10"}],

Cell[CellGroupData[{
Cell[53912, 2061, 103, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[54018, 2065, 809, 14, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[54842, 2082, 151, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.11"}],

Cell[CellGroupData[{
Cell[55018, 2090, 107, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[55128, 2094, 1076, 18, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[56219, 2115, 128, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.12"}],

Cell[CellGroupData[{
Cell[56372, 2123, 79, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[56454, 2127, 83, 3, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[56552, 2133, 313, 7, 70, "Text",
  CellTags->{"S3.2.2", "2.13"}],
Cell[56868, 2142, 159, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.14"}],

Cell[CellGroupData[{
Cell[57052, 2150, 146, 5, 70, "Input",
  CellTags->"S3.2.2"],
Cell[57201, 2157, 328, 7, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[57544, 2167, 164, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.15"}],

Cell[CellGroupData[{
Cell[57733, 2175, 85, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[57821, 2179, 1825, 142, 70, 1752, 139, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[59661, 2324, 217, 6, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.16"}],

Cell[CellGroupData[{
Cell[59903, 2334, 122, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[60028, 2338, 332, 7, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[60375, 2348, 160, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.17"}],

Cell[CellGroupData[{
Cell[60560, 2356, 97, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[60660, 2360, 330, 6, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[61005, 2369, 97, 1, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.18"}],

Cell[CellGroupData[{
Cell[61127, 2374, 85, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[61215, 2378, 2360, 187, 70, 2287, 184, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[63590, 2568, 203, 5, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.19"}],

Cell[CellGroupData[{
Cell[63818, 2577, 116, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[63937, 2581, 330, 6, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[64282, 2590, 138, 4, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.20"}],

Cell[CellGroupData[{
Cell[64445, 2598, 146, 5, 70, "Input",
  CellTags->"S3.2.2"],
Cell[64594, 2605, 325, 6, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[64934, 2614, 99, 1, 70, "MathCaption",
  CellTags->{"S3.2.2", "2.21"}],

Cell[CellGroupData[{
Cell[65058, 2619, 114, 2, 70, "Input",
  CellTags->"S3.2.2"],
Cell[65175, 2623, 106, 3, 70, "Output",
  CellTags->"S3.2.2"]
}, Open  ]],
Cell[65296, 2629, 1270, 29, 70, "Text",
  CellTags->{"S3.2.2", "2.22"}],
Cell[66569, 2660, 120, 5, 70, "Caption",
  CellTags->"S3.2.2"],
Cell[66692, 2667, 765, 19, 70, "Text",
  CellTags->{"S3.2.2", "2.23"}],
Cell[67460, 2688, 185, 7, 70, "Caption",
  CellTags->"S3.2.2"],
Cell[67648, 2697, 376, 10, 70, "Text",
  CellTags->{"S3.2.2", "2.24"}],
Cell[68027, 2709, 91, 1, 70, "Subsection",
  CellTags->{"S3.2.3", "3.1"}],
Cell[68121, 2712, 389, 7, 70, "Text",
  CellTags->{"S3.2.3", "3.2"}],
Cell[68513, 2721, 553, 10, 70, "DisplayFormula",
  CellTags->{"S3.2.3", "3.3"}],
Cell[69069, 2733, 47, 1, 70, "Text",
  CellTags->{"S3.2.3", "3.4"}],
Cell[69119, 2736, 553, 10, 70, "DisplayFormula",
  CellTags->{"S3.2.3", "3.5"}],
Cell[69675, 2748, 47, 1, 70, "Text",
  CellTags->{"S3.2.3", "3.6"}],
Cell[69725, 2751, 560, 11, 70, "DisplayFormula",
  CellTags->{"S3.2.3", "3.7"}],
Cell[70288, 2764, 47, 1, 70, "Text",
  CellTags->{"S3.2.3", "3.8"}],
Cell[70338, 2767, 600, 12, 70, "DisplayFormula",
  CellTags->{"S3.2.3", "3.9"}],
Cell[70941, 2781, 946, 27, 70, "Text",
  CellTags->{"S3.2.3", "3.10"}],
Cell[71890, 2810, 3723, 74, 70, "Text",
  CellTags->{"S3.2.3", "3.11"}],
Cell[75616, 2886, 68, 1, 70, "Caption",
  CellTags->"S3.2.3"],
Cell[75687, 2889, 1486, 33, 70, "Text",
  CellTags->{"S3.2.3", "3.12"}],
Cell[77176, 2924, 254, 11, 70, "Caption",
  CellTags->"S3.2.3"],
Cell[77433, 2937, 2445, 83, 70, "Text",
  CellTags->{"S3.2.3", "3.13"}],
Cell[79881, 3022, 2604, 55, 70, "Text",
  CellTags->{"S3.2.3", "3.14"}],
Cell[82488, 3079, 115, 5, 70, "Caption",
  CellTags->"S3.2.3"],
Cell[82606, 3086, 96, 1, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.15"}],
Cell[82705, 3089, 121, 5, 70, "Input",
  CellTags->"S3.2.3"],
Cell[82829, 3096, 198, 5, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.16"}],

Cell[CellGroupData[{
Cell[83052, 3105, 102, 2, 70, "Input",
  CellTags->"S3.2.3"],
Cell[83157, 3109, 506, 9, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[83678, 3121, 154, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.17"}],

Cell[CellGroupData[{
Cell[83857, 3129, 114, 2, 70, "Input",
  CellTags->"S3.2.3"],
Cell[83974, 3133, 127, 3, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[84116, 3139, 282, 10, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.18"}],

Cell[CellGroupData[{
Cell[84423, 3153, 103, 2, 70, "Input",
  CellTags->"S3.2.3"],
Cell[84529, 3157, 522, 10, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[85066, 3170, 173, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.19"}],

Cell[CellGroupData[{
Cell[85264, 3178, 109, 2, 70, "Input",
  CellTags->"S3.2.3"],
Cell[85376, 3182, 514, 9, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[85905, 3194, 146, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.20"}],

Cell[CellGroupData[{
Cell[86076, 3202, 147, 5, 70, "Input",
  CellTags->"S3.2.3"],
Cell[86226, 3209, 127, 3, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[86368, 3215, 159, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.21"}],

Cell[CellGroupData[{
Cell[86552, 3223, 186, 6, 70, "Input",
  CellTags->"S3.2.3"],
Cell[86741, 3231, 104, 3, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[86860, 3237, 132, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.22"}],

Cell[CellGroupData[{
Cell[87017, 3245, 145, 5, 70, "Input",
  CellTags->"S3.2.3"],
Cell[87165, 3252, 85, 3, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[87265, 3258, 338, 9, 70, "Text",
  CellTags->{"S3.2.3", "3.23"}],
Cell[87606, 3269, 1317, 29, 70, "Text",
  CellTags->{"S3.2.3", "3.24"}],
Cell[88926, 3300, 59, 1, 70, "Caption",
  CellTags->"S3.2.3"],
Cell[88988, 3303, 470, 17, 70, "Text",
  CellTags->{"S3.2.3", "3.25"}],
Cell[89461, 3322, 1080, 25, 70, "Text",
  CellTags->{"S3.2.3", "3.26"}],
Cell[90544, 3349, 168, 7, 70, "Caption",
  CellTags->"S3.2.3"],
Cell[90715, 3358, 134, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.27"}],

Cell[CellGroupData[{
Cell[90874, 3366, 158, 5, 70, "Input",
  CellTags->"S3.2.3"],
Cell[91035, 3373, 672, 12, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[91722, 3388, 139, 4, 70, "MathCaption",
  CellTags->{"S3.2.3", "3.28"}],

Cell[CellGroupData[{
Cell[91886, 3396, 147, 5, 70, "Input",
  CellTags->"S3.2.3"],
Cell[92036, 3403, 85, 3, 70, "Output",
  CellTags->"S3.2.3"]
}, Open  ]],
Cell[92136, 3409, 92, 1, 70, "Subsection",
  CellTags->{"S3.2.4", "4.1"}],
Cell[92231, 3412, 2410, 79, 70, "Text",
  CellTags->{"S3.2.4", "4.2"}],
Cell[94644, 3493, 5662, 107, 70, "Text",
  CellTags->{"S3.2.4", "4.3"}],
Cell[100309, 3602, 75, 1, 70, "Caption",
  CellTags->"S3.2.4"],
Cell[100387, 3605, 946, 28, 70, "Text",
  CellTags->{"S3.2.4", "4.4"}],
Cell[101336, 3635, 1821, 40, 70, "Text",
  CellTags->{"S3.2.4", "4.5"}],
Cell[103160, 3677, 167, 7, 70, "Caption",
  CellTags->"S3.2.4"],
Cell[103330, 3686, 1325, 30, 70, "Text",
  CellTags->{"S3.2.4", "4.6"}],
Cell[104658, 3718, 283, 11, 70, "Caption",
  CellTags->"S3.2.4"],
Cell[104944, 3731, 103, 1, 70, "MathCaption",
  CellTags->{"S3.2.4", "4.7"}],
Cell[105050, 3734, 122, 5, 70, "Input",
  CellTags->"S3.2.4"],
Cell[105175, 3741, 271, 8, 70, "MathCaption",
  CellTags->{"S3.2.4", "4.8"}],

Cell[CellGroupData[{
Cell[105471, 3753, 114, 2, 70, "Input",
  CellTags->"S3.2.4"],
Cell[105588, 3757, 1538, 26, 70, "Output",
  CellTags->"S3.2.4"]
}, Open  ]],
Cell[107141, 3786, 228, 5, 70, "MathCaption",
  CellTags->{"S3.2.4", "4.9"}],

Cell[CellGroupData[{
Cell[107394, 3795, 152, 5, 70, "Input",
  CellTags->"S3.2.4"],
Cell[107549, 3802, 547, 10, 70, "Output",
  CellTags->"S3.2.4"]
}, Open  ]],
Cell[108111, 3815, 138, 4, 70, "MathCaption",
  CellTags->{"S3.2.4", "4.10"}],

Cell[CellGroupData[{
Cell[108274, 3823, 85, 2, 70, "Input",
  CellTags->"S3.2.4"],
Cell[108362, 3827, 2182, 172, 70, 2109, 169, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.2.4"]
}, Open  ]],
Cell[110559, 4002, 87, 1, 70, "MathCaption",
  CellTags->{"S3.2.4", "4.11"}],

Cell[CellGroupData[{
Cell[110671, 4007, 136, 5, 70, "Input",
  CellTags->"S3.2.4"],
Cell[110810, 4014, 130, 3, 70, "Output",
  CellTags->"S3.2.4"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

