(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    124250,       6753]*)
(*NotebookOutlinePosition[    141648,       7260]*)
(*  CellTagsIndexPosition[    140175,       7200]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["3.3 Other Utilities", "Section",
  CellTags->"Contents"],

Cell["3.3 Other Utilities", "Section",
  CellTags->{"S3.3.0", "0.1"}],

Cell[TextData[{
  "As we know, the output of ",
  StyleBox["WaveletTransform", "MR"],
  " is a list of lists. Apart from the first sublist which is the residual \
trend, each sublist contains the coefficients of details at a particular \
resolution level. For one\[Hyphen]dimensional data, there are usually two \
ways of visualizing these coefficients. One way is to plot the coefficients \
at a particular level ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm
      \`{d\_0\%j, d\_1\%j, \[Ellipsis], d\_k\%j, \[Ellipsis]}\)], 
    "InlineFormula",
    CellTags->"S3.3.0"],
  ", against the index ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ". Sometimes it is useful to stack the plots of coefficients of different \
levels together to compare the relative magnitudes of the coefficients. ",
  StyleBox["PlotCoefficients[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox["]", "MR"],
  " accomplishes this. It plots each sublist of ",
  StyleBox["coefs", "TI"],
  " on the same vertical scale and stack these plots on top of each other. \
Note that since the sublist can have different lengths, the horizontal scale \
is determined according to the longest sublist. That is, if the longest \
sublist has length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", the coefficients in any sublist with length ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " are plotted as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`N  k/n\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`k = 0, 1, \[Ellipsis], n - 1\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ". \nAnother way of visualizing the relative magnitude of \
one\[Hyphen]dimensional coefficients is to use phase space plot or time\
\[Hyphen]frequency plot. With each wavelet basis function, we associate a \
rectangular area in phase space. The width of each rectangle is proportional \
to the \"spread\" of the particular wavelet function in time ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]  t\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " and its height is proportional to that in frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ". It is located roughly at ",
  Cell[BoxData[
      \(TraditionalForm\`{\(t\^*\), \(\[Omega]\^*\)}\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", the \"average\" location of the wavelet in the time and frequency \
domains. The area of each rectangle is a constant. For large ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", the rectangle associated with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(j  k\)\) \((t)\)\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " will be located in the upper\[Hyphen]right corner of the phase space, \
occupying a thin, tall region, whereas for small ",
  Cell[BoxData[
      \(TraditionalForm\`j\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", it will be located in the lower\[Hyphen]left corner, occupying a wide, \
short region. We plot the wavelet coefficients in phase space by shading the \
areas of corresponding basis functions according to the absolute values of \
the coefficients. The larger the absolute value, the darker the shading. "
}], "Text",
  CellTags->{"S3.3.0", "0.2"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotCoefficients[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\\\
\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("plot one\[Hyphen]dimensional wavelet, sine, or cosine \
coefficients "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PhaseSpacePlot[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("plot one\[Hyphen]dimensional wavelet, sine, or cosine coefficients \
in phase space "\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.3"}],

Cell["Plotting one\[Hyphen]dimensional coefficients.", "Caption",
  CellTags->"S3.3.0"],

Cell["\<\
Note that the usual graphics options can be used with these two \
functions. \
\>", "Text",
  CellTags->{"S3.3.0", "0.4"}],

Cell["This loads the package.", "MathCaption",
  CellTags->{"S3.3.0", "0.5"}],

Cell["Needs[\"Wavelets`Wavelets`\"]", "Input",
  CellLabel->"In[1]:= ",
  CellTags->"S3.3.0"],

Cell["\<\
We first generate random data of length 40 and then show the length \
of each sublist of the wavelet transformed data.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.6"}],

Cell[CellGroupData[{

Cell["\<\
(SeedRandom[4586347];
data = Table[Random[], {40}];
d2 = DaubechiesFilter[2];
wtdata = WaveletTransform[data, d2];
Length /@ wtdata)\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({5, 5, 10, 20}\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  StyleBox["PlotCoefficients", "MR"],
  " stacks the plots of sublists together with the first sublist at the \
bottom. Note that the horizontal scale corresponds to the index of the \
coefficients in the longest sublist. Note also that the usual graphics \
options can be used with this function."
}], "MathCaption",
  CellTags->{"S3.3.0", "0.7"}],

Cell[CellGroupData[{

Cell["PlotCoefficients[wtdata, Frame -> True]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 -0.117044 0.104698 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(15)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02381 .1871 L
s
.21429 .01472 m
.21429 .10899 L
s
.40476 .01472 m
.40476 .20025 L
s
.59524 .01472 m
.59524 .18592 L
s
.78571 .01472 m
.78571 .17879 L
s
.02381 .2826 m
.02381 .28144 L
s
.21429 .2826 m
.21429 .26225 L
s
.40476 .2826 m
.40476 .31359 L
s
.59524 .2826 m
.59524 .29381 L
s
.78571 .2826 m
.78571 .28794 L
s
.02381 .41436 m
.02381 .37554 L
s
.11905 .41436 m
.11905 .45201 L
s
.21429 .41436 m
.21429 .44023 L
s
.30952 .41436 m
.30952 .4124 L
s
.40476 .41436 m
.40476 .42531 L
s
.5 .41436 m
.5 .43985 L
s
.59524 .41436 m
.59524 .43376 L
s
.69048 .41436 m
.69048 .48024 L
s
.78571 .41436 m
.78571 .37504 L
s
.88095 .41436 m
.88095 .42705 L
s
.02381 .54612 m
.02381 .60332 L
s
.07143 .54612 m
.07143 .5053 L
s
.11905 .54612 m
.11905 .52958 L
s
.16667 .54612 m
.16667 .53581 L
s
.21429 .54612 m
.21429 .53462 L
s
.2619 .54612 m
.2619 .52083 L
s
.30952 .54612 m
.30952 .55984 L
s
.35714 .54612 m
.35714 .51202 L
s
.40476 .54612 m
.40476 .49065 L
s
.45238 .54612 m
.45238 .56595 L
s
.5 .54612 m
.5 .52166 L
s
.54762 .54612 m
.54762 .54871 L
s
.59524 .54612 m
.59524 .54291 L
s
.64286 .54612 m
.64286 .52541 L
s
.69048 .54612 m
.69048 .57301 L
s
.7381 .54612 m
.7381 .58629 L
s
.78571 .54612 m
.78571 .57096 L
s
.83333 .54612 m
.83333 .56102 L
s
.88095 .54612 m
.88095 .48321 L
s
.92857 .54612 m
.92857 .57165 L
s
0 1 1 r
.02381 .01472 m
.97619 .01472 L
s
.02381 .2826 m
.97619 .2826 L
s
.02381 .41436 m
.97619 .41436 L
s
.02381 .54612 m
.97619 .54612 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
We can also just pick one particular resolution level or a few \
levels to plot.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.8"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[wtdata[[3]], Axes -> True,
AxesOrigin -> {-0.2, 0}]\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.234736 0.585765 [
[.02381 .22224 -3 -9 ]
[.02381 .22224 3 0 ]
[.21429 .22224 -3 -9 ]
[.21429 .22224 3 0 ]
[.40476 .22224 -3 -9 ]
[.40476 .22224 3 0 ]
[.59524 .22224 -3 -9 ]
[.59524 .22224 3 0 ]
[.78571 .22224 -3 -9 ]
[.78571 .22224 3 0 ]
[.97619 .22224 -6 -9 ]
[.97619 .22224 6 0 ]
[-0.00774 .00043 -24 -4.5 ]
[-0.00774 .00043 0 4.5 ]
[-0.00774 .11758 -24 -4.5 ]
[-0.00774 .11758 0 4.5 ]
[-0.00774 .35189 -18 -4.5 ]
[-0.00774 .35189 0 4.5 ]
[-0.00774 .46904 -18 -4.5 ]
[-0.00774 .46904 0 4.5 ]
[-0.00774 .58619 -18 -4.5 ]
[-0.00774 .58619 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .23474 m
.02381 .24099 L
s
[(0)] .02381 .22224 0 1 Mshowa
.21429 .23474 m
.21429 .24099 L
s
[(2)] .21429 .22224 0 1 Mshowa
.40476 .23474 m
.40476 .24099 L
s
[(4)] .40476 .22224 0 1 Mshowa
.59524 .23474 m
.59524 .24099 L
s
[(6)] .59524 .22224 0 1 Mshowa
.78571 .23474 m
.78571 .24099 L
s
[(8)] .78571 .22224 0 1 Mshowa
.97619 .23474 m
.97619 .24099 L
s
[(10)] .97619 .22224 0 1 Mshowa
.125 Mabswid
.07143 .23474 m
.07143 .23849 L
s
.11905 .23474 m
.11905 .23849 L
s
.16667 .23474 m
.16667 .23849 L
s
.2619 .23474 m
.2619 .23849 L
s
.30952 .23474 m
.30952 .23849 L
s
.35714 .23474 m
.35714 .23849 L
s
.45238 .23474 m
.45238 .23849 L
s
.5 .23474 m
.5 .23849 L
s
.54762 .23474 m
.54762 .23849 L
s
.64286 .23474 m
.64286 .23849 L
s
.69048 .23474 m
.69048 .23849 L
s
.7381 .23474 m
.7381 .23849 L
s
.83333 .23474 m
.83333 .23849 L
s
.88095 .23474 m
.88095 .23849 L
s
.92857 .23474 m
.92857 .23849 L
s
.25 Mabswid
0 .23474 m
1 .23474 L
s
.00476 .00043 m
.01101 .00043 L
s
[(-0.4)] -0.00774 .00043 1 0 Mshowa
.00476 .11758 m
.01101 .11758 L
s
[(-0.2)] -0.00774 .11758 1 0 Mshowa
.00476 .35189 m
.01101 .35189 L
s
[(0.2)] -0.00774 .35189 1 0 Mshowa
.00476 .46904 m
.01101 .46904 L
s
[(0.4)] -0.00774 .46904 1 0 Mshowa
.00476 .58619 m
.01101 .58619 L
s
[(0.6)] -0.00774 .58619 1 0 Mshowa
.125 Mabswid
.00476 .02972 m
.00851 .02972 L
s
.00476 .05901 m
.00851 .05901 L
s
.00476 .08829 m
.00851 .08829 L
s
.00476 .14687 m
.00851 .14687 L
s
.00476 .17616 m
.00851 .17616 L
s
.00476 .20545 m
.00851 .20545 L
s
.00476 .26402 m
.00851 .26402 L
s
.00476 .29331 m
.00851 .29331 L
s
.00476 .3226 m
.00851 .3226 L
s
.00476 .38118 m
.00851 .38118 L
s
.00476 .41047 m
.00851 .41047 L
s
.00476 .43975 m
.00851 .43975 L
s
.00476 .49833 m
.00851 .49833 L
s
.00476 .52762 m
.00851 .52762 L
s
.00476 .55691 m
.00851 .55691 L
s
.00476 .61548 m
.00851 .61548 L
s
.25 Mabswid
.00476 0 m
.00476 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .23474 m
.02381 .01751 L
s
.11905 .23474 m
.11905 .44538 L
s
.21429 .23474 m
.21429 .37946 L
s
.30952 .23474 m
.30952 .22378 L
s
.40476 .23474 m
.40476 .29598 L
s
.5 .23474 m
.5 .37732 L
s
.59524 .23474 m
.59524 .34329 L
s
.69048 .23474 m
.69048 .60332 L
s
.78571 .23474 m
.78571 .01472 L
s
.88095 .23474 m
.88095 .30573 L
s
0 1 1 r
.02381 .23474 m
.97619 .23474 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "In addition to the usual graphics options, the function ",
  StyleBox["PlotCoefficients", "MR"],
  " has another option ",
  StyleBox["PlotLines", "MR"],
  ", which specifies whether to plot the vertical lines joining the data \
points and the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis. "
}], "Text",
  CellTags->{"S3.3.0", "0.9"}],

Cell[TextData[{
  "We can choose not to plot the vertical lines joining the data points and \
the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis."
}], "MathCaption",
  CellTags->{"S3.3.0", "0.10"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[wtdata, PlotLines -> False,
Axes -> {True, False}]\
\>", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 -0.117044 0.104698 [
[.02381 .07985 -3 -9 ]
[.02381 .07985 3 0 ]
[.2619 .07985 -3 -9 ]
[.2619 .07985 3 0 ]
[.5 .07985 -6 -9 ]
[.5 .07985 6 0 ]
[.7381 .07985 -6 -9 ]
[.7381 .07985 6 0 ]
[.97619 .07985 -6 -9 ]
[.97619 .07985 6 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .09235 m
.02381 .0986 L
s
[(0)] .02381 .07985 0 1 Mshowa
.2619 .09235 m
.2619 .0986 L
s
[(5)] .2619 .07985 0 1 Mshowa
.5 .09235 m
.5 .0986 L
s
[(10)] .5 .07985 0 1 Mshowa
.7381 .09235 m
.7381 .0986 L
s
[(15)] .7381 .07985 0 1 Mshowa
.97619 .09235 m
.97619 .0986 L
s
[(20)] .97619 .07985 0 1 Mshowa
.125 Mabswid
.07143 .09235 m
.07143 .0961 L
s
.11905 .09235 m
.11905 .0961 L
s
.16667 .09235 m
.16667 .0961 L
s
.21429 .09235 m
.21429 .0961 L
s
.30952 .09235 m
.30952 .0961 L
s
.35714 .09235 m
.35714 .0961 L
s
.40476 .09235 m
.40476 .0961 L
s
.45238 .09235 m
.45238 .0961 L
s
.54762 .09235 m
.54762 .0961 L
s
.59524 .09235 m
.59524 .0961 L
s
.64286 .09235 m
.64286 .0961 L
s
.69048 .09235 m
.69048 .0961 L
s
.78571 .09235 m
.78571 .0961 L
s
.83333 .09235 m
.83333 .0961 L
s
.88095 .09235 m
.88095 .0961 L
s
.92857 .09235 m
.92857 .0961 L
s
.25 Mabswid
0 .09235 m
1 .09235 L
s
.008 w
.02381 .1871 Mdot
.21429 .10899 Mdot
.40476 .20025 Mdot
.59524 .18592 Mdot
.78571 .17879 Mdot
.02381 .28144 Mdot
.21429 .26225 Mdot
.40476 .31359 Mdot
.59524 .29381 Mdot
.78571 .28794 Mdot
.02381 .37554 Mdot
.11905 .45201 Mdot
.21429 .44023 Mdot
.30952 .4124 Mdot
.40476 .42531 Mdot
.5 .43985 Mdot
.59524 .43376 Mdot
.69048 .48024 Mdot
.78571 .37504 Mdot
.88095 .42705 Mdot
.02381 .60332 Mdot
.07143 .5053 Mdot
.11905 .52958 Mdot
.16667 .53581 Mdot
.21429 .53462 Mdot
.2619 .52083 Mdot
.30952 .55984 Mdot
.35714 .51202 Mdot
.40476 .49065 Mdot
.45238 .56595 Mdot
.5 .52166 Mdot
.54762 .54871 Mdot
.59524 .54291 Mdot
.64286 .52541 Mdot
.69048 .57301 Mdot
.7381 .58629 Mdot
.78571 .57096 Mdot
.83333 .56102 Mdot
.88095 .48321 Mdot
.92857 .57165 Mdot
0 1 1 r
.5 Mabswid
.02381 .01472 m
.97619 .01472 L
s
.02381 .2826 m
.97619 .2826 L
s
.02381 .41436 m
.97619 .41436 L
s
.02381 .54612 m
.97619 .54612 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotLines\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"True\\\\\\\"\\\", \\\"MR\
\\\"]\\) \"\>", 
                  RowBox[{\("whether to plot lines from data points to "\), 
                    StyleBox["x",
                      "InlineFormula"], \(" axis "\)}]}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->True}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.11"}],

Cell[TextData[{
  "Option for ",
  StyleBox["PlotCoefficients", "MR"],
  "."
}], "Caption",
  CellTags->"S3.3.0"],

Cell[TextData[{
  "If the sublists in turn contain sublists, as in the output of ",
  StyleBox["WaveletPacketCoefficients", "MR"],
  ", the function ",
  StyleBox["PlotCoefficients", "MR"],
  " will flatten the sublist in each level and plot them with a dividing line \
indicating the original grouping of the coefficients. "
}], "Text",
  CellTags->{"S3.3.0", "0.12"}],

Cell["This gives the wavelet packet coefficients table.", "MathCaption",
  CellTags->{"S3.3.0", "0.13"}],

Cell["wpdata = WaveletPacketCoefficients[data, d2];", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"S3.3.0"],

Cell["\<\
Each sublist is flattened and vertical lines are drawn to indicate \
the original grouping of the coefficients.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.14"}],

Cell[CellGroupData[{

Cell["PlotCoefficients[wpdata, Frame -> True]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 -0.153457 0.0474491 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(20)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(30)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(40)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02381 .05725 L
s
.04762 .01472 m
.04762 .01929 L
s
.07143 .01472 m
.07143 .0263 L
s
.09524 .01472 m
.09524 .05956 L
s
.11905 .01472 m
.11905 .04463 L
s
.14286 .01472 m
.14286 .05813 L
s
.16667 .01472 m
.16667 .03815 L
s
.19048 .01472 m
.19048 .03682 L
s
.21429 .01472 m
.21429 .03644 L
s
.2381 .01472 m
.2381 .04659 L
s
.2619 .01472 m
.2619 .01785 L
s
.28571 .01472 m
.28571 .02327 L
s
.30952 .01472 m
.30952 .03309 L
s
.33333 .01472 m
.33333 .02885 L
s
.35714 .01472 m
.35714 .01785 L
s
.38095 .01472 m
.38095 .04066 L
s
.40476 .01472 m
.40476 .01508 L
s
.42857 .01472 m
.42857 .05452 L
s
.45238 .01472 m
.45238 .05291 L
s
.47619 .01472 m
.47619 .0437 L
s
.5 .01472 m
.5 .0389 L
s
.52381 .01472 m
.52381 .05587 L
s
.54762 .01472 m
.54762 .04254 L
s
.57143 .01472 m
.57143 .0349 L
s
.59524 .01472 m
.59524 .04381 L
s
.61905 .01472 m
.61905 .0513 L
s
.64286 .01472 m
.64286 .03096 L
s
.66667 .01472 m
.66667 .0375 L
s
.69048 .01472 m
.69048 .06135 L
s
.71429 .01472 m
.71429 .05533 L
s
.7381 .01472 m
.7381 .05497 L
s
.7619 .01472 m
.7619 .0154 L
s
.78571 .01472 m
.78571 .03963 L
s
.80952 .01472 m
.80952 .02345 L
s
.83333 .01472 m
.83333 .05183 L
s
.85714 .01472 m
.85714 .05429 L
s
.88095 .01472 m
.88095 .02126 L
s
.90476 .01472 m
.90476 .05677 L
s
.92857 .01472 m
.92857 .04869 L
s
.95238 .01472 m
.95238 .02834 L
s
.02381 .18289 m
.02381 .20405 L
s
.04762 .18289 m
.04762 .22708 L
s
.07143 .18289 m
.07143 .23604 L
s
.09524 .18289 m
.09524 .21344 L
s
.11905 .18289 m
.11905 .21964 L
s
.14286 .18289 m
.14286 .19385 L
s
.16667 .18289 m
.16667 .20093 L
s
.19048 .18289 m
.19048 .20104 L
s
.21429 .18289 m
.21429 .22117 L
s
.2381 .18289 m
.2381 .22567 L
s
.2619 .18289 m
.2619 .23262 L
s
.28571 .18289 m
.28571 .215 L
s
.30952 .18289 m
.30952 .22823 L
s
.33333 .18289 m
.33333 .21499 L
s
.35714 .18289 m
.35714 .24832 L
s
.38095 .18289 m
.38095 .20735 L
s
.40476 .18289 m
.40476 .20543 L
s
.42857 .18289 m
.42857 .22994 L
s
.45238 .18289 m
.45238 .22708 L
s
.47619 .18289 m
.47619 .21964 L
s
.5 .18289 m
.5 .20881 L
s
.52381 .18289 m
.52381 .16439 L
s
.54762 .18289 m
.54762 .17539 L
s
.57143 .18289 m
.57143 .17821 L
s
.59524 .18289 m
.59524 .17767 L
s
.61905 .18289 m
.61905 .17143 L
s
.64286 .18289 m
.64286 .18911 L
s
.66667 .18289 m
.66667 .16744 L
s
.69048 .18289 m
.69048 .15775 L
s
.71429 .18289 m
.71429 .19187 L
s
.7381 .18289 m
.7381 .1718 L
s
.7619 .18289 m
.7619 .18406 L
s
.78571 .18289 m
.78571 .18143 L
s
.80952 .18289 m
.80952 .1735 L
s
.83333 .18289 m
.83333 .19507 L
s
.85714 .18289 m
.85714 .20109 L
s
.88095 .18289 m
.88095 .19415 L
s
.90476 .18289 m
.90476 .18964 L
s
.92857 .18289 m
.92857 .15438 L
s
.95238 .18289 m
.95238 .19446 L
s
.02381 .35106 m
.02381 .40621 L
s
.04762 .35106 m
.04762 .40911 L
s
.07143 .35106 m
.07143 .37968 L
s
.09524 .35106 m
.09524 .378 L
s
.11905 .35106 m
.11905 .41234 L
s
.14286 .35106 m
.14286 .40795 L
s
.16667 .35106 m
.16667 .41132 L
s
.19048 .35106 m
.19048 .40209 L
s
.21429 .35106 m
.21429 .40645 L
s
.2381 .35106 m
.2381 .40217 L
s
.2619 .35106 m
.2619 .33346 L
s
.28571 .35106 m
.28571 .36812 L
s
.30952 .35106 m
.30952 .36278 L
s
.33333 .35106 m
.33333 .35017 L
s
.35714 .35106 m
.35714 .35602 L
s
.38095 .35106 m
.38095 .36261 L
s
.40476 .35106 m
.40476 .35985 L
s
.42857 .35106 m
.42857 .38092 L
s
.45238 .35106 m
.45238 .33324 L
s
.47619 .35106 m
.47619 .35681 L
s
.5 .35106 m
.5 .34703 L
s
.52381 .35106 m
.52381 .34384 L
s
.54762 .35106 m
.54762 .34235 L
s
.57143 .35106 m
.57143 .33434 L
s
.59524 .35106 m
.59524 .3438 L
s
.61905 .35106 m
.61905 .34758 L
s
.64286 .35106 m
.64286 .34288 L
s
.66667 .35106 m
.66667 .37382 L
s
.69048 .35106 m
.69048 .35426 L
s
.71429 .35106 m
.71429 .35517 L
s
.7381 .35106 m
.7381 .38278 L
s
.7619 .35106 m
.7619 .34784 L
s
.78571 .35106 m
.78571 .35425 L
s
.80952 .35106 m
.80952 .36697 L
s
.83333 .35106 m
.83333 .32835 L
s
.85714 .35106 m
.85714 .34246 L
s
.88095 .35106 m
.88095 .35555 L
s
.90476 .35106 m
.90476 .35475 L
s
.92857 .35106 m
.92857 .35156 L
s
.95238 .35106 m
.95238 .31865 L
s
.02381 .51923 m
.02381 .59736 L
s
.04762 .51923 m
.04762 .56196 L
s
.07143 .51923 m
.07143 .60332 L
s
.09524 .51923 m
.09524 .59682 L
s
.11905 .51923 m
.11905 .59359 L
s
.14286 .51923 m
.14286 .5187 L
s
.16667 .51923 m
.16667 .51001 L
s
.19048 .51923 m
.19048 .53327 L
s
.21429 .51923 m
.21429 .52431 L
s
.2381 .51923 m
.2381 .52165 L
s
.2619 .51923 m
.2619 .52775 L
s
.28571 .51923 m
.28571 .52377 L
s
.30952 .51923 m
.30952 .5294 L
s
.33333 .51923 m
.33333 .54372 L
s
.35714 .51923 m
.35714 .50928 L
s
.38095 .51923 m
.38095 .49729 L
s
.40476 .51923 m
.40476 .52792 L
s
.42857 .51923 m
.42857 .51649 L
s
.45238 .51923 m
.45238 .50894 L
s
.47619 .51923 m
.47619 .49372 L
s
.5 .51923 m
.5 .51146 L
s
.52381 .51923 m
.52381 .49986 L
s
.54762 .51923 m
.54762 .50803 L
s
.57143 .51923 m
.57143 .53451 L
s
.59524 .51923 m
.59524 .52425 L
s
.61905 .51923 m
.61905 .51801 L
s
.64286 .51923 m
.64286 .52216 L
s
.66667 .51923 m
.66667 .51972 L
s
.69048 .51923 m
.69048 .50312 L
s
.71429 .51923 m
.71429 .51588 L
s
.7381 .51923 m
.7381 .53051 L
s
.7619 .51923 m
.7619 .5301 L
s
.78571 .51923 m
.78571 .5016 L
s
.80952 .51923 m
.80952 .52879 L
s
.83333 .51923 m
.83333 .49989 L
s
.85714 .51923 m
.85714 .55452 L
s
.88095 .51923 m
.88095 .51084 L
s
.90476 .51923 m
.90476 .50041 L
s
.92857 .51923 m
.92857 .52607 L
s
.95238 .51923 m
.95238 .53389 L
s
0 1 1 r
.02381 .01472 m
.97619 .01472 L
s
.02381 .18289 m
.97619 .18289 L
s
.02381 .35106 m
.97619 .35106 L
s
.02381 .51923 m
.97619 .51923 L
s
.4881 .26697 m
.4881 .0988 L
s
.25 .43515 m
.25 .26697 L
s
.4881 .43515 m
.4881 .26697 L
s
.72619 .43515 m
.72619 .26697 L
s
.13095 .60332 m
.13095 .43515 L
s
.25 .60332 m
.25 .43515 L
s
.36905 .60332 m
.36905 .43515 L
s
.4881 .60332 m
.4881 .43515 L
s
.60714 .60332 m
.60714 .43515 L
s
.72619 .60332 m
.72619 .43515 L
s
.84524 .60332 m
.84524 .43515 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
In the phase space plot, each rectangle represents a wavelet; and \
the darker a rectangle, the larger the absolute value of the corresponding \
wavelet coefficient. The residual trend is plotted in the bottom row; the \
finest detail, in the top row.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.15"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[wtdata, Frame -> True, FrameTicks -> None,
FrameLabel -> {\"time\", \"frequency\"}]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.294302 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -9 -27 ]
[-0.01875 .30902 0 27 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 1 Mshowa
0 0 m
0 .61803 L
s
[(frequency)] -0.01875 .30902 1 0 90 Mrotshowa
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01472 translate
.95238 .07357 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000
pop
P
% End of image
% Start of gray image
p
.02381 .08829 translate
.95238 .07358 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FBB087D4EB
pop
P
% End of image
% Start of gray image
p
.02381 .16187 translate
.95238 .14715 scale
10 string
10 1 8 [10 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
696D9BF8D59CB40067CE
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .2943 scale
20 string
20 1 8 [20 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2161BFD7D39DCA7B28B2A0F5F3AF97639FC60B9C
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "Note that since the residual trend usually has much larger coefficients \
than details, we normalize the coefficients excluding the trend part, that \
is, the largest detail coefficient has the darkest shade. \nSometimes, for \
data with many levels the rectangles at higher levels can be too tall and \
they render the lower\[Hyphen]level rectangles too short to discern. In this \
case, you may prefer to plot the above plot with cells of equal heights, that \
is, to use a \"logarithmic\" scale for the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis by setting the option ",
  StyleBox["LogarithmicScale", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["True", "MR"],
  ". "
}], "Text",
  CellTags->{"S3.3.0", "0.16"}],

Cell["\<\
The above plot is plotted with cells of equal height for viewing \
convenience.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.17"}],

Cell[CellGroupData[{

Cell["PhaseSpacePlot[wtdata, LogarithmicScale -> True]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.047619 0.0147151 0.147151 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01472 translate
.95238 .14715 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000
pop
P
% End of image
% Start of gray image
p
.02381 .16187 translate
.95238 .14715 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FBB087D4EB
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .14715 scale
10 string
10 1 8 [10 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
696D9BF8D59CB40067CE
pop
P
% End of image
% Start of gray image
p
.02381 .45617 translate
.95238 .14715 scale
20 string
20 1 8 [20 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
2161BFD7D39DCA7B28B2A0F5F3AF97639FC60B9C
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "Unlike the case of a wavelet transform, the result of a wavelet packet \
transform is not ordered in frequency, but rather, it is ordered according to \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", the index of the wavelet packet ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ". To get a correct phase space plot, we must reorder the output of ",
  StyleBox["WaveletPacketTransform", "MR"],
  " before using ",
  StyleBox["PhaseSpacePlot", "MR"],
  ". The ordering we use is the so\[Hyphen]called gray code order. It \
rearranges the output of ",
  StyleBox["WaveletPacketTransform", "MR"],
  " according to increasing frequency. "
}], "Text",
  CellTags->{"S3.3.0", "0.18"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"GrayCodeOrder[\\\\\\\"\\\
\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"order \\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \
\\\"TI\\\"]\\) according to gray code order \"\>"}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.19"}],

Cell["Gray code order.", "Caption",
  CellTags->"S3.3.0"],

Cell[TextData[{
  "This function should only be used to order the output of \
one\[Hyphen]dimensional ",
  StyleBox["WaveletPacketTransform", "MR"],
  ". "
}], "Text",
  CellTags->{"S3.3.0", "0.20"}],

Cell["\<\
This gives the wavelet packet coefficients in the best basis.\
\>", 
  "MathCaption",
  CellTags->{"S3.3.0", "0.21"}],

Cell["WaveletPacketTransform[data, d2];", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"S3.3.0"],

Cell["We order the coefficients before plotting the phase plot.", 
  "MathCaption",
  CellTags->{"S3.3.0", "0.22"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[GrayCodeOrder[%], Frame -> True,
FrameTicks -> None, FrameLabel -> {\"time\", \"frequency\"}]\
\>", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.147151 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -9 -27 ]
[-0.01875 .30902 0 27 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 1 Mshowa
0 0 m
0 .61803 L
s
[(frequency)] -0.01875 .30902 1 0 90 Mrotshowa
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01472 translate
.95238 .07357 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
0000000000
pop
P
% End of image
% Start of gray image
p
.02381 .08829 translate
.95238 .07358 scale
5 string
5 1 8 [5 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FBB791D7EC
pop
P
% End of image
% Start of gray image
p
.02381 .16187 translate
.95238 .14715 scale
10 string
10 1 8 [10 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
7579A3F8D8A4BA1473D2
pop
P
% End of image
% Start of gray image
p
.02381 .30902 translate
.95238 .14715 scale
10 string
10 1 8 [10 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
05E6E6824CBCDCE2FC00
pop
P
% End of image
% Start of gray image
p
.02381 .45617 translate
.95238 .14715 scale
10 string
10 1 8 [10 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E0C6BB7BC6E4BF4CE6DF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "We can also use ",
  StyleBox["PlotCoefficients", "MR"],
  " and ",
  StyleBox["PhaseSpacePlot", "MR"],
  " for the output of one\[Hyphen]dimensional trigonometric transforms. \
However, we should keep in mind that the roles of time and frequency are \
interchanged. "
}], "Text",
  CellTags->{"S3.3.0", "0.23"}],

Cell["\<\
This gives the sine transform of the data after the mean has been \
subtracted.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.24"}],

Cell["SinTransform[data-(Plus @@ data)/40, 8];", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"S3.3.0"],

Cell["\<\
In contrast to the case of the wavelet transform, here each sublist \
represents a particular time range and the coefficients in a sublist are \
arranged according to increasing frequency.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.25"}],

Cell[CellGroupData[{

Cell["\<\
PlotCoefficients[%, Frame -> True,
FrameLabel->{\"frequency\", \"\"}]\
\>", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0147151 0.0780547 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -27 -18 ]
[.5 -0.0125 27 -9 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(4)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(6)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(8)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
[(frequency)] .5 -0.0125 0 -9 Mabsadd 0 1 Mshowa
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12167 m
.02381 .13101 L
s
.14286 .12167 m
.14286 .11678 L
s
.2619 .12167 m
.2619 .08311 L
s
.38095 .12167 m
.38095 .11677 L
s
.5 .12167 m
.5 .13477 L
s
.61905 .12167 m
.61905 .16062 L
s
.7381 .12167 m
.7381 .16212 L
s
.85714 .12167 m
.85714 .12866 L
s
.02381 .22897 m
.02381 .17873 L
s
.14286 .22897 m
.14286 .21687 L
s
.2619 .22897 m
.2619 .22332 L
s
.38095 .22897 m
.38095 .25173 L
s
.5 .22897 m
.5 .25127 L
s
.61905 .22897 m
.61905 .23099 L
s
.7381 .22897 m
.7381 .21975 L
s
.85714 .22897 m
.85714 .21265 L
s
.02381 .33593 m
.02381 .36111 L
s
.14286 .33593 m
.14286 .35678 L
s
.2619 .33593 m
.2619 .34531 L
s
.38095 .33593 m
.38095 .34948 L
s
.5 .33593 m
.5 .30958 L
s
.61905 .33593 m
.61905 .31292 L
s
.7381 .33593 m
.7381 .31824 L
s
.85714 .33593 m
.85714 .30616 L
s
.02381 .44288 m
.02381 .45562 L
s
.14286 .44288 m
.14286 .45741 L
s
.2619 .44288 m
.2619 .40479 L
s
.38095 .44288 m
.38095 .48468 L
s
.5 .44288 m
.5 .45911 L
s
.61905 .44288 m
.61905 .45103 L
s
.7381 .44288 m
.7381 .43061 L
s
.85714 .44288 m
.85714 .44113 L
s
.02381 .54984 m
.02381 .55516 L
s
.14286 .54984 m
.14286 .54744 L
s
.2619 .54984 m
.2619 .54585 L
s
.38095 .54984 m
.38095 .53995 L
s
.5 .54984 m
.5 .5273 L
s
.61905 .54984 m
.61905 .56362 L
s
.7381 .54984 m
.7381 .60332 L
s
.85714 .54984 m
.85714 .56155 L
s
0 1 1 r
.02381 .12167 m
.97619 .12167 L
s
.02381 .22897 m
.97619 .22897 L
s
.02381 .33593 m
.97619 .33593 L
s
.02381 .44288 m
.97619 .44288 L
s
.02381 .54984 m
.97619 .54984 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
The sine packet transform picks out the best basis using the \
entropy criterion.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.26"}],

Cell[CellGroupData[{

Cell["\<\
sinp = SinPacketTransform[data-(Plus @@ data)/40,
8, Taper -> False]\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({{0.17404060248093347`, \(-0.0283110767980918076`\), 
        \(-0.508112218839651053`\), \(-0.0451743661341599445`\), 
        0.144956566699868698`, 0.351922789667174429`, 0.548174699290741784`, 
        0.0418600110889704968`}, {\(-0.579100444396211599`\), 
        \(-0.225419866836565185`\), 0.0989436091483427837`, 
        0.0603404002583970111`, 0.416505238761023655`, 
        \(-0.167790745841790922`\), \(-0.0559647525822802816`\), 
        \(-0.232390771759894132`\)}, {0.0831480589237804323`, 
        \(-0.601769337791532343`\)}, {0.273158635697263729`}, {
        0.0789758895345502587`}, {\(-0.0221458256096636052`\)}, {
        0.33555570457856696`}, {0.0545809937487754481`}, {
        \(-0.106463695684933901`\)}, {0.252056455207524665`, 
        \(-0.0163545873680916091`\)}, {\(-0.189535442771810345`\)}, {
        \(-0.05156796451322875`\)}, {0.0167317324630961028`, 
        0.749885824819669011`, \(-0.112955775344759401`\), 
        0.317913355155538424`}, {0.0745067649796747843`, 
        0.0707965625543993493`, \(-0.186386054181982512`\), 
        \(-0.0153272092118795377`\), \(-0.625512711270374222`\), 
        0.15595588347781164`, 0.433892263674971623`, 
        \(-0.0132036096634533128`\)}}\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "Note that frequency is plotted along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis, and time, along the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis."
}], "MathCaption",
  CellTags->{"S3.3.0", "0.27"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[%, Frame -> True, FrameTicks -> None,
FrameLabel -> {\"frequency\", \"time\"}, AspectRatio -> 1]\
\>", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.119048 0.0238095 0.190476 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -27 -9 ]
[.5 -0.0125 27 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -9 -12 ]
[-0.01875 .5 0 12 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(frequency)] .5 -0.0125 0 1 Mshowa
0 0 m
0 1 L
s
[(time)] -0.01875 .5 1 0 90 Mrotshowa
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .19048 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C4F652F0CE8744F1
pop
P
% End of image
% Start of gray image
p
.02381 .21429 translate
.95238 .19047 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3AB3DEEB71C6ECB0
pop
P
% End of image
% Start of gray image
p
.02381 .40476 translate
.95238 .04762 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E332
pop
P
% End of image
% Start of gray image
p
.02381 .45238 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A2
pop
P
% End of image
% Start of gray image
p
.02381 .47619 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E5
pop
P
% End of image
% Start of gray image
p
.02381 .5 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F8
pop
P
% End of image
% Start of gray image
p
.02381 .52381 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8D
pop
P
% End of image
% Start of gray image
p
.02381 .54762 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
pop
P
% End of image
% Start of gray image
p
.02381 .57143 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DB
pop
P
% End of image
% Start of gray image
p
.02381 .59524 translate
.95238 .04762 scale
2 string
2 1 8 [2 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A9FA
pop
P
% End of image
% Start of gray image
p
.02381 .64286 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BF
pop
P
% End of image
% Start of gray image
p
.02381 .66667 translate
.95238 .02381 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EE
pop
P
% End of image
% Start of gray image
p
.02381 .69048 translate
.95238 .09523 scale
4 string
4 1 8 [4 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FA00D993
pop
P
% End of image
% Start of gray image
p
.02381 .78571 translate
.95238 .19048 scale
8 string
8 1 8 [8 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E6E7C0FA2ACA6BFB
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "We can follow the usual convention of plotting time along the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " axis by setting the option ",
  StyleBox["ExchangeAxes", "MR"],
  " to ",
  StyleBox["True", "MR"],
  "."
}], "MathCaption",
  CellTags->{"S3.3.0", "0.28"}],

Cell[CellGroupData[{

Cell["\<\
PhaseSpacePlot[%%, ExchangeAxes -> True,
Frame -> True, FrameTicks -> None,
FrameLabel -> {\"time\", \"frequency\"}, AspectRatio -> 1]\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0238095 0.119048 [
[ 0 0 -0.125 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -9 -27 ]
[-0.01875 .5 0 27 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
[(time)] .5 -0.0125 0 1 Mshowa
0 0 m
0 1 L
s
[(frequency)] -0.01875 .5 1 0 90 Mrotshowa
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.19048 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
C4
F6
52
F0
CE
87
44
F1
pop
P
% End of image
% Start of gray image
p
.21429 .02381 translate
.19047 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
3A
B3
DE
EB
71
C6
EC
B0
pop
P
% End of image
% Start of gray image
p
.40476 .02381 translate
.04762 .95238 scale
1 string
1 2 8 [1 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E3
32
pop
P
% End of image
% Start of gray image
p
.45238 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A2
pop
P
% End of image
% Start of gray image
p
.47619 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E5
pop
P
% End of image
% Start of gray image
p
.5 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
F8
pop
P
% End of image
% Start of gray image
p
.52381 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
8D
pop
P
% End of image
% Start of gray image
p
.54762 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
ED
pop
P
% End of image
% Start of gray image
p
.57143 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
DB
pop
P
% End of image
% Start of gray image
p
.59524 .02381 translate
.04762 .95238 scale
1 string
1 2 8 [1 0 0 2 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
A9
FA
pop
P
% End of image
% Start of gray image
p
.64286 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
BF
pop
P
% End of image
% Start of gray image
p
.66667 .02381 translate
.02381 .95238 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
EE
pop
P
% End of image
% Start of gray image
p
.69048 .02381 translate
.09523 .95238 scale
1 string
1 4 8 [1 0 0 4 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FA
00
D9
93
pop
P
% End of image
% Start of gray image
p
.78571 .02381 translate
.19048 .95238 scale
1 string
1 8 8 [1 0 0 8 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
E6
E7
C0
FA
2A
CA
6B
FB
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ExchangeAxes\\\\\\\"\\\",\
 \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to exchange the axes "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"LogarithmicScale\\\\\\\"\
\\\", \\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to use logarithmic scale "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.29"}],

Cell[TextData[{
  "Options for ",
  StyleBox["PhaseSpacePlot", "MR"],
  "."
}], "Caption",
  CellTags->"S3.3.0"],

Cell[TextData[{
  "To see how the original space is divided into subspaces, we can use the \
function ",
  StyleBox["ShowBasisPosition", "MR"],
  ". Again the function accepts the usual graphics options. "
}], "Text",
  CellTags->{"S3.3.0", "0.30"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ShowBasisPosition[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("show the position of basis functions "\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.31"}],

Cell["Function showing the basis position.", "Caption",
  CellTags->"S3.3.0"],

Cell["\<\
The top row represents the original space and each subsequent row \
shows further splitting of the space. The shaded areas are the subspaces \
whose basis functions form the basis of this particular sine packet \
transform.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.32"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition[sinp]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.0147151 0.117721 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 .4 r
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.97619 .01472 L
s
.02381 .13244 m
.97619 .13244 L
s
.02381 .25016 m
.97619 .25016 L
s
.02381 .36788 m
.97619 .36788 L
s
.02381 .4856 m
.97619 .4856 L
s
.02381 .60332 m
.97619 .60332 L
s
.02381 .01472 m
.02381 .60332 L
s
.04762 .01472 m
.04762 .13244 L
s
.07143 .01472 m
.07143 .25016 L
s
.09524 .01472 m
.09524 .13244 L
s
.11905 .01472 m
.11905 .36788 L
s
.14286 .01472 m
.14286 .13244 L
s
.16667 .01472 m
.16667 .25016 L
s
.19048 .01472 m
.19048 .13244 L
s
.21429 .01472 m
.21429 .4856 L
s
.2381 .01472 m
.2381 .13244 L
s
.2619 .01472 m
.2619 .25016 L
s
.28571 .01472 m
.28571 .13244 L
s
.30952 .01472 m
.30952 .36788 L
s
.33333 .01472 m
.33333 .13244 L
s
.35714 .01472 m
.35714 .25016 L
s
.38095 .01472 m
.38095 .13244 L
s
.40476 .01472 m
.40476 .4856 L
s
.42857 .01472 m
.42857 .13244 L
s
.45238 .01472 m
.45238 .25016 L
s
.47619 .01472 m
.47619 .13244 L
s
.5 .01472 m
.5 .36788 L
s
.52381 .01472 m
.52381 .13244 L
s
.54762 .01472 m
.54762 .25016 L
s
.57143 .01472 m
.57143 .13244 L
s
.59524 .01472 m
.59524 .4856 L
s
.61905 .01472 m
.61905 .13244 L
s
.64286 .01472 m
.64286 .25016 L
s
.66667 .01472 m
.66667 .13244 L
s
.69048 .01472 m
.69048 .36788 L
s
.71429 .01472 m
.71429 .13244 L
s
.7381 .01472 m
.7381 .25016 L
s
.7619 .01472 m
.7619 .13244 L
s
.78571 .01472 m
.78571 .4856 L
s
.80952 .01472 m
.80952 .13244 L
s
.83333 .01472 m
.83333 .25016 L
s
.85714 .01472 m
.85714 .13244 L
s
.88095 .01472 m
.88095 .36788 L
s
.90476 .01472 m
.90476 .13244 L
s
.92857 .01472 m
.92857 .25016 L
s
.95238 .01472 m
.95238 .13244 L
s
.97619 .01472 m
.97619 .60332 L
s
% Start of gray image
p
.02381 .36788 translate
.19048 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.21429 .36788 translate
.19047 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.40476 .13244 translate
.04762 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.45238 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.47619 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.5 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.52381 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.54762 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.57143 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.59524 .13244 translate
.04762 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.64286 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.66667 .01472 translate
.02381 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.69048 .25016 translate
.09523 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% Start of gray image
p
.78571 .36788 translate
.19048 .11772 scale
1 string
1 1 8 [1 0 0 1 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
19
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
For two\[Hyphen]dimensional transforms, we view the coefficients by \
plotting their density plot. That is, a matrix of numbers shades a grid of \
corresponding dimensions with the darkest shade representing the smallest \
number and the lightest representing the largest. \
\>", "Text",
  CellTags->{"S3.3.0", "0.33"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"PlotCoefficients2D[\\\\\\\
\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\
\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  \("give density plot of two\[Hyphen]dimensional wavelet, \
sine, or cosine coefficients "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"ShowBasisPosition2D[\\\\\
\\\"\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", \("show subspaces that give the basis functions "\)}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.34"}],

Cell["Showing two\[Hyphen]dimensional coefficients and basis position.", 
  "Caption",
  CellTags->"S3.3.0"],

Cell[TextData[{
  "A function ",
  Cell[BoxData[
      \(TraditionalForm\`f \((x, y)\)\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " is defined and two\[Hyphen]dimensional data of size ",
  Cell[BoxData[
      \(TraditionalForm\`{64, 64}\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " are generated according to the defined function."
}], "MathCaption",
  CellTags->{"S3.3.0", "0.35"}],

Cell["\<\
(f[x_, y_]:= 1 /; (2 <= Abs[x] < 3 && Abs[y] < 3)||(
 2 <= Abs[y] < 3 && Abs[x] < 3);
 f[x_, y_]:= 0;
 data = Table[f[x, y], {x, -4, 4-1/8, 1/8},
 {y, -4, 4-1/8, 1/8}];)\
\>", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"S3.3.0"],

Cell["This gives the density plot of the data.", "MathCaption",
  CellTags->{"S3.3.0", "0.36"}],

Cell[CellGroupData[{

Cell["ListDensityPlot[data, Mesh -> False]", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.015024 0.0192308 0.015024 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.16947 -0.0125 -6 -9 ]
[.16947 -0.0125 6 0 ]
[.31971 -0.0125 -6 -9 ]
[.31971 -0.0125 6 0 ]
[.46995 -0.0125 -6 -9 ]
[.46995 -0.0125 6 0 ]
[.62019 -0.0125 -6 -9 ]
[.62019 -0.0125 6 0 ]
[.77043 -0.0125 -6 -9 ]
[.77043 -0.0125 6 0 ]
[.92067 -0.0125 -6 -9 ]
[.92067 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .16947 -12 -4.5 ]
[-0.0125 .16947 0 4.5 ]
[-0.0125 .31971 -12 -4.5 ]
[-0.0125 .31971 0 4.5 ]
[-0.0125 .46995 -12 -4.5 ]
[-0.0125 .46995 0 4.5 ]
[-0.0125 .62019 -12 -4.5 ]
[-0.0125 .62019 0 4.5 ]
[-0.0125 .77043 -12 -4.5 ]
[-0.0125 .77043 0 4.5 ]
[-0.0125 .92067 -12 -4.5 ]
[-0.0125 .92067 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.16947 0 m
.16947 .00625 L
s
[(10)] .16947 -0.0125 0 1 Mshowa
.31971 0 m
.31971 .00625 L
s
[(20)] .31971 -0.0125 0 1 Mshowa
.46995 0 m
.46995 .00625 L
s
[(30)] .46995 -0.0125 0 1 Mshowa
.62019 0 m
.62019 .00625 L
s
[(40)] .62019 -0.0125 0 1 Mshowa
.77043 0 m
.77043 .00625 L
s
[(50)] .77043 -0.0125 0 1 Mshowa
.92067 0 m
.92067 .00625 L
s
[(60)] .92067 -0.0125 0 1 Mshowa
.125 Mabswid
.04928 0 m
.04928 .00375 L
s
.07933 0 m
.07933 .00375 L
s
.10937 0 m
.10937 .00375 L
s
.13942 0 m
.13942 .00375 L
s
.19952 0 m
.19952 .00375 L
s
.22957 0 m
.22957 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.28966 0 m
.28966 .00375 L
s
.34976 0 m
.34976 .00375 L
s
.37981 0 m
.37981 .00375 L
s
.40986 0 m
.40986 .00375 L
s
.4399 0 m
.4399 .00375 L
s
.5 0 m
.5 .00375 L
s
.53005 0 m
.53005 .00375 L
s
.5601 0 m
.5601 .00375 L
s
.59014 0 m
.59014 .00375 L
s
.65024 0 m
.65024 .00375 L
s
.68029 0 m
.68029 .00375 L
s
.71034 0 m
.71034 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.80048 0 m
.80048 .00375 L
s
.83053 0 m
.83053 .00375 L
s
.86058 0 m
.86058 .00375 L
s
.89063 0 m
.89063 .00375 L
s
.95072 0 m
.95072 .00375 L
s
.98077 0 m
.98077 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .16947 m
.00625 .16947 L
s
[(10)] -0.0125 .16947 1 0 Mshowa
0 .31971 m
.00625 .31971 L
s
[(20)] -0.0125 .31971 1 0 Mshowa
0 .46995 m
.00625 .46995 L
s
[(30)] -0.0125 .46995 1 0 Mshowa
0 .62019 m
.00625 .62019 L
s
[(40)] -0.0125 .62019 1 0 Mshowa
0 .77043 m
.00625 .77043 L
s
[(50)] -0.0125 .77043 1 0 Mshowa
0 .92067 m
.00625 .92067 L
s
[(60)] -0.0125 .92067 1 0 Mshowa
.125 Mabswid
0 .04928 m
.00375 .04928 L
s
0 .07933 m
.00375 .07933 L
s
0 .10937 m
.00375 .10937 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .22957 m
.00375 .22957 L
s
0 .25962 m
.00375 .25962 L
s
0 .28966 m
.00375 .28966 L
s
0 .34976 m
.00375 .34976 L
s
0 .37981 m
.00375 .37981 L
s
0 .40986 m
.00375 .40986 L
s
0 .4399 m
.00375 .4399 L
s
0 .5 m
.00375 .5 L
s
0 .53005 m
.00375 .53005 L
s
0 .5601 m
.00375 .5601 L
s
0 .59014 m
.00375 .59014 L
s
0 .65024 m
.00375 .65024 L
s
0 .68029 m
.00375 .68029 L
s
0 .71034 m
.00375 .71034 L
s
0 .74038 m
.00375 .74038 L
s
0 .80048 m
.00375 .80048 L
s
0 .83053 m
.00375 .83053 L
s
0 .86058 m
.00375 .86058 L
s
0 .89063 m
.00375 .89063 L
s
0 .95072 m
.00375 .95072 L
s
0 .98077 m
.00375 .98077 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.16947 .99375 m
.16947 1 L
s
.31971 .99375 m
.31971 1 L
s
.46995 .99375 m
.46995 1 L
s
.62019 .99375 m
.62019 1 L
s
.77043 .99375 m
.77043 1 L
s
.92067 .99375 m
.92067 1 L
s
.125 Mabswid
.04928 .99625 m
.04928 1 L
s
.07933 .99625 m
.07933 1 L
s
.10937 .99625 m
.10937 1 L
s
.13942 .99625 m
.13942 1 L
s
.19952 .99625 m
.19952 1 L
s
.22957 .99625 m
.22957 1 L
s
.25962 .99625 m
.25962 1 L
s
.28966 .99625 m
.28966 1 L
s
.34976 .99625 m
.34976 1 L
s
.37981 .99625 m
.37981 1 L
s
.40986 .99625 m
.40986 1 L
s
.4399 .99625 m
.4399 1 L
s
.5 .99625 m
.5 1 L
s
.53005 .99625 m
.53005 1 L
s
.5601 .99625 m
.5601 1 L
s
.59014 .99625 m
.59014 1 L
s
.65024 .99625 m
.65024 1 L
s
.68029 .99625 m
.68029 1 L
s
.71034 .99625 m
.71034 1 L
s
.74038 .99625 m
.74038 1 L
s
.80048 .99625 m
.80048 1 L
s
.83053 .99625 m
.83053 1 L
s
.86058 .99625 m
.86058 1 L
s
.89063 .99625 m
.89063 1 L
s
.95072 .99625 m
.95072 1 L
s
.98077 .99625 m
.98077 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .16947 m
1 .16947 L
s
.99375 .31971 m
1 .31971 L
s
.99375 .46995 m
1 .46995 L
s
.99375 .62019 m
1 .62019 L
s
.99375 .77043 m
1 .77043 L
s
.99375 .92067 m
1 .92067 L
s
.125 Mabswid
.99625 .04928 m
1 .04928 L
s
.99625 .07933 m
1 .07933 L
s
.99625 .10937 m
1 .10937 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .22957 m
1 .22957 L
s
.99625 .25962 m
1 .25962 L
s
.99625 .28966 m
1 .28966 L
s
.99625 .34976 m
1 .34976 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .40986 m
1 .40986 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5 m
1 .5 L
s
.99625 .53005 m
1 .53005 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .59014 m
1 .59014 L
s
.99625 .65024 m
1 .65024 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .71034 m
1 .71034 L
s
.99625 .74038 m
1 .74038 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .83053 m
1 .83053 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .89063 m
1 .89063 L
s
.99625 .95072 m
1 .95072 L
s
.99625 .98077 m
1 .98077 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFF00000000000000
000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000
00000000000000000000000000000000
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
We transform the data using the Daubechies filter of order 2.\
\>", 
  "MathCaption",
  CellTags->{"S3.3.0", "0.37"}],

Cell["\<\
(d2 = DaubechiesFilter[2];
WaveletTransform[data, d2, 3];)\
\>", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"S3.3.0"],

Cell["\<\
This gives the density plot of the wavelet transformed data. Note \
that the residual trend is normalized separately so as to make it more \
discernible.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.38"}],

Cell[CellGroupData[{

Cell["PlotCoefficients2D[%]", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -6 -9 ]
[.17262 -0.0125 6 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .17262 -12 -4.5 ]
[-0.0125 .17262 0 4.5 ]
[-0.0125 .32143 -12 -4.5 ]
[-0.0125 .32143 0 4.5 ]
[-0.0125 .47024 -12 -4.5 ]
[-0.0125 .47024 0 4.5 ]
[-0.0125 .61905 -12 -4.5 ]
[-0.0125 .61905 0 4.5 ]
[-0.0125 .76786 -12 -4.5 ]
[-0.0125 .76786 0 4.5 ]
[-0.0125 .91667 -12 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(10)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(20)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(30)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(40)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(50)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(60)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .17262 m
.00625 .17262 L
s
[(10)] -0.0125 .17262 1 0 Mshowa
0 .32143 m
.00625 .32143 L
s
[(20)] -0.0125 .32143 1 0 Mshowa
0 .47024 m
.00625 .47024 L
s
[(30)] -0.0125 .47024 1 0 Mshowa
0 .61905 m
.00625 .61905 L
s
[(40)] -0.0125 .61905 1 0 Mshowa
0 .76786 m
.00625 .76786 L
s
[(50)] -0.0125 .76786 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(60)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .05357 m
.00375 .05357 L
s
0 .08333 m
.00375 .08333 L
s
0 .1131 m
.00375 .1131 L
s
0 .14286 m
.00375 .14286 L
s
0 .20238 m
.00375 .20238 L
s
0 .23214 m
.00375 .23214 L
s
0 .2619 m
.00375 .2619 L
s
0 .29167 m
.00375 .29167 L
s
0 .35119 m
.00375 .35119 L
s
0 .38095 m
.00375 .38095 L
s
0 .41071 m
.00375 .41071 L
s
0 .44048 m
.00375 .44048 L
s
0 .5 m
.00375 .5 L
s
0 .52976 m
.00375 .52976 L
s
0 .55952 m
.00375 .55952 L
s
0 .58929 m
.00375 .58929 L
s
0 .64881 m
.00375 .64881 L
s
0 .67857 m
.00375 .67857 L
s
0 .70833 m
.00375 .70833 L
s
0 .7381 m
.00375 .7381 L
s
0 .79762 m
.00375 .79762 L
s
0 .82738 m
.00375 .82738 L
s
0 .85714 m
.00375 .85714 L
s
0 .8869 m
.00375 .8869 L
s
0 .94643 m
.00375 .94643 L
s
0 .97619 m
.00375 .97619 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.17262 .99375 m
.17262 1 L
s
.32143 .99375 m
.32143 1 L
s
.47024 .99375 m
.47024 1 L
s
.61905 .99375 m
.61905 1 L
s
.76786 .99375 m
.76786 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.05357 .99625 m
.05357 1 L
s
.08333 .99625 m
.08333 1 L
s
.1131 .99625 m
.1131 1 L
s
.14286 .99625 m
.14286 1 L
s
.20238 .99625 m
.20238 1 L
s
.23214 .99625 m
.23214 1 L
s
.2619 .99625 m
.2619 1 L
s
.29167 .99625 m
.29167 1 L
s
.35119 .99625 m
.35119 1 L
s
.38095 .99625 m
.38095 1 L
s
.41071 .99625 m
.41071 1 L
s
.44048 .99625 m
.44048 1 L
s
.5 .99625 m
.5 1 L
s
.52976 .99625 m
.52976 1 L
s
.55952 .99625 m
.55952 1 L
s
.58929 .99625 m
.58929 1 L
s
.64881 .99625 m
.64881 1 L
s
.67857 .99625 m
.67857 1 L
s
.70833 .99625 m
.70833 1 L
s
.7381 .99625 m
.7381 1 L
s
.79762 .99625 m
.79762 1 L
s
.82738 .99625 m
.82738 1 L
s
.85714 .99625 m
.85714 1 L
s
.8869 .99625 m
.8869 1 L
s
.94643 .99625 m
.94643 1 L
s
.97619 .99625 m
.97619 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .17262 m
1 .17262 L
s
.99375 .32143 m
1 .32143 L
s
.99375 .47024 m
1 .47024 L
s
.99375 .61905 m
1 .61905 L
s
.99375 .76786 m
1 .76786 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .05357 m
1 .05357 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .1131 m
1 .1131 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .20238 m
1 .20238 L
s
.99625 .23214 m
1 .23214 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .29167 m
1 .29167 L
s
.99625 .35119 m
1 .35119 L
s
.99625 .38095 m
1 .38095 L
s
.99625 .41071 m
1 .41071 L
s
.99625 .44048 m
1 .44048 L
s
.99625 .5 m
1 .5 L
s
.99625 .52976 m
1 .52976 L
s
.99625 .55952 m
1 .55952 L
s
.99625 .58929 m
1 .58929 L
s
.99625 .64881 m
1 .64881 L
s
.99625 .67857 m
1 .67857 L
s
.99625 .70833 m
1 .70833 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .79762 m
1 .79762 L
s
.99625 .82738 m
1 .82738 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .8869 m
1 .8869 L
s
.99625 .94643 m
1 .94643 L
s
.99625 .97619 m
1 .97619 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
050C0B0B0B0B0B05767F7F7F7F7F7E767575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
0CF9FCFCFCFFE30678CFCAC9C9CCC77676757C7D7D7D7D7D
7D7D7D7D7D7C757575757575757575757575757575757575
75757575757575757575757575757575
0BFC1A100D33EC077578211E1D2A7A767675838585858585
858585858583757575757575757575757575757575757575
75757575757575757575757575757575
0BFC1005022AEC07757570707071757576757C7E76757575
757575767D7C757575757575757575757575757575757575
75757575757575757575757575757575
0BFC0D020027EC0775757575757575757575757668666666
666666687575757575757579594B4B4B4B4B4B4B4B4B4B4B
4B4B4B4B4B4B4B4B4B4B4B4E75757575
0BFF332A274AEE077575626161647575757575766F6E6E6E
6E6E6E6F75757575757575747D8181818181818181818181
81818181818181818181818075757575
0BE3ECECECEECE06778CFAFEFFF087767575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
050607070707060572050101010010757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
767875757575777276777675757576737575757575757575
7575757575757575757575757575757292A0A0A0A0A0A0A0
A0A0A0A0A0A0A09D7575757575757575
7FCF787575758C057787757575757B607575757575757575
757575757575757575757575757575776E6A6A6A6A6A6A6A
6A6A6A6A6A6A6A6B7575757575757575
7FCA21707562FA017675647575728C747575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
7FC91E707561FE0175757575757577757575757670707070
707070707575757575757575757575757575757575757575
75757575757575757575757575757575
7FC91D707561FF01757575757575757575757673AAB1B1B1
B1B1B2AB7575757575757575757575757575757575757575
75757575757575757575757575757575
7FCC2A717564F0007575727575757A7576757B7B7B7B7B7B
7B7B7B7B7B7B757575757575757575757575757575757575
75757575757575757575757575757575
7EC77A7575758710767B8C77757A5B717578413A3A3A3A3A
3A3A3A3A3940757575757575757575757575757575757575
75757575757575757575757575757575
767676757575767573607475757571917575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757676767575757575757575757675757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757578757576767675757575
757575757576747575757575757575757575757575757575
75757575757575757575757575757575
757C837C7575757575757575767B41757576767675757575
757575757576727575757575757575757575757575757575
75757575757575757575757575757575
757D857E7676757575757576737B3A757576767575757575
757575757776747575757575757575757575757575757575
75757575757575757575757575757575
757D8576686F757575757570AA7B3A757575757575757575
757575757975757575757575757575757575757575757575
75757575757575757575757575757575
757D8575666E757575757570B17B3A757575757575757575
757575757775757575757575757575757575757575757575
75757575757575757575757575757575
757D8575666E757575757570B17B3A757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757D8575666E757575757570B17B3A757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757D8575666E757575757570B17B3A757575757575757575
757575757575757575757575757575738A95959595959595
95959595959595937575757575757575
757D8575666E757575757570B17B3A757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757D8575666E757575757570B27B3A757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757D8576686F757575757570AB7B3A757575757575757575
757575757775757575757575757575757575757575757575
75757575757575757575757575757575
757D857D7575757575757575757B39757575757779777575
757575776775757575757578615656565656565656565656
56565656565656565656565875757575
757C837C7575757575757575757B40757576767675757575
757575757576747575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757574727475757575
757575757574847575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757974757575757575757575757575757575757575
757575757875757575757575757575757575757575757575
75757575757575757575757575757575
75757575597D757575757575757575757575757575757575
757575756175757575757575847275757575757575757575
75757575757575757575757580757575
757575754B81757575757575757575757575757575757575
757575755675757575757575727775757575757575757575
75757575757575757575757573757575
757575754B81757575757575757575757575757575757575
757575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B81757572777575757575757575757575757575
737575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575926E7575757575757575757575757575
8A7575755675757575757575757575756779757575757575
75757575757575756B75757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757974757575757575
75757575757575757875757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B817575A06A7575757575757575757575757575
957575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B8175759D6B7575757575757575757575757575
937575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B81757575757575757575757575757575757575
757575755675757575757575757575756B78757575757575
75757575757575756E75757575757575
757575754B81757575757575757575757575757575757575
757575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754B81757575757575757575757575757575757575
757575755675757575757575757575757575757575757575
75757575757575757575757575757575
757575754E80757575757575757575757575757575757575
757575755875757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575807375757575757575757575
7575757575757575757575757D757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
757575757575757575757575757575757575757575757575
757575757575757575757575757575757575757575757575
75757575757575757575757575757575
pop
P
% End of image
.5 Mabswid
.14286 .02381 m
.14286 .2619 L
s
.2619 .02381 m
.2619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.02381 .14286 m
.2619 .14286 L
s
.02381 .2619 m
.5 .2619 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .02381 m
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
This shows the division of space without showing the density \
plot.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.39"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition2D[%%, AspectRatio -> 1]", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.14286 .02381 m
.14286 .2619 L
s
.2619 .02381 m
.2619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.02381 .14286 m
.2619 .14286 L
s
.02381 .2619 m
.5 .2619 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .02381 m
.02381 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["This computes the wavelet packet transform.", "MathCaption",
  CellTags->{"S3.3.0", "0.40"}],

Cell["\<\
WaveletPacketTransform[data, d2, 3,
BoundaryCondition -> Zero];\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"S3.3.0"],

Cell["\<\
We see that the best basis is formed from the bases of these \
subspaces.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.41"}],

Cell[CellGroupData[{

Cell["ShowBasisPosition2D[%, AspectRatio -> 1]", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5 .2619 m
.02381 .2619 L
s
.2619 .5 m
.2619 .02381 L
s
.97619 .2619 m
.5 .2619 L
s
.7381 .5 m
.7381 .02381 L
s
.5 .7381 m
.02381 .7381 L
s
.2619 .97619 m
.2619 .5 L
s
.2619 .14286 m
.02381 .14286 L
s
.14286 .2619 m
.14286 .02381 L
s
.5 .14286 m
.2619 .14286 L
s
.38095 .2619 m
.38095 .02381 L
s
.2619 .38095 m
.02381 .38095 L
s
.14286 .5 m
.14286 .2619 L
s
.7381 .14286 m
.5 .14286 L
s
.61905 .2619 m
.61905 .02381 L
s
.97619 .14286 m
.7381 .14286 L
s
.85714 .2619 m
.85714 .02381 L
s
.2619 .61905 m
.02381 .61905 L
s
.14286 .7381 m
.14286 .5 L
s
.2619 .85714 m
.02381 .85714 L
s
.14286 .97619 m
.14286 .7381 L
s
.02381 .02381 m
.02381 .97619 L
s
.5 .02381 m
.5 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
This shows the density plot of the coefficients. Note that for \
wavelet packet transforms, the residual trend is not normalized separately.\
\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.42"}],

Cell[CellGroupData[{

Cell["PlotCoefficients2D[%%]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"S3.3.0"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.014881 0.0238095 0.014881 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17262 -0.0125 -6 -9 ]
[.17262 -0.0125 6 0 ]
[.32143 -0.0125 -6 -9 ]
[.32143 -0.0125 6 0 ]
[.47024 -0.0125 -6 -9 ]
[.47024 -0.0125 6 0 ]
[.61905 -0.0125 -6 -9 ]
[.61905 -0.0125 6 0 ]
[.76786 -0.0125 -6 -9 ]
[.76786 -0.0125 6 0 ]
[.91667 -0.0125 -6 -9 ]
[.91667 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .17262 -12 -4.5 ]
[-0.0125 .17262 0 4.5 ]
[-0.0125 .32143 -12 -4.5 ]
[-0.0125 .32143 0 4.5 ]
[-0.0125 .47024 -12 -4.5 ]
[-0.0125 .47024 0 4.5 ]
[-0.0125 .61905 -12 -4.5 ]
[-0.0125 .61905 0 4.5 ]
[-0.0125 .76786 -12 -4.5 ]
[-0.0125 .76786 0 4.5 ]
[-0.0125 .91667 -12 -4.5 ]
[-0.0125 .91667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17262 0 m
.17262 .00625 L
s
[(10)] .17262 -0.0125 0 1 Mshowa
.32143 0 m
.32143 .00625 L
s
[(20)] .32143 -0.0125 0 1 Mshowa
.47024 0 m
.47024 .00625 L
s
[(30)] .47024 -0.0125 0 1 Mshowa
.61905 0 m
.61905 .00625 L
s
[(40)] .61905 -0.0125 0 1 Mshowa
.76786 0 m
.76786 .00625 L
s
[(50)] .76786 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(60)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .17262 m
.00625 .17262 L
s
[(10)] -0.0125 .17262 1 0 Mshowa
0 .32143 m
.00625 .32143 L
s
[(20)] -0.0125 .32143 1 0 Mshowa
0 .47024 m
.00625 .47024 L
s
[(30)] -0.0125 .47024 1 0 Mshowa
0 .61905 m
.00625 .61905 L
s
[(40)] -0.0125 .61905 1 0 Mshowa
0 .76786 m
.00625 .76786 L
s
[(50)] -0.0125 .76786 1 0 Mshowa
0 .91667 m
.00625 .91667 L
s
[(60)] -0.0125 .91667 1 0 Mshowa
.125 Mabswid
0 .05357 m
.00375 .05357 L
s
0 .08333 m
.00375 .08333 L
s
0 .1131 m
.00375 .1131 L
s
0 .14286 m
.00375 .14286 L
s
0 .20238 m
.00375 .20238 L
s
0 .23214 m
.00375 .23214 L
s
0 .2619 m
.00375 .2619 L
s
0 .29167 m
.00375 .29167 L
s
0 .35119 m
.00375 .35119 L
s
0 .38095 m
.00375 .38095 L
s
0 .41071 m
.00375 .41071 L
s
0 .44048 m
.00375 .44048 L
s
0 .5 m
.00375 .5 L
s
0 .52976 m
.00375 .52976 L
s
0 .55952 m
.00375 .55952 L
s
0 .58929 m
.00375 .58929 L
s
0 .64881 m
.00375 .64881 L
s
0 .67857 m
.00375 .67857 L
s
0 .70833 m
.00375 .70833 L
s
0 .7381 m
.00375 .7381 L
s
0 .79762 m
.00375 .79762 L
s
0 .82738 m
.00375 .82738 L
s
0 .85714 m
.00375 .85714 L
s
0 .8869 m
.00375 .8869 L
s
0 .94643 m
.00375 .94643 L
s
0 .97619 m
.00375 .97619 L
s
.25 Mabswid
0 0 m
0 1 L
s
.02381 .99375 m
.02381 1 L
s
.17262 .99375 m
.17262 1 L
s
.32143 .99375 m
.32143 1 L
s
.47024 .99375 m
.47024 1 L
s
.61905 .99375 m
.61905 1 L
s
.76786 .99375 m
.76786 1 L
s
.91667 .99375 m
.91667 1 L
s
.125 Mabswid
.05357 .99625 m
.05357 1 L
s
.08333 .99625 m
.08333 1 L
s
.1131 .99625 m
.1131 1 L
s
.14286 .99625 m
.14286 1 L
s
.20238 .99625 m
.20238 1 L
s
.23214 .99625 m
.23214 1 L
s
.2619 .99625 m
.2619 1 L
s
.29167 .99625 m
.29167 1 L
s
.35119 .99625 m
.35119 1 L
s
.38095 .99625 m
.38095 1 L
s
.41071 .99625 m
.41071 1 L
s
.44048 .99625 m
.44048 1 L
s
.5 .99625 m
.5 1 L
s
.52976 .99625 m
.52976 1 L
s
.55952 .99625 m
.55952 1 L
s
.58929 .99625 m
.58929 1 L
s
.64881 .99625 m
.64881 1 L
s
.67857 .99625 m
.67857 1 L
s
.70833 .99625 m
.70833 1 L
s
.7381 .99625 m
.7381 1 L
s
.79762 .99625 m
.79762 1 L
s
.82738 .99625 m
.82738 1 L
s
.85714 .99625 m
.85714 1 L
s
.8869 .99625 m
.8869 1 L
s
.94643 .99625 m
.94643 1 L
s
.97619 .99625 m
.97619 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .02381 m
1 .02381 L
s
.99375 .17262 m
1 .17262 L
s
.99375 .32143 m
1 .32143 L
s
.99375 .47024 m
1 .47024 L
s
.99375 .61905 m
1 .61905 L
s
.99375 .76786 m
1 .76786 L
s
.99375 .91667 m
1 .91667 L
s
.125 Mabswid
.99625 .05357 m
1 .05357 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .1131 m
1 .1131 L
s
.99625 .14286 m
1 .14286 L
s
.99625 .20238 m
1 .20238 L
s
.99625 .23214 m
1 .23214 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .29167 m
1 .29167 L
s
.99625 .35119 m
1 .35119 L
s
.99625 .38095 m
1 .38095 L
s
.99625 .41071 m
1 .41071 L
s
.99625 .44048 m
1 .44048 L
s
.99625 .5 m
1 .5 L
s
.99625 .52976 m
1 .52976 L
s
.99625 .55952 m
1 .55952 L
s
.99625 .58929 m
1 .58929 L
s
.99625 .64881 m
1 .64881 L
s
.99625 .67857 m
1 .67857 L
s
.99625 .70833 m
1 .70833 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .79762 m
1 .79762 L
s
.99625 .82738 m
1 .82738 L
s
.99625 .85714 m
1 .85714 L
s
.99625 .8869 m
1 .8869 L
s
.99625 .94643 m
1 .94643 L
s
.99625 .97619 m
1 .97619 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
64 string
64 64 8 [64 0 0 64 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFF81FFFFFFFFFFFFFF81FFFFFFFFFFFFFF81
00000000000000810000000000000081FFFFFFFFFFFFFF81
00000000000000818181818181818181
FFFFFFFFFFFFFF81FFFFFFFFFFFFFF81FFFFFFFFFFFFFF81
FFFFFFFFFFFFFF810000FFFFFFFF00810000000000000081
00000000000000810000000000000081
FFFFFFFFFFFFFF8100FF00000000FF810000000000009481
0000000000000081FFFFFFFFFFFF6F81FFFFFFFFFFFFFF81
FFFFFFFFFFFF8181FFFFFFFFFFFFFF81
FFFFFF8100FFFF81000000000000A0818116828182779481
FFFFFFFFFFFF81819476848181776F810000000000008181
81818181818181810000000000008181
FFFFFF0000FFFF8182FF83818284A081FFFFFFFFFFFF9481
81818181818181810000000000006F818181818181818181
81818181818181818181818181818181
FFFFFFFFFFFFFF81000000000000A081FF00FFFFFFFF0081
FFFFFFFFFFFF8181FFFFFFFFFFFFFF810000000000008181
FFFFFFFFFFFF81818181818181818181
FFFFFFFFFFFFFF81FFFFFFFFFFFFFF810000FFFFFFFF0081
FF00FFFFFFFF00810000000000000081FFFFFFFFFFFFFF81
0000FFFFFFFF0081FFFFFFFFFFFF8181
818181818181818100000000000000810000000000000081
000000000000008100000000000000810000000000000081
00000000000000810000000000000081
FFFF00008E00FF00FFFFFF7E7E7EFF00FFFFFFFF82FFFF00
00000082828200FF00000000820000FFFFFFFF818181FF00
00000080808000FF8181818181818181
FFFFFF00EE00FF00FFFF00009C00FF00FFFF00008500FF00
FFFFFFFF88FF00000000FFFF80FF00FF000000008200FFFF
0000FFFF76FF00FF0000007C7C7C00FF
FFFF00007700FF00FF0000005200FF00850000008100FF7C
000000007E00FFFF77FFFFFF81FF0086FFFFFFFF81FF0000
81FFFFFF6CFF0081FFFFFFFF5FFF0000
FFFF00008100FF00820000008400FF8F8597A08181846A7C
81FFFFFF81FF008177858A8081815B86810000008100FF81
8181818181818181810000008700FF81
FFFF00008100FF0082838D81817D558F85FFFFFF81FF007C
8181818181818181770000008000FF868181818181818181
81818181818181818181818181818181
FFFF00008B00FF00820000008100FF8F00FFFFFF88FF00FF
81FFFFFF81FF0081FFFFFFFF88FF0000810000007E00FF81
81FFFFFF82FF00818181818181818181
FFFFFF575757FF00FFFFFFFFADFF00000000FFFF90FF00FF
00FFFFFF99FF00FF0000FFFF7DFF00FFFFFFFFFF87FF0000
0000FFFF84FF00FF81FFFFFF85FF0081
81818181818181810000008D8D8D00FF0000008D8D8D00FF
00000000930000FF0000007F7F7F00FF000000007F00FFFF
0000007F7F7F00FF000000007F0000FF
FFFF008EFFFF0000FFFF8282820000008181818181818181
818181818181818181818181818181818181818181818181
81818181818181818181818181818181
FFFF0031FF000000FFFF00B9FFFF000081FFFFFF80808080
8080808080FF0081810000007F7F7F7F7F7F7F7F7F00FF81
81818181818181818181818181818181
FFFF0084FFFFFF00FF00009CFFFFFF0081FFFFFF77777777
7777777777FF0081810000007B7B7B7B7B7B7B7B7B00FF81
810000007B7B7B7B7B7B7B7B7B00FF81
FFFF0081FFFFFF00FF000080FFFFFF8281FFFF6B0000AEAE
AEAEAE00FFFF00818180ACFFFFFF8383838383FF00728181
81FFFFFF838383838383838383FF0081
FFFF0081FFFFFF007B7E8181818374828180870000009D9D
9D9D9D00FF846E818180ACFFFFFF8787878787FF00728181
818181FFFFFF8888888888FF00818181
FFFF0080FFFFFF00FF000080FFFFFF828180870000008080
80808000FF846E818180AC738C808181818181807A728181
818181000000808080808000FF818181
FFFF919191000000FFFFFF74000000008180878184828181
8181818096846E818180AC738C808181818181807A728181
81818181818181818181818181818181
818181818181818100007D7D7DFFFFFF8180878184828181
8181818096846E818180AC738C808181818181807A728181
81818181818181818181818181818181
00FF00FF81FFFF0000FF0081818100008180878184828181
8181818096846E818180AC738C808181818181807A728181
81818181818181818181818181818181
00FF00FF81FF000000FF00FF81FFFF008180878184828181
8181818096846E818180AC738C808181818181807A728181
81818181818181818181818181818181
00FF00FF81FFFF0000FF00FF81FFFF008180878184828181
8181818096846E818180AC738C808181818181807A728181
81818181818181818181818181818181
00FF00FF81FFFF0081FF00FF81FFFF008180870000008080
80808000FF846E818180ACFFFFFF8181818181FF00728181
81818181818181818181818181818181
00FF00FF81FFFF00817A7F828181A795818087FFFFFF8181
818181FF00846E818180ACFFFFFF8181818181FF00728181
818181FFFFFF8181818181FF00818181
00FF00FF81FFFF0081FF00FF81FFFF0081FFFFFF79797979
7979797979FF00818100000081818181818181818100FF81
818181000000818181818100FF818181
00FF0081818100000000FF0081000000810000007D7D7D7D
7D7D7D7D7D00FF818100000082828282828282828200FF81
8100000082828282828282828200FF81
8181818181818181FF00FF818181FFFF8181818181818181
818181818181818181818181818181818181818181818181
81FFFFFF818181818181818181FF0081
0000FF8100FF00000000818181FF00008181818181818181
818181818181818181818181818181818181818181818181
81818181818181818181818181818181
0000FF8100FF00000000FF8100FF00008100008181818181
818181818100008181818181818181818181818181818181
81818181818181818181818181818181
00FFFF8100FF000000FFFF8100FFFF008100008181818181
818181818100008181818181818181818181818181818181
81818181818181818181818181818181
00FFFF8100FF000000FFFF8100FFFF80810000FFFF818181
818181FFFF00008181818181818181818181818181818181
81818181818181818181818181818181
00FFFF8100FF0000827B838182878280818383FFFF818181
818181FFFF827E8181818181FF0081818181818181818181
818181818181818181818181FF818181
00FFFF8100FF000000FFFF8100FFFF80818383FFFF818181
818181FFFF827E818181818100FF81818181818181818181
81818181818181818181818100818181
0000818181FF000000000081FF0000008183837F80818181
8181818184827E81818181817B7F81818181818181818181
81818181818181818181818185818181
8181818181818181FFFF81818100FFFF8183837F80818181
8181818184827E81818181817B7F81818181818181818181
81818181818181818181818185818181
FF00FF008100FF00FF00FF818181FF008183837F80818181
8181818184827E81818181817B7F818100FF818181818181
81818181818181810081818185818181
FF00FF008100FF00FF00FF008100FF008183837F80818181
8181818184827E81818181817B7F8181FF00818181818181
8181818181818181FF81818185818181
FF00FF008100FF00FF00FF008100FF008183837F80818181
8181818184827E81818181817B7F81818884818181818181
81818181818181817E81818185818181
FF00FF008100FF008200FF008100FF00818383FFFF818181
818181FFFF827E81818181817B7F81818884818181818181
81818181818181817E81818185818181
FF00FF008100FF00827C7C82817F8D908183830000818181
8181810000827E81818181817B7F81818884818181818181
81818181818181817E81818185818181
FF00FF008100FF008200FF008100FF008100008181818181
8181818181000081818181817B7F81818884818181818181
81818181818181817E81818185818181
FF00FF818181FF00FFFF00FF81FF00FF81FFFF8181818181
8181818181FFFF81818181817B7F81818884818181818181
81818181818181817E81818185818181
818181818181818100FF0081818100FF8181818181818181
8181818181818181818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FF000000008181818100008181818181818181
8181818181818181818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FF00000000FF8181FF0000818100FF81818181
81818181818100FF818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FFFF0000FFFF8181FFFF00818100FF81818181
81818181818100FF818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FFFF0087FFFF8181FFFF81818100FFFF008181
81818181FF0000FF818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FFFF0087858481817D838181818082FF008181
81818181FF008080818181817B7F81818884818181818181
81818181818181817E81818185818181
0000FF8181FFFF0087FFFF8181FFFF8181818082FF008181
81818181FF008080818181817B7F81818884818181818181
81818181818181817E81818185818181
000081818181000000000081810000008181808283808181
8181818183828080818181817B7F81818884818181818181
81818181818181817E81818185818181
8181818181818181FFFF81818181FFFF8181808283808181
8181818183828080818181817B7F81818884818181818181
81818181818181817E81818185818181
8100FF008181FF008100FF81818181008181808283808181
8181818183828080818181817B7F818100FF818181818181
81818181818181810081818185818181
8100FF008181FF008100FF008181FF008181808283808181
8181818183828080818181817B7F81818181818181818181
81818181818181818181818185818181
8100FF008181FF008100FF008181FF008181808283808181
8181818183828080818181817B7F81818181818181818181
81818181818181818181818185818181
8100FF008181FF008180FF008181FF0081818082FF008181
81818181FF008080818181817B7F81818181818181818181
81818181818181818181818185818181
8100FF008181FF008180917F818182838181808200FF8181
8181818100FF808081818181FF0081818181818181818181
818181818181818181818181FF818181
8100FF008181FF008180FF008181FF00818100FF81818181
81818181818100FF81818181818181818181818181818181
81818181818181818181818181818181
8100FF8181818100810000FF818100008181FF0081818181
818181818181FF0081818181818181818181818181818181
81818181818181818181818181818181
818181818181818181FF0081818181FF8181818181818181
818181818181818181818181818181818181818181818181
81818181818181818181818181818181
pop
P
% End of image
.5 Mabswid
.5 .2619 m
.02381 .2619 L
s
.2619 .5 m
.2619 .02381 L
s
.97619 .2619 m
.5 .2619 L
s
.7381 .5 m
.7381 .02381 L
s
.5 .7381 m
.02381 .7381 L
s
.2619 .97619 m
.2619 .5 L
s
.2619 .14286 m
.02381 .14286 L
s
.14286 .2619 m
.14286 .02381 L
s
.5 .14286 m
.2619 .14286 L
s
.38095 .2619 m
.38095 .02381 L
s
.2619 .38095 m
.02381 .38095 L
s
.14286 .5 m
.14286 .2619 L
s
.7381 .14286 m
.5 .14286 L
s
.61905 .2619 m
.61905 .02381 L
s
.97619 .14286 m
.7381 .14286 L
s
.85714 .2619 m
.85714 .02381 L
s
.2619 .61905 m
.02381 .61905 L
s
.14286 .7381 m
.14286 .5 L
s
.2619 .85714 m
.02381 .85714 L
s
.14286 .97619 m
.14286 .7381 L
s
.02381 .02381 m
.02381 .97619 L
s
.5 .02381 m
.5 .97619 L
s
.97619 .02381 m
.97619 .97619 L
s
.02381 .02381 m
.97619 .02381 L
s
.02381 .5 m
.97619 .5 L
s
.02381 .97619 m
.97619 .97619 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 180},
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],

Cell[TextData[{
  "The energy associated with a mode or a basis function is defined to be the \
modulus squared of the corresponding coefficient. We order the coefficients \
so that ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c\_i \[VerticalSeparator]  \[GreaterEqual]  
        \[VerticalSeparator] c\_\(i + 1\) \[VerticalSeparator] \)\)], 
    "InlineFormula",
    CellTags->"S3.3.0"],
  ". With this ordering, we define a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"E", \((k)\), "=", 
          UnderoverscriptBox["\[Sum]", \(i = 1\), "k",
            LimitsPositioning->True], "\[VerticalSeparator]", \(c\_i\), 
          \( \[VerticalSeparator] \^2\)}], TraditionalForm]], "InlineFormula",
    
    CellTags->"S3.3.0"],
  ", which we call the \"cumulative energy\", that gives the energy of the \
first ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " largest coefficients. ",
  StyleBox["CumulativeEnergy[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox["]", "MR"],
  " gives the list ",
  Cell[BoxData[
      \(TraditionalForm\`{E \((1)\), E \((2)\), \[Ellipsis], E \((N)\)}\)], 
    "InlineFormula",
    CellTags->"S3.3.0"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " is the total number of coefficients in ",
  StyleBox["coefs", "TI"],
  " and ",
  StyleBox["CumulativeEnergy[", "MR"],
  StyleBox["coefs", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["]", "MR"],
  " gives ",
  Cell[BoxData[
      \(TraditionalForm\`{E \((1)\), E \((2)\), \[Ellipsis], E \((n)\)}\)], 
    "InlineFormula",
    CellTags->"S3.3.0"],
  ". "
}], "Text",
  CellTags->{"S3.3.0", "0.43"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CumulativeEnergy[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", "\<\"compute cumulative energy of \\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\
\\\\\"\\\", \\\"TI\\\"]\\) \"\>"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"CumulativeEnergy[\\\\\\\"\
\\\", \\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"data\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"n\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \
\"\>", 
                  RowBox[{\("compute cumulative energy up to "\), 
                    StyleBox[\(E \((n)\)\),
                      "InlineFormula"]}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.44"}],

Cell["Function calculating cumulative energy.", "Caption",
  CellTags->"S3.3.0"],

Cell[TextData[{
  "In data compression, there are usually two ways to specify how much we \
want to compress. One way is to specify the number of coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " to retain, that is, fix the compression ratio ",
  Cell[BoxData[
      \(TraditionalForm\`N/M\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`N\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " is the total number of coefficients before compression. Alternatively, we \
can also fix the threshold ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S3.3.0"],
  ", so that any coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`c\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " is set to zero if ",
  Cell[BoxData[
      \(TraditionalForm
      \`\( \[VerticalSeparator] c \[VerticalSeparator]  < \[Tau]\)\)], 
    "InlineFormula",
    CellTags->"S3.3.0"],
  ". We can also get rid of noise present in the data using what is called \
the wavelet shrinkage method. During compression, in addition to setting the \
coefficients below certain threshold ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " to zero, we can also \"shrink the coefficients above the threshold by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S3.3.0"],
  "\"; that is, the new coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_i\)\&~\)\)], "InlineFormula",
    CellTags->"S3.3.0"],
  " after compression is "
}], "Text",
  CellTags->{"S3.3.0", "0.45"}],

Cell[BoxData[
    FormBox[
      RowBox[{\(\(c\_i\)\&~\), "=", 
        RowBox[{"{", GridBox[{
              {
                StyleBox["0",
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{\(" if "\), 
                    
                    StyleBox[
                      \( \[VerticalSeparator] c\_i \[VerticalSeparator]  < 
                        \[Tau]\),
                      "DisplayFormula"]}],
                  "DisplayFormula"]},
              {
                StyleBox[
                  RowBox[{
                    StyleBox[\("sign"\),
                      "TI"], \((c\_i)\), 
                    \(( \[VerticalSeparator] c\_i \[VerticalSeparator] -
                        \[Tau])\)}],
                  "DisplayFormula"], 
                StyleBox[
                  RowBox[{
                    RowBox[{\(" if "\), 
                      
                      StyleBox[
                        \( \[VerticalSeparator] c\_i \[VerticalSeparator]  
                          \[GreaterEqual] \[Tau]\),
                        "DisplayFormula"]}], "."}],
                  "DisplayFormula"]}
              },
            ColumnAlignments->{Left}]}]}], TraditionalForm]], "DisplayFormula",\

  CellTags->{"S3.3.0", "0.46"}],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Compress[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"M\\\\\\\"\\\", \\\"TI\\\"]\\)\\!\\(\\*StyleBox[\
\\\"\\\\\\\"]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("set all but "\), 
                    StyleBox["M",
                      "InlineFormula"], \(" coefficients to zero "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Compress[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"tau\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"Threshold\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"True]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("set all coefficients "\), 
                    StyleBox[
                      RowBox[{
                      "\[VerticalSeparator]", \(c\_i\), 
                        "\[VerticalSeparator]", "<", 
                        StyleBox[\("tau"\),
                          "TI"]}],
                      "InlineFormula"], \(" to zero "\)}]},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Compress[\\\\\\\"\\\", \
\\\"MR\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\"coefs\\\\\\\"\\\", \\\"TI\\\"]\\)\
\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"tau\\\\\\\"\\\", \
\\\"TI\\\"]\\)\\!\\(\\*StyleBox[\\\"\\\\\\\",\\\\\\\"\\\", \\\"MR\\\"]\\) \\!\
\\(\\*StyleBox[\\\"\\\\\\\"Shrinking\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"->\\\\\\\"\\\", \\\"MR\\\"]\\) \
\\!\\(\\*StyleBox[\\\"\\\\\\\"True]\\\\\\\"\\\", \\\"MR\\\"]\\) \"\>", 
                  RowBox[{\("set all coefficients "\), 
                    StyleBox[
                      RowBox[{
                      "\[VerticalSeparator]", \(c\_i\), 
                        "\[VerticalSeparator]", "<", 
                        StyleBox[\("tau"\),
                          "TI"]}],
                      "InlineFormula"], 
                    "\<\" to zero and shrink the rest by \\!\\(\\*StyleBox[\\\
\"\\\\\\\"tau\\\\\\\"\\\", \\\"TI\\\"]\\)\"\>"}]}
                },
              ColumnAlignments->{Right, Left}],
            GridBoxOptions->{RowLines->False}]],
        "2ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.47"}],

Cell["Function doing compression.", "Caption",
  CellTags->"S3.3.0"],

Cell[BoxData[
    FormBox[
      StyleBox[
        FrameBox[
          StyleBox[GridBox[{
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"option name\\\\\\\"\\\", \
\\\"TI\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"default \
value\\\\\\\"\\\", \\\"TI\\\"]\\) \"\>", "\[Null]"},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Shrinking\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to shrink the coefficients "\)},
               
                 {"\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"Threshold\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", 
                  "\<\"\\!\\(\\*StyleBox[\\\"\\\\\\\"False\\\\\\\"\\\", \
\\\"MR\\\"]\\) \"\>", \("whether to compress with a threshold "\)}
                },
              ColumnAlignments->{Left}],
            GridBoxOptions->{RowLines->{True, False}}]],
        "3ColumnBox"], TraditionalForm]], "Text",
  CellTags->{"S3.3.0", "0.48"}],

Cell[TextData[{
  "Options for ",
  StyleBox["Compress", "MR"],
  "."
}], "Caption",
  CellTags->"S3.3.0"],

Cell["\<\
This gives the wavelet transform of a set of random data of length \
20.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.49"}],

Cell[CellGroupData[{

Cell["\<\
(SeedRandom[45847];
data = Table[Random[], {20}];
wtdata = WaveletTransform[data, d2])\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({{1.24857134924582457`, 1.13744000222406493`, 1.18921018948804068`, 
        1.2735552543813875`, 0.823890425400905179`}, {0.140280369065296923`, 
        0.172853463181100552`, \(-0.0441019334264225459`\), 
        \(-0.416244253602429736`\), \(-0.235086115936368011`\)}, {
        \(-0.084029885996213629`\), \(-0.649959365136246081`\), 
        \(-0.082612922913436293`\), 0.458739974704335384`, 
        \(-0.164880152327499089`\), 0.171663528668461147`, 
        0.0767713781315524101`, \(-0.0546394147261515517`\), 
        0.0726262242342400465`, \(-0.279487847305084535`\)}}\)], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["This shows the normalized cumulative energy function.", "MathCaption",
  CellTags->{"S3.3.0", "0.50"}],

Cell[CellGroupData[{

Cell["\<\
Short[CumulativeEnergy[wtdata]/
(Flatten[data].Flatten[data])]\
\>", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    TagBox[
      \({0.212202246362916113`, \[LeftSkeleton]18\[RightSkeleton], 
        0.999999999999999644`}\),
      Short]], "Output",
  CellLabel->"Out[27]//Short= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
We keep the 10 coefficients with the largest absolute values.\
\>", 
  "MathCaption",
  CellTags->{"S3.3.0", "0.51"}],

Cell[CellGroupData[{

Cell["Compress[wtdata, 10]", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({{1.24857134924582457`, 1.13744000222406493`, 1.18921018948804068`, 
        1.2735552543813875`, 0.823890425400905179`}, {0, 0, 0, 
        \(-0.416244253602429736`\), \(-0.235086115936368011`\)}, {0, 
        \(-0.649959365136246081`\), 0, 0.458739974704335384`, 0, 0, 0, 0, 0, 
        \(-0.279487847305084535`\)}}\)], "Output",
  CellLabel->"Out[28]= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["\<\
Here we set the coefficients whose absolute values are less than \
0.3 to zero.\
\>", "MathCaption",
  CellTags->{"S3.3.0", "0.52"}],

Cell[CellGroupData[{

Cell["Compress[wtdata, 0.3, Threshold -> True]", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({{1.24857134924582457`, 1.13744000222406493`, 1.18921018948804068`, 
        1.2735552543813875`, 0.823890425400905179`}, {0, 0, 0, 
        \(-0.416244253602429736`\), 0}, {0, \(-0.649959365136246081`\), 0, 
        0.458739974704335384`, 0, 0, 0, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[29]= ",
  CellTags->"S3.3.0"]
}, Open  ]],

Cell["This shrinks the above result by 0.3.", "MathCaption",
  CellTags->{"S3.3.0", "0.53"}],

Cell[CellGroupData[{

Cell["Compress[wtdata, 0.3, Shrinking -> True]", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"S3.3.0"],

Cell[BoxData[
    \({{0.948571349245824535`, 0.837440002224064983`, 0.889210189488040647`, 
        0.973555254381387413`, 0.523890425400905179`}, {0, 0, 0, 
        \(-0.116244253602429781`\), 0}, {0, \(-0.349959365136246081`\), 0, 
        0.158739974704335384`, 0, 0, 0, 0, 0, 0}}\)], "Output",
  CellLabel->"Out[30]= ",
  CellTags->"S3.3.0"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 79}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Contents"->{
    Cell[1709, 49, 62, 1, 58, "Section",
      CellTags->"Contents"]},
  "S3.3.0"->{
    Cell[1774, 52, 69, 1, 58, "Section",
      CellTags->{"S3.3.0", "0.1"}],
    Cell[1846, 55, 3769, 90, 354, "Text",
      CellTags->{"S3.3.0", "0.2"}],
    Cell[5618, 147, 971, 21, 99, "Text",
      CellTags->{"S3.3.0", "0.3"}],
    Cell[6592, 170, 87, 1, 16, "Caption",
      CellTags->"S3.3.0"],
    Cell[6682, 173, 132, 4, 24, "Text",
      CellTags->{"S3.3.0", "0.4"}],
    Cell[6817, 179, 77, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.5"}],
    Cell[6897, 182, 93, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[6993, 186, 180, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.6"}],
    Cell[7198, 194, 204, 8, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[7405, 204, 95, 3, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[7515, 210, 364, 7, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.7"}],
    Cell[7904, 221, 103, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[8010, 225, 4000, 335, 70, 3927, 332, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[12025, 563, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.8"}],
    Cell[12192, 571, 140, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[12335, 578, 3441, 244, 70, 3368, 241, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[15791, 825, 409, 12, 70, "Text",
      CellTags->{"S3.3.0", "0.9"}],
    Cell[16203, 839, 251, 8, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.10"}],
    Cell[16479, 851, 139, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[16621, 858, 2643, 178, 70, 2570, 175, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[19279, 1039, 894, 22, 70, "Text",
      CellTags->{"S3.3.0", "0.11"}],
    Cell[20176, 1063, 113, 5, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[20292, 1070, 369, 8, 70, "Text",
      CellTags->{"S3.3.0", "0.12"}],
    Cell[20664, 1080, 104, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.13"}],
    Cell[20771, 1083, 109, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[20883, 1087, 174, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.14"}],
    Cell[21082, 1095, 103, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[21188, 1099, 8386, 728, 70, 8313, 725, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[29589, 1830, 314, 6, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.15"}],
    Cell[29928, 1840, 170, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[30101, 1847, 1752, 122, 70, 1679, 119, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[31868, 1972, 803, 19, 70, "Text",
      CellTags->{"S3.3.0", "0.16"}],
    Cell[32674, 1993, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.17"}],
    Cell[32841, 2001, 112, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[32956, 2005, 1410, 97, 70, 1337, 94, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[34381, 2105, 797, 20, 70, "Text",
      CellTags->{"S3.3.0", "0.18"}],
    Cell[35181, 2127, 647, 15, 70, "Text",
      CellTags->{"S3.3.0", "0.19"}],
    Cell[35831, 2144, 57, 1, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[35891, 2147, 199, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.20"}],
    Cell[36093, 2155, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.21"}],
    Cell[36223, 2161, 98, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[36324, 2165, 115, 2, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.22"}],
    Cell[36464, 2171, 181, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[36648, 2178, 1934, 137, 70, 1861, 134, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[38597, 2318, 331, 9, 70, "Text",
      CellTags->{"S3.3.0", "0.23"}],
    Cell[38931, 2329, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.24"}],
    Cell[39076, 2335, 105, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[39184, 2339, 251, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.25"}],
    Cell[39460, 2348, 142, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[39605, 2355, 3840, 317, 70, 3767, 314, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[43460, 2675, 144, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.26"}],
    Cell[43629, 2683, 141, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[43773, 2690, 1308, 22, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[45096, 2715, 335, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.27"}],
    Cell[45456, 2730, 184, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[45643, 2737, 3456, 272, 70, 3383, 269, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[49114, 3012, 333, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.28"}],
    Cell[49472, 3027, 207, 6, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[49682, 3035, 3482, 298, 70, 3409, 295, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[53179, 3336, 1038, 24, 70, "Text",
      CellTags->{"S3.3.0", "0.29"}],
    Cell[54220, 3362, 112, 5, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[54335, 3369, 249, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.30"}],
    Cell[54587, 3377, 600, 14, 70, "Text",
      CellTags->{"S3.3.0", "0.31"}],
    Cell[55190, 3393, 77, 1, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[55270, 3396, 286, 6, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.32"}],
    Cell[55581, 3406, 88, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[55672, 3410, 4729, 391, 70, 4656, 388, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[60416, 3804, 329, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.33"}],
    Cell[60748, 3812, 956, 20, 70, "Text",
      CellTags->{"S3.3.0", "0.34"}],
    Cell[61707, 3834, 108, 2, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[61818, 3838, 392, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.35"}],
    Cell[62213, 3851, 242, 8, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[62458, 3861, 95, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.36"}],
    Cell[62578, 3866, 101, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[62682, 3870, 14336, 708, 70, 14263, 705, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[77033, 4581, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.37"}],
    Cell[77163, 4587, 131, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[77297, 4594, 216, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.38"}],
    Cell[77538, 4603, 86, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[77627, 4607, 14634, 739, 70, 14561, 736, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[92276, 5349, 131, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.39"}],
    Cell[92432, 5357, 106, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[92541, 5361, 935, 70, 70, 862, 67, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[93491, 5434, 98, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.40"}],
    Cell[93592, 5437, 136, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[93731, 5444, 136, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.41"}],
    Cell[93892, 5452, 105, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[94000, 5456, 1427, 118, 70, 1354, 115, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[95442, 5577, 205, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.42"}],
    Cell[95672, 5586, 87, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[95762, 5590, 15126, 787, 70, 15053, 784, "GraphicsData", 
    "PostScript", "Graphics",
      ImageCacheValid->False,
      CellTags->"S3.3.0"],
    Cell[110903, 6380, 1756, 53, 70, "Text",
      CellTags->{"S3.3.0", "0.43"}],
    Cell[112662, 6435, 1169, 25, 70, "Text",
      CellTags->{"S3.3.0", "0.44"}],
    Cell[113834, 6462, 80, 1, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[113917, 6465, 1678, 45, 70, "Text",
      CellTags->{"S3.3.0", "0.45"}],
    Cell[115598, 6512, 1282, 35, 70, "DisplayFormula",
      CellTags->{"S3.3.0", "0.46"}],
    Cell[116883, 6549, 2779, 54, 70, "Text",
      CellTags->{"S3.3.0", "0.47"}],
    Cell[119665, 6605, 68, 1, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[119736, 6608, 1038, 24, 70, "Text",
      CellTags->{"S3.3.0", "0.48"}],
    Cell[120777, 6634, 106, 5, 70, "Caption",
      CellTags->"S3.3.0"],
    Cell[120886, 6641, 135, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.49"}],
    Cell[121046, 6649, 159, 6, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[121208, 6657, 664, 11, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[121887, 6671, 108, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.50"}],
    Cell[122020, 6676, 135, 5, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[122158, 6683, 207, 6, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[122380, 6692, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.51"}],
    Cell[122532, 6700, 85, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[122620, 6704, 399, 7, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[123034, 6714, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.52"}],
    Cell[123201, 6722, 105, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[123309, 6726, 340, 6, 70, "Output",
      CellTags->"S3.3.0"],
    Cell[123664, 6735, 92, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.53"}],
    Cell[123781, 6740, 105, 2, 70, "Input",
      CellTags->"S3.3.0"],
    Cell[123889, 6744, 345, 6, 70, "Output",
      CellTags->"S3.3.0"]},
  "0.1"->{
    Cell[1774, 52, 69, 1, 58, "Section",
      CellTags->{"S3.3.0", "0.1"}]},
  "0.2"->{
    Cell[1846, 55, 3769, 90, 354, "Text",
      CellTags->{"S3.3.0", "0.2"}]},
  "0.3"->{
    Cell[5618, 147, 971, 21, 99, "Text",
      CellTags->{"S3.3.0", "0.3"}]},
  "0.4"->{
    Cell[6682, 173, 132, 4, 24, "Text",
      CellTags->{"S3.3.0", "0.4"}]},
  "0.5"->{
    Cell[6817, 179, 77, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.5"}]},
  "0.6"->{
    Cell[6993, 186, 180, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.6"}]},
  "0.7"->{
    Cell[7515, 210, 364, 7, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.7"}]},
  "0.8"->{
    Cell[12025, 563, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.8"}]},
  "0.9"->{
    Cell[15791, 825, 409, 12, 70, "Text",
      CellTags->{"S3.3.0", "0.9"}]},
  "0.10"->{
    Cell[16203, 839, 251, 8, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.10"}]},
  "0.11"->{
    Cell[19279, 1039, 894, 22, 70, "Text",
      CellTags->{"S3.3.0", "0.11"}]},
  "0.12"->{
    Cell[20292, 1070, 369, 8, 70, "Text",
      CellTags->{"S3.3.0", "0.12"}]},
  "0.13"->{
    Cell[20664, 1080, 104, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.13"}]},
  "0.14"->{
    Cell[20883, 1087, 174, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.14"}]},
  "0.15"->{
    Cell[29589, 1830, 314, 6, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.15"}]},
  "0.16"->{
    Cell[31868, 1972, 803, 19, 70, "Text",
      CellTags->{"S3.3.0", "0.16"}]},
  "0.17"->{
    Cell[32674, 1993, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.17"}]},
  "0.18"->{
    Cell[34381, 2105, 797, 20, 70, "Text",
      CellTags->{"S3.3.0", "0.18"}]},
  "0.19"->{
    Cell[35181, 2127, 647, 15, 70, "Text",
      CellTags->{"S3.3.0", "0.19"}]},
  "0.20"->{
    Cell[35891, 2147, 199, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.20"}]},
  "0.21"->{
    Cell[36093, 2155, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.21"}]},
  "0.22"->{
    Cell[36324, 2165, 115, 2, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.22"}]},
  "0.23"->{
    Cell[38597, 2318, 331, 9, 70, "Text",
      CellTags->{"S3.3.0", "0.23"}]},
  "0.24"->{
    Cell[38931, 2329, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.24"}]},
  "0.25"->{
    Cell[39184, 2339, 251, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.25"}]},
  "0.26"->{
    Cell[43460, 2675, 144, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.26"}]},
  "0.27"->{
    Cell[45096, 2715, 335, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.27"}]},
  "0.28"->{
    Cell[49114, 3012, 333, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.28"}]},
  "0.29"->{
    Cell[53179, 3336, 1038, 24, 70, "Text",
      CellTags->{"S3.3.0", "0.29"}]},
  "0.30"->{
    Cell[54335, 3369, 249, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.30"}]},
  "0.31"->{
    Cell[54587, 3377, 600, 14, 70, "Text",
      CellTags->{"S3.3.0", "0.31"}]},
  "0.32"->{
    Cell[55270, 3396, 286, 6, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.32"}]},
  "0.33"->{
    Cell[60416, 3804, 329, 6, 70, "Text",
      CellTags->{"S3.3.0", "0.33"}]},
  "0.34"->{
    Cell[60748, 3812, 956, 20, 70, "Text",
      CellTags->{"S3.3.0", "0.34"}]},
  "0.35"->{
    Cell[61818, 3838, 392, 11, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.35"}]},
  "0.36"->{
    Cell[62458, 3861, 95, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.36"}]},
  "0.37"->{
    Cell[77033, 4581, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.37"}]},
  "0.38"->{
    Cell[77297, 4594, 216, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.38"}]},
  "0.39"->{
    Cell[92276, 5349, 131, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.39"}]},
  "0.40"->{
    Cell[93491, 5434, 98, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.40"}]},
  "0.41"->{
    Cell[93731, 5444, 136, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.41"}]},
  "0.42"->{
    Cell[95442, 5577, 205, 5, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.42"}]},
  "0.43"->{
    Cell[110903, 6380, 1756, 53, 70, "Text",
      CellTags->{"S3.3.0", "0.43"}]},
  "0.44"->{
    Cell[112662, 6435, 1169, 25, 70, "Text",
      CellTags->{"S3.3.0", "0.44"}]},
  "0.45"->{
    Cell[113917, 6465, 1678, 45, 70, "Text",
      CellTags->{"S3.3.0", "0.45"}]},
  "0.46"->{
    Cell[115598, 6512, 1282, 35, 70, "DisplayFormula",
      CellTags->{"S3.3.0", "0.46"}]},
  "0.47"->{
    Cell[116883, 6549, 2779, 54, 70, "Text",
      CellTags->{"S3.3.0", "0.47"}]},
  "0.48"->{
    Cell[119736, 6608, 1038, 24, 70, "Text",
      CellTags->{"S3.3.0", "0.48"}]},
  "0.49"->{
    Cell[120886, 6641, 135, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.49"}]},
  "0.50"->{
    Cell[121887, 6671, 108, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.50"}]},
  "0.51"->{
    Cell[122380, 6692, 127, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.51"}]},
  "0.52"->{
    Cell[123034, 6714, 142, 4, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.52"}]},
  "0.53"->{
    Cell[123664, 6735, 92, 1, 70, "MathCaption",
      CellTags->{"S3.3.0", "0.53"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Contents", 124887, 6771},
  {"S3.3.0", 124972, 6774},
  {"0.1", 135065, 7037},
  {"0.2", 135154, 7040},
  {"0.3", 135244, 7043},
  {"0.4", 135333, 7046},
  {"0.5", 135421, 7049},
  {"0.6", 135515, 7052},
  {"0.7", 135610, 7055},
  {"0.8", 135705, 7058},
  {"0.9", 135801, 7061},
  {"0.10", 135892, 7064},
  {"0.11", 135990, 7067},
  {"0.12", 136083, 7070},
  {"0.13", 136175, 7073},
  {"0.14", 136274, 7076},
  {"0.15", 136373, 7079},
  {"0.16", 136472, 7082},
  {"0.17", 136565, 7085},
  {"0.18", 136664, 7088},
  {"0.19", 136757, 7091},
  {"0.20", 136850, 7094},
  {"0.21", 136942, 7097},
  {"0.22", 137041, 7100},
  {"0.23", 137140, 7103},
  {"0.24", 137232, 7106},
  {"0.25", 137331, 7109},
  {"0.26", 137430, 7112},
  {"0.27", 137529, 7115},
  {"0.28", 137629, 7118},
  {"0.29", 137729, 7121},
  {"0.30", 137823, 7124},
  {"0.31", 137915, 7127},
  {"0.32", 138008, 7130},
  {"0.33", 138107, 7133},
  {"0.34", 138199, 7136},
  {"0.35", 138292, 7139},
  {"0.36", 138392, 7142},
  {"0.37", 138490, 7145},
  {"0.38", 138589, 7148},
  {"0.39", 138688, 7151},
  {"0.40", 138787, 7154},
  {"0.41", 138885, 7157},
  {"0.42", 138984, 7160},
  {"0.43", 139083, 7163},
  {"0.44", 139178, 7166},
  {"0.45", 139273, 7169},
  {"0.46", 139368, 7172},
  {"0.47", 139473, 7175},
  {"0.48", 139568, 7178},
  {"0.49", 139663, 7181},
  {"0.50", 139763, 7184},
  {"0.51", 139863, 7187},
  {"0.52", 139963, 7190},
  {"0.53", 140063, 7193}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 62, 1, 58, "Section",
  CellTags->"Contents"],
Cell[1774, 52, 69, 1, 58, "Section",
  CellTags->{"S3.3.0", "0.1"}],
Cell[1846, 55, 3769, 90, 354, "Text",
  CellTags->{"S3.3.0", "0.2"}],
Cell[5618, 147, 971, 21, 99, "Text",
  CellTags->{"S3.3.0", "0.3"}],
Cell[6592, 170, 87, 1, 16, "Caption",
  CellTags->"S3.3.0"],
Cell[6682, 173, 132, 4, 24, "Text",
  CellTags->{"S3.3.0", "0.4"}],
Cell[6817, 179, 77, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.5"}],
Cell[6897, 182, 93, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[6993, 186, 180, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.6"}],

Cell[CellGroupData[{
Cell[7198, 194, 204, 8, 70, "Input",
  CellTags->"S3.3.0"],
Cell[7405, 204, 95, 3, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[7515, 210, 364, 7, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.7"}],

Cell[CellGroupData[{
Cell[7904, 221, 103, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[8010, 225, 4000, 335, 70, 3927, 332, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[12025, 563, 142, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.8"}],

Cell[CellGroupData[{
Cell[12192, 571, 140, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[12335, 578, 3441, 244, 70, 3368, 241, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[15791, 825, 409, 12, 70, "Text",
  CellTags->{"S3.3.0", "0.9"}],
Cell[16203, 839, 251, 8, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.10"}],

Cell[CellGroupData[{
Cell[16479, 851, 139, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[16621, 858, 2643, 178, 70, 2570, 175, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[19279, 1039, 894, 22, 70, "Text",
  CellTags->{"S3.3.0", "0.11"}],
Cell[20176, 1063, 113, 5, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[20292, 1070, 369, 8, 70, "Text",
  CellTags->{"S3.3.0", "0.12"}],
Cell[20664, 1080, 104, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.13"}],
Cell[20771, 1083, 109, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[20883, 1087, 174, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.14"}],

Cell[CellGroupData[{
Cell[21082, 1095, 103, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[21188, 1099, 8386, 728, 70, 8313, 725, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[29589, 1830, 314, 6, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.15"}],

Cell[CellGroupData[{
Cell[29928, 1840, 170, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[30101, 1847, 1752, 122, 70, 1679, 119, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[31868, 1972, 803, 19, 70, "Text",
  CellTags->{"S3.3.0", "0.16"}],
Cell[32674, 1993, 142, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.17"}],

Cell[CellGroupData[{
Cell[32841, 2001, 112, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[32956, 2005, 1410, 97, 70, 1337, 94, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[34381, 2105, 797, 20, 70, "Text",
  CellTags->{"S3.3.0", "0.18"}],
Cell[35181, 2127, 647, 15, 70, "Text",
  CellTags->{"S3.3.0", "0.19"}],
Cell[35831, 2144, 57, 1, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[35891, 2147, 199, 6, 70, "Text",
  CellTags->{"S3.3.0", "0.20"}],
Cell[36093, 2155, 127, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.21"}],
Cell[36223, 2161, 98, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[36324, 2165, 115, 2, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.22"}],

Cell[CellGroupData[{
Cell[36464, 2171, 181, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[36648, 2178, 1934, 137, 70, 1861, 134, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[38597, 2318, 331, 9, 70, "Text",
  CellTags->{"S3.3.0", "0.23"}],
Cell[38931, 2329, 142, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.24"}],
Cell[39076, 2335, 105, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[39184, 2339, 251, 5, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.25"}],

Cell[CellGroupData[{
Cell[39460, 2348, 142, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[39605, 2355, 3840, 317, 70, 3767, 314, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[43460, 2675, 144, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.26"}],

Cell[CellGroupData[{
Cell[43629, 2683, 141, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[43773, 2690, 1308, 22, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[45096, 2715, 335, 11, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.27"}],

Cell[CellGroupData[{
Cell[45456, 2730, 184, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[45643, 2737, 3456, 272, 70, 3383, 269, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[49114, 3012, 333, 11, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.28"}],

Cell[CellGroupData[{
Cell[49472, 3027, 207, 6, 70, "Input",
  CellTags->"S3.3.0"],
Cell[49682, 3035, 3482, 298, 70, 3409, 295, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[53179, 3336, 1038, 24, 70, "Text",
  CellTags->{"S3.3.0", "0.29"}],
Cell[54220, 3362, 112, 5, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[54335, 3369, 249, 6, 70, "Text",
  CellTags->{"S3.3.0", "0.30"}],
Cell[54587, 3377, 600, 14, 70, "Text",
  CellTags->{"S3.3.0", "0.31"}],
Cell[55190, 3393, 77, 1, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[55270, 3396, 286, 6, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.32"}],

Cell[CellGroupData[{
Cell[55581, 3406, 88, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[55672, 3410, 4729, 391, 70, 4656, 388, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[60416, 3804, 329, 6, 70, "Text",
  CellTags->{"S3.3.0", "0.33"}],
Cell[60748, 3812, 956, 20, 70, "Text",
  CellTags->{"S3.3.0", "0.34"}],
Cell[61707, 3834, 108, 2, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[61818, 3838, 392, 11, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.35"}],
Cell[62213, 3851, 242, 8, 70, "Input",
  CellTags->"S3.3.0"],
Cell[62458, 3861, 95, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.36"}],

Cell[CellGroupData[{
Cell[62578, 3866, 101, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[62682, 3870, 14336, 708, 70, 14263, 705, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[77033, 4581, 127, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.37"}],
Cell[77163, 4587, 131, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[77297, 4594, 216, 5, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.38"}],

Cell[CellGroupData[{
Cell[77538, 4603, 86, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[77627, 4607, 14634, 739, 70, 14561, 736, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[92276, 5349, 131, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.39"}],

Cell[CellGroupData[{
Cell[92432, 5357, 106, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[92541, 5361, 935, 70, 70, 862, 67, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[93491, 5434, 98, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.40"}],
Cell[93592, 5437, 136, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[93731, 5444, 136, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.41"}],

Cell[CellGroupData[{
Cell[93892, 5452, 105, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[94000, 5456, 1427, 118, 70, 1354, 115, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[95442, 5577, 205, 5, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.42"}],

Cell[CellGroupData[{
Cell[95672, 5586, 87, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[95762, 5590, 15126, 787, 70, 15053, 784, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False,
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[110903, 6380, 1756, 53, 70, "Text",
  CellTags->{"S3.3.0", "0.43"}],
Cell[112662, 6435, 1169, 25, 70, "Text",
  CellTags->{"S3.3.0", "0.44"}],
Cell[113834, 6462, 80, 1, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[113917, 6465, 1678, 45, 70, "Text",
  CellTags->{"S3.3.0", "0.45"}],
Cell[115598, 6512, 1282, 35, 70, "DisplayFormula",
  CellTags->{"S3.3.0", "0.46"}],
Cell[116883, 6549, 2779, 54, 70, "Text",
  CellTags->{"S3.3.0", "0.47"}],
Cell[119665, 6605, 68, 1, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[119736, 6608, 1038, 24, 70, "Text",
  CellTags->{"S3.3.0", "0.48"}],
Cell[120777, 6634, 106, 5, 70, "Caption",
  CellTags->"S3.3.0"],
Cell[120886, 6641, 135, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.49"}],

Cell[CellGroupData[{
Cell[121046, 6649, 159, 6, 70, "Input",
  CellTags->"S3.3.0"],
Cell[121208, 6657, 664, 11, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[121887, 6671, 108, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.50"}],

Cell[CellGroupData[{
Cell[122020, 6676, 135, 5, 70, "Input",
  CellTags->"S3.3.0"],
Cell[122158, 6683, 207, 6, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[122380, 6692, 127, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.51"}],

Cell[CellGroupData[{
Cell[122532, 6700, 85, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[122620, 6704, 399, 7, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[123034, 6714, 142, 4, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.52"}],

Cell[CellGroupData[{
Cell[123201, 6722, 105, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[123309, 6726, 340, 6, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]],
Cell[123664, 6735, 92, 1, 70, "MathCaption",
  CellTags->{"S3.3.0", "0.53"}],

Cell[CellGroupData[{
Cell[123781, 6740, 105, 2, 70, "Input",
  CellTags->"S3.3.0"],
Cell[123889, 6744, 345, 6, 70, "Output",
  CellTags->"S3.3.0"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

