(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51434,       2072]*)
(*NotebookOutlinePosition[     75594,       2761]*)
(*  CellTagsIndexPosition[     69445,       2591]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Mathematica", "SBO"],
  " Wavelet Explorer"
}], "IndexSection",
  CellTags->"MasterIndexHeading"],

Cell[TextData[{
  "Approximation space, ",
  ButtonBox["1.2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Approximation space"],

Cell[TextData[{
  "B\[Hyphen]splines, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.4"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.10"},
    ButtonStyle->"AddOnsLink"],
  "\n        orthogonalization of, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.33"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"B-splines"],

Cell[TextData[{
  "Band\[Hyphen]limited function, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Band-limited function"],

Cell[TextData[{
  StyleBox["BasisType", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.34"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.12"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.5"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"BasisType"],

Cell[TextData[{
  "Battle\[Hyphen]Lemari\[EAcute] wavelet, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.112"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.120"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Battle-Lemarie wavelet"],

Cell[TextData[{
  "Bell, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Bell"],

Cell[TextData[{
  "Best basis, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.34"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Best basis"],

Cell[TextData[{
  "Best level, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.51"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Best level"],

Cell[TextData[{
  StyleBox["BestLevel", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.51"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.22"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.5"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"BestLevel"],

Cell[TextData[{
  "Biorthogonal spline filter, ",
  ButtonBox["1.6.3",
    ButtonData:>{"Wavelets 1.6.3", "3.10"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Biorthogonal spline filter"],

Cell[TextData[{
  "Biorthogonal wavelets, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Biorthogonal wavelets"],

Cell[TextData[{
  "Biorthogonality conditions, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.20"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.32"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Biorthogonality conditions"],

Cell[TextData[{
  StyleBox["BiorthogonalSplineFilter", "MR"],
  ", ",
  ButtonBox["1.6.3",
    ButtonData:>{"Wavelets 1.6.3", "3.11"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.32"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"BiorthogonalSplineFilter"],

Cell[TextData[{
  "Boundary condition, ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.16"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Boundary condition"],

Cell[TextData[{
  StyleBox["BoundaryCondition", "MR"],
  ", ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.18"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.34"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.47"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.22"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.12"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.26"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.5"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"BoundaryCondition"],

Cell[TextData[{
  "Box function, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Box function"],

Cell[TextData[{
  StyleBox["BSpline", "MR"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.13"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.47"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"BSpline"],

Cell[TextData[{
  "Burgers equation, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Burgers equation"],

Cell[TextData[{
  "Cascade algorithm, ",
  ButtonBox["1.5.7",
    ButtonData:>{"Wavelets 1.5.7", "7.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Cascade algorithm"],

Cell[TextData[{
  "Chirp signal, ",
  ButtonBox["2.1.3",
    ButtonData:>{"Wavelets 2.1.3", "3.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Chirp signal"],

Cell[TextData[{
  StyleBox["CoifletFilter", "MR"],
  ", ",
  ButtonBox["1.4.5",
    ButtonData:>{"Wavelets 1.4.5", "5.15"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CoifletFilter"],

Cell[TextData[{
  "Coiflets filters, ",
  ButtonBox["1.4.5",
    ButtonData:>{"Wavelets 1.4.5", "5.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Coiflets filters"],

Cell[TextData[{
  "Coifman and Meyer basis, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Coifman and Meyer basis"],

Cell[TextData[{
  StyleBox["Compress", "MR"],
  ", ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.30"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.47"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Compress"],

Cell[TextData[{
  "Compression, data, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.30"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Compression"],

Cell[TextData[{
  "Compression ratio, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.30"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Compression ratio"],

Cell[TextData[{
  "Cos\[Hyphen]II and Cos\[Hyphen]IV bases, ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.10"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Cos-II and Cos-IV bases"],

Cell[TextData[{
  "Cosine packet, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.32"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Cosine packet"],

Cell[TextData[{
  StyleBox["CosPacket", "MR"],
  ", ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.33"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.54"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CosPacket"],

Cell[TextData[{
  StyleBox["CosPacketCoefficients", "MR"],
  ", ",
  ButtonBox["1.7.5",
    ButtonData:>{"Wavelets 1.7.5", "5.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CosPacketCoefficients"],

Cell[TextData[{
  StyleBox["CosPacketTransform", "MR"],
  ", ",
  ButtonBox["1.7.5",
    ButtonData:>{"Wavelets 1.7.5", "5.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CosPacketTransform"],

Cell[TextData[{
  "Cost function, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.46"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Cost function"],

Cell[TextData[{
  StyleBox["CostFunction", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.46"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.22"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.5"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CostFunction"],

Cell[TextData[{
  StyleBox["CosTransform", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.31"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.35"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.11"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CosTransform"],

Cell[TextData[{
  "Cumulative energy, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.25"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Cumulative energy"],

Cell[TextData[{
  StyleBox["CumulativeEnergy", "MR"],
  ", ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.25"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.44"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"CumulativeEnergy"],

Cell[TextData[{
  "Data compression, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.30"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Data compression"],

Cell[TextData[{
  "Daubechies filters, extremal phase, ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.38"},
    ButtonStyle->"AddOnsLink"],
  "\n        least asymmetric, ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Daubechies filters"],

Cell[TextData[{
  "Daubechies wavelets, construction of, ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        extremal phase, ",
  ButtonBox["1.4.3",
    ButtonData:>{"Wavelets 1.4.3", "3.31"},
    ButtonStyle->"AddOnsLink"],
  "\n        least asymmetric, ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.56"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Daubechies wavelets"],

Cell[TextData[{
  StyleBox["DaubechiesFilter", "MR"],
  ", ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.24"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.28"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"DaubechiesFilter"],

Cell[TextData[{
  "Decimation, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Decimation"],

Cell[TextData[{
  "Denoising, with shrinking, ",
  ButtonBox["2.1.2",
    ButtonData:>{"Wavelets 2.1.2", "2.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        without shrinking, ",
  ButtonBox["2.1.2",
    ButtonData:>{"Wavelets 2.1.2", "2.12"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Denoising"],

Cell[TextData[{
  "Detail space, ",
  ButtonBox["1.2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.6"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Detail space"],

Cell[TextData[{
  "Dilation equation, ",
  ButtonBox["1.2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        in two dimensions, ",
  ButtonBox["1.5.4",
    ButtonData:>{"Wavelets 1.5.4", "4.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Dilation equation"],

Cell[TextData[{
  "Discrete sine and cosine transforms, ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        implementation of, ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.24"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Discrete sine and cosine transforms"],

Cell[TextData[{
  "Down\[Hyphen]sampling, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Down-sampling"],

Cell[TextData[{
  StyleBox["DScalingFunction", "MR"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.21"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.4",
    ButtonData:>{"Wavelets 3.1.4", "4.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"DScalingFunction"],

Cell[TextData[{
  "Dual basis, ",
  ButtonBox["1.6.1",
    ButtonData:>{"Wavelets 1.6.1", "1.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Dual basis"],

Cell[TextData[{
  "Dual multiresolution analysis, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Dual multiresolution analysis"],

Cell[TextData[{
  "Dual scaling function, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Dual scaling function"],

Cell[TextData[{
  "dual space, ",
  ButtonBox["1.6.1",
    ButtonData:>{"Wavelets 1.6.1", "1.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"dual space"],

Cell[TextData[{
  "Dual wavelet, ",
  ButtonBox["1.6.2",
    ButtonData:>{"Wavelets 1.6.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Dual wavelet"],

Cell[TextData[{
  StyleBox["DWavelet", "MR"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.32"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.4",
    ButtonData:>{"Wavelets 3.1.4", "4.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"DWavelet"],

Cell[TextData[{
  "Energy, associated with a mode, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.25"},
    ButtonStyle->"AddOnsLink"],
  "\n        cumulative, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.25"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Energy"],

Cell[TextData[{
  "Entropy, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.34"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Entropy"],

Cell[TextData[{
  "Entropy criterion, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.34"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Entropy criterion"],

Cell[TextData[{
  StyleBox["ExchangeAxes", "MR"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.29"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ExchangeAxes"],

Cell[TextData[{
  "Filter, finite impulse response (FIR), ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        half\[Hyphen]band, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        highpass, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.130"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        lowpass, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.130"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.6"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Filter"],

Cell[TextData[{
  "Filter bank, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        analysis, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        synthesis, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.18"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Filter bank"],

Cell[TextData[{
  "Filter coefficients, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.80"},
    ButtonStyle->"AddOnsLink"],
  "\n        Daubechies' extremal phase, ",
  ButtonBox["1.4.2",
    ButtonData:>{"Wavelets 1.4.2", "2.16"},
    ButtonStyle->"AddOnsLink"],
  "\n        Daubechies' least asymmetric, ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        Haar, ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.58"},
    ButtonStyle->"AddOnsLink"],
  "\n        Meyer, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.93"},
    ButtonStyle->"AddOnsLink"],
  "\n        Shannon, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.44"},
    ButtonStyle->"AddOnsLink"],
  "\n        spline, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.92"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Filter coefficients"],

Cell[TextData[{
  "Folding, ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.10"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Folding"],

Cell[TextData[{
  "Franklin multiresolution analysis, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.114"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Franklin multiresolution analysis"],

Cell[TextData[{
  "Franklin wavelet, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.114"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Franklin wavelet"],

Cell[TextData[{
  "Frequency response function, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        plot of, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.26"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Frequency response function"],

Cell[TextData[{
  "Gray code ordering, ",
  ButtonBox["2.1.3",
    ButtonData:>{"Wavelets 2.1.3", "3.22"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Gray code ordering"],

Cell[TextData[{
  StyleBox["GrayCodeOrder", "MR"],
  ", ",
  ButtonBox["2.1.3",
    ButtonData:>{"Wavelets 2.1.3", "3.22"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.19"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"GrayCodeOrder"],

Cell[TextData[{
  "Haar multiresolution analysis, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Haar multiresolution analysis"],

Cell[TextData[{
  "Haar wavelet, ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.58"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Haar wavelet"],

Cell[TextData[{
  StyleBox["HaarFilter", "MR"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"HaarFilter"],

Cell[TextData[{
  "Hat function, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.11"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Hat function"],

Cell[TextData[{
  "Highpass filter, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.130"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Highpass filter"],

Cell[TextData[{
  StyleBox["HighpassFilter", "MR"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.7"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.37"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"HighpassFilter"],

Cell[TextData[{
  "infinite impulse response (IIR), ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"infinite impulse response (IIR)"],

Cell[TextData[{
  StyleBox["Interpolation", "MR"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.36"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Interpolation"],

Cell[TextData[{
  StyleBox["InterpolationDomain", "MR"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.36"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InterpolationDomain"],

Cell[TextData[{
  "Inverse wavelet transform, ",
  ButtonBox["1.5.2",
    ButtonData:>{"Wavelets 1.5.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Inverse wavelet transform"],

Cell[TextData[{
  StyleBox["InverseCosPacketTransform", "MR"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseCosPacketTransform"],

Cell[TextData[{
  StyleBox["InverseCosTransform", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.33"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.11"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseCosTransform"],

Cell[TextData[{
  StyleBox["InverseMalvarTransform", "MR"],
  ", ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.18"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.24"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseMalvarTransform"],

Cell[TextData[{
  StyleBox["InverseSinPacketTransform", "MR"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseSinPacketTransform"],

Cell[TextData[{
  StyleBox["InverseSinTransform", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.33"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.11"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseSinTransform"],

Cell[TextData[{
  StyleBox["InverseTransform", "MR"],
  ", ",
  ButtonBox["1.5.7",
    ButtonData:>{"Wavelets 1.5.7", "7.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.36"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseTransform"],

Cell[TextData[{
  StyleBox["InverseWaveletPacketTransform", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.62"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseWaveletPacketTransform"],

Cell[TextData[{
  StyleBox["InverseWaveletTransform", "MR"],
  ", ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.21"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"InverseWaveletTransform"],

Cell[TextData[{
  StyleBox["LeastAsymmetricFilter", "MR"],
  ", ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.42"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.55"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"LeastAsymmetricFilter"],

Cell[TextData[{
  "Library of bases, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.12"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Library of bases"],

Cell[TextData[{
  "Linear phase filter, ",
  ButtonBox["1.4.4",
    ButtonData:>{"Wavelets 1.4.4", "4.6"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Linear phase filter"],

Cell[TextData[{
  "Local trigonometric basis, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Local trigonometric basis"],

Cell[TextData[{
  "Local trigonometric transform, ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Local trigonometric transform"],

Cell[TextData[{
  StyleBox["LogarithmicScale", "MR"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.29"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"LogarithmicScale"],

Cell[TextData[{
  "Lowpass filter, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.130"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Lowpass filter"],

Cell[TextData[{
  "Malvar basis, ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.12"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Malvar basis"],

Cell[TextData[{
  StyleBox["MalvarTransform", "MR"],
  ", ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.17"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.24"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MalvarTransform"],

Cell[TextData[{
  StyleBox["Mathematica", "TI"],
  " Package, ",
  ButtonBox["0.1.1",
    ButtonData:>{"Wavelets 0.1.1", "1.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Mathematica Package"],

Cell[TextData[{
  "Mean square error, relative, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.60"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Mean square error"],

Cell[TextData[{
  "Meyer wavelets, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.49"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.80"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.72"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Meyer wavelets"],

Cell[TextData[{
  StyleBox["MeyerFilter", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.101"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.26"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MeyerFilter"],

Cell[TextData[{
  StyleBox["MeyerPhi", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.85"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MeyerPhi"],

Cell[TextData[{
  StyleBox["MeyerPsi", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.85"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MeyerPsi"],

Cell[TextData[{
  "Moment\[Hyphen]vanishing condition, ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.8"},
    ButtonStyle->"AddOnsLink"],
  "\n        for coiflets, ",
  ButtonBox["1.4.5",
    ButtonData:>{"Wavelets 1.4.5", "5.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Moment-vanishing condition"],

Cell[TextData[{
  StyleBox["MRDecomposition", "MR"],
  ", ",
  ButtonBox["3.2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.46"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"MRDecomposition"],

Cell[TextData[{
  "Multiresolution analysis, ",
  ButtonBox["1.2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        Franklin, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.114"},
    ButtonStyle->"AddOnsLink"],
  "\n        Haar, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.3"},
    ButtonStyle->"AddOnsLink"],
  "\n        Shannon, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.24"},
    ButtonStyle->"AddOnsLink"],
  "\n        spline, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.20"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.21"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Multiresolution analysis"],

Cell[TextData[{
  "Multiresolution decomposition, ",
  ButtonBox["2.2.1",
    ButtonData:>{"Wavelets 2.2.1", "1.17"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Multiresolution decomposition"],

Cell[TextData[{
  "Perfect reconstruction, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.28"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Perfect reconstruction"],

Cell[TextData[{
  "Phase space plot, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.17"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Phase space plot"],

Cell[TextData[{
  StyleBox["PhaseSpacePlot", "MR"],
  ", ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.17"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"PhaseSpacePlot"],

Cell[TextData[{
  StyleBox["PlotCoefficients", "MR"],
  ", ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.22"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.14"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"PlotCoefficients"],

Cell[TextData[{
  StyleBox["PlotCoefficients2D", "MR"],
  ", ",
  ButtonBox["2.2.1",
    ButtonData:>{"Wavelets 2.2.1", "1.11"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.34"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"PlotCoefficients2D"],

Cell[TextData[{
  StyleBox["PlotLines", "MR"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.11"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"PlotLines"],

Cell[TextData[{
  "Polarity, ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.7.4",
    ButtonData:>{"Wavelets 1.7.4", "4.12"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Polarity"],

Cell[TextData[{
  "Pyramid algorithm, ",
  ButtonBox["1.5.1",
    ButtonData:>{"Wavelets 1.5.1", "1.24"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Pyramid algorithm"],

Cell[TextData[{
  "Refinement equation, ",
  ButtonBox["1.2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Refinement equation"],

Cell[TextData[{
  "Resolution level, ",
  ButtonBox["1.2",
    ButtonData:>{"Wavelets 1.2", "0.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.1",
    ButtonData:>{"Wavelets 1.5.1", "1.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Resolution level"],

Cell[TextData[{
  "Response function, frequency, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  "\n        plot of, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.26"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Response function"],

Cell[TextData[{
  "Scaling function, ",
  ButtonBox["1.2.1",
    ButtonData:>{"Wavelets 1.2.1", "1.8"},
    ButtonStyle->"AddOnsLink"],
  "\n        computing, ",
  ButtonBox["1.4.3",
    ButtonData:>{"Wavelets 1.4.3", "3.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        derivatives of, ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.18"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        in two dimensions, ",
  ButtonBox["1.5.4",
    ButtonData:>{"Wavelets 1.5.4", "4.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        orthogonality condition of, ",
  ButtonBox["1.2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.19"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.25"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Scaling function"],

Cell[TextData[{
  StyleBox["ScalingFunction", "MR"],
  ", ",
  ButtonBox["1.4.3",
    ButtonData:>{"Wavelets 1.4.3", "3.13"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.3",
    ButtonData:>{"Wavelets 1.4.3", "3.23"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ScalingFunction"],

Cell[TextData[{
  "Shannon, multiresolution analysis, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.24"},
    ButtonStyle->"AddOnsLink"],
  "\n        sampling theorem, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.8"},
    ButtonStyle->"AddOnsLink"],
  "\n        wavelet, ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.37"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Shannon"],

Cell[TextData[{
  StyleBox["ShannonFilter", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.47"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.26"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ShannonFilter"],

Cell[TextData[{
  StyleBox["ShannonPhi", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.40"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ShannonPhi"],

Cell[TextData[{
  StyleBox["ShannonPsi", "MR"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.40"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ShannonPsi"],

Cell[TextData[{
  "Shock, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Shock"],

Cell[TextData[{
  StyleBox["ShowBasisPosition", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.43"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.31"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ShowBasisPosition"],

Cell[TextData[{
  StyleBox["ShowBasisPosition2D", "MR"],
  ", ",
  ButtonBox["2.2.1",
    ButtonData:>{"Wavelets 2.2.1", "1.11"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.34"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"ShowBasisPosition2D"],

Cell[TextData[{
  StyleBox["Shrinking", "MR"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.48"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Shrinking"],

Cell[TextData[{
  "Sin packet, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.32"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Sin packet"],

Cell[TextData[{
  "Sin\[Hyphen]II and Sin\[Hyphen]IV bases, ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.10"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Sin-II and Sin-IV bases"],

Cell[TextData[{
  StyleBox["SinPacket", "MR"],
  ", ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.33"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.54"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SinPacket"],

Cell[TextData[{
  StyleBox["SinPacketCoefficients", "MR"],
  ", ",
  ButtonBox["1.7.5",
    ButtonData:>{"Wavelets 1.7.5", "5.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SinPacketCoefficients"],

Cell[TextData[{
  StyleBox["SinPacketTransform", "MR"],
  ", ",
  ButtonBox["1.7.5",
    ButtonData:>{"Wavelets 1.7.5", "5.10"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SinPacketTransform"],

Cell[TextData[{
  StyleBox["SinTransform", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.31"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.11"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SinTransform"],

Cell[TextData[{
  "Smooth local trigonometric bases, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.18"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Smooth local trigonometric bases"],

Cell[TextData[{
  "Sound signal, analysis of a, ",
  ButtonBox["2.1.4",
    ButtonData:>{"Wavelets 2.1.4", "4.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Sound signal"],

Cell[TextData[{
  "Spectral factorization, ",
  ButtonBox["1.4.1",
    ButtonData:>{"Wavelets 1.4.1", "1.28"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Spectral factorization"],

Cell[TextData[{
  "Speech signal, analysis of a, ",
  ButtonBox["2.1.3",
    ButtonData:>{"Wavelets 2.1.3", "3.37"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Speech signal"],

Cell[TextData[{
  "Spline, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        B\[Hyphen]splines, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        Biorthogonal wavelet, ",
  ButtonBox["1.6.3",
    ButtonData:>{"Wavelets 1.6.3", "3.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        filters, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.74"},
    ButtonStyle->"AddOnsLink"],
  "\n        function space, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        multiresolution analysis, ",
  ButtonBox["1.2.2",
    ButtonData:>{"Wavelets 1.2.2", "2.19"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.21"},
    ButtonStyle->"AddOnsLink"],
  "\n        wavelet, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.112"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Spline"],

Cell[TextData[{
  StyleBox["SplineFilter", "MR"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.95"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.1",
    ButtonData:>{"Wavelets 3.1.1", "1.26"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SplineFilter"],

Cell[TextData[{
  StyleBox["SplinePhi", "MR"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.61"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.66"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SplinePhi"],

Cell[TextData[{
  StyleBox["SplinePsi", "MR"],
  ", ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.111"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.40"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"SplinePsi"],

Cell[TextData[{
  "Splitting algorithm, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.6"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Splitting algorithm"],

Cell[TextData[{
  "Subband filtering, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.6"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Subband filtering"],

Cell[TextData[{
  StyleBox["Taper", "MR"],
  ", ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.34"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.56"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.12"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.3",
    ButtonData:>{"Wavelets 3.2.3", "3.26"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.4",
    ButtonData:>{"Wavelets 3.2.4", "4.5"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Taper"],

Cell[TextData[{
  "Taper function, ",
  ButtonBox["1.7.2",
    ButtonData:>{"Wavelets 1.7.2", "2.34"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.22"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Taper function"],

Cell[TextData[{
  "Taper width, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.26"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Taper width"],

Cell[TextData[{
  StyleBox["Threshold", "MR"],
  ", ",
  ButtonBox["3.3",
    ButtonData:>{"Wavelets 3.3", "0.48"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Threshold"],

Cell[TextData[{
  "Threshold function, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.46"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Threshold function"],

Cell[TextData[{
  "Time\[Hyphen]frequency plot, ",
  ButtonBox["2.1.1",
    ButtonData:>{"Wavelets 2.1.1", "1.17"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Time-frequency plot"],

Cell[TextData[{
  "Transfer function, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        plot of, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.126"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.3.2",
    ButtonData:>{"Wavelets 1.3.2", "2.26"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Transfer function"],

Cell[TextData[{
  "Two\[Hyphen]scale equation, ",
  ButtonBox["1.2.3",
    ButtonData:>{"Wavelets 1.2.3", "3.4"},
    ButtonStyle->"AddOnsLink"],
  "\n        for B\[Hyphen]spline, ",
  ButtonBox["1.3.1",
    ButtonData:>{"Wavelets 1.3.1", "1.21"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Two-scale equation"],

Cell[TextData[{
  "Upsampling, ",
  ButtonBox["1.5.3",
    ButtonData:>{"Wavelets 1.5.3", "3.18"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Upsampling"],

Cell[TextData[{
  "Walsh functions, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.24"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Walsh functions"],

Cell[TextData[{
  "Wavelet, basic, ",
  ButtonBox["1.2.4",
    ButtonData:>{"Wavelets 1.2.4", "4.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        derivatives of, ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.31"},
    ButtonStyle->"AddOnsLink"],
  "\n        in Fourier space, ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.12"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.4.6",
    ButtonData:>{"Wavelets 1.4.6", "6.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        in two dimensions, ",
  ButtonBox["1.5.4",
    ButtonData:>{"Wavelets 1.5.4", "4.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        mother, ",
  ButtonBox["1.2.4",
    ButtonData:>{"Wavelets 1.2.4", "4.6"},
    ButtonStyle->"AddOnsLink"],
  "\n        orthogonality condition of, ",
  ButtonBox["1.2.5",
    ButtonData:>{"Wavelets 1.2.5", "5.33"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet"],

Cell[TextData[{
  StyleBox["Wavelet", "MR"],
  ", ",
  ButtonBox["1.4.3",
    ButtonData:>{"Wavelets 1.4.3", "3.32"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet"],

Cell[TextData[{
  "Wavelet equation, ",
  ButtonBox["1.2.4",
    ButtonData:>{"Wavelets 1.2.4", "4.8"},
    ButtonStyle->"AddOnsLink"],
  "\n        in two dimensions, ",
  ButtonBox["1.5.4",
    ButtonData:>{"Wavelets 1.5.4", "4.8"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet equation"],

Cell[TextData[{
  "Wavelet packet, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.12"},
    ButtonStyle->"AddOnsLink"],
  "\n        generate, ",
  ButtonBox["1.5.7",
    ButtonData:>{"Wavelets 1.5.7", "7.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet packet"],

Cell[TextData[{
  "Wavelet packet transform, ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet packet transform"],

Cell[TextData[{
  "Wavelet shrinkage method, ",
  ButtonBox["2.1.2",
    ButtonData:>{"Wavelets 2.1.2", "2.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet shrinkage method"],

Cell[TextData[{
  "Wavelet transform, ",
  ButtonBox["1.5.1",
    ButtonData:>{"Wavelets 1.5.1", "1.1"},
    ButtonStyle->"AddOnsLink"],
  "\n        biorthogonal, ",
  ButtonBox["1.6.4",
    ButtonData:>{"Wavelets 1.6.4", "4.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        in two dimensions, ",
  ButtonBox["1.5.4",
    ButtonData:>{"Wavelets 1.5.4", "4.1"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Wavelet transform"],

Cell[TextData[{
  StyleBox["WaveletPacket", "MR"],
  ", ",
  ButtonBox["1.5.7",
    ButtonData:>{"Wavelets 1.5.7", "7.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"WaveletPacket"],

Cell[TextData[{
  StyleBox["WaveletPacketCoefficients", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.27"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.29"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"WaveletPacketCoefficients"],

Cell[TextData[{
  StyleBox["WaveletPacketTransform", "MR"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.37"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.6",
    ButtonData:>{"Wavelets 1.5.6", "6.39"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.2",
    ButtonData:>{"Wavelets 3.2.2", "2.7"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"WaveletPacketTransform"],

Cell[TextData[{
  StyleBox["WaveletTransform", "MR"],
  ", ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.5.5",
    ButtonData:>{"Wavelets 1.5.5", "5.15"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.2.1",
    ButtonData:>{"Wavelets 3.2.1", "1.15"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"WaveletTransform"],

Cell[TextData[{
  "Window function, ",
  ButtonBox["1.7.1",
    ButtonData:>{"Wavelets 1.7.1", "1.2"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.2"},
    ButtonStyle->"AddOnsLink"],
  "\n        construction of, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.22"},
    ButtonStyle->"AddOnsLink"],
  "\n        properties of, ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.18"},
    ButtonStyle->"AddOnsLink"],
  "\n        rectangular, ",
  ButtonBox["1.7.1",
    ButtonData:>{"Wavelets 1.7.1", "1.4"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Window function"],

Cell[TextData[{
  "Windowed Fourier transform, ",
  ButtonBox["1.7.1",
    ButtonData:>{"Wavelets 1.7.1", "1.2"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Windowed Fourier transform"],

Cell[TextData[{
  StyleBox["WindowFunction", "MR"],
  ", ",
  ButtonBox["1.7.3",
    ButtonData:>{"Wavelets 1.7.3", "3.27"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.2",
    ButtonData:>{"Wavelets 3.1.2", "2.54"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"WindowFunction"],

Cell[TextData[{
  StyleBox["Zoom", "MR"],
  ", ",
  ButtonBox["1.5.8",
    ButtonData:>{"Wavelets 1.5.8", "8.3"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["3.1.3",
    ButtonData:>{"Wavelets 3.1.3", "3.3"},
    ButtonStyle->"AddOnsLink"]
}], "Index",
  CellTags->"Zoom"],

Cell[TextData[{
  "Zoom in, ",
  ButtonBox["1.5.8",
    ButtonData:>{"Wavelets 1.5.8", "8.2"},
    ButtonStyle->"AddOnsLink"],
  " "
}], "Index"]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 15}, {34, Automatic}},
Visible->True,
StyleDefinitions -> "HelpBrowser.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MasterIndexHeading"->{
    Cell[1709, 49, 125, 4, 41, "IndexSection",
      CellTags->"MasterIndexHeading"]},
  "Approximation space"->{
    Cell[1837, 55, 185, 6, 16, "Index",
      CellTags->"Approximation space"]},
  "B-splines"->{
    Cell[2025, 63, 413, 14, 32, "Index",
      CellTags->"B-splines"]},
  "Band-limited function"->{
    Cell[2441, 79, 197, 6, 16, "Index",
      CellTags->"Band-limited function"]},
  "BasisType"->{
    Cell[2641, 87, 397, 15, 16, "Index",
      CellTags->"BasisType"]},
  "Battle-Lemarie wavelet"->{
    Cell[3041, 104, 341, 10, 32, "Index",
      CellTags->"Battle-Lemarie wavelet"]},
  "Bell"->{
    Cell[3385, 116, 155, 6, 16, "Index",
      CellTags->"Bell"]},
  "Best basis"->{
    Cell[3543, 124, 168, 6, 16, "Index",
      CellTags->"Best basis"]},
  "Best level"->{
    Cell[3714, 132, 168, 6, 16, "Index",
      CellTags->"Best level"]},
  "BestLevel"->{
    Cell[3885, 140, 397, 15, 16, "Index",
      CellTags->"BestLevel"]},
  "Biorthogonal spline filter"->{
    Cell[4285, 157, 200, 6, 16, "Index",
      CellTags->"Biorthogonal spline filter"]},
  "Biorthogonal wavelets"->{
    Cell[4488, 165, 189, 6, 16, "Index",
      CellTags->"Biorthogonal wavelets"]},
  "Biorthogonality conditions"->{
    Cell[4680, 173, 435, 14, 32, "Index",
      CellTags->"Biorthogonality conditions"]},
  "BiorthogonalSplineFilter"->{
    Cell[5118, 189, 323, 11, 16, "Index",
      CellTags->"BiorthogonalSplineFilter"]},
  "Boundary condition"->{
    Cell[5444, 202, 184, 6, 16, "Index",
      CellTags->"Boundary condition"]},
  "BoundaryCondition"->{
    Cell[5631, 210, 833, 31, 16, "Index",
      CellTags->"BoundaryCondition"]},
  "Box function"->{
    Cell[6467, 243, 171, 6, 16, "Index",
      CellTags->"Box function"]},
  "BSpline"->{
    Cell[6641, 251, 289, 11, 16, "Index",
      CellTags->"BSpline"]},
  "Burgers equation"->{
    Cell[6933, 264, 179, 6, 16, "Index",
      CellTags->"Burgers equation"]},
  "Cascade algorithm"->{
    Cell[7115, 272, 181, 6, 16, "Index",
      CellTags->"Cascade algorithm"]},
  "Chirp signal"->{
    Cell[7299, 280, 171, 6, 16, "Index",
      CellTags->"Chirp signal"]},
  "CoifletFilter"->{
    Cell[7473, 288, 301, 11, 16, "Index",
      CellTags->"CoifletFilter"]},
  "Coiflets filters"->{
    Cell[7777, 301, 179, 6, 16, "Index",
      CellTags->"Coiflets filters"]},
  "Coifman and Meyer basis"->{
    Cell[7959, 309, 193, 6, 16, "Index",
      CellTags->"Coifman and Meyer basis"]},
  "Compress"->{
    Cell[8155, 317, 287, 11, 16, "Index",
      CellTags->"Compress"]},
  "Compression"->{
    Cell[8445, 330, 176, 6, 16, "Index",
      CellTags->"Compression"]},
  "Compression ratio"->{
    Cell[8624, 338, 182, 6, 16, "Index",
      CellTags->"Compression ratio"]},
  "Cos-II and Cos-IV bases"->{
    Cell[8809, 346, 210, 6, 16, "Index",
      CellTags->"Cos-II and Cos-IV bases"]},
  "Cosine packet"->{
    Cell[9022, 354, 174, 6, 16, "Index",
      CellTags->"Cosine packet"]},
  "CosPacket"->{
    Cell[9199, 362, 293, 11, 16, "Index",
      CellTags->"CosPacket"]},
  "CosPacketCoefficients"->{
    Cell[9495, 375, 315, 11, 16, "Index",
      CellTags->"CosPacketCoefficients"]},
  "CosPacketTransform"->{
    Cell[9813, 388, 310, 11, 16, "Index",
      CellTags->"CosPacketTransform"]},
  "Cost function"->{
    Cell[10126, 401, 174, 6, 16, "Index",
      CellTags->"Cost function"]},
  "CostFunction"->{
    Cell[10303, 409, 403, 15, 70, "Index",
      CellTags->"CostFunction"]},
  "CosTransform"->{
    Cell[10709, 426, 404, 15, 70, "Index",
      CellTags->"CosTransform"]},
  "Cumulative energy"->{
    Cell[11116, 443, 182, 6, 70, "Index",
      CellTags->"Cumulative energy"]},
  "CumulativeEnergy"->{
    Cell[11301, 451, 303, 11, 70, "Index",
      CellTags->"CumulativeEnergy"]},
  "Data compression"->{
    Cell[11607, 464, 180, 6, 70, "Index",
      CellTags->"Data compression"]},
  "Daubechies filters"->{
    Cell[11790, 472, 435, 14, 70, "Index",
      CellTags->"Daubechies filters"]},
  "Daubechies wavelets"->{
    Cell[12228, 488, 462, 14, 70, "Index",
      CellTags->"Daubechies wavelets"]},
  "DaubechiesFilter"->{
    Cell[12693, 504, 412, 15, 70, "Index",
      CellTags->"DaubechiesFilter"]},
  "Decimation"->{
    Cell[13108, 521, 167, 6, 70, "Index",
      CellTags->"Decimation"]},
  "Denoising"->{
    Cell[13278, 529, 313, 10, 70, "Index",
      CellTags->"Denoising"]},
  "Detail space"->{
    Cell[13594, 541, 171, 6, 70, "Index",
      CellTags->"Detail space"]},
  "Dilation equation"->{
    Cell[13768, 549, 442, 14, 70, "Index",
      CellTags->"Dilation equation"]},
  "Discrete sine and cosine transforms"->{
    Cell[14213, 565, 349, 10, 70, "Index",
      CellTags->"Discrete sine and cosine transforms"]},
  "Down-sampling"->{
    Cell[14565, 577, 181, 6, 70, "Index",
      CellTags->"Down-sampling"]},
  "DScalingFunction"->{
    Cell[14749, 585, 306, 11, 70, "Index",
      CellTags->"DScalingFunction"]},
  "Dual basis"->{
    Cell[15058, 598, 167, 6, 70, "Index",
      CellTags->"Dual basis"]},
  "Dual multiresolution analysis"->{
    Cell[15228, 606, 205, 6, 70, "Index",
      CellTags->"Dual multiresolution analysis"]},
  "Dual scaling function"->{
    Cell[15436, 614, 189, 6, 70, "Index",
      CellTags->"Dual scaling function"]},
  "dual space"->{
    Cell[15628, 622, 167, 6, 70, "Index",
      CellTags->"dual space"]},
  "Dual wavelet"->{
    Cell[15798, 630, 171, 6, 70, "Index",
      CellTags->"Dual wavelet"]},
  "DWavelet"->{
    Cell[15972, 638, 290, 11, 70, "Index",
      CellTags->"DWavelet"]},
  "Energy"->{
    Cell[16265, 651, 309, 10, 70, "Index",
      CellTags->"Energy"]},
  "Entropy"->{
    Cell[16577, 663, 162, 6, 70, "Index",
      CellTags->"Entropy"]},
  "Entropy criterion"->{
    Cell[16742, 671, 182, 6, 70, "Index",
      CellTags->"Entropy criterion"]},
  "ExchangeAxes"->{
    Cell[16927, 679, 190, 7, 70, "Index",
      CellTags->"ExchangeAxes"]},
  "Filter"->{
    Cell[17120, 688, 776, 26, 70, "Index",
      CellTags->"Filter"]},
  "Filter bank"->{
    Cell[17899, 716, 415, 14, 70, "Index",
      CellTags->"Filter bank"]},
  "Filter coefficients"->{
    Cell[18317, 732, 951, 30, 70, "Index",
      CellTags->"Filter coefficients"]},
  "Folding"->{
    Cell[19271, 764, 162, 6, 70, "Index",
      CellTags->"Folding"]},
  "Franklin multiresolution analysis"->{
    Cell[19436, 772, 215, 6, 70, "Index",
      CellTags->"Franklin multiresolution analysis"]},
  "Franklin wavelet"->{
    Cell[19654, 780, 181, 6, 70, "Index",
      CellTags->"Franklin wavelet"]},
  "Frequency response function"->{
    Cell[19838, 788, 639, 22, 70, "Index",
      CellTags->"Frequency response function"]},
  "Gray code ordering"->{
    Cell[20480, 812, 184, 6, 70, "Index",
      CellTags->"Gray code ordering"]},
  "GrayCodeOrder"->{
    Cell[20667, 820, 297, 11, 70, "Index",
      CellTags->"GrayCodeOrder"]},
  "Haar multiresolution analysis"->{
    Cell[20967, 833, 205, 6, 70, "Index",
      CellTags->"Haar multiresolution analysis"]},
  "Haar wavelet"->{
    Cell[21175, 841, 172, 6, 70, "Index",
      CellTags->"Haar wavelet"]},
  "HaarFilter"->{
    Cell[21350, 849, 190, 7, 70, "Index",
      CellTags->"HaarFilter"]},
  "Hat function"->{
    Cell[21543, 858, 276, 10, 70, "Index",
      CellTags->"Hat function"]},
  "Highpass filter"->{
    Cell[21822, 870, 179, 6, 70, "Index",
      CellTags->"Highpass filter"]},
  "HighpassFilter"->{
    Cell[22004, 878, 302, 11, 70, "Index",
      CellTags->"HighpassFilter"]},
  "infinite impulse response (IIR)"->{
    Cell[22309, 891, 209, 6, 70, "Index",
      CellTags->"infinite impulse response (IIR)"]},
  "Interpolation"->{
    Cell[22521, 899, 196, 7, 70, "Index",
      CellTags->"Interpolation"]},
  "InterpolationDomain"->{
    Cell[22720, 908, 208, 7, 70, "Index",
      CellTags->"InterpolationDomain"]},
  "Inverse wavelet transform"->{
    Cell[22931, 917, 197, 6, 70, "Index",
      CellTags->"Inverse wavelet transform"]},
  "InverseCosPacketTransform"->{
    Cell[23131, 925, 219, 7, 70, "Index",
      CellTags->"InverseCosPacketTransform"]},
  "InverseCosTransform"->{
    Cell[23353, 934, 313, 11, 70, "Index",
      CellTags->"InverseCosTransform"]},
  "InverseMalvarTransform"->{
    Cell[23669, 947, 319, 11, 70, "Index",
      CellTags->"InverseMalvarTransform"]},
  "InverseSinPacketTransform"->{
    Cell[23991, 960, 219, 7, 70, "Index",
      CellTags->"InverseSinPacketTransform"]},
  "InverseSinTransform"->{
    Cell[24213, 969, 313, 11, 70, "Index",
      CellTags->"InverseSinTransform"]},
  "InverseTransform"->{
    Cell[24529, 982, 307, 11, 70, "Index",
      CellTags->"InverseTransform"]},
  "InverseWaveletPacketTransform"->{
    Cell[24839, 995, 332, 11, 70, "Index",
      CellTags->"InverseWaveletPacketTransform"]},
  "InverseWaveletTransform"->{
    Cell[25174, 1008, 321, 11, 70, "Index",
      CellTags->"InverseWaveletTransform"]},
  "LeastAsymmetricFilter"->{
    Cell[25498, 1021, 422, 15, 70, "Index",
      CellTags->"LeastAsymmetricFilter"]},
  "Library of bases"->{
    Cell[25923, 1038, 180, 6, 70, "Index",
      CellTags->"Library of bases"]},
  "Linear phase filter"->{
    Cell[26106, 1046, 185, 6, 70, "Index",
      CellTags->"Linear phase filter"]},
  "Local trigonometric basis"->{
    Cell[26294, 1054, 197, 6, 70, "Index",
      CellTags->"Local trigonometric basis"]},
  "Local trigonometric transform"->{
    Cell[26494, 1062, 205, 6, 70, "Index",
      CellTags->"Local trigonometric transform"]},
  "LogarithmicScale"->{
    Cell[26702, 1070, 198, 7, 70, "Index",
      CellTags->"LogarithmicScale"]},
  "Lowpass filter"->{
    Cell[26903, 1079, 177, 6, 70, "Index",
      CellTags->"Lowpass filter"]},
  "Malvar basis"->{
    Cell[27083, 1087, 276, 10, 70, "Index",
      CellTags->"Malvar basis"]},
  "MalvarTransform"->{
    Cell[27362, 1099, 305, 11, 70, "Index",
      CellTags->"MalvarTransform"]},
  "Mathematica Package"->{
    Cell[27670, 1112, 207, 7, 70, "Index",
      CellTags->"Mathematica Package"]},
  "Mean square error"->{
    Cell[27880, 1121, 192, 6, 70, "Index",
      CellTags->"Mean square error"]},
  "Meyer wavelets"->{
    Cell[28075, 1129, 412, 14, 70, "Index",
      CellTags->"Meyer wavelets"]},
  "MeyerFilter"->{
    Cell[28490, 1145, 298, 11, 70, "Index",
      CellTags->"MeyerFilter"]},
  "MeyerPhi"->{
    Cell[28791, 1158, 291, 11, 70, "Index",
      CellTags->"MeyerPhi"]},
  "MeyerPsi"->{
    Cell[29085, 1171, 291, 11, 70, "Index",
      CellTags->"MeyerPsi"]},
  "Moment-vanishing condition"->{
    Cell[29379, 1184, 333, 10, 70, "Index",
      CellTags->"Moment-vanishing condition"]},
  "MRDecomposition"->{
    Cell[29715, 1196, 200, 7, 70, "Index",
      CellTags->"MRDecomposition"]},
  "Multiresolution analysis"->{
    Cell[29918, 1205, 785, 26, 70, "Index",
      CellTags->"Multiresolution analysis"]},
  "Multiresolution decomposition"->{
    Cell[30706, 1233, 206, 6, 70, "Index",
      CellTags->"Multiresolution decomposition"]},
  "Perfect reconstruction"->{
    Cell[30915, 1241, 192, 6, 70, "Index",
      CellTags->"Perfect reconstruction"]},
  "Phase space plot"->{
    Cell[31110, 1249, 180, 6, 70, "Index",
      CellTags->"Phase space plot"]},
  "PhaseSpacePlot"->{
    Cell[31293, 1257, 298, 11, 70, "Index",
      CellTags->"PhaseSpacePlot"]},
  "PlotCoefficients"->{
    Cell[31594, 1270, 407, 15, 70, "Index",
      CellTags->"PlotCoefficients"]},
  "PlotCoefficients2D"->{
    Cell[32004, 1287, 307, 11, 70, "Index",
      CellTags->"PlotCoefficients2D"]},
  "PlotLines"->{
    Cell[32314, 1300, 184, 7, 70, "Index",
      CellTags->"PlotLines"]},
  "Polarity"->{
    Cell[32501, 1309, 269, 10, 70, "Index",
      CellTags->"Polarity"]},
  "Pyramid algorithm"->{
    Cell[32773, 1321, 182, 6, 70, "Index",
      CellTags->"Pyramid algorithm"]},
  "Refinement equation"->{
    Cell[32958, 1329, 185, 6, 70, "Index",
      CellTags->"Refinement equation"]},
  "Resolution level"->{
    Cell[33146, 1337, 279, 10, 70, "Index",
      CellTags->"Resolution level"]},
  "Response function"->{
    Cell[33428, 1349, 526, 18, 70, "Index",
      CellTags->"Response function"]},
  "Scaling function"->{
    Cell[33957, 1369, 1043, 34, 70, "Index",
      CellTags->"Scaling function"]},
  "ScalingFunction"->{
    Cell[35003, 1405, 409, 15, 70, "Index",
      CellTags->"ScalingFunction"]},
  "Shannon"->{
    Cell[35415, 1422, 545, 18, 70, "Index",
      CellTags->"Shannon"]},
  "ShannonFilter"->{
    Cell[35963, 1442, 301, 11, 70, "Index",
      CellTags->"ShannonFilter"]},
  "ShannonPhi"->{
    Cell[36267, 1455, 295, 11, 70, "Index",
      CellTags->"ShannonPhi"]},
  "ShannonPsi"->{
    Cell[36565, 1468, 295, 11, 70, "Index",
      CellTags->"ShannonPsi"]},
  "Shock"->{
    Cell[36863, 1481, 157, 6, 70, "Index",
      CellTags->"Shock"]},
  "ShowBasisPosition"->{
    Cell[37023, 1489, 305, 11, 70, "Index",
      CellTags->"ShowBasisPosition"]},
  "ShowBasisPosition2D"->{
    Cell[37331, 1502, 309, 11, 70, "Index",
      CellTags->"ShowBasisPosition2D"]},
  "Shrinking"->{
    Cell[37643, 1515, 184, 7, 70, "Index",
      CellTags->"Shrinking"]},
  "Sin packet"->{
    Cell[37830, 1524, 168, 6, 70, "Index",
      CellTags->"Sin packet"]},
  "Sin-II and Sin-IV bases"->{
    Cell[38001, 1532, 210, 6, 70, "Index",
      CellTags->"Sin-II and Sin-IV bases"]},
  "SinPacket"->{
    Cell[38214, 1540, 293, 11, 70, "Index",
      CellTags->"SinPacket"]},
  "SinPacketCoefficients"->{
    Cell[38510, 1553, 315, 11, 70, "Index",
      CellTags->"SinPacketCoefficients"]},
  "SinPacketTransform"->{
    Cell[38828, 1566, 310, 11, 70, "Index",
      CellTags->"SinPacketTransform"]},
  "SinTransform"->{
    Cell[39141, 1579, 299, 11, 70, "Index",
      CellTags->"SinTransform"]},
  "Smooth local trigonometric bases"->{
    Cell[39443, 1592, 212, 6, 70, "Index",
      CellTags->"Smooth local trigonometric bases"]},
  "Sound signal"->{
    Cell[39658, 1600, 186, 6, 70, "Index",
      CellTags->"Sound signal"]},
  "Spectral factorization"->{
    Cell[39847, 1608, 192, 6, 70, "Index",
      CellTags->"Spectral factorization"]},
  "Speech signal"->{
    Cell[40042, 1616, 189, 6, 70, "Index",
      CellTags->"Speech signal"]},
  "Spline"->{
    Cell[40234, 1624, 1041, 34, 70, "Index",
      CellTags->"Spline"]},
  "SplineFilter"->{
    Cell[41278, 1660, 299, 11, 70, "Index",
      CellTags->"SplineFilter"]},
  "SplinePhi"->{
    Cell[41580, 1673, 398, 15, 70, "Index",
      CellTags->"SplinePhi"]},
  "SplinePsi"->{
    Cell[41981, 1690, 294, 11, 70, "Index",
      CellTags->"SplinePsi"]},
  "Splitting algorithm"->{
    Cell[42278, 1703, 185, 6, 70, "Index",
      CellTags->"Splitting algorithm"]},
  "Subband filtering"->{
    Cell[42466, 1711, 181, 6, 70, "Index",
      CellTags->"Subband filtering"]},
  "Taper"->{
    Cell[42650, 1719, 599, 23, 70, "Index",
      CellTags->"Taper"]},
  "Taper function"->{
    Cell[43252, 1744, 281, 10, 70, "Index",
      CellTags->"Taper function"]},
  "Taper width"->{
    Cell[43536, 1756, 170, 6, 70, "Index",
      CellTags->"Taper width"]},
  "Threshold"->{
    Cell[43709, 1764, 184, 7, 70, "Index",
      CellTags->"Threshold"]},
  "Threshold function"->{
    Cell[43896, 1773, 184, 6, 70, "Index",
      CellTags->"Threshold function"]},
  "Time-frequency plot"->{
    Cell[44083, 1781, 194, 6, 70, "Index",
      CellTags->"Time-frequency plot"]},
  "Transfer function"->{
    Cell[44280, 1789, 619, 22, 70, "Index",
      CellTags->"Transfer function"]},
  "Two-scale equation"->{
    Cell[44902, 1813, 326, 10, 70, "Index",
      CellTags->"Two-scale equation"]},
  "Upsampling"->{
    Cell[45231, 1825, 168, 6, 70, "Index",
      CellTags->"Upsampling"]},
  "Walsh functions"->{
    Cell[45402, 1833, 178, 6, 70, "Index",
      CellTags->"Walsh functions"]},
  "Wavelet"->{
    Cell[45583, 1841, 924, 30, 70, "Index",
      CellTags->"Wavelet"],
    Cell[46510, 1873, 288, 11, 70, "Index",
      CellTags->"Wavelet"]},
  "Wavelet equation"->{
    Cell[46801, 1886, 310, 10, 70, "Index",
      CellTags->"Wavelet equation"]},
  "Wavelet packet"->{
    Cell[47114, 1898, 298, 10, 70, "Index",
      CellTags->"Wavelet packet"]},
  "Wavelet packet transform"->{
    Cell[47415, 1910, 195, 6, 70, "Index",
      CellTags->"Wavelet packet transform"]},
  "Wavelet shrinkage method"->{
    Cell[47613, 1918, 195, 6, 70, "Index",
      CellTags->"Wavelet shrinkage method"]},
  "Wavelet transform"->{
    Cell[47811, 1926, 438, 14, 70, "Index",
      CellTags->"Wavelet transform"]},
  "WaveletPacket"->{
    Cell[48252, 1942, 299, 11, 70, "Index",
      CellTags->"WaveletPacket"]},
  "WaveletPacketCoefficients"->{
    Cell[48554, 1955, 429, 15, 70, "Index",
      CellTags->"WaveletPacketCoefficients"]},
  "WaveletPacketTransform"->{
    Cell[48986, 1972, 423, 15, 70, "Index",
      CellTags->"WaveletPacketTransform"]},
  "WaveletTransform"->{
    Cell[49412, 1989, 411, 15, 70, "Index",
      CellTags->"WaveletTransform"]},
  "Window function"->{
    Cell[49826, 2006, 664, 22, 70, "Index",
      CellTags->"Window function"]},
  "Windowed Fourier transform"->{
    Cell[50493, 2030, 199, 6, 70, "Index",
      CellTags->"Windowed Fourier transform"]},
  "WindowFunction"->{
    Cell[50695, 2038, 303, 11, 70, "Index",
      CellTags->"WindowFunction"]},
  "Zoom"->{
    Cell[51001, 2051, 281, 11, 70, "Index",
      CellTags->"Zoom"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MasterIndexHeading", 52081, 2090},
  {"Approximation space", 52195, 2093},
  {"B-splines", 52293, 2096},
  {"Band-limited function", 52394, 2099},
  {"BasisType", 52494, 2102},
  {"Battle-Lemarie wavelet", 52596, 2105},
  {"Bell", 52694, 2108},
  {"Best basis", 52779, 2111},
  {"Best level", 52870, 2114},
  {"BestLevel", 52960, 2117},
  {"Biorthogonal spline filter", 53067, 2120},
  {"Biorthogonal wavelets", 53185, 2123},
  {"Biorthogonality conditions", 53303, 2126},
  {"BiorthogonalSplineFilter", 53425, 2129},
  {"Boundary condition", 53539, 2132},
  {"BoundaryCondition", 53645, 2135},
  {"Box function", 53746, 2138},
  {"BSpline", 53836, 2141},
  {"Burgers equation", 53931, 2144},
  {"Cascade algorithm", 54035, 2147},
  {"Chirp signal", 54135, 2150},
  {"CoifletFilter", 54231, 2153},
  {"Coiflets filters", 54332, 2156},
  {"Coifman and Meyer basis", 54442, 2159},
  {"Compress", 54544, 2162},
  {"Compression", 54635, 2165},
  {"Compression ratio", 54734, 2168},
  {"Cos-II and Cos-IV bases", 54845, 2171},
  {"Cosine packet", 54952, 2174},
  {"CosPacket", 55045, 2177},
  {"CosPacketCoefficients", 55147, 2180},
  {"CosPacketTransform", 55258, 2183},
  {"Cost function", 55361, 2186},
  {"CostFunction", 55458, 2189},
  {"CosTransform", 55555, 2192},
  {"Cumulative energy", 55657, 2195},
  {"CumulativeEnergy", 55762, 2198},
  {"Data compression", 55867, 2201},
  {"Daubechies filters", 55973, 2204},
  {"Daubechies wavelets", 56083, 2207},
  {"DaubechiesFilter", 56191, 2210},
  {"Decimation", 56290, 2213},
  {"Denoising", 56381, 2216},
  {"Detail space", 56475, 2219},
  {"Dilation equation", 56576, 2222},
  {"Discrete sine and cosine transforms", 56701, 2225},
  {"Down-sampling", 56822, 2228},
  {"DScalingFunction", 56923, 2231},
  {"Dual basis", 57022, 2234},
  {"Dual multiresolution analysis", 57133, 2237},
  {"Dual scaling function", 57255, 2240},
  {"dual space", 57358, 2243},
  {"Dual wavelet", 57452, 2246},
  {"DWavelet", 57544, 2249},
  {"Energy", 57631, 2252},
  {"Entropy", 57717, 2255},
  {"Entropy criterion", 57813, 2258},
  {"ExchangeAxes", 57914, 2261},
  {"Filter", 58004, 2264},
  {"Filter bank", 58094, 2267},
  {"Filter coefficients", 58197, 2270},
  {"Folding", 58296, 2273},
  {"Franklin multiresolution analysis", 58408, 2276},
  {"Franklin wavelet", 58529, 2279},
  {"Frequency response function", 58644, 2282},
  {"Gray code ordering", 58762, 2285},
  {"GrayCodeOrder", 58865, 2288},
  {"Haar multiresolution analysis", 58980, 2291},
  {"Haar wavelet", 59093, 2294},
  {"HaarFilter", 59187, 2297},
  {"Hat function", 59281, 2300},
  {"Highpass filter", 59381, 2303},
  {"HighpassFilter", 59482, 2306},
  {"infinite impulse response (IIR)", 59600, 2309},
  {"Interpolation", 59716, 2312},
  {"InterpolationDomain", 59820, 2315},
  {"Inverse wavelet transform", 59936, 2318},
  {"InverseCosPacketTransform", 60058, 2321},
  {"InverseCosTransform", 60174, 2324},
  {"InverseMalvarTransform", 60288, 2327},
  {"InverseSinPacketTransform", 60408, 2330},
  {"InverseSinTransform", 60524, 2333},
  {"InverseTransform", 60632, 2336},
  {"InverseWaveletPacketTransform", 60750, 2339},
  {"InverseWaveletTransform", 60875, 2342},
  {"LeastAsymmetricFilter", 60993, 2345},
  {"Library of bases", 61104, 2348},
  {"Linear phase filter", 61212, 2351},
  {"Local trigonometric basis", 61329, 2354},
  {"Local trigonometric transform", 61456, 2357},
  {"LogarithmicScale", 61574, 2360},
  {"Lowpass filter", 61677, 2363},
  {"Malvar basis", 61776, 2366},
  {"MalvarTransform", 61877, 2369},
  {"Mathematica Package", 61985, 2372},
  {"Mean square error", 62094, 2375},
  {"Meyer wavelets", 62198, 2378},
  {"MeyerFilter", 62297, 2381},
  {"MeyerPhi", 62390, 2384},
  {"MeyerPsi", 62480, 2387},
  {"Moment-vanishing condition", 62588, 2390},
  {"MRDecomposition", 62703, 2393},
  {"Multiresolution analysis", 62815, 2396},
  {"Multiresolution decomposition", 62942, 2399},
  {"Perfect reconstruction", 63066, 2402},
  {"Phase space plot", 63177, 2405},
  {"PhaseSpacePlot", 63280, 2408},
  {"PlotCoefficients", 63384, 2411},
  {"PlotCoefficients2D", 63492, 2414},
  {"PlotLines", 63593, 2417},
  {"Polarity", 63683, 2420},
  {"Pyramid algorithm", 63782, 2423},
  {"Refinement equation", 63891, 2426},
  {"Resolution level", 63999, 2429},
  {"Response function", 64106, 2432},
  {"Scaling function", 64213, 2435},
  {"ScalingFunction", 64319, 2438},
  {"Shannon", 64415, 2441},
  {"ShannonFilter", 64509, 2444},
  {"ShannonPhi", 64606, 2447},
  {"ShannonPsi", 64700, 2450},
  {"Shock", 64789, 2453},
  {"ShowBasisPosition", 64884, 2456},
  {"ShowBasisPosition2D", 64994, 2459},
  {"Shrinking", 65096, 2462},
  {"Sin packet", 65188, 2465},
  {"Sin-II and Sin-IV bases", 65294, 2468},
  {"SinPacket", 65399, 2471},
  {"SinPacketCoefficients", 65503, 2474},
  {"SinPacketTransform", 65616, 2477},
  {"SinTransform", 65720, 2480},
  {"Smooth local trigonometric bases", 65838, 2483},
  {"Sound signal", 65955, 2486},
  {"Spectral factorization", 66062, 2489},
  {"Speech signal", 66170, 2492},
  {"Spline", 66262, 2495},
  {"SplineFilter", 66355, 2498},
  {"SplinePhi", 66450, 2501},
  {"SplinePsi", 66542, 2504},
  {"Splitting algorithm", 66644, 2507},
  {"Subband filtering", 66753, 2510},
  {"Taper", 66848, 2513},
  {"Taper function", 66941, 2516},
  {"Taper width", 67040, 2519},
  {"Threshold", 67133, 2522},
  {"Threshold function", 67233, 2525},
  {"Time-frequency plot", 67343, 2528},
  {"Transfer function", 67452, 2531},
  {"Two-scale equation", 67561, 2534},
  {"Upsampling", 67663, 2537},
  {"Walsh functions", 67761, 2540},
  {"Wavelet", 67856, 2543},
  {"Wavelet equation", 68025, 2548},
  {"Wavelet packet", 68129, 2551},
  {"Wavelet packet transform", 68241, 2554},
  {"Wavelet shrinkage method", 68362, 2557},
  {"Wavelet transform", 68476, 2560},
  {"WaveletPacket", 68580, 2563},
  {"WaveletPacketCoefficients", 68692, 2566},
  {"WaveletPacketTransform", 68813, 2569},
  {"WaveletTransform", 68925, 2572},
  {"Window function", 69030, 2575},
  {"Windowed Fourier transform", 69145, 2578},
  {"WindowFunction", 69258, 2581},
  {"Zoom", 69350, 2584}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 125, 4, 41, "IndexSection",
  CellTags->"MasterIndexHeading"],
Cell[1837, 55, 185, 6, 16, "Index",
  CellTags->"Approximation space"],
Cell[2025, 63, 413, 14, 32, "Index",
  CellTags->"B-splines"],
Cell[2441, 79, 197, 6, 16, "Index",
  CellTags->"Band-limited function"],
Cell[2641, 87, 397, 15, 16, "Index",
  CellTags->"BasisType"],
Cell[3041, 104, 341, 10, 32, "Index",
  CellTags->"Battle-Lemarie wavelet"],
Cell[3385, 116, 155, 6, 16, "Index",
  CellTags->"Bell"],
Cell[3543, 124, 168, 6, 16, "Index",
  CellTags->"Best basis"],
Cell[3714, 132, 168, 6, 16, "Index",
  CellTags->"Best level"],
Cell[3885, 140, 397, 15, 16, "Index",
  CellTags->"BestLevel"],
Cell[4285, 157, 200, 6, 16, "Index",
  CellTags->"Biorthogonal spline filter"],
Cell[4488, 165, 189, 6, 16, "Index",
  CellTags->"Biorthogonal wavelets"],
Cell[4680, 173, 435, 14, 32, "Index",
  CellTags->"Biorthogonality conditions"],
Cell[5118, 189, 323, 11, 16, "Index",
  CellTags->"BiorthogonalSplineFilter"],
Cell[5444, 202, 184, 6, 16, "Index",
  CellTags->"Boundary condition"],
Cell[5631, 210, 833, 31, 16, "Index",
  CellTags->"BoundaryCondition"],
Cell[6467, 243, 171, 6, 16, "Index",
  CellTags->"Box function"],
Cell[6641, 251, 289, 11, 16, "Index",
  CellTags->"BSpline"],
Cell[6933, 264, 179, 6, 16, "Index",
  CellTags->"Burgers equation"],
Cell[7115, 272, 181, 6, 16, "Index",
  CellTags->"Cascade algorithm"],
Cell[7299, 280, 171, 6, 16, "Index",
  CellTags->"Chirp signal"],
Cell[7473, 288, 301, 11, 16, "Index",
  CellTags->"CoifletFilter"],
Cell[7777, 301, 179, 6, 16, "Index",
  CellTags->"Coiflets filters"],
Cell[7959, 309, 193, 6, 16, "Index",
  CellTags->"Coifman and Meyer basis"],
Cell[8155, 317, 287, 11, 16, "Index",
  CellTags->"Compress"],
Cell[8445, 330, 176, 6, 16, "Index",
  CellTags->"Compression"],
Cell[8624, 338, 182, 6, 16, "Index",
  CellTags->"Compression ratio"],
Cell[8809, 346, 210, 6, 16, "Index",
  CellTags->"Cos-II and Cos-IV bases"],
Cell[9022, 354, 174, 6, 16, "Index",
  CellTags->"Cosine packet"],
Cell[9199, 362, 293, 11, 16, "Index",
  CellTags->"CosPacket"],
Cell[9495, 375, 315, 11, 16, "Index",
  CellTags->"CosPacketCoefficients"],
Cell[9813, 388, 310, 11, 16, "Index",
  CellTags->"CosPacketTransform"],
Cell[10126, 401, 174, 6, 16, "Index",
  CellTags->"Cost function"],
Cell[10303, 409, 403, 15, 70, "Index",
  CellTags->"CostFunction"],
Cell[10709, 426, 404, 15, 70, "Index",
  CellTags->"CosTransform"],
Cell[11116, 443, 182, 6, 70, "Index",
  CellTags->"Cumulative energy"],
Cell[11301, 451, 303, 11, 70, "Index",
  CellTags->"CumulativeEnergy"],
Cell[11607, 464, 180, 6, 70, "Index",
  CellTags->"Data compression"],
Cell[11790, 472, 435, 14, 70, "Index",
  CellTags->"Daubechies filters"],
Cell[12228, 488, 462, 14, 70, "Index",
  CellTags->"Daubechies wavelets"],
Cell[12693, 504, 412, 15, 70, "Index",
  CellTags->"DaubechiesFilter"],
Cell[13108, 521, 167, 6, 70, "Index",
  CellTags->"Decimation"],
Cell[13278, 529, 313, 10, 70, "Index",
  CellTags->"Denoising"],
Cell[13594, 541, 171, 6, 70, "Index",
  CellTags->"Detail space"],
Cell[13768, 549, 442, 14, 70, "Index",
  CellTags->"Dilation equation"],
Cell[14213, 565, 349, 10, 70, "Index",
  CellTags->"Discrete sine and cosine transforms"],
Cell[14565, 577, 181, 6, 70, "Index",
  CellTags->"Down-sampling"],
Cell[14749, 585, 306, 11, 70, "Index",
  CellTags->"DScalingFunction"],
Cell[15058, 598, 167, 6, 70, "Index",
  CellTags->"Dual basis"],
Cell[15228, 606, 205, 6, 70, "Index",
  CellTags->"Dual multiresolution analysis"],
Cell[15436, 614, 189, 6, 70, "Index",
  CellTags->"Dual scaling function"],
Cell[15628, 622, 167, 6, 70, "Index",
  CellTags->"dual space"],
Cell[15798, 630, 171, 6, 70, "Index",
  CellTags->"Dual wavelet"],
Cell[15972, 638, 290, 11, 70, "Index",
  CellTags->"DWavelet"],
Cell[16265, 651, 309, 10, 70, "Index",
  CellTags->"Energy"],
Cell[16577, 663, 162, 6, 70, "Index",
  CellTags->"Entropy"],
Cell[16742, 671, 182, 6, 70, "Index",
  CellTags->"Entropy criterion"],
Cell[16927, 679, 190, 7, 70, "Index",
  CellTags->"ExchangeAxes"],
Cell[17120, 688, 776, 26, 70, "Index",
  CellTags->"Filter"],
Cell[17899, 716, 415, 14, 70, "Index",
  CellTags->"Filter bank"],
Cell[18317, 732, 951, 30, 70, "Index",
  CellTags->"Filter coefficients"],
Cell[19271, 764, 162, 6, 70, "Index",
  CellTags->"Folding"],
Cell[19436, 772, 215, 6, 70, "Index",
  CellTags->"Franklin multiresolution analysis"],
Cell[19654, 780, 181, 6, 70, "Index",
  CellTags->"Franklin wavelet"],
Cell[19838, 788, 639, 22, 70, "Index",
  CellTags->"Frequency response function"],
Cell[20480, 812, 184, 6, 70, "Index",
  CellTags->"Gray code ordering"],
Cell[20667, 820, 297, 11, 70, "Index",
  CellTags->"GrayCodeOrder"],
Cell[20967, 833, 205, 6, 70, "Index",
  CellTags->"Haar multiresolution analysis"],
Cell[21175, 841, 172, 6, 70, "Index",
  CellTags->"Haar wavelet"],
Cell[21350, 849, 190, 7, 70, "Index",
  CellTags->"HaarFilter"],
Cell[21543, 858, 276, 10, 70, "Index",
  CellTags->"Hat function"],
Cell[21822, 870, 179, 6, 70, "Index",
  CellTags->"Highpass filter"],
Cell[22004, 878, 302, 11, 70, "Index",
  CellTags->"HighpassFilter"],
Cell[22309, 891, 209, 6, 70, "Index",
  CellTags->"infinite impulse response (IIR)"],
Cell[22521, 899, 196, 7, 70, "Index",
  CellTags->"Interpolation"],
Cell[22720, 908, 208, 7, 70, "Index",
  CellTags->"InterpolationDomain"],
Cell[22931, 917, 197, 6, 70, "Index",
  CellTags->"Inverse wavelet transform"],
Cell[23131, 925, 219, 7, 70, "Index",
  CellTags->"InverseCosPacketTransform"],
Cell[23353, 934, 313, 11, 70, "Index",
  CellTags->"InverseCosTransform"],
Cell[23669, 947, 319, 11, 70, "Index",
  CellTags->"InverseMalvarTransform"],
Cell[23991, 960, 219, 7, 70, "Index",
  CellTags->"InverseSinPacketTransform"],
Cell[24213, 969, 313, 11, 70, "Index",
  CellTags->"InverseSinTransform"],
Cell[24529, 982, 307, 11, 70, "Index",
  CellTags->"InverseTransform"],
Cell[24839, 995, 332, 11, 70, "Index",
  CellTags->"InverseWaveletPacketTransform"],
Cell[25174, 1008, 321, 11, 70, "Index",
  CellTags->"InverseWaveletTransform"],
Cell[25498, 1021, 422, 15, 70, "Index",
  CellTags->"LeastAsymmetricFilter"],
Cell[25923, 1038, 180, 6, 70, "Index",
  CellTags->"Library of bases"],
Cell[26106, 1046, 185, 6, 70, "Index",
  CellTags->"Linear phase filter"],
Cell[26294, 1054, 197, 6, 70, "Index",
  CellTags->"Local trigonometric basis"],
Cell[26494, 1062, 205, 6, 70, "Index",
  CellTags->"Local trigonometric transform"],
Cell[26702, 1070, 198, 7, 70, "Index",
  CellTags->"LogarithmicScale"],
Cell[26903, 1079, 177, 6, 70, "Index",
  CellTags->"Lowpass filter"],
Cell[27083, 1087, 276, 10, 70, "Index",
  CellTags->"Malvar basis"],
Cell[27362, 1099, 305, 11, 70, "Index",
  CellTags->"MalvarTransform"],
Cell[27670, 1112, 207, 7, 70, "Index",
  CellTags->"Mathematica Package"],
Cell[27880, 1121, 192, 6, 70, "Index",
  CellTags->"Mean square error"],
Cell[28075, 1129, 412, 14, 70, "Index",
  CellTags->"Meyer wavelets"],
Cell[28490, 1145, 298, 11, 70, "Index",
  CellTags->"MeyerFilter"],
Cell[28791, 1158, 291, 11, 70, "Index",
  CellTags->"MeyerPhi"],
Cell[29085, 1171, 291, 11, 70, "Index",
  CellTags->"MeyerPsi"],
Cell[29379, 1184, 333, 10, 70, "Index",
  CellTags->"Moment-vanishing condition"],
Cell[29715, 1196, 200, 7, 70, "Index",
  CellTags->"MRDecomposition"],
Cell[29918, 1205, 785, 26, 70, "Index",
  CellTags->"Multiresolution analysis"],
Cell[30706, 1233, 206, 6, 70, "Index",
  CellTags->"Multiresolution decomposition"],
Cell[30915, 1241, 192, 6, 70, "Index",
  CellTags->"Perfect reconstruction"],
Cell[31110, 1249, 180, 6, 70, "Index",
  CellTags->"Phase space plot"],
Cell[31293, 1257, 298, 11, 70, "Index",
  CellTags->"PhaseSpacePlot"],
Cell[31594, 1270, 407, 15, 70, "Index",
  CellTags->"PlotCoefficients"],
Cell[32004, 1287, 307, 11, 70, "Index",
  CellTags->"PlotCoefficients2D"],
Cell[32314, 1300, 184, 7, 70, "Index",
  CellTags->"PlotLines"],
Cell[32501, 1309, 269, 10, 70, "Index",
  CellTags->"Polarity"],
Cell[32773, 1321, 182, 6, 70, "Index",
  CellTags->"Pyramid algorithm"],
Cell[32958, 1329, 185, 6, 70, "Index",
  CellTags->"Refinement equation"],
Cell[33146, 1337, 279, 10, 70, "Index",
  CellTags->"Resolution level"],
Cell[33428, 1349, 526, 18, 70, "Index",
  CellTags->"Response function"],
Cell[33957, 1369, 1043, 34, 70, "Index",
  CellTags->"Scaling function"],
Cell[35003, 1405, 409, 15, 70, "Index",
  CellTags->"ScalingFunction"],
Cell[35415, 1422, 545, 18, 70, "Index",
  CellTags->"Shannon"],
Cell[35963, 1442, 301, 11, 70, "Index",
  CellTags->"ShannonFilter"],
Cell[36267, 1455, 295, 11, 70, "Index",
  CellTags->"ShannonPhi"],
Cell[36565, 1468, 295, 11, 70, "Index",
  CellTags->"ShannonPsi"],
Cell[36863, 1481, 157, 6, 70, "Index",
  CellTags->"Shock"],
Cell[37023, 1489, 305, 11, 70, "Index",
  CellTags->"ShowBasisPosition"],
Cell[37331, 1502, 309, 11, 70, "Index",
  CellTags->"ShowBasisPosition2D"],
Cell[37643, 1515, 184, 7, 70, "Index",
  CellTags->"Shrinking"],
Cell[37830, 1524, 168, 6, 70, "Index",
  CellTags->"Sin packet"],
Cell[38001, 1532, 210, 6, 70, "Index",
  CellTags->"Sin-II and Sin-IV bases"],
Cell[38214, 1540, 293, 11, 70, "Index",
  CellTags->"SinPacket"],
Cell[38510, 1553, 315, 11, 70, "Index",
  CellTags->"SinPacketCoefficients"],
Cell[38828, 1566, 310, 11, 70, "Index",
  CellTags->"SinPacketTransform"],
Cell[39141, 1579, 299, 11, 70, "Index",
  CellTags->"SinTransform"],
Cell[39443, 1592, 212, 6, 70, "Index",
  CellTags->"Smooth local trigonometric bases"],
Cell[39658, 1600, 186, 6, 70, "Index",
  CellTags->"Sound signal"],
Cell[39847, 1608, 192, 6, 70, "Index",
  CellTags->"Spectral factorization"],
Cell[40042, 1616, 189, 6, 70, "Index",
  CellTags->"Speech signal"],
Cell[40234, 1624, 1041, 34, 70, "Index",
  CellTags->"Spline"],
Cell[41278, 1660, 299, 11, 70, "Index",
  CellTags->"SplineFilter"],
Cell[41580, 1673, 398, 15, 70, "Index",
  CellTags->"SplinePhi"],
Cell[41981, 1690, 294, 11, 70, "Index",
  CellTags->"SplinePsi"],
Cell[42278, 1703, 185, 6, 70, "Index",
  CellTags->"Splitting algorithm"],
Cell[42466, 1711, 181, 6, 70, "Index",
  CellTags->"Subband filtering"],
Cell[42650, 1719, 599, 23, 70, "Index",
  CellTags->"Taper"],
Cell[43252, 1744, 281, 10, 70, "Index",
  CellTags->"Taper function"],
Cell[43536, 1756, 170, 6, 70, "Index",
  CellTags->"Taper width"],
Cell[43709, 1764, 184, 7, 70, "Index",
  CellTags->"Threshold"],
Cell[43896, 1773, 184, 6, 70, "Index",
  CellTags->"Threshold function"],
Cell[44083, 1781, 194, 6, 70, "Index",
  CellTags->"Time-frequency plot"],
Cell[44280, 1789, 619, 22, 70, "Index",
  CellTags->"Transfer function"],
Cell[44902, 1813, 326, 10, 70, "Index",
  CellTags->"Two-scale equation"],
Cell[45231, 1825, 168, 6, 70, "Index",
  CellTags->"Upsampling"],
Cell[45402, 1833, 178, 6, 70, "Index",
  CellTags->"Walsh functions"],
Cell[45583, 1841, 924, 30, 70, "Index",
  CellTags->"Wavelet"],
Cell[46510, 1873, 288, 11, 70, "Index",
  CellTags->"Wavelet"],
Cell[46801, 1886, 310, 10, 70, "Index",
  CellTags->"Wavelet equation"],
Cell[47114, 1898, 298, 10, 70, "Index",
  CellTags->"Wavelet packet"],
Cell[47415, 1910, 195, 6, 70, "Index",
  CellTags->"Wavelet packet transform"],
Cell[47613, 1918, 195, 6, 70, "Index",
  CellTags->"Wavelet shrinkage method"],
Cell[47811, 1926, 438, 14, 70, "Index",
  CellTags->"Wavelet transform"],
Cell[48252, 1942, 299, 11, 70, "Index",
  CellTags->"WaveletPacket"],
Cell[48554, 1955, 429, 15, 70, "Index",
  CellTags->"WaveletPacketCoefficients"],
Cell[48986, 1972, 423, 15, 70, "Index",
  CellTags->"WaveletPacketTransform"],
Cell[49412, 1989, 411, 15, 70, "Index",
  CellTags->"WaveletTransform"],
Cell[49826, 2006, 664, 22, 70, "Index",
  CellTags->"Window function"],
Cell[50493, 2030, 199, 6, 70, "Index",
  CellTags->"Windowed Fourier transform"],
Cell[50695, 2038, 303, 11, 70, "Index",
  CellTags->"WindowFunction"],
Cell[51001, 2051, 281, 11, 70, "Index",
  CellTags->"Zoom"],
Cell[51285, 2064, 145, 6, 70, "Index"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

